symbols = {
	"GMSJ01": {
		"Runtime.PPCEABI.H::memset": 0x80003100,
		"memset": 0x80003100,
		"Runtime.PPCEABI.H::__fill_mem": 0x80003130,
		"__fill_mem": 0x80003130,
		"Runtime.PPCEABI.H::memcpy": 0x800031f4,
		"memcpy": 0x800031f4,
		"TRK_MINNOW_DOLPHIN::TRK_memcpy": 0x80003244,
		"TRK_memcpy": 0x80003244,
		"TRK_MINNOW_DOLPHIN::TRK_memset": 0x80003268,
		"TRK_memset": 0x80003268,
		"TRK_MINNOW_DOLPHIN::__TRK_reset": 0x800051cc,
		"__TRK_reset": 0x800051cc,
		"os::__check_pad3": 0x800051ec,
		"__check_pad3": 0x800051ec,
		"os::__start": 0x8000522c,
		"os::__init_registers": 0x80005364,
		"__init_registers": 0x80005364,
		"os::__init_data": 0x80005380,
		"__init_data": 0x80005380,
		"os::__init_hardware": 0x80005440,
		"__init_hardware": 0x80005440,
		"os::__flush_cache": 0x80005460,
		"__flush_cache": 0x80005460,
		"Runtime.PPCEABI.H::@152": 0x80005540,
		"Runtime.PPCEABI.H::@157": 0x80005548,
		"Runtime.PPCEABI.H::@174": 0x80005550,
		"Runtime.PPCEABI.H::@182": 0x80005568,
		"Runtime.PPCEABI.H::@201": 0x80005570,
		"@201": 0x80005570,
		"Runtime.PPCEABI.H::@153": 0x800055a0,
		"Runtime.PPCEABI.H::@158": 0x800055ac,
		"Runtime.PPCEABI.H::@175": 0x800055b8,
		"Runtime.PPCEABI.H::@183": 0x800055c4,
		"Runtime.PPCEABI.H::@202": 0x800055d0,
		"@202": 0x800055d0,
		"main::main": 0x80005600,
		"main::__sinit_main_cpp": 0x80005644,
		"__sinit_main_cpp": 0x80005644,
		"JKRArchive::~JKRArchive": 0x80005770,
		"JKRArchive::findDirectory": 0x800057d4,
		"findDirectory": 0x800057d4,
		"JKRArchive::findTypeResource": 0x80005994,
		"findTypeResource": 0x80005994,
		"JKRArchive::findFsResource": 0x80005a8c,
		"findFsResource": 0x80005a8c,
		"JKRArchive::findIdxResource": 0x80005b90,
		"findIdxResource": 0x80005b90,
		"JKRArchive::findNameResource": 0x80005bb8,
		"findNameResource": 0x80005bb8,
		"JKRArchive::findPtrResource": 0x80005c78,
		"findPtrResource": 0x80005c78,
		"JKRAramArchive::JKRAramArchive": 0x80005e1c,
		"JKRAramArchive::~JKRAramArchive": 0x80005ec8,
		"JKRFile::~JKRFile": 0x80005ffc,
		"JKRAramArchive::open": 0x80006060,
		"JKRAramHeap::JKRAramHeap": 0x80006638,
		"JKRAramHeap::~JKRAramHeap": 0x8000671c,
		"JKRAramHeap::alloc": 0x800067c4,
		"JKRAramHeap::allocFromHead": 0x80006844,
		"JKRAramHeap::allocFromTail": 0x800068d0,
		"JSystem::__sinit_JKRAramHeap_cpp": 0x80006948,
		"__sinit_JKRAramHeap_cpp": 0x80006948,
		"JSUList<JKRAramBlock>::~JSUList": 0x80006994,
		"JKRAram::create": 0x800069ec,
		"JKRAram::JKRAram": 0x80006a7c,
		"JKRAram::~JKRAram": 0x80006ba8,
		"JKRAram::run": 0x80006c38,
		"JKRAram::mainRamToAram": 0x80006ca0,
		"mainRamToAram": 0x80006ca0,
		"JSystem::JKRDecompressFromAramToMainRam": 0x80007314,
		"JKRDecompressFromAramToMainRam": 0x80007314,
		"JSystem::__sinit_JKRAram_cpp": 0x80007834,
		"__sinit_JKRAram_cpp": 0x80007834,
		"JSUList<JKRAMCommand>::~JSUList": 0x80007880,
		"JKRArchive::check_mount_already": 0x800078d8,
		"check_mount_already": 0x800078d8,
		"JKRArchive::mount": 0x8000792c,
		"mount": 0x8000792c,
		"JKRArchive::becomeCurrent": 0x80007af0,
		"becomeCurrent": 0x80007af0,
		"JKRArchive::getDirEntry": 0x80007b80,
		"getDirEntry": 0x80007b80,
		"JKRArchive::getGlbResource": 0x80007bf8,
		"JKRArchive::removeResourceAll": 0x80007f14,
		"JKRArchive::removeResource": 0x80007fac,
		"JKRArchive::detachResource": 0x8000800c,
		"detachResource": 0x8000800c,
		"JKRArchive::getResSize": 0x80008048,
		"JKRArchive::countFile": 0x8000807c,
		"countFile": 0x8000807c,
		"JKRArchive::getFirstFile": 0x800080dc,
		"getFirstFile": 0x800080dc,
		"JKRCompArchive::JKRCompArchive": 0x80008184,
		"JKRCompArchive::~JKRCompArchive": 0x8000822c,
		"JKRCompArchive::open": 0x80008360,
		"JKRCompArchive::removeResourceAll": 0x80008b9c,
		"JKRCompArchive::removeResource": 0x80008c40,
		"JKRDisposer::JKRDisposer": 0x80008cb4,
		"JKRDisposer::~JKRDisposer": 0x80008d2c,
		"JKRDvdArchive::JKRDvdArchive": 0x80008db0,
		"JKRDvdArchive::~JKRDvdArchive": 0x80008e58,
		"JKRDvdArchive::open": 0x80008f60,
		"JKRDvdFile::~JKRDvdFile": 0x800097d4,
		"JKRDvdFile::initiate": 0x80009874,
		"JKRDvdFile::close": 0x800099d0,
		"close": 0x800099d0,
		"JKRDvdFile::readData": 0x80009a4c,
		"JKRDvdFile::writeData": 0x80009b14,
		"JKRDvdFile::sync": 0x80009b1c,
		"JKRDvdFile::doneProcess": 0x80009b70,
		"doneProcess": 0x80009b70,
		"JKRDvdFile::getFileSize": 0x80009ba0,
		"getFileSize": 0x80009ba0,
		"JSystem::__sinit_JKRDvdFile_cpp": 0x80009ba8,
		"__sinit_JKRDvdFile_cpp": 0x80009ba8,
		"JSUList<JKRDvdFile>::~JSUList": 0x80009bf4,
		"JKRExpHeap::createRoot": 0x80009c4c,
		"createRoot": 0x80009c4c,
		"JKRExpHeap::destroy": 0x80009e54,
		"destroy": 0x80009e54,
		"JKRExpHeap::JKRExpHeap": 0x80009ee4,
		"JKRExpHeap::~JKRExpHeap": 0x80009f88,
		"JKRExpHeap::changeGroupID": 0x80009ff4,
		"JKRExpHeap::alloc": 0x8000a04c,
		"JKRExpHeap::free": 0x8000a7d4,
		"JKRExpHeap::freeAll": 0x8000a848,
		"JKRExpHeap::freeTail": 0x8000a8c4,
		"JKRExpHeap::resize": 0x8000a954,
		"JKRExpHeap::getSize": 0x8000ab14,
		"JKRExpHeap::getFreeSize": 0x8000ab9c,
		"JKRExpHeap::getTotalFreeSize": 0x8000ac08,
		"JKRExpHeap::getUsedSize": 0x8000ac6c,
		"getUsedSize": 0x8000ac6c,
		"JKRExpHeap::check": 0x8000ace8,
		"JKRExpHeap::appendUsedList": 0x8000aecc,
		"appendUsedList": 0x8000aecc,
		"JKRExpHeap::setFreeBlock": 0x8000af64,
		"setFreeBlock": 0x8000af64,
		"JKRExpHeap::removeFreeBlock": 0x8000afb0,
		"removeFreeBlock": 0x8000afb0,
		"JKRExpHeap::recycleFreeBlock": 0x8000afe4,
		"recycleFreeBlock": 0x8000afe4,
		"JKRExpHeap::joinTwoBlocks": 0x8000b1cc,
		"joinTwoBlocks": 0x8000b1cc,
		"JKRExpHeap::dump": 0x8000b2d4,
		"JKRExpHeap::dump_sort": 0x8000b49c,
		"JKRExpHeap::CMemBlock::initiate": 0x8000b694,
		"JKRExpHeap::CMemBlock::allocFore": 0x8000b6b4,
		"allocFore": 0x8000b6b4,
		"JKRExpHeap::CMemBlock::allocBack": 0x8000b6f8,
		"allocBack": 0x8000b6f8,
		"JKRExpHeap::CMemBlock::free": 0x8000b750,
		"JKRExpHeap::CMemBlock::getHeapBlock": 0x8000b7b0,
		"getHeapBlock": 0x8000b7b0,
		"JKRExpHeap::state_register": 0x8000b7cc,
		"JKRExpHeap::state_compare": 0x8000b890,
		"JKRExpHeap::getCurrentGroupId": 0x8000b8c0,
		"JKRExpHeap::getHeapType": 0x8000b8c8,
		"JKRArcFinder::JKRArcFinder": 0x8000b920,
		"JKRArcFinder::findNextFile": 0x8000b9bc,
		"findNextFile": 0x8000b9bc,
		"JKRArcFinder::~JKRArcFinder": 0x8000ba74,
		"JKRFileLoader::JKRFileLoader": 0x8000bad0,
		"JKRFileLoader::~JKRFileLoader": 0x8000bb30,
		"JKRFileLoader::unmount": 0x8000bbbc,
		"JKRFileLoader::getVolume": 0x8000bc0c,
		"getVolume": 0x8000bc0c,
		"JKRFileLoader::changeDirectory": 0x8000bc78,
		"changeDirectory": 0x8000bc78,
		"JKRFileLoader::getResSize": 0x8000bda0,
		"JKRFileLoader::findVolume": 0x8000be30,
		"findVolume": 0x8000be30,
		"JKRFileLoader::findFirstFile": 0x8000bebc,
		"findFirstFile": 0x8000bebc,
		"JKRFileLoader::fetchVolumeName": 0x8000bf84,
		"fetchVolumeName": 0x8000bf84,
		"JSystem::__sinit_JKRFileLoader_cpp": 0x8000c06c,
		"__sinit_JKRFileLoader_cpp": 0x8000c06c,
		"JSUList<JKRFileLoader>::~JSUList": 0x8000c0b8,
		"JKRHeap::JKRHeap": 0x8000c110,
		"JKRHeap::~JKRHeap": 0x8000c230,
		"JKRHeap::initArena": 0x8000c348,
		"initArena": 0x8000c348,
		"JKRHeap::becomeSystemHeap": 0x8000c42c,
		"becomeSystemHeap": 0x8000c42c,
		"JKRHeap::becomeCurrentHeap": 0x8000c43c,
		"becomeCurrentHeap": 0x8000c43c,
		"JKRHeap::alloc": 0x8000c44c,
		"JKRHeap::free": 0x8000c4c4,
		"JKRHeap::freeAll": 0x8000c51c,
		"JKRHeap::findFromRoot": 0x8000c56c,
		"findFromRoot": 0x8000c56c,
		"JKRHeap::find": 0x8000c5a8,
		"find": 0x8000c5a8,
		"JKRHeap::dispose_subroutine": 0x8000c6b4,
		"dispose_subroutine": 0x8000c6b4,
		"JKRHeap::copyMemory": 0x8000c7f0,
		"copyMemory": 0x8000c7f0,
		"JSystem::JKRDefaultMemoryErrorRoutine": 0x8000c87c,
		"JKRDefaultMemoryErrorRoutine": 0x8000c87c,
		"JSystem::operator_delete": 0x8000cab0,
		"operator_delete": 0x8000cab0,
		"JSystem::operator_delete[]": 0x8000cb14,
		"operator_delete[]": 0x8000cb14,
		"JKRHeap::state_register": 0x8000cb78,
		"JKRHeap::state_compare": 0x8000cb7c,
		"JKRHeap::state_dump": 0x8000cb94,
		"state_dump": 0x8000cb94,
		"JKRHeap::dump_sort": 0x8000cb98,
		"JKRHeap::changeGroupID": 0x8000cba0,
		"JKRHeap::getCurrentGroupId": 0x8000cba8,
		"JKRMemArchive::~JKRMemArchive": 0x8000cd50,
		"JKRMemArchive::mountFixed": 0x8000cdf8,
		"mountFixed": 0x8000cdf8,
		"JKRMemArchive::unmountFixed": 0x8000cf08,
		"unmountFixed": 0x8000cf08,
		"JKRMemArchive::removeResourceAll": 0x8000d274,
		"JKRMemArchive::removeResource": 0x8000d2c4,
		"JKRMemArchive::fetchResource_subroutine": 0x8000d300,
		"JKRSolidHeap::create": 0x8000d3d8,
		"JKRSolidHeap::JKRSolidHeap": 0x8000d458,
		"JKRSolidHeap::~JKRSolidHeap": 0x8000d4b4,
		"JKRSolidHeap::alloc": 0x8000d520,
		"JKRSolidHeap::allocFromHead": 0x8000d5d0,
		"JKRSolidHeap::allocFromTail": 0x8000d6b4,
		"JKRSolidHeap::free": 0x8000d788,
		"JKRSolidHeap::freeAll": 0x8000d7b4,
		"JKRSolidHeap::freeTail": 0x8000d814,
		"JKRSolidHeap::resize": 0x8000d8a0,
		"JKRSolidHeap::getSize": 0x8000d8d0,
		"JKRSolidHeap::check": 0x8000d900,
		"JKRSolidHeap::dump": 0x8000d990,
		"JKRSolidHeap::state_register": 0x8000dab0,
		"JKRSolidHeap::getTotalFreeSize": 0x8000db18,
		"JKRSolidHeap::getFreeSize": 0x8000db44,
		"JKRSolidHeap::state_compare": 0x8000db4c,
		"JKRSolidHeap::getHeapType": 0x8000db7c,
		"JKRStdHeap::create": 0x8000db88,
		"JKRStdHeap::JKRStdHeap": 0x8000dc08,
		"JKRStdHeap::~JKRStdHeap": 0x8000dc5c,
		"JKRStdHeap::alloc": 0x8000dcd8,
		"JKRStdHeap::free": 0x8000dd88,
		"JKRStdHeap::freeAll": 0x8000ddd0,
		"JKRStdHeap::freeTail": 0x8000de24,
		"JKRStdHeap::resize": 0x8000de4c,
		"JKRStdHeap::getFreeSize": 0x8000de7c,
		"JKRStdHeap::state_register": 0x8000dea8,
		"JKRStdHeap::state_compare": 0x8000debc,
		"JKRStdHeap::getSize": 0x8000deec,
		"JKRStdHeap::getTotalFreeSize": 0x8000df10,
		"JKRStdHeap::getHeapType": 0x8000df3c,
		"JKRStdHeap::check": 0x8000df48,
		"JKRStdHeap::dump": 0x8000df78,
		"JKRThread::JKRThread": 0x8000dfbc,
		"JKRThread::~JKRThread": 0x8000e0ec,
		"JKRThread::start": 0x8000e1c4,
		"JKRThread::run": 0x8000e1f0,
		"JSystem::__sinit_JKRThread_cpp": 0x8000e1f8,
		"__sinit_JKRThread_cpp": 0x8000e1f8,
		"JSUList<JKRThread>::~JSUList": 0x8000e244,
		"JSUOutputStream::~JSUOutputStream": 0x8000e29c,
		"JSUOutputStream::write": 0x8000e2f8,
		"JSUOutputStream::skip": 0x8000e350,
		"JSURandomOutputStream::seek": 0x8000e3dc,
		"JSUInputStream::~JSUInputStream": 0x8000e534,
		"JSUInputStream::read": 0x8000e590,
		"JSUInputStream::skip": 0x8000e7dc,
		"JSURandomInputStream::align": 0x8000e864,
		"align": 0x8000e864,
		"JSURandomInputStream::skip": 0x8000e8f4,
		"JSURandomInputStream::peek": 0x8000e950,
		"peek": 0x8000e950,
		"JSURandomInputStream::seek": 0x8000ea0c,
		"JSUPtrLink::JSUPtrLink": 0x8000eb18,
		"JSUPtrLink::~JSUPtrLink": 0x8000eb30,
		"JSUPtrList::~JSUPtrList": 0x8000ebcc,
		"JSUPtrList::initiate": 0x8000ec34,
		"JSUPtrList::append": 0x8000ec48,
		"JSUPtrList::prepend": 0x8000ed04,
		"prepend": 0x8000ed04,
		"JSUPtrList::insert": 0x8000edc0,
		"JSUPtrList::remove": 0x8000ef9c,
		"JSUMemoryInputStream::setBuffer": 0x8000f04c,
		"JSUMemoryInputStream::readData": 0x8000f060,
		"JSUMemoryInputStream::seekPos": 0x8000f0d8,
		"JSUMemoryOutputStream::setBuffer": 0x8000f154,
		"JSUMemoryOutputStream::writeData": 0x8000f168,
		"JSUMemoryOutputStream::seekPos": 0x8000f1dc,
		"JSUMemoryOutputStream::getLength": 0x8000f2cc,
		"JSUMemoryOutputStream::getPosition": 0x8000f2d4,
		"JSUFileInputStream::JSUFileInputStream": 0x8000f360,
		"JSUFileInputStream::readData": 0x8000f3a4,
		"JSUFileInputStream::seekPos": 0x8000f478,
		"JSUFileInputStream::~JSUFileInputStream": 0x8000f560,
		"JSUFileInputStream::getLength": 0x8000f5d4,
		"JSUFileInputStream::getPosition": 0x8000f604,
		"JUTException::create": 0x8000f60c,
		"JUTException::run": 0x8000f670,
		"JUTException::JUTException": 0x8000f730,
		"JUTException::errorHandler": 0x8000f810,
		"errorHandler": 0x8000f810,
		"JUTException::showFloat": 0x8000f900,
		"showFloat": 0x8000f900,
		"JSystem::__fpclassifyf": 0x8000fd48,
		"__fpclassifyf": 0x8000fd48,
		"JUTException::searchPartialModule": 0x8000fdb0,
		"searchPartialModule": 0x8000fdb0,
		"JSystem::search_name_part": 0x8000fe70,
		"search_name_part": 0x8000fe70,
		"JUTException::showStack": 0x8000fee8,
		"showStack": 0x8000fee8,
		"JUTException::showGPR": 0x8000ffe8,
		"showGPR": 0x8000ffe8,
		"JUTException::showMapInfo_subroutine": 0x800100a8,
		"showMapInfo_subroutine": 0x800100a8,
		"JUTException::showGPRMap": 0x80010208,
		"showGPRMap": 0x80010208,
		"JUTException::readPad": 0x800102f8,
		"readPad": 0x800102f8,
		"JUTException::printContext": 0x800104e4,
		"printContext": 0x800104e4,
		"JUTException::waitTime": 0x80010988,
		"waitTime": 0x80010988,
		"JUTException::createFB": 0x80010a14,
		"createFB": 0x80010a14,
		"JUTException::getFpscr": 0x80010adc,
		"getFpscr": 0x80010adc,
		"JUTException::setPreUserCallback": 0x80010b04,
		"setPreUserCallback": 0x80010b04,
		"JUTException::appendMapFile": 0x80010b14,
		"appendMapFile": 0x80010b14,
		"JUTException::queryMapAddress": 0x80010ba8,
		"queryMapAddress": 0x80010ba8,
		"JUTException::queryMapAddress_single": 0x80010ca0,
		"queryMapAddress_single": 0x80010ca0,
		"JUTException::createConsole": 0x80010fec,
		"createConsole": 0x80010fec,
		"JUTExternalFB::JUTExternalFB": 0x800110cc,
		"JUTException::~JUTException": 0x800110ec,
		"JSystem::__sinit_JUTException_cpp": 0x80011150,
		"__sinit_JUTException_cpp": 0x80011150,
		"JSUList<JUTException::JUTExMapFile>::~JSUList": 0x800111a0,
		"JUTDirectPrint::start": 0x800111f8,
		"JUTDirectPrint::JUTDirectPrint": 0x80011248,
		"JUTDirectPrint::erase": 0x80011284,
		"JUTDirectPrint::drawChar": 0x80011378,
		"drawChar": 0x80011378,
		"JUTDirectPrint::changeFrameBuffer": 0x80011578,
		"changeFrameBuffer": 0x80011578,
		"JUTDirectPrint::drawString": 0x800115ac,
		"drawString": 0x800115ac,
		"JUTDirectPrint::drawString_f": 0x800115d8,
		"drawString_f": 0x800115d8,
		"JUTFont::JUTFont": 0x800117bc,
		"JUTFont::initiate": 0x80011828,
		"JUTFont::setCharColor": 0x8001182c,
		"setCharColor": 0x8001182c,
		"JUTFont::setGradColor": 0x80011850,
		"setGradColor": 0x80011850,
		"JUTFont::drawString_size_scale": 0x80011874,
		"drawString_size_scale": 0x80011874,
		"JUTFont::~JUTFont": 0x80011964,
		"JUTFont::setGX": 0x800119b0,
		"JUTGamePad::JUTGamePad": 0x800119dc,
		"JUTGamePad::~JUTGamePad": 0x80011ab8,
		"JUTGamePad::initList": 0x80011b64,
		"initList": 0x80011b64,
		"JUTGamePad::init": 0x80011ba0,
		"JUTGamePad::read": 0x80011bd8,
		"JUTGamePad::assign": 0x80011efc,
		"assign": 0x80011efc,
		"JUTGamePad::update": 0x80011fac,
		"JUTGamePad::checkResetSwitch": 0x80012194,
		"checkResetSwitch": 0x80012194,
		"JUTGamePad::clearForReset": 0x80012214,
		"clearForReset": 0x80012214,
		"JUTGamePad::CButton::clear": 0x80012240,
		"JUTGamePad::CButton::update": 0x8001227c,
		"JUTGamePad::CStick::clear": 0x8001240c,
		"JUTGamePad::CStick::update": 0x80012428,
		"JUTGamePad::CStick::getButton": 0x800125c4,
		"getButton": 0x800125c4,
		"JUTGamePad::CRumble::clear": 0x80012670,
		"JUTGamePad::CRumble::stopMotor": 0x800126dc,
		"stopMotor": 0x800126dc,
		"JUTGamePad::CRumble::stopMotorHard": 0x8001273c,
		"stopMotorHard": 0x8001273c,
		"JUTGamePad::CRumble::update": 0x8001279c,
		"JUTGamePad::CRumble::setEnable": 0x80012968,
		"setEnable": 0x80012968,
		"JUTGamePad::CButton::setRepeat": 0x80012a6c,
		"setRepeat": 0x80012a6c,
		"JUTGamePad::setButtonRepeat": 0x80012a88,
		"setButtonRepeat": 0x80012a88,
		"JUTGamePad::recalibrate": 0x80012ad4,
		"recalibrate": 0x80012ad4,
		"JUTGamePadRecord::read": 0x80012b90,
		"JUTGamePadRecord::write": 0x80012c3c,
		"JUTGamePadRecord::streamDataToPadStatus": 0x80012cf8,
		"streamDataToPadStatus": 0x80012cf8,
		"JUTGamePadRecord::padStatusToStreamData": 0x80012d90,
		"padStatusToStreamData": 0x80012d90,
		"JSystem::__sinit_JUTGamePad_cpp": 0x80012e28,
		"__sinit_JUTGamePad_cpp": 0x80012e28,
		"JUTGamePad::CStick::CStick": 0x80012f1c,
		"JUTGamePad::CButton::CButton": 0x80012f38,
		"JSUList<JUTGamePad>::~JSUList": 0x80012f74,
		"JUTNameTab::JUTNameTab": 0x80012fcc,
		"JUTNameTab::getIndex": 0x80012ff0,
		"JUTNameTab::getName": 0x8001308c,
		"getName": 0x8001308c,
		"JUTNameTab::calcKeyCode": 0x800130bc,
		"JUTPalette::storeTLUT": 0x800130ec,
		"storeTLUT": 0x800130ec,
		"JUTPalette::JUTPalette": 0x80013184,
		"JUTPalette::load": 0x800131d4,
		"JUTRect::set": 0x8001321c,
		"JUTRect::copy": 0x80013230,
		"JUTRect::add": 0x80013254,
		"JUTRect::intersect": 0x80013288,
		"intersect": 0x80013288,
		"JUTRect::move": 0x80013308,
		"JUTRect::resize": 0x80013344,
		"JUTRect::reform": 0x80013360,
		"reform": 0x80013360,
		"JUTRect::normalize": 0x80013394,
		"JUTRect::isEmpty": 0x800133c8,
		"isEmpty": 0x800133c8,
		"JUTTexture::JUTTexture": 0x80013528,
		"JUTTexture::~JUTTexture": 0x8001360c,
		"JUTTexture::storeTIMG": 0x8001367c,
		"storeTIMG": 0x8001367c,
		"JUTTexture::attachPalette": 0x80013804,
		"attachPalette": 0x80013804,
		"JUTTexture::load": 0x80013a78,
		"JSystem::JMANewSinTable": 0x80013ac8,
		"JMANewSinTable": 0x80013ac8,
		"JSystem::JMAEulerToQuat": 0x80013c88,
		"JMAEulerToQuat": 0x80013c88,
		"JSystem::JMAQuatLerp": 0x80013d40,
		"JMAQuatLerp": 0x80013d40,
		"JSystem::JMAHermiteInterpolation": 0x80013de4,
		"JMAHermiteInterpolation": 0x80013de4,
		"J2DPane::~J2DPane": 0x80014630,
		"J2DPane::draw": 0x80014710,
		"J2DGrafContext::~J2DGrafContext": 0x80014b0c,
		"J2DPane::clip": 0x80014b58,
		"clip": 0x80014b58,
		"J2DPane::search": 0x80014ba4,
		"J2DPane::makeMatrix": 0x80014c38,
		"makeMatrix": 0x80014c38,
		"J2DPane::setCullBack": 0x80014da4,
		"setCullBack": 0x80014da4,
		"J2DPane::setBasePosition": 0x80014e98,
		"setBasePosition": 0x80014e98,
		"J2DPane::setConnectParent": 0x80014fcc,
		"J2DPicture::J2DPicture": 0x80014fec,
		"J2DPicture::~J2DPicture": 0x80015478,
		"J2DPicture::insert": 0x80015544,
		"J2DPicture::remove": 0x80015670,
		"J2DPicture::changeTexture": 0x8001575c,
		"J2DPicture::drawFullSet": 0x800158f4,
		"drawFullSet": 0x800158f4,
		"J2DPicture::draw": 0x80015fb0,
		"J2DPicture::drawTexCoord": 0x800163a8,
		"drawTexCoord": 0x800163a8,
		"J2DPicture::setTevMode": 0x800165a0,
		"J2DPicture::swap": 0x800169f4,
		"swap": 0x800169f4,
		"J2DPicture::setBlendKonstColor": 0x80016a08,
		"setBlendKonstColor": 0x80016a08,
		"J2DPicture::setBlendKonstAlpha": 0x80016b40,
		"setBlendKonstAlpha": 0x80016b40,
		"JSystem::J2DPrint_print_alpha_va": 0x80016c78,
		"J2DPrint_print_alpha_va": 0x80016c78,
		"J2DPrint::~J2DPrint": 0x80016e2c,
		"J2DPrint::initiate": 0x80016e78,
		"J2DPrint::private_initiate": 0x80016f00,
		"private_initiate": 0x80016f00,
		"J2DPrint::setBuffer": 0x80017088,
		"J2DPrint::setFontSize": 0x800170f4,
		"setFontSize": 0x800170f4,
		"J2DPrint::locate": 0x80017154,
		"locate": 0x80017154,
		"J2DPrint::getWidth": 0x80017350,
		"J2DPrint::printReturn": 0x8001745c,
		"printReturn": 0x8001745c,
		"J2DPrint::parse": 0x800176b8,
		"parse": 0x800176b8,
		"J2DPrint::doCtrlCode": 0x80017ef8,
		"doCtrlCode": 0x80017ef8,
		"J2DPrint::doEscapeCode": 0x8001806c,
		"doEscapeCode": 0x8001806c,
		"J2DPrint::initchar": 0x80018654,
		"initchar": 0x80018654,
		"J2DPrint::getNumber": 0x80018698,
		"getNumber": 0x80018698,
		"J2DScreen::~J2DScreen": 0x800187a0,
		"J2DScreen::makeHiearachyPanes": 0x80018804,
		"makeHiearachyPanes": 0x80018804,
		"J2DScreen::stop": 0x80018e28,
		"J2DScreen::draw": 0x80018e64,
		"J2DScreen::search": 0x8001910c,
		"J2DSetScreen::J2DSetScreen": 0x8001913c,
		"J2DScreen::drawSelf": 0x80019284,
		"J2DSetScreen::~J2DSetScreen": 0x8001933c,
		"J2DTextBox::initiate": 0x800199a0,
		"J2DTextBox::~J2DTextBox": 0x80019ad0,
		"J2DTextBox::setFont": 0x80019b74,
		"setFont": 0x80019b74,
		"J2DTextBox::draw": 0x80019be4,
		"J2DTextBox::getStringPtr": 0x80019d1c,
		"getStringPtr": 0x80019d1c,
		"J2DTextBox::setString": 0x80019d24,
		"setString": 0x80019d24,
		"J2DTextBox::setConnectParent": 0x80019df4,
		"J2DTextBox::resize": 0x80019fd0,
		"J2DWindow::J2DWindow": 0x8001a080,
		"J2DWindow::~J2DWindow": 0x8001a81c,
		"J2DWindow::Texture::~Texture": 0x8001a944,
		"J2DWindow::draw_private": 0x8001a9a8,
		"draw_private": 0x8001a9a8,
		"J2DWindow::resize": 0x8001ae64,
		"J2DWindow::drawContents": 0x8001b044,
		"drawContents": 0x8001b044,
		"J2DWindow::Texture::drawContentsTexture": 0x8001b4f8,
		"drawContentsTexture": 0x8001b4f8,
		"J2DWindow::Texture::setTevMode": 0x8001b6e0,
		"JSystem::J3DCalcZValue": 0x8001bab0,
		"J3DCalcZValue": 0x8001bab0,
		"JSystem::J3DPSCalcInverseTranspose": 0x8001bae8,
		"J3DPSCalcInverseTranspose": 0x8001bae8,
		"JSystem::J3DGetTextureMtx": 0x8001bd1c,
		"J3DGetTextureMtx": 0x8001bd1c,
		"JSystem::J3DGetTextureMtxOld": 0x8001bdf4,
		"J3DGetTextureMtxOld": 0x8001bdf4,
		"JSystem::J3DGetTextureMtxMaya": 0x8001becc,
		"J3DGetTextureMtxMaya": 0x8001becc,
		"JSystem::J3DGetTextureMtxMayaOld": 0x8001c01c,
		"J3DGetTextureMtxMayaOld": 0x8001c01c,
		"JSystem::J3DScaleNrmMtx33": 0x8001c16c,
		"J3DScaleNrmMtx33": 0x8001c16c,
		"JSystem::J3DMtxProjConcat": 0x8001c1c0,
		"J3DMtxProjConcat": 0x8001c1c0,
		"JSystem::J3DPSMtx33Copy": 0x8001c2e4,
		"J3DPSMtx33Copy": 0x8001c2e4,
		"JSystem::J3DPSMtx33CopyFrom34": 0x8001c310,
		"J3DPSMtx33CopyFrom34": 0x8001c310,
		"JSystem::J3DPSMtxArrayCopy": 0x8001c344,
		"J3DPSMtxArrayCopy": 0x8001c344,
		"JSystem::J3DMTXConcatArrayIndexedSrc": 0x8001c388,
		"J3DMTXConcatArrayIndexedSrc": 0x8001c388,
		"JSystem::J3DPSMtxArrayConcat": 0x8001c4c0,
		"J3DPSMtxArrayConcat": 0x8001c4c0,
		"J3DDeformData::deform": 0x8001c59c,
		"J3DDeformData::setAnm": 0x8001c684,
		"J3DAnmCluster::getWeight": 0x8001c82c,
		"J3DDeformer::normalize": 0x8001cf84,
		"J3DDeformer::normalizeWeight": 0x8001d034,
		"normalizeWeight": 0x8001d034,
		"J3DSkinDeform::J3DSkinDeform": 0x8001d090,
		"J3DSkinDeform::initMtxIndexArray": 0x8001d0b8,
		"initMtxIndexArray": 0x8001d0b8,
		"J3DSkinDeform::calcNrmMtx": 0x8001d49c,
		"J3DSkinDeform::deform": 0x8001d5c8,
		"J3DAnmVtxColor::getColor": 0x8001da6c,
		"J3DSkinDeform::~J3DSkinDeform": 0x8001da70,
		"J3DMtxCalcBasic::J3DMtxCalcBasic": 0x8001dbb0,
		"J3DNode::updateOut": 0x8001ddb4,
		"J3DNode::updateIn": 0x8001ddb8,
		"J3DNode::calcOut": 0x8001dfe0,
		"J3DNode::calcIn": 0x8001dfe4,
		"J3DNode::entryIn": 0x8001e064,
		"JSystem::J3DNewMtxCalcAnm": 0x8001e788,
		"J3DNewMtxCalcAnm": 0x8001e788,
		"J3DMtxCalcMaya::~J3DMtxCalcMaya": 0x8001e9f8,
		"J3DJoint::initialize": 0x8001ebfc,
		"J3DJoint::addMesh": 0x8001ecf0,
		"addMesh": 0x8001ecf0,
		"J3DJoint::updateIn": 0x8001ed10,
		"J3DJoint::updateOut": 0x8001efac,
		"J3DJoint::calcIn": 0x8001efd0,
		"J3DJoint::calcOut": 0x8001f050,
		"J3DJoint::entryIn": 0x8001f074,
		"J3DJoint::getType": 0x8001f24c,
		"J3DJoint::~J3DJoint": 0x8001f258,
		"J3DNode::init": 0x8001f2bc,
		"J3DColorBlockLightOff::initialize": 0x8001fd18,
		"J3DColorBlockLightOn::initialize": 0x8001fd84,
		"J3DTevBlock2::initialize": 0x8001fe58,
		"J3DTevBlock4::initialize": 0x8001ff90,
		"J3DTevBlock16::initialize": 0x80020118,
		"J3DMaterial::createColorBlock": 0x8002043c,
		"createColorBlock": 0x8002043c,
		"J3DColorChan::J3DColorChan": 0x80020580,
		"JSystem::calcColorChanID": 0x800205e4,
		"calcColorChanID": 0x800205e4,
		"J3DGXColor::J3DGXColor": 0x80020760,
		"J3DColorBlock::~J3DColorBlock": 0x80020764,
		"J3DMaterial::createTexGenBlock": 0x800207b0,
		"createTexGenBlock": 0x800207b0,
		"J3DTexCoord::J3DTexCoord": 0x80020880,
		"J3DTexGenBlock::~J3DTexGenBlock": 0x800208a0,
		"J3DMaterial::createTevBlock": 0x800208ec,
		"createTevBlock": 0x800208ec,
		"J3DTevSwapModeTable::J3DTevSwapModeTable": 0x80020c9c,
		"J3DGXColorS10::J3DGXColorS10": 0x80020ca8,
		"J3DIndTevStage::J3DIndTevStage": 0x80020cac,
		"J3DTevStage::J3DTevStage": 0x80020cfc,
		"J3DTevOrder::J3DTevOrder": 0x80020f50,
		"J3DTevBlock::~J3DTevBlock": 0x80020f70,
		"J3DMaterial::createIndBlock": 0x80020fbc,
		"createIndBlock": 0x80020fbc,
		"J3DIndTexCoordScale::~J3DIndTexCoordScale": 0x800210b4,
		"J3DIndTexCoordScale::J3DIndTexCoordScale": 0x800210f4,
		"J3DIndTexMtx::~J3DIndTexMtx": 0x8002110c,
		"J3DIndTexMtx::J3DIndTexMtx": 0x8002114c,
		"J3DIndTexOrder::J3DIndTexOrder": 0x8002118c,
		"J3DIndBlock::~J3DIndBlock": 0x800211a4,
		"J3DMaterial::createPEBlock": 0x800211f0,
		"createPEBlock": 0x800211f0,
		"J3DPEBlock::~J3DPEBlock": 0x80021338,
		"J3DMaterial::initialize": 0x80021384,
		"J3DMaterial::addShape": 0x800213d4,
		"addShape": 0x800213d4,
		"J3DColorBlockLightOff::countDLSize": 0x800213dc,
		"J3DColorBlockLightOn::countDLSize": 0x800213e4,
		"J3DTexGenBlockBasic::countDLSize": 0x800213ec,
		"J3DTevBlock1::countDLSize": 0x800213f4,
		"J3DTevBlock2::countDLSize": 0x800213fc,
		"J3DTevBlock4::countDLSize": 0x80021404,
		"J3DTevBlock16::countDLSize": 0x8002140c,
		"J3DIndBlockFull::countDLSize": 0x80021414,
		"J3DPEBlockOpa::countDLSize": 0x8002141c,
		"J3DPEBlockTexEdge::countDLSize": 0x80021424,
		"J3DPEBlockXlu::countDLSize": 0x8002142c,
		"J3DPEBlockFull::countDLSize": 0x80021434,
		"J3DMaterial::countDLSize": 0x8002143c,
		"J3DColorBlockLightOff::load": 0x800214f0,
		"J3DColorBlockLightOn::load": 0x800215e8,
		"J3DTexGenBlockBasic::load": 0x80021744,
		"J3DTexGenBlockBasic::patch": 0x800217fc,
		"patch": 0x800217fc,
		"J3DTevBlock1::load": 0x8002189c,
		"J3DTevBlock2::load": 0x80021a88,
		"J3DTevBlock4::load": 0x80021f8c,
		"J3DTevBlock16::load": 0x800224c4,
		"J3DIndBlockFull::load": 0x800229fc,
		"J3DPEBlockOpa::load": 0x80022bec,
		"J3DPEBlockTexEdge::load": 0x80022d64,
		"J3DPEBlockXlu::load": 0x80022ed8,
		"J3DPEBlockFull::load": 0x80023050,
		"JSystem::J3DGDWrite_u32": 0x80023188,
		"J3DGDWrite_u32": 0x80023188,
		"JSystem::__GDWrite": 0x800231e8,
		"__GDWrite": 0x800231e8,
		"JSystem::GDOverflowCheck": 0x80023200,
		"J3DColorBlockLightOff::reset": 0x80023238,
		"J3DColorBlockLightOn::reset": 0x8002330c,
		"J3DLightInfo::operator_=": 0x800234cc,
		"J3DTexGenBlockBasic::reset": 0x80023550,
		"J3DTevBlock1::reset": 0x80023790,
		"J3DTevBlock2::reset": 0x800238b8,
		"J3DTevBlock4::reset": 0x80023c20,
		"J3DTevBlock16::reset": 0x800241e0,
		"J3DIndBlockFull::reset": 0x8002448c,
		"J3DIndTexMtxInfo::operator_=": 0x800245b0,
		"J3DPEBlockFull::reset": 0x800245ec,
		"J3DPEBlock::getZCompLoc": 0x80024964,
		"J3DPEBlock::getBlend": 0x80024974,
		"J3DPEBlock::getAlphaComp": 0x8002497c,
		"J3DFogInfo::operator_=": 0x80024984,
		"J3DMaterial::makeDisplayList": 0x80024a54,
		"makeDisplayList": 0x80024a54,
		"J3DMaterial::load": 0x80024bb8,
		"J3DMaterial::safeMakeDisplayList": 0x80024c3c,
		"safeMakeDisplayList": 0x80024c3c,
		"J3DTexGenBlockBasic::calc": 0x80024da0,
		"J3DMaterial::calc": 0x80025030,
		"J3DMaterial::setCurrentMtx": 0x80025060,
		"setCurrentMtx": 0x80025060,
		"J3DMaterial::copy": 0x8002518c,
		"J3DPEBlock::reset": 0x8002524c,
		"J3DIndBlock::reset": 0x80025250,
		"J3DTevBlock::reset": 0x80025254,
		"J3DTexGenBlock::reset": 0x80025258,
		"J3DColorBlock::reset": 0x8002525c,
		"J3DMaterial::change": 0x80025260,
		"change": 0x80025260,
		"J3DMaterial::newSharedDisplayList": 0x80025298,
		"newSharedDisplayList": 0x80025298,
		"J3DPEBlockFull::getType": 0x80025310,
		"J3DPEBlockFull::setFog": 0x8002531c,
		"J3DPEBlockFull::replaceFog": 0x80025324,
		"J3DPEBlockFull::getFog": 0x80025334,
		"J3DPEBlockFull::getAlphaComp": 0x80025374,
		"J3DPEBlockFull::getBlend": 0x800253c4,
		"J3DPEBlockFull::getZMode": 0x800253e4,
		"J3DPEBlockFull::getZCompLoc": 0x80025400,
		"J3DPEBlockFull::getDither": 0x8002541c,
		"J3DPEBlockFull::~J3DPEBlockFull": 0x80025424,
		"J3DIndBlockFull::getType": 0x80025480,
		"J3DIndBlockFull::setIndTexStageNum": 0x8002548c,
		"J3DIndBlockFull::getIndTexStageNum": 0x80025494,
		"J3DIndBlockFull::getIndTexOrder": 0x800254d4,
		"J3DIndBlockFull::getIndTexMtx": 0x80025548,
		"J3DIndBlockFull::getIndTexCoordScale": 0x80025594,
		"J3DIndBlockFull::~J3DIndBlockFull": 0x800255a8,
		"J3DTevBlock16::getType": 0x80025644,
		"J3DTevBlock16::getTexNo": 0x80025674,
		"J3DTevBlock16::getTevOrder": 0x800256cc,
		"J3DTevBlock16::getTevColor": 0x80025718,
		"J3DTevBlock16::getTevKColor": 0x80025754,
		"J3DTevBlock16::getTevKColorSel": 0x80025784,
		"J3DTevBlock16::getTevKAlphaSel": 0x800257ac,
		"J3DTevBlock16::getTevStageNum": 0x800257cc,
		"J3DTevBlock16::getTevStage": 0x8002584c,
		"J3DTevBlock16::getTevSwapModeTable": 0x800258f0,
		"J3DTevBlock16::getIndTevStage": 0x800259a8,
		"J3DTevBlock16::~J3DTevBlock16": 0x800259bc,
		"J3DTevBlock4::getType": 0x80025a18,
		"J3DTevBlock4::getTexNo": 0x80025a48,
		"J3DTevBlock4::getTevOrder": 0x80025aa0,
		"J3DTevBlock4::getTevColor": 0x80025aec,
		"J3DTevBlock4::getTevKColor": 0x80025b28,
		"J3DTevBlock4::getTevKColorSel": 0x80025b58,
		"J3DTevBlock4::getTevKAlphaSel": 0x80025b80,
		"J3DTevBlock4::getTevStageNum": 0x80025ba0,
		"J3DTevBlock4::getTevStage": 0x80025c20,
		"J3DTevBlock4::getTevSwapModeTable": 0x80025cc4,
		"J3DTevBlock4::getIndTevStage": 0x80025d7c,
		"J3DTevBlock4::~J3DTevBlock4": 0x80025d90,
		"J3DTevBlock2::getType": 0x80025dec,
		"J3DTevBlock2::getTexNo": 0x80025e1c,
		"J3DTevBlock2::getTevOrder": 0x80025e74,
		"J3DTevBlock2::getTevColor": 0x80025ec0,
		"J3DTevBlock2::getTevKColor": 0x80025efc,
		"J3DTevBlock2::getTevKColorSel": 0x80025f2c,
		"J3DTevBlock2::getTevKAlphaSel": 0x80025f54,
		"J3DTevBlock2::getTevStageNum": 0x80025f74,
		"J3DTevBlock2::getTevStage": 0x80025ff4,
		"J3DTevBlock2::getTevSwapModeTable": 0x80026098,
		"J3DTevBlock2::getIndTevStage": 0x80026150,
		"J3DTevBlock2::~J3DTevBlock2": 0x80026164,
		"J3DTevBlock1::getType": 0x800261c0,
		"J3DTevBlock1::getTexNo": 0x800261f0,
		"J3DTevBlock1::getTevOrder": 0x80026248,
		"J3DTevBlock1::getTevColor": 0x80026264,
		"J3DTevBlock1::getTevKColor": 0x80026274,
		"J3DTevBlock1::getTevKColorSel": 0x80026284,
		"J3DTevBlock1::getTevKAlphaSel": 0x80026294,
		"J3DTevBlock1::getTevStageNum": 0x800262a4,
		"J3DTevBlock1::getTevStage": 0x80026324,
		"J3DTevBlock1::getTevSwapModeTable": 0x80026348,
		"J3DTevBlock1::getIndTevStage": 0x800263f8,
		"J3DTevBlock1::~J3DTevBlock1": 0x8002640c,
		"J3DTexGenBlockBasic::getType": 0x80026468,
		"J3DTexGenBlockBasic::getTexGenNum": 0x80026488,
		"getTexGenNum": 0x80026488,
		"J3DTexGenBlockBasic::setTexCoord": 0x80026490,
		"setTexCoord": 0x80026490,
		"J3DTexGenBlockBasic::getTexCoord": 0x800264b4,
		"getTexCoord": 0x800264b4,
		"J3DTexGenBlockBasic::setTexMtx": 0x800264c8,
		"setTexMtx": 0x800264c8,
		"J3DTexGenBlockBasic::replaceTexMtx": 0x800264d8,
		"replaceTexMtx": 0x800264d8,
		"J3DTexGenBlockBasic::getTexMtx": 0x800264ec,
		"getTexMtx": 0x800264ec,
		"J3DTexGenBlockBasic::getNBTScale": 0x80026544,
		"getNBTScale": 0x80026544,
		"J3DTexGenBlockBasic::~J3DTexGenBlockBasic": 0x8002654c,
		"J3DColorBlockLightOn::getType": 0x800265a8,
		"J3DColorBlockLightOn::getMatColor": 0x800265dc,
		"J3DColorBlockLightOn::getAmbColor": 0x80026618,
		"J3DColorBlockLightOn::getColorChanNum": 0x80026640,
		"J3DColorBlockLightOn::getColorChan": 0x80026670,
		"J3DColorBlockLightOn::setLight": 0x80026684,
		"J3DColorBlockLightOn::replaceLight": 0x80026694,
		"J3DColorBlockLightOn::getLight": 0x800266a8,
		"J3DColorBlockLightOn::getCullMode": 0x800266cc,
		"J3DColorBlockLightOn::~J3DColorBlockLightOn": 0x800266d4,
		"J3DColorBlockLightOff::getType": 0x80026730,
		"J3DColorBlockLightOff::getMatColor": 0x80026764,
		"J3DColorBlockLightOff::getAmbColor": 0x80026780,
		"J3DColorBlockLightOff::getColorChanNum": 0x8002679c,
		"J3DColorBlockLightOff::getColorChan": 0x800267cc,
		"J3DColorBlockLightOff::setLight": 0x800267e0,
		"J3DColorBlockLightOff::replaceLight": 0x800267e4,
		"J3DColorBlockLightOff::getLight": 0x800267ec,
		"J3DColorBlockLightOff::getCullMode": 0x80026808,
		"J3DColorBlockLightOff::~J3DColorBlockLightOff": 0x80026810,
		"J3DPEBlockXlu::getType": 0x8002686c,
		"J3DPEBlockXlu::~J3DPEBlockXlu": 0x80026878,
		"J3DPEBlock::setFog": 0x800268d4,
		"J3DPEBlock::replaceFog": 0x800268d8,
		"J3DPEBlock::getDither": 0x80026908,
		"J3DPEBlockTexEdge::getType": 0x80026910,
		"J3DPEBlockTexEdge::~J3DPEBlockTexEdge": 0x8002691c,
		"J3DPEBlockOpa::getType": 0x80026978,
		"J3DPEBlockOpa::~J3DPEBlockOpa": 0x80026984,
		"J3DIndBlockNull::reset": 0x800269e0,
		"J3DIndBlockNull::countDLSize": 0x800269e4,
		"J3DIndBlockNull::getType": 0x800269ec,
		"J3DIndBlockNull::setIndTexStageNum": 0x800269f8,
		"J3DIndBlockNull::getIndTexStageNum": 0x800269fc,
		"J3DIndBlockNull::getIndTexOrder": 0x80026a0c,
		"J3DIndBlockNull::getIndTexMtx": 0x80026a1c,
		"J3DIndBlockNull::getIndTexCoordScale": 0x80026a2c,
		"J3DIndBlockNull::~J3DIndBlockNull": 0x80026a34,
		"J3DIndBlockNull::load": 0x80026a90,
		"J3DModelData::clear": 0x80026a94,
		"J3DModelData::J3DModelData": 0x80026b08,
		"J3DModelData::~J3DModelData": 0x80026b5c,
		"J3DModelData::makeHierarchy": 0x80026bcc,
		"J3DNode::getType": 0x80026d78,
		"J3DModelData::isDeformableVertexFormat": 0x80026d84,
		"isDeformableVertexFormat": 0x80026d84,
		"J3DModelData::setMaterialTable": 0x80026e08,
		"setMaterialTable": 0x80026e08,
		"J3DModelData::entryMatColorAnimator": 0x80026ec0,
		"entryMatColorAnimator": 0x80026ec0,
		"J3DModelData::entryTexMtxAnimator": 0x80026f74,
		"entryTexMtxAnimator": 0x80026f74,
		"J3DModelData::entryTevRegAnimator": 0x80027148,
		"entryTevRegAnimator": 0x80027148,
		"J3DModelData::removeMatColorAnimator": 0x800272b4,
		"removeMatColorAnimator": 0x800272b4,
		"J3DModelData::removeTexNoAnimator": 0x8002732c,
		"removeTexNoAnimator": 0x8002732c,
		"J3DModelData::removeTexMtxAnimator": 0x800273c0,
		"removeTexMtxAnimator": 0x800273c0,
		"J3DModelData::removeTevRegAnimator": 0x80027464,
		"removeTevRegAnimator": 0x80027464,
		"J3DModelData::setMatColorAnimator": 0x80027580,
		"setMatColorAnimator": 0x80027580,
		"J3DModelData::setTexNoAnimator": 0x80027600,
		"setTexNoAnimator": 0x80027600,
		"J3DModelData::setTexMtxAnimator": 0x800276a8,
		"setTexMtxAnimator": 0x800276a8,
		"J3DModelData::setTevRegAnimator": 0x800277e0,
		"setTevRegAnimator": 0x800277e0,
		"J3DModel::~J3DModel": 0x800279cc,
		"J3DModel::initialize": 0x80027a18,
		"J3DModel::entryModelData": 0x80027abc,
		"entryModelData": 0x80027abc,
		"J3DModel::lock": 0x80027f9c,
		"lock": 0x80027f9c,
		"J3DModel::unlock": 0x800280cc,
		"unlock": 0x800280cc,
		"J3DModel::makeDL": 0x800281fc,
		"J3DModel::setSkinDeform": 0x80028294,
		"setSkinDeform": 0x80028294,
		"J3DModel::calcWeightEnvelopeMtx": 0x80028310,
		"calcWeightEnvelopeMtx": 0x80028310,
		"J3DModel::update": 0x800284ec,
		"J3DModel::calc": 0x800286f0,
		"J3DModel::entry": 0x800288f4,
		"J3DModel::viewCalc": 0x800289e4,
		"J3DModel::calcNrmMtx": 0x80028c1c,
		"J3DModel::calcBumpMtx": 0x80028d74,
		"calcBumpMtx": 0x80028d74,
		"J3DModel::calcBBoard": 0x80028e68,
		"calcBBoard": 0x80028e68,
		"J3DModel::prepareShapePackets": 0x80029370,
		"prepareShapePackets": 0x80029370,
		"J3DNode::J3DNode": 0x80029534,
		"J3DNode::~J3DNode": 0x80029558,
		"J3DNode::appendChild": 0x800295a4,
		"appendChild": 0x800295a4,
		"J3DShapeMtx::loadMtxIndx_PNGP": 0x800295d8,
		"loadMtxIndx_PNGP": 0x800295d8,
		"J3DShapeMtx::loadMtxIndx_PCPU": 0x80029634,
		"loadMtxIndx_PCPU": 0x80029634,
		"J3DShapeMtx::loadMtxIndx_NCPU": 0x80029694,
		"loadMtxIndx_NCPU": 0x80029694,
		"J3DShapeMtx::loadMtxIndx_PNCPU": 0x800296e0,
		"loadMtxIndx_PNCPU": 0x800296e0,
		"J3DShapeMtx::load": 0x80029730,
		"J3DShapeMtx::calcNBTScale": 0x8002978c,
		"J3DShapeMtx::~J3DShapeMtx": 0x800297f4,
		"J3DShapeMtxDL::load": 0x80029840,
		"J3DShapeMtxMulti::load": 0x80029868,
		"J3DShapeMtxMulti::calcNBTScale": 0x80029910,
		"J3DShapeDraw::J3DShapeDraw": 0x8002999c,
		"J3DShapeDraw::draw": 0x800299b4,
		"J3DShape::initialize": 0x800299e0,
		"J3DShape::calcNBTScale": 0x80029a4c,
		"J3DShape::countBumpMtxNum": 0x80029ac4,
		"countBumpMtxNum": 0x80029ac4,
		"J3DShape::makeVtxArrayCmd": 0x80029b48,
		"makeVtxArrayCmd": 0x80029b48,
		"J3DShape::makeVcdVatCmd": 0x80029de0,
		"makeVcdVatCmd": 0x80029de0,
		"J3DShape::loadVtxArray": 0x80029e54,
		"loadVtxArray": 0x80029e54,
		"J3DShape::draw": 0x80029ec4,
		"J3DShapeDraw::~J3DShapeDraw": 0x8002a02c,
		"J3DShapeMtxMulti::~J3DShapeMtxMulti": 0x8002a078,
		"J3DShapeMtxMulti::getType": 0x8002a0d4,
		"J3DShapeMtxMulti::getUseMtxNum": 0x8002a0e0,
		"J3DShapeMtxMulti::getUseMtxIndex": 0x8002a0e8,
		"J3DShapeMtxDL::~J3DShapeMtxDL": 0x8002a0f8,
		"J3DShapeMtxDL::calcNBTScale": 0x8002a154,
		"J3DShapeMtx::getType": 0x8002a158,
		"JSystem::__sinit_J3DShape_cpp": 0x8002a164,
		"__sinit_J3DShape_cpp": 0x8002a164,
		"J3DSys::J3DSys": 0x8002a1d0,
		"J3DSys::loadPosMtxIndx": 0x8002a2ec,
		"loadPosMtxIndx": 0x8002a2ec,
		"J3DSys::loadNrmMtxIndx": 0x8002a314,
		"loadNrmMtxIndx": 0x8002a314,
		"J3DSys::setTexCacheRegion": 0x8002a33c,
		"setTexCacheRegion": 0x8002a33c,
		"J3DSys::drawInit": 0x8002a4fc,
		"drawInit": 0x8002a4fc,
		"J3DSys::reinitTexture": 0x8002abc8,
		"reinitTexture": 0x8002abc8,
		"JSystem::__sinit_J3DSys_cpp": 0x8002ac6c,
		"__sinit_J3DSys_cpp": 0x8002ac6c,
		"J3DFrameCtrl::init": 0x8002ac94,
		"J3DFrameCtrl::checkPass": 0x8002acc4,
		"checkPass": 0x8002acc4,
		"J3DFrameCtrl::update": 0x8002b264,
		"J3DAnmBase::~J3DAnmBase": 0x8002b6dc,
		"J3DAnmTransformFull::getTransform": 0x8002b728,
		"JSystem::J3DHermiteInterpolationS": 0x8002be1c,
		"J3DHermiteInterpolationS": 0x8002be1c,
		"JSystem::J3DGetKeyFrameInterpolationS": 0x8002be70,
		"J3DGetKeyFrameInterpolationS": 0x8002be70,
		"J3DAnmTransformKey::calcTransform": 0x8002c0a0,
		"J3DAnmTextureSRTKey::calcTransform": 0x8002c58c,
		"J3DAnmClusterFull::getWeight": 0x8002c850,
		"J3DAnmClusterKey::getWeight": 0x8002c928,
		"J3DAnmVtxColorFull::getColor": 0x8002c9ac,
		"J3DAnmVtxColorKey::getColor": 0x8002cd04,
		"J3DAnmColor::searchUpdateMaterialID": 0x8002d060,
		"J3DAnmColorFull::getColor": 0x8002d0f0,
		"J3DAnmColorKey::getColor": 0x8002d440,
		"J3DAnmTexPattern::getTexNo": 0x8002d78c,
		"J3DAnmTexPattern::searchUpdateMaterialID": 0x8002d878,
		"J3DAnmTextureSRTKey::searchUpdateMaterialID": 0x8002d908,
		"J3DAnmTevRegKey::getTevColorReg": 0x8002da2c,
		"getTevColorReg": 0x8002da2c,
		"J3DAnmTevRegKey::getTevKonstReg": 0x8002dd78,
		"getTevKonstReg": 0x8002dd78,
		"J3DAnmTevRegKey::searchUpdateMaterialID": 0x8002e0c4,
		"J3DAnmColorKey::~J3DAnmColorKey": 0x8002e1b8,
		"J3DAnmColor::getColor": 0x8002e224,
		"J3DAnmColor::~J3DAnmColor": 0x8002e228,
		"J3DAnmColorFull::~J3DAnmColorFull": 0x8002e284,
		"J3DAnmVtxColorKey::~J3DAnmVtxColorKey": 0x8002e2f0,
		"J3DAnmVtxColor::~J3DAnmVtxColor": 0x8002e35c,
		"J3DAnmVtxColorFull::~J3DAnmVtxColorFull": 0x8002e3b8,
		"J3DAnmClusterKey::~J3DAnmClusterKey": 0x8002e424,
		"J3DAnmCluster::~J3DAnmCluster": 0x8002e490,
		"J3DAnmClusterFull::~J3DAnmClusterFull": 0x8002e4ec,
		"J3DAnmTransformKey::~J3DAnmTransformKey": 0x8002e588,
		"J3DAnmTransform::~J3DAnmTransform": 0x8002e5f4,
		"J3DAnmTransformFull::~J3DAnmTransformFull": 0x8002e650,
		"J3DJointFactory::J3DJointFactory": 0x8002eb84,
		"J3DJointFactory::create": 0x8002ebdc,
		"J3DMaterialFactory::J3DMaterialFactory": 0x8002edb0,
		"J3DMaterialFactory::countUniqueMaterials": 0x8002efe4,
		"J3DMaterialFactory::countStages": 0x8002f020,
		"J3DMaterialFactory::create": 0x8002f104,
		"J3DMaterialFactory::newMatColor": 0x8002fa28,
		"J3DMaterialFactory::newColorChanNum": 0x8002fab8,
		"J3DMaterialFactory::newColorChan": 0x8002faf0,
		"J3DMaterialFactory::newAmbColor": 0x8002fbb8,
		"newAmbColor": 0x8002fbb8,
		"J3DMaterialFactory::newTexGenNum": 0x8002fc48,
		"J3DMaterialFactory::newTexCoord": 0x8002fc80,
		"J3DMaterialFactory::newTexMtx": 0x8002fcf4,
		"J3DMaterialFactory::newCullMode": 0x8002fd88,
		"J3DMaterialFactory::newTexNo": 0x8002fdc8,
		"J3DMaterialFactory::newTevOrder": 0x8002fe10,
		"J3DMaterialFactory::newTevColor": 0x8002fe84,
		"J3DMaterialFactory::newTevKColor": 0x8002ff1c,
		"J3DMaterialFactory::newTevStageNum": 0x8002ffac,
		"J3DMaterialFactory::newTevStage": 0x8002ffe4,
		"J3DMaterialFactory::newTevSwapModeTable": 0x80030250,
		"J3DMaterialFactory::newIndTexStageNum": 0x800302ec,
		"newIndTexStageNum": 0x800302ec,
		"J3DMaterialFactory::newIndTexOrder": 0x80030314,
		"newIndTexOrder": 0x80030314,
		"J3DMaterialFactory::newIndTexMtx": 0x80030374,
		"newIndTexMtx": 0x80030374,
		"J3DMaterialFactory::newIndTevStage": 0x8003043c,
		"newIndTevStage": 0x8003043c,
		"J3DMaterialFactory::newIndTexCoordScale": 0x80030520,
		"newIndTexCoordScale": 0x80030520,
		"J3DMaterialFactory::newFog": 0x80030580,
		"J3DMaterialFactory::newAlphaComp": 0x8003060c,
		"J3DMaterialFactory::newBlend": 0x8003068c,
		"J3DMaterialFactory::newZMode": 0x80030708,
		"J3DMaterialFactory::newZCompLoc": 0x8003076c,
		"J3DMaterialFactory::newDither": 0x800307a4,
		"J3DMaterialFactory::newNBTScale": 0x800307dc,
		"J3DModelLoaderDataBase::load": 0x80030a64,
		"J3DModelLoader_v26::~J3DModelLoader_v26": 0x80030b88,
		"J3DModelLoader_v21::~J3DModelLoader_v21": 0x80030be4,
		"J3DModelLoader::~J3DModelLoader": 0x80030c40,
		"J3DModelLoaderDataBase::loadMaterialTable": 0x80030c8c,
		"J3DModelLoader::load": 0x80030dac,
		"J3DModelLoader::readMaterial_v21": 0x80030fd0,
		"J3DModelLoader::readMaterial": 0x80030fd4,
		"J3DModelLoader::loadMaterialTable": 0x80030fd8,
		"J3DModelLoader::readMaterialTable_v21": 0x8003111c,
		"J3DModelLoader::readMaterialTable": 0x80031120,
		"J3DModelLoader::setupBBoardInfo": 0x80031124,
		"setupBBoardInfo": 0x80031124,
		"J3DModelLoader::readInformation": 0x80031270,
		"readInformation": 0x80031270,
		"J3DModelLoader::readVertex": 0x80031434,
		"readVertex": 0x80031434,
		"J3DModelLoader::readEnvelop": 0x80031630,
		"readEnvelop": 0x80031630,
		"J3DModelLoader::readDraw": 0x800316c0,
		"readDraw": 0x800316c0,
		"J3DModelLoader::readJoint": 0x80031754,
		"readJoint": 0x80031754,
		"J3DModelLoader_v26::readMaterial": 0x80031844,
		"J3DMaterial::~J3DMaterial": 0x80031a9c,
		"J3DMaterial::J3DMaterial": 0x80031adc,
		"J3DModelLoader_v21::readMaterial_v21": 0x80031b0c,
		"J3DModelLoader::readShape": 0x80031d64,
		"readShape": 0x80031d64,
		"J3DModelLoader::readTexture": 0x80031eac,
		"readTexture": 0x80031eac,
		"J3DModelLoader_v26::readMaterialTable": 0x80031f64,
		"J3DModelLoader_v21::readMaterialTable_v21": 0x800320a8,
		"J3DModelLoader::readTextureTable": 0x800321ec,
		"readTextureTable": 0x800321ec,
		"J3DTexture::~J3DTexture": 0x800322a4,
		"J3DShapeFactory::J3DShapeFactory": 0x80032380,
		"J3DShapeFactory::create": 0x80032430,
		"J3DShapeFactory::newShapeMtx": 0x800325e8,
		"newShapeMtx": 0x800325e8,
		"J3DShapeFactory::newShapeDraw": 0x800326dc,
		"newShapeDraw": 0x800326dc,
		"J3DShapeFactory::allocVcdVatCmdBuffer": 0x80032770,
		"allocVcdVatCmdBuffer": 0x80032770,
		"J3DAnmLoaderDataBase::load": 0x80032808,
		"J3DAnmVtxColor::J3DAnmVtxColor": 0x80032f08,
		"J3DAnmColor::J3DAnmColor": 0x80032f60,
		"J3DAnmFullLoader_v15::J3DAnmFullLoader_v15": 0x80032fc4,
		"J3DAnmLoader::~J3DAnmLoader": 0x80032fe0,
		"J3DAnmFullLoader_v15::~J3DAnmFullLoader_v15": 0x8003302c,
		"J3DAnmKeyLoader_v15::J3DAnmKeyLoader_v15": 0x80033088,
		"J3DAnmKeyLoader_v15::~J3DAnmKeyLoader_v15": 0x800330a4,
		"J3DAnmFullLoader_v15::load": 0x80033100,
		"J3DAnmFullLoader_v15::readAnmTransform": 0x8003322c,
		"J3DAnmFullLoader_v15::readAnmColor": 0x800332c0,
		"J3DAnmFullLoader_v15::readAnmTexPattern": 0x800333a8,
		"readAnmTexPattern": 0x800333a8,
		"J3DAnmFullLoader_v15::readAnmVisibility": 0x80033468,
		"readAnmVisibility": 0x80033468,
		"J3DAnmFullLoader_v15::readAnmCluster": 0x800334e4,
		"J3DAnmFullLoader_v15::readAnmVtxColor": 0x80033550,
		"J3DAnmKeyLoader_v15::load": 0x800336c8,
		"J3DAnmKeyLoader_v15::readAnmTransform": 0x800337f4,
		"J3DAnmKeyLoader_v15::readAnmTextureSRT": 0x80033890,
		"readAnmTextureSRT": 0x80033890,
		"J3DAnmKeyLoader_v15::readAnmColor": 0x80033a8c,
		"J3DAnmKeyLoader_v15::readAnmCluster": 0x80033b94,
		"J3DAnmKeyLoader_v15::readAnmTevReg": 0x80033c00,
		"readAnmTevReg": 0x80033c00,
		"J3DAnmKeyLoader_v15::readAnmVtxColor": 0x80033dbc,
		"J3DAnmVisibilityFull::~J3DAnmVisibilityFull": 0x80033f34,
		"J3DAnmTexPattern::~J3DAnmTexPattern": 0x80033f98,
		"J3DAnmTevRegKey::~J3DAnmTevRegKey": 0x80033ffc,
		"J3DAnmTextureSRTKey::~J3DAnmTextureSRTKey": 0x80034060,
		"JGadget::TList_pointer_void::TList_pointer_void": 0x800341fc,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::erase": 0x8003421c,
		"JGadget::TList_pointer_void::~TList_pointer_void": 0x80034288,
		"JGadget::TList_pointer_void::insert": 0x8003436c,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::CreateNode_": 0x800343f4,
		"CreateNode_": 0x800343f4,
		"JSystem::JKRDecompressFromDVD": 0x800349ac,
		"JKRDecompressFromDVD": 0x800349ac,
		"JKRDvdRipper::isErrorRetry": 0x80034f20,
		"isErrorRetry": 0x80034f20,
		"JSystem::__sinit_JKRDvdRipper_cpp": 0x80034f28,
		"__sinit_JKRDvdRipper_cpp": 0x80034f28,
		"JSUList<JKRDMCommand>::~JSUList": 0x80034f74,
		"J2DGrafContext::setPort": 0x8003515c,
		"J2DGrafContext::setup2D": 0x80035228,
		"setup2D": 0x80035228,
		"J2DGrafContext::setScissor": 0x800353d4,
		"setScissor": 0x800353d4,
		"J2DGrafContext::scissor": 0x8003548c,
		"scissor": 0x8003548c,
		"J2DGrafContext::setColor": 0x800354f4,
		"J2DGrafContext::setLineWidth": 0x800355b0,
		"setLineWidth": 0x800355b0,
		"J2DGrafContext::fillBox": 0x800355dc,
		"fillBox": 0x800355dc,
		"J2DGrafContext::setLookat": 0x80035708,
		"JKRDvdAramRipper::loadToAram_Async": 0x800358b0,
		"loadToAram_Async": 0x800358b0,
		"JKRDvdAramRipper::callCommand_Async": 0x8003595c,
		"callCommand_Async": 0x8003595c,
		"JKRDvdAramRipper::syncAram": 0x80035c88,
		"syncAram": 0x80035c88,
		"JKRADCommand::JKRADCommand": 0x80035d58,
		"JKRADCommand::~JKRADCommand": 0x80035d94,
		"JSystem::JKRDecompressFromDVDToAram": 0x80035e20,
		"JKRDecompressFromDVDToAram": 0x80035e20,
		"JSystem::dmaBufferFlush": 0x80036380,
		"dmaBufferFlush": 0x80036380,
		"JSystem::__sinit_JKRDvdAramRipper_cpp": 0x800363e8,
		"__sinit_JKRDvdAramRipper_cpp": 0x800363e8,
		"JSUList<JKRADCommand>::~JSUList": 0x80036434,
		"JKRDecomp::create": 0x8003648c,
		"JKRDecomp::JKRDecomp": 0x800364e8,
		"JKRDecomp::~JKRDecomp": 0x80036540,
		"JKRDecomp::run": 0x800365a4,
		"JKRDecomp::sendCommand": 0x80036664,
		"JKRDecomp::orderSync": 0x80036694,
		"JKRDecomp::decode": 0x8003673c,
		"decode": 0x8003673c,
		"JKRDecomp::decodeSZP": 0x800367c8,
		"decodeSZP": 0x800367c8,
		"JKRDecomp::decodeSZS": 0x80036974,
		"decodeSZS": 0x80036974,
		"JKRDecomp::checkCompressed": 0x80036a58,
		"checkCompressed": 0x80036a58,
		"JKRDecompCommand::JKRDecompCommand": 0x80036aa8,
		"JKRDecompCommand::~JKRDecompCommand": 0x80036af8,
		"J2DOrthoGraph::setPort": 0x80036cec,
		"J2DOrthoGraph::setLookat": 0x80036da4,
		"J2DOrthoGraph::scissorBounds": 0x80036de0,
		"scissorBounds": 0x80036de0,
		"J3DVertexData::J3DVertexData": 0x80037180,
		"J3DVertexData::~J3DVertexData": 0x800371cc,
		"J3DVertexBuffer::J3DVertexBuffer": 0x8003720c,
		"J3DVertexBuffer::~J3DVertexBuffer": 0x80037278,
		"J3DVertexBuffer::copyTransformedVtxArray": 0x800372c4,
		"copyTransformedVtxArray": 0x800372c4,
		"J3DDrawMtxData::J3DDrawMtxData": 0x80037394,
		"J3DDrawMtxData::~J3DDrawMtxData": 0x800373a8,
		"J3DDisplayListObj::newDisplayList": 0x800373e8,
		"newDisplayList": 0x800373e8,
		"J3DDisplayListObj::callDL": 0x80037444,
		"callDL": 0x80037444,
		"J3DPacket::isSame": 0x80037470,
		"J3DPacket::entry": 0x80037478,
		"J3DPacket::addChildPacket": 0x80037480,
		"addChildPacket": 0x80037480,
		"J3DCallBackPacket::draw": 0x800374a0,
		"J3DPacket::draw": 0x80037530,
		"J3DPacket::~J3DPacket": 0x80037534,
		"J3DDrawPacket::~J3DDrawPacket": 0x80037580,
		"J3DDrawPacket::draw": 0x800375dc,
		"J3DDrawPacket::beginDL": 0x80037608,
		"beginDL": 0x80037608,
		"J3DDrawPacket::endDL": 0x80037668,
		"endDL": 0x80037668,
		"J3DMatPacket::J3DMatPacket": 0x800376c4,
		"J3DMatPacket::~J3DMatPacket": 0x80037718,
		"J3DMatPacket::addShapePacket": 0x80037784,
		"addShapePacket": 0x80037784,
		"J3DMatPacket::draw": 0x800377a4,
		"J3DShapePacket::J3DShapePacket": 0x80037844,
		"J3DCallBackPacket::~J3DCallBackPacket": 0x800378a8,
		"J3DShapePacket::~J3DShapePacket": 0x80037904,
		"J3DShapePacket::draw": 0x80037970,
		"J3DMatPacket::isSame": 0x80037a34,
		"JSystem::J3DLoadArrayBasePtr": 0x80037a58,
		"J3DLoadArrayBasePtr": 0x80037a58,
		"JSystem::J3DSetVtxAttrFmtv": 0x80037a8c,
		"J3DSetVtxAttrFmtv": 0x80037a8c,
		"JSystem::loadCullMode": 0x80038018,
		"loadCullMode": 0x80038018,
		"J3DLightObj::load": 0x8003801c,
		"J3DTexMtx::calc": 0x800380b0,
		"J3DTexMtx::load": 0x80038540,
		"JSystem::loadTexNo": 0x80038570,
		"loadTexNo": 0x80038570,
		"JSystem::loadDither": 0x800388b8,
		"loadDither": 0x800388b8,
		"JSystem::loadNBTScale": 0x800388bc,
		"loadNBTScale": 0x800388bc,
		"JSystem::makeTexCoordTable": 0x800388f0,
		"makeTexCoordTable": 0x800388f0,
		"JSystem::makeAlphaCmpTable": 0x80038adc,
		"makeAlphaCmpTable": 0x80038adc,
		"JSystem::makeZModeTable": 0x80038e84,
		"makeZModeTable": 0x80038e84,
		"JSystem::makeTevSwapTable": 0x80038fbc,
		"makeTevSwapTable": 0x80038fbc,
		"J3DDrawBuffer::J3DDrawBuffer": 0x80039130,
		"J3DDrawBuffer::frameInit": 0x800391d8,
		"frameInit": 0x800391d8,
		"J3DDrawBuffer::entryMatSort": 0x80039210,
		"entryMatSort": 0x80039210,
		"J3DDrawBuffer::entryMatAnmSort": 0x80039368,
		"entryMatAnmSort": 0x80039368,
		"J3DDrawBuffer::entryZSort": 0x80039428,
		"entryZSort": 0x80039428,
		"J3DDrawBuffer::entryModelSort": 0x80039528,
		"entryModelSort": 0x80039528,
		"J3DDrawBuffer::entryInvalidSort": 0x80039578,
		"entryInvalidSort": 0x80039578,
		"J3DDrawBuffer::entryNonSort": 0x800395cc,
		"entryNonSort": 0x800395cc,
		"J3DDrawBuffer::entryImm": 0x80039600,
		"entryImm": 0x80039600,
		"J3DDrawBuffer::draw": 0x80039620,
		"J3DDrawBuffer::drawHead": 0x80039674,
		"drawHead": 0x80039674,
		"J3DDrawBuffer::drawTail": 0x80039700,
		"drawTail": 0x80039700,
		"JSystem::__sinit_J3DDrawBuffer_cpp": 0x8003978c,
		"__sinit_J3DDrawBuffer_cpp": 0x8003978c,
		"J3DTexNoAnm::calc": 0x80039858,
		"J3DMaterialAnm::initialize": 0x80039888,
		"J3DMaterialAnm::calc": 0x800398f8,
		"J3DMaterialAnm::~J3DMaterialAnm": 0x80039aec,
		"JGadget::TVector_pointer_void::TVector_pointer_void": 0x80039b38,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::DestroyElement_": 0x80039b64,
		"std::__copy<void*,1,0>::copy": 0x80039b78,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::InsertRaw": 0x80039c34,
		"JGadget::TVector_pointer_void::~TVector_pointer_void": 0x80039f28,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::erase": 0x80039f90,
		"JGadget::TVector_pointer_void::insert": 0x80039ff8,
		"JGadget::TVector_pointer_void::reserve": 0x8003a070,
		"reserve": 0x8003a070,
		"JKRAramBlock::JKRAramBlock": 0x8003a148,
		"JKRAramBlock::~JKRAramBlock": 0x8003a1b4,
		"JKRAramBlock::allocHead": 0x8003a270,
		"allocHead": 0x8003a270,
		"JKRAramBlock::allocTail": 0x8003a30c,
		"allocTail": 0x8003a30c,
		"JKRAramPiece::sendCommand": 0x8003a3b0,
		"JKRAramPiece::orderAsync": 0x8003a3d0,
		"orderAsync": 0x8003a3d0,
		"JKRAramPiece::orderSync": 0x8003a524,
		"JKRAramPiece::startDMA": 0x8003a5d4,
		"startDMA": 0x8003a5d4,
		"JKRAramPiece::doneDMA": 0x8003a64c,
		"doneDMA": 0x8003a64c,
		"JKRAMCommand::JKRAMCommand": 0x8003a6f4,
		"JKRAMCommand::~JKRAMCommand": 0x8003a768,
		"JSystem::__sinit_JKRAramPiece_cpp": 0x8003a810,
		"__sinit_JKRAramPiece_cpp": 0x8003a810,
		"JKRAramStream::create": 0x8003a85c,
		"JKRAramStream::JKRAramStream": 0x8003a8c8,
		"JKRAramStream::~JKRAramStream": 0x8003a920,
		"JKRAramStream::run": 0x8003a984,
		"JKRAramStream::readFromAram": 0x8003a9ec,
		"readFromAram": 0x8003a9ec,
		"JKRAramStream::writeToAram": 0x8003a9f4,
		"writeToAram": 0x8003a9f4,
		"JKRAramStream::write_StreamToAram_Async": 0x8003abc4,
		"write_StreamToAram_Async": 0x8003abc4,
		"JKRAramStream::sync": 0x8003ac80,
		"JKRAramStream::setTransBuffer": 0x8003ad14,
		"setTransBuffer": 0x8003ad14,
		"JKRAramStreamCommand::JKRAramStreamCommand": 0x8003ad68,
		"JUTAssertion::flushMessage": 0x8003ad74,
		"flushMessage": 0x8003ad74,
		"JUTFont::isLeadByte_1Byte": 0x8003ae0c,
		"isLeadByte_1Byte": 0x8003ae0c,
		"JUTFont::isLeadByte_2Byte": 0x8003ae14,
		"isLeadByte_2Byte": 0x8003ae14,
		"JUTFont::isLeadByte_ShiftJIS": 0x8003ae1c,
		"isLeadByte_ShiftJIS": 0x8003ae1c,
		"JUTResFont::JUTResFont": 0x8003ae6c,
		"JUTResFont::~JUTResFont": 0x8003aee8,
		"JUTResFont::initiate": 0x8003af84,
		"JUTResFont::protected_initiate": 0x8003b010,
		"protected_initiate": 0x8003b010,
		"JUTResFont::countBlock": 0x8003b0c0,
		"countBlock": 0x8003b0c0,
		"JUTResFont::setBlock": 0x8003b1b8,
		"setBlock": 0x8003b1b8,
		"JUTResFont::drawChar_scale": 0x8003b66c,
		"JUTResFont::getDescent": 0x8003ba7c,
		"JUTResFont::getHeight": 0x8003ba88,
		"JUTResFont::getAscent": 0x8003bae4,
		"JUTResFont::loadFont": 0x8003bafc,
		"loadFont": 0x8003bafc,
		"JUTResFont::getWidthEntry": 0x8003bbfc,
		"JUTResFont::isLeadByte": 0x8003bc98,
		"JUTResFont::getFontCode": 0x8003bcc8,
		"getFontCode": 0x8003bcc8,
		"JUTResFont::getFontType": 0x8003be48,
		"JUTResFont::loadImage": 0x8003be54,
		"JUTResFont::convertSjis": 0x8003bfc8,
		"convertSjis": 0x8003bfc8,
		"JUTResFont::getLeading": 0x8003bff8,
		"JUTRomFont::JUTRomFont": 0x8003c004,
		"JUTRomFont::initiate": 0x8003c060,
		"JUTRomFont::~JUTRomFont": 0x8003c0a4,
		"JUTRomFont::loadImage": 0x8003c140,
		"JUTRomFont::setGX": 0x8003c214,
		"JUTRomFont::drawChar_scale": 0x8003c2ec,
		"JUTRomFont::getDescent": 0x8003c740,
		"JUTRomFont::getAscent": 0x8003c74c,
		"JUTRomFont::getHeight": 0x8003c758,
		"JUTRomFont::getWidth": 0x8003c7b4,
		"JUTRomFont::getWidthEntry": 0x8003c7c0,
		"JUTRomFont::isLeadByte": 0x8003c828,
		"JUTRomFont::getLeading": 0x8003c858,
		"JUTRomFont::getResFont": 0x8003c864,
		"getResFont": 0x8003c864,
		"JUTRomFont::getFontType": 0x8003c86c,
		"JSystem::J3DGDLoadTexMtxImm": 0x8003c878,
		"J3DGDLoadTexMtxImm": 0x8003c878,
		"JSystem::J3DGDSetChanAmbColor": 0x8003cf20,
		"J3DGDSetChanAmbColor": 0x8003cf20,
		"JSystem::J3DGDSetChanMatColor": 0x8003d064,
		"J3DGDSetChanMatColor": 0x8003d064,
		"JSystem::J3DGDSetChanCtrl": 0x8003d1a8,
		"J3DGDSetChanCtrl": 0x8003d1a8,
		"JSystem::J3DGDSetTexCoordGen": 0x8003d414,
		"J3DGDSetTexCoordGen": 0x8003d414,
		"JSystem::J3DGDSetFog": 0x8003d77c,
		"J3DGDSetFog": 0x8003d77c,
		"JSystem::J3DGDSetTexCoordScale2": 0x8003daf8,
		"J3DGDSetTexCoordScale2": 0x8003daf8,
		"JSystem::J3DGDSetTexImgAttr": 0x8003dcf4,
		"J3DGDSetTexImgAttr": 0x8003dcf4,
		"JSystem::J3DGDSetTexImgPtr": 0x8003ddd8,
		"J3DGDSetTexImgPtr": 0x8003ddd8,
		"JSystem::J3DGDSetTexTlut": 0x8003dea4,
		"J3DGDSetTexTlut": 0x8003dea4,
		"JSystem::J3DGDLoadTlut": 0x8003df78,
		"J3DGDLoadTlut": 0x8003df78,
		"JSystem::J3DGDSetTevKColor": 0x8003e330,
		"J3DGDSetTevKColor": 0x8003e330,
		"JSystem::JRNLoadCurrentMtx": 0x8003e498,
		"JRNLoadCurrentMtx": 0x8003e498,
		"JSystem::JRNSetTevIndirect": 0x8003e530,
		"JRNSetTevIndirect": 0x8003e530,
		"JSystem::JRNSetIndTexMtx": 0x8003e658,
		"JRNSetIndTexMtx": 0x8003e658,
		"JSystem::JRNSetIndTexCoordScale": 0x8003e930,
		"JRNSetIndTexCoordScale": 0x8003e930,
		"JSystem::JRNSetIndTexOrder": 0x8003ea20,
		"JRNSetIndTexOrder": 0x8003ea20,
		"JSystem::JRNLoadTexCached": 0x8003ec34,
		"JRNLoadTexCached": 0x8003ec34,
		"JSystem::JRNISetTevOrder": 0x8003ecb4,
		"JRNISetTevOrder": 0x8003ecb4,
		"JSystem::JRNISetTevColorS10": 0x8003ee24,
		"JRNISetTevColorS10": 0x8003ee24,
		"JSystem::JRNISetFogRangeAdj": 0x8003f058,
		"JRNISetFogRangeAdj": 0x8003f058,
		"JUTConsole::create": 0x8003f204,
		"JUTConsole::JUTConsole": 0x8003f29c,
		"JUTConsole::~JUTConsole": 0x8003f3a0,
		"JUTConsole::getLineFromObjectSize": 0x8003f410,
		"getLineFromObjectSize": 0x8003f410,
		"JUTConsole::clear": 0x8003f420,
		"JUTConsole::doDraw": 0x8003f47c,
		"doDraw": 0x8003f47c,
		"JUTConsole::print_f": 0x8003f920,
		"print_f": 0x8003f920,
		"JUTConsole::print": 0x8003f9a0,
		"JSystem::JUTConsole_print_f_va_": 0x8003fbb0,
		"JUTConsole_print_f_va_": 0x8003fbb0,
		"JUTConsole::scroll": 0x8003fbf8,
		"scroll": 0x8003fbf8,
		"JUTConsole::getUsedLine": 0x8003fcd4,
		"getUsedLine": 0x8003fcd4,
		"JUTConsole::getLineOffset": 0x8003fcf8,
		"getLineOffset": 0x8003fcf8,
		"JUTConsoleManager::JUTConsoleManager": 0x8003fd1c,
		"JUTConsoleManager::createManager": 0x8003fd44,
		"createManager": 0x8003fd44,
		"JUTConsoleManager::appendConsole": 0x8003fd8c,
		"appendConsole": 0x8003fd8c,
		"JUTConsoleManager::removeConsole": 0x8003fe28,
		"removeConsole": 0x8003fe28,
		"JGadget::TNodeLinkList::end": 0x8003ff00,
		"JGadget::TLinkList<10JUTConsole,-24>::iterator::iterator": 0x8003ff0c,
		"JUTConsoleManager::drawDirect": 0x8003ff18,
		"drawDirect": 0x8003ff18,
		"JUTConsoleManager::setDirectConsole": 0x8003ff98,
		"setDirectConsole": 0x8003ff98,
		"JGadget::TLinkListNode::getNext": 0x80040148,
		"getNext": 0x80040148,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getValue": 0x80040150,
		"Element_getValue": 0x80040150,
		"JGadget::TNodeLinkList::iterator::operator_->": 0x80040158,
		"operator_->": 0x80040158,
		"JGadget::TLinkListNode::getPrev": 0x80040160,
		"getPrev": 0x80040160,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getNode": 0x80040168,
		"JSystem::JUTSetReportConsole": 0x80040170,
		"JUTSetReportConsole": 0x80040170,
		"JSystem::JUTGetReportConsole": 0x80040178,
		"JUTGetReportConsole": 0x80040178,
		"JSystem::JUTSetWarningConsole": 0x80040180,
		"JUTSetWarningConsole": 0x80040180,
		"JSystem::JUTGetWarningConsole": 0x80040188,
		"JUTGetWarningConsole": 0x80040188,
		"JSystem::JUTReportConsole_f": 0x80040190,
		"JUTReportConsole_f": 0x80040190,
		"JSystem::JUTReportConsole": 0x80040254,
		"JUTReportConsole": 0x80040254,
		"JSystem::JUTWarningConsole_f": 0x80040280,
		"JUTWarningConsole_f": 0x80040280,
		"JSystem::JUTWarningConsole": 0x80040344,
		"JUTWarningConsole": 0x80040344,
		"JUTDirectFile::JUTDirectFile": 0x80040370,
		"JUTDirectFile::~JUTDirectFile": 0x80040394,
		"JUTDirectFile::fopen": 0x800403dc,
		"fopen": 0x800403dc,
		"JUTDirectFile::fclose": 0x80040480,
		"fclose": 0x80040480,
		"JUTDirectFile::fgets": 0x800404dc,
		"fgets": 0x800404dc,
		"JGadget::TNodeLinkList::Insert": 0x80040714,
		"JGadget::TNodeLinkList::Erase": 0x80040740,
		"Erase": 0x80040740,
		"JGadget::TNodeLinkList::Remove": 0x80040764,
		"Remove": 0x80040764,
		"JGadget::TNodeLinkList::Remove_if": 0x800407b4,
		"Remove_if": 0x800407b4,
		"JGadget::TSingleNodeLinkList::~TSingleNodeLinkList": 0x800408d4,
		"JGadget::TSingleNodeLinkList::Insert": 0x80040914,
		"JDrama::TActor::load": 0x80040948,
		"JSystem::__ct__Q26JDrama10TFlagT<Us>FUs": 0x80040b00,
		"JDrama::TActor::perform": 0x80040b50,
		"JDrama::TPolarCamera::load": 0x80040de4,
		"JDrama::TPolarCamera::perform": 0x80040e4c,
		"JDrama::TLookAtCamera::perform": 0x80041304,
		"JDrama::TOrthoProj::load": 0x8004147c,
		"JDrama::TOrthoProj::perform": 0x800414f4,
		"JDrama::TSmplChara::load": 0x80041918,
		"JDrama::TSmplChara::~TSmplChara": 0x8004196c,
		"JDrama::TSmplChara::getRes": 0x80041a00,
		"JDrama::TSmplChara::mountArc": 0x80041a30,
		"mountArc": 0x80041a30,
		"JDrama::TDirector::searchF": 0x80041ad4,
		"JDrama::TDirector::direct": 0x80041b88,
		"JDrama::TDisplay::TDisplay": 0x80041d94,
		"JDrama::TDisplay::startRendering": 0x80041ec0,
		"startRendering": 0x80041ec0,
		"JDrama::TDisplay::endRendering": 0x80041fb8,
		"endRendering": 0x80041fb8,
		"JDrama::TDrawBufObj::load": 0x8004217c,
		"JDrama::TDrawBufObj::perform": 0x800421f4,
		"JDrama::TDStageDisp::TDStageDisp": 0x8004230c,
		"JDrama::TViewConnecter::~TViewConnecter": 0x800424dc,
		"JDrama::TDStageDisp::getEfbCtrlDisp": 0x80042550,
		"getEfbCtrlDisp": 0x80042550,
		"JDrama::TDStageDisp::~TDStageDisp": 0x800425e4,
		"JDrama::TDStageGroup::perform": 0x80042668,
		"JDrama::TDStageGroup::~TDStageGroup": 0x800426fc,
		"JDrama::TEfbCtrl::perform": 0x800427d0,
		"JDrama::TEfbCtrl::setSrcRect": 0x800428a8,
		"setSrcRect": 0x800428a8,
		"JDrama::TEfbCtrlDisp::perform": 0x80042960,
		"JDrama::TEfbCtrlTex::TEfbCtrlTex": 0x80042ab8,
		"JDrama::TEfbCtrlTex::setTexAttb": 0x80042b9c,
		"setTexAttb": 0x80042b9c,
		"JDrama::TEfbCtrlTex::perform": 0x80042c08,
		"JDrama::TEfbCtrlTex::~TEfbCtrlTex": 0x80042e00,
		"JDrama::TEfbCtrlDisp::~TEfbCtrlDisp": 0x80042e84,
		"JDrama::DecidePixelFmt": 0x80042f08,
		"DecidePixelFmt": 0x80042f08,
		"JDrama::IssueGXSetCopyFilter": 0x800430b0,
		"IssueGXSetCopyFilter": 0x800430b0,
		"JDrama::IssueGXSetCopyClear": 0x80043100,
		"IssueGXSetCopyClear": 0x80043100,
		"JDrama::IssueGXCopyDisp": 0x800431d8,
		"IssueGXCopyDisp": 0x800431d8,
		"JDrama::TFrmGXSet::perform": 0x8004336c,
		"JDrama::TGraphics::setViewport": 0x80043604,
		"setViewport": 0x80043604,
		"JDrama::TLight::load": 0x80043788,
		"JDrama::TLight::perform": 0x800437ec,
		"JDrama::TLight::correct": 0x80043844,
		"correct": 0x80043844,
		"JDrama::TLightAry::load": 0x80043948,
		"JDrama::TLightAry::searchF": 0x80043a40,
		"JDrama::TLightAry::setLightNum": 0x80043ad0,
		"setLightNum": 0x80043ad0,
		"JDrama::TIdxLight::TIdxLight": 0x80043c1c,
		"JDrama::TLightAry::perform": 0x80043ec8,
		"JDrama::TAmbColor::load": 0x80043f68,
		"JDrama::TAmbColor::perform": 0x80043fb8,
		"JDrama::TAmbAry::load": 0x80044014,
		"JDrama::TAmbAry::searchF": 0x8004410c,
		"JDrama::TAmbAry::setAmbNum": 0x8004419c,
		"setAmbNum": 0x8004419c,
		"JDrama::TAmbColor::TAmbColor": 0x80044294,
		"JDrama::TLightMap::load": 0x80044338,
		"JDrama::TLightMap::TLightInfo::TLightInfo": 0x8004442c,
		"JDrama::TLightMap::perform": 0x8004443c,
		"JDrama::TLightMap::~TLightMap": 0x800444d4,
		"JDrama::TAmbAry::~TAmbAry": 0x80044548,
		"JDrama::TAmbAry::perform": 0x800445bc,
		"JDrama::TLightAry::~TLightAry": 0x800445c0,
		"JDrama::TNameRef::calcKeyCode": 0x8004468c,
		"JDrama::TNameRef::genObject": 0x8004474c,
		"genObject": 0x8004474c,
		"JDrama::TNameRef::~TNameRef": 0x800447fc,
		"JDrama::TNameRef::load": 0x80044850,
		"JDrama::TNameRef::save": 0x800448a8,
		"JDrama::TNameRef::loadAfter": 0x800448ac,
		"JDrama::TNameRef::searchF": 0x800448b0,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadSuper": 0x80044920,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfterSuper": 0x80044940,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::searchF": 0x80044960,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::loadAfter": 0x80044a48,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::load": 0x80044af4,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::perform": 0x80044c3c,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::searchF": 0x80044cf8,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfter": 0x80044de0,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::load": 0x80044e98,
		"JDrama::TNameRefGen::load": 0x80044fe0,
		"JDrama::TNameRefGen::getNameRef": 0x800450cc,
		"JDrama::TLight::TLight": 0x80045714,
		"JDrama::TCamera::TCamera": 0x800458e8,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::~TNameRefPtrListT": 0x800459b4,
		"~TNameRefPtrListT": 0x800459b4,
		"JDrama::TPlacement::load": 0x80045a2c,
		"JDrama::IsEqualRenderModeVIParams": 0x80045a94,
		"IsEqualRenderModeVIParams": 0x80045a94,
		"JDrama::IsRenderModeHalfAspectRatio": 0x80045bb4,
		"IsRenderModeHalfAspectRatio": 0x80045bb4,
		"JDrama::GetRenderModeYScale": 0x80045bd0,
		"GetRenderModeYScale": 0x80045bd0,
		"JDrama::CalcRenderModeXFBHeight": 0x80045c74,
		"CalcRenderModeXFBHeight": 0x80045c74,
		"JDrama::CalcRenderModeVIXOrigin": 0x80045d54,
		"CalcRenderModeVIXOrigin": 0x80045d54,
		"JDrama::CalcRenderModeVIYOrigin": 0x80045d98,
		"CalcRenderModeVIYOrigin": 0x80045d98,
		"JDrama::CopyRenderModeSamplePattern": 0x80045ddc,
		"CopyRenderModeSamplePattern": 0x80045ddc,
		"JDrama::CopyRenderModeVFilter": 0x80045e04,
		"CopyRenderModeVFilter": 0x80045e04,
		"TCamConnecter::perform": 0x80045ef4,
		"JDrama::TScreen::TScreen": 0x80045f90,
		"JDrama::TScreen::assignCamera": 0x80046068,
		"assignCamera": 0x80046068,
		"JDrama::TScreen::assignViewObj": 0x80046074,
		"assignViewObj": 0x80046074,
		"JDrama::TScreen::~TScreen": 0x80046080,
		"TCamConnecter::~TCamConnecter": 0x80046104,
		"JDrama::TSmJ3DAct::load": 0x80046188,
		"JDrama::TSmJ3DAct::perform": 0x8004628c,
		"JDrama::TSmJ3DScn::TSmJ3DScn": 0x80046818,
		"JDrama::TSmJ3DScn::perform": 0x8004691c,
		"JDrama::TSmJ3DScn::loadSuper": 0x80046a30,
		"JDrama::TSmJ3DScn::~TSmJ3DScn": 0x80046ae4,
		"JDrama::TVideo::TVideo": 0x80046b80,
		"JDrama::TVideo::setNextXFB": 0x80046c74,
		"setNextXFB": 0x80046c74,
		"JDrama::TVideo::waitForRetrace": 0x80046c7c,
		"waitForRetrace": 0x80046c7c,
		"JDrama::TViewConnecter::TViewConnecter": 0x80046e34,
		"JDrama::TViewConnecter::perform": 0x80046ed0,
		"JDrama::TViewObj::testPerform": 0x80046f6c,
		"testPerform": 0x80046f6c,
		"JDrama::TViewport::TViewport": 0x80046fd4,
		"JDrama::TViewport::perform": 0x80047064,
		"JDrama::TViewport::load": 0x80047114,
		"JDrama::TViewport::~TViewport": 0x8004718c,
		"JALCalc::linearTransform": 0x80047200,
		"linearTransform": 0x80047200,
		"JALCalc::getParamByExp": 0x80047274,
		"getParamByExp": 0x80047274,
		"JALCalc::getRandom": 0x800473c8,
		"getRandom": 0x800473c8,
		"JALCalc::getRandom_0_1": 0x8004745c,
		"getRandom_0_1": 0x8004745c,
		"JALCalc::getDist": 0x800474d0,
		"getDist": 0x800474d0,
		"JALCalc::getDistPow": 0x80047548,
		"getDistPow": 0x80047548,
		"JALSystem::init": 0x8004761c,
		"JALSystem::gateCheckFunc": 0x8004765c,
		"gateCheckFunc": 0x8004765c,
		"JALSystem::processModFunc": 0x800477d0,
		"processModFunc": 0x800477d0,
		"JALSystem::processModDistVolume": 0x800479d0,
		"processModDistVolume": 0x800479d0,
		"JALSystem::append": 0x80047a7c,
		"JSUList<JALSeModDataGrpMemb>::JSUList": 0x80048048,
		"JALSystem::appendGrpMember": 0x80048078,
		"appendGrpMember": 0x80048078,
		"JALSystem::TFlagManager::TFlagManager": 0x80048348,
		"JALSystem::TFlagManager::addUseFlag": 0x80048490,
		"addUseFlag": 0x80048490,
		"JALSystem::TFlagManager::isRegistered": 0x800484ac,
		"isRegistered": 0x800484ac,
		"JALSeModDataGrp<JALSeModVolDGrp>::calcGrp": 0x800484d8,
		"JALSeModDataGrp<JALSeModEffFGrp>::calcGrp": 0x8004853c,
		"JALSeModDataGrp<JALSeModEffFGrp>::gateCheckGrp": 0x800485a0,
		"JALSeModDataGrp<JALSeModPitFGrp>::gateCheckGrp": 0x80048654,
		"JALSeModDataGrp<JALSeModVolFGrp>::calcGrp": 0x800486a4,
		"JALSeModDataGrp<JALSeModVolFGrp>::gateCheckGrp": 0x80048708,
		"JALSeModData<JALSeModEffDGrp>::calcDyna": 0x80048758,
		"JALSeModData<JALSeModEffDGrp>::gateCheckDyna": 0x80048790,
		"JALSeModData<JALSeModPitDGrp>::calcDyna": 0x80048824,
		"JALSeModData<JALSeModPitDGrp>::gateCheckDyna": 0x8004885c,
		"JALSeModData<JALSeModVolDGrp>::calcDyna": 0x800488f0,
		"JALSeModData<JALSeModVolDGrp>::gateCheckDyna": 0x80048928,
		"JALSeModData<JALSeModEffFGrp>::calcDyna": 0x800489bc,
		"JALSeModData<JALSeModEffFGrp>::gateCheckDyna": 0x800489f4,
		"JALSeModData<JALSeModPitFGrp>::gateCheckDyna": 0x80048ac0,
		"JALSeModData<JALSeModVolFGrp>::calcDyna": 0x80048b54,
		"JALSeModData<JALSeModVolFGrp>::gateCheckDyna": 0x80048b8c,
		"JALSeModData<JALSeModEffDist>::calcDyna": 0x80048c20,
		"JALSeModData<JALSeModEffDist>::gateCheckDyna": 0x80048c58,
		"JALSeModData<JALSeModPitDist>::calcDyna": 0x80048cec,
		"JALSeModData<JALSeModPitDist>::gateCheckDyna": 0x80048d24,
		"JALSeModData<JALSeModVolDist>::calc": 0x80048db8,
		"JALSeModData<JALSeModVolDist>::calcDyna": 0x80048e1c,
		"JALSeModData<JALSeModVolDist>::gateCheckDyna": 0x80048e54,
		"JALSeModData<JALSeModEffFunk>::calc": 0x80048ee8,
		"JALSeModData<JALSeModEffFunk>::calcDyna": 0x80048f4c,
		"JALSeModData<JALSeModEffFunk>::gateCheck": 0x80048f84,
		"JALSeModData<JALSeModEffFunk>::gateCheckDyna": 0x80048fd4,
		"JALSeModData<JALSeModPitFunk>::calc": 0x80049068,
		"JALSeModData<JALSeModPitFunk>::calcDyna": 0x800490cc,
		"JALSeModData<JALSeModPitFunk>::gateCheck": 0x80049104,
		"JALSeModData<JALSeModPitFunk>::gateCheckDyna": 0x80049154,
		"JALSeModData<JALSeModVolFunk>::gateCheck": 0x80049284,
		"JALSeModData<JALSeModVolFunk>::gateCheckDyna": 0x800492d4,
		"JALListS<JALSeModPitFunk,unsigned_long><JALSeModPitFunk,unsigned_long>::search": 0x800493a4,
		"JALListS<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::search": 0x800493d8,
		"JALListS<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::search": 0x8004940c,
		"JALListS<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::search": 0x80049440,
		"JALListS<JALSeModPitFGrp,unsigned_long><JALSeModPitFGrp,unsigned_long>::search": 0x80049474,
		"JALListS<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::search": 0x800494a8,
		"JALListS<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::search": 0x800494dc,
		"JALListS<JALSeModPitDGrp,unsigned_long><JALSeModPitDGrp,unsigned_long>::search": 0x80049510,
		"JALListS<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::search": 0x80049544,
		"JALLinkD<JALSeModDataGrpMemb,unsigned_long><JALSeModDataGrpMemb,unsigned_long>::JALLinkD": 0x80049578,
		"JALLinkD": 0x80049578,
		"JALSeModData<JALSeModVolFunk>::JALSeModData": 0x800495e8,
		"JALSeModData<JALSeModPitFunk>::JALSeModData": 0x80049674,
		"JALSeModData<JALSeModEffFunk>::JALSeModData": 0x80049700,
		"JALSeModData<JALSeModVolDist>::JALSeModData": 0x8004978c,
		"JALSeModData<JALSeModPitDist>::JALSeModData": 0x80049818,
		"JALSeModData<JALSeModEffDist>::JALSeModData": 0x800498a4,
		"JALSeModData<JALSeModVolFGrp>::JALSeModData": 0x80049930,
		"JALSeModData<JALSeModPitFGrp>::JALSeModData": 0x800499bc,
		"JALSeModData<JALSeModEffFGrp>::JALSeModData": 0x80049a48,
		"JALSeModData<JALSeModVolDGrp>::JALSeModData": 0x80049ad4,
		"JALSeModData<JALSeModPitDGrp>::JALSeModData": 0x80049b60,
		"JALSeModData<JALSeModEffDGrp>::JALSeModData": 0x80049bec,
		"JALListGrp<JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x80049c78,
		"JALListGrp<JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x80049d30,
		"JALListGrp<JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x80049d8c,
		"JALListHioNode<JALSeModVolFunk,unsigned_long><JALSeModVolFunk,unsigned_long>::JALListHioNode": 0x80049de8,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x80049e3c,
		"__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x80049e3c,
		"JALListHioNode<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::JALListHioNode": 0x80049e90,
		"JALListHioNode<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::JALListHioNode": 0x80049ee4,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x80049f38,
		"__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x80049f38,
		"JALListHioNode<JALSeModEffDist,unsigned_long><JALSeModEffDist,unsigned_long>::JALListHioNode": 0x80049f8c,
		"JALListHioNode<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::JALListHioNode": 0x80049fe0,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x8004a034,
		"__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x8004a034,
		"JALListHioNode<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::JALListHioNode": 0x8004a088,
		"JALListHioNode<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::JALListHioNode": 0x8004a0dc,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x8004a130,
		"__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x8004a130,
		"JALListHioNode<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::JALListHioNode": 0x8004a184,
		"JSystem::__sinit_JALModSe_cpp": 0x8004a1d8,
		"__sinit_JALModSe_cpp": 0x8004a1d8,
		"JAIAnimeSound::JAIAnimeSound": 0x8004a864,
		"JAIAnimeSound::initActorAnimSound": 0x8004a8d8,
		"initActorAnimSound": 0x8004a8d8,
		"JAIAnimeSound::setAnimSoundVec": 0x8004aa2c,
		"setAnimSoundVec": 0x8004aa2c,
		"JAIAnimeSound::setAnimSoundActor": 0x8004aa64,
		"setAnimSoundActor": 0x8004aa64,
		"JAIAnimeSound::playActorAnimSound": 0x8004aeb8,
		"playActorAnimSound": 0x8004aeb8,
		"JAIAnimeSound::startAnimSound": 0x8004b0cc,
		"JAIAnimeSound::setSpeedModifySound": 0x8004b100,
		"JAIAnimeSound::stop": 0x8004b240,
		"JAIBasic::JAIBasic": 0x8004b2a8,
		"JAIBasic::initInterfaceMain": 0x8004b380,
		"initInterfaceMain": 0x8004b380,
		"JAIBasic::setCameraInfo": 0x8004b5ac,
		"JAIBasic::initStream": 0x8004b5e0,
		"initStream": 0x8004b5e0,
		"JAIBasic::setRegisterTrackCallback": 0x8004b618,
		"JAIBasic::initReadFile": 0x8004b640,
		"initReadFile": 0x8004b640,
		"JAIBasic::checkInitListFile": 0x8004b70c,
		"checkInitListFile": 0x8004b70c,
		"JAIBasic::checkInitDataFile": 0x8004b7f8,
		"checkInitDataFile": 0x8004b7f8,
		"JAIBasic::checkInitDataOnMemory": 0x8004b868,
		"checkInitDataOnMemory": 0x8004b868,
		"JAIBasic::transInitDataFile": 0x8004bc9c,
		"transInitDataFile": 0x8004bc9c,
		"JAIBasic::initBankWave": 0x8004bd88,
		"initBankWave": 0x8004bd88,
		"JAIBasic::setWaveScene": 0x8004bf5c,
		"setWaveScene": 0x8004bf5c,
		"JAIBasic::setSceneSetFinishCallback": 0x8004c00c,
		"setSceneSetFinishCallback": 0x8004c00c,
		"JAIBasic::finishSceneSet": 0x8004c058,
		"finishSceneSet": 0x8004c058,
		"JAIBasic::loadSceneWave": 0x8004c078,
		"loadSceneWave": 0x8004c078,
		"JAIBasic::checkSceneWaveOnMemory": 0x8004c118,
		"checkSceneWaveOnMemory": 0x8004c118,
		"JAIBasic::loadGroupWave": 0x8004c14c,
		"JAIBasic::initNullData": 0x8004c1d0,
		"initNullData": 0x8004c1d0,
		"JAIBasic::initDriver": 0x8004c2f0,
		"initDriver": 0x8004c2f0,
		"JAIBasic::initInterface": 0x8004c368,
		"initInterface": 0x8004c368,
		"JAIBasic::initAllocParameter": 0x8004c38c,
		"initAllocParameter": 0x8004c38c,
		"JAIBasic::initSeqsLoadArea": 0x8004c450,
		"initSeqsLoadArea": 0x8004c450,
		"JAIBasic::setInitFileLoadSwitch": 0x8004c4dc,
		"setInitFileLoadSwitch": 0x8004c4dc,
		"JAIBasic::startFrameInterfaceWork": 0x8004c4e4,
		"startFrameInterfaceWork": 0x8004c4e4,
		"JAIBasic::processFrameWork": 0x8004c504,
		"processFrameWork": 0x8004c504,
		"JAIBasic::checkStream": 0x8004c66c,
		"checkStream": 0x8004c66c,
		"JAIBasic::checkDummyPositionBuffer": 0x8004c6b0,
		"checkDummyPositionBuffer": 0x8004c6b0,
		"JAIBasic::startSoundActor": 0x8004c748,
		"JAIBasic::startSoundActorReturnHandle": 0x8004c7dc,
		"startSoundActorReturnHandle": 0x8004c7dc,
		"JAIBasic::startSoundDirectID": 0x8004c88c,
		"startSoundDirectID": 0x8004c88c,
		"JAIBasic::startSoundIndirectID": 0x8004c8fc,
		"startSoundIndirectID": 0x8004c8fc,
		"JAIBasic::startSoundBasic": 0x8004c974,
		"startSoundBasic": 0x8004c974,
		"JAIBasic::stopSoundHandle": 0x8004caec,
		"stopSoundHandle": 0x8004caec,
		"JAIBasic::changeIDToCategory": 0x8004ccdc,
		"changeIDToCategory": 0x8004ccdc,
		"JAIBasic::stopAllSe": 0x8004cce4,
		"stopAllSe": 0x8004cce4,
		"JAIBasic::getControllerHandle": 0x8004cd4c,
		"getControllerHandle": 0x8004cd4c,
		"JAIBasic::releaseControllerHandle": 0x8004cda4,
		"releaseControllerHandle": 0x8004cda4,
		"JAIBasic::getStreamParameter": 0x8004ce1c,
		"JAIBasic::releaseStreamParameterPointer": 0x8004ce7c,
		"releaseStreamParameterPointer": 0x8004ce7c,
		"JAIBasic::getSeqParametermeterPointer": 0x8004cef4,
		"getSeqParametermeterPointer": 0x8004cef4,
		"JAIBasic::releaseSeqParameterPointer": 0x8004cf54,
		"releaseSeqParameterPointer": 0x8004cf54,
		"JAIBasic::getSeParametermeterPointer": 0x8004cfcc,
		"getSeParametermeterPointer": 0x8004cfcc,
		"JAIBasic::releaseSeParameterPointer": 0x8004d05c,
		"releaseSeParameterPointer": 0x8004d05c,
		"JAIBasic::releaseDummyVecPointer": 0x8004d0dc,
		"releaseDummyVecPointer": 0x8004d0dc,
		"JAIBasic::getMapInfoFxline": 0x8004d154,
		"getMapInfoFxline": 0x8004d154,
		"JAIBasic::getMapInfoGround": 0x8004d16c,
		"JAIBasic::getMapInfoFxParameter": 0x8004d184,
		"getMapInfoFxParameter": 0x8004d184,
		"JAIBasic::getInfoPointerFromID": 0x8004d19c,
		"getInfoPointerFromID": 0x8004d19c,
		"JAIBasic::getInfoFormat": 0x8004d214,
		"getInfoFormat": 0x8004d214,
		"JAIBasic::setSeCategoryVolume": 0x8004d26c,
		"setSeCategoryVolume": 0x8004d26c,
		"JAIBasic::setParameterSeqSync": 0x8004d2a8,
		"JAIBasic::getSoundInfoFromID": 0x8004d478,
		"getSoundInfoFromID": 0x8004d478,
		"JAIBasic::getSeqTrackNumber": 0x8004d4a4,
		"getSeqTrackNumber": 0x8004d4a4,
		"JAIBasic::getSoundPrioity": 0x8004d4ac,
		"getSoundPrioity": 0x8004d4ac,
		"JAIBasic::getSoundSwBit": 0x8004d4b4,
		"getSoundSwBit": 0x8004d4b4,
		"JAIBasic::setSeExtParameter": 0x8004d4bc,
		"JAIBasic::routeToTrack": 0x8004d668,
		"routeToTrack": 0x8004d668,
		"JAIBasic::initHeap": 0x8004d6a8,
		"initHeap": 0x8004d6a8,
		"JAIBasic::allocHeap": 0x8004d6f0,
		"allocHeap": 0x8004d6f0,
		"JAIBasic::makeSound": 0x8004d738,
		"JAIBasic::loadDVDFile": 0x8004d7cc,
		"loadDVDFile": 0x8004d7cc,
		"JAIBasic::loadTmpDVDFile": 0x8004d850,
		"loadTmpDVDFile": 0x8004d850,
		"JAIBasic::deleteTmpDVDFile": 0x8004d8c8,
		"deleteTmpDVDFile": 0x8004d8c8,
		"JAIBasic::loadArcSeqData": 0x8004d904,
		"loadArcSeqData": 0x8004d904,
		"JSystem::__sinit_JAIBasic_cpp": 0x8004da74,
		"__sinit_JAIBasic_cpp": 0x8004da74,
		"JSystem::__sinit_JAIConst_cpp": 0x8004daa4,
		"__sinit_JAIConst_cpp": 0x8004daa4,
		"JAIData::init": 0x8004dae8,
		"JAIData::initLinkBuffer": 0x8004db0c,
		"initLinkBuffer": 0x8004db0c,
		"JAIData::initSeqParaLinkBuffer": 0x8004dc64,
		"initSeqParaLinkBuffer": 0x8004dc64,
		"JAIData::initSeqParameter": 0x8004dd70,
		"initSeqParameter": 0x8004dd70,
		"JAIData::initSePara": 0x8004dfc0,
		"initSePara": 0x8004dfc0,
		"JAIData::initStreamParaLinkBuffer": 0x8004e120,
		"initStreamParaLinkBuffer": 0x8004e120,
		"JAIData::initStreamParameter": 0x8004e22c,
		"initStreamParameter": 0x8004e22c,
		"JAIData::initSeqTrackInfoParameter": 0x8004e288,
		"initSeqTrackInfoParameter": 0x8004e288,
		"JAIData::initStreamUpdateParameter": 0x8004e36c,
		"initStreamUpdateParameter": 0x8004e36c,
		"JAIData::setSeMovePara": 0x8004e3bc,
		"setSeMovePara": 0x8004e3bc,
		"JAIData::moveParameter": 0x8004e420,
		"moveParameter": 0x8004e420,
		"JAIData::checkOnMemory": 0x8004e468,
		"checkOnMemory": 0x8004e468,
		"JAIData::checkUsefulAutoHeapPosition": 0x8004e530,
		"checkUsefulAutoHeapPosition": 0x8004e530,
		"JAIData::getFreeAutoHeapPointer": 0x8004e5e0,
		"getFreeAutoHeapPointer": 0x8004e5e0,
		"JAIData::releaseAutoHeapPointer": 0x8004e62c,
		"releaseAutoHeapPointer": 0x8004e62c,
		"JAIData::getFreeStayHeapPointer": 0x8004e650,
		"getFreeStayHeapPointer": 0x8004e650,
		"JAIData::setAutoHeapLoadedFlag": 0x8004e708,
		"setAutoHeapLoadedFlag": 0x8004e708,
		"JAIData::getInfoPointer": 0x8004e71c,
		"getInfoPointer": 0x8004e71c,
		"JAIData::initData": 0x8004e874,
		"JAIData::initInfoDataWork": 0x8004f0e4,
		"initInfoDataWork": 0x8004f0e4,
		"JAIEntry::checkSoundHandle": 0x8004f204,
		"checkSoundHandle": 0x8004f204,
		"JAIEntry::initSoundParameter": 0x8004f2c0,
		"initSoundParameter": 0x8004f2c0,
		"JAISeEntry::storeBuffer": 0x8004f364,
		"JAISeqEntry::storeBuffer": 0x8004f6e0,
		"JAIStreamEntry::storeBuffer": 0x8004f9cc,
		"JAIBasic::checkNextFrameSe": 0x8004facc,
		"checkNextFrameSe": 0x8004facc,
		"JAIBasic::sendPlayingSeCommand": 0x80050220,
		"sendPlayingSeCommand": 0x80050220,
		"JAIBasic::setSeqMuteFromSeStart": 0x800507a4,
		"setSeqMuteFromSeStart": 0x800507a4,
		"JAIBasic::checkSeMovePara": 0x80050884,
		"checkSeMovePara": 0x80050884,
		"JAIBasic::sendSeAllParameter": 0x800509b0,
		"sendSeAllParameter": 0x800509b0,
		"JAIBasic::releaseSeRegist": 0x80050fbc,
		"releaseSeRegist": 0x80050fbc,
		"JAIBasic::stopSeq": 0x800511a0,
		"JAIBasic::checkEntriedSeq": 0x800512e4,
		"checkEntriedSeq": 0x800512e4,
		"JAIBasic::checkPlayingSeqTrack": 0x80051670,
		"checkPlayingSeqTrack": 0x80051670,
		"JAIBasic::checkPlayingSeq": 0x8005250c,
		"checkPlayingSeq": 0x8005250c,
		"JAIBasic::checkStoppedSeq": 0x80052614,
		"checkStoppedSeq": 0x80052614,
		"JAIBasic::checkStartedSeq": 0x800526e0,
		"checkStartedSeq": 0x800526e0,
		"JAIBasic::checkFadeoutSeq": 0x80052798,
		"checkFadeoutSeq": 0x80052798,
		"JAIBasic::checkReadSeq": 0x80052874,
		"checkReadSeq": 0x80052874,
		"JAIBasic::checkSeqWave": 0x80052a40,
		"checkSeqWave": 0x80052a40,
		"JAIBasic::checkDvdLoadArc": 0x80052b58,
		"checkDvdLoadArc": 0x80052b58,
		"JAIBasic::checkEntriedStream": 0x80052c34,
		"checkEntriedStream": 0x80052c34,
		"JAIBasic::checkWaitStream": 0x80052d00,
		"checkWaitStream": 0x80052d00,
		"JAIBasic::checkRequestStream": 0x80052de8,
		"checkRequestStream": 0x80052de8,
		"JAIBasic::checkPlayingStream": 0x80052e80,
		"checkPlayingStream": 0x80052e80,
		"JAInter::StreamLib::Play_DirectPCM": 0x800532b0,
		"Play_DirectPCM": 0x800532b0,
		"JAInter::StreamLib::init": 0x800533cc,
		"JAInter::StreamLib::allocBuffer": 0x8005342c,
		"allocBuffer": 0x8005342c,
		"JAInter::StreamLib::getNeedBufferSize": 0x80053554,
		"getNeedBufferSize": 0x80053554,
		"JAInter::StreamLib::__DecodePCM": 0x800535e0,
		"__DecodePCM": 0x800535e0,
		"JAInter::StreamLib::__DecodeADPCM": 0x80053740,
		"__DecodeADPCM": 0x80053740,
		"JAInter::StreamLib::__LoadFin": 0x80053c14,
		"__LoadFin": 0x80053c14,
		"JAInter::StreamLib::LoadADPCM": 0x80053c34,
		"LoadADPCM": 0x80053c34,
		"JAInter::StreamLib::setVolume": 0x80053d48,
		"JAInter::StreamLib::setPitch": 0x80053d58,
		"JAInter::StreamLib::setPan": 0x80053d68,
		"JAInter::StreamLib::stop": 0x80053d78,
		"JAInter::StreamLib::setPauseFlag": 0x80053d88,
		"JAInter::StreamLib::clearPauseFlag": 0x80053d9c,
		"clearPauseFlag": 0x80053d9c,
		"JAInter::StreamLib::setPrepareFlag": 0x80053db4,
		"setPrepareFlag": 0x80053db4,
		"JAInter::StreamLib::setOutputMode": 0x80053dbc,
		"JAInter::StreamLib::getPlayingFlag": 0x80053dc4,
		"getPlayingFlag": 0x80053dc4,
		"JAInter::StreamLib::start": 0x80053dcc,
		"JAInter::StreamLib::__start": 0x80053e44,
		"JAInter::StreamLib::callBack": 0x80054190,
		"callBack": 0x80054190,
		"JSystem::__sinit_JAIGFrameStream_cpp": 0x80054a64,
		"__sinit_JAIGFrameStream_cpp": 0x80054a64,
		"JASystem::Kernel::TSolidHeap::~TSolidHeap": 0x80054aa0,
		"JAIGlobalParameter::setParamInitDataPointer": 0x80054ae0,
		"setParamInitDataPointer": 0x80054ae0,
		"JAIGlobalParameter::setParamSeqPlayTrackMax": 0x80054af8,
		"setParamSeqPlayTrackMax": 0x80054af8,
		"JAIGlobalParameter::setParamSeqControlBufferMax": 0x80054b08,
		"setParamSeqControlBufferMax": 0x80054b08,
		"JAIGlobalParameter::setParamAutoHeapMax": 0x80054b10,
		"setParamAutoHeapMax": 0x80054b10,
		"JAIGlobalParameter::setParamStayHeapMax": 0x80054b18,
		"setParamStayHeapMax": 0x80054b18,
		"JAIGlobalParameter::setParamInputGainDown": 0x80054b20,
		"setParamInputGainDown": 0x80054b20,
		"JAIGlobalParameter::setParamOutputGainUp": 0x80054b28,
		"setParamOutputGainUp": 0x80054b28,
		"JAIGlobalParameter::setParamDistanceMax": 0x80054b30,
		"setParamDistanceMax": 0x80054b30,
		"JAIGlobalParameter::setParamMaxVolumeDistance": 0x80054b38,
		"setParamMaxVolumeDistance": 0x80054b38,
		"JAIGlobalParameter::setParamMinDistanceVolume": 0x80054b40,
		"setParamMinDistanceVolume": 0x80054b40,
		"JAIGlobalParameter::setParamStreamInsideBufferCut": 0x80054b48,
		"setParamStreamInsideBufferCut": 0x80054b48,
		"JAIGlobalParameter::setParamAutoHeapRoomSize": 0x80054b5c,
		"setParamAutoHeapRoomSize": 0x80054b5c,
		"JAIGlobalParameter::setParamStayHeapSize": 0x80054b64,
		"setParamStayHeapSize": 0x80054b64,
		"JAIGlobalParameter::setParamInitDataFileName": 0x80054b6c,
		"setParamInitDataFileName": 0x80054b6c,
		"JAIGlobalParameter::setParamWavePath": 0x80054b74,
		"setParamWavePath": 0x80054b74,
		"JAIGlobalParameter::setParamSequenceArchivesPath": 0x80054b7c,
		"setParamSequenceArchivesPath": 0x80054b7c,
		"JAIGlobalParameter::setParamStreamPath": 0x80054b84,
		"setParamStreamPath": 0x80054b84,
		"JAIGlobalParameter::setParamSystemTrackMax": 0x80054b8c,
		"setParamSystemTrackMax": 0x80054b8c,
		"JAIGlobalParameter::setParamSystemRootTrackMax": 0x80054b94,
		"setParamSystemRootTrackMax": 0x80054b94,
		"JAIGlobalParameter::setParamSoundOutputMode": 0x80054b9c,
		"setParamSoundOutputMode": 0x80054b9c,
		"JAIGlobalParameter::getParamSeCategoryMax": 0x80054c28,
		"getParamSeCategoryMax": 0x80054c28,
		"JAIGlobalParameter::getParamSeqTrackMax": 0x80054c38,
		"getParamSeqTrackMax": 0x80054c38,
		"JAIGlobalParameter::getParamOutputGainUp": 0x80054c40,
		"getParamOutputGainUp": 0x80054c40,
		"JAIGlobalParameter::getParamMaxVolumeDistance": 0x80054c48,
		"getParamMaxVolumeDistance": 0x80054c48,
		"JAISound::JAISound": 0x80054c50,
		"JAISound::initMoveParameter": 0x80054c78,
		"initMoveParameter": 0x80054c78,
		"JAISound::getSeCategoryNumber": 0x80054d28,
		"getSeCategoryNumber": 0x80054d28,
		"JAISound::getSwBit": 0x80054d54,
		"getSwBit": 0x80054d54,
		"JAISound::checkSwBit": 0x80054d80,
		"checkSwBit": 0x80054d80,
		"JAISound::getInfoPriority": 0x80054dbc,
		"getInfoPriority": 0x80054dbc,
		"JAISound::clearMainSoundPPointer": 0x80054de8,
		"clearMainSoundPPointer": 0x80054de8,
		"JAISound::release": 0x80054e00,
		"JAISound::stop": 0x80054e14,
		"JAISound::setVolume": 0x80054e44,
		"JAISound::setPan": 0x80054ecc,
		"JAISound::setPitch": 0x80054f54,
		"JAISound::setFxmix": 0x80054fdc,
		"setFxmix": 0x80054fdc,
		"JAISound::setDolby": 0x80055054,
		"JAISound::setTempoProportion": 0x800550cc,
		"setTempoProportion": 0x800550cc,
		"JAISound::setPortData": 0x80055124,
		"setPortData": 0x80055124,
		"JAISound::setDistanceVolumeCommon": 0x80055188,
		"JAISound::setDistancePanCommon": 0x800552dc,
		"setDistancePanCommon": 0x800552dc,
		"JAISound::setPositionDopplarCommon": 0x80055430,
		"setPositionDopplarCommon": 0x80055430,
		"JAISound::setSeqInterVolume": 0x8005560c,
		"setSeqInterVolume": 0x8005560c,
		"JAISound::setSeqInterPan": 0x8005570c,
		"setSeqInterPan": 0x8005570c,
		"JAISound::setSeqInterPitch": 0x8005580c,
		"setSeqInterPitch": 0x8005580c,
		"JAISound::setSeqInterFxmix": 0x8005590c,
		"setSeqInterFxmix": 0x8005590c,
		"JAISound::setSeqInterDolby": 0x80055a0c,
		"setSeqInterDolby": 0x80055a0c,
		"JAISound::setSeqTempoProportion": 0x80055b48,
		"setSeqTempoProportion": 0x80055b48,
		"JAISound::setSeqPortData": 0x80055bf8,
		"setSeqPortData": 0x80055bf8,
		"JAISound::setWaveReadMode": 0x80055d64,
		"setWaveReadMode": 0x80055d64,
		"JAISound::setTrackInterruptSwitch": 0x80055e04,
		"setTrackInterruptSwitch": 0x80055e04,
		"JAISound::setTrackPortData": 0x80055ea8,
		"setTrackPortData": 0x80055ea8,
		"JAISound::setSeInterVolume": 0x80055fc8,
		"setSeInterVolume": 0x80055fc8,
		"JAISound::setSeInterPan": 0x80056190,
		"setSeInterPan": 0x80056190,
		"JAISound::setSeInterFxmix": 0x80056358,
		"setSeInterFxmix": 0x80056358,
		"JAISound::setSeInterDolby": 0x80056520,
		"setSeInterDolby": 0x80056520,
		"JAISound::setSeInterPitch": 0x800566e8,
		"setSeInterPitch": 0x800566e8,
		"JAISound::setSePortData": 0x800568a4,
		"setSePortData": 0x800568a4,
		"JAISound::setSeDistanceParameters": 0x80056a24,
		"JAISound::setSeDistanceVolume": 0x80056b98,
		"JAISound::setSeDistancePan": 0x80056c98,
		"JAISound::setSeDistancePitch": 0x80056d60,
		"JAISound::setSePositionDopplar": 0x80056f58,
		"setSePositionDopplar": 0x80056f58,
		"JAISound::setSeDistanceFxmix": 0x80057054,
		"setSeDistanceFxmix": 0x80057054,
		"JAISound::setSeDistanceFir": 0x80057148,
		"setSeDistanceFir": 0x80057148,
		"JAISound::setSeDistanceDolby": 0x8005714c,
		"JAISound::setStreamInterVolume": 0x80057218,
		"setStreamInterVolume": 0x80057218,
		"JAISound::setStreamInterPitch": 0x80057318,
		"setStreamInterPitch": 0x80057318,
		"JAISound::setStreamInterPan": 0x80057418,
		"setStreamInterPan": 0x80057418,
		"JAISound::setPauseMode": 0x80057518,
		"setPauseMode": 0x80057518,
		"JAISound::getSeqInterVolume": 0x800578c8,
		"getSeqInterVolume": 0x800578c8,
		"JAISound::getStreamInterVolume": 0x8005791c,
		"getStreamInterVolume": 0x8005791c,
		"JAISound::getSeqParameter": 0x800579ac,
		"getSeqParameter": 0x800579ac,
		"JAISound::getSeParameter": 0x800579b4,
		"getSeParameter": 0x800579b4,
		"JAISound::getStreamParameter": 0x800579bc,
		"JAISound::getTrackPortRoute": 0x800579c4,
		"getTrackPortRoute": 0x800579c4,
		"JAISystemInterface::checkFileExsistence": 0x80057a00,
		"checkFileExsistence": 0x80057a00,
		"JAISystemInterface::checkSeqActiveFlag": 0x80057a44,
		"checkSeqActiveFlag": 0x80057a44,
		"JAISystemInterface::trackToSeqp": 0x80057b4c,
		"trackToSeqp": 0x80057b4c,
		"JAISystemInterface::setSeqPortargsF32": 0x80057bdc,
		"setSeqPortargsF32": 0x80057bdc,
		"JAISystemInterface::setSeqPortargsU32": 0x80057bf8,
		"setSeqPortargsU32": 0x80057bf8,
		"JAISystemInterface::rootInit": 0x80057c14,
		"rootInit": 0x80057c14,
		"JAISystemInterface::trackInit": 0x80057c8c,
		"trackInit": 0x80057c8c,
		"JAISystemInterface::outerInit": 0x80057d7c,
		"outerInit": 0x80057d7c,
		"JAISystemInterface::setSePortParameter": 0x80057f6c,
		"setSePortParameter": 0x80057f6c,
		"JAISystemInterface::setSeqData": 0x800580c0,
		"JAISystemInterface::startSeq": 0x80058140,
		"JAISystemInterface::stopSeq": 0x80058198,
		"JAISystemInterface::writePortApp": 0x800581e0,
		"JAISystemInterface::readPortApp": 0x80058238,
		"JSystem::__sinit_JAISystemInterface_cpp": 0x80058290,
		"__sinit_JAISystemInterface_cpp": 0x80058290,
		"JASystem::Kernel::TPortCmd::~TPortCmd": 0x800582cc,
		"JASystem::TBank::getCurrentHeap": 0x8005830c,
		"JASystem::BankMgr::init": 0x80058320,
		"JASystem::BankMgr::registBankBNK": 0x8005843c,
		"registBankBNK": 0x8005843c,
		"JASystem::BankMgr::getPhysicalNumber": 0x800584a4,
		"getPhysicalNumber": 0x800584a4,
		"JASystem::BankMgr::setVir2PhyTable": 0x800584b4,
		"setVir2PhyTable": 0x800584b4,
		"JASystem::BankMgr::assignWaveBank": 0x800584d0,
		"assignWaveBank": 0x800584d0,
		"JASystem::BankMgr::noteOn": 0x80058544,
		"JASystem::BankMgr::noteOnOsc": 0x80058954,
		"noteOnOsc": 0x80058954,
		"JASystem::BankMgr::gateOn": 0x80058aac,
		"JASystem::TBasicBank::TBasicBank": 0x80058b74,
		"JASystem::TBank::~TBank": 0x80058ba0,
		"JASystem::TBasicBank::~TBasicBank": 0x80058bec,
		"JASystem::TBasicBank::setInstCount": 0x80058c60,
		"setInstCount": 0x80058c60,
		"JASystem::TBasicBank::setInst": 0x80058cc4,
		"setInst": 0x80058cc4,
		"JASystem::TBasicBank::getInst": 0x80058cd4,
		"getInst": 0x80058cd4,
		"JASystem::TBasicBank::getType": 0x80058cf8,
		"JASystem::TBasicInst::TBasicInst": 0x80058d04,
		"JASystem::TInst::~TInst": 0x80058d48,
		"JASystem::TBasicInst::~TBasicInst": 0x80058d94,
		"JASystem::TBasicInst::getParam": 0x80058e20,
		"JASystem::TBasicInst::getKeymapIndex": 0x80058ffc,
		"getKeymapIndex": 0x80058ffc,
		"JASystem::TBasicInst::setKeyRegionCount": 0x80059004,
		"setKeyRegionCount": 0x80059004,
		"JASystem::TBasicInst::TKeymap::TKeymap": 0x8005908c,
		"JASystem::TBasicInst::setEffectCount": 0x800590a4,
		"JASystem::TBasicInst::setEffect": 0x8005911c,
		"JASystem::TBasicInst::setOscCount": 0x8005912c,
		"setOscCount": 0x8005912c,
		"JASystem::TBasicInst::setOsc": 0x800591a4,
		"setOsc": 0x800591a4,
		"JASystem::TBasicInst::getKeyRegion": 0x800591b4,
		"getKeyRegion": 0x800591b4,
		"JASystem::TBasicInst::TKeymap::~TKeymap": 0x800591d8,
		"JASystem::TBasicInst::TKeymap::setVeloRegionCount": 0x8005922c,
		"JASystem::TBasicInst::getType": 0x800592cc,
		"JASystem::TBasicWaveBank::TBasicWaveBank": 0x800592d8,
		"JASystem::TWaveBank::~TWaveBank": 0x80059308,
		"JASystem::TBasicWaveBank::~TBasicWaveBank": 0x80059354,
		"JASystem::TBasicWaveBank::getWaveGroup": 0x800593d8,
		"getWaveGroup": 0x800593d8,
		"JASystem::TBasicWaveBank::setGroupCount": 0x800593fc,
		"setGroupCount": 0x800593fc,
		"JASystem::TBasicWaveBank::setWaveTableSize": 0x80059484,
		"JASystem::TBasicWaveBank::incWaveTable": 0x800594e8,
		"incWaveTable": 0x800594e8,
		"JASystem::TBasicWaveBank::decWaveTable": 0x80059548,
		"decWaveTable": 0x80059548,
		"JASystem::TBasicWaveBank::getWaveHandle": 0x800595d8,
		"JASystem::TBasicWaveBank::TWaveGroup::TWaveGroup": 0x8005960c,
		"JASystem::Kernel::THeap::~THeap": 0x8005966c,
		"JASystem::TBasicWaveBank::TWaveGroup::~TWaveGroup": 0x800596ac,
		"JASystem::TBasicWaveBank::TWaveInfo::~TWaveInfo": 0x8005971c,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveArcFileName": 0x8005977c,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveCount": 0x800597f0,
		"setWaveCount": 0x800597f0,
		"JASystem::TBasicWaveBank::TWaveInfo::TWaveInfo": 0x80059990,
		"JASystem::TBasicWaveBank::TWaveHandle::~TWaveHandle": 0x800599c0,
		"JASystem::TWaveHandle::~TWaveHandle": 0x80059a1c,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveInfo": 0x80059a68,
		"JASystem::TBasicWaveBank::TWaveHandle::getWaveInfo": 0x80059aec,
		"JASystem::TBasicWaveBank::TWaveHandle::getWavePtr": 0x80059af4,
		"JASystem::TBasicWaveBank::TWaveGroup::getWaveArcFileName": 0x80059b20,
		"JASystem::TBasicWaveBank::TWaveGroup::getHeap": 0x80059b28,
		"JASystem::TBasicWaveBank::getType": 0x80059b30,
		"JASystem::BNKParser::createBasicBank": 0x80059b3c,
		"createBasicBank": 0x80059b3c,
		"JASystem::TDrumSet::TDrumSet": 0x8005a26c,
		"JASystem::BNKParser::findOscPtr": 0x8005a2d4,
		"findOscPtr": 0x8005a2d4,
		"JASystem::BNKParser::getOscTableEndPtr": 0x8005a430,
		"getOscTableEndPtr": 0x8005a430,
		"JASystem::TDrumSet::getParam": 0x8005a51c,
		"JASystem::TDrumSet::getPerc": 0x8005a70c,
		"getPerc": 0x8005a70c,
		"JASystem::TDrumSet::TPerc::TPerc": 0x8005a720,
		"JASystem::TDrumSet::TPerc::~TPerc": 0x8005a754,
		"JASystem::TDrumSet::TPerc::setEffectCount": 0x8005a7b0,
		"JASystem::TDrumSet::TPerc::setVeloRegionCount": 0x8005a828,
		"JASystem::TDrumSet::TPerc::getVeloRegion": 0x8005a880,
		"JASystem::TDrumSet::TPerc::setEffect": 0x8005a890,
		"JASystem::TDrumSet::TPerc::setRelease": 0x8005a8a0,
		"setRelease": 0x8005a8a0,
		"JASystem::TDrumSet::~TDrumSet": 0x8005a8a8,
		"JASystem::TDrumSet::getType": 0x8005a92c,
		"JASystem::TInstEffect::setTarget": 0x8005a938,
		"setTarget": 0x8005a938,
		"JASystem::TInstRand::getY": 0x8005a940,
		"JASystem::TInstSense::getY": 0x8005a9e0,
		"JASystem::TInstSense::setParams": 0x8005ab04,
		"setParams": 0x8005ab04,
		"JASystem::TSimpleWaveBank::TSimpleWaveBank": 0x8005ab18,
		"JASystem::TSimpleWaveBank::~TSimpleWaveBank": 0x8005ab98,
		"JASystem::TSimpleWaveBank::TWaveHandle::~TWaveHandle": 0x8005ac24,
		"JASystem::TSimpleWaveBank::setWaveTableSize": 0x8005ac80,
		"JASystem::TSimpleWaveBank::TWaveHandle::TWaveHandle": 0x8005ad08,
		"JASystem::TSimpleWaveBank::getWaveHandle": 0x8005ad2c,
		"JASystem::TSimpleWaveBank::setWaveInfo": 0x8005ad50,
		"JASystem::TSimpleWaveBank::setWaveArcFileName": 0x8005add8,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWaveInfo": 0x8005ae4c,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWavePtr": 0x8005ae54,
		"JASystem::TSimpleWaveBank::getType": 0x8005ae78,
		"JASystem::WaveArcLoader::init": 0x8005aeb4,
		"JASystem::WaveArcLoader::setCurrentDir": 0x8005af00,
		"setCurrentDir": 0x8005af00,
		"JASystem::WaveArcLoader::getCurrentDir": 0x8005af60,
		"getCurrentDir": 0x8005af60,
		"JASystem::WaveArcLoader::loadWave": 0x8005af6c,
		"JASystem::WaveArcLoader::eraseWave": 0x8005b09c,
		"JASystem::WaveArcLoader::getRootHeap": 0x8005b128,
		"getRootHeap": 0x8005b128,
		"JSystem::__sinit_JASWaveArcLoader_cpp": 0x8005b134,
		"__sinit_JASWaveArcLoader_cpp": 0x8005b134,
		"JASystem::TWaveBank::getCurrentHeap": 0x8005b170,
		"JASystem::WaveBankMgr::init": 0x8005b184,
		"JASystem::WaveBankMgr::getWaveBank": 0x8005b1dc,
		"getWaveBank": 0x8005b1dc,
		"JASystem::WaveBankMgr::registWaveBankWS": 0x8005b1ec,
		"registWaveBankWS": 0x8005b1ec,
		"JASystem::WaveBankMgr::loadWave": 0x8005b26c,
		"JASystem::WaveBankMgr::eraseWave": 0x8005b35c,
		"JASystem::WSParser::getGroupCount": 0x8005b44c,
		"getGroupCount": 0x8005b44c,
		"JASystem::WSParser::createBasicWaveBank": 0x8005b474,
		"createBasicWaveBank": 0x8005b474,
		"JASystem::WSParser::createSimpleWaveBank": 0x8005b6a0,
		"createSimpleWaveBank": 0x8005b6a0,
		"JSystem::Console_printf": 0x8005b968,
		"Console_printf": 0x8005b968,
		"JASystem::AudioThread::setDSPSyncCount": 0x8005b9b8,
		"setDSPSyncCount": 0x8005b9b8,
		"JASystem::AudioThread::getDSPSyncCount": 0x8005b9c0,
		"getDSPSyncCount": 0x8005b9c0,
		"JASystem::AudioThread::syncAudio": 0x8005b9c8,
		"syncAudio": 0x8005b9c8,
		"JASystem::AudioThread::audioproc": 0x8005ba48,
		"audioproc": 0x8005ba48,
		"JASystem::AudioThread::syncDSP": 0x8005bba8,
		"syncDSP": 0x8005bba8,
		"JASystem::AudioThread::stop": 0x8005bc30,
		"JASystem::AudioThread::setPriority": 0x8005bc80,
		"setPriority": 0x8005bc80,
		"JASystem::AudioThread::start": 0x8005bc9c,
		"JASystem::Driver::DSPQueue::init": 0x8005bdb8,
		"JASystem::Driver::DSPQueue::enQueue": 0x8005be28,
		"enQueue": 0x8005be28,
		"JASystem::Driver::DSPQueue::deQueue": 0x8005bed8,
		"deQueue": 0x8005bed8,
		"JASystem::Driver::DSPQueue::deleteQueue": 0x8005bfe0,
		"deleteQueue": 0x8005bfe0,
		"JASystem::Driver::DSPQueue::checkQueue": 0x8005c040,
		"checkQueue": 0x8005c040,
		"JASystem::Driver::calcEffect": 0x8005c11c,
		"calcEffect": 0x8005c11c,
		"JASystem::Driver::calcPan": 0x8005c1dc,
		"JASystem::Driver::__UpdateJcToDSP": 0x8005c2d8,
		"__UpdateJcToDSP": 0x8005c2d8,
		"JASystem::Driver::__UpdateJcToDSPInit": 0x8005c420,
		"__UpdateJcToDSPInit": 0x8005c420,
		"JASystem::Driver::extraUpdate": 0x8005c528,
		"extraUpdate": 0x8005c528,
		"JASystem::Driver::updatecallLogicalChannel": 0x8005c60c,
		"updatecallLogicalChannel": 0x8005c60c,
		"JASystem::Driver::killBrokenLogicalChannels": 0x8005c7a8,
		"killBrokenLogicalChannels": 0x8005c7a8,
		"JASystem::Driver::updateMixer": 0x8005c850,
		"updateMixer": 0x8005c850,
		"JASystem::Driver::updatecallDSPChannel": 0x8005ca84,
		"updatecallDSPChannel": 0x8005ca84,
		"JASystem::TChannel::init": 0x8005ce28,
		"JASystem::TChannel::setOscillator": 0x8005cfd0,
		"setOscillator": 0x8005cfd0,
		"JASystem::TChannel::setOscInit": 0x8005cfe0,
		"setOscInit": 0x8005cfe0,
		"JASystem::TChannel::forceStopOsc": 0x8005d014,
		"forceStopOsc": 0x8005d014,
		"JASystem::TChannel::releaseOsc": 0x8005d068,
		"releaseOsc": 0x8005d068,
		"JASystem::TChannel::directReleaseOsc": 0x8005d0bc,
		"directReleaseOsc": 0x8005d0bc,
		"JASystem::TChannel::bankOscToOfs": 0x8005d0d0,
		"bankOscToOfs": 0x8005d0d0,
		"JASystem::TChannel::effectOsc": 0x8005d124,
		"effectOsc": 0x8005d124,
		"JASystem::TChannel::getOscState": 0x8005d19c,
		"getOscState": 0x8005d19c,
		"JASystem::TChannel::isOsc": 0x8005d1b0,
		"isOsc": 0x8005d1b0,
		"JASystem::TChannel::copyOsc": 0x8005d1d8,
		"copyOsc": 0x8005d1d8,
		"JASystem::TChannel::overwriteOsc": 0x8005d238,
		"overwriteOsc": 0x8005d238,
		"JASystem::TChannel::setKeySweepTarget": 0x8005d31c,
		"setKeySweepTarget": 0x8005d31c,
		"JASystem::TChannel::setPauseFlag": 0x8005d3b4,
		"JASystem::TChannel::setPauseFlagReq": 0x8005d3bc,
		"setPauseFlagReq": 0x8005d3bc,
		"JASystem::TChannel::setPanPower": 0x8005d3cc,
		"setPanPower": 0x8005d3cc,
		"JASystem::TChannel::resetInitialVolume": 0x8005d400,
		"resetInitialVolume": 0x8005d400,
		"JASystem::TChannel::play": 0x8005d490,
		"JASystem::TChannel::stop": 0x8005d5b4,
		"JASystem::TChannel::updateJcToDSP": 0x8005d60c,
		"updateJcToDSP": 0x8005d60c,
		"JASystem::TChannel::forceStopLogicalChannel": 0x8005d644,
		"forceStopLogicalChannel": 0x8005d644,
		"JASystem::TChannel::stopLogicalChannel": 0x8005d67c,
		"stopLogicalChannel": 0x8005d67c,
		"JASystem::TChannel::playLogicalChannel": 0x8005d6ec,
		"playLogicalChannel": 0x8005d6ec,
		"JASystem::TChannel::updateEffectorParam": 0x8005d984,
		"updateEffectorParam": 0x8005d984,
		"JASystem::TChannelMgr::init": 0x8005dc50,
		"JASystem::TChannelMgr::stopAll": 0x8005dd44,
		"stopAll": 0x8005dd44,
		"JASystem::TChannelMgr::stopAllRelease": 0x8005dd88,
		"stopAllRelease": 0x8005dd88,
		"JASystem::TChannelMgr::addListHead": 0x8005dde4,
		"addListHead": 0x8005dde4,
		"JASystem::TChannelMgr::addListTail": 0x8005de44,
		"addListTail": 0x8005de44,
		"JASystem::TChannelMgr::getListHead": 0x8005ded8,
		"getListHead": 0x8005ded8,
		"JASystem::TChannelMgr::cutList": 0x8005df50,
		"cutList": 0x8005df50,
		"JASystem::TChannelMgr::initAllocChannel": 0x8005dfcc,
		"initAllocChannel": 0x8005dfcc,
		"JASystem::TChannelMgr::getLogicalChannel": 0x8005e040,
		"getLogicalChannel": 0x8005e040,
		"JASystem::TChannelMgr::receiveAllChannels": 0x8005e184,
		"receiveAllChannels": 0x8005e184,
		"JASystem::TChannelMgr::checkLimitStart": 0x8005e2dc,
		"checkLimitStart": 0x8005e2dc,
		"JASystem::TChannelMgr::checkLimitStop": 0x8005e460,
		"checkLimitStop": 0x8005e460,
		"JASystem::ChGlobal::getChannelHandle": 0x8005e52c,
		"getChannelHandle": 0x8005e52c,
		"JASystem::ChGlobal::init": 0x8005e54c,
		"JASystem::TOscillator::~TOscillator": 0x8005e674,
		"JASystem::TOscillator::TOscillator": 0x8005e6b4,
		"JASystem::TChannel::~TChannel": 0x8005e6e4,
		"JASystem::TChannel::TChannel": 0x8005e724,
		"JASystem::ChGlobal::alloc": 0x8005e74c,
		"JASystem::ChGlobal::release": 0x8005e7f4,
		"JASystem::ChGlobal::releaseAll": 0x8005e858,
		"releaseAll": 0x8005e858,
		"JASystem::Driver::init": 0x8005e9a4,
		"JASystem::Driver::setMixerLevel": 0x8005e9dc,
		"setMixerLevel": 0x8005e9dc,
		"JASystem::Driver::getMixerLevel": 0x8005ea18,
		"getMixerLevel": 0x8005ea18,
		"JASystem::Driver::setOutputMode": 0x8005ea20,
		"JASystem::Driver::getOutputMode": 0x8005ea28,
		"getOutputMode": 0x8005ea28,
		"JASystem::Driver::getUpdateInterval": 0x8005ea30,
		"getUpdateInterval": 0x8005ea30,
		"JASystem::DSPBuf::updateDSP": 0x8005ea38,
		"updateDSP": 0x8005ea38,
		"JASystem::DSPBuf::mixDSP": 0x8005ea8c,
		"mixDSP": 0x8005ea8c,
		"JASystem::DSPBuf::finishDSPFrame": 0x8005eab0,
		"finishDSPFrame": 0x8005eab0,
		"JASystem::DSPBuf::process": 0x8005ead4,
		"process": 0x8005ead4,
		"JASystem::TDSPChannel::forceStop": 0x8005ef38,
		"JASystem::TDSPChannel::forceDelete": 0x8005efc8,
		"forceDelete": 0x8005efc8,
		"JASystem::TDSPChannel::play": 0x8005efdc,
		"JASystem::TDSPChannel::stop": 0x8005f014,
		"JASystem::TDSPChannel::initAll": 0x8005f044,
		"initAll": 0x8005f044,
		"JASystem::TDSPChannel::~TDSPChannel": 0x8005f134,
		"JASystem::TDSPChannel::TDSPChannel": 0x8005f174,
		"JASystem::TDSPChannel::alloc": 0x8005f184,
		"JASystem::TDSPChannel::free": 0x8005f284,
		"JASystem::TDSPChannel::getLower": 0x8005f30c,
		"getLower": 0x8005f30c,
		"JASystem::TDSPChannel::getLowerActive": 0x8005f3c0,
		"getLowerActive": 0x8005f3c0,
		"JASystem::TDSPChannel::breakLower": 0x8005f44c,
		"breakLower": 0x8005f44c,
		"JASystem::TDSPChannel::updateAll": 0x8005f538,
		"updateAll": 0x8005f538,
		"JSystem::DSP_CreateMap": 0x8005f760,
		"DSP_CreateMap": 0x8005f760,
		"JASystem::DSPInterface::getDSPHandle": 0x8005f7ec,
		"getDSPHandle": 0x8005f7ec,
		"JASystem::DSPInterface::invalChannelAll": 0x8005f800,
		"invalChannelAll": 0x8005f800,
		"JASystem::DSPInterface::initBuffer": 0x8005f828,
		"initBuffer": 0x8005f828,
		"JASystem::DSPInterface::getFXHandle": 0x8005f934,
		"getFXHandle": 0x8005f934,
		"JASystem::DSPInterface::FXBuffer::setFXLine": 0x8005f944,
		"setFXLine": 0x8005f944,
		"JASystem::DSPInterface::DSPBuffer::allocInit": 0x8005fa98,
		"allocInit": 0x8005fa98,
		"JASystem::DSPInterface::DSPBuffer::playStart": 0x8005fae4,
		"playStart": 0x8005fae4,
		"JASystem::DSPInterface::DSPBuffer::setWaveInfo": 0x8005fba0,
		"JASystem::DSPInterface::DSPBuffer::setOscInfo": 0x8005fc6c,
		"setOscInfo": 0x8005fc6c,
		"JASystem::DSPInterface::DSPBuffer::initAutoMixer": 0x8005fc84,
		"initAutoMixer": 0x8005fc84,
		"JASystem::DSPInterface::DSPBuffer::setAutoMixer": 0x8005fcb0,
		"setAutoMixer": 0x8005fcb0,
		"JASystem::DSPInterface::DSPBuffer::setPitch": 0x8005fcd4,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitDelayMax": 0x8005fcec,
		"setMixerInitDelayMax": 0x8005fcec,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitVolume": 0x8005fcf8,
		"setMixerInitVolume": 0x8005fcf8,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolume": 0x8005fd1c,
		"setMixerVolume": 0x8005fd1c,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolumeOnly": 0x8005fd4c,
		"setMixerVolumeOnly": 0x8005fd4c,
		"JASystem::DSPInterface::DSPBuffer::setPauseFlag": 0x8005fd68,
		"JASystem::DSPInterface::DSPBuffer::flushChannel": 0x8005fd74,
		"flushChannel": 0x8005fd74,
		"JASystem::DSPInterface::DSPBuffer::setIIRFilterParam": 0x8005fd98,
		"setIIRFilterParam": 0x8005fd98,
		"JASystem::DSPInterface::DSPBuffer::setFIR8FilterParam": 0x8005fdbc,
		"setFIR8FilterParam": 0x8005fdbc,
		"JASystem::DSPInterface::DSPBuffer::setFilterMode": 0x8005fe00,
		"setFilterMode": 0x8005fe00,
		"JASystem::DSPInterface::DSPBuffer::initFilter": 0x8005fe40,
		"initFilter": 0x8005fe40,
		"JASystem::DSPInterface::DSPBuffer::setDistFilter": 0x8005fe88,
		"setDistFilter": 0x8005fe88,
		"JASystem::DSPInterface::DSPBuffer::setBusConnect": 0x8005fe90,
		"setBusConnect": 0x8005fe90,
		"JASystem::TOscillator::init": 0x8005feb4,
		"JASystem::TOscillator::initStart": 0x8005feec,
		"initStart": 0x8005feec,
		"JASystem::TOscillator::getOffset": 0x8005ff4c,
		"getOffset": 0x8005ff4c,
		"JASystem::TOscillator::getOffsetNoCount": 0x80060058,
		"getOffsetNoCount": 0x80060058,
		"JASystem::TOscillator::forceStop": 0x800600b4,
		"JASystem::TOscillator::release": 0x800600f0,
		"JASystem::TOscillator::calc": 0x80060278,
		"JASystem::Kernel::init": 0x80060618,
		"JASystem::Kernel::initSystem": 0x80060648,
		"initSystem": 0x80060648,
		"JASystem::Kernel::registerMixCallback": 0x800606fc,
		"registerMixCallback": 0x800606fc,
		"JASystem::Kernel::vframeWork": 0x80060708,
		"vframeWork": 0x80060708,
		"JASystem::Kernel::updateDac": 0x80060898,
		"updateDac": 0x80060898,
		"JASystem::Kernel::mixMonoTrack": 0x80060940,
		"mixMonoTrack": 0x80060940,
		"JASystem::Kernel::mixMonoTrackWide": 0x80060a3c,
		"mixMonoTrackWide": 0x80060a3c,
		"JASystem::Kernel::mixExtraTrack": 0x80060b38,
		"mixExtraTrack": 0x80060b38,
		"JASystem::Kernel::mixInterleaveTrack": 0x80060c50,
		"mixInterleaveTrack": 0x80060c50,
		"JASystem::Calc::initSinfT": 0x80060cec,
		"initSinfT": 0x80060cec,
		"JASystem::Calc::sinfT": 0x80060e14,
		"sinfT": 0x80060e14,
		"JASystem::Calc::sinfDolby2": 0x80060e40,
		"sinfDolby2": 0x80060e40,
		"JASystem::Calc::imixcopy": 0x80060e6c,
		"imixcopy": 0x80060e6c,
		"JASystem::Calc::bcopy": 0x80060f40,
		"bcopy": 0x80060f40,
		"JASystem::Calc::bzero": 0x80061220,
		"bzero": 0x80061220,
		"JASystem::Kernel::resetCallback": 0x80061484,
		"resetCallback": 0x80061484,
		"JASystem::Kernel::registerSubframeCallback": 0x800614f8,
		"registerSubframeCallback": 0x800614f8,
		"JASystem::Kernel::registerAiCallback": 0x80061550,
		"registerAiCallback": 0x80061550,
		"JASystem::Kernel::aiCallback": 0x80061638,
		"aiCallback": 0x80061638,
		"JASystem::Kernel::subframeCallback": 0x800616d8,
		"subframeCallback": 0x800616d8,
		"JASystem::Kernel::TPortCmd::TPortCmd": 0x80061778,
		"JASystem::Kernel::TPortCmd::addPortCmdOnce": 0x80061790,
		"addPortCmdOnce": 0x80061790,
		"JASystem::Kernel::TPortCmd::setPortCmd": 0x800617b4,
		"setPortCmd": 0x800617b4,
		"JASystem::Kernel::TPortCmd::addPortCmd": 0x800617cc,
		"addPortCmd": 0x800617cc,
		"JASystem::Kernel::portCmdInit": 0x8006184c,
		"portCmdInit": 0x8006184c,
		"JASystem::Kernel::getPortCmd": 0x80061894,
		"getPortCmd": 0x80061894,
		"JASystem::Kernel::portCmdMain": 0x800618d4,
		"portCmdMain": 0x800618d4,
		"JASystem::Dvd::init": 0x80061944,
		"JASystem::Dvd::extendPath": 0x80061990,
		"extendPath": 0x80061990,
		"JASystem::Dvd::dvdProcInit": 0x80061a18,
		"dvdProcInit": 0x80061a18,
		"JASystem::Dvd::dvdProc": 0x80061ac4,
		"dvdProc": 0x80061ac4,
		"JASystem::Dvd::loadToDramDvdTMain": 0x80061b50,
		"loadToDramDvdTMain": 0x80061b50,
		"JASystem::Dvd::loadToDramDvdT": 0x80061c78,
		"loadToDramDvdT": 0x80061c78,
		"JASystem::Dvd::loadToAramDvdTMain": 0x80061d2c,
		"loadToAramDvdTMain": 0x80061d2c,
		"JASystem::Dvd::loadToAramDvdT": 0x80061f94,
		"loadToAramDvdT": 0x80061f94,
		"JASystem::Dvd::checkFileExtend": 0x80062048,
		"checkFileExtend": 0x80062048,
		"JASystem::Dvd::loadFileDvdT": 0x800620fc,
		"loadFileDvdT": 0x800620fc,
		"JASystem::Dvd::checkPassDvdT": 0x800621e4,
		"checkPassDvdT": 0x800621e4,
		"JASystem::Dvd::checkFile": 0x80062268,
		"checkFile": 0x80062268,
		"JASystem::Dvd::loadFile": 0x800622c4,
		"JASystem::Dvd::pauseDvdT": 0x80062378,
		"pauseDvdT": 0x80062378,
		"JASystem::Dvd::unpauseDvdT": 0x80062384,
		"unpauseDvdT": 0x80062384,
		"JASystem::Dvd::registerFastOpen": 0x800623bc,
		"registerFastOpen": 0x800623bc,
		"JASystem::Dvd::openDvd": 0x800624ac,
		"openDvd": 0x800624ac,
		"JASystem::Dvd::getCallStack": 0x80062504,
		"getCallStack": 0x80062504,
		"JASystem::Dvd::dvdReadMutex": 0x80062560,
		"dvdReadMutex": 0x80062560,
		"JASystem::Dvd::doError": 0x800625ec,
		"doError": 0x800625ec,
		"JASystem::Dvd::doFinish": 0x80062634,
		"doFinish": 0x80062634,
		"JASystem::Dvd::dvdThreadCheckBack": 0x80062678,
		"dvdThreadCheckBack": 0x80062678,
		"JASystem::Dvd::allocDvdBuffer": 0x800626c4,
		"allocDvdBuffer": 0x800626c4,
		"JASystem::Dvd::writeBufferSize": 0x8006279c,
		"writeBufferSize": 0x8006279c,
		"JASystem::Dvd::updateBuffer": 0x80062854,
		"updateBuffer": 0x80062854,
		"JASystem::Dvd::aramDmaFinish": 0x80062928,
		"aramDmaFinish": 0x80062928,
		"JASystem::HardStream::main": 0x80062938,
		"JASystem::HardStream::firstBgmCallback": 0x80062dbc,
		"firstBgmCallback": 0x80062dbc,
		"JASystem::HardStream::secondBgmCallback": 0x80062e48,
		"secondBgmCallback": 0x80062e48,
		"JASystem::HardStream::getAddrCallback": 0x80062e5c,
		"getAddrCallback": 0x80062e5c,
		"JASystem::HardStream::TControl::TControl": 0x80062fdc,
		"JASystem::HardStream::TControl::getIntroNum": 0x8006303c,
		"getIntroNum": 0x8006303c,
		"JASystem::HardStream::TControl::getLoopNum": 0x80063074,
		"getLoopNum": 0x80063074,
		"JASystem::HardStream::TControl::clearListOne": 0x800630ac,
		"clearListOne": 0x800630ac,
		"JASystem::HardStream::TControl::getLastAddr": 0x800630e0,
		"getLastAddr": 0x800630e0,
		"JASystem::HardStream::TControl::startFirst": 0x800630f4,
		"startFirst": 0x800630f4,
		"JASystem::HardStream::TControl::startSecond": 0x80063214,
		"startSecond": 0x80063214,
		"JASystem::HardStream::TControl::resetFader": 0x80063334,
		"resetFader": 0x80063334,
		"JASystem::HardStream::TControl::getCurVol": 0x80063370,
		"getCurVol": 0x80063370,
		"JASystem::HardStream::TControl::calcCurVolume": 0x800633a8,
		"calcCurVolume": 0x800633a8,
		"JASystem::HardStream::TControl::volFloatToU8": 0x8006362c,
		"volFloatToU8": 0x8006362c,
		"JSystem::__sinit_JASHardStream_cpp": 0x8006366c,
		"__sinit_JASHardStream_cpp": 0x8006366c,
		"JASystem::HardStream::TControl::~TControl": 0x800636a8,
		"JASystem::Kernel::THeap::THeap": 0x800636e8,
		"JASystem::Kernel::THeap::selfAlloc": 0x80063734,
		"selfAlloc": 0x80063734,
		"JASystem::Kernel::THeap::initMotherHeap": 0x80063834,
		"initMotherHeap": 0x80063834,
		"JASystem::Kernel::THeap::allocHeapCheck": 0x80063890,
		"allocHeapCheck": 0x80063890,
		"JASystem::Kernel::THeap::alloc": 0x80063a44,
		"JASystem::Kernel::THeap::free": 0x80063a84,
		"JASystem::Kernel::TSolidHeap::TSolidHeap": 0x80063c24,
		"JASystem::Kernel::TSolidHeap::alloc": 0x80063c40,
		"JASystem::Kernel::TSolidHeap::init": 0x80063c9c,
		"JASystem::Kernel::TSolidHeap::getRemain": 0x80063ce4,
		"getRemain": 0x80063ce4,
		"JASystem::Kernel::stackInit": 0x80063cfc,
		"stackInit": 0x80063cfc,
		"JASystem::Kernel::probeStart": 0x80063dcc,
		"probeStart": 0x80063dcc,
		"JASystem::Kernel::probeFinish": 0x80063dd0,
		"probeFinish": 0x80063dd0,
		"JASystem::Kernel::sysDramSetup": 0x80063dd4,
		"sysDramSetup": 0x80063dd4,
		"JASystem::Kernel::allocFromSysDram": 0x80063e2c,
		"allocFromSysDram": 0x80063e2c,
		"JASystem::Kernel::sysAramSetup": 0x80063e84,
		"sysAramSetup": 0x80063e84,
		"JASystem::Kernel::allocFromSysAramFull": 0x80063eec,
		"allocFromSysAramFull": 0x80063eec,
		"JSystem::__sinit_JASSystemHeap_cpp": 0x80063f4c,
		"__sinit_JASSystemHeap_cpp": 0x80063f4c,
		"JASystem::Vload::initHeader": 0x80063f88,
		"initHeader": 0x80063f88,
		"JASystem::Vload::initHeaderM": 0x80063fb0,
		"initHeaderM": 0x80063fb0,
		"JASystem::Vload::getArchiveHandle": 0x8006411c,
		"getArchiveHandle": 0x8006411c,
		"JASystem::Vload::getRealHandle": 0x800641a4,
		"getRealHandle": 0x800641a4,
		"JASystem::Vload::checkSize": 0x8006421c,
		"checkSize": 0x8006421c,
		"JASystem::Vload::loadFile": 0x80064250,
		"JASystem::Vload::loadFileAsync": 0x800642fc,
		"loadFileAsync": 0x800642fc,
		"JASystem::Vload::initVloadBuffers": 0x8006439c,
		"initVloadBuffers": 0x8006439c,
		"JASystem::TTrack::TNoteMgr::init": 0x80064460,
		"JASystem::TTrack::TNoteMgr::endProcess": 0x800644b8,
		"endProcess": 0x800644b8,
		"JASystem::TTrack::TNoteMgr::getChannel": 0x800644e0,
		"getChannel": 0x800644e0,
		"JASystem::TTrack::TOuterParam::TOuterParam": 0x80064530,
		"JASystem::TTrack::TOuterParam::initExtBuffer": 0x8006457c,
		"initExtBuffer": 0x8006457c,
		"JASystem::TTrack::TOuterParam::setOuterSwitch": 0x8006458c,
		"setOuterSwitch": 0x8006458c,
		"JASystem::TTrack::TOuterParam::checkOuterSwitch": 0x80064594,
		"checkOuterSwitch": 0x80064594,
		"JASystem::TTrack::TOuterParam::setOuterUpdate": 0x800645b4,
		"setOuterUpdate": 0x800645b4,
		"JASystem::TTrack::TOuterParam::getOuterUpdate": 0x800645bc,
		"getOuterUpdate": 0x800645bc,
		"JASystem::TTrack::TOuterParam::getIntFirFilter": 0x800645c4,
		"getIntFirFilter": 0x800645c4,
		"JASystem::TTrack::TOuterParam::setParam": 0x800645d4,
		"setParam": 0x800645d4,
		"JASystem::TTrack::TOuterParam::onSwitch": 0x80064670,
		"onSwitch": 0x80064670,
		"JASystem::TTrack::TOuterParam::setFirFilter": 0x8006468c,
		"setFirFilter": 0x8006468c,
		"JASystem::Player::extend8to16": 0x800646e8,
		"extend8to16": 0x800646e8,
		"JASystem::Player::pitchToCent": 0x80064708,
		"pitchToCent": 0x80064708,
		"JASystem::Player::getRandomS32": 0x800647d4,
		"getRandomS32": 0x800647d4,
		"JASystem::TRegisterParam::TRegisterParam": 0x8006480c,
		"JASystem::TRegisterParam::init": 0x8006485c,
		"JASystem::TRegisterParam::inherit": 0x800648c4,
		"inherit": 0x800648c4,
		"JASystem::TRegisterParam::getBankNumber": 0x80064934,
		"getBankNumber": 0x80064934,
		"JASystem::TRegisterParam::getProgramNumber": 0x80064944,
		"getProgramNumber": 0x80064944,
		"JASystem::TSeqCtrl::init": 0x80064950,
		"JASystem::TSeqCtrl::loopE": 0x800649b8,
		"loopE": 0x800649b8,
		"JASystem::TSeqCtrl::waitCountDown": 0x80064a24,
		"waitCountDown": 0x80064a24,
		"JASystem::TSeqCtrl::callIntr": 0x80064a54,
		"callIntr": 0x80064a54,
		"JASystem::TSeqCtrl::retIntr": 0x80064a8c,
		"retIntr": 0x80064a8c,
		"JASystem::TSeqCtrl::get16": 0x80064ac0,
		"get16": 0x80064ac0,
		"JASystem::TSeqCtrl::get24": 0x80064ae8,
		"get24": 0x80064ae8,
		"JASystem::TSeqCtrl::get32": 0x80064b10,
		"get32": 0x80064b10,
		"JASystem::TSeqCtrl::read16": 0x80064b48,
		"read16": 0x80064b48,
		"JASystem::TSeqCtrl::read24": 0x80064b80,
		"read24": 0x80064b80,
		"JASystem::TTrack::TTrack": 0x80064bc4,
		"JASystem::TTrack::MoveParam_::MoveParam_": 0x80064de4,
		"JASystem::TTrack::AInnerParam_::AInnerParam_": 0x80064dfc,
		"JASystem::TTrack::setInterrupt": 0x80064f2c,
		"setInterrupt": 0x80064f2c,
		"JASystem::TTrack::assignExtBuffer": 0x80064f54,
		"assignExtBuffer": 0x80064f54,
		"JASystem::TTrack::setInnerMemory": 0x80064f70,
		"setInnerMemory": 0x80064f70,
		"JASystem::TTrack::setPanSwitchExt": 0x80064f78,
		"setPanSwitchExt": 0x80064f78,
		"JASystem::TTrack::setPanSwitchParent": 0x80064f88,
		"setPanSwitchParent": 0x80064f88,
		"JASystem::TTrack::flushAll": 0x80064f98,
		"flushAll": 0x80064f98,
		"JASystem::TTrack::initTimed": 0x80064fd0,
		"initTimed": 0x80064fd0,
		"JASystem::TTrack::noteOn": 0x800650f0,
		"JASystem::TTrack::noteOff": 0x80065428,
		"noteOff": 0x80065428,
		"JASystem::TTrack::gateOn": 0x800654b4,
		"JASystem::TTrack::oscSetupFull": 0x80065524,
		"oscSetupFull": 0x80065524,
		"JASystem::TTrack::oscSetupSimpleEnv": 0x80065650,
		"oscSetupSimpleEnv": 0x80065650,
		"JASystem::TTrack::oscUpdateParam": 0x800656c0,
		"oscUpdateParam": 0x800656c0,
		"JASystem::TTrack::oscSetupSimple": 0x80065728,
		"oscSetupSimple": 0x80065728,
		"JASystem::TTrack::updateTrackAll": 0x80065804,
		"updateTrackAll": 0x80065804,
		"JASystem::TTrack::updateTrack": 0x80065bbc,
		"updateTrack": 0x80065bbc,
		"JASystem::TTrack::updateTempo": 0x800660ec,
		"updateTempo": 0x800660ec,
		"JASystem::TTrack::updateSeq": 0x80066218,
		"updateSeq": 0x80066218,
		"JASystem::TTrack::incSelfOsc": 0x800662ec,
		"incSelfOsc": 0x800662ec,
		"JASystem::TTrack::mainProc": 0x800663e0,
		"JASystem::TTrack::seqTimeToDspTime": 0x80066884,
		"seqTimeToDspTime": 0x80066884,
		"JASystem::TTrack::writeTimeParam": 0x80066940,
		"writeTimeParam": 0x80066940,
		"JASystem::TTrack::writeRegParam": 0x80066b44,
		"writeRegParam": 0x80066b44,
		"JASystem::TTrack::setSeqData": 0x8006704c,
		"JASystem::TTrack::startSeq": 0x800670f0,
		"JASystem::TTrack::stopSeq": 0x8006716c,
		"JASystem::TTrack::closeTrack": 0x800671ec,
		"closeTrack": 0x800671ec,
		"JASystem::TTrack::muteTrack": 0x8006734c,
		"muteTrack": 0x8006734c,
		"JASystem::TTrack::initTrack": 0x8006741c,
		"initTrack": 0x8006741c,
		"JASystem::TTrack::startTrack": 0x800676ac,
		"startTrack": 0x800676ac,
		"JASystem::TTrack::openTrack": 0x80067740,
		"openTrack": 0x80067740,
		"JASystem::TTrack::loadTbl": 0x80067798,
		"loadTbl": 0x80067798,
		"JASystem::TTrack::readReg32": 0x80067840,
		"readReg32": 0x80067840,
		"JASystem::TTrack::exchangeRegisterValue": 0x800678dc,
		"exchangeRegisterValue": 0x800678dc,
		"JASystem::TTrack::readRegDirect": 0x80067994,
		"readRegDirect": 0x80067994,
		"JASystem::TTrack::writeRegDirect": 0x80067bd0,
		"writeRegDirect": 0x80067bd0,
		"JASystem::TTrack::writePortAppDirect": 0x80067c9c,
		"writePortAppDirect": 0x80067c9c,
		"JASystem::TTrack::readPortAppDirect": 0x80067cf8,
		"readPortAppDirect": 0x80067cf8,
		"JASystem::TTrack::setExtFirFilterD": 0x80067d1c,
		"setExtFirFilterD": 0x80067d1c,
		"JASystem::TTrack::writePortApp": 0x80067d48,
		"JASystem::TTrack::readPortApp": 0x80067df0,
		"JASystem::TTrack::pauseTrack": 0x80067e60,
		"pauseTrack": 0x80067e60,
		"JASystem::TTrack::unPauseTrack": 0x80067f94,
		"unPauseTrack": 0x80067f94,
		"JASystem::TTrack::pauseTrackAll": 0x80068070,
		"pauseTrackAll": 0x80068070,
		"JASystem::TTrack::unPauseTrackAll": 0x80068094,
		"unPauseTrackAll": 0x80068094,
		"JASystem::TTrack::reset": 0x800680b8,
		"JASystem::TTrack::panCalc": 0x800680c8,
		"panCalc": 0x800680c8,
		"JASystem::TTrack::rootCallback": 0x80068114,
		"rootCallback": 0x80068114,
		"JASystem::TTrack::registerTrackCallback": 0x800682a4,
		"JSystem::__sinit_JASTrack_cpp": 0x800682b0,
		"__sinit_JASTrack_cpp": 0x800682b0,
		"JASystem::TIntrMgr::init": 0x800682dc,
		"JASystem::TIntrMgr::request": 0x80068320,
		"JASystem::TIntrMgr::setIntr": 0x80068344,
		"setIntr": 0x80068344,
		"JASystem::TIntrMgr::resetInter": 0x80068368,
		"resetInter": 0x80068368,
		"JASystem::TIntrMgr::checkIntr": 0x80068380,
		"checkIntr": 0x80068380,
		"JASystem::TIntrMgr::timerProcess": 0x800683ec,
		"timerProcess": 0x800683ec,
		"JASystem::TrackMgr::init": 0x8006845c,
		"JASystem::TTrack::~TTrack": 0x80068550,
		"JASystem::TrackMgr::handleToSeq": 0x800685b4,
		"handleToSeq": 0x800685b4,
		"JASystem::TrackMgr::reset": 0x800685d8,
		"JASystem::TrackMgr::initRegistTrack": 0x80068674,
		"initRegistTrack": 0x80068674,
		"JASystem::TrackMgr::getNewTrack": 0x80068704,
		"getNewTrack": 0x80068704,
		"JASystem::TrackMgr::allocNewRoot": 0x8006878c,
		"allocNewRoot": 0x8006878c,
		"JASystem::TrackMgr::deAllocRoot": 0x800687d4,
		"deAllocRoot": 0x800687d4,
		"JASystem::TrackMgr::registTrack": 0x80068820,
		"registTrack": 0x80068820,
		"JASystem::TrackMgr::unRegistTrack": 0x8006893c,
		"unRegistTrack": 0x8006893c,
		"JASystem::TrackMgr::backTrack": 0x800689b4,
		"backTrack": 0x800689b4,
		"JASystem::TrackMgr::registerTrackCallback": 0x80068a14,
		"JASystem::TTrackPort::init": 0x80068a34,
		"JMath::TRandom_fast_::TRandom_fast_": 0x80068b1c,
		"JMath::TRandom_enough_::setSeed": 0x80068b24,
		"setSeed": 0x80068b24,
		"J3DMaterialFactory_v21::J3DMaterialFactory_v21": 0x80068c18,
		"J3DMaterialFactory_v21::countUniqueMaterials": 0x80068df8,
		"J3DMaterialFactory_v21::countStages": 0x80068e50,
		"J3DMaterialFactory_v21::create": 0x80068f34,
		"J3DMaterialFactory_v21::newMatColor": 0x80069680,
		"J3DMaterialFactory_v21::newColorChanNum": 0x80069710,
		"J3DMaterialFactory_v21::newColorChan": 0x80069748,
		"J3DMaterialFactory_v21::newTexGenNum": 0x80069810,
		"J3DMaterialFactory_v21::newTexCoord": 0x80069848,
		"J3DMaterialFactory_v21::newTexMtx": 0x800698bc,
		"J3DMaterialFactory_v21::newCullMode": 0x80069950,
		"J3DMaterialFactory_v21::newTexNo": 0x80069990,
		"J3DMaterialFactory_v21::newTevOrder": 0x800699d8,
		"J3DMaterialFactory_v21::newTevColor": 0x80069a4c,
		"J3DMaterialFactory_v21::newTevKColor": 0x80069ae4,
		"J3DMaterialFactory_v21::newTevStageNum": 0x80069b74,
		"J3DMaterialFactory_v21::newTevStage": 0x80069bac,
		"J3DMaterialFactory_v21::newTevSwapModeTable": 0x80069e18,
		"J3DMaterialFactory_v21::newFog": 0x80069eb4,
		"J3DMaterialFactory_v21::newAlphaComp": 0x80069f40,
		"J3DMaterialFactory_v21::newBlend": 0x80069fc0,
		"J3DMaterialFactory_v21::newZMode": 0x8006a03c,
		"J3DMaterialFactory_v21::newZCompLoc": 0x8006a0a0,
		"J3DMaterialFactory_v21::newDither": 0x8006a0d8,
		"J3DMaterialFactory_v21::newNBTScale": 0x8006a110,
		"JASystem::TSeqParser::cmdOpenTrack": 0x8006a1d0,
		"cmdOpenTrack": 0x8006a1d0,
		"JASystem::TSeqParser::cmdOpenTrackBros": 0x8006a250,
		"cmdOpenTrackBros": 0x8006a250,
		"JASystem::TSeqParser::cmdCall": 0x8006a2e4,
		"cmdCall": 0x8006a2e4,
		"JASystem::TSeqParser::cmdRet": 0x8006a400,
		"cmdRet": 0x8006a400,
		"JASystem::TSeqParser::cmdJmp": 0x8006a480,
		"cmdJmp": 0x8006a480,
		"JASystem::TSeqParser::cmdLoopS": 0x8006a5bc,
		"cmdLoopS": 0x8006a5bc,
		"JASystem::TSeqParser::cmdLoopE": 0x8006a5f4,
		"cmdLoopE": 0x8006a5f4,
		"JASystem::TSeqParser::cmdReadPort": 0x8006a62c,
		"cmdReadPort": 0x8006a62c,
		"JASystem::TSeqParser::cmdWritePort": 0x8006a678,
		"cmdWritePort": 0x8006a678,
		"JASystem::TSeqParser::cmdCheckPortImport": 0x8006a6a0,
		"cmdCheckPortImport": 0x8006a6a0,
		"JASystem::TSeqParser::cmdCheckPortExport": 0x8006a6d8,
		"cmdCheckPortExport": 0x8006a6d8,
		"JASystem::TSeqParser::cmdWait": 0x8006a710,
		"cmdWait": 0x8006a710,
		"JASystem::TSeqParser::cmdConnectName": 0x8006a730,
		"cmdConnectName": 0x8006a730,
		"JASystem::TSeqParser::cmdParentWritePort": 0x8006a74c,
		"cmdParentWritePort": 0x8006a74c,
		"JASystem::TSeqParser::cmdChildWritePort": 0x8006a784,
		"cmdChildWritePort": 0x8006a784,
		"JASystem::TSeqParser::cmdSetLastNote": 0x8006a7c4,
		"cmdSetLastNote": 0x8006a7c4,
		"JASystem::TSeqParser::cmdTimeRelate": 0x8006a7e0,
		"cmdTimeRelate": 0x8006a7e0,
		"JASystem::TSeqParser::cmdSimpleOsc": 0x8006a804,
		"cmdSimpleOsc": 0x8006a804,
		"JASystem::TSeqParser::cmdSimpleEnv": 0x8006a834,
		"cmdSimpleEnv": 0x8006a834,
		"JASystem::TSeqParser::cmdSimpleADSR": 0x8006a868,
		"cmdSimpleADSR": 0x8006a868,
		"JASystem::TSeqParser::cmdTranspose": 0x8006a924,
		"cmdTranspose": 0x8006a924,
		"JASystem::TSeqParser::cmdCloseTrack": 0x8006a95c,
		"cmdCloseTrack": 0x8006a95c,
		"JASystem::TSeqParser::cmdOutSwitch": 0x8006a9b4,
		"cmdOutSwitch": 0x8006a9b4,
		"JASystem::TSeqParser::cmdUpdateSync": 0x8006aa0c,
		"cmdUpdateSync": 0x8006aa0c,
		"JASystem::TSeqParser::cmdBusConnect": 0x8006aa38,
		"cmdBusConnect": 0x8006aa38,
		"JASystem::TSeqParser::cmdPauseStatus": 0x8006aa5c,
		"cmdPauseStatus": 0x8006aa5c,
		"JASystem::TSeqParser::cmdVolumeMode": 0x8006aa6c,
		"cmdVolumeMode": 0x8006aa6c,
		"JASystem::TSeqParser::cmdSetInterrupt": 0x8006aa7c,
		"cmdSetInterrupt": 0x8006aa7c,
		"JASystem::TSeqParser::cmdDisInterrupt": 0x8006aab4,
		"cmdDisInterrupt": 0x8006aab4,
		"JASystem::TSeqParser::cmdClrI": 0x8006aae0,
		"cmdClrI": 0x8006aae0,
		"JASystem::TSeqParser::cmdSetI": 0x8006aaf8,
		"cmdSetI": 0x8006aaf8,
		"JASystem::TSeqParser::cmdRetI": 0x8006ab08,
		"cmdRetI": 0x8006ab08,
		"JASystem::TSeqParser::cmdIntTimer": 0x8006ab38,
		"cmdIntTimer": 0x8006ab38,
		"JASystem::TSeqParser::cmdConnectOpen": 0x8006ab54,
		"cmdConnectOpen": 0x8006ab54,
		"JASystem::TSeqParser::cmdConnectClose": 0x8006ab90,
		"cmdConnectClose": 0x8006ab90,
		"JASystem::TSeqParser::cmdSyncCPU": 0x8006abd8,
		"cmdSyncCPU": 0x8006abd8,
		"JASystem::TSeqParser::cmdFlushAll": 0x8006ac40,
		"cmdFlushAll": 0x8006ac40,
		"JASystem::TSeqParser::cmdFlushRelease": 0x8006ac68,
		"cmdFlushRelease": 0x8006ac68,
		"JASystem::TSeqParser::cmdTimeBase": 0x8006ac90,
		"cmdTimeBase": 0x8006ac90,
		"JASystem::TSeqParser::cmdTempo": 0x8006accc,
		"cmdTempo": 0x8006accc,
		"JASystem::TSeqParser::cmdFinish": 0x8006ad14,
		"cmdFinish": 0x8006ad14,
		"JASystem::TSeqParser::cmdNop": 0x8006ae00,
		"cmdNop": 0x8006ae00,
		"JASystem::TSeqParser::cmdPanPowSet": 0x8006ae08,
		"cmdPanPowSet": 0x8006ae08,
		"JASystem::TSeqParser::cmdIIRSet": 0x8006ae8c,
		"cmdIIRSet": 0x8006ae8c,
		"JASystem::TSeqParser::cmdFIRSet": 0x8006af90,
		"cmdFIRSet": 0x8006af90,
		"JASystem::TSeqParser::cmdEXTSet": 0x8006afc4,
		"cmdEXTSet": 0x8006afc4,
		"JASystem::TSeqParser::cmdPanSwSet": 0x8006b018,
		"cmdPanSwSet": 0x8006b018,
		"JASystem::TSeqParser::cmdOscRoute": 0x8006b108,
		"cmdOscRoute": 0x8006b108,
		"JASystem::TSeqParser::cmdIIRCutOff": 0x8006b158,
		"cmdIIRCutOff": 0x8006b158,
		"JASystem::TSeqParser::cmdOscFull": 0x8006b260,
		"cmdOscFull": 0x8006b260,
		"JASystem::TSeqParser::cmdCheckWave": 0x8006b29c,
		"cmdCheckWave": 0x8006b29c,
		"JASystem::TSeqParser::cmdPrintf": 0x8006b2cc,
		"cmdPrintf": 0x8006b2cc,
		"JASystem::TSeqParser::Cmd_Process": 0x8006b4ec,
		"Cmd_Process": 0x8006b4ec,
		"JASystem::TSeqParser::RegCmd_Process": 0x8006b644,
		"RegCmd_Process": 0x8006b644,
		"JASystem::TSeqParser::cmdNoteOff": 0x8006b728,
		"cmdNoteOff": 0x8006b728,
		"JASystem::TSeqParser::cmdNoteOn": 0x8006b808,
		"cmdNoteOn": 0x8006b808,
		"JASystem::TSeqParser::conditionCheck": 0x8006bae8,
		"conditionCheck": 0x8006bae8,
		"JASystem::TSeqParser::mainProc": 0x8006bbd8,
		"JSystem::__sinit_JASSeqParser_cpp": 0x8006beac,
		"__sinit_JASSeqParser_cpp": 0x8006beac,
		"J3DMaterialTable::clear": 0x8006c4e0,
		"J3DMaterialTable::J3DMaterialTable": 0x8006c4fc,
		"J3DMaterialTable::~J3DMaterialTable": 0x8006c524,
		"JSystem::JPAGetEmitterInfoPtr": 0x8006c570,
		"JPAGetEmitterInfoPtr": 0x8006c570,
		"JPABaseEmitter::JPABaseEmitter": 0x8006c57c,
		"JPABaseEmitter::getFovy": 0x8006c694,
		"getFovy": 0x8006c694,
		"JPABaseEmitter::getAspect": 0x8006c6a4,
		"getAspect": 0x8006c6a4,
		"JPABaseEmitter::deleteAllParticle": 0x8006c6b4,
		"deleteAllParticle": 0x8006c6b4,
		"JPABaseEmitter::createChildParticle": 0x8006c788,
		"createChildParticle": 0x8006c788,
		"JPAParticle::addBaseVelVec": 0x8006cd3c,
		"addBaseVelVec": 0x8006cd3c,
		"JPAParticle::setBaseVelVec": 0x8006cda4,
		"setBaseVelVec": 0x8006cda4,
		"JPABaseEmitter::getEmitterGlobalTranslation": 0x8006cdc0,
		"getEmitterGlobalTranslation": 0x8006cdc0,
		"JPABaseEmitter::calcEmitterGlobalParams": 0x8006cea8,
		"calcEmitterGlobalParams": 0x8006cea8,
		"JPABaseEmitter::loadBaseEmitterBlock": 0x8006d21c,
		"loadBaseEmitterBlock": 0x8006d21c,
		"JPABaseEmitter::drawEmitterCallBack": 0x8006d5ec,
		"drawEmitterCallBack": 0x8006d5ec,
		"JPABaseEmitter::createParticle": 0x8006d62c,
		"createParticle": 0x8006d62c,
		"JPABaseEmitter::calcCurrentRateTimerStep": 0x8006e8d4,
		"calcCurrentRateTimerStep": 0x8006e8d4,
		"JPABaseEmitter::calcCreateParticle": 0x8006e928,
		"calcCreateParticle": 0x8006e928,
		"JPABaseEmitter::checkStartFrame": 0x8006ec38,
		"checkStartFrame": 0x8006ec38,
		"JPABaseEmitter::checkMaxFrame": 0x8006ec94,
		"checkMaxFrame": 0x8006ec94,
		"JPABaseEmitter::doParticle": 0x8006ed40,
		"doParticle": 0x8006ed40,
		"JPABaseEmitter::doChildParticle": 0x8006eeac,
		"doChildParticle": 0x8006eeac,
		"JPABaseEmitter::calcKeyFrameAnime": 0x8006f008,
		"calcKeyFrameAnime": 0x8006f008,
		"JPABaseEmitter::calc": 0x8006f1d8,
		"JPABaseEmitter::setGlobalRTMatrix": 0x8006f324,
		"setGlobalRTMatrix": 0x8006f324,
		"JPABaseEmitter::setGlobalSRTMatrix": 0x8006f354,
		"setGlobalSRTMatrix": 0x8006f354,
		"JSystem::__sinit_JPAEmitter_cpp": 0x8006f388,
		"__sinit_JPAEmitter_cpp": 0x8006f388,
		"JPAEmitterManager::JPAEmitterManager": 0x8006f3e8,
		"JSUList<JPABaseEmitter>::JSUList": 0x8006f6c0,
		"JSUList<JPABaseEmitter>::~JSUList": 0x8006f6f0,
		"JPAEmitterManager::calcBase": 0x8006f748,
		"calcBase": 0x8006f748,
		"JPAEmitterManager::calc": 0x8006f824,
		"JPAEmitterManager::createEmitterBase": 0x8006fa04,
		"createEmitterBase": 0x8006fa04,
		"JPAEmitterManager::createSimpleEmitterID": 0x8006fbb0,
		"createSimpleEmitterID": 0x8006fbb0,
		"JPAEmitterManager::createEmitter": 0x8006fc18,
		"createEmitter": 0x8006fc18,
		"JPAEmitterManager::deleteEmitter": 0x8006fcb0,
		"deleteEmitter": 0x8006fcb0,
		"JPAEmitterManager::forceDeleteEmitter": 0x8006fd14,
		"forceDeleteEmitter": 0x8006fd14,
		"JPABaseField::JPABaseField": 0x8006fd7c,
		"JPABaseField::~JPABaseField": 0x8006fe14,
		"JPABaseField::set": 0x8006fe7c,
		"JPABaseField::checkMaxDistance": 0x8006fe80,
		"JPABaseField::calcFieldFadeScale": 0x8006fed8,
		"calcFieldFadeScale": 0x8006fed8,
		"JPABaseField::calcFieldVelocity": 0x8006fffc,
		"calcFieldVelocity": 0x8006fffc,
		"JPABaseField::affect": 0x8007016c,
		"JPABaseField::loadFieldBlock": 0x8007018c,
		"loadFieldBlock": 0x8007018c,
		"JPAGravityField::JPAGravityField": 0x800703e8,
		"JPAGravityField::~JPAGravityField": 0x8007042c,
		"JPAGravityField::set": 0x800704a4,
		"JPAAirField::JPAAirField": 0x80070540,
		"JPAAirField::set": 0x80070584,
		"JPAAirField::affect": 0x800706cc,
		"JPAParticle::getBaseVelVec": 0x80070904,
		"getBaseVelVec": 0x80070904,
		"JPAMagnetField::JPAMagnetField": 0x80070920,
		"JPAMagnetField::~JPAMagnetField": 0x80070964,
		"JPAMagnetField::set": 0x800709dc,
		"JPAMagnetField::affect": 0x80070a54,
		"JPANewtonField::JPANewtonField": 0x80070b94,
		"JPANewtonField::~JPANewtonField": 0x80070bd8,
		"JPANewtonField::set": 0x80070c50,
		"JPANewtonField::affect": 0x80070cd4,
		"JPAVortexField::JPAVortexField": 0x80070ed0,
		"JPAVortexField::~JPAVortexField": 0x80070f28,
		"JPAVortexField::set": 0x80070fa0,
		"JPAVortexField::affect": 0x80070ff8,
		"JPAVortexField::checkMaxDistance": 0x80071160,
		"JPAConvectionField::JPAConvectionField": 0x80071168,
		"JPAConvectionField::~JPAConvectionField": 0x800711cc,
		"JPAConvectionField::set": 0x80071244,
		"JPAConvectionField::affect": 0x800714f8,
		"JPAConvectionField::checkMaxDistance": 0x800717f0,
		"JPARandomField::JPARandomField": 0x800717f8,
		"JPARandomField::~JPARandomField": 0x8007183c,
		"JPARandomField::affect": 0x800718b4,
		"JPADragField::JPADragField": 0x800719f4,
		"JPADragField::~JPADragField": 0x80071a38,
		"JPADragField::affect": 0x80071ab0,
		"JPAParticle::getDragForce": 0x80071bd0,
		"getDragForce": 0x80071bd0,
		"JPAFieldManager::JPAFieldManager": 0x80071bd8,
		"JPAFieldManager::deleteAllField": 0x80071c08,
		"deleteAllField": 0x80071c08,
		"JPAFieldManager::calcFieldParams": 0x80071c80,
		"calcFieldParams": 0x80071c80,
		"JPAFieldManager::affectField": 0x80071d08,
		"affectField": 0x80071d08,
		"JPAFieldManager::setField": 0x80071de0,
		"setField": 0x80071de0,
		"JPAFieldManager::setGravityField": 0x80071e84,
		"setGravityField": 0x80071e84,
		"JPAFieldManager::setAirField": 0x80071ef8,
		"setAirField": 0x80071ef8,
		"JPAFieldManager::setMagnetField": 0x80071f6c,
		"setMagnetField": 0x80071f6c,
		"JPAFieldManager::setNewtonField": 0x80071fe0,
		"setNewtonField": 0x80071fe0,
		"JPAFieldManager::setVortexField": 0x80072054,
		"setVortexField": 0x80072054,
		"JPAFieldManager::setConvectionField": 0x800720c8,
		"setConvectionField": 0x800720c8,
		"JPAFieldManager::setRandomField": 0x8007213c,
		"setRandomField": 0x8007213c,
		"JPAFieldManager::setDragField": 0x800721b0,
		"setDragField": 0x800721b0,
		"JPAAirField::~JPAAirField": 0x80072224,
		"JSystem::__sinit_JPAField_cpp": 0x8007229c,
		"__sinit_JPAField_cpp": 0x8007229c,
		"JSystem::JPASqrtf": 0x800722c4,
		"JPASqrtf": 0x800722c4,
		"JSystem::JPAGetXYZRotateMtx": 0x800722e8,
		"JPAGetXYZRotateMtx": 0x800722e8,
		"JSystem::JPAGetXYRotateMtx": 0x80072500,
		"JPAGetXYRotateMtx": 0x80072500,
		"JSystem::JPAGetYZRotateMtx": 0x80072634,
		"JPAGetYZRotateMtx": 0x80072634,
		"JSystem::JPAGetYRotateMtx": 0x80072768,
		"JPAGetYRotateMtx": 0x80072768,
		"JSystem::JPAVecToRotaMtx": 0x80072800,
		"JPAVecToRotaMtx": 0x80072800,
		"JSystem::JPAConvertFixToFloat": 0x800729b4,
		"JPAConvertFixToFloat": 0x800729b4,
		"JSystem::JPAConvertFixVecToFloatVec": 0x80072a70,
		"JPAConvertFixVecToFloatVec": 0x80072a70,
		"JSystem::JPAGetRMtxSTVecElement": 0x80072c98,
		"JPAGetRMtxSTVecElement": 0x80072c98,
		"JSystem::JPAGetRMtxTVecElement": 0x80072f2c,
		"JPAGetRMtxTVecElement": 0x80072f2c,
		"JSystem::JPAGetKeyFrameValue": 0x8007319c,
		"JPAGetKeyFrameValue": 0x8007319c,
		"JSystem::JPAGetKeyFrameInterpolation": 0x800731bc,
		"JPAGetKeyFrameInterpolation": 0x800731bc,
		"JPABaseParticle::incTimer": 0x8007326c,
		"incTimer": 0x8007326c,
		"JPABaseParticle::executeParticleCallBack": 0x800732cc,
		"executeParticleCallBack": 0x800732cc,
		"JPABaseParticle::drawParticleCallBack": 0x8007330c,
		"drawParticleCallBack": 0x8007330c,
		"JPAParticle::JPAParticle": 0x8007334c,
		"JPAParticle::init": 0x80073398,
		"JPAParticle::setVelocity": 0x800733d8,
		"setVelocity": 0x800733d8,
		"JPAParticle::calcVelocity": 0x80073494,
		"JPABaseParticle::initGlobalPosition": 0x800735bc,
		"initGlobalPosition": 0x800735bc,
		"JPABaseParticle::calcGlobalPosition": 0x80073624,
		"calcGlobalPosition": 0x80073624,
		"JPABaseParticle::getCurrentPosition": 0x800736bc,
		"getCurrentPosition": 0x800736bc,
		"JPAParticle::checkCreateChildParticle": 0x80073748,
		"checkCreateChildParticle": 0x80073748,
		"JPAParticle::getDynamicsWeight": 0x8007380c,
		"getDynamicsWeight": 0x8007380c,
		"JPAParticle::getAirResistance": 0x80073814,
		"getAirResistance": 0x80073814,
		"JPAParticle::getCurrentDragForce": 0x8007381c,
		"getCurrentDragForce": 0x8007381c,
		"JPAParticle::accessBaseVelVec": 0x80073824,
		"accessBaseVelVec": 0x80073824,
		"JPAParticle::accessFAccVec": 0x8007382c,
		"accessFAccVec": 0x8007382c,
		"JPAParticle::accessFVelVec": 0x80073834,
		"accessFVelVec": 0x80073834,
		"JPAParticle::getDrawParamPPtr": 0x8007383c,
		"getDrawParamPPtr": 0x8007383c,
		"JPAParticle::getDrawParamCPtr": 0x80073844,
		"getDrawParamCPtr": 0x80073844,
		"JPAParticle::getWidth": 0x8007384c,
		"JPAParticle::getHeight": 0x8007386c,
		"JPADrawSetupTev::setupTev": 0x8007388c,
		"setupTev": 0x8007388c,
		"JPADraw::initialize": 0x80073bcc,
		"JPADraw::draw": 0x80073f30,
		"JPADraw::calc": 0x800741b4,
		"JPADraw::calcParticle": 0x80074228,
		"calcParticle": 0x80074228,
		"JPADraw::calcChild": 0x800742d0,
		"calcChild": 0x800742d0,
		"JPADraw::initParticle": 0x80074378,
		"JPADraw::initChild": 0x800746c8,
		"initChild": 0x800746c8,
		"JPADraw::swapImage": 0x8007498c,
		"swapImage": 0x8007498c,
		"JPADraw::setDrawExecVisitorsBeforeCB": 0x800749ec,
		"setDrawExecVisitorsBeforeCB": 0x800749ec,
		"JPADraw::setDrawExecVisitorsAfterCB": 0x80075094,
		"setDrawExecVisitorsAfterCB": 0x80075094,
		"JPADraw::setDrawCalcVisitors": 0x80075694,
		"setDrawCalcVisitors": 0x80075694,
		"JPADraw::setParticleClipBoard": 0x80075f70,
		"setParticleClipBoard": 0x80075f70,
		"JPADraw::setChildClipBoard": 0x80076310,
		"setChildClipBoard": 0x80076310,
		"JPADraw::drawParticle": 0x80076630,
		"drawParticle": 0x80076630,
		"JPADraw::drawChild": 0x80076890,
		"drawChild": 0x80076890,
		"JPADraw::zDraw": 0x80076b34,
		"zDraw": 0x80076b34,
		"JPADraw::zDrawParticle": 0x80076bbc,
		"zDrawParticle": 0x80076bbc,
		"JPADraw::zDrawChild": 0x80076dcc,
		"zDrawChild": 0x80076dcc,
		"JPADraw::getMainTextureID": 0x80077020,
		"getMainTextureID": 0x80077020,
		"JPADraw::loadYBBMtx": 0x80077060,
		"loadYBBMtx": 0x80077060,
		"JSystem::__sinit_JPADraw_cpp": 0x80077130,
		"__sinit_JPADraw_cpp": 0x80077130,
		"JPADrawClipBoard::~JPADrawClipBoard": 0x800776ac,
		"JPADrawVisitorContainer::~JPADrawVisitorContainer": 0x800776f0,
		"JPADrawCalcChildScaleOut::~JPADrawCalcChildScaleOut": 0x800782d0,
		"JPADrawCalcChildAlphaOut::~JPADrawCalcChildAlphaOut": 0x8007832c,
		"JPADrawCalcAlphaFlickMultSin::~JPADrawCalcAlphaFlickMultSin": 0x800785f4,
		"JPADrawCalcAlphaFlickAddSin::~JPADrawCalcAlphaFlickAddSin": 0x80078650,
		"JPADrawCalcAlphaFlickNrmSin::~JPADrawCalcAlphaFlickNrmSin": 0x800786ac,
		"JPADrawCalcAlpha::~JPADrawCalcAlpha": 0x80078708,
		"JPADrawCalcColorCopyFromEmitter::~JPADrawCalcColorCopyFromEmitter": 0x800789d0,
		"JPADrawCalcEmitterVisitor::~JPADrawCalcEmitterVisitor": 0x80078b24,
		"JPADrawCalcScaleAnmTimingReverseY::~JPADrawCalcScaleAnmTimingReverseY": 0x80078b70,
		"JPADrawCalcScaleAnmTimingReverseX::~JPADrawCalcScaleAnmTimingReverseX": 0x80078bcc,
		"JPADrawCalcScaleAnmTimingRepeatY::~JPADrawCalcScaleAnmTimingRepeatY": 0x80078c28,
		"JPADrawCalcScaleAnmTimingRepeatX::~JPADrawCalcScaleAnmTimingRepeatX": 0x80078c84,
		"JPADrawCalcScaleAnmTimingNormal::~JPADrawCalcScaleAnmTimingNormal": 0x80078ce0,
		"JPADrawCalcScaleCopyX2Y::~JPADrawCalcScaleCopyX2Y": 0x80078d3c,
		"JPADrawCalcScaleYBySpeed::~JPADrawCalcScaleYBySpeed": 0x80078d98,
		"JPADrawCalcScaleY::~JPADrawCalcScaleY": 0x80078df4,
		"JPADrawCalcScaleXBySpeed::~JPADrawCalcScaleXBySpeed": 0x80078e50,
		"JPADrawCalcScaleX::~JPADrawCalcScaleX": 0x80078eac,
		"JPADrawCalcParticleVisitor::~JPADrawCalcParticleVisitor": 0x80078f08,
		"JPADrawExecStripeCross::~JPADrawExecStripeCross": 0x80078fd0,
		"JPADrawExecStripe::~JPADrawExecStripe": 0x8007902c,
		"JPADrawExecLine::~JPADrawExecLine": 0x80079088,
		"JPADrawExecPoint::~JPADrawExecPoint": 0x800790e4,
		"JPADrawExecRotationCross::~JPADrawExecRotationCross": 0x80079140,
		"JPADrawExecRotation::~JPADrawExecRotation": 0x8007919c,
		"JPADrawExecDirBillBoard::~JPADrawExecDirBillBoard": 0x800791f8,
		"JPADrawExecRotDirectionalCross::~JPADrawExecRotDirectionalCross": 0x80079254,
		"JPADrawExecDirectionalCross::~JPADrawExecDirectionalCross": 0x800792b0,
		"JPADrawExecRotDirectional::~JPADrawExecRotDirectional": 0x8007930c,
		"JPADrawExecDirectional::~JPADrawExecDirectional": 0x80079368,
		"JPADrawExecRotYBillBoard::~JPADrawExecRotYBillBoard": 0x800793c4,
		"JPADrawExecYBillBoard::~JPADrawExecYBillBoard": 0x80079420,
		"JPADrawExecRotBillBoard::~JPADrawExecRotBillBoard": 0x8007947c,
		"JPADrawExecBillBoard::~JPADrawExecBillBoard": 0x800794d8,
		"JPADrawExecLoadExTex::~JPADrawExecLoadExTex": 0x80079534,
		"JPADrawExecLoadDefaultTexture::~JPADrawExecLoadDefaultTexture": 0x8007960c,
		"JPADrawExecRegisterPrmAEnv::~JPADrawExecRegisterPrmAEnv": 0x80079668,
		"JPADrawExecRegisterPrmCEnv::~JPADrawExecRegisterPrmCEnv": 0x800796c4,
		"JPADrawExecRegisterEnvColorAnm::~JPADrawExecRegisterEnvColorAnm": 0x80079720,
		"JPADrawExecRegisterPrmAlphaAnm::~JPADrawExecRegisterPrmAlphaAnm": 0x8007977c,
		"JPADrawExecRegisterPrmColorAnm::~JPADrawExecRegisterPrmColorAnm": 0x800797d8,
		"JPADrawExecRegisterColorChildPE::~JPADrawExecRegisterColorChildPE": 0x80079834,
		"JPADrawExecRegisterColorEmitterE::~JPADrawExecRegisterColorEmitterE": 0x80079890,
		"JPADrawExecRegisterColorEmitterP::~JPADrawExecRegisterColorEmitterP": 0x800798ec,
		"JPADrawExecRegisterColorEmitterPE::~JPADrawExecRegisterColorEmitterPE": 0x80079948,
		"JPADrawExecSetLineWidth::~JPADrawExecSetLineWidth": 0x800799a4,
		"JPADrawExecSetPointSize::~JPADrawExecSetPointSize": 0x80079a00,
		"JPADrawExecParticleVisitor::~JPADrawExecParticleVisitor": 0x80079ad8,
		"JPADrawExecGenIdtMtx::~JPADrawExecGenIdtMtx": 0x80079b24,
		"JPADrawExecGenTexMtx0::~JPADrawExecGenTexMtx0": 0x80079b80,
		"JPADrawExecGenPrjTexMtx::~JPADrawExecGenPrjTexMtx": 0x80079bdc,
		"JPADrawExecGenPrjMtx::~JPADrawExecGenPrjMtx": 0x80079c38,
		"JPADrawExecEmitterVisitor::~JPADrawExecEmitterVisitor": 0x80079c94,
		"JPADrawExecLoadExTex::exec": 0x80079ce0,
		"JPADrawExecGenPrjMtx::exec": 0x80079ed4,
		"JPADrawExecGenPrjTexMtx::exec": 0x80079f84,
		"JPADrawExecGenTexMtx0::exec": 0x8007a130,
		"JPADrawExecGenIdtMtx::exec": 0x8007a178,
		"JPADrawExecLoadDefaultTexture::exec": 0x8007a38c,
		"JPADrawExecSetPointSize::exec": 0x8007a3f8,
		"JPADrawExecSetLineWidth::exec": 0x8007a44c,
		"JPADrawExecRegisterPrmColorAnm::exec": 0x8007a4a0,
		"JPADrawExecRegisterPrmAlphaAnm::exec": 0x8007a57c,
		"JPADrawExecRegisterEnvColorAnm::exec": 0x8007a668,
		"JPADrawExecRegisterPrmCEnv::exec": 0x8007a700,
		"JPADrawExecRegisterPrmAEnv::exec": 0x8007a840,
		"JPADrawExecBillBoard::exec": 0x8007ab80,
		"JPADrawExecRotBillBoard::exec": 0x8007ad58,
		"JPADrawExecYBillBoard::exec": 0x8007af74,
		"JPADrawExecRotYBillBoard::exec": 0x8007b198,
		"JSystem::dirTypeVel": 0x8007b400,
		"dirTypeVel": 0x8007b400,
		"JSystem::dirTypePos": 0x8007b41c,
		"dirTypePos": 0x8007b41c,
		"JSystem::dirTypePosInv": 0x8007b438,
		"dirTypePosInv": 0x8007b438,
		"JSystem::dirTypeEmtrDir": 0x8007b478,
		"dirTypeEmtrDir": 0x8007b478,
		"JSystem::dirTypePrevPtcl": 0x8007b494,
		"dirTypePrevPtcl": 0x8007b494,
		"JSystem::rotTypeY": 0x8007b53c,
		"rotTypeY": 0x8007b53c,
		"JSystem::rotTypeX": 0x8007b57c,
		"rotTypeX": 0x8007b57c,
		"JSystem::rotTypeZ": 0x8007b5bc,
		"rotTypeZ": 0x8007b5bc,
		"JSystem::rotTypeXYZ": 0x8007b5fc,
		"rotTypeXYZ": 0x8007b5fc,
		"JSystem::rotTypeYJiggle": 0x8007b658,
		"rotTypeYJiggle": 0x8007b658,
		"JPADrawExecDirectional::exec": 0x8007b6b0,
		"JPADrawExecRotDirectional::exec": 0x8007bac4,
		"JPADrawExecDirectionalCross::exec": 0x8007bf20,
		"JPADrawExecRotDirectionalCross::exec": 0x8007c478,
		"JPADrawExecDirBillBoard::exec": 0x8007ca18,
		"JPADrawExecRotation::exec": 0x8007cd68,
		"JPADrawExecRotationCross::exec": 0x8007cf90,
		"JPADrawExecPoint::exec": 0x8007d2fc,
		"JPADrawExecLine::exec": 0x8007d388,
		"JSystem::stripeGetNext": 0x8007d548,
		"stripeGetNext": 0x8007d548,
		"JSystem::stripeGetPrev": 0x8007d550,
		"stripeGetPrev": 0x8007d550,
		"JPADrawExecStripe::exec": 0x8007d558,
		"JPADrawExecStripeCross::exec": 0x8007d9c8,
		"JPADrawExecRegisterColorEmitterPE::exec": 0x8007e1b0,
		"JPADrawExecRegisterColorEmitterP::exec": 0x8007e2b4,
		"JPADrawExecRegisterColorEmitterE::exec": 0x8007e354,
		"JPADrawExecRegisterColorChildPE::exec": 0x8007e3dc,
		"JPADrawCalcScaleX::calc": 0x8007e7ec,
		"JPADrawCalcScaleY::calc": 0x8007e890,
		"JPADrawCalcScaleXBySpeed::calc": 0x8007e934,
		"JPADrawCalcScaleYBySpeed::calc": 0x8007ea64,
		"JPADrawCalcScaleCopyX2Y::calc": 0x8007eb94,
		"JPADrawCalcScaleAnmTimingNormal::calc": 0x8007ebcc,
		"JPADrawCalcScaleAnmTimingRepeatX::calc": 0x8007ebdc,
		"JPADrawCalcScaleAnmTimingRepeatY::calc": 0x8007ec48,
		"JPADrawCalcScaleAnmTimingReverseX::calc": 0x8007ecb4,
		"JPADrawCalcScaleAnmTimingReverseY::calc": 0x8007ed54,
		"JPADrawCalcColorCopyFromEmitter::calc": 0x8007eeac,
		"JPADrawCalcAlpha::calc": 0x8007f1bc,
		"JPADrawCalcAlphaFlickNrmSin::calc": 0x8007f240,
		"JPADrawCalcAlphaFlickAddSin::calc": 0x8007f330,
		"JPADrawCalcAlphaFlickMultSin::calc": 0x8007f454,
		"JPADrawCalcChildAlphaOut::calc": 0x8007f8f4,
		"JPADrawCalcChildScaleOut::calc": 0x8007f93c,
		"JPAExTexShape::JPAExTexShape": 0x8007fa94,
		"JPADataBlock::~JPADataBlock": 0x8007fbb4,
		"JPAExTexShape::~JPAExTexShape": 0x8007fc00,
		"JPADataBlock::JPADataBlock": 0x8007fc5c,
		"JPAEmitterLoaderDataBase::load": 0x8007fcdc,
		"JPAEmitterLoader_v10::~JPAEmitterLoader_v10": 0x8007fd60,
		"JPAEmitterLoader_v10::JPAEmitterLoader_v10": 0x8007fdbc,
		"JPAEmitterLoader::~JPAEmitterLoader": 0x8007fdec,
		"JPAEmitterLoader_v10::load": 0x8007fe38,
		"JPAKeyFrameAnime::JPAKeyFrameAnime": 0x80080220,
		"JPAKeyFrameAnime::~JPAKeyFrameAnime": 0x8008025c,
		"JSystem::makeColorTable": 0x800802b8,
		"makeColorTable": 0x800802b8,
		"JPABaseShape::JPABaseShape": 0x80080528,
		"JPABaseShape::~JPABaseShape": 0x80080a88,
		"JPAExtraShape::JPAExtraShape": 0x80080ae4,
		"JPAExtraShape::~JPAExtraShape": 0x80080d98,
		"JPATextureResource::JPATextureResource": 0x80080df4,
		"JPATextureResource::registration": 0x80080e64,
		"registration": 0x80080e64,
		"JPAEmitterResource::getByUserIndex": 0x80080f20,
		"getByUserIndex": 0x80080f20,
		"JPAResourceManager::JPAResourceManager": 0x80080f64,
		"JPASweepShape::JPASweepShape": 0x800810f0,
		"JPASweepShape::~JPASweepShape": 0x8008123c,
		"JPATexture::JPATexture": 0x80081298,
		"JPADefaultTexture::initialize": 0x800812f8,
		"JPATexture::~JPATexture": 0x800817a0,
		"JStage::TAmbientLight::~TAmbientLight": 0x80081818,
		"JStage::TAmbientLight::JSGFGetType": 0x8008187c,
		"JStage::TAmbientLight::JSGGetColor": 0x80081884,
		"JStage::TAmbientLight::JSGSetColor": 0x8008189c,
		"JStage::TCamera::~TCamera": 0x800818a0,
		"JStage::TCamera::JSGFGetType": 0x80081904,
		"JStage::TCamera::JSGGetProjectionType": 0x8008190c,
		"JStage::TCamera::JSGSetProjectionType": 0x80081914,
		"JStage::TCamera::JSGGetProjectionNear": 0x80081918,
		"JStage::TCamera::JSGSetProjectionNear": 0x80081920,
		"JStage::TCamera::JSGGetProjectionFar": 0x80081924,
		"JStage::TCamera::JSGSetProjectionFar": 0x8008192c,
		"JStage::TCamera::JSGGetProjectionFovy": 0x80081930,
		"JStage::TCamera::JSGSetProjectionFovy": 0x80081938,
		"JStage::TCamera::JSGGetProjectionAspect": 0x8008193c,
		"JStage::TCamera::JSGSetProjectionAspect": 0x80081944,
		"JStage::TCamera::JSGGetProjectionField": 0x80081948,
		"JStage::TCamera::JSGSetProjectionField": 0x8008194c,
		"JStage::TCamera::JSGGetViewType": 0x80081950,
		"JSGGetViewType": 0x80081950,
		"JStage::TCamera::JSGSetViewType": 0x80081958,
		"JSGSetViewType": 0x80081958,
		"JStage::TCamera::JSGGetViewPosition": 0x8008195c,
		"JStage::TCamera::JSGSetViewPosition": 0x80081960,
		"JStage::TCamera::JSGGetViewUpVector": 0x80081964,
		"JStage::TCamera::JSGSetViewUpVector": 0x80081968,
		"JStage::TCamera::JSGGetViewTargetPosition": 0x8008196c,
		"JStage::TCamera::JSGSetViewTargetPosition": 0x80081970,
		"JStage::TCamera::JSGGetViewRoll": 0x80081974,
		"JSGGetViewRoll": 0x80081974,
		"JStage::TCamera::JSGSetViewRoll": 0x8008197c,
		"JSGSetViewRoll": 0x8008197c,
		"JStage::TActor::~TActor": 0x80081980,
		"JStage::TActor::JSGFGetType": 0x800819e4,
		"JStage::TActor::JSGGetTranslation": 0x800819ec,
		"JStage::TActor::JSGSetTranslation": 0x800819f0,
		"JStage::TActor::JSGGetScaling": 0x800819f4,
		"JStage::TActor::JSGSetScaling": 0x800819f8,
		"JStage::TActor::JSGGetRotation": 0x800819fc,
		"JStage::TActor::JSGSetRotation": 0x80081a00,
		"JStage::TActor::JSGGetShape": 0x80081a04,
		"JSGGetShape": 0x80081a04,
		"JStage::TActor::JSGSetShape": 0x80081a0c,
		"JSGSetShape": 0x80081a0c,
		"JStage::TActor::JSGGetAnimation": 0x80081a10,
		"JSGGetAnimation": 0x80081a10,
		"JStage::TActor::JSGSetAnimation": 0x80081a18,
		"JSGSetAnimation": 0x80081a18,
		"JStage::TActor::JSGGetAnimationFrame": 0x80081a1c,
		"JSGGetAnimationFrame": 0x80081a1c,
		"JStage::TActor::JSGSetAnimationFrame": 0x80081a24,
		"JSGSetAnimationFrame": 0x80081a24,
		"JStage::TActor::JSGGetAnimationFrameMax": 0x80081a28,
		"JSGGetAnimationFrameMax": 0x80081a28,
		"JStage::TLight::~TLight": 0x80081a30,
		"JStage::TLight::JSGFGetType": 0x80081a94,
		"JStage::TLight::JSGGetLightType": 0x80081a9c,
		"JStage::TLight::JSGSetLightType": 0x80081aa4,
		"JStage::TLight::JSGGetColor": 0x80081aa8,
		"JStage::TLight::JSGSetColor": 0x80081ac0,
		"JStage::TLight::JSGGetDistanceAttenuation": 0x80081ac4,
		"JSGGetDistanceAttenuation": 0x80081ac4,
		"JStage::TLight::JSGSetDistanceAttenuation": 0x80081ac8,
		"JSGSetDistanceAttenuation": 0x80081ac8,
		"JStage::TLight::JSGGetAngleAttenuation": 0x80081acc,
		"JSGGetAngleAttenuation": 0x80081acc,
		"JStage::TLight::JSGSetAngleAttenuation": 0x80081ad0,
		"JSGSetAngleAttenuation": 0x80081ad0,
		"JStage::TLight::JSGGetPosition": 0x80081ad4,
		"JStage::TLight::JSGSetPosition": 0x80081ad8,
		"JStage::TLight::JSGGetDirection": 0x80081adc,
		"JSGGetDirection": 0x80081adc,
		"JStage::TLight::JSGSetDirection": 0x80081ae0,
		"JSGSetDirection": 0x80081ae0,
		"JStage::TObject::~TObject": 0x80081ae4,
		"JStage::TObject::JSGGetName": 0x80081b30,
		"JSGGetName": 0x80081b30,
		"JStage::TObject::JSGGetFlag": 0x80081b38,
		"JStage::TObject::JSGSetFlag": 0x80081b40,
		"JStage::TObject::JSGGetData": 0x80081b44,
		"JSGGetData": 0x80081b44,
		"JStage::TObject::JSGSetData": 0x80081b4c,
		"JSGSetData": 0x80081b4c,
		"JStage::TObject::JSGGetParent": 0x80081b50,
		"JSGGetParent": 0x80081b50,
		"JStage::TObject::JSGSetParent": 0x80081b54,
		"JSGSetParent": 0x80081b54,
		"JStage::TObject::JSGSetRelation": 0x80081b58,
		"JSGSetRelation": 0x80081b58,
		"JStage::TSystem::~TSystem": 0x80081b5c,
		"JStage::TSystem::JSGFGetType": 0x80081bc0,
		"JStage::TSystem::JSGFindObject": 0x80081bc8,
		"JStage::TSystem::JSGCreateObject": 0x80081bd0,
		"JSGCreateObject": 0x80081bd0,
		"JStage::TSystem::JSGDestroyObject": 0x80081bd8,
		"JSGDestroyObject": 0x80081bd8,
		"JStage::TSystem::JSGGetSystemData": 0x80081bdc,
		"JSGGetSystemData": 0x80081bdc,
		"JStage::TSystem::JSGSetSystemData": 0x80081be4,
		"JSGSetSystemData": 0x80081be4,
		"Runtime.PPCEABI.H::__va_arg": 0x800825ec,
		"__va_arg": 0x800825ec,
		"Runtime.PPCEABI.H::__destroy_global_chain": 0x800826e0,
		"__destroy_global_chain": 0x800826e0,
		"Runtime.PPCEABI.H::__register_global_object": 0x80082728,
		"__register_global_object": 0x80082728,
		"Runtime.PPCEABI.H::__destroy_new_array": 0x80082740,
		"__destroy_new_array": 0x80082740,
		"Runtime.PPCEABI.H::__destroy_arr": 0x800827bc,
		"__destroy_arr": 0x800827bc,
		"Runtime.PPCEABI.H::__construct_array": 0x80082834,
		"__construct_array": 0x80082834,
		"__partial_array_destructor::~__partial_array_destructor": 0x80082934,
		"Runtime.PPCEABI.H::__construct_new_array": 0x800829ec,
		"__construct_new_array": 0x800829ec,
		"Runtime.PPCEABI.H::__ptmf_test": 0x80082af4,
		"__ptmf_test": 0x80082af4,
		"Runtime.PPCEABI.H::__ptmf_scall": 0x80082b24,
		"__ptmf_scall": 0x80082b24,
		"Runtime.PPCEABI.H::__unregister_fragment": 0x80082b4c,
		"__unregister_fragment": 0x80082b4c,
		"Runtime.PPCEABI.H::__register_fragment": 0x80082b80,
		"__register_fragment": 0x80082b80,
		"Runtime.PPCEABI.H::__cvt_fp2unsigned": 0x80082bbc,
		"__cvt_fp2unsigned": 0x80082bbc,
		"Runtime.PPCEABI.H::__div2u": 0x80082c18,
		"__div2u": 0x80082c18,
		"Runtime.PPCEABI.H::__div2i": 0x80082d04,
		"__div2i": 0x80082d04,
		"Runtime.PPCEABI.H::__mod2u": 0x80082e3c,
		"__mod2u": 0x80082e3c,
		"Runtime.PPCEABI.H::__mod2i": 0x80082f20,
		"__mod2i": 0x80082f20,
		"Runtime.PPCEABI.H::__shl2i": 0x8008302c,
		"__shl2i": 0x8008302c,
		"Runtime.PPCEABI.H::__shr2u": 0x80083050,
		"__shr2u": 0x80083050,
		"Runtime.PPCEABI.H::__shr2i": 0x80083074,
		"__shr2i": 0x80083074,
		"Runtime.PPCEABI.H::__cvt_sll_flt": 0x8008309c,
		"__cvt_sll_flt": 0x8008309c,
		"Runtime.PPCEABI.H::__cvt_dbl_usll": 0x80083150,
		"__cvt_dbl_usll": 0x80083150,
		"Runtime.PPCEABI.H::GetR2": 0x8008321c,
		"GetR2": 0x8008321c,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions": 0x80083224,
		"__fini_cpp_exceptions": 0x80083224,
		"Runtime.PPCEABI.H::__init_cpp_exceptions": 0x80083258,
		"__init_cpp_exceptions": 0x80083258,
		"MSL_C.PPCEABI.bare.H::exit": 0x80083298,
		"exit": 0x80083298,
		"MSL_C.PPCEABI.bare.H::__num2dec": 0x800833a4,
		"__num2dec": 0x800833a4,
		"MSL_C.PPCEABI.bare.H::__flush_buffer": 0x80083758,
		"__flush_buffer": 0x80083758,
		"MSL_C.PPCEABI.bare.H::__prep_buffer": 0x80083824,
		"__prep_buffer": 0x80083824,
		"MSL_C.PPCEABI.bare.H::__kill_critical_regions": 0x80083858,
		"__kill_critical_regions": 0x80083858,
		"MSL_C.PPCEABI.bare.H::toupper": 0x8008385c,
		"toupper": 0x8008385c,
		"MSL_C.PPCEABI.bare.H::tolower": 0x80083884,
		"tolower": 0x80083884,
		"MSL_C.PPCEABI.bare.H::fwrite": 0x800838ac,
		"fwrite": 0x800838ac,
		"MSL_C.PPCEABI.bare.H::wcstombs": 0x80083b88,
		"wcstombs": 0x80083b88,
		"MSL_C.PPCEABI.bare.H::memcmp": 0x80083bc4,
		"memcmp": 0x80083bc4,
		"MSL_C.PPCEABI.bare.H::memchr": 0x80083c08,
		"memchr": 0x80083c08,
		"MSL_C.PPCEABI.bare.H::memmove": 0x80083c34,
		"memmove": 0x80083c34,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_unaligned": 0x80083d10,
		"__copy_longs_rev_unaligned": 0x80083d10,
		"MSL_C.PPCEABI.bare.H::__copy_longs_unaligned": 0x80083dc0,
		"__copy_longs_unaligned": 0x80083dc0,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_aligned": 0x80083e84,
		"__copy_longs_rev_aligned": 0x80083e84,
		"MSL_C.PPCEABI.bare.H::__copy_longs_aligned": 0x80083f30,
		"__copy_longs_aligned": 0x80083f30,
		"MSL_C.PPCEABI.bare.H::__stdio_atexit": 0x80083fec,
		"__stdio_atexit": 0x80083fec,
		"MSL_C.PPCEABI.bare.H::sprintf": 0x80083ff0,
		"sprintf": 0x80083ff0,
		"MSL_C.PPCEABI.bare.H::snprintf": 0x800840c4,
		"snprintf": 0x800840c4,
		"MSL_C.PPCEABI.bare.H::vsnprintf": 0x80084194,
		"vsnprintf": 0x80084194,
		"MSL_C.PPCEABI.bare.H::vprintf": 0x80084204,
		"vprintf": 0x80084204,
		"MSL_C.PPCEABI.bare.H::__StringWrite": 0x80084280,
		"__StringWrite": 0x80084280,
		"MSL_C.PPCEABI.bare.H::__FileWrite": 0x800842ec,
		"__FileWrite": 0x800842ec,
		"MSL_C.PPCEABI.bare.H::__pformatter": 0x80084344,
		"__pformatter": 0x80084344,
		"MSL_C.PPCEABI.bare.H::float2str": 0x80084974,
		"float2str": 0x80084974,
		"MSL_C.PPCEABI.bare.H::round_decimal": 0x80084fac,
		"round_decimal": 0x80084fac,
		"MSL_C.PPCEABI.bare.H::longlong2str": 0x800850e0,
		"longlong2str": 0x800850e0,
		"MSL_C.PPCEABI.bare.H::long2str": 0x800853c0,
		"long2str": 0x800853c0,
		"MSL_C.PPCEABI.bare.H::parse_format": 0x800855e4,
		"parse_format": 0x800855e4,
		"MSL_C.PPCEABI.bare.H::srand": 0x80085abc,
		"srand": 0x80085abc,
		"MSL_C.PPCEABI.bare.H::rand": 0x80085ac4,
		"rand": 0x80085ac4,
		"MSL_C.PPCEABI.bare.H::__StringRead": 0x80085ae8,
		"__StringRead": 0x80085ae8,
		"MSL_C.PPCEABI.bare.H::strstr": 0x80085b78,
		"strstr": 0x80085b78,
		"MSL_C.PPCEABI.bare.H::strrchr": 0x80085be4,
		"strrchr": 0x80085be4,
		"MSL_C.PPCEABI.bare.H::strchr": 0x80085c2c,
		"strchr": 0x80085c2c,
		"MSL_C.PPCEABI.bare.H::strcmp": 0x80085c5c,
		"strcmp": 0x80085c5c,
		"MSL_C.PPCEABI.bare.H::strcat": 0x80085d80,
		"strcat": 0x80085d80,
		"MSL_C.PPCEABI.bare.H::strncpy": 0x80085dac,
		"strncpy": 0x80085dac,
		"MSL_C.PPCEABI.bare.H::strcpy": 0x80085df0,
		"strcpy": 0x80085df0,
		"MSL_C.PPCEABI.bare.H::strlen": 0x80085ea4,
		"strlen": 0x80085ea4,
		"MSL_C.PPCEABI.bare.H::strtol": 0x80085ec4,
		"strtol": 0x80085ec4,
		"MSL_C.PPCEABI.bare.H::strtoul": 0x80085fb4,
		"strtoul": 0x80085fb4,
		"MSL_C.PPCEABI.bare.H::__strtoul": 0x80086060,
		"__strtoul": 0x80086060,
		"MSL_C.PPCEABI.bare.H::__close_console": 0x800863a8,
		"__close_console": 0x800863a8,
		"MSL_C.PPCEABI.bare.H::__write_console": 0x800863b0,
		"__write_console": 0x800863b0,
		"MSL_C.PPCEABI.bare.H::__read_console": 0x80086448,
		"__read_console": 0x80086448,
		"MSL_C.PPCEABI.bare.H::fwide": 0x80086528,
		"fwide": 0x80086528,
		"MSL_C.PPCEABI.bare.H::fabs": 0x800865a8,
		"fabs": 0x800865a8,
		"MSL_C.PPCEABI.bare.H::__ieee754_atan2": 0x800865b0,
		"__ieee754_atan2": 0x800865b0,
		"MSL_C.PPCEABI.bare.H::frexp": 0x80086a88,
		"frexp": 0x80086a88,
		"MSL_C.PPCEABI.bare.H::atan2": 0x80086b24,
		"atan2": 0x80086b24,
		"MSL_C.PPCEABI.bare.H::fabsf": 0x80086b44,
		"fabsf": 0x80086b44,
		"MSL_C.PPCEABI.bare.H::atanf": 0x80086b4c,
		"atanf": 0x80086b4c,
		"MSL_C.PPCEABI.bare.H::_inv_sqrtf": 0x80086d60,
		"_inv_sqrtf": 0x80086d60,
		"MSL_C.PPCEABI.bare.H::acosf": 0x80086dd0,
		"acosf": 0x80086dd0,
		"MSL_C.PPCEABI.bare.H::atan2f": 0x80086e14,
		"atan2f": 0x80086e14,
		"MSL_C.PPCEABI.bare.H::tanf": 0x80086eec,
		"tanf": 0x80086eec,
		"MSL_C.PPCEABI.bare.H::cos": 0x80086f30,
		"cos": 0x80086f30,
		"MSL_C.PPCEABI.bare.H::sin": 0x80086f50,
		"sin": 0x80086f50,
		"MSL_C.PPCEABI.bare.H::cosf": 0x80086f70,
		"cosf": 0x80086f70,
		"MSL_C.PPCEABI.bare.H::sinf": 0x80087104,
		"sinf": 0x80087104,
		"MSL_C.PPCEABI.bare.H::__sinit_trigf_c": 0x800872a8,
		"__sinit_trigf_c": 0x800872a8,
		"MSL_C.PPCEABI.bare.H::powf": 0x800872d8,
		"powf": 0x800872d8,
		"MSL_C.PPCEABI.bare.H::expf": 0x80087a18,
		"expf": 0x80087a18,
		"TRK_MINNOW_DOLPHIN::TRKHandleRequestEvent": 0x80087b00,
		"TRKHandleRequestEvent": 0x80087b00,
		"TRK_MINNOW_DOLPHIN::TRKHandleSupportEvent": 0x80087b28,
		"TRKHandleSupportEvent": 0x80087b28,
		"TRK_MINNOW_DOLPHIN::TRKIdle": 0x80087b48,
		"TRKIdle": 0x80087b48,
		"TRK_MINNOW_DOLPHIN::TRKNubMainLoop": 0x80087b74,
		"TRKNubMainLoop": 0x80087b74,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEventQueue": 0x80087c68,
		"TRKInitializeEventQueue": 0x80087c68,
		"TRK_MINNOW_DOLPHIN::TRKCopyEvent": 0x80087cc4,
		"TRKCopyEvent": 0x80087cc4,
		"TRK_MINNOW_DOLPHIN::TRKGetNextEvent": 0x80087ce8,
		"TRKGetNextEvent": 0x80087ce8,
		"TRK_MINNOW_DOLPHIN::TRKPostEvent": 0x80087da8,
		"TRKPostEvent": 0x80087da8,
		"TRK_MINNOW_DOLPHIN::TRKConstructEvent": 0x80087e88,
		"TRKConstructEvent": 0x80087e88,
		"TRK_MINNOW_DOLPHIN::TRKDestructEvent": 0x80087ea0,
		"TRKDestructEvent": 0x80087ea0,
		"TRK_MINNOW_DOLPHIN::TRKInitializeNub": 0x80087ec4,
		"TRKInitializeNub": 0x80087ec4,
		"TRK_MINNOW_DOLPHIN::TRKTerminateNub": 0x80087f98,
		"TRKTerminateNub": 0x80087f98,
		"TRK_MINNOW_DOLPHIN::TRKNubWelcome": 0x80087fbc,
		"TRKNubWelcome": 0x80087fbc,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEndian": 0x80087fe4,
		"TRKInitializeEndian": 0x80087fe4,
		"TRK_MINNOW_DOLPHIN::TRKMessageSend": 0x80088058,
		"TRKMessageSend": 0x80088058,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferUsed": 0x80088080,
		"TRKSetBufferUsed": 0x80088080,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMessageBuffers": 0x80088088,
		"TRKInitializeMessageBuffers": 0x80088088,
		"TRK_MINNOW_DOLPHIN::TRKGetFreeBuffer": 0x80088100,
		"TRKGetFreeBuffer": 0x80088100,
		"TRK_MINNOW_DOLPHIN::TRKGetBuffer": 0x8008819c,
		"TRKGetBuffer": 0x8008819c,
		"TRK_MINNOW_DOLPHIN::TRKReleaseBuffer": 0x800881c8,
		"TRKReleaseBuffer": 0x800881c8,
		"TRK_MINNOW_DOLPHIN::TRKResetBuffer": 0x80088230,
		"TRKResetBuffer": 0x80088230,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferPosition": 0x80088270,
		"TRKSetBufferPosition": 0x80088270,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer": 0x800882a0,
		"TRKAppendBuffer": 0x800882a0,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer": 0x80088344,
		"TRKReadBuffer": 0x80088344,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui16": 0x800883d0,
		"TRKAppendBuffer1_ui16": 0x800883d0,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui32": 0x80088424,
		"TRKAppendBuffer1_ui32": 0x80088424,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui64": 0x80088488,
		"TRKAppendBuffer1_ui64": 0x80088488,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui8": 0x80088510,
		"TRKAppendBuffer_ui8": 0x80088510,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui32": 0x80088578,
		"TRKAppendBuffer_ui32": 0x80088578,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui8": 0x800885f4,
		"TRKReadBuffer1_ui8": 0x800885f4,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui16": 0x80088618,
		"TRKReadBuffer1_ui16": 0x80088618,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui32": 0x80088698,
		"TRKReadBuffer1_ui32": 0x80088698,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui64": 0x80088728,
		"TRKReadBuffer1_ui64": 0x80088728,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui8": 0x800887d8,
		"TRKReadBuffer_ui8": 0x800887d8,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui32": 0x8008884c,
		"TRKReadBuffer_ui32": 0x8008884c,
		"TRK_MINNOW_DOLPHIN::TRKTestForPacket": 0x800888c8,
		"TRKTestForPacket": 0x800888c8,
		"TRK_MINNOW_DOLPHIN::TRKGetInput": 0x80088998,
		"TRKGetInput": 0x80088998,
		"TRK_MINNOW_DOLPHIN::TRKProcessInput": 0x80088a14,
		"TRKProcessInput": 0x80088a14,
		"TRK_MINNOW_DOLPHIN::TRKInitializeSerialHandler": 0x80088a64,
		"TRKInitializeSerialHandler": 0x80088a64,
		"TRK_MINNOW_DOLPHIN::TRKTerminateSerialHandler": 0x80088a88,
		"TRKTerminateSerialHandler": 0x80088a88,
		"TRK_MINNOW_DOLPHIN::usr_put_initialize": 0x80088a90,
		"usr_put_initialize": 0x80088a90,
		"TRK_MINNOW_DOLPHIN::TRKInitializeDispatcher": 0x80088a94,
		"TRKInitializeDispatcher": 0x80088a94,
		"TRK_MINNOW_DOLPHIN::TRKDispatchMessage": 0x80088aa8,
		"TRKDispatchMessage": 0x80088aa8,
		"TRK_MINNOW_DOLPHIN::TRKMessageIntoReply": 0x80088b2c,
		"TRKMessageIntoReply": 0x80088b2c,
		"TRK_MINNOW_DOLPHIN::TRKSendACK": 0x80088bc4,
		"TRKSendACK": 0x80088bc4,
		"TRK_MINNOW_DOLPHIN::TRKStandardACK": 0x80088c14,
		"TRKStandardACK": 0x80088c14,
		"TRK_MINNOW_DOLPHIN::TRKDoUnsupported": 0x80088c48,
		"TRKDoUnsupported": 0x80088c48,
		"TRK_MINNOW_DOLPHIN::TRKDoConnect": 0x80088c70,
		"TRKDoConnect": 0x80088c70,
		"TRK_MINNOW_DOLPHIN::TRKDoDisconnect": 0x80088c98,
		"TRKDoDisconnect": 0x80088c98,
		"TRK_MINNOW_DOLPHIN::TRKDoReset": 0x80088ce8,
		"TRKDoReset": 0x80088ce8,
		"TRK_MINNOW_DOLPHIN::TRKDoVersions": 0x80088d18,
		"TRKDoVersions": 0x80088d18,
		"TRK_MINNOW_DOLPHIN::TRKDoSupportMask": 0x80088e9c,
		"TRKDoSupportMask": 0x80088e9c,
		"TRK_MINNOW_DOLPHIN::TRKDoCPUType": 0x80088f78,
		"TRKDoCPUType": 0x80088f78,
		"TRK_MINNOW_DOLPHIN::TRKDoReadMemory": 0x800891bc,
		"TRKDoReadMemory": 0x800891bc,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteMemory": 0x800893a4,
		"TRKDoWriteMemory": 0x800893a4,
		"TRK_MINNOW_DOLPHIN::TRKDoReadRegisters": 0x800895a0,
		"TRKDoReadRegisters": 0x800895a0,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteRegisters": 0x800897a4,
		"TRKDoWriteRegisters": 0x800897a4,
		"TRK_MINNOW_DOLPHIN::TRKDoFlushCache": 0x800899ac,
		"TRKDoFlushCache": 0x800899ac,
		"TRK_MINNOW_DOLPHIN::TRKDoContinue": 0x80089ae4,
		"TRKDoContinue": 0x80089ae4,
		"TRK_MINNOW_DOLPHIN::TRKDoStep": 0x80089b48,
		"TRKDoStep": 0x80089b48,
		"TRK_MINNOW_DOLPHIN::TRKDoStop": 0x80089d4c,
		"TRKDoStop": 0x80089d4c,
		"TRK_MINNOW_DOLPHIN::TRKSuppAccessFile": 0x80089dd0,
		"TRKSuppAccessFile": 0x80089dd0,
		"TRK_MINNOW_DOLPHIN::TRKRequestSend": 0x8008a0a8,
		"TRKRequestSend": 0x8008a0a8,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMutex": 0x8008a24c,
		"TRKInitializeMutex": 0x8008a24c,
		"TRK_MINNOW_DOLPHIN::TRKAcquireMutex": 0x8008a254,
		"TRKAcquireMutex": 0x8008a254,
		"TRK_MINNOW_DOLPHIN::TRKReleaseMutex": 0x8008a25c,
		"TRKReleaseMutex": 0x8008a25c,
		"TRK_MINNOW_DOLPHIN::TRKDoNotifyStopped": 0x8008a264,
		"TRKDoNotifyStopped": 0x8008a264,
		"TRK_MINNOW_DOLPHIN::TRK_flush_cache": 0x8008a33c,
		"TRK_flush_cache": 0x8008a33c,
		"TRK_MINNOW_DOLPHIN::TRK_fill_mem": 0x8008a374,
		"TRK_fill_mem": 0x8008a374,
		"TRK_MINNOW_DOLPHIN::__TRK_get_MSR": 0x8008a438,
		"__TRK_get_MSR": 0x8008a438,
		"TRK_MINNOW_DOLPHIN::__TRK_set_MSR": 0x8008a440,
		"__TRK_set_MSR": 0x8008a440,
		"TRK_MINNOW_DOLPHIN::TRKValidMemory32": 0x8008a448,
		"TRKValidMemory32": 0x8008a448,
		"TRK_MINNOW_DOLPHIN::TRK_ppc_memcpy": 0x8008a580,
		"TRK_ppc_memcpy": 0x8008a580,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessMemory": 0x8008a5bc,
		"TRKTargetAccessMemory": 0x8008a5bc,
		"TRK_MINNOW_DOLPHIN::TRKTargetReadInstruction": 0x8008a720,
		"TRKTargetReadInstruction": 0x8008a720,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessDefault": 0x8008a76c,
		"TRKTargetAccessDefault": 0x8008a76c,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessFP": 0x8008a868,
		"TRKTargetAccessFP": 0x8008a868,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended1": 0x8008a9b0,
		"TRKTargetAccessExtended1": 0x8008a9b0,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended2": 0x8008ab28,
		"TRKTargetAccessExtended2": 0x8008ab28,
		"TRK_MINNOW_DOLPHIN::TRKTargetVersions": 0x8008aca4,
		"TRKTargetVersions": 0x8008aca4,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportMask": 0x8008accc,
		"TRKTargetSupportMask": 0x8008accc,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUType": 0x8008ad70,
		"TRKTargetCPUType": 0x8008ad70,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandler": 0x8008add8,
		"TRKInterruptHandler": 0x8008add8,
		"TRK_MINNOW_DOLPHIN::TRKExceptionHandler": 0x8008af6c,
		"TRKExceptionHandler": 0x8008af6c,
		"TRK_MINNOW_DOLPHIN::TRKPostInterruptEvent": 0x8008b008,
		"TRKPostInterruptEvent": 0x8008b008,
		"TRK_MINNOW_DOLPHIN::TRKSwapAndGo": 0x8008b0b8,
		"TRKSwapAndGo": 0x8008b0b8,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandlerEnableInterrupts": 0x8008b17c,
		"TRKInterruptHandlerEnableInterrupts": 0x8008b17c,
		"TRK_MINNOW_DOLPHIN::TRKTargetInterrupt": 0x8008b1d0,
		"TRKTargetInterrupt": 0x8008b1d0,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddStopInfo": 0x8008b234,
		"TRKTargetAddStopInfo": 0x8008b234,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddExceptionInfo": 0x8008b2c4,
		"TRKTargetAddExceptionInfo": 0x8008b2c4,
		"TRK_MINNOW_DOLPHIN::TRKTargetEnableTrace": 0x8008b34c,
		"TRKTargetEnableTrace": 0x8008b34c,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepDone": 0x8008b388,
		"TRKTargetStepDone": 0x8008b388,
		"TRK_MINNOW_DOLPHIN::TRKTargetDoStep": 0x8008b40c,
		"TRKTargetDoStep": 0x8008b40c,
		"TRK_MINNOW_DOLPHIN::TRKTargetCheckStep": 0x8008b47c,
		"TRKTargetCheckStep": 0x8008b47c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSingleStep": 0x8008b4e4,
		"TRKTargetSingleStep": 0x8008b4e4,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepOutOfRange": 0x8008b528,
		"TRKTargetStepOutOfRange": 0x8008b528,
		"TRK_MINNOW_DOLPHIN::TRKTargetGetPC": 0x8008b570,
		"TRKTargetGetPC": 0x8008b570,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportRequest": 0x8008b580,
		"TRKTargetSupportRequest": 0x8008b580,
		"TRK_MINNOW_DOLPHIN::TRKTargetFlushCache": 0x8008b670,
		"TRKTargetFlushCache": 0x8008b670,
		"TRK_MINNOW_DOLPHIN::TRKTargetStopped": 0x8008b6ac,
		"TRKTargetStopped": 0x8008b6ac,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetStopped": 0x8008b6bc,
		"TRKTargetSetStopped": 0x8008b6bc,
		"TRK_MINNOW_DOLPHIN::TRKTargetStop": 0x8008b6cc,
		"TRKTargetStop": 0x8008b6cc,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSPR": 0x8008b6f4,
		"TRKPPCAccessSPR": 0x8008b6f4,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessPairedSingleRegister": 0x8008b7a4,
		"TRKPPCAccessPairedSingleRegister": 0x8008b7a4,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessFPRegister": 0x8008b81c,
		"TRKPPCAccessFPRegister": 0x8008b81c,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSpecialReg": 0x8008b99c,
		"TRKPPCAccessSpecialReg": 0x8008b99c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetInputPendingPtr": 0x8008ba04,
		"TRKTargetSetInputPendingPtr": 0x8008ba04,
		"TRK_MINNOW_DOLPHIN::InitMetroTRK": 0x8008ba14,
		"InitMetroTRK": 0x8008ba14,
		"TRK_MINNOW_DOLPHIN::EnableMetroTRKInterrupts": 0x8008baa8,
		"EnableMetroTRKInterrupts": 0x8008baa8,
		"TRK_MINNOW_DOLPHIN::TRKTargetTranslate": 0x8008bac8,
		"TRKTargetTranslate": 0x8008bac8,
		"TRK_MINNOW_DOLPHIN::TRK_copy_vector": 0x8008bb10,
		"TRK_copy_vector": 0x8008bb10,
		"TRK_MINNOW_DOLPHIN::__TRK_copy_vectors": 0x8008bb70,
		"__TRK_copy_vectors": 0x8008bb70,
		"TRK_MINNOW_DOLPHIN::TRKInitializeTarget": 0x8008bc04,
		"TRKInitializeTarget": 0x8008bc04,
		"TRK_MINNOW_DOLPHIN::TRKSaveExtended1Block": 0x8008bc54,
		"TRKSaveExtended1Block": 0x8008bc54,
		"TRK_MINNOW_DOLPHIN::TRKRestoreExtended1Block": 0x8008be0c,
		"TRKRestoreExtended1Block": 0x8008be0c,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUMinorType": 0x8008bfc4,
		"TRKTargetCPUMinorType": 0x8008bfc4,
		"TRK_MINNOW_DOLPHIN::TRK_main": 0x8008bfcc,
		"TRK_main": 0x8008bfcc,
		"TRK_MINNOW_DOLPHIN::TRKLoadContext": 0x8008c014,
		"TRKLoadContext": 0x8008c014,
		"TRK_MINNOW_DOLPHIN::TRKEXICallBack": 0x8008c09c,
		"TRKEXICallBack": 0x8008c09c,
		"TRK_MINNOW_DOLPHIN::InitMetroTRKCommTable": 0x8008c0d4,
		"InitMetroTRKCommTable": 0x8008c0d4,
		"TRK_MINNOW_DOLPHIN::TRKUARTInterruptHandler": 0x8008c1bc,
		"TRKUARTInterruptHandler": 0x8008c1bc,
		"TRK_MINNOW_DOLPHIN::TRKInitializeIntDrivenUART": 0x8008c1c0,
		"TRKInitializeIntDrivenUART": 0x8008c1c0,
		"TRK_MINNOW_DOLPHIN::EnableEXI2Interrupts": 0x8008c200,
		"EnableEXI2Interrupts": 0x8008c200,
		"TRK_MINNOW_DOLPHIN::TRKPollUART": 0x8008c230,
		"TRKPollUART": 0x8008c230,
		"TRK_MINNOW_DOLPHIN::TRKReadUARTN": 0x8008c260,
		"TRKReadUARTN": 0x8008c260,
		"TRK_MINNOW_DOLPHIN::TRKWriteUARTN": 0x8008c2a4,
		"TRKWriteUARTN": 0x8008c2a4,
		"TRK_MINNOW_DOLPHIN::ReserveEXI2Port": 0x8008c2e8,
		"ReserveEXI2Port": 0x8008c2e8,
		"TRK_MINNOW_DOLPHIN::UnreserveEXI2Port": 0x8008c318,
		"UnreserveEXI2Port": 0x8008c318,
		"TRK_MINNOW_DOLPHIN::TRK_board_display": 0x8008c348,
		"TRK_board_display": 0x8008c348,
		"TRK_MINNOW_DOLPHIN::TRKTargetContinue": 0x8008c36c,
		"TRKTargetContinue": 0x8008c36c,
		"base::PPCMfmsr": 0x8008c3a0,
		"PPCMfmsr": 0x8008c3a0,
		"base::PPCMtmsr": 0x8008c3a8,
		"PPCMtmsr": 0x8008c3a8,
		"base::PPCMfhid0": 0x8008c3b0,
		"PPCMfhid0": 0x8008c3b0,
		"base::PPCMthid0": 0x8008c3b8,
		"PPCMthid0": 0x8008c3b8,
		"base::PPCMfl2cr": 0x8008c3c0,
		"PPCMfl2cr": 0x8008c3c0,
		"base::PPCMtl2cr": 0x8008c3c8,
		"PPCMtl2cr": 0x8008c3c8,
		"base::PPCMtdec": 0x8008c3d0,
		"PPCMtdec": 0x8008c3d0,
		"base::PPCSync": 0x8008c3d8,
		"PPCSync": 0x8008c3d8,
		"base::PPCHalt": 0x8008c3e0,
		"PPCHalt": 0x8008c3e0,
		"base::PPCMfhid2": 0x8008c3f4,
		"PPCMfhid2": 0x8008c3f4,
		"base::PPCMthid2": 0x8008c3fc,
		"PPCMthid2": 0x8008c3fc,
		"base::PPCMtwpar": 0x8008c404,
		"PPCMtwpar": 0x8008c404,
		"base::PPCDisableSpeculation": 0x8008c40c,
		"PPCDisableSpeculation": 0x8008c40c,
		"base::PPCSetFpNonIEEEMode": 0x8008c434,
		"PPCSetFpNonIEEEMode": 0x8008c434,
		"db::DBInit": 0x8008c43c,
		"DBInit": 0x8008c43c,
		"db::__DBExceptionDestinationAux": 0x8008c464,
		"__DBExceptionDestinationAux": 0x8008c464,
		"db::__DBExceptionDestination": 0x8008c4ac,
		"__DBExceptionDestination": 0x8008c4ac,
		"db::__DBIsExceptionMarked": 0x8008c4bc,
		"__DBIsExceptionMarked": 0x8008c4bc,
		"db::DBPrintf": 0x8008c4d8,
		"DBPrintf": 0x8008c4d8,
		"os::OSGetConsoleType": 0x8008c528,
		"OSGetConsoleType": 0x8008c528,
		"os::ClearArena": 0x8008c550,
		"ClearArena": 0x8008c550,
		"os::InquiryCallback": 0x8008c678,
		"InquiryCallback": 0x8008c678,
		"os::OSInit": 0x8008c6b4,
		"OSInit": 0x8008c6b4,
		"os::OSExceptionInit": 0x8008ca6c,
		"OSExceptionInit": 0x8008ca6c,
		"os::__OSDBIntegrator": 0x8008ccec,
		"__OSDBIntegrator": 0x8008ccec,
		"os::__OSDBJump": 0x8008cd10,
		"__OSDBJump": 0x8008cd10,
		"os::__OSSetExceptionHandler": 0x8008cd14,
		"__OSSetExceptionHandler": 0x8008cd14,
		"os::__OSGetExceptionHandler": 0x8008cd30,
		"__OSGetExceptionHandler": 0x8008cd30,
		"os::OSExceptionVector": 0x8008cd44,
		"OSExceptionVector": 0x8008cd44,
		"os::OSDefaultExceptionHandler": 0x8008cde0,
		"OSDefaultExceptionHandler": 0x8008cde0,
		"os::__OSPSInit": 0x8008ce38,
		"__OSPSInit": 0x8008ce38,
		"os::__OSGetDIConfig": 0x8008ce70,
		"__OSGetDIConfig": 0x8008ce70,
		"os::OSInitAlarm": 0x8008ce84,
		"OSInitAlarm": 0x8008ce84,
		"os::OSCreateAlarm": 0x8008ced0,
		"OSCreateAlarm": 0x8008ced0,
		"os::InsertAlarm": 0x8008cedc,
		"InsertAlarm": 0x8008cedc,
		"os::OSSetAlarm": 0x8008d12c,
		"OSSetAlarm": 0x8008d12c,
		"os::OSCancelAlarm": 0x8008d194,
		"OSCancelAlarm": 0x8008d194,
		"os::DecrementerExceptionCallback": 0x8008d2b0,
		"DecrementerExceptionCallback": 0x8008d2b0,
		"os::DecrementerExceptionHandler": 0x8008d4e0,
		"DecrementerExceptionHandler": 0x8008d4e0,
		"os::DLInsert": 0x8008d530,
		"DLInsert": 0x8008d530,
		"os::OSAllocFromHeap": 0x8008d5dc,
		"OSAllocFromHeap": 0x8008d5dc,
		"os::OSFreeToHeap": 0x8008d6d8,
		"OSFreeToHeap": 0x8008d6d8,
		"os::OSInitAlloc": 0x8008d754,
		"OSInitAlloc": 0x8008d754,
		"os::OSCreateHeap": 0x8008d7c4,
		"OSCreateHeap": 0x8008d7c4,
		"os::OSDestroyHeap": 0x8008d830,
		"OSDestroyHeap": 0x8008d830,
		"os::OSCheckHeap": 0x8008d844,
		"OSCheckHeap": 0x8008d844,
		"os::OSReferentSize": 0x8008dba4,
		"OSReferentSize": 0x8008dba4,
		"os::OSDumpHeap": 0x8008dbb0,
		"OSDumpHeap": 0x8008dbb0,
		"os::OSGetArenaHi": 0x8008dcb4,
		"OSGetArenaHi": 0x8008dcb4,
		"os::OSGetArenaLo": 0x8008dcbc,
		"OSGetArenaLo": 0x8008dcbc,
		"os::OSSetArenaHi": 0x8008dcc4,
		"OSSetArenaHi": 0x8008dcc4,
		"os::OSSetArenaLo": 0x8008dccc,
		"OSSetArenaLo": 0x8008dccc,
		"os::__OSInitAudioSystem": 0x8008dcd4,
		"__OSInitAudioSystem": 0x8008dcd4,
		"os::__OSStopAudioSystem": 0x8008de90,
		"__OSStopAudioSystem": 0x8008de90,
		"os::DCEnable": 0x8008df68,
		"DCEnable": 0x8008df68,
		"os::DCInvalidateRange": 0x8008df7c,
		"DCInvalidateRange": 0x8008df7c,
		"os::DCFlushRange": 0x8008dfac,
		"DCFlushRange": 0x8008dfac,
		"os::DCStoreRange": 0x8008dfe0,
		"DCStoreRange": 0x8008dfe0,
		"os::DCFlushRangeNoSync": 0x8008e014,
		"DCFlushRangeNoSync": 0x8008e014,
		"os::DCZeroRange": 0x8008e044,
		"DCZeroRange": 0x8008e044,
		"os::ICInvalidateRange": 0x8008e074,
		"ICInvalidateRange": 0x8008e074,
		"os::ICFlashInvalidate": 0x8008e0ac,
		"ICFlashInvalidate": 0x8008e0ac,
		"os::ICEnable": 0x8008e0bc,
		"ICEnable": 0x8008e0bc,
		"os::__LCEnable": 0x8008e0d0,
		"__LCEnable": 0x8008e0d0,
		"os::LCEnable": 0x8008e19c,
		"LCEnable": 0x8008e19c,
		"os::LCDisable": 0x8008e1d4,
		"LCDisable": 0x8008e1d4,
		"os::LCStoreBlocks": 0x8008e1fc,
		"LCStoreBlocks": 0x8008e1fc,
		"os::LCStoreData": 0x8008e220,
		"LCStoreData": 0x8008e220,
		"os::LCQueueWait": 0x8008e2cc,
		"LCQueueWait": 0x8008e2cc,
		"os::L2GlobalInvalidate": 0x8008e2e4,
		"L2GlobalInvalidate": 0x8008e2e4,
		"os::DMAErrorHandler": 0x8008e37c,
		"DMAErrorHandler": 0x8008e37c,
		"os::__OSCacheInit": 0x8008e4dc,
		"__OSCacheInit": 0x8008e4dc,
		"os::__OSLoadFPUContext": 0x8008e5d0,
		"__OSLoadFPUContext": 0x8008e5d0,
		"os::__OSSaveFPUContext": 0x8008e6f4,
		"__OSSaveFPUContext": 0x8008e6f4,
		"os::OSSetCurrentContext": 0x8008e81c,
		"OSSetCurrentContext": 0x8008e81c,
		"os::OSGetCurrentContext": 0x8008e878,
		"OSGetCurrentContext": 0x8008e878,
		"os::OSSaveContext": 0x8008e884,
		"OSSaveContext": 0x8008e884,
		"os::OSLoadContext": 0x8008e904,
		"OSLoadContext": 0x8008e904,
		"os::OSGetStackPointer": 0x8008e9dc,
		"OSGetStackPointer": 0x8008e9dc,
		"os::OSClearContext": 0x8008e9e4,
		"OSClearContext": 0x8008e9e4,
		"os::OSInitContext": 0x8008ea08,
		"OSInitContext": 0x8008ea08,
		"os::OSDumpContext": 0x8008eac4,
		"OSDumpContext": 0x8008eac4,
		"os::OSSwitchFPUContext": 0x8008ed6c,
		"OSSwitchFPUContext": 0x8008ed6c,
		"os::__OSContextInit": 0x8008edf0,
		"__OSContextInit": 0x8008edf0,
		"os::OSFillFPUContext": 0x8008ee38,
		"OSFillFPUContext": 0x8008ee38,
		"os::OSReport": 0x8008ef64,
		"OSReport": 0x8008ef64,
		"os::OSPanic": 0x8008efe4,
		"OSPanic": 0x8008efe4,
		"os::OSSetErrorHandler": 0x8008f110,
		"OSSetErrorHandler": 0x8008f110,
		"os::__OSUnhandledException": 0x8008f12c,
		"__OSUnhandledException": 0x8008f12c,
		"os::GetFontCode": 0x8008f32c,
		"GetFontCode": 0x8008f32c,
		"os::Decode": 0x8008f4c8,
		"Decode": 0x8008f4c8,
		"os::OSGetFontEncode": 0x8008f63c,
		"OSGetFontEncode": 0x8008f63c,
		"os::ReadROM": 0x8008f694,
		"ReadROM": 0x8008f694,
		"os::OSLoadFont": 0x8008f720,
		"OSLoadFont": 0x8008f720,
		"os::ExpandFontSheet": 0x8008fa54,
		"ExpandFontSheet": 0x8008fa54,
		"os::OSInitFont": 0x8008fe04,
		"OSInitFont": 0x8008fe04,
		"os::OSGetFontTexture": 0x8008fee4,
		"OSGetFontTexture": 0x8008fee4,
		"os::OSGetFontWidth": 0x8009008c,
		"OSGetFontWidth": 0x8009008c,
		"os::OSDisableInterrupts": 0x800901cc,
		"OSDisableInterrupts": 0x800901cc,
		"os::OSEnableInterrupts": 0x800901e0,
		"OSEnableInterrupts": 0x800901e0,
		"os::OSRestoreInterrupts": 0x800901f4,
		"OSRestoreInterrupts": 0x800901f4,
		"os::__OSSetInterruptHandler": 0x80090218,
		"__OSSetInterruptHandler": 0x80090218,
		"os::__OSGetInterruptHandler": 0x80090234,
		"__OSGetInterruptHandler": 0x80090234,
		"os::__OSInterruptInit": 0x80090248,
		"__OSInterruptInit": 0x80090248,
		"os::SetInterruptMask": 0x800902bc,
		"SetInterruptMask": 0x800902bc,
		"os::__OSMaskInterrupts": 0x80090594,
		"__OSMaskInterrupts": 0x80090594,
		"os::__OSUnmaskInterrupts": 0x8009061c,
		"__OSUnmaskInterrupts": 0x8009061c,
		"os::__OSDispatchInterrupt": 0x800906a4,
		"__OSDispatchInterrupt": 0x800906a4,
		"os::ExternalInterruptHandler": 0x800909e8,
		"ExternalInterruptHandler": 0x800909e8,
		"os::__OSModuleInit": 0x80090a38,
		"__OSModuleInit": 0x80090a38,
		"os::OSInitMessageQueue": 0x80090a50,
		"OSInitMessageQueue": 0x80090a50,
		"os::OSSendMessage": 0x80090ab0,
		"OSSendMessage": 0x80090ab0,
		"os::OSReceiveMessage": 0x80090b78,
		"OSReceiveMessage": 0x80090b78,
		"os::OnReset": 0x80090c54,
		"os::MEMIntrruptHandler": 0x80090c90,
		"MEMIntrruptHandler": 0x80090c90,
		"os::OSProtectRange": 0x80090cfc,
		"OSProtectRange": 0x80090cfc,
		"os::Config24MB": 0x80090dc0,
		"Config24MB": 0x80090dc0,
		"os::Config48MB": 0x80090e40,
		"Config48MB": 0x80090e40,
		"os::RealMode": 0x80090ec0,
		"RealMode": 0x80090ec0,
		"os::__OSInitMemoryProtection": 0x80090ed8,
		"__OSInitMemoryProtection": 0x80090ed8,
		"os::OSInitMutex": 0x80090ff8,
		"OSInitMutex": 0x80090ff8,
		"os::OSLockMutex": 0x80091030,
		"OSLockMutex": 0x80091030,
		"os::OSUnlockMutex": 0x8009110c,
		"OSUnlockMutex": 0x8009110c,
		"os::__OSUnlockAllMutex": 0x800911d4,
		"__OSUnlockAllMutex": 0x800911d4,
		"os::OSTryLockMutex": 0x80091244,
		"OSTryLockMutex": 0x80091244,
		"os::OSInitCond": 0x80091300,
		"OSInitCond": 0x80091300,
		"os::OSWaitCond": 0x80091320,
		"OSWaitCond": 0x80091320,
		"os::OSSignalCond": 0x800913f4,
		"OSSignalCond": 0x800913f4,
		"os::Run": 0x80091414,
		"Run": 0x80091414,
		"os::Callback": 0x80091454,
		"os::__OSReboot": 0x80091460,
		"__OSReboot": 0x80091460,
		"os::OSRegisterResetFunction": 0x80091620,
		"OSRegisterResetFunction": 0x80091620,
		"os::Reset": 0x800916a4,
		"Reset": 0x800916a4,
		"os::__OSDoHotReset": 0x80091714,
		"__OSDoHotReset": 0x80091714,
		"os::OSResetSystem": 0x8009175c,
		"OSResetSystem": 0x8009175c,
		"os::OSGetResetCode": 0x800919d4,
		"OSGetResetCode": 0x800919d4,
		"os::__OSResetSWInterruptHandler": 0x80091a04,
		"__OSResetSWInterruptHandler": 0x80091a04,
		"os::OSGetResetButtonState": 0x80091af8,
		"OSGetResetButtonState": 0x80091af8,
		"os::OSGetResetSwitchState": 0x80091d90,
		"OSGetResetSwitchState": 0x80091d90,
		"os::WriteSramCallback": 0x80091db0,
		"WriteSramCallback": 0x80091db0,
		"os::WriteSram": 0x80091e10,
		"WriteSram": 0x80091e10,
		"os::__OSInitSram": 0x80091f28,
		"__OSInitSram": 0x80091f28,
		"os::__OSLockSram": 0x8009205c,
		"__OSLockSram": 0x8009205c,
		"os::__OSLockSramEx": 0x800920b8,
		"__OSLockSramEx": 0x800920b8,
		"os::UnlockSram": 0x80092114,
		"UnlockSram": 0x80092114,
		"os::__OSUnlockSram": 0x8009241c,
		"__OSUnlockSram": 0x8009241c,
		"os::__OSUnlockSramEx": 0x80092440,
		"__OSUnlockSramEx": 0x80092440,
		"os::__OSSyncSram": 0x80092464,
		"__OSSyncSram": 0x80092464,
		"os::__OSReadROM": 0x80092474,
		"__OSReadROM": 0x80092474,
		"os::OSGetSoundMode": 0x80092598,
		"OSGetSoundMode": 0x80092598,
		"os::OSSetSoundMode": 0x80092618,
		"OSSetSoundMode": 0x80092618,
		"os::OSGetProgressiveMode": 0x800926bc,
		"OSGetProgressiveMode": 0x800926bc,
		"os::OSSetProgressiveMode": 0x8009272c,
		"OSSetProgressiveMode": 0x8009272c,
		"os::OSGetWirelessID": 0x800927d0,
		"OSGetWirelessID": 0x800927d0,
		"os::OSSetWirelessID": 0x80092854,
		"OSSetWirelessID": 0x80092854,
		"os::OSInitStopwatch": 0x80092900,
		"OSInitStopwatch": 0x80092900,
		"os::OSStartStopwatch": 0x8009292c,
		"OSStartStopwatch": 0x8009292c,
		"os::OSStopStopwatch": 0x80092968,
		"OSStopStopwatch": 0x80092968,
		"os::OSCheckStopwatch": 0x80092a34,
		"OSCheckStopwatch": 0x80092a34,
		"os::OSResetStopwatch": 0x80092aa4,
		"OSResetStopwatch": 0x80092aa4,
		"os::SystemCallVector": 0x80092acc,
		"SystemCallVector": 0x80092acc,
		"os::__OSInitSystemCall": 0x80092aec,
		"__OSInitSystemCall": 0x80092aec,
		"os::__OSThreadInit": 0x80092b50,
		"__OSThreadInit": 0x80092b50,
		"os::OSInitThreadQueue": 0x80092c78,
		"OSInitThreadQueue": 0x80092c78,
		"os::OSGetCurrentThread": 0x80092c88,
		"OSGetCurrentThread": 0x80092c88,
		"os::OSIsThreadTerminated": 0x80092c94,
		"OSIsThreadTerminated": 0x80092c94,
		"os::OSDisableScheduler": 0x80092cc8,
		"OSDisableScheduler": 0x80092cc8,
		"os::OSEnableScheduler": 0x80092d08,
		"OSEnableScheduler": 0x80092d08,
		"os::UnsetRun": 0x80092d48,
		"UnsetRun": 0x80092d48,
		"os::__OSGetEffectivePriority": 0x80092db0,
		"__OSGetEffectivePriority": 0x80092db0,
		"os::SetEffectivePriority": 0x80092dec,
		"SetEffectivePriority": 0x80092dec,
		"os::__OSPromoteThread": 0x80092fac,
		"__OSPromoteThread": 0x80092fac,
		"os::SelectThread": 0x80092ffc,
		"SelectThread": 0x80092ffc,
		"os::__OSReschedule": 0x800931fc,
		"__OSReschedule": 0x800931fc,
		"os::OSYieldThread": 0x8009322c,
		"OSYieldThread": 0x8009322c,
		"os::OSCreateThread": 0x80093268,
		"OSCreateThread": 0x80093268,
		"os::OSExitThread": 0x80093388,
		"OSExitThread": 0x80093388,
		"os::OSCancelThread": 0x8009346c,
		"OSCancelThread": 0x8009346c,
		"os::OSJoinThread": 0x80093628,
		"OSJoinThread": 0x80093628,
		"os::OSDetachThread": 0x80093768,
		"OSDetachThread": 0x80093768,
		"os::OSResumeThread": 0x80093808,
		"OSResumeThread": 0x80093808,
		"os::OSSuspendThread": 0x80093a90,
		"OSSuspendThread": 0x80093a90,
		"os::OSSleepThread": 0x80093c00,
		"OSSleepThread": 0x80093c00,
		"os::OSWakeupThread": 0x80093cec,
		"OSWakeupThread": 0x80093cec,
		"os::OSGetThreadPriority": 0x80093df0,
		"OSGetThreadPriority": 0x80093df0,
		"os::OSGetTime": 0x80093df8,
		"OSGetTime": 0x80093df8,
		"os::OSGetTick": 0x80093e10,
		"OSGetTick": 0x80093e10,
		"os::__OSGetSystemTime": 0x80093e18,
		"__OSGetSystemTime": 0x80093e18,
		"os::GetDates": 0x80093e7c,
		"GetDates": 0x80093e7c,
		"os::OSTicksToCalendarTime": 0x80094018,
		"OSTicksToCalendarTime": 0x80094018,
		"os::__init_user": 0x8009421c,
		"__init_user": 0x8009421c,
		"os::__init_cpp": 0x8009423c,
		"__init_cpp": 0x8009423c,
		"os::_ExitProcess": 0x80094290,
		"_ExitProcess": 0x80094290,
		"mtx::PSMTXIdentity": 0x800942b0,
		"PSMTXIdentity": 0x800942b0,
		"mtx::PSMTXCopy": 0x800942dc,
		"PSMTXCopy": 0x800942dc,
		"mtx::PSMTXConcat": 0x80094310,
		"PSMTXConcat": 0x80094310,
		"mtx::PSMTXInverse": 0x800943dc,
		"PSMTXInverse": 0x800943dc,
		"mtx::PSMTXRotRad": 0x800944d4,
		"PSMTXRotRad": 0x800944d4,
		"mtx::PSMTXRotTrig": 0x80094544,
		"PSMTXRotTrig": 0x80094544,
		"mtx::PSMTXRotAxisRad": 0x800945ec,
		"PSMTXRotAxisRad": 0x800945ec,
		"mtx::PSMTXTrans": 0x800946f0,
		"PSMTXTrans": 0x800946f0,
		"mtx::PSMTXTransApply": 0x80094724,
		"PSMTXTransApply": 0x80094724,
		"mtx::PSMTXScale": 0x80094764,
		"PSMTXScale": 0x80094764,
		"mtx::PSMTXScaleApply": 0x8009478c,
		"PSMTXScaleApply": 0x8009478c,
		"mtx::PSMTXQuat": 0x800947d8,
		"PSMTXQuat": 0x800947d8,
		"mtx::C_MTXLookAt": 0x8009487c,
		"C_MTXLookAt": 0x8009487c,
		"mtx::C_MTXLightFrustum": 0x80094a08,
		"C_MTXLightFrustum": 0x80094a08,
		"mtx::C_MTXLightPerspective": 0x80094a9c,
		"C_MTXLightPerspective": 0x80094a9c,
		"mtx::C_MTXLightOrtho": 0x80094b68,
		"C_MTXLightOrtho": 0x80094b68,
		"mtx::PSMTXMultVec": 0x80094bf0,
		"PSMTXMultVec": 0x80094bf0,
		"mtx::PSMTXMultVecArray": 0x80094c44,
		"PSMTXMultVecArray": 0x80094c44,
		"mtx::PSMTXMultVecSR": 0x80094cd0,
		"PSMTXMultVecSR": 0x80094cd0,
		"mtx::C_MTXPerspective": 0x80094d24,
		"C_MTXPerspective": 0x80094d24,
		"mtx::C_MTXOrtho": 0x80094df4,
		"C_MTXOrtho": 0x80094df4,
		"mtx::PSVECAdd": 0x80094e8c,
		"PSVECAdd": 0x80094e8c,
		"mtx::PSVECSubtract": 0x80094eb0,
		"PSVECSubtract": 0x80094eb0,
		"mtx::PSVECScale": 0x80094ed4,
		"PSVECScale": 0x80094ed4,
		"mtx::PSVECNormalize": 0x80094ef0,
		"PSVECNormalize": 0x80094ef0,
		"mtx::PSVECMag": 0x80094f34,
		"PSVECMag": 0x80094f34,
		"mtx::PSVECDotProduct": 0x80094f70,
		"PSVECDotProduct": 0x80094f70,
		"mtx::PSVECCrossProduct": 0x80094f90,
		"PSVECCrossProduct": 0x80094f90,
		"mtx::PSVECSquareDistance": 0x80094fcc,
		"PSVECSquareDistance": 0x80094fcc,
		"mtx::PSVECDistance": 0x80094ff4,
		"PSVECDistance": 0x80094ff4,
		"dvd::__DVDInitWA": 0x80095040,
		"__DVDInitWA": 0x80095040,
		"dvd::__DVDInterruptHandler": 0x80095080,
		"__DVDInterruptHandler": 0x80095080,
		"dvd::AlarmHandlerForTimeout": 0x800953f8,
		"AlarmHandlerForTimeout": 0x800953f8,
		"dvd::Read": 0x80095468,
		"Read": 0x80095468,
		"dvd::SeekTwiceBeforeRead": 0x80095578,
		"SeekTwiceBeforeRead": 0x80095578,
		"dvd::DVDLowRead": 0x800955f8,
		"DVDLowRead": 0x800955f8,
		"dvd::DVDLowSeek": 0x80095890,
		"DVDLowSeek": 0x80095890,
		"dvd::DVDLowWaitCoverClose": 0x80095924,
		"DVDLowWaitCoverClose": 0x80095924,
		"dvd::DVDLowReadDiskID": 0x80095950,
		"DVDLowReadDiskID": 0x80095950,
		"dvd::DVDLowStopMotor": 0x800959f4,
		"DVDLowStopMotor": 0x800959f4,
		"dvd::DVDLowRequestError": 0x80095a80,
		"DVDLowRequestError": 0x80095a80,
		"dvd::DVDLowInquiry": 0x80095b0c,
		"DVDLowInquiry": 0x80095b0c,
		"dvd::DVDLowAudioStream": 0x80095ba8,
		"DVDLowAudioStream": 0x80095ba8,
		"dvd::DVDLowRequestAudioStatus": 0x80095c40,
		"DVDLowRequestAudioStatus": 0x80095c40,
		"dvd::DVDLowAudioBufferConfig": 0x80095ccc,
		"DVDLowAudioBufferConfig": 0x80095ccc,
		"dvd::DVDLowReset": 0x80095d68,
		"DVDLowReset": 0x80095d68,
		"dvd::DVDLowBreak": 0x80095e24,
		"DVDLowBreak": 0x80095e24,
		"dvd::DVDLowClearCallback": 0x80095e38,
		"DVDLowClearCallback": 0x80095e38,
		"dvd::__DVDLowSetWAType": 0x80095e50,
		"__DVDLowSetWAType": 0x80095e50,
		"dvd::__DVDFSInit": 0x80095e94,
		"__DVDFSInit": 0x80095e94,
		"dvd::DVDConvertPathToEntrynum": 0x80095ecc,
		"DVDConvertPathToEntrynum": 0x80095ecc,
		"dvd::DVDFastOpen": 0x800961c0,
		"DVDFastOpen": 0x800961c0,
		"dvd::DVDOpen": 0x80096234,
		"DVDOpen": 0x80096234,
		"dvd::DVDClose": 0x800962fc,
		"DVDClose": 0x800962fc,
		"dvd::entryToPath": 0x80096320,
		"entryToPath": 0x80096320,
		"dvd::DVDGetCurrentDir": 0x80096480,
		"DVDGetCurrentDir": 0x80096480,
		"dvd::DVDChangeDir": 0x80096544,
		"DVDChangeDir": 0x80096544,
		"dvd::DVDReadAsyncPrio": 0x800965a4,
		"DVDReadAsyncPrio": 0x800965a4,
		"dvd::cbForReadAsync": 0x80096664,
		"cbForReadAsync": 0x80096664,
		"dvd::DVDReadPrio": 0x80096694,
		"DVDReadPrio": 0x80096694,
		"dvd::cbForReadSync": 0x800967ac,
		"cbForReadSync": 0x800967ac,
		"dvd::DVDPrepareStreamAsync": 0x800967d0,
		"DVDPrepareStreamAsync": 0x800967d0,
		"dvd::cbForPrepareStreamAsync": 0x800968bc,
		"cbForPrepareStreamAsync": 0x800968bc,
		"dvd::DVDInit": 0x800968ec,
		"DVDInit": 0x800968ec,
		"dvd::stateReadingFST": 0x800969e8,
		"stateReadingFST": 0x800969e8,
		"dvd::cbForStateReadingFST": 0x80096a3c,
		"cbForStateReadingFST": 0x80096a3c,
		"dvd::cbForStateError": 0x80096abc,
		"cbForStateError": 0x80096abc,
		"dvd::stateTimeout": 0x80096b64,
		"stateTimeout": 0x80096b64,
		"dvd::stateGettingError": 0x80096c00,
		"stateGettingError": 0x80096c00,
		"dvd::CategorizeError": 0x80096c28,
		"CategorizeError": 0x80096c28,
		"dvd::cbForStateGettingError": 0x80096cdc,
		"cbForStateGettingError": 0x80096cdc,
		"dvd::cbForUnrecoveredError": 0x80096f70,
		"cbForUnrecoveredError": 0x80096f70,
		"dvd::cbForUnrecoveredErrorRetry": 0x80096fd8,
		"cbForUnrecoveredErrorRetry": 0x80096fd8,
		"dvd::stateGoToRetry": 0x80097070,
		"stateGoToRetry": 0x80097070,
		"dvd::cbForStateGoToRetry": 0x80097098,
		"cbForStateGoToRetry": 0x80097098,
		"dvd::stateCheckID": 0x800971f0,
		"stateCheckID": 0x800971f0,
		"dvd::stateCheckID3": 0x800972d4,
		"stateCheckID3": 0x800972d4,
		"dvd::stateCheckID2": 0x80097308,
		"stateCheckID2": 0x80097308,
		"dvd::cbForStateCheckID1": 0x80097340,
		"cbForStateCheckID1": 0x80097340,
		"dvd::cbForStateCheckID2": 0x80097454,
		"cbForStateCheckID2": 0x80097454,
		"dvd::cbForStateCheckID3": 0x800974f8,
		"cbForStateCheckID3": 0x800974f8,
		"dvd::stateCoverClosed": 0x80097638,
		"stateCoverClosed": 0x80097638,
		"dvd::stateCoverClosed_CMD": 0x80097704,
		"stateCoverClosed_CMD": 0x80097704,
		"dvd::cbForStateCoverClosed": 0x80097734,
		"cbForStateCoverClosed": 0x80097734,
		"dvd::stateMotorStopped": 0x800977a4,
		"stateMotorStopped": 0x800977a4,
		"dvd::cbForStateMotorStopped": 0x800977cc,
		"cbForStateMotorStopped": 0x800977cc,
		"dvd::stateReady": 0x800978b0,
		"stateReady": 0x800978b0,
		"dvd::stateBusy": 0x80097af8,
		"stateBusy": 0x80097af8,
		"dvd::cbForStateBusy": 0x80097db8,
		"cbForStateBusy": 0x80097db8,
		"dvd::DVDReadAbsAsyncPrio": 0x8009838c,
		"DVDReadAbsAsyncPrio": 0x8009838c,
		"dvd::DVDReadAbsAsyncForBS": 0x80098468,
		"DVDReadAbsAsyncForBS": 0x80098468,
		"dvd::DVDReadDiskID": 0x80098538,
		"DVDReadDiskID": 0x80098538,
		"dvd::DVDPrepareStreamAbsAsync": 0x8009860c,
		"DVDPrepareStreamAbsAsync": 0x8009860c,
		"dvd::DVDCancelStreamAsync": 0x800986d0,
		"DVDCancelStreamAsync": 0x800986d0,
		"dvd::DVDStopStreamAtEndAsync": 0x8009878c,
		"DVDStopStreamAtEndAsync": 0x8009878c,
		"dvd::DVDGetStreamPlayAddrAsync": 0x80098848,
		"DVDGetStreamPlayAddrAsync": 0x80098848,
		"dvd::DVDInquiryAsync": 0x80098904,
		"DVDInquiryAsync": 0x80098904,
		"dvd::DVDReset": 0x800989d4,
		"DVDReset": 0x800989d4,
		"dvd::DVDGetCommandBlockStatus": 0x80098a18,
		"DVDGetCommandBlockStatus": 0x80098a18,
		"dvd::DVDGetDriveStatus": 0x80098a64,
		"DVDGetDriveStatus": 0x80098a64,
		"dvd::DVDSetAutoInvalidation": 0x80098b10,
		"DVDSetAutoInvalidation": 0x80098b10,
		"dvd::DVDCancelAsync": 0x80098b20,
		"DVDCancelAsync": 0x80098b20,
		"dvd::DVDCancel": 0x80098d90,
		"DVDCancel": 0x80098d90,
		"dvd::cbForCancelSync": 0x80098e3c,
		"cbForCancelSync": 0x80098e3c,
		"dvd::DVDGetCurrentDiskID": 0x80098e60,
		"DVDGetCurrentDiskID": 0x80098e60,
		"dvd::DVDCheckDisk": 0x80098e68,
		"DVDCheckDisk": 0x80098e68,
		"dvd::__DVDPrepareResetAsync": 0x80098f4c,
		"__DVDPrepareResetAsync": 0x80098f4c,
		"dvd::__DVDClearWaitingQueue": 0x80099068,
		"__DVDClearWaitingQueue": 0x80099068,
		"dvd::__DVDPushWaitingQueue": 0x800990a0,
		"__DVDPushWaitingQueue": 0x800990a0,
		"dvd::__DVDPopWaitingQueue": 0x80099108,
		"__DVDPopWaitingQueue": 0x80099108,
		"dvd::__DVDCheckWaitingQueue": 0x800991a8,
		"__DVDCheckWaitingQueue": 0x800991a8,
		"dvd::__DVDDequeueWaitingQueue": 0x80099200,
		"__DVDDequeueWaitingQueue": 0x80099200,
		"dvd::ErrorCode2Num": 0x80099260,
		"ErrorCode2Num": 0x80099260,
		"dvd::__DVDStoreErrorCode": 0x8009937c,
		"__DVDStoreErrorCode": 0x8009937c,
		"dvd::cb": 0x800993f8,
		"dvd::__fstLoad": 0x800994d0,
		"__fstLoad": 0x800994d0,
		"vi::__VIRetraceHandler": 0x80099638,
		"__VIRetraceHandler": 0x80099638,
		"vi::VISetPostRetraceCallback": 0x80099860,
		"VISetPostRetraceCallback": 0x80099860,
		"vi::getTiming": 0x800998a4,
		"getTiming": 0x800998a4,
		"vi::__VIInit": 0x80099934,
		"__VIInit": 0x80099934,
		"vi::VIInit": 0x80099b2c,
		"VIInit": 0x80099b2c,
		"vi::VIWaitForRetrace": 0x80099fa4,
		"VIWaitForRetrace": 0x80099fa4,
		"vi::setFbbRegs": 0x80099ff8,
		"setFbbRegs": 0x80099ff8,
		"vi::setVerticalRegs": 0x8009a2cc,
		"setVerticalRegs": 0x8009a2cc,
		"vi::VIConfigure": 0x8009a46c,
		"VIConfigure": 0x8009a46c,
		"vi::VIFlush": 0x8009ac08,
		"VIFlush": 0x8009ac08,
		"vi::VISetNextFrameBuffer": 0x8009ad24,
		"VISetNextFrameBuffer": 0x8009ad24,
		"vi::VISetBlack": 0x8009ad90,
		"VISetBlack": 0x8009ad90,
		"vi::VIGetRetraceCount": 0x8009ae0c,
		"VIGetRetraceCount": 0x8009ae0c,
		"vi::getCurrentFieldEvenOdd": 0x8009ae14,
		"getCurrentFieldEvenOdd": 0x8009ae14,
		"vi::VIGetNextField": 0x8009ae7c,
		"VIGetNextField": 0x8009ae7c,
		"vi::VIGetCurrentLine": 0x8009af24,
		"VIGetCurrentLine": 0x8009af24,
		"vi::VIGetTvFormat": 0x8009afbc,
		"VIGetTvFormat": 0x8009afbc,
		"vi::VIGetDTVStatus": 0x8009b038,
		"VIGetDTVStatus": 0x8009b038,
		"pad::ClampStick": 0x8009b074,
		"ClampStick": 0x8009b074,
		"pad::PADClamp": 0x8009b1a4,
		"PADClamp": 0x8009b1a4,
		"pad::UpdateOrigin": 0x8009b2ac,
		"UpdateOrigin": 0x8009b2ac,
		"pad::PADOriginCallback": 0x8009b450,
		"PADOriginCallback": 0x8009b450,
		"pad::PADOriginUpdateCallback": 0x8009b514,
		"PADOriginUpdateCallback": 0x8009b514,
		"pad::PADProbeCallback": 0x8009b5d4,
		"PADProbeCallback": 0x8009b5d4,
		"pad::PADTypeAndStatusCallback": 0x8009b6ac,
		"PADTypeAndStatusCallback": 0x8009b6ac,
		"pad::PADReceiveCheckCallback": 0x8009b9d8,
		"PADReceiveCheckCallback": 0x8009b9d8,
		"pad::PADReset": 0x8009bb0c,
		"PADReset": 0x8009bb0c,
		"pad::PADRecalibrate": 0x8009bc0c,
		"PADRecalibrate": 0x8009bc0c,
		"pad::PADInit": 0x8009bd10,
		"PADInit": 0x8009bd10,
		"pad::PADRead": 0x8009bf20,
		"PADRead": 0x8009bf20,
		"pad::PADControlMotor": 0x8009c2cc,
		"PADControlMotor": 0x8009c2cc,
		"pad::PADSetSpec": 0x8009c370,
		"PADSetSpec": 0x8009c370,
		"pad::SPEC0_MakeStatus": 0x8009c3d0,
		"SPEC0_MakeStatus": 0x8009c3d0,
		"pad::SPEC1_MakeStatus": 0x8009c544,
		"SPEC1_MakeStatus": 0x8009c544,
		"pad::SPEC2_MakeStatus": 0x8009c6b8,
		"SPEC2_MakeStatus": 0x8009c6b8,
		"pad::PADSetAnalogMode": 0x8009cab0,
		"PADSetAnalogMode": 0x8009cab0,
		"pad::OnReset": 0x8009cb24,
		"pad::SamplingHandler": 0x8009ccb8,
		"SamplingHandler": 0x8009ccb8,
		"pad::PADSetSamplingCallback": 0x8009cd18,
		"PADSetSamplingCallback": 0x8009cd18,
		"pad::__PADDisableRecalibration": 0x8009cd6c,
		"__PADDisableRecalibration": 0x8009cd6c,
		"ai::AIRegisterDMACallback": 0x8009cde8,
		"AIRegisterDMACallback": 0x8009cde8,
		"ai::AIInitDMA": 0x8009ce2c,
		"AIInitDMA": 0x8009ce2c,
		"ai::AIStartDMA": 0x8009ceb4,
		"AIStartDMA": 0x8009ceb4,
		"ai::AIResetStreamSampleCount": 0x8009cecc,
		"AIResetStreamSampleCount": 0x8009cecc,
		"ai::AISetStreamPlayState": 0x8009cee4,
		"AISetStreamPlayState": 0x8009cee4,
		"ai::AIGetStreamPlayState": 0x8009cfbc,
		"AIGetStreamPlayState": 0x8009cfbc,
		"ai::AISetDSPSampleRate": 0x8009cfcc,
		"AISetDSPSampleRate": 0x8009cfcc,
		"ai::AIGetDSPSampleRate": 0x8009d0ac,
		"AIGetDSPSampleRate": 0x8009d0ac,
		"ai::AISetStreamSampleRate": 0x8009d0c0,
		"AISetStreamSampleRate": 0x8009d0c0,
		"ai::__AI_set_stream_sample_rate": 0x8009d0e8,
		"__AI_set_stream_sample_rate": 0x8009d0e8,
		"ai::AIGetStreamSampleRate": 0x8009d1bc,
		"AIGetStreamSampleRate": 0x8009d1bc,
		"ai::AISetStreamVolLeft": 0x8009d1cc,
		"AISetStreamVolLeft": 0x8009d1cc,
		"ai::AIGetStreamVolLeft": 0x8009d1e8,
		"AIGetStreamVolLeft": 0x8009d1e8,
		"ai::AISetStreamVolRight": 0x8009d1f8,
		"AISetStreamVolRight": 0x8009d1f8,
		"ai::AIGetStreamVolRight": 0x8009d214,
		"AIGetStreamVolRight": 0x8009d214,
		"ai::AIInit": 0x8009d224,
		"AIInit": 0x8009d224,
		"ai::__AISHandler": 0x8009d388,
		"__AISHandler": 0x8009d388,
		"ai::__AIDHandler": 0x8009d404,
		"__AIDHandler": 0x8009d404,
		"ai::__AICallbackStackSwitch": 0x8009d494,
		"__AICallbackStackSwitch": 0x8009d494,
		"ai::__AI_SRC_INIT": 0x8009d4ec,
		"__AI_SRC_INIT": 0x8009d4ec,
		"ar::ARRegisterDMACallback": 0x8009d6d0,
		"ARRegisterDMACallback": 0x8009d6d0,
		"ar::ARStartDMA": 0x8009d714,
		"ARStartDMA": 0x8009d714,
		"ar::ARAlloc": 0x8009d804,
		"ARAlloc": 0x8009d804,
		"ar::ARInit": 0x8009d86c,
		"ARInit": 0x8009d86c,
		"ar::ARGetBaseAddress": 0x8009d928,
		"ARGetBaseAddress": 0x8009d928,
		"ar::ARGetSize": 0x8009d930,
		"ARGetSize": 0x8009d930,
		"ar::__ARHandler": 0x8009d938,
		"__ARHandler": 0x8009d938,
		"ar::__ARChecksize": 0x8009d9b0,
		"__ARChecksize": 0x8009d9b0,
		"ar::__ARQServiceQueueLo": 0x8009e2c4,
		"__ARQServiceQueueLo": 0x8009e2c4,
		"ar::__ARQCallbackHack": 0x8009e3c4,
		"__ARQCallbackHack": 0x8009e3c4,
		"ar::__ARQInterruptServiceRoutine": 0x8009e3c8,
		"__ARQInterruptServiceRoutine": 0x8009e3c8,
		"ar::ARQInit": 0x8009e494,
		"ARQInit": 0x8009e494,
		"ar::ARQPostRequest": 0x8009e4fc,
		"ARQPostRequest": 0x8009e4fc,
		"dsp::DSPCheckMailToDSP": 0x8009e658,
		"DSPCheckMailToDSP": 0x8009e658,
		"dsp::DSPCheckMailFromDSP": 0x8009e668,
		"DSPCheckMailFromDSP": 0x8009e668,
		"dsp::DSPReadMailFromDSP": 0x8009e678,
		"DSPReadMailFromDSP": 0x8009e678,
		"dsp::DSPSendMailToDSP": 0x8009e690,
		"DSPSendMailToDSP": 0x8009e690,
		"dsp::DSPAssertInt": 0x8009e6a4,
		"DSPAssertInt": 0x8009e6a4,
		"dsp::DSPInit": 0x8009e6e4,
		"DSPInit": 0x8009e6e4,
		"dsp::__DSP_debug_printf": 0x8009e79c,
		"__DSP_debug_printf": 0x8009e79c,
		"dsp::__DSP_exec_task": 0x8009e7ec,
		"__DSP_exec_task": 0x8009e7ec,
		"dsp::__DSP_boot_task": 0x8009e98c,
		"__DSP_boot_task": 0x8009e98c,
		"dsp::__DSP_insert_task": 0x8009eb18,
		"__DSP_insert_task": 0x8009eb18,
		"dsp::__DSP_remove_task": 0x8009ebb8,
		"__DSP_remove_task": 0x8009ebb8,
		"card::__CARDDefaultApiCallback": 0x8009ec4c,
		"__CARDDefaultApiCallback": 0x8009ec4c,
		"card::__CARDSyncCallback": 0x8009ec50,
		"__CARDSyncCallback": 0x8009ec50,
		"card::__CARDExtHandler": 0x8009ec84,
		"__CARDExtHandler": 0x8009ec84,
		"card::__CARDExiHandler": 0x8009ed5c,
		"__CARDExiHandler": 0x8009ed5c,
		"card::__CARDTxHandler": 0x8009ee74,
		"__CARDTxHandler": 0x8009ee74,
		"card::__CARDUnlockedHandler": 0x8009ef1c,
		"__CARDUnlockedHandler": 0x8009ef1c,
		"card::__CARDEnableInterrupt": 0x8009efa0,
		"__CARDEnableInterrupt": 0x8009efa0,
		"card::__CARDReadStatus": 0x8009f060,
		"__CARDReadStatus": 0x8009f060,
		"card::__CARDClearStatus": 0x8009f150,
		"__CARDClearStatus": 0x8009f150,
		"card::TimeoutHandler": 0x8009f1fc,
		"TimeoutHandler": 0x8009f1fc,
		"card::Retry": 0x8009f2a0,
		"Retry": 0x8009f2a0,
		"card::UnlockedCallback": 0x8009f4cc,
		"UnlockedCallback": 0x8009f4cc,
		"card::__CARDStart": 0x8009f5dc,
		"__CARDStart": 0x8009f5dc,
		"card::__CARDReadSegment": 0x8009f790,
		"__CARDReadSegment": 0x8009f790,
		"card::__CARDWritePage": 0x8009f8c4,
		"__CARDWritePage": 0x8009f8c4,
		"card::__CARDEraseSector": 0x8009f9e0,
		"__CARDEraseSector": 0x8009f9e0,
		"card::CARDInit": 0x8009fac0,
		"CARDInit": 0x8009fac0,
		"card::__CARDSetDiskID": 0x8009fb5c,
		"__CARDSetDiskID": 0x8009fb5c,
		"card::__CARDGetControlBlock": 0x8009fb94,
		"__CARDGetControlBlock": 0x8009fb94,
		"card::__CARDPutControlBlock": 0x8009fc4c,
		"__CARDPutControlBlock": 0x8009fc4c,
		"card::CARDFreeBlocks": 0x8009fcb0,
		"CARDFreeBlocks": 0x8009fcb0,
		"card::__CARDSync": 0x8009fe00,
		"__CARDSync": 0x8009fe00,
		"card::OnReset": 0x8009fe98,
		"card::bitrev": 0x8009fee8,
		"bitrev": 0x8009fee8,
		"card::ReadArrayUnlock": 0x800a0054,
		"ReadArrayUnlock": 0x800a0054,
		"card::DummyLen": 0x800a0198,
		"DummyLen": 0x800a0198,
		"card::__CARDUnlock": 0x800a025c,
		"__CARDUnlock": 0x800a025c,
		"card::InitCallback": 0x800a0db4,
		"InitCallback": 0x800a0db4,
		"card::DoneCallback": 0x800a0e24,
		"DoneCallback": 0x800a0e24,
		"card::BlockReadCallback": 0x800a1148,
		"BlockReadCallback": 0x800a1148,
		"card::__CARDRead": 0x800a1224,
		"__CARDRead": 0x800a1224,
		"card::BlockWriteCallback": 0x800a1288,
		"BlockWriteCallback": 0x800a1288,
		"card::__CARDWrite": 0x800a1364,
		"__CARDWrite": 0x800a1364,
		"card::__CARDGetFatBlock": 0x800a13c8,
		"__CARDGetFatBlock": 0x800a13c8,
		"card::__CARDAllocBlock": 0x800a156c,
		"__CARDAllocBlock": 0x800a156c,
		"card::__CARDUpdateFatBlock": 0x800a1684,
		"__CARDUpdateFatBlock": 0x800a1684,
		"card::__CARDGetDirBlock": 0x800a1730,
		"__CARDGetDirBlock": 0x800a1730,
		"card::__CARDUpdateDir": 0x800a18d0,
		"__CARDUpdateDir": 0x800a18d0,
		"card::__CARDCheckSum": 0x800a1994,
		"__CARDCheckSum": 0x800a1994,
		"card::VerifyID": 0x800a1b44,
		"VerifyID": 0x800a1b44,
		"card::VerifyDir": 0x800a1dc8,
		"VerifyDir": 0x800a1dc8,
		"card::VerifyFAT": 0x800a2008,
		"VerifyFAT": 0x800a2008,
		"card::__CARDVerify": 0x800a228c,
		"__CARDVerify": 0x800a228c,
		"card::CARDCheckExAsync": 0x800a2318,
		"CARDCheckExAsync": 0x800a2318,
		"card::CARDCheck": 0x800a28a8,
		"CARDCheck": 0x800a28a8,
		"card::IsCard": 0x800a28fc,
		"IsCard": 0x800a28fc,
		"card::CARDProbeEx": 0x800a29c8,
		"CARDProbeEx": 0x800a29c8,
		"card::DoMount": 0x800a2b44,
		"DoMount": 0x800a2b44,
		"card::__CARDMountCallback": 0x800a2f54,
		"__CARDMountCallback": 0x800a2f54,
		"card::CARDMountAsync": 0x800a305c,
		"CARDMountAsync": 0x800a305c,
		"card::CARDMount": 0x800a31fc,
		"CARDMount": 0x800a31fc,
		"card::DoUnmount": 0x800a3244,
		"DoUnmount": 0x800a3244,
		"card::CARDUnmount": 0x800a32e0,
		"CARDUnmount": 0x800a32e0,
		"card::FormatCallback": 0x800a338c,
		"FormatCallback": 0x800a338c,
		"card::__CARDFormatRegionAsync": 0x800a34d0,
		"__CARDFormatRegionAsync": 0x800a34d0,
		"card::CARDFormat": 0x800a3b28,
		"CARDFormat": 0x800a3b28,
		"card::__CARDCompareFileName": 0x800a3b7c,
		"__CARDCompareFileName": 0x800a3b7c,
		"card::__CARDAccess": 0x800a3be4,
		"__CARDAccess": 0x800a3be4,
		"card::__CARDIsPublic": 0x800a3c7c,
		"__CARDIsPublic": 0x800a3c7c,
		"card::CARDOpen": 0x800a3cac,
		"CARDOpen": 0x800a3cac,
		"card::CARDClose": 0x800a3e24,
		"CARDClose": 0x800a3e24,
		"card::CreateCallbackFat": 0x800a3e78,
		"CreateCallbackFat": 0x800a3e78,
		"card::CARDCreateAsync": 0x800a3fa8,
		"CARDCreateAsync": 0x800a3fa8,
		"card::CARDCreate": 0x800a41c8,
		"CARDCreate": 0x800a41c8,
		"card::__CARDSeek": 0x800a4210,
		"__CARDSeek": 0x800a4210,
		"card::ReadCallback": 0x800a43c8,
		"ReadCallback": 0x800a43c8,
		"card::CARDReadAsync": 0x800a44f8,
		"CARDReadAsync": 0x800a44f8,
		"card::CARDRead": 0x800a4640,
		"CARDRead": 0x800a4640,
		"card::CARDWriteAsync": 0x800a48a8,
		"CARDWriteAsync": 0x800a48a8,
		"card::CARDWrite": 0x800a49bc,
		"CARDWrite": 0x800a49bc,
		"card::UpdateIconOffsets": 0x800a4a04,
		"UpdateIconOffsets": 0x800a4a04,
		"card::CARDGetStatus": 0x800a4bfc,
		"CARDGetStatus": 0x800a4bfc,
		"card::CARDSetStatusAsync": 0x800a4d28,
		"CARDSetStatusAsync": 0x800a4d28,
		"card::CARDSetStatus": 0x800a4e9c,
		"CARDSetStatus": 0x800a4e9c,
		"gx::__GXDefaultTexRegionCallback": 0x800a4ee4,
		"__GXDefaultTexRegionCallback": 0x800a4ee4,
		"gx::__GXDefaultTlutRegionCallback": 0x800a4f60,
		"__GXDefaultTlutRegionCallback": 0x800a4f60,
		"gx::GXInit": 0x800a4f84,
		"GXInit": 0x800a4f84,
		"gx::__GXInitGX": 0x800a5750,
		"__GXInitGX": 0x800a5750,
		"gx::GXCPInterruptHandler": 0x800a5fd4,
		"GXCPInterruptHandler": 0x800a5fd4,
		"gx::GXInitFifoBase": 0x800a6110,
		"GXInitFifoBase": 0x800a6110,
		"gx::GXInitFifoPtrs": 0x800a617c,
		"GXInitFifoPtrs": 0x800a617c,
		"gx::GXInitFifoLimits": 0x800a61ec,
		"GXInitFifoLimits": 0x800a61ec,
		"gx::GXSetCPUFifo": 0x800a61f8,
		"GXSetCPUFifo": 0x800a61f8,
		"gx::GXSetGPFifo": 0x800a6308,
		"GXSetGPFifo": 0x800a6308,
		"gx::GXGetFifoPtrs": 0x800a6480,
		"GXGetFifoPtrs": 0x800a6480,
		"gx::GXEnableBreakPt": 0x800a6518,
		"GXEnableBreakPt": 0x800a6518,
		"gx::GXDisableBreakPt": 0x800a65b0,
		"GXDisableBreakPt": 0x800a65b0,
		"gx::__GXFifoInit": 0x800a6614,
		"__GXFifoInit": 0x800a6614,
		"gx::__GXFifoReadEnable": 0x800a6660,
		"__GXFifoReadEnable": 0x800a6660,
		"gx::__GXFifoReadDisable": 0x800a6688,
		"__GXFifoReadDisable": 0x800a6688,
		"gx::__GXFifoLink": 0x800a66ac,
		"__GXFifoLink": 0x800a66ac,
		"gx::__GXWriteFifoIntEnable": 0x800a66f0,
		"__GXWriteFifoIntEnable": 0x800a66f0,
		"gx::__GXWriteFifoIntReset": 0x800a673c,
		"__GXWriteFifoIntReset": 0x800a673c,
		"gx::GXGetCPUFifo": 0x800a6788,
		"GXGetCPUFifo": 0x800a6788,
		"gx::__GXXfVtxSpecs": 0x800a6790,
		"__GXXfVtxSpecs": 0x800a6790,
		"gx::GXSetVtxDesc": 0x800a68e8,
		"GXSetVtxDesc": 0x800a68e8,
		"gx::GXSetVtxDescv": 0x800a6c48,
		"GXSetVtxDescv": 0x800a6c48,
		"gx::__GXSetVCD": 0x800a6fcc,
		"__GXSetVCD": 0x800a6fcc,
		"gx::__GXCalculateVLim": 0x800a7020,
		"__GXCalculateVLim": 0x800a7020,
		"gx::GXGetVtxDesc": 0x800a7144,
		"GXGetVtxDesc": 0x800a7144,
		"gx::GXGetVtxDescv": 0x800a72f8,
		"GXGetVtxDescv": 0x800a72f8,
		"gx::GXClearVtxDesc": 0x800a7368,
		"GXClearVtxDesc": 0x800a7368,
		"gx::GXSetVtxAttrFmt": 0x800a73b4,
		"GXSetVtxAttrFmt": 0x800a73b4,
		"gx::GXSetVtxAttrFmtv": 0x800a7710,
		"GXSetVtxAttrFmtv": 0x800a7710,
		"gx::__GXSetVAT": 0x800a7a8c,
		"__GXSetVAT": 0x800a7a8c,
		"gx::GXGetVtxAttrFmt": 0x800a7b28,
		"GXGetVtxAttrFmt": 0x800a7b28,
		"gx::GXGetVtxAttrFmtv": 0x800a7d70,
		"GXGetVtxAttrFmtv": 0x800a7d70,
		"gx::GXSetArray": 0x800a7de4,
		"GXSetArray": 0x800a7de4,
		"gx::GXInvalidateVtxCache": 0x800a7e70,
		"GXInvalidateVtxCache": 0x800a7e70,
		"gx::GXSetTexCoordGen2": 0x800a7e80,
		"GXSetTexCoordGen2": 0x800a7e80,
		"gx::GXSetNumTexGens": 0x800a8150,
		"GXSetNumTexGens": 0x800a8150,
		"gx::GXSetMisc": 0x800a8198,
		"GXSetMisc": 0x800a8198,
		"gx::GXFlush": 0x800a8210,
		"GXFlush": 0x800a8210,
		"gx::GXSetDrawSync": 0x800a826c,
		"GXSetDrawSync": 0x800a826c,
		"gx::GXSetDrawDone": 0x800a8324,
		"GXSetDrawDone": 0x800a8324,
		"gx::GXWaitDrawDone": 0x800a83bc,
		"GXWaitDrawDone": 0x800a83bc,
		"gx::GXDrawDone": 0x800a8408,
		"GXDrawDone": 0x800a8408,
		"gx::GXPixModeSync": 0x800a8488,
		"GXPixModeSync": 0x800a8488,
		"gx::GXPokeAlphaMode": 0x800a84ac,
		"GXPokeAlphaMode": 0x800a84ac,
		"gx::GXPokeAlphaRead": 0x800a84c0,
		"GXPokeAlphaRead": 0x800a84c0,
		"gx::GXPokeAlphaUpdate": 0x800a84d4,
		"GXPokeAlphaUpdate": 0x800a84d4,
		"gx::GXPokeBlendMode": 0x800a84f0,
		"GXPokeBlendMode": 0x800a84f0,
		"gx::GXPokeColorUpdate": 0x800a8578,
		"GXPokeColorUpdate": 0x800a8578,
		"gx::GXPokeDstAlpha": 0x800a8594,
		"GXPokeDstAlpha": 0x800a8594,
		"gx::GXPokeDither": 0x800a85a8,
		"GXPokeDither": 0x800a85a8,
		"gx::GXPokeZMode": 0x800a85c4,
		"GXPokeZMode": 0x800a85c4,
		"gx::GXPeekARGB": 0x800a85ec,
		"GXPeekARGB": 0x800a85ec,
		"gx::GXPeekZ": 0x800a8610,
		"GXPeekZ": 0x800a8610,
		"gx::GXSetDrawSyncCallback": 0x800a8638,
		"GXSetDrawSyncCallback": 0x800a8638,
		"gx::GXTokenInterruptHandler": 0x800a867c,
		"GXTokenInterruptHandler": 0x800a867c,
		"gx::GXFinishInterruptHandler": 0x800a8704,
		"GXFinishInterruptHandler": 0x800a8704,
		"gx::__GXPEInit": 0x800a8788,
		"__GXPEInit": 0x800a8788,
		"gx::__GXSetDirtyState": 0x800a8808,
		"__GXSetDirtyState": 0x800a8808,
		"gx::GXBegin": 0x800a88a8,
		"GXBegin": 0x800a88a8,
		"gx::__GXSendFlushPrim": 0x800a8998,
		"__GXSendFlushPrim": 0x800a8998,
		"gx::GXSetLineWidth": 0x800a8a20,
		"GXSetLineWidth": 0x800a8a20,
		"gx::GXSetPointSize": 0x800a8a78,
		"GXSetPointSize": 0x800a8a78,
		"gx::GXEnableTexOffsets": 0x800a8acc,
		"GXEnableTexOffsets": 0x800a8acc,
		"gx::GXSetCullMode": 0x800a8b30,
		"GXSetCullMode": 0x800a8b30,
		"gx::GXSetCoPlanar": 0x800a8b80,
		"GXSetCoPlanar": 0x800a8b80,
		"gx::__GXSetGenMode": 0x800a8bc4,
		"__GXSetGenMode": 0x800a8bc4,
		"gx::GXSetDispCopySrc": 0x800a8be8,
		"GXSetDispCopySrc": 0x800a8be8,
		"gx::GXSetTexCopySrc": 0x800a8ca8,
		"GXSetTexCopySrc": 0x800a8ca8,
		"gx::GXSetDispCopyDst": 0x800a8d68,
		"GXSetDispCopyDst": 0x800a8d68,
		"gx::GXSetTexCopyDst": 0x800a8dac,
		"GXSetTexCopyDst": 0x800a8dac,
		"gx::GXSetDispCopyFrame2Field": 0x800a8f1c,
		"GXSetDispCopyFrame2Field": 0x800a8f1c,
		"gx::GXSetCopyClamp": 0x800a8f48,
		"GXSetCopyClamp": 0x800a8f48,
		"gx::GXGetNumXfbLines": 0x800a8fc4,
		"GXGetNumXfbLines": 0x800a8fc4,
		"gx::GXGetYScaleFactor": 0x800a9054,
		"GXGetYScaleFactor": 0x800a9054,
		"gx::GXSetDispCopyYScale": 0x800a928c,
		"GXSetDispCopyYScale": 0x800a928c,
		"gx::GXSetCopyClear": 0x800a9360,
		"GXSetCopyClear": 0x800a9360,
		"gx::GXSetCopyFilter": 0x800a93c8,
		"GXSetCopyFilter": 0x800a93c8,
		"gx::GXSetDispCopyGamma": 0x800a95f0,
		"GXSetDispCopyGamma": 0x800a95f0,
		"gx::GXCopyDisp": 0x800a960c,
		"GXCopyDisp": 0x800a960c,
		"gx::GXCopyTex": 0x800a977c,
		"GXCopyTex": 0x800a977c,
		"gx::GXClearBoundingBox": 0x800a990c,
		"GXClearBoundingBox": 0x800a990c,
		"gx::GXInitLightAttn": 0x800a9944,
		"GXInitLightAttn": 0x800a9944,
		"gx::GXInitLightAttnA": 0x800a9960,
		"GXInitLightAttnA": 0x800a9960,
		"gx::GXInitLightAttnK": 0x800a9970,
		"GXInitLightAttnK": 0x800a9970,
		"gx::GXInitLightDistAttn": 0x800a9980,
		"GXInitLightDistAttn": 0x800a9980,
		"gx::GXInitLightPos": 0x800a9a50,
		"GXInitLightPos": 0x800a9a50,
		"gx::GXInitSpecularDir": 0x800a9a60,
		"GXInitSpecularDir": 0x800a9a60,
		"gx::GXInitLightColor": 0x800a9b34,
		"GXInitLightColor": 0x800a9b34,
		"gx::GXGetLightColor": 0x800a9b5c,
		"GXGetLightColor": 0x800a9b5c,
		"gx::GXLoadLightObjImm": 0x800a9b8c,
		"GXLoadLightObjImm": 0x800a9b8c,
		"gx::GXSetChanAmbColor": 0x800a9cd4,
		"GXSetChanAmbColor": 0x800a9cd4,
		"gx::GXSetChanMatColor": 0x800a9e3c,
		"GXSetChanMatColor": 0x800a9e3c,
		"gx::GXSetNumChans": 0x800a9fa4,
		"GXSetNumChans": 0x800a9fa4,
		"gx::GXSetChanCtrl": 0x800a9ff0,
		"GXSetChanCtrl": 0x800a9ff0,
		"gx::GXGetTexBufferSize": 0x800aa1d4,
		"GXGetTexBufferSize": 0x800aa1d4,
		"gx::__GetImageTileCount": 0x800aa330,
		"__GetImageTileCount": 0x800aa330,
		"gx::GXInitTexObj": 0x800aa3f8,
		"GXInitTexObj": 0x800aa3f8,
		"gx::GXInitTexObjCI": 0x800aa66c,
		"GXInitTexObjCI": 0x800aa66c,
		"gx::GXInitTexObjLOD": 0x800aa6b4,
		"GXInitTexObjLOD": 0x800aa6b4,
		"gx::GXGetTexObjAll": 0x800aa848,
		"GXGetTexObjAll": 0x800aa848,
		"gx::GXGetTexObjWidth": 0x800aa8b0,
		"GXGetTexObjWidth": 0x800aa8b0,
		"gx::GXGetTexObjHeight": 0x800aa8c0,
		"GXGetTexObjHeight": 0x800aa8c0,
		"gx::GXGetTexObjFmt": 0x800aa8d0,
		"GXGetTexObjFmt": 0x800aa8d0,
		"gx::GXLoadTexObjPreLoaded": 0x800aa8d8,
		"GXLoadTexObjPreLoaded": 0x800aa8d8,
		"gx::GXLoadTexObj": 0x800aaa80,
		"GXLoadTexObj": 0x800aaa80,
		"gx::GXInitTlutObj": 0x800aaad4,
		"GXInitTlutObj": 0x800aaad4,
		"gx::GXLoadTlut": 0x800aab1c,
		"GXLoadTlut": 0x800aab1c,
		"gx::GXInitTexCacheRegion": 0x800aabb8,
		"GXInitTexCacheRegion": 0x800aabb8,
		"gx::GXInitTlutRegion": 0x800aacd8,
		"GXInitTlutRegion": 0x800aacd8,
		"gx::GXInvalidateTexAll": 0x800aad20,
		"GXInvalidateTexAll": 0x800aad20,
		"gx::GXSetTexRegionCallback": 0x800aad68,
		"GXSetTexRegionCallback": 0x800aad68,
		"gx::GXSetTlutRegionCallback": 0x800aad7c,
		"GXSetTlutRegionCallback": 0x800aad7c,
		"gx::GXSetTexCoordScaleManually": 0x800aad90,
		"GXSetTexCoordScaleManually": 0x800aad90,
		"gx::GXSetTexCoordCylWrap": 0x800aae2c,
		"GXSetTexCoordCylWrap": 0x800aae2c,
		"gx::__SetSURegs": 0x800aaeb0,
		"__SetSURegs": 0x800aaeb0,
		"gx::__GXSetSUTexRegs": 0x800aaf7c,
		"__GXSetSUTexRegs": 0x800aaf7c,
		"gx::__GXSetTmemConfig": 0x800ab0f8,
		"__GXSetTmemConfig": 0x800ab0f8,
		"gx::GXSetTevIndirect": 0x800ab338,
		"GXSetTevIndirect": 0x800ab338,
		"gx::GXSetIndTexMtx": 0x800ab3d4,
		"GXSetIndTexMtx": 0x800ab3d4,
		"gx::GXSetIndTexCoordScale": 0x800ab534,
		"GXSetIndTexCoordScale": 0x800ab534,
		"gx::GXSetIndTexOrder": 0x800ab708,
		"GXSetIndTexOrder": 0x800ab708,
		"gx::GXSetNumIndStages": 0x800ab840,
		"GXSetNumIndStages": 0x800ab840,
		"gx::GXSetTevDirect": 0x800ab86c,
		"GXSetTevDirect": 0x800ab86c,
		"gx::GXSetTevIndWarp": 0x800ab8b4,
		"GXSetTevIndWarp": 0x800ab8b4,
		"gx::__GXUpdateBPMask": 0x800ab918,
		"__GXUpdateBPMask": 0x800ab918,
		"gx::__GXFlushTextureState": 0x800ab9e4,
		"__GXFlushTextureState": 0x800ab9e4,
		"gx::GXSetTevOp": 0x800aba08,
		"GXSetTevOp": 0x800aba08,
		"gx::GXSetTevColorIn": 0x800abbac,
		"GXSetTevColorIn": 0x800abbac,
		"gx::GXSetTevAlphaIn": 0x800abc2c,
		"GXSetTevAlphaIn": 0x800abc2c,
		"gx::GXSetTevColorOp": 0x800abcb0,
		"GXSetTevColorOp": 0x800abcb0,
		"gx::GXSetTevAlphaOp": 0x800abd70,
		"GXSetTevAlphaOp": 0x800abd70,
		"gx::GXSetTevColor": 0x800abe30,
		"GXSetTevColor": 0x800abe30,
		"gx::GXSetTevColorS10": 0x800abea4,
		"GXSetTevColorS10": 0x800abea4,
		"gx::GXSetTevKColor": 0x800abf18,
		"GXSetTevKColor": 0x800abf18,
		"gx::GXSetTevKColorSel": 0x800abf8c,
		"GXSetTevKColorSel": 0x800abf8c,
		"gx::GXSetTevKAlphaSel": 0x800abff8,
		"GXSetTevKAlphaSel": 0x800abff8,
		"gx::GXSetTevSwapMode": 0x800ac064,
		"GXSetTevSwapMode": 0x800ac064,
		"gx::GXSetTevSwapModeTable": 0x800ac0bc,
		"GXSetTevSwapModeTable": 0x800ac0bc,
		"gx::GXSetAlphaCompare": 0x800ac15c,
		"GXSetAlphaCompare": 0x800ac15c,
		"gx::GXSetZTexture": 0x800ac1ac,
		"GXSetZTexture": 0x800ac1ac,
		"gx::GXSetTevOrder": 0x800ac230,
		"GXSetTevOrder": 0x800ac230,
		"gx::GXSetNumTevStages": 0x800ac40c,
		"GXSetNumTevStages": 0x800ac40c,
		"gx::GXSetFog": 0x800ac440,
		"GXSetFog": 0x800ac440,
		"gx::GXSetFogRangeAdj": 0x800ac5f0,
		"GXSetFogRangeAdj": 0x800ac5f0,
		"gx::GXSetBlendMode": 0x800ac6f0,
		"GXSetBlendMode": 0x800ac6f0,
		"gx::GXSetColorUpdate": 0x800ac7f4,
		"GXSetColorUpdate": 0x800ac7f4,
		"gx::GXSetAlphaUpdate": 0x800ac834,
		"GXSetAlphaUpdate": 0x800ac834,
		"gx::GXSetZMode": 0x800ac874,
		"GXSetZMode": 0x800ac874,
		"gx::GXSetZCompLoc": 0x800ac8ec,
		"GXSetZCompLoc": 0x800ac8ec,
		"gx::GXSetPixelFmt": 0x800ac92c,
		"GXSetPixelFmt": 0x800ac92c,
		"gx::GXSetDither": 0x800aca3c,
		"GXSetDither": 0x800aca3c,
		"gx::GXSetDstAlpha": 0x800aca7c,
		"GXSetDstAlpha": 0x800aca7c,
		"gx::GXSetFieldMask": 0x800acad0,
		"GXSetFieldMask": 0x800acad0,
		"gx::GXSetFieldMode": 0x800acb08,
		"GXSetFieldMode": 0x800acb08,
		"gx::GXDrawSphere": 0x800acb88,
		"GXDrawSphere": 0x800acb88,
		"gx::GXDrawCubeFace": 0x800acf04,
		"GXDrawCubeFace": 0x800acf04,
		"gx::GXDrawCube": 0x800ad11c,
		"GXDrawCube": 0x800ad11c,
		"gx::__GXSetRange": 0x800ad36c,
		"__GXSetRange": 0x800ad36c,
		"gx::GXCallDisplayList": 0x800ad370,
		"GXCallDisplayList": 0x800ad370,
		"gx::GXProject": 0x800ad3e0,
		"GXProject": 0x800ad3e0,
		"gx::GXSetProjection": 0x800ad554,
		"GXSetProjection": 0x800ad554,
		"gx::GXGetProjectionv": 0x800ad628,
		"GXGetProjectionv": 0x800ad628,
		"gx::WriteMTXPS4x3": 0x800ad6a0,
		"WriteMTXPS4x3": 0x800ad6a0,
		"gx::WriteMTXPS3x3from3x4": 0x800ad6d4,
		"WriteMTXPS3x3from3x4": 0x800ad6d4,
		"gx::WriteMTXPS4x2": 0x800ad708,
		"WriteMTXPS4x2": 0x800ad708,
		"gx::GXLoadPosMtxImm": 0x800ad72c,
		"GXLoadPosMtxImm": 0x800ad72c,
		"gx::GXLoadPosMtxIndx": 0x800ad768,
		"GXLoadPosMtxIndx": 0x800ad768,
		"gx::GXLoadNrmMtxImm": 0x800ad798,
		"GXLoadNrmMtxImm": 0x800ad798,
		"gx::GXLoadNrmMtxIndx3x3": 0x800ad7d8,
		"GXLoadNrmMtxIndx3x3": 0x800ad7d8,
		"gx::GXSetCurrentMtx": 0x800ad80c,
		"GXSetCurrentMtx": 0x800ad80c,
		"gx::GXLoadTexMtxImm": 0x800ad848,
		"GXLoadTexMtxImm": 0x800ad848,
		"gx::GXSetViewportJitter": 0x800ad8cc,
		"GXSetViewportJitter": 0x800ad8cc,
		"gx::GXSetViewport": 0x800ad9e8,
		"GXSetViewport": 0x800ad9e8,
		"gx::GXGetViewportv": 0x800ada0c,
		"GXGetViewportv": 0x800ada0c,
		"gx::GXSetScissor": 0x800ada58,
		"GXSetScissor": 0x800ada58,
		"gx::GXSetScissorBoxOffset": 0x800adb08,
		"GXSetScissorBoxOffset": 0x800adb08,
		"gx::GXSetClipMode": 0x800adb4c,
		"GXSetClipMode": 0x800adb4c,
		"gx::__GXSetMatrixIndex": 0x800adb74,
		"__GXSetMatrixIndex": 0x800adb74,
		"gx::GXSetGPMetric": 0x800adbf8,
		"GXSetGPMetric": 0x800adbf8,
		"gx::GXClearGPMetric": 0x800ae490,
		"GXClearGPMetric": 0x800ae490,
		"gx::GXReadPixMetric": 0x800ae4a0,
		"GXReadPixMetric": 0x800ae4a0,
		"gx::GXClearPixMetric": 0x800ae530,
		"GXClearPixMetric": 0x800ae530,
		"OdemuExi2::DBClose": 0x800ae560,
		"DBClose": 0x800ae560,
		"OdemuExi2::DBOpen": 0x800ae564,
		"DBOpen": 0x800ae564,
		"OdemuExi2::DBWrite": 0x800ae568,
		"DBWrite": 0x800ae568,
		"OdemuExi2::DBRead": 0x800ae7c8,
		"DBRead": 0x800ae7c8,
		"OdemuExi2::DBQueryData": 0x800ae854,
		"DBQueryData": 0x800ae854,
		"OdemuExi2::DBInitInterrupts": 0x800ae8f0,
		"DBInitInterrupts": 0x800ae8f0,
		"OdemuExi2::DBInitComm": 0x800ae944,
		"DBInitComm": 0x800ae944,
		"OdemuExi2::DBGHandler": 0x800ae9bc,
		"DBGHandler": 0x800ae9bc,
		"OdemuExi2::MWCallback": 0x800ae9fc,
		"MWCallback": 0x800ae9fc,
		"OdemuExi2::DBGReadStatus": 0x800aea38,
		"DBGReadStatus": 0x800aea38,
		"OdemuExi2::DBGWrite": 0x800aeae4,
		"DBGWrite": 0x800aeae4,
		"OdemuExi2::DBGRead": 0x800aebc0,
		"DBGRead": 0x800aebc0,
		"OdemuExi2::DBGReadMailbox": 0x800aec9c,
		"DBGReadMailbox": 0x800aec9c,
		"OdemuExi2::DBGEXIImm": 0x800aed48,
		"DBGEXIImm": 0x800aed48,
		"amcstubs::EXI2_Init": 0x800aefe0,
		"EXI2_Init": 0x800aefe0,
		"amcstubs::EXI2_EnableInterrupts": 0x800aefe4,
		"EXI2_EnableInterrupts": 0x800aefe4,
		"amcstubs::EXI2_Poll": 0x800aefe8,
		"EXI2_Poll": 0x800aefe8,
		"amcstubs::EXI2_ReadN": 0x800aeff0,
		"EXI2_ReadN": 0x800aeff0,
		"amcstubs::EXI2_WriteN": 0x800aeff8,
		"EXI2_WriteN": 0x800aeff8,
		"amcstubs::EXI2_Reserve": 0x800af000,
		"EXI2_Reserve": 0x800af000,
		"amcstubs::EXI2_Unreserve": 0x800af004,
		"EXI2_Unreserve": 0x800af004,
		"amcstubs::AMC_IsStub": 0x800af008,
		"AMC_IsStub": 0x800af008,
		"odenotstub::Hu_IsStub": 0x800af010,
		"Hu_IsStub": 0x800af010,
		"gd::GDInitGDLObj": 0x800af018,
		"GDInitGDLObj": 0x800af018,
		"gd::GDFlushCurrToMem": 0x800af030,
		"GDFlushCurrToMem": 0x800af030,
		"gd::GDPadCurr32": 0x800af05c,
		"GDPadCurr32": 0x800af05c,
		"gd::GDOverflowed": 0x800af154,
		"GDOverflowed": 0x800af154,
		"gd::GDSetOverflowCallback": 0x800af184,
		"GDSetOverflowCallback": 0x800af184,
		"gd::GDSetVtxDescv": 0x800af18c,
		"GDSetVtxDescv": 0x800af18c,
		"gd::GDSetVtxAttrFmtv": 0x800af788,
		"GDSetVtxAttrFmtv": 0x800af788,
		"gd::GDSetArray": 0x800afda8,
		"GDSetArray": 0x800afda8,
		"gd::GDSetArrayRaw": 0x800affb4,
		"GDSetArrayRaw": 0x800affb4,
		"gd::GDSetCullMode": 0x800b01bc,
		"GDSetCullMode": 0x800b01bc,
		"gd::GDSetGenMode2": 0x800b0348,
		"GDSetGenMode2": 0x800b0348,
		"gd::GDSetLightAttn": 0x800b0784,
		"GDSetLightAttn": 0x800b0784,
		"gd::GDSetLightColor": 0x800b0c20,
		"GDSetLightColor": 0x800b0c20,
		"gd::GDSetLightPos": 0x800b0dc8,
		"GDSetLightPos": 0x800b0dc8,
		"gd::GDSetLightDir": 0x800b109c,
		"GDSetLightDir": 0x800b109c,
		"gd::GDSetChanMatColor": 0x800b1370,
		"GDSetChanMatColor": 0x800b1370,
		"gd::GDSetChanCtrl": 0x800b1508,
		"GDSetChanCtrl": 0x800b1508,
		"gd::GDSetBlendMode": 0x800b181c,
		"GDSetBlendMode": 0x800b181c,
		"gd::GDSetBlendModeEtc": 0x800b1aa8,
		"GDSetBlendModeEtc": 0x800b1aa8,
		"gd::GDSetZMode": 0x800b1cb4,
		"GDSetZMode": 0x800b1cb4,
		"gd::GDSetDstAlpha": 0x800b1db8,
		"GDSetDstAlpha": 0x800b1db8,
		"gd::GDSetTevOp": 0x800b1ea4,
		"GDSetTevOp": 0x800b1ea4,
		"gd::GDSetTevColorCalc": 0x800b2138,
		"GDSetTevColorCalc": 0x800b2138,
		"gd::GDSetTevAlphaCalcAndSwap": 0x800b2384,
		"GDSetTevAlphaCalcAndSwap": 0x800b2384,
		"gd::GDSetAlphaCompare": 0x800b25f8,
		"GDSetAlphaCompare": 0x800b25f8,
		"gd::GDSetTevOrder": 0x800b26fc,
		"GDSetTevOrder": 0x800b26fc,
		"gd::GDSetCurrentMtx": 0x800b286c,
		"GDSetCurrentMtx": 0x800b286c,
		"si::SIBusy": 0x800b2c38,
		"SIBusy": 0x800b2c38,
		"si::SIIsChanBusy": 0x800b2c58,
		"SIIsChanBusy": 0x800b2c58,
		"si::CompleteTransfer": 0x800b2c94,
		"CompleteTransfer": 0x800b2c94,
		"si::SIInterruptHandler": 0x800b2f90,
		"SIInterruptHandler": 0x800b2f90,
		"si::SIEnablePollingInterrupt": 0x800b32d4,
		"SIEnablePollingInterrupt": 0x800b32d4,
		"si::SIRegisterPollingHandler": 0x800b336c,
		"SIRegisterPollingHandler": 0x800b336c,
		"si::SIUnregisterPollingHandler": 0x800b3438,
		"SIUnregisterPollingHandler": 0x800b3438,
		"si::SIInit": 0x800b352c,
		"SIInit": 0x800b352c,
		"si::__SITransfer": 0x800b35d0,
		"__SITransfer": 0x800b35d0,
		"si::SIGetStatus": 0x800b37dc,
		"SIGetStatus": 0x800b37dc,
		"si::SISetCommand": 0x800b3858,
		"SISetCommand": 0x800b3858,
		"si::SITransferCommands": 0x800b386c,
		"SITransferCommands": 0x800b386c,
		"si::SISetXY": 0x800b387c,
		"SISetXY": 0x800b387c,
		"si::SIEnablePolling": 0x800b38e8,
		"SIEnablePolling": 0x800b38e8,
		"si::SIDisablePolling": 0x800b3984,
		"SIDisablePolling": 0x800b3984,
		"si::SIGetResponseRaw": 0x800b39f0,
		"SIGetResponseRaw": 0x800b39f0,
		"si::SIGetResponse": 0x800b3ac4,
		"SIGetResponse": 0x800b3ac4,
		"si::AlarmHandler": 0x800b3b88,
		"si::SITransfer": 0x800b3c14,
		"SITransfer": 0x800b3c14,
		"si::GetTypeCallback": 0x800b3d80,
		"GetTypeCallback": 0x800b3d80,
		"si::SIGetType": 0x800b4018,
		"SIGetType": 0x800b4018,
		"si::SIGetTypeAsync": 0x800b41dc,
		"SIGetTypeAsync": 0x800b41dc,
		"si::SISetSamplingRate": 0x800b4318,
		"SISetSamplingRate": 0x800b4318,
		"si::SIRefreshSamplingRate": 0x800b43fc,
		"SIRefreshSamplingRate": 0x800b43fc,
		"exi::SetExiInterruptMask": 0x800b4420,
		"SetExiInterruptMask": 0x800b4420,
		"exi::EXIImm": 0x800b4514,
		"EXIImm": 0x800b4514,
		"exi::EXIImmEx": 0x800b4770,
		"EXIImmEx": 0x800b4770,
		"exi::EXIDma": 0x800b4810,
		"EXIDma": 0x800b4810,
		"exi::EXISync": 0x800b48fc,
		"EXISync": 0x800b48fc,
		"exi::EXIClearInterrupts": 0x800b4b34,
		"EXIClearInterrupts": 0x800b4b34,
		"exi::EXISetExiCallback": 0x800b4b7c,
		"EXISetExiCallback": 0x800b4b7c,
		"exi::__EXIProbe": 0x800b4bf8,
		"__EXIProbe": 0x800b4bf8,
		"exi::EXIProbe": 0x800b4d6c,
		"EXIProbe": 0x800b4d6c,
		"exi::EXIProbeEx": 0x800b4dec,
		"EXIProbeEx": 0x800b4dec,
		"exi::EXIAttach": 0x800b4ea0,
		"EXIAttach": 0x800b4ea0,
		"exi::EXIDetach": 0x800b4fac,
		"EXIDetach": 0x800b4fac,
		"exi::EXISelect": 0x800b5068,
		"EXISelect": 0x800b5068,
		"exi::EXIDeselect": 0x800b5194,
		"EXIDeselect": 0x800b5194,
		"exi::EXIIntrruptHandler": 0x800b52a4,
		"EXIIntrruptHandler": 0x800b52a4,
		"exi::TCIntrruptHandler": 0x800b536c,
		"TCIntrruptHandler": 0x800b536c,
		"exi::EXTIntrruptHandler": 0x800b5584,
		"EXTIntrruptHandler": 0x800b5584,
		"exi::EXIInit": 0x800b564c,
		"EXIInit": 0x800b564c,
		"exi::EXILock": 0x800b5760,
		"EXILock": 0x800b5760,
		"exi::EXIUnlock": 0x800b5854,
		"EXIUnlock": 0x800b5854,
		"exi::EXIGetState": 0x800b5930,
		"EXIGetState": 0x800b5930,
		"exi::UnlockedHandler": 0x800b5948,
		"UnlockedHandler": 0x800b5948,
		"exi::EXIGetID": 0x800b5970,
		"EXIGetID": 0x800b5970,
		"exi::InitializeUART": 0x800b5cec,
		"InitializeUART": 0x800b5cec,
		"exi::ReadUARTN": 0x800b5d5c,
		"ReadUARTN": 0x800b5d5c,
		"exi::WriteUARTN": 0x800b5d64,
		"WriteUARTN": 0x800b5d64,
		"thp::THPVideoDecode": 0x800b5f64,
		"THPVideoDecode": 0x800b5f64,
		"thp::__THPSetupBuffers": 0x800b61a8,
		"__THPSetupBuffers": 0x800b61a8,
		"thp::__THPReadFrameHeader": 0x800b61ec,
		"__THPReadFrameHeader": 0x800b61ec,
		"thp::__THPReadScaneHeader": 0x800b6328,
		"__THPReadScaneHeader": 0x800b6328,
		"thp::__THPReadQuantizationTable": 0x800b6444,
		"__THPReadQuantizationTable": 0x800b6444,
		"thp::__THPReadHuffmanTableSpecification": 0x800b6800,
		"__THPReadHuffmanTableSpecification": 0x800b6800,
		"thp::__THPHuffGenerateSizeTable": 0x800b69e0,
		"__THPHuffGenerateSizeTable": 0x800b69e0,
		"thp::__THPHuffGenerateCodeTable": 0x800b6ad0,
		"__THPHuffGenerateCodeTable": 0x800b6ad0,
		"thp::__THPHuffGenerateDecoderTables": 0x800b6b38,
		"__THPHuffGenerateDecoderTables": 0x800b6b38,
		"thp::__THPRestartDefinition": 0x800b6cf4,
		"__THPRestartDefinition": 0x800b6cf4,
		"thp::__THPPrepBitStream": 0x800b6d48,
		"__THPPrepBitStream": 0x800b6d48,
		"thp::__THPDecompressYUV": 0x800b6f94,
		"__THPDecompressYUV": 0x800b6f94,
		"thp::__THPDecompressiMCURow512x448": 0x800b70a0,
		"__THPDecompressiMCURow512x448": 0x800b70a0,
		"thp::__THPDecompressiMCURow640x480": 0x800b8b28,
		"__THPDecompressiMCURow640x480": 0x800b8b28,
		"thp::__THPDecompressiMCURowNxN": 0x800ba5b4,
		"__THPDecompressiMCURowNxN": 0x800ba5b4,
		"thp::__THPHuffDecodeDCTCompY": 0x800bc060,
		"__THPHuffDecodeDCTCompY": 0x800bc060,
		"thp::__THPHuffDecodeDCTCompU": 0x800bc6dc,
		"__THPHuffDecodeDCTCompU": 0x800bc6dc,
		"thp::__THPHuffDecodeDCTCompV": 0x800bcd84,
		"__THPHuffDecodeDCTCompV": 0x800bcd84,
		"thp::THPInit": 0x800bd42c,
		"THPInit": 0x800bd42c,
		"thp::THPAudioDecode": 0x800bd4a4,
		"THPAudioDecode": 0x800bd4a4,
		"thp::__THPAudioGetNewSample": 0x800bd908,
		"__THPAudioGetNewSample": 0x800bd908,
		"thp::__THPAudioInitialize": 0x800bd998,
		"__THPAudioInitialize": 0x800bd998,
		"THPPlayer::PopDecodedAudioBuffer": 0x800bd9d4,
		"PopDecodedAudioBuffer": 0x800bd9d4,
		"THPPlayer::PushFreeAudioBuffer": 0x800bda18,
		"PushFreeAudioBuffer": 0x800bda18,
		"THPPlayer::AudioDecode": 0x800bda48,
		"AudioDecode": 0x800bda48,
		"THPPlayer::AudioDecoderForOnMemory": 0x800bdb44,
		"AudioDecoderForOnMemory": 0x800bdb44,
		"THPPlayer::AudioDecoder": 0x800bdbf4,
		"AudioDecoder": 0x800bdbf4,
		"THPPlayer::AudioDecodeThreadCancel": 0x800bdc1c,
		"AudioDecodeThreadCancel": 0x800bdc1c,
		"THPPlayer::AudioDecodeThreadStart": 0x800bdc58,
		"AudioDecodeThreadStart": 0x800bdc58,
		"THPPlayer::CreateAudioDecodeThread": 0x800bdc8c,
		"CreateAudioDecodeThread": 0x800bdc8c,
		"THPPlayer::THPGXYuv2RgbDraw": 0x800bdd4c,
		"THPGXYuv2RgbDraw": 0x800bdd4c,
		"THPPlayer::THPGXYuv2RgbSetup": 0x800bdf30,
		"THPGXYuv2RgbSetup": 0x800bdf30,
		"THPPlayer::THPGXRestore": 0x800be414,
		"THPGXRestore": 0x800be414,
		"THPPlayer::THPPlayerSetVolume": 0x800be52c,
		"THPPlayerSetVolume": 0x800be52c,
		"THPPlayer::MixAudio": 0x800be668,
		"MixAudio": 0x800be668,
		"THPPlayer::THPPlayerDrawDone": 0x800be844,
		"THPPlayerDrawDone": 0x800be844,
		"THPPlayer::THPPlayerGetState": 0x800be8b8,
		"THPPlayerGetState": 0x800be8b8,
		"THPPlayer::THPPlayerGetAudioInfo": 0x800be8c8,
		"THPPlayerGetAudioInfo": 0x800be8c8,
		"THPPlayer::THPPlayerGetVideoInfo": 0x800be910,
		"THPPlayerGetVideoInfo": 0x800be910,
		"THPPlayer::THPPlayerDrawCurrentFrame": 0x800be958,
		"THPPlayerDrawCurrentFrame": 0x800be958,
		"THPPlayer::ProperTimingForGettingNextFrame": 0x800bea24,
		"ProperTimingForGettingNextFrame": 0x800bea24,
		"THPPlayer::PlayControl": 0x800beb48,
		"PlayControl": 0x800beb48,
		"THPPlayer::THPPlayerPause": 0x800bee0c,
		"THPPlayerPause": 0x800bee0c,
		"THPPlayer::THPPlayerStop": 0x800bee4c,
		"THPPlayerStop": 0x800bee4c,
		"THPPlayer::THPPlayerPlay": 0x800bef24,
		"THPPlayerPlay": 0x800bef24,
		"THPPlayer::THPPlayerPrepare": 0x800bef80,
		"THPPlayerPrepare": 0x800bef80,
		"THPPlayer::PrepareReady": 0x800bf1f0,
		"PrepareReady": 0x800bf1f0,
		"THPPlayer::InitAllMessageQueue": 0x800bf220,
		"InitAllMessageQueue": 0x800bf220,
		"THPPlayer::THPPlayerSetBuffer": 0x800bf2f0,
		"THPPlayerSetBuffer": 0x800bf2f0,
		"THPPlayer::THPPlayerCalcNeedMemory": 0x800bf520,
		"THPPlayerCalcNeedMemory": 0x800bf520,
		"THPPlayer::THPPlayerClose": 0x800bf5c8,
		"THPPlayerClose": 0x800bf5c8,
		"THPPlayer::THPPlayerOpen": 0x800bf620,
		"THPPlayerOpen": 0x800bf620,
		"THPPlayer::THPPlayerQuit": 0x800bf8b0,
		"THPPlayerQuit": 0x800bf8b0,
		"THPPlayer::THPPlayerInit": 0x800bf8e4,
		"THPPlayerInit": 0x800bf8e4,
		"THPPlayer::audioCallbackWithMSound": 0x800bf9ac,
		"audioCallbackWithMSound": 0x800bf9ac,
		"THPPlayer::PushReadedBuffer2": 0x800bfa60,
		"PushReadedBuffer2": 0x800bfa60,
		"THPPlayer::PopReadedBuffer2": 0x800bfa90,
		"PopReadedBuffer2": 0x800bfa90,
		"THPPlayer::PushFreeReadBuffer": 0x800bfac4,
		"PushFreeReadBuffer": 0x800bfac4,
		"THPPlayer::PopReadedBuffer": 0x800bfaf4,
		"PopReadedBuffer": 0x800bfaf4,
		"THPPlayer::Reader": 0x800bfb28,
		"Reader": 0x800bfb28,
		"THPPlayer::ReadThreadCancel": 0x800bfc18,
		"ReadThreadCancel": 0x800bfc18,
		"THPPlayer::ReadThreadStart": 0x800bfc54,
		"ReadThreadStart": 0x800bfc54,
		"THPPlayer::CreateReadThread": 0x800bfc88,
		"CreateReadThread": 0x800bfc88,
		"THPPlayer::PopDecodedTextureSet": 0x800bfd24,
		"PopDecodedTextureSet": 0x800bfd24,
		"THPPlayer::PushFreeTextureSet": 0x800bfd68,
		"PushFreeTextureSet": 0x800bfd68,
		"THPPlayer::VideoDecode": 0x800bfd98,
		"VideoDecode": 0x800bfd98,
		"THPPlayer::VideoDecoderForOnMemory": 0x800bfec8,
		"VideoDecoderForOnMemory": 0x800bfec8,
		"THPPlayer::VideoDecoder": 0x800bfffc,
		"VideoDecoder": 0x800bfffc,
		"THPPlayer::VideoDecodeThreadCancel": 0x800c00d8,
		"VideoDecodeThreadCancel": 0x800c00d8,
		"THPPlayer::VideoDecodeThreadStart": 0x800c0114,
		"VideoDecodeThreadStart": 0x800c0114,
		"THPPlayer::CreateVideoDecodeThread": 0x800c0148,
		"CreateVideoDecodeThread": 0x800c0148,
		"TDLColorTexQuad::draw": 0x800c0224,
		"TDLColorTexQuad::setEnd": 0x800c02c4,
		"TDLColorTexQuad::requestCol": 0x800c045c,
		"requestCol": 0x800c045c,
		"TDLColorTexQuad::createBuffer": 0x800c0640,
		"TDLTexQuad::draw": 0x800c0720,
		"TDLTexQuad::setEnd": 0x800c0828,
		"TDLTexQuad::request": 0x800c098c,
		"TDLTexQuad::createBuffer": 0x800c0b28,
		"TDLTexQuad::createDLBuffer": 0x800c0bc8,
		"createDLBuffer": 0x800c0bc8,
		"TSilhouette::~TSilhouette": 0x800c0c80,
		"MarioUtil::SMS_UnifyMaterial": 0x800c0cf4,
		"SMS_UnifyMaterial": 0x800c0cf4,
		"MarioUtil::SMS_CalcMatAnmAndMakeDL": 0x800c0da8,
		"SMS_CalcMatAnmAndMakeDL": 0x800c0da8,
		"MarioUtil::SMS_ShowJoint": 0x800c0e74,
		"SMS_ShowJoint": 0x800c0e74,
		"MarioUtil::SMS_DrawInit": 0x800c0ec4,
		"SMS_DrawInit": 0x800c0ec4,
		"MarioUtil::SMS_MakeDLAndLock": 0x800c0ef0,
		"SMS_MakeDLAndLock": 0x800c0ef0,
		"MarioUtil::SMS_DrawShape": 0x800c0f78,
		"SMS_DrawShape": 0x800c0f78,
		"MarioUtil::SMS_SettingDrawShape": 0x800c0fdc,
		"SMS_SettingDrawShape": 0x800c0fdc,
		"MarioUtil::SMS_DrawCube": 0x800c1048,
		"SMS_DrawCube": 0x800c1048,
		"MarioUtil::SMS_CountPolygonNumInShape": 0x800c11c8,
		"SMS_CountPolygonNumInShape": 0x800c11c8,
		"MarioUtil::ViewFrustumClipCheck": 0x800c12a4,
		"ViewFrustumClipCheck": 0x800c12a4,
		"MarioUtil::SetViewFrustumClipCheckPerspective": 0x800c1414,
		"SetViewFrustumClipCheckPerspective": 0x800c1414,
		"MarioUtil::SetViewFrustumClipCheck": 0x800c14bc,
		"SetViewFrustumClipCheck": 0x800c14bc,
		"MarioUtil::SMS_ResetDamageFogEffect": 0x800c1820,
		"SMS_ResetDamageFogEffect": 0x800c1820,
		"MarioUtil::SMS_AddDamageFogEffect": 0x800c18c4,
		"SMS_AddDamageFogEffect": 0x800c18c4,
		"TTrembleModelEffect::reset": 0x800c19e4,
		"TTrembleModelEffect::movement": 0x800c1bc4,
		"JGeometry::TVec3<short><short>::sub": 0x800c20bc,
		"TTrembleModelEffect::clash": 0x800c20f0,
		"clash": 0x800c20f0,
		"JGeometry::TVec3<short><short>::add": 0x800c233c,
		"TTrembleModelEffect::tremble": 0x800c2370,
		"tremble": 0x800c2370,
		"TTrembleModelEffect::init": 0x800c2734,
		"TSilhouette::perform": 0x800c2cc4,
		"TSilhouette::setting": 0x800c30bc,
		"setting": 0x800c30bc,
		"TSilhouette::loadAfter": 0x800c3258,
		"TSilhouette::load": 0x800c3494,
		"TLightWithDBSetManager::~TLightWithDBSetManager": 0x800c34f4,
		"TLightWithDBSetManager::getLightPos": 0x800c3568,
		"getLightPos": 0x800c3568,
		"TLightWithDBSetManager::makeDrawBuffer": 0x800c3570,
		"TLightWithDBSetManager::addChildGroupObj": 0x800c35e4,
		"addChildGroupObj": 0x800c35e4,
		"JGadget::TList_pointer<PQ26JDrama8TViewObj>::iterator::iterator": 0x800c3714,
		"JGadget::TList_pointer<JDrama::TViewObj*>::end": 0x800c3720,
		"TLightWithDBSetManager::perform": 0x800c3744,
		"TLightWithDBSetManager::loadAfter": 0x800c3840,
		"TLightWithDBSetManager::TLightWithDBSetManager": 0x800c38e4,
		"TLightWithDBSet::~TLightWithDBSet": 0x800c3ce8,
		"TIndirectLightWithDBSet::makeDrawBuffer": 0x800c3d5c,
		"TLightDrawBuffer::setLight": 0x800c3ef0,
		"TMapObjectLightWithDBSet::makeDrawBuffer": 0x800c3f24,
		"TObjectLightWithDBSet::makeDrawBuffer": 0x800c40b8,
		"TPlayerLightWithDBSet::makeDrawBuffer": 0x800c425c,
		"TLightCommon::~TLightCommon": 0x800c440c,
		"TLightWithDBSet::resetLightDrawBuffer": 0x800c4480,
		"resetLightDrawBuffer": 0x800c4480,
		"TLightWithDBSet::changeLightDrawBuffer": 0x800c44bc,
		"changeLightDrawBuffer": 0x800c44bc,
		"TLightWithDBSet::perform": 0x800c4534,
		"TLightDrawBuffer::perform": 0x800c467c,
		"TLightDrawBuffer::TLightDrawBuffer": 0x800c46c0,
		"TLightMario::getAmbColor": 0x800c47ec,
		"TLightMario::getLightColor": 0x800c48cc,
		"TLightMario::setLight": 0x800c49cc,
		"TLightMario::perform": 0x800c4c3c,
		"TLightShadow::perform": 0x800c4c7c,
		"TLightCommon::perform": 0x800c4cb8,
		"TLightCommon::setLight": 0x800c4dec,
		"TLightCommon::getLightPosition": 0x800c505c,
		"getLightPosition": 0x800c505c,
		"TLightCommon::getAmbColor": 0x800c50a8,
		"TLightCommon::getLightColor": 0x800c5134,
		"TLightCommon::loadAfter": 0x800c51ec,
		"TLightCommon::TLightCommon": 0x800c5378,
		"TIndirectLightWithDBSet::~TIndirectLightWithDBSet": 0x800c5444,
		"TMapObjectLightWithDBSet::~TMapObjectLightWithDBSet": 0x800c54c8,
		"TObjectLightWithDBSet::~TObjectLightWithDBSet": 0x800c554c,
		"TPlayerLightWithDBSet::~TPlayerLightWithDBSet": 0x800c55d0,
		"TLightDrawBuffer::~TLightDrawBuffer": 0x800c5654,
		"TLightMario::~TLightMario": 0x800c56c8,
		"TLightShadow::~TLightShadow": 0x800c574c,
		"MarioUtil::MsVECMag2": 0x800c57d0,
		"MsVECMag2": 0x800c57d0,
		"MarioUtil::MsVECNormalize": 0x800c57f8,
		"MsVECNormalize": 0x800c57f8,
		"MarioUtil::SMSCalcJumpVelocityXZ": 0x800c5824,
		"SMSCalcJumpVelocityXZ": 0x800c5824,
		"MarioUtil::SMSCalcJumpVelocityY": 0x800c5920,
		"SMSCalcJumpVelocityY": 0x800c5920,
		"MarioUtil::SMS_GoRotate": 0x800c59c8,
		"SMS_GoRotate": 0x800c59c8,
		"MarioUtil::MsIsInSight": 0x800c5ab0,
		"MsIsInSight": 0x800c5ab0,
		"MarioUtil::MsWrap": 0x800c5c50,
		"MarioUtil::MsMtxSetTRS": 0x800c5ca4,
		"MsMtxSetTRS": 0x800c5ca4,
		"MarioUtil::MsMtxSetXYZRPH": 0x800c5de8,
		"MsMtxSetXYZRPH": 0x800c5de8,
		"MarioUtil::MsMtxSetRotRPH": 0x800c5e98,
		"MsMtxSetRotRPH": 0x800c5e98,
		"MarioUtil::MsGetRotFromZaxis": 0x800c5f90,
		"MsGetRotFromZaxis": 0x800c5f90,
		"MarioUtil::matan": 0x800c61c4,
		"matan": 0x800c61c4,
		"MarioUtil::FConverge": 0x800c6468,
		"FConverge": 0x800c6468,
		"MarioUtil::IConverge": 0x800c6498,
		"IConverge": 0x800c6498,
		"MarioUtil::SMS_GetActorMtx": 0x800c64c8,
		"SMS_GetActorMtx": 0x800c64c8,
		"TRope::moveHead": 0x800c6540,
		"TRope::constraintTail": 0x800c66cc,
		"constraintTail": 0x800c66cc,
		"TRope::constraintHead": 0x800c68f8,
		"constraintHead": 0x800c68f8,
		"TRope::collision": 0x800c6a9c,
		"collision": 0x800c6a9c,
		"TRope::TRope": 0x800c6c04,
		"TRopePoint::TRopePoint": 0x800c6e54,
		"MarioUtil::SMS_GetLightPerspectiveForEffectMtx": 0x800c6e58,
		"SMS_GetLightPerspectiveForEffectMtx": 0x800c6e58,
		"MarioUtil::SMS_MakeJointsToArc": 0x800c6ec4,
		"SMS_MakeJointsToArc": 0x800c6ec4,
		"TMultiMtxEffect::setUserArea": 0x800c736c,
		"setUserArea": 0x800c736c,
		"TMultiMtxEffect::setup": 0x800c73bc,
		"JGeometry::TVec3<float><float>::__ct": 0x800c78d4,
		"__ct": 0x800c78d4,
		"TParamT<JGeometry::TVec3<float><float>>::TParamT": 0x800c78e4,
		"MarioUtil::TMtxSwingRZReverseXZCallBack": 0x800c79a8,
		"TMtxSwingRZReverseXZCallBack": 0x800c79a8,
		"MarioUtil::TMtxSwingRZCallBack": 0x800c7a54,
		"TMtxSwingRZCallBack": 0x800c7a54,
		"TMtxSwingRZ::calcLocalXY": 0x800c7ae8,
		"calcLocalXY": 0x800c7ae8,
		"MarioUtil::TMtxTimeLagCallBack": 0x800c7d48,
		"TMtxTimeLagCallBack": 0x800c7d48,
		"TMtxTimeLag::calc": 0x800c7d80,
		"MarioUtil::MtxToQuat": 0x800c8314,
		"MtxToQuat": 0x800c8314,
		"TMtxSwingRZ::getParams": 0x800c8544,
		"TMtxTimeLag::getParams": 0x800c854c,
		"TMtxEffectBase::getParams": 0x800c8554,
		"TScreenTexture::~TScreenTexture": 0x800c855c,
		"TScreenTexture::perform": 0x800c85d0,
		"MarioUtil::SMS_FillScreenAlpha": 0x800c85d4,
		"SMS_FillScreenAlpha": 0x800c85d4,
		"TScreenTexture::replace": 0x800c8790,
		"replace": 0x800c8790,
		"TScreenTexture::load": 0x800c88a4,
		"TAfterEffect::perform": 0x800c8928,
		"TAfterEffect::calcDashBlurValue": 0x800c90c8,
		"calcDashBlurValue": 0x800c90c8,
		"TAfterEffect::loadAfter": 0x800c91a4,
		"TAfterEffect::load": 0x800c921c,
		"TAfterEffect::~TAfterEffect": 0x800c9308,
		"TMBindShadowManager::~TMBindShadowManager": 0x800c937c,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::erase": 0x800c9488,
		"JGadget::TList<P16TMBindShadowBody,Q27JGadget31TAllocator<P16TMBindShadowBody>>::iterator::iterator": 0x800c94f4,
		"TMBindShadowManager::calcVtx": 0x800c94fc,
		"calcVtx": 0x800c94fc,
		"TMBindShadowManager::forceRequest": 0x800c9fec,
		"forceRequest": 0x800c9fec,
		"TMBindShadowManager::request": 0x800ca11c,
		"TMBindShadowManager::drawShadow": 0x800ca444,
		"drawShadow": 0x800ca444,
		"TMBindShadowManager::drawShadowGD": 0x800cae70,
		"drawShadowGD": 0x800cae70,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::~TSetup5$2216ShadowUtil_cpp": 0x800cb7b4,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::~TSetup4$2207ShadowUtil_cpp": 0x800cb818,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::~TSetup3$2195ShadowUtil_cpp": 0x800cb87c,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::~TSetup2$2190ShadowUtil_cpp": 0x800cb8e0,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::~TCylinder$2171ShadowUtil_cpp": 0x800cb944,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::~TSetup1$2172ShadowUtil_cpp": 0x800cb9a8,
		"TMBindShadowManager::drawShadowVolume": 0x800cba0c,
		"drawShadowVolume": 0x800cba0c,
		"MarioUtil::conectCubeSame": 0x800cc298,
		"conectCubeSame": 0x800cc298,
		"MarioUtil::conectCubeDiffer": 0x800cc3dc,
		"conectCubeDiffer": 0x800cc3dc,
		"TMBindShadowManager::perform": 0x800cc538,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::insert": 0x800cc600,
		"TMBindShadowManager::load": 0x800cc6b8,
		"TMBindShadowManager::TMBindShadowManager": 0x800cc814,
		"TAlphaShadowBlendQuad::TAlphaShadowBlendQuad": 0x800cca4c,
		"TAlphaShadowQuadAry::TAlphaShadowQuadAry": 0x800cca7c,
		"TAlphaShadowQuad::TAlphaShadowQuad": 0x800cca94,
		"TCircleShadowRequest::TCircleShadowRequest": 0x800ccab0,
		"TModelShadowInfo::TModelShadowInfo": 0x800ccae8,
		"TSquareShadowInfo::TSquareShadowInfo": 0x800ccb14,
		"TMBindShadowBody::entryDrawShadow": 0x800ccb40,
		"entryDrawShadow": 0x800ccb40,
		"TMBindShadowBody::TMBindShadowBody": 0x800cce4c,
		"TMBindShadowParts::calc": 0x800cd224,
		"TMBindShadowParts::TMBindShadowParts": 0x800cd49c,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::makeDL": 0x800cd568,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::makeDL": 0x800cd5c8,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::makeDL": 0x800cd628,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::makeDL": 0x800cd67c,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::makeDL": 0x800cd6dc,
		"MarioUtil::GDOverflowCheck": 0x800ce220,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::makeDL": 0x800ce258,
		"MarioUtil::ReInitTevStages": 0x800ce35c,
		"ReInitTevStages": 0x800ce35c,
		"MarioUtil::ReInitTransform": 0x800ce5c8,
		"ReInitTransform": 0x800ce5c8,
		"MarioUtil::ReInitGeometry": 0x800ce834,
		"ReInitGeometry": 0x800ce834,
		"MarioUtil::ReInitializeGX": 0x800ce948,
		"ReInitializeGX": 0x800ce948,
		"MarioUtil::SMS_EmitSinkInPollutionEffect": 0x800ceb9c,
		"SMS_EmitSinkInPollutionEffect": 0x800ceb9c,
		"MarioUtil::SMS_EmitRippleSea": 0x800ced84,
		"SMS_EmitRippleSea": 0x800ced84,
		"MarioUtil::SMS_EmitRipplePool": 0x800cee34,
		"SMS_EmitRipplePool": 0x800cee34,
		"MarioUtil::SMS_EmitRippleTiny": 0x800ceee4,
		"SMS_EmitRippleTiny": 0x800ceee4,
		"MarioUtil::SMS_CreateMinimumSDLModel": 0x800cef64,
		"SMS_CreateMinimumSDLModel": 0x800cef64,
		"MarioUtil::SMS_CreatePartsModel": 0x800cefe8,
		"SMS_CreatePartsModel": 0x800cefe8,
		"MarioUtil::SMS_RideMoveCalcLocalPos": 0x800cf058,
		"SMS_RideMoveCalcLocalPos": 0x800cf058,
		"MarioUtil::SMS_RideMoveByGroundActor": 0x800cf0f8,
		"SMS_RideMoveByGroundActor": 0x800cf0f8,
		"TMultiBtk::update": 0x800cf28c,
		"TMultiBtk::setNthData": 0x800cf318,
		"setNthData": 0x800cf318,
		"TMultiBtk::TMultiBtk": 0x800cf414,
		"RumbleMgr::finishPause": 0x800cf4d8,
		"finishPause": 0x800cf4d8,
		"RumbleMgr::startPause": 0x800cf4ec,
		"startPause": 0x800cf4ec,
		"RumbleMgr::setActive": 0x800cf560,
		"setActive": 0x800cf560,
		"RumbleMgr::update": 0x800cf614,
		"RumbleMgr::reset": 0x800cfbe8,
		"RumbleMgr::init": 0x800cfddc,
		"RumbleMgr::RumbleMgr": 0x800cfff0,
		"RumbleControllerMgr::update": 0x800d0128,
		"RumbleControllerMgr::updateMotorCount": 0x800d020c,
		"updateMotorCount": 0x800d020c,
		"RumbleControllerMgr::stop": 0x800d028c,
		"RumbleControllerMgr::reset": 0x800d0478,
		"RumbleChannelMgr::update": 0x800d0600,
		"RumbleChannelMgr::RumbleChannelMgr": 0x800d08e8,
		"RumbleType::getIndex": 0x800d0914,
		"MarioUtil::SMS_ShowAllShapePacket": 0x800d0988,
		"SMS_ShowAllShapePacket": 0x800d0988,
		"MarioUtil::SMS_HideAllShapePacket": 0x800d0a88,
		"SMS_HideAllShapePacket": 0x800d0a88,
		"MarioUtil::SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x800d0b88,
		"SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x800d0b88,
		"MarioUtil::SMS_InitPacket_OneTevColorAndOneTevKColor": 0x800d0c18,
		"SMS_InitPacket_OneTevColorAndOneTevKColor": 0x800d0c18,
		"MarioUtil::SMS_InitPacket_OneTevKColorAndFog": 0x800d0cb0,
		"SMS_InitPacket_OneTevKColorAndFog": 0x800d0cb0,
		"MarioUtil::SMS_InitPacket_TwoTevKColor": 0x800d0d98,
		"SMS_InitPacket_TwoTevKColor": 0x800d0d98,
		"MarioUtil::SMS_InitPacket_OneTevKColor": 0x800d0e20,
		"SMS_InitPacket_OneTevKColor": 0x800d0e20,
		"MarioUtil::SMS_InitPacket_Fog": 0x800d0ea8,
		"SMS_InitPacket_Fog": 0x800d0ea8,
		"MarioUtil::SMS_InitPacket_ThreeTevColor": 0x800d0f34,
		"SMS_InitPacket_ThreeTevColor": 0x800d0f34,
		"MarioUtil::SMS_InitPacket_TwoTevColor": 0x800d0fcc,
		"SMS_InitPacket_TwoTevColor": 0x800d0fcc,
		"MarioUtil::SMS_InitPacket_OneTevColor": 0x800d1054,
		"SMS_InitPacket_OneTevColor": 0x800d1054,
		"MarioUtil::SMS_InitPacket_MatColor": 0x800d10dc,
		"SMS_InitPacket_MatColor": 0x800d10dc,
		"MarioUtil::ShapePacketCallBackFunc": 0x800d1164,
		"ShapePacketCallBackFunc": 0x800d1164,
		"MarioUtil::FifoSetFog": 0x800d18f4,
		"FifoSetFog": 0x800d18f4,
		"MarioUtil::FifoSetFogRangeAdj": 0x800d1a4c,
		"FifoSetFogRangeAdj": 0x800d1a4c,
		"TGDLStatic::make": 0x800d1b84,
		"make": 0x800d1b84,
		"TGDLStatic::alloc": 0x800d1d14,
		"TGDLStatic::~TGDLStatic": 0x800d1dc0,
		"TGDLStatic::TGDLSentinel::~TGDLSentinel": 0x800d1e14,
		"MarioUtil::TGDLStaticOverFlow": 0x800d1e8c,
		"TGDLStaticOverFlow": 0x800d1e8c,
		"MarioUtil::SMS_ChangeTextureAll": 0x800d1e9c,
		"SMS_ChangeTextureAll": 0x800d1e9c,
		"MarioUtil::SMS_GetSandRiseUpRatio": 0x800d1fb8,
		"SMS_GetSandRiseUpRatio": 0x800d1fb8,
		"MarioUtil::SMS_GetGroundActor": 0x800d2004,
		"SMS_GetGroundActor": 0x800d2004,
		"MarioUtil::SMS_GetMonteVillageAreaInMario": 0x800d2038,
		"SMS_GetMonteVillageAreaInMario": 0x800d2038,
		"Koga::ToolData::Attach": 0x800d2234,
		"Attach": 0x800d2234,
		"Koga::ToolData::~ToolData": 0x800d2250,
		"Koga::ToolData::ToolData": 0x800d229c,
		"M3DUtil::M3UMtxCalcBlendAux": 0x800d27f0,
		"M3UMtxCalcBlendAux": 0x800d27f0,
		"M3UModel::setMtxCalc": 0x800d2c0c,
		"setMtxCalc": 0x800d2c0c,
		"M3UModel::perform": 0x800d2c10,
		"M3UModel::entryOut": 0x800d2ce8,
		"M3UModel::entryIn": 0x800d2d38,
		"M3UModel::updateOut": 0x800d2db4,
		"M3UModel::updateIn": 0x800d2dfc,
		"M3UModel::updateInTexPatternAnm": 0x800d2e48,
		"updateInTexPatternAnm": 0x800d2e48,
		"M3UModel::updateInMotion": 0x800d2e84,
		"M3UModel::changeAnmTexPattern": 0x800d2fa8,
		"changeAnmTexPattern": 0x800d2fa8,
		"M3UModel::changeMtxCalcAnmTransform": 0x800d2fec,
		"changeMtxCalcAnmTransform": 0x800d2fec,
		"M3UModelCommon::getMtxCalc": 0x800d3030,
		"MActor::updateMatAnm": 0x800d308c,
		"updateMatAnm": 0x800d308c,
		"MActor::entryOut": 0x800d3120,
		"MActorAnmBase::updateOut": 0x800d319c,
		"MActor::entryIn": 0x800d31a0,
		"MActorAnmBase::updateIn": 0x800d321c,
		"MActor::updateOut": 0x800d3220,
		"MActor::updateIn": 0x800d3304,
		"MActor::setBrkFromIndex": 0x800d33e8,
		"setBrkFromIndex": 0x800d33e8,
		"MActorAnmMatEach<J3DAnmTevRegKey>::setAnmFromIndex": 0x800d3438,
		"MActor::setBrk": 0x800d3500,
		"setBrk": 0x800d3500,
		"MActorAnmEach<J3DAnmTevRegKey>::setAnm": 0x800d3550,
		"MActor::setBlk": 0x800d367c,
		"setBlk": 0x800d367c,
		"MActorAnmEach<J3DAnmClusterKey>::setAnm": 0x800d36cc,
		"MActor::setBtkFromIndex": 0x800d37f8,
		"setBtkFromIndex": 0x800d37f8,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::setAnmFromIndex": 0x800d3848,
		"MActor::setBtk": 0x800d3910,
		"setBtk": 0x800d3910,
		"MActorAnmEach<J3DAnmTextureSRTKey>::setAnm": 0x800d3960,
		"MActor::setBtpFromIndex": 0x800d3a8c,
		"setBtpFromIndex": 0x800d3a8c,
		"MActorAnmMatEach<J3DAnmTexPattern>::setAnmFromIndex": 0x800d3aec,
		"MActor::setBtp": 0x800d3bb4,
		"setBtp": 0x800d3bb4,
		"MActorAnmEach<J3DAnmTexPattern>::setAnm": 0x800d3c04,
		"MActor::setBpkFromIndex": 0x800d3d30,
		"setBpkFromIndex": 0x800d3d30,
		"MActorAnmMatEach<J3DAnmColorKey>::setAnmFromIndex": 0x800d3d80,
		"MActor::setBpk": 0x800d3e48,
		"setBpk": 0x800d3e48,
		"MActorAnmEach<J3DAnmColorKey>::setAnm": 0x800d3e98,
		"MActorAnmEach<J3DAnmTransformKey>::setAnm": 0x800d3fc4,
		"MActor::checkCurBckFromIndex": 0x800d40f0,
		"checkCurBckFromIndex": 0x800d40f0,
		"MActor::setBckFromIndex": 0x800d4120,
		"setBckFromIndex": 0x800d4120,
		"MActor::setBck": 0x800d415c,
		"setBck": 0x800d415c,
		"MActor::setFrameRate": 0x800d4198,
		"setFrameRate": 0x800d4198,
		"MActor::getCurAnmIdx": 0x800d41b4,
		"getCurAnmIdx": 0x800d41b4,
		"MActor::checkBckPass": 0x800d41d8,
		"checkBckPass": 0x800d41d8,
		"MActor::getFrameCtrl": 0x800d4224,
		"MActor::checkAnmFileExist": 0x800d4248,
		"checkAnmFileExist": 0x800d4248,
		"MActor::checkCurAnmFromIndex": 0x800d4368,
		"checkCurAnmFromIndex": 0x800d4368,
		"MActor::checkCurAnm": 0x800d43a0,
		"checkCurAnm": 0x800d43a0,
		"MActor::perform": 0x800d44d8,
		"MActor::matAnmFrameUpdate": 0x800d46b0,
		"matAnmFrameUpdate": 0x800d46b0,
		"MActor::frameUpdate": 0x800d4724,
		"frameUpdate": 0x800d4724,
		"MActor::entry": 0x800d47e4,
		"MActor::setLightType": 0x800d4930,
		"setLightType": 0x800d4930,
		"MActor::setLightData": 0x800d4950,
		"setLightData": 0x800d4950,
		"MActor::setLightID": 0x800d49f0,
		"setLightID": 0x800d49f0,
		"MActor::viewCalc": 0x800d4a04,
		"MActor::calc": 0x800d4a40,
		"MActor::calcAnm": 0x800d4b48,
		"calcAnm": 0x800d4b48,
		"MActor::updateOutSubBck": 0x800d4cdc,
		"updateOutSubBck": 0x800d4cdc,
		"MActor::updateInSubBck": 0x800d4d68,
		"updateInSubBck": 0x800d4d68,
		"MActor::setJointCallback": 0x800d4df4,
		"setJointCallback": 0x800d4df4,
		"MActor::offMakeDL": 0x800d4e10,
		"offMakeDL": 0x800d4e10,
		"MActor::unlockDLIfNeed": 0x800d4e58,
		"unlockDLIfNeed": 0x800d4e58,
		"MActor::resetDL": 0x800d4ec8,
		"resetDL": 0x800d4ec8,
		"MActor::initDL": 0x800d500c,
		"initDL": 0x800d500c,
		"MActor::setAnimation": 0x800d5134,
		"MActor::curAnmEndsNext": 0x800d51ac,
		"curAnmEndsNext": 0x800d51ac,
		"MActor::isCurAnmAlreadyEnd": 0x800d5318,
		"isCurAnmAlreadyEnd": 0x800d5318,
		"MActor::setModel": 0x800d53e0,
		"MActorAnmBase::setModel": 0x800d56d0,
		"MActor::MActor": 0x800d56d8,
		"MActorAnmBase::MActorAnmBase": 0x800d5bd0,
		"MActorAnmBlk::verifySuffix": 0x800d5c34,
		"MActorAnmBlk::setAnmFromIndex": 0x800d5c5c,
		"MActorAnmBlk::updateOut": 0x800d5cdc,
		"MActorAnmBlk::updateIn": 0x800d5d04,
		"MActorAnmBrk::checkUseMaterialID": 0x800d5d80,
		"MActorAnmBrk::checkUseMaterialIDInit": 0x800d5dc0,
		"MActorAnmBrk::updateOut": 0x800d5e00,
		"MActorAnmBrk::updateIn": 0x800d5e2c,
		"MActorAnmBrk::setTevKColorAnmKeyPtr": 0x800d5e80,
		"setTevKColorAnmKeyPtr": 0x800d5e80,
		"J3DTevKColorAnm::~J3DTevKColorAnm": 0x800d5f90,
		"J3DTevKColorAnm::J3DTevKColorAnm": 0x800d5fd0,
		"MActorAnmBrk::setTevColorAnmKeyPtr": 0x800d5fe0,
		"setTevColorAnmKeyPtr": 0x800d5fe0,
		"J3DTevColorAnm::~J3DTevColorAnm": 0x800d60f0,
		"J3DTevColorAnm::J3DTevColorAnm": 0x800d6130,
		"MActorAnmBpk::updateOut": 0x800d6140,
		"MActorAnmBpk::updateIn": 0x800d616c,
		"MActorAnmBpk::setMatColorAnmKeyPtr": 0x800d61b8,
		"setMatColorAnmKeyPtr": 0x800d61b8,
		"J3DMatColorAnm::~J3DMatColorAnm": 0x800d62c8,
		"J3DMatColorAnm::J3DMatColorAnm": 0x800d6308,
		"MActorAnmBpk::checkUseMaterialID": 0x800d6318,
		"MActorAnmBpk::checkUseMaterialIDInit": 0x800d6370,
		"MActorAnmBtk::updateOut": 0x800d6458,
		"MActorAnmBtk::updateIn": 0x800d6484,
		"MActorAnmBtk::setTexMtxAnmKeyPtr": 0x800d64d4,
		"setTexMtxAnmKeyPtr": 0x800d64d4,
		"J3DTexMtxAnm::~J3DTexMtxAnm": 0x800d65fc,
		"J3DTexMtxAnm::J3DTexMtxAnm": 0x800d663c,
		"MActorAnmBtk::checkUseMaterialID": 0x800d664c,
		"MActorAnmBtk::checkUseMaterialIDInit": 0x800d66bc,
		"MActorAnmBtp::updateOut": 0x800d67bc,
		"MActorAnmBtp::updateIn": 0x800d67e8,
		"MActorAnmBtp::checkUseMaterialID": 0x800d6834,
		"MActorAnmBtp::checkUseMaterialIDInit": 0x800d688c,
		"MActorAnmBtp::setTexNoAnmFullPtr": 0x800d6980,
		"setTexNoAnmFullPtr": 0x800d6980,
		"MActorAnmBck::setAnmFromIndex": 0x800d6afc,
		"MActorAnmBck::updateOut": 0x800d6c0c,
		"MActorAnmBck::updateIn": 0x800d6c30,
		"MActorAnmBck::setModel": 0x800d6d10,
		"J3DMtxCalcBasicAnm::J3DMtxCalcBasicAnm": 0x800d6de0,
		"MActorAnmBck::getOldMotionBlendFrame": 0x800d6fb0,
		"MActorAnmBck::setOldMotionBlendAnmPtr": 0x800d6fe4,
		"MActorAnmBck::getOldMotionBlendAnmPtr": 0x800d7010,
		"MActorAnmBck::setMotionBlendRatio": 0x800d7044,
		"MActorAnmBck::getMotionBlendRatio": 0x800d7070,
		"MActorAnmBck::initNormalMotionBlend": 0x800d70a4,
		"initNormalMotionBlend": 0x800d70a4,
		"MActorAnmBck::initSimpleMotionBlend": 0x800d7124,
		"initSimpleMotionBlend": 0x800d7124,
		"MActorAnmBase::checkUseMaterialID": 0x800d71b4,
		"MActorAnmBase::checkUseMaterialIDInit": 0x800d71b8,
		"MActorAnmBrk::verifySuffix": 0x800d71bc,
		"MActorAnmBpk::verifySuffix": 0x800d71e4,
		"MActorAnmBtk::verifySuffix": 0x800d720c,
		"MActorAnmBtp::verifySuffix": 0x800d7234,
		"MActorAnmBck::verifySuffix": 0x800d725c,
		"MActorAnmData::createSampleModelData": 0x800d7284,
		"createSampleModelData": 0x800d7284,
		"MActorAnmData::addFileTable": 0x800d72e0,
		"addFileTable": 0x800d72e0,
		"MActorAnmData::init": 0x800d775c,
		"MActorAnmData::partsNameToIdx": 0x800d7d34,
		"partsNameToIdx": 0x800d7d34,
		"M3DUtil::MActorCalcKeyCode": 0x800d7dd4,
		"MActorCalcKeyCode": 0x800d7dd4,
		"MActorAnmData::MActorAnmData": 0x800d7e04,
		"MActorAnmDataBase::sortByFileNameRaw": 0x800d7f90,
		"sortByFileNameRaw": 0x800d7f90,
		"MActorAnmDataBase::checkLower": 0x800d81b0,
		"checkLower": 0x800d81b0,
		"MActorAnmDataEach<J3DAnmClusterKey>::loadAnmPtrArray": 0x800d8278,
		"MActorAnmDataEach<J3DAnmTevRegKey>::loadAnmPtrArray": 0x800d8368,
		"MActorAnmDataEach<J3DAnmTextureSRTKey>::loadAnmPtrArray": 0x800d8458,
		"MActorAnmDataEach<J3DAnmTexPattern>::loadAnmPtrArray": 0x800d8548,
		"MActorAnmDataEach<J3DAnmColorKey>::loadAnmPtrArray": 0x800d8638,
		"MActorAnmDataEach<J3DAnmTransformKey>::loadAnmPtrArray": 0x800d8728,
		"SDLModel::~SDLModel": 0x800d8818,
		"SDLModel::viewCalcSimple": 0x800d887c,
		"viewCalcSimple": 0x800d887c,
		"SDLModel::entry": 0x800d8954,
		"JGadget::TList<SDLDrawBufToken*,JGadget::TAllocator<SDLDrawBufToken*>>::insert": 0x800d8ad4,
		"SDLModel::entryModelDataSDL": 0x800d8b8c,
		"entryModelDataSDL": 0x800d8b8c,
		"SDLMatPacket::~SDLMatPacket": 0x800d9214,
		"SDLModel::SDLModel": 0x800d9278,
		"SDLMatPacket::SDLMatPacket": 0x800d930c,
		"SDLModelData::entrySDLModels": 0x800d9348,
		"entrySDLModels": 0x800d9348,
		"SDLModelData::SDLModelData": 0x800d9544,
		"SDLModelData::recursiveEntry": 0x800d95a8,
		"SDLModelData::entryNode": 0x800d98b4,
		"entryNode": 0x800d98b4,
		"SDLModelData::entrySameMat": 0x800d9940,
		"entrySameMat": 0x800d9940,
		"M3DUtil::SMS_MakeMActor": 0x800d9a74,
		"SMS_MakeMActor": 0x800d9a74,
		"M3DUtil::SMS_MakeMActorWithAnmData": 0x800d9aec,
		"SMS_MakeMActorWithAnmData": 0x800d9aec,
		"M3DUtil::SMS_MakeMActorsWithAnmData": 0x800d9b88,
		"SMS_MakeMActorsWithAnmData": 0x800d9b88,
		"M3DUtil::SMS_MakeSDLModelData": 0x800d9c6c,
		"SMS_MakeSDLModelData": 0x800d9c6c,
		"M3DUtil::SMS_MakeMActorFromSDLModelData": 0x800d9ccc,
		"SMS_MakeMActorFromSDLModelData": 0x800d9ccc,
		"SampleCtrlShape::SampleCtrlShape": 0x800d9d6c,
		"SampleCtrlMaterial::SampleCtrlMaterial": 0x800d9db8,
		"SampleCtrlJoint::SampleCtrlJoint": 0x800da294,
		"SampleCtrlJoint::~SampleCtrlJoint": 0x800da2f8,
		"SampleCtrlMaterial::~SampleCtrlMaterial": 0x800da344,
		"SampleCtrlShape::~SampleCtrlShape": 0x800da390,
		"SampleCtrlModelData::SampleCtrlModelData": 0x800da3dc,
		"SampleCtrlModelData::makeHierarchy": 0x800da5bc,
		"SampleCtrlModelData::~SampleCtrlModelData": 0x800da6b8,
		"TMotionBlendCtrl::getOldMotionBlendFrame": 0x800da704,
		"TMotionBlendCtrl::setOldMotionBlendAnmPtr": 0x800da710,
		"TMotionBlendCtrl::getOldMotionBlendAnmPtr": 0x800da71c,
		"TMotionBlendCtrl::setNewAnm": 0x800da728,
		"setNewAnm": 0x800da728,
		"TMotionBlendCtrl::keepCurAnm": 0x800da74c,
		"keepCurAnm": 0x800da74c,
		"TMotionBlendCtrl::setMotionBlendRatio": 0x800da760,
		"TMotionBlendCtrl::getMotionBlendRatio": 0x800da76c,
		"TMotionBlendCtrl::execSimpleMotionBlend": 0x800da778,
		"execSimpleMotionBlend": 0x800da778,
		"M3DUtil::CLBPalFrame": 0x800da8f0,
		"M3DUtil::CLBRoundf": 0x800da948,
		"TLodAnm::setBckAndBtpAnm": 0x800da97c,
		"setBckAndBtpAnm": 0x800da97c,
		"TLodAnm::setBtpAnm_": 0x800da9e0,
		"setBtpAnm_": 0x800da9e0,
		"TLodAnm::setBckAnm_": 0x800daab8,
		"setBckAnm_": 0x800daab8,
		"TLodAnm::TLodAnm": 0x800dab9c,
		"TBaseParam::TBaseParam": 0x800dabf4,
		"TBaseParam::load": 0x800dac44,
		"TMarioParticleManager::~TMarioParticleManager": 0x800dac48,
		"System::SMSSetEmitterPolColor": 0x800dacbc,
		"SMSSetEmitterPolColor": 0x800dacbc,
		"TMarioParticleManager::getAvailableIdx": 0x800dadd8,
		"getAvailableIdx": 0x800dadd8,
		"TMarioParticleManager::emitTry": 0x800daefc,
		"emitTry": 0x800daefc,
		"TMarioParticleManager::emitParticleCallBack": 0x800db0b4,
		"emitParticleCallBack": 0x800db0b4,
		"TMarioParticleManager::emitAndBindToMtx": 0x800db244,
		"emitAndBindToMtx": 0x800db244,
		"TMarioParticleManager::emitAndBindToSRTMtxPtr": 0x800db348,
		"emitAndBindToSRTMtxPtr": 0x800db348,
		"TMarioParticleManager::emitAndBindToMtxPtr": 0x800db58c,
		"emitAndBindToMtxPtr": 0x800db58c,
		"TMarioParticleManager::emitAndBindToPosPtr": 0x800db7d0,
		"emitAndBindToPosPtr": 0x800db7d0,
		"TMarioParticleManager::emitWithRotate": 0x800db9fc,
		"emitWithRotate": 0x800db9fc,
		"TMarioParticleManager::emit": 0x800dbb1c,
		"TMarioParticleManager::perform": 0x800dbd30,
		"TMarioParticleManager::createEffectInfoAry": 0x800dc0d8,
		"createEffectInfoAry": 0x800dc0d8,
		"TMarioParticleManager::TMarioParticleManager": 0x800dc19c,
		"TMarioParticleManager::TInfo::TInfo": 0x800dc208,
		"TMarioEmitterCallBackBindToSRTMtxPtr::draw": 0x800dc228,
		"TMarioEmitterCallBackBindToSRTMtxPtr::execute": 0x800dc22c,
		"TMarioEmitterCallBackBindToMtxPtr::draw": 0x800dc258,
		"TMarioEmitterCallBackBindToMtxPtr::execute": 0x800dc25c,
		"TMarioEmitterCallBackBindToPosPtr::draw": 0x800dc288,
		"TMarioEmitterCallBackBindToPosPtr::execute": 0x800dc28c,
		"TEmitterIndirectViewObj::perform": 0x800dc2ac,
		"TEmitterViewObj::perform": 0x800dc368,
		"TEmitterViewObj::TEmitterViewObj": 0x800dc40c,
		"TEmitterIndirectViewObj::~TEmitterIndirectViewObj": 0x800dc484,
		"TEmitterViewObj::~TEmitterViewObj": 0x800dc508,
		"System::__sinit_EmitterViewObj_cpp": 0x800dc57c,
		"__sinit_EmitterViewObj_cpp": 0x800dc57c,
		"TEventWatcher::perform": 0x800dc614,
		"TEventWatcher::launchScript": 0x800dc654,
		"launchScript": 0x800dc654,
		"TSpcTypedBinary<TEventWatcher>::initUserBuiltin": 0x800dc818,
		"System::evIsWaterMelonIsReached": 0x800dcf34,
		"evIsWaterMelonIsReached": 0x800dcf34,
		"System::SpcTrace": 0x800dd0a4,
		"System::evInvalidatePad": 0x800dd0f4,
		"evInvalidatePad": 0x800dd0f4,
		"System::evOnNeutralMarioKey": 0x800dd238,
		"evOnNeutralMarioKey": 0x800dd238,
		"System::evWarpFrontToMario": 0x800dd2d8,
		"evWarpFrontToMario": 0x800dd2d8,
		"System::evAppear8RedCoinsAndTimer": 0x800dd528,
		"evAppear8RedCoinsAndTimer": 0x800dd528,
		"System::evAppearReadyGo": 0x800dd710,
		"evAppearReadyGo": 0x800dd710,
		"System::evSetEventForWaterMelon": 0x800dd7b0,
		"evSetEventForWaterMelon": 0x800dd7b0,
		"System::evStartAppearJetBalloon": 0x800dd974,
		"evStartAppearJetBalloon": 0x800dd974,
		"System::evWarpMario": 0x800ddbd0,
		"evWarpMario": 0x800ddbd0,
		"System::evSetCollision": 0x800ddf50,
		"evSetCollision": 0x800ddf50,
		"System::evChangeSunglass": 0x800de1c4,
		"evChangeSunglass": 0x800de1c4,
		"System::evStartMiss": 0x800de3b8,
		"evStartMiss": 0x800de3b8,
		"System::evStartEventSE": 0x800de450,
		"evStartEventSE": 0x800de450,
		"System::evStartSE": 0x800de5d8,
		"evStartSE": 0x800de5d8,
		"System::evStopBGM": 0x800de73c,
		"evStopBGM": 0x800de73c,
		"System::evPutNozzle": 0x800de878,
		"evPutNozzle": 0x800de878,
		"System::evEggYoshiStartFruit": 0x800dea48,
		"evEggYoshiStartFruit": 0x800dea48,
		"System::evStartBGM": 0x800dec18,
		"evStartBGM": 0x800dec18,
		"System::evManiCoinDown": 0x800ded50,
		"evManiCoinDown": 0x800ded50,
		"System::evSetEventID": 0x800dedec,
		"evSetEventID": 0x800dedec,
		"System::evSetTransScale": 0x800df044,
		"evSetTransScale": 0x800df044,
		"System::evIsInsideFastCube": 0x800df6b8,
		"evIsInsideFastCube": 0x800df6b8,
		"System::evIsFinishMareBottleDemo": 0x800df978,
		"evIsFinishMareBottleDemo": 0x800df978,
		"System::evStartMareBottleDemo": 0x800dfa6c,
		"evStartMareBottleDemo": 0x800dfa6c,
		"System::evSetMarioWaiting": 0x800dfb7c,
		"evSetMarioWaiting": 0x800dfb7c,
		"System::evIsInsideCube": 0x800dfc24,
		"evIsInsideCube": 0x800dfc24,
		"System::evKillWoodBox": 0x800dfda8,
		"evKillWoodBox": 0x800dfda8,
		"System::evRefreshWoodBox": 0x800e004c,
		"evRefreshWoodBox": 0x800e004c,
		"System::evCheckWoodBox": 0x800e02f0,
		"evCheckWoodBox": 0x800e02f0,
		"System::evStartMarioTalking": 0x800e059c,
		"evStartMarioTalking": 0x800e059c,
		"System::evChangeNozzle": 0x800e0634,
		"evChangeNozzle": 0x800e0634,
		"System::evAppearShineForWoodBox": 0x800e0790,
		"evAppearShineForWoodBox": 0x800e0790,
		"System::evAppearShineFromKageMario": 0x800e08fc,
		"evAppearShineFromKageMario": 0x800e08fc,
		"System::evAppearShineFromNPCWithoutDemo": 0x800e0bb8,
		"evAppearShineFromNPCWithoutDemo": 0x800e0bb8,
		"System::evAppearShine": 0x800e0e48,
		"evAppearShine": 0x800e0e48,
		"System::evAppearShineFromNPC": 0x800e1070,
		"evAppearShineFromNPC": 0x800e1070,
		"System::evAppearMushroom1up": 0x800e13d4,
		"evAppearMushroom1up": 0x800e13d4,
		"System::evKillMushroom1up": 0x800e15f8,
		"evKillMushroom1up": 0x800e15f8,
		"System::evKillShine": 0x800e17f4,
		"evKillShine": 0x800e17f4,
		"System::evGetTime": 0x800e19c4,
		"evGetTime": 0x800e19c4,
		"System::evMonteManReachFlag": 0x800e1a60,
		"evMonteManReachFlag": 0x800e1a60,
		"System::evStopTimer": 0x800e1b4c,
		"evStopTimer": 0x800e1b4c,
		"System::evStartMonteman": 0x800e1be8,
		"evStartMonteman": 0x800e1be8,
		"System::evStartTimer": 0x800e1d74,
		"evStartTimer": 0x800e1d74,
		"System::evInsertTimer": 0x800e1ee0,
		"evInsertTimer": 0x800e1ee0,
		"System::evForceCloseTalk": 0x800e2114,
		"evForceCloseTalk": 0x800e2114,
		"System::evRaiseBuilding": 0x800e21ac,
		"evRaiseBuilding": 0x800e21ac,
		"System::evIsMapEventFinishedAll": 0x800e233c,
		"evIsMapEventFinishedAll": 0x800e233c,
		"System::evStartOpenModelGate": 0x800e2510,
		"evStartOpenModelGate": 0x800e2510,
		"System::evStartEMarioDisappear": 0x800e26d4,
		"evStartEMarioDisappear": 0x800e26d4,
		"System::evStartEMarioGateDrawing": 0x800e2898,
		"evStartEMarioGateDrawing": 0x800e2898,
		"System::evStartEMarioRunAway": 0x800e2a5c,
		"evStartEMarioRunAway": 0x800e2a5c,
		"System::evIsEMarioDownWaitingToTalk": 0x800e2c20,
		"evIsEMarioDownWaitingToTalk": 0x800e2c20,
		"System::evIsEMarioReachedToGoal": 0x800e2de8,
		"evIsEMarioReachedToGoal": 0x800e2de8,
		"System::evLaunchEventClearDemo": 0x800e2fb0,
		"evLaunchEventClearDemo": 0x800e2fb0,
		"System::evIsBossDefeated": 0x800e3060,
		"evIsBossDefeated": 0x800e3060,
		"System::evSetGraffitoMultiplied": 0x800e310c,
		"evSetGraffitoMultiplied": 0x800e310c,
		"System::evIsGraffitoCoverage0": 0x800e32b8,
		"evIsGraffitoCoverage0": 0x800e32b8,
		"System::evGameOver": 0x800e3364,
		"evGameOver": 0x800e3364,
		"System::evRegisterMovie": 0x800e3404,
		"evRegisterMovie": 0x800e3404,
		"System::evSetNextStage": 0x800e3548,
		"evSetNextStage": 0x800e3548,
		"System::evGetPollutionLevel": 0x800e3750,
		"evGetPollutionLevel": 0x800e3750,
		"System::evGetRestTime": 0x800e37e8,
		"evGetRestTime": 0x800e37e8,
		"System::evSetPollutionIncreaseCount": 0x800e38c4,
		"evSetPollutionIncreaseCount": 0x800e38c4,
		"System::evSetAttentionTime": 0x800e397c,
		"evSetAttentionTime": 0x800e397c,
		"System::evSetTimeLimit": 0x800e3a34,
		"evSetTimeLimit": 0x800e3a34,
		"System::evSetDead4LiveActor": 0x800e3b88,
		"evSetDead4LiveActor": 0x800e3b88,
		"System::evSetHide4LiveActor": 0x800e3db4,
		"evSetHide4LiveActor": 0x800e3db4,
		"System::evIsOnLiveActorFlag": 0x800e3fe0,
		"evIsOnLiveActorFlag": 0x800e3fe0,
		"System::evPushNerve4LiveActor": 0x800e4248,
		"evPushNerve4LiveActor": 0x800e4248,
		"System::evSetFlagNPCCanTaken": 0x800e449c,
		"evSetFlagNPCCanTaken": 0x800e449c,
		"System::evIsTalkModeNow": 0x800e46b0,
		"evIsTalkModeNow": 0x800e46b0,
		"System::evSetValue2TalkVariable": 0x800e4774,
		"evSetValue2TalkVariable": 0x800e4774,
		"System::evGetTalkSelectedValue": 0x800e4858,
		"evGetTalkSelectedValue": 0x800e4858,
		"System::evGetTalkMode": 0x800e48f4,
		"evGetTalkMode": 0x800e48f4,
		"System::evSetTalkMsgID": 0x800e498c,
		"evSetTalkMsgID": 0x800e498c,
		"System::evGetTalkNPCName": 0x800e4b8c,
		"evGetTalkNPCName": 0x800e4b8c,
		"System::evGetTalkNPC": 0x800e4ccc,
		"evGetTalkNPC": 0x800e4ccc,
		"System::evIsNearActors": 0x800e4d74,
		"evIsNearActors": 0x800e4d74,
		"System::evIsNearSameActors": 0x800e50f8,
		"evIsNearSameActors": 0x800e50f8,
		"System::evSetFlagNPCDead": 0x800e5600,
		"evSetFlagNPCDead": 0x800e5600,
		"System::evSetFlagNPCDontThrow": 0x800e5888,
		"evSetFlagNPCDontThrow": 0x800e5888,
		"System::evSetFlagNPCDontTalk": 0x800e5b10,
		"evSetFlagNPCDontTalk": 0x800e5b10,
		"System::evGetNPCType": 0x800e5d98,
		"evGetNPCType": 0x800e5d98,
		"System::evGetNameRefName": 0x800e5f78,
		"evGetNameRefName": 0x800e5f78,
		"System::evGetNameRefHandle": 0x800e60e0,
		"evGetNameRefHandle": 0x800e60e0,
		"System::evSetSystemFlag": 0x800e6230,
		"evSetSystemFlag": 0x800e6230,
		"System::evGetSystemFlag": 0x800e641c,
		"evGetSystemFlag": 0x800e641c,
		"TSpcTypedInterp<TEventWatcher>::~TSpcTypedInterp": 0x800e6558,
		"~TSpcTypedInterp": 0x800e6558,
		"TSpcTypedBinary<TEventWatcher>::~TSpcTypedBinary": 0x800e65bc,
		"TSpcTypedInterp<TEventWatcher>::dispatchBuiltin": 0x800e6620,
		"System::__sinit_EventWatcher_cpp": 0x800e6698,
		"__sinit_EventWatcher_cpp": 0x800e6698,
		"TFlagManager::saveOption": 0x800e6a9c,
		"saveOption": 0x800e6a9c,
		"TFlagManager::loadOption": 0x800e6bc8,
		"loadOption": 0x800e6bc8,
		"TFlagManager::correctOptFlag": 0x800e6ccc,
		"correctOptFlag": 0x800e6ccc,
		"TFlagManager::resetOpt": 0x800e6d78,
		"resetOpt": 0x800e6d78,
		"TFlagManager::saveFail": 0x800e6d88,
		"saveFail": 0x800e6d88,
		"TFlagManager::saveSuccess": 0x800e6dc0,
		"saveSuccess": 0x800e6dc0,
		"TFlagManager::save": 0x800e6e18,
		"TFlagManager::correctFlag": 0x800e6fac,
		"correctFlag": 0x800e6fac,
		"TFlagManager::firstStart": 0x800e7164,
		"firstStart": 0x800e7164,
		"TFlagManager::restore": 0x800e73b8,
		"restore": 0x800e73b8,
		"TFlagManager::load": 0x800e760c,
		"TFlagManager::setNozzleRight": 0x800e7958,
		"setNozzleRight": 0x800e7958,
		"TFlagManager::getNozzleRight": 0x800e79f8,
		"getNozzleRight": 0x800e79f8,
		"TFlagManager::setBlueCoinFlag": 0x800e7a88,
		"setBlueCoinFlag": 0x800e7a88,
		"TFlagManager::getBlueCoinFlag": 0x800e7b3c,
		"getBlueCoinFlag": 0x800e7b3c,
		"TFlagManager::incGoldCoinFlag": 0x800e7bcc,
		"incGoldCoinFlag": 0x800e7bcc,
		"TFlagManager::setShineFlag": 0x800e7c68,
		"setShineFlag": 0x800e7c68,
		"TFlagManager::getShineFlag": 0x800e7ce4,
		"getShineFlag": 0x800e7ce4,
		"TFlagManager::incMario": 0x800e7d28,
		"incMario": 0x800e7d28,
		"TFlagManager::decFlag": 0x800e7d8c,
		"decFlag": 0x800e7d8c,
		"TFlagManager::incFlag": 0x800e7db0,
		"incFlag": 0x800e7db0,
		"TFlagManager::setBool": 0x800e7ea0,
		"setBool": 0x800e7ea0,
		"TFlagManager::getBool": 0x800e7fe0,
		"getBool": 0x800e7fe0,
		"TFlagManager::setFlag": 0x800e80d8,
		"setFlag": 0x800e80d8,
		"TFlagManager::getFlag": 0x800e8308,
		"getFlag": 0x800e8308,
		"TFlagManager::resetStage": 0x800e84b0,
		"resetStage": 0x800e84b0,
		"TFlagManager::resetGame": 0x800e865c,
		"resetGame": 0x800e865c,
		"TFlagManager::resetCard": 0x800e882c,
		"resetCard": 0x800e882c,
		"TFlagManager::start": 0x800e8a40,
		"TGCLogoDir::direct_dolby": 0x800e8ae0,
		"direct_dolby": 0x800e8ae0,
		"TGCLogoDir::direct_nlogo": 0x800e8c44,
		"direct_nlogo": 0x800e8c44,
		"TGCLogoDir::direct": 0x800e8fc8,
		"TGCLogoDir::setup": 0x800e91cc,
		"TGCLogoDir::TGCLogoDir": 0x800e98ec,
		"TNintendo2D::perform": 0x800e99ac,
		"TNintendo2D::~TNintendo2D": 0x800e9b7c,
		"System::__sinit_GCLogoDir_cpp": 0x800e9bf0,
		"__sinit_GCLogoDir_cpp": 0x800e9bf0,
		"TGXAlphaUpdate::~TGXAlphaUpdate": 0x800e9ef4,
		"TGXAlphaUpdate::perform": 0x800e9f68,
		"TReInitGX::perform": 0x800e9fbc,
		"TSMSDrawInit::perform": 0x800e9fe4,
		"TJ3DSysSetViewMtx::perform": 0x800ea00c,
		"TJ3DSysFlag::perform": 0x800ea040,
		"TReInitGX::~TReInitGX": 0x800ea0c4,
		"TSMSDrawInit::~TSMSDrawInit": 0x800ea138,
		"TJ3DSysSetViewMtx::~TJ3DSysSetViewMtx": 0x800ea1ac,
		"TJ3DSysFlag::~TJ3DSysFlag": 0x800ea220,
		"TMarDirector::registerEventWatcher": 0x800ea294,
		"registerEventWatcher": 0x800ea294,
		"TMarDirector::setup": 0x800ea31c,
		"TMarDirector::setupThreadFunc": 0x800ea390,
		"TMarDirector::TMarDirector": 0x800ea3b0,
		"TMarDirector::TDemoInfo::TDemoInfo": 0x800ea72c,
		"JGadget::TSingleNodeLinkList::Initialize_": 0x800ea738,
		"Initialize_": 0x800ea738,
		"System::__sinit_MarDirector_cpp": 0x800ea750,
		"__sinit_MarDirector_cpp": 0x800ea750,
		"TMarDirector::moveStage": 0x800eab40,
		"moveStage": 0x800eab40,
		"TMarDirector::updateGameMode": 0x800eaf70,
		"updateGameMode": 0x800eaf70,
		"TGameSequence::set": 0x800eb7f8,
		"TMarDirector::nextStateInitialize": 0x800eb80c,
		"nextStateInitialize": 0x800eb80c,
		"TMarDirector::setMario": 0x800ebe48,
		"setMario": 0x800ebe48,
		"TMarDirector::currentStateFinalize": 0x800ec11c,
		"currentStateFinalize": 0x800ec11c,
		"TMarDirector::changeState": 0x800ec404,
		"System::decideNextScenario": 0x800ecb70,
		"decideNextScenario": 0x800ecb70,
		"System::decideNextStage": 0x800eccc4,
		"decideNextStage": 0x800eccc4,
		"JDrama::TFlagT<unsigned_short><unsigned_short>::set": 0x800ecda8,
		"System::__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x800ecdb0,
		"__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x800ecdb0,
		"TMarDirector::direct": 0x800ecdbc,
		"System::__sinit_MarDirectorDirect_cpp": 0x800ed2cc,
		"__sinit_MarDirectorDirect_cpp": 0x800ed2cc,
		"TMarDirector::fireStreamingMovie": 0x800ed5c8,
		"fireStreamingMovie": 0x800ed5c8,
		"TMarDirector::fireEndDemoCamera": 0x800ed7b0,
		"fireEndDemoCamera": 0x800ed7b0,
		"TMarDirector::fireStartDemoCamera": 0x800ed7c0,
		"fireStartDemoCamera": 0x800ed7c0,
		"TMarDirector::setNextStage": 0x800ed8a0,
		"setNextStage": 0x800ed8a0,
		"TMarDirector::movement": 0x800eda30,
		"TMarDirector::fireRideYoshi": 0x800eda60,
		"fireRideYoshi": 0x800eda60,
		"TMarDirector::fireGetStar": 0x800edae8,
		"fireGetStar": 0x800edae8,
		"TMarDirector::fireGetNozzle": 0x800edb64,
		"fireGetNozzle": 0x800edb64,
		"TMarDirector::fireGetBlueCoin": 0x800edc74,
		"fireGetBlueCoin": 0x800edc74,
		"TMarDirector::movement_game": 0x800edd0c,
		"movement_game": 0x800edd0c,
		"TMarDirector::findNearestTalkNPC": 0x800eded0,
		"findNearestTalkNPC": 0x800eded0,
		"TMarDirector::entryNPC": 0x800edf90,
		"entryNPC": 0x800edf90,
		"System::__sinit_MarDirectorEvent_cpp": 0x800edfc4,
		"__sinit_MarDirectorEvent_cpp": 0x800edfc4,
		"TMarDirector::setupPerformList_console": 0x800ee2c0,
		"setupPerformList_console": 0x800ee2c0,
		"TMarDirector::initECDisp": 0x800ee3d0,
		"initECDisp": 0x800ee3d0,
		"TMarDirector::initECTMir": 0x800eefec,
		"initECTMir": 0x800eefec,
		"TMarDirector::initECTGft": 0x800ef0e4,
		"initECTGft": 0x800ef0e4,
		"TMarDirector::preEntry": 0x800ef6b4,
		"preEntry": 0x800ef6b4,
		"TMarDirector::setup2": 0x800efc08,
		"setup2": 0x800efc08,
		"System::__sinit_MarDirectorSetup2_cpp": 0x800f01c4,
		"__sinit_MarDirectorSetup2_cpp": 0x800f01c4,
		"System::MarErrInit": 0x800f04d0,
		"MarErrInit": 0x800f04d0,
		"System::MarErrException": 0x800f0550,
		"MarErrException": 0x800f0550,
		"TMarNameRefGen::getNameRef": 0x800f05ec,
		"TStagePositionInfo::~TStagePositionInfo": 0x800f2308,
		"std::__copy<TStagePositionInfo,0,0>::copy": 0x800f236c,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::TVector": 0x800f2524,
		"TScenarioArchiveName::~TScenarioArchiveName": 0x800f2550,
		"std::__copy<TScenarioArchiveName,0,0>::copy": 0x800f25b4,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::TVector": 0x800f26d8,
		"TCubeGeneralInfo::TCubeGeneralInfo": 0x800f2768,
		"std::__copy<TCameraMapTool,0,0>::copy": 0x800f2874,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::TVector": 0x800f2a7c,
		"TStageEventInfo::~TStageEventInfo": 0x800f2aa8,
		"std::__copy<TStageEventInfo,0,0>::copy": 0x800f2b0c,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::TVector": 0x800f2cec,
		"TCubeManagerMarioIn::~TCubeManagerMarioIn": 0x800f2ed4,
		"TSunGlass::TSunGlass": 0x800f3040,
		"JGadget::TList_pointer<THitActor*>::TList_pointer": 0x800f317c,
		"TList_pointer": 0x800f317c,
		"TWaterSplash::TWaterSplash": 0x800f32a4,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::searchF": 0x800f32a8,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::loadAfter": 0x800f3344,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::load": 0x800f33a4,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::erase": 0x800f359c,
		"TStagePositionInfo::TStagePositionInfo": 0x800f3680,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::InsertRaw": 0x800f36c4,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::searchF": 0x800f3b74,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::loadAfter": 0x800f3c10,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::load": 0x800f3c70,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::perform": 0x800f3d80,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::searchF": 0x800f3e3c,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfterSuper": 0x800f3f24,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfter": 0x800f3f44,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadSuper": 0x800f3ffc,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::load": 0x800f401c,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::searchF": 0x800f4164,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::loadAfter": 0x800f4200,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::load": 0x800f4260,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::erase": 0x800f4458,
		"TCameraMapTool::TCameraMapTool": 0x800f453c,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::InsertRaw": 0x800f45b0,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::searchF": 0x800f4ab0,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::loadAfter": 0x800f4b4c,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::load": 0x800f4bac,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::searchF": 0x800f4cbc,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::loadAfter": 0x800f4d58,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::load": 0x800f4db8,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::erase": 0x800f4f90,
		"TScenarioArchiveName::TScenarioArchiveName": 0x800f5074,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::InsertRaw": 0x800f50a8,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::~TNameRefAryT": 0x800f5494,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::~TNameRefPtrAryT": 0x800f5518,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::~TNameRefAryT": 0x800f5590,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::~TNameRefAryT": 0x800f568c,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::~TNameRefAryT": 0x800f5710,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::erase": 0x800f5794,
		"TCubeManagerFast::~TCubeManagerFast": 0x800f5810,
		"TCubeManagerArea::~TCubeManagerArea": 0x800f58a4,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::searchF": 0x800f5938,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::loadAfter": 0x800f59d4,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::load": 0x800f5a34,
		"TStageEventInfo::TStageEventInfo": 0x800f5c94,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::InsertRaw": 0x800f5d00,
		"TStageEventInfo::operator_=": 0x800f6020,
		"System::__sinit_MarNameRefGen_cpp": 0x800f6074,
		"__sinit_MarNameRefGen_cpp": 0x800f6074,
		"TMenuDirector::setFixedStageValue": 0x800f6370,
		"setFixedStageValue": 0x800f6370,
		"TMenuDirector::direct": 0x800f67a8,
		"TMenuDirector::rsetup": 0x800f70a0,
		"TMenuDirector::setup": 0x800f79bc,
		"TMenuDirector::setupThreadFunc": 0x800f7ae8,
		"TMenuDirector::TMenuDirector": 0x800f7bc0,
		"System::__sinit_MenuDir_cpp": 0x800f7c94,
		"__sinit_MenuDir_cpp": 0x800f7c94,
		"TParams::finalize": 0x800f8194,
		"TParams::init": 0x800f81a4,
		"TParamT<JGeometry::TVec3<float><float>>::load": 0x800f82dc,
		"TParamT<float><float>::load": 0x800f8330,
		"TParamT<long><long>::load": 0x800f8384,
		"TParamT<short><short>::load": 0x800f83d8,
		"TParamT<unsigned_char><unsigned_char>::load": 0x800f842c,
		"TPerformList::~TPerformList": 0x800f8480,
		"TPerformList::load": 0x800f86b0,
		"JGadget::TSingleLinkList<TPerformLink,0>::Element_getNode": 0x800f8810,
		"JGadget::TSingleLinkList<12TPerformLink,0>::iterator::iterator": 0x800f8814,
		"JGadget::TSingleNodeLinkList::end": 0x800f8820,
		"TPerformList::perform": 0x800f882c,
		"System::SMSSetupMovieRenderingInfo": 0x800f8904,
		"SMSSetupMovieRenderingInfo": 0x800f8904,
		"System::SMSSetupGameRenderingInfo": 0x800f8a14,
		"SMSSetupGameRenderingInfo": 0x800f8a14,
		"System::SMSSetupTitleRenderingInfo": 0x800f8b50,
		"SMSSetupTitleRenderingInfo": 0x800f8b50,
		"System::SMSSetupTitleRenderMode": 0x800f8c58,
		"SMSSetupTitleRenderMode": 0x800f8c58,
		"System::SMSSetupGCLogoRenderingInfo": 0x800f8d68,
		"SMSSetupGCLogoRenderingInfo": 0x800f8d68,
		"System::SMSGetRederRect_Game": 0x800f8e20,
		"SMSGetRederRect_Game": 0x800f8e20,
		"TSnapTimeObj::~TSnapTimeObj": 0x800f8e74,
		"TSnapTimeObj::perform": 0x800f8ee8,
		"TTalkCursor::~TTalkCursor": 0x800f8fcc,
		"TTalkCursor::associateNPC": 0x800f9040,
		"associateNPC": 0x800f9040,
		"TTalkCursor::perform": 0x800f90cc,
		"TTalkCursor::loadAfter": 0x800f910c,
		"System::SMS_ResetTexCacheRegion": 0x800f91fc,
		"SMS_ResetTexCacheRegion": 0x800f91fc,
		"TAlphaCatch::~TAlphaCatch": 0x800f9238,
		"TAlphaCatch::perform": 0x800f92ac,
		"TZBufferCatch::perform": 0x800f92f0,
		"TZBufferCatch::~TZBufferCatch": 0x800f9328,
		"TApplication::mountStageArchive": 0x800f939c,
		"mountStageArchive": 0x800f939c,
		"TApplication::drawDVDErr": 0x800f9548,
		"drawDVDErr": 0x800f9548,
		"TApplication::gameLoop": 0x800f9954,
		"gameLoop": 0x800f9954,
		"TTimeRec::crTimeAry": 0x800f9d84,
		"crTimeAry": 0x800f9d84,
		"TApplication::proc": 0x800f9d9c,
		"TApplication::checkAdditionalMovie": 0x800fa1ec,
		"checkAdditionalMovie": 0x800fa1ec,
		"TApplication::finalize": 0x800fa3d0,
		"TApplication::initialize_nlogoAfter": 0x800fa488,
		"initialize_nlogoAfter": 0x800fa488,
		"TApplication::initialize_bootAfter": 0x800fa7d4,
		"initialize_bootAfter": 0x800fa7d4,
		"System::SetupThreadFuncLogo": 0x800faa84,
		"SetupThreadFuncLogo": 0x800faa84,
		"TApplication::setupThreadFuncLogo": 0x800faaa4,
		"setupThreadFuncLogo": 0x800faaa4,
		"TApplication::initialize": 0x800fadc8,
		"System::SetupThreadFuncBoot": 0x800fb27c,
		"SetupThreadFuncBoot": 0x800fb27c,
		"System::SMSSwitch2DArchive": 0x800fb2b8,
		"SMSSwitch2DArchive": 0x800fb2b8,
		"System::SMSMountAramArchive": 0x800fb380,
		"SMSMountAramArchive": 0x800fb380,
		"System::SMSLoadArchive": 0x800fb438,
		"SMSLoadArchive": 0x800fb438,
		"TApplication::TApplication": 0x800fb50c,
		"System::SMSGetAnmFrameRate": 0x800fb5dc,
		"SMSGetAnmFrameRate": 0x800fb5dc,
		"System::SMSGetVSyncTimesPerSec": 0x800fb64c,
		"SMSGetVSyncTimesPerSec": 0x800fb64c,
		"TMarioGamePad::~TMarioGamePad": 0x800fb6b4,
		"System::__sinit_Application_cpp": 0x800fb718,
		"__sinit_Application_cpp": 0x800fb718,
		"TScenarioArchiveName::load": 0x800fba14,
		"TMarioGamePad::read": 0x800fba58,
		"TMarioGamePad::onNeutralMarioKey": 0x800fbad8,
		"onNeutralMarioKey": 0x800fbad8,
		"TMarioGamePad::updateMeaning": 0x800fbae4,
		"updateMeaning": 0x800fbae4,
		"TMarioGamePad::reset": 0x800fc380,
		"System::CLBCalcRatio": 0x800fc3f8,
		"System::__sinit_MarioGamePad_cpp": 0x800fc460,
		"__sinit_MarioGamePad_cpp": 0x800fc460,
		"TStageEventInfo::load": 0x800fc46c,
		"System::SMS_getShineIDofExStage": 0x800fc504,
		"SMS_getShineIDofExStage": 0x800fc504,
		"System::SMS_getShineStage": 0x800fc534,
		"SMS_getShineStage": 0x800fc534,
		"System::SMS_isOptionMap": 0x800fc54c,
		"SMS_isOptionMap": 0x800fc54c,
		"System::SMS_isDivingMap": 0x800fc568,
		"SMS_isDivingMap": 0x800fc568,
		"System::SMS_isMultiPlayerMap": 0x800fc59c,
		"SMS_isMultiPlayerMap": 0x800fc59c,
		"System::SMS_isExMap": 0x800fc5c4,
		"SMS_isExMap": 0x800fc5c4,
		"System::SMSGetGCLogoVideoWidth": 0x800fc60c,
		"SMSGetGCLogoVideoWidth": 0x800fc60c,
		"System::SMSGetGCLogoRenderHeight": 0x800fc614,
		"SMSGetGCLogoRenderHeight": 0x800fc614,
		"System::SMSGetGCLogoRenderWidth": 0x800fc61c,
		"SMSGetGCLogoRenderWidth": 0x800fc61c,
		"System::SMSGetTitleRenderHeight": 0x800fc624,
		"SMSGetTitleRenderHeight": 0x800fc624,
		"System::SMSGetTitleRenderWidth": 0x800fc62c,
		"SMSGetTitleRenderWidth": 0x800fc62c,
		"System::SMSGetGameRenderHeight": 0x800fc634,
		"SMSGetGameRenderHeight": 0x800fc634,
		"System::SMSGetGameRenderWidth": 0x800fc63c,
		"SMSGetGameRenderWidth": 0x800fc63c,
		"System::SMSGetTitleVideoWidth": 0x800fc6a8,
		"SMSGetTitleVideoWidth": 0x800fc6a8,
		"System::SMSGetGameVideoWidth": 0x800fc714,
		"SMSGetGameVideoWidth": 0x800fc714,
		"TStagePositionInfo::load": 0x800fc71c,
		"TProcessMeter::TProcessMeter": 0x800fc7e4,
		"TTimeRec::drawSyncCallback": 0x800fc824,
		"TTimeRec::snapGXTime": 0x800fc874,
		"snapGXTime": 0x800fc874,
		"TTimeRec::flip": 0x800fc920,
		"flip": 0x800fc920,
		"TTimeArray::TTimeArray": 0x800fc9b0,
		"TTimeRec::start": 0x800fc9bc,
		"TTimeArray::append": 0x800fca58,
		"TDrawSyncManager::pushBreakPoint": 0x800fca8c,
		"pushBreakPoint": 0x800fca8c,
		"TDrawSyncManager::drawSyncCallbackSub": 0x800fcae4,
		"drawSyncCallbackSub": 0x800fcae4,
		"TDrawSyncManager::setCallback": 0x800fcba8,
		"setCallback": 0x800fcba8,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::DestroyElement_": 0x800fcbdc,
		"TDrawSyncManager::threadFunc": 0x800fcbf0,
		"threadFunc": 0x800fcbf0,
		"TFifo::getLoopIdx": 0x800fcd68,
		"getLoopIdx": 0x800fcd68,
		"TDrawSyncManager::drawSyncCallback": 0x800fcd84,
		"TDrawSyncManager::start": 0x800fcdb8,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::insert": 0x800fcef0,
		"TDrawSyncManager::TDrawSyncTokenRange::TDrawSyncTokenRange": 0x800fd298,
		"TTHPRender::~TTHPRender": 0x800fd2a8,
		"TTHPRender::perform": 0x800fd31c,
		"TTHPRender::TTHPRender": 0x800fd38c,
		"TMarNameRefGen::getNameRef_BossEnemy": 0x800fd404,
		"getNameRef_BossEnemy": 0x800fd404,
		"System::__sinit_MarNameRefGen_BossEnemy_cpp": 0x800fdfc4,
		"__sinit_MarNameRefGen_BossEnemy_cpp": 0x800fdfc4,
		"TMarNameRefGen::getNameRef_Enemy": 0x800fe2c0,
		"getNameRef_Enemy": 0x800fe2c0,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::TRotation3": 0x801003f4,
		"TNameKuriLauncherManager::~TNameKuriLauncherManager": 0x80100ab4,
		"THamuKuriLauncherManager::~THamuKuriLauncherManager": 0x80100b30,
		"TMarNameRefGen::getNameRef_Map": 0x80100ba4,
		"getNameRef_Map": 0x80100ba4,
		"TMarNameRefGen::getNameRef_MapObj": 0x80100edc,
		"getNameRef_MapObj": 0x80100edc,
		"TTelesaSlot::TTelesaSlot": 0x8010482c,
		"TFence::TFence": 0x80104e64,
		"TMarNameRefGen::getNameRef_NPC": 0x8010546c,
		"getNameRef_NPC": 0x8010546c,
		"TMareWManager::~TMareWManager": 0x801067ac,
		"TMareMManager::~TMareMManager": 0x80106840,
		"TCardManager::cmdLoop": 0x801068d4,
		"cmdLoop": 0x801068d4,
		"TCardManager::writeOptionBlock_": 0x80106afc,
		"writeOptionBlock_": 0x80106afc,
		"TCardManager::writeBlock_": 0x80106c94,
		"writeBlock_": 0x80106c94,
		"TCardManager::readBlock_": 0x80106eb4,
		"readBlock_": 0x80106eb4,
		"TCardManager::getBookmarkInfos_": 0x80107120,
		"getBookmarkInfos_": 0x80107120,
		"TCardManager::open_": 0x801072f4,
		"open_": 0x801072f4,
		"TCardManager::setCardStat_": 0x80107484,
		"setCardStat_": 0x80107484,
		"TCardManager::filledInitData_": 0x801076c8,
		"filledInitData_": 0x801076c8,
		"TCardManager::createFile_": 0x80107a18,
		"createFile_": 0x80107a18,
		"TCardManager::mount_": 0x80107b50,
		"mount_": 0x80107b50,
		"System::detachCallback": 0x80107d9c,
		"detachCallback": 0x80107d9c,
		"TCardManager::getLastStatus": 0x80107dac,
		"getLastStatus": 0x80107dac,
		"TCardManager::writeOptionBlock": 0x80107e04,
		"writeOptionBlock": 0x80107e04,
		"TCardManager::getOptionWriteStream": 0x80107e54,
		"getOptionWriteStream": 0x80107e54,
		"TCardManager::getOptionReadStream": 0x80107f70,
		"getOptionReadStream": 0x80107f70,
		"TCardManager::readOptionBlock": 0x80107fa0,
		"readOptionBlock": 0x80107fa0,
		"TCardManager::writeBlock": 0x80107ff0,
		"writeBlock": 0x80107ff0,
		"TCardManager::getWriteStream": 0x80108050,
		"getWriteStream": 0x80108050,
		"TCardManager::getReadStream": 0x801080a4,
		"getReadStream": 0x801080a4,
		"TCardManager::readBlock": 0x801080d4,
		"readBlock": 0x801080d4,
		"TCardManager::getBookmarkInfos": 0x80108134,
		"getBookmarkInfos": 0x80108134,
		"TCardManager::createFile": 0x80108194,
		"createFile": 0x80108194,
		"TCardManager::format": 0x801081e4,
		"format": 0x801081e4,
		"TCardManager::unmount": 0x80108234,
		"TCardManager::probe": 0x801082b0,
		"probe": 0x801082b0,
		"TCardManager::~TCardManager": 0x80108334,
		"TCardManager::TCardManager": 0x801083e0,
		"TCardManager::TCriteria::TCriteria": 0x801084ac,
		"System::cardmain": 0x801084b8,
		"cardmain": 0x801084b8,
		"TCardManager::copyTo": 0x801084d8,
		"copyTo": 0x801084d8,
		"TCardManager::decideUseSector": 0x80108674,
		"decideUseSector": 0x80108674,
		"TCardManager::TCriteria::set": 0x801086e4,
		"System::CalcCheckSum": 0x80108748,
		"CalcCheckSum": 0x80108748,
		"TMarDirector::loadParticleMario": 0x80108820,
		"loadParticleMario": 0x80108820,
		"TMarDirector::loadParticle": 0x80109a84,
		"loadParticle": 0x80109a84,
		"TMarDirector::initLoadParticle": 0x8010a404,
		"initLoadParticle": 0x8010a404,
		"TMarDirector::loadResource": 0x8010a590,
		"loadResource": 0x8010a590,
		"System::__sinit_MarDirectorLoadResource_cpp": 0x8010a9c8,
		"__sinit_MarDirectorLoadResource_cpp": 0x8010a9c8,
		"TMovieDirector::direct": 0x8010acc4,
		"TMovieDirector::decideNextMode": 0x8010b39c,
		"decideNextMode": 0x8010b39c,
		"TMovieDirector::rsetup": 0x8010b640,
		"TMovieDirector::setup": 0x8010be04,
		"TMovieDirector::setupThreadFunc": 0x8010bf38,
		"TMovieDirector::TMovieDirector": 0x8010bf58,
		"TMovieDirector::getStreamMovieName": 0x8010c008,
		"getStreamMovieName": 0x8010c008,
		"System::__sinit_MovieDirector_cpp": 0x8010c030,
		"__sinit_MovieDirector_cpp": 0x8010c030,
		"TMarDirector::createObjects": 0x8010c334,
		"createObjects": 0x8010c334,
		"TMarDirector::setupObjects": 0x8010c3ac,
		"setupObjects": 0x8010c3ac,
		"TMarDirector::decideMarioPosIdx": 0x8010e460,
		"decideMarioPosIdx": 0x8010e460,
		"System::__sinit_MarDirectorSetupObjects_cpp": 0x8010e6f0,
		"__sinit_MarDirectorSetupObjects_cpp": 0x8010e6f0,
		"MSStage::setPosPtr": 0x8010e9ec,
		"setPosPtr": 0x8010e9ec,
		"MSSTageSimpleEnvironment::proc": 0x8010e9f0,
		"MSStageCubeSwitch::proc": 0x8010ea2c,
		"MSStageCubeFadeMonte::proc": 0x8010ec04,
		"MSStageCubeFade::proc": 0x8010f0b4,
		"MSStageDistFadeMonte::proc": 0x8010f400,
		"MSStageDistFade::proc": 0x8010f808,
		"MSStageDistFade::MSStageDistFade": 0x8010fae0,
		"MSStage::stageLoop": 0x8010fb38,
		"stageLoop": 0x8010fb38,
		"MSStage::init": 0x8010fb64,
		"MSMainProc::startStageBGM": 0x8010fe78,
		"startStageBGM": 0x8010fe78,
		"MSMainProc::endStageEntranceDemo": 0x8010ff5c,
		"endStageEntranceDemo": 0x8010ff5c,
		"MSMainProc::entranceDemoLoop": 0x8010fffc,
		"entranceDemoLoop": 0x8010fffc,
		"MSMainProc::startStageEntranceDemo": 0x80110000,
		"startStageEntranceDemo": 0x80110000,
		"MSMainProc::setMSoundEnterStage": 0x801100a0,
		"setMSoundEnterStage": 0x801100a0,
		"MSMainProc::setBossNotDamagedFlag": 0x801109fc,
		"setBossNotDamagedFlag": 0x801109fc,
		"MSMainProc::setBossLivesFlag2": 0x80110a04,
		"setBossLivesFlag2": 0x80110a04,
		"MSMainProc::setBossLivesFlagOnlyFlag": 0x80110a50,
		"setBossLivesFlagOnlyFlag": 0x80110a50,
		"MSMainProc::setBossLivesFlag": 0x80110a58,
		"setBossLivesFlag": 0x80110a58,
		"MSMainProc::fromTalkingCameraDemo": 0x80110aa4,
		"fromTalkingCameraDemo": 0x80110aa4,
		"MSMainProc::toTalkingCameraDemo": 0x80110acc,
		"toTalkingCameraDemo": 0x80110acc,
		"MSMainProc::fromInnerCameraDemo": 0x80110b38,
		"fromInnerCameraDemo": 0x80110b38,
		"MSMainProc::toInnerCameraDemo": 0x80110b48,
		"toInnerCameraDemo": 0x80110b48,
		"MSMainProc::getMonteVillageActorArea": 0x80110b58,
		"getMonteVillageActorArea": 0x80110b58,
		"System::__sinit_MSoundMainSide_cpp": 0x80110c04,
		"__sinit_MSoundMainSide_cpp": 0x80110c04,
		"TTargetArrow::~TTargetArrow": 0x80110f00,
		"TTargetArrow::setPos": 0x80110f74,
		"setPos": 0x80110f74,
		"TTargetArrow::perform": 0x80110fa4,
		"TTargetArrow::loadAfter": 0x80110fe0,
		"TLiveActor::stopAnmSound": 0x80111044,
		"stopAnmSound": 0x80111044,
		"TLiveActor::getBasNameTable": 0x80111080,
		"TLiveActor::setCurAnmSound": 0x80111088,
		"setCurAnmSound": 0x80111088,
		"TLiveActor::setAnmSound": 0x8011117c,
		"setAnmSound": 0x8011117c,
		"TLiveActor::updateAnmSound": 0x80111220,
		"TLiveActor::initAnmSound": 0x80111288,
		"TLiveActor::getTakingMtx": 0x80111398,
		"TLiveActor::getFocalPoint": 0x801113b8,
		"TLiveActor::getJointTransByIndex": 0x801113d4,
		"getJointTransByIndex": 0x801113d4,
		"TLiveActor::hasMapCollision": 0x8011145c,
		"TLiveActor::getGravityY": 0x80111478,
		"TLiveActor::calcVelocityToJumpToY": 0x80111480,
		"calcVelocityToJumpToY": 0x80111480,
		"TLiveActor::performOnlyDraw": 0x801114d4,
		"performOnlyDraw": 0x801114d4,
		"TLiveActor::perform": 0x801115b0,
		"TLiveActor::drawObject": 0x801116b8,
		"TLiveActor::requestShadow": 0x80111710,
		"TLiveActor::moveObject": 0x8011187c,
		"TLiveActor::setGroundCollision": 0x801119e0,
		"TLiveActor::getShadowType": 0x80111a38,
		"TLiveActor::receiveMessage": 0x80111a40,
		"TLiveActor::kill": 0x80111a48,
		"TLiveActor::calcRootMatrix": 0x80111a64,
		"TLiveActor::control": 0x80111b08,
		"TLiveActor::bind": 0x80111cd8,
		"TLiveActor::load": 0x80111f34,
		"TLiveActor::init": 0x80111fcc,
		"TLiveActor::initLodAnm": 0x801121dc,
		"initLodAnm": 0x801121dc,
		"TLiveActor::getRootJointMtx": 0x80112268,
		"TLiveActor::getModel": 0x80112270,
		"getModel": 0x80112270,
		"TLiveActor::calcRideMomentum": 0x8011227c,
		"calcRideMomentum": 0x8011227c,
		"Strategic::MsWrap": 0x80112498,
		"TLiveActor::belongToGround": 0x801124e0,
		"belongToGround": 0x801124e0,
		"TLiveActor::calcRidePos": 0x80112560,
		"calcRidePos": 0x80112560,
		"TLiveActor::TLiveActor": 0x80112690,
		"Strategic::__sinit_liveactor_cpp": 0x801127c0,
		"__sinit_liveactor_cpp": 0x801127c0,
		"TSpcTypedBinary<TLiveActor>::initUserBuiltin": 0x80112ac4,
		"Strategic::linPushNerve": 0x80112bb8,
		"linPushNerve": 0x80112bb8,
		"Strategic::linSetSRT": 0x80112db0,
		"linSetSRT": 0x80112db0,
		"Strategic::linGetSRT": 0x801131a0,
		"linGetSRT": 0x801131a0,
		"Strategic::linSetAnmRate": 0x80113938,
		"linSetAnmRate": 0x80113938,
		"Strategic::linSetBls": 0x80113bac,
		"linSetBls": 0x80113bac,
		"Strategic::linSetBlk": 0x80113cc0,
		"linSetBlk": 0x80113cc0,
		"Strategic::linSetBtk": 0x80113de8,
		"linSetBtk": 0x80113de8,
		"Strategic::linSetBtp": 0x80113f10,
		"linSetBtp": 0x80113f10,
		"Strategic::linSetBpk": 0x80114038,
		"linSetBpk": 0x80114038,
		"Strategic::linSetBck": 0x80114160,
		"linSetBck": 0x80114160,
		"Strategic::NerveGetByIndex": 0x80114288,
		"NerveGetByIndex": 0x80114288,
		"TLiveManager::hasMapCollision": 0x80114620,
		"TLiveManager::getActorByFlag": 0x80114668,
		"getActorByFlag": 0x80114668,
		"TLiveManager::perform": 0x801146a8,
		"TLiveManager::setFlagOutOfCube": 0x801147a4,
		"TLiveManager::clipActors": 0x8011486c,
		"TLiveManager::clipActorsAux": 0x80114894,
		"clipActorsAux": 0x80114894,
		"TLiveManager::manageActor": 0x801149bc,
		"manageActor": 0x801149bc,
		"TLiveManager::load": 0x801149e8,
		"TLiveManager::createSpcBinary": 0x80114a28,
		"createSpcBinary": 0x80114a28,
		"TLiveManager::TLiveManager": 0x80114aac,
		"TObjCheckList::TObjCheckList": 0x80114bf0,
		"TObjHitCheck::TObjHitCheck": 0x80114c00,
		"TObjHitCheck::clearHitNum": 0x80114dd8,
		"clearHitNum": 0x80114dd8,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::begin": 0x801151ec,
		"TObjHitCheck::checkActorsHit": 0x801151f8,
		"checkActorsHit": 0x801151f8,
		"TObjHitCheck::entryGroup": 0x80115544,
		"entryGroup": 0x80115544,
		"TObjHitCheck::checkAndEntryGroup": 0x8011571c,
		"checkAndEntryGroup": 0x8011571c,
		"TObjHitCheck::checkWater": 0x801159dc,
		"checkWater": 0x801159dc,
		"TObjHitCheck::suffererIsInAttackArea": 0x80115b94,
		"suffererIsInAttackArea": 0x80115b94,
		"Strategic::checkDistance": 0x80115be8,
		"checkDistance": 0x80115be8,
		"TObjManager::searchF": 0x80115c5c,
		"TObjManager::getModelDataKeeper": 0x80115cec,
		"getModelDataKeeper": 0x80115cec,
		"TObjManager::createAnmData": 0x80115d38,
		"TObjManager::createModelData": 0x80115d98,
		"TObjManager::createModelDataArrayBase": 0x80115dcc,
		"createModelDataArrayBase": 0x80115dcc,
		"TObjManager::createModelDataArray": 0x80115eb4,
		"TObjManager::perform": 0x80115edc,
		"TObjManager::getMActorAnmData": 0x80115fc8,
		"TObjManager::load": 0x80116014,
		"TObjManager::manageObj": 0x801160bc,
		"manageObj": 0x801160bc,
		"TObjManager::TObjManager": 0x801160dc,
		"TObjChara::getRes": 0x80116168,
		"TObjChara::~TObjChara": 0x801161a8,
		"TObjChara::load": 0x8011621c,
		"TMActorKeeper::createMActorFromAllBmd": 0x801163f0,
		"createMActorFromAllBmd": 0x801163f0,
		"TMActorKeeper::createMActor": 0x80116508,
		"createMActor": 0x80116508,
		"TMActorKeeper::createMActorFromNthData": 0x8011675c,
		"createMActorFromNthData": 0x8011675c,
		"TMActorKeeper::createMActorFromDefaultBmd": 0x8011689c,
		"createMActorFromDefaultBmd": 0x8011689c,
		"TMActorKeeper::getMActor": 0x801169c0,
		"TMActorKeeper::createAndRegister": 0x80116abc,
		"createAndRegister": 0x80116abc,
		"TModelDataKeeper::TModelDataKeeper": 0x80116b78,
		"TModelDataKeeper::getModelDataNum": 0x80116b94,
		"getModelDataNum": 0x80116b94,
		"TModelDataKeeper::getDataByName": 0x80116bc0,
		"getDataByName": 0x80116bc0,
		"TModelDataKeeper::getNthData": 0x80116cdc,
		"getNthData": 0x80116cdc,
		"TModelDataKeeper::createAndKeepData": 0x80116d54,
		"createAndKeepData": 0x80116d54,
		"TModelDataKeeper::loadModelData": 0x80116e38,
		"loadModelData": 0x80116e38,
		"TModelDataNode::registerDataAndJoinNewNode": 0x80116eb0,
		"registerDataAndJoinNewNode": 0x80116eb0,
		"TSpcInterp::update": 0x80116f14,
		"TSpcInterp::verifyArgNum": 0x80117430,
		"verifyArgNum": 0x80117430,
		"TSpcInterp::dump": 0x80117550,
		"TSpcInterp::~TSpcInterp": 0x801177e8,
		"TSpcInterp::TSpcInterp": 0x8011789c,
		"TSpcStack<unsigned_long><unsigned_long>::~TSpcStack": 0x80117aa0,
		"TSpcStack<TSpcSlice>::~TSpcStack": 0x80117b00,
		"TSpcSlice::TSpcSlice": 0x80117b64,
		"TSpcInterp::dispatchBuiltin": 0x80117b74,
		"TSpcInterp::dispatchBuiltinDefault": 0x80117b94,
		"dispatchBuiltinDefault": 0x80117b94,
		"TSpcInterp::execend": 0x80117d88,
		"execend": 0x80117d88,
		"TSpcInterp::execint1": 0x80117dc4,
		"execint1": 0x80117dc4,
		"TSpcInterp::execint0": 0x80117e3c,
		"execint0": 0x80117e3c,
		"TSpcInterp::execpop": 0x80117eb0,
		"execpop": 0x80117eb0,
		"TSpcInterp::execjmp": 0x80117ef4,
		"execjmp": 0x80117ef4,
		"TSpcInterp::execjne": 0x80117f4c,
		"execjne": 0x80117f4c,
		"TSpcInterp::execret0": 0x80118074,
		"execret0": 0x80118074,
		"TSpcInterp::execret": 0x80118250,
		"execret": 0x80118250,
		"TSpcInterp::execmkds": 0x801183d8,
		"execmkds": 0x801183d8,
		"TSpcInterp::execmkfr": 0x801184ec,
		"execmkfr": 0x801184ec,
		"TSpcInterp::execfunc": 0x801185d8,
		"execfunc": 0x801185d8,
		"TSpcInterp::execcall": 0x80118694,
		"execcall": 0x80118694,
		"TSpcInterp::execshr": 0x801188d8,
		"execshr": 0x801188d8,
		"TSpcInterp::execshl": 0x80118aa8,
		"execshl": 0x80118aa8,
		"TSpcInterp::execbor": 0x80118c78,
		"execbor": 0x80118c78,
		"TSpcInterp::execband": 0x80118e48,
		"execband": 0x80118e48,
		"TSpcInterp::execor": 0x80119018,
		"execor": 0x80119018,
		"TSpcSlice::getDataInt": 0x801191e4,
		"getDataInt": 0x801191e4,
		"TSpcInterp::execand": 0x8011922c,
		"execand": 0x8011922c,
		"TSpcInterp::execnot": 0x801193f8,
		"execnot": 0x801193f8,
		"TSpcInterp::execneg": 0x8011952c,
		"execneg": 0x8011952c,
		"TSpcInterp::execle": 0x80119644,
		"execle": 0x80119644,
		"TSpcSlice::getDataFloat": 0x80119820,
		"getDataFloat": 0x80119820,
		"TSpcInterp::execge": 0x80119878,
		"execge": 0x80119878,
		"TSpcInterp::execlt": 0x80119a54,
		"execlt": 0x80119a54,
		"TSpcInterp::execgt": 0x80119c2c,
		"execgt": 0x80119c2c,
		"TSpcInterp::execne": 0x80119e04,
		"execne": 0x80119e04,
		"TSpcSlice::operator_!=": 0x80119f6c,
		"operator_!=": 0x80119f6c,
		"TSpcInterp::execeq": 0x8011a108,
		"execeq": 0x8011a108,
		"TSpcSlice::operator_==": 0x8011a270,
		"TSpcInterp::execass": 0x8011a40c,
		"execass": 0x8011a40c,
		"TSpcInterp::execmod": 0x8011a568,
		"execmod": 0x8011a568,
		"TSpcInterp::execdiv": 0x8011a740,
		"execdiv": 0x8011a740,
		"TSpcInterp::execmul": 0x8011aa18,
		"execmul": 0x8011aa18,
		"TSpcInterp::execsub": 0x8011acf0,
		"execsub": 0x8011acf0,
		"TSpcInterp::execadd": 0x8011afc8,
		"execadd": 0x8011afc8,
		"TSpcInterp::execdec": 0x8011b2a0,
		"execdec": 0x8011b2a0,
		"TSpcInterp::execinc": 0x8011b40c,
		"execinc": 0x8011b40c,
		"TSpcInterp::execnop": 0x8011b578,
		"execnop": 0x8011b578,
		"TSpcInterp::execvar": 0x8011b57c,
		"execvar": 0x8011b57c,
		"TSpcInterp::execadr": 0x8011b690,
		"execadr": 0x8011b690,
		"TSpcInterp::fetchU32": 0x8011b714,
		"fetchU32": 0x8011b714,
		"TSpcInterp::execstr": 0x8011b768,
		"execstr": 0x8011b768,
		"TSpcBinary::getHeader": 0x8011b860,
		"getHeader": 0x8011b860,
		"TSpcInterp::execflt": 0x8011b868,
		"execflt": 0x8011b868,
		"TSpcInterp::execint": 0x8011b930,
		"execint": 0x8011b930,
		"TSpcInterp::fetchS32": 0x8011b9b4,
		"fetchS32": 0x8011b9b4,
		"TSpcBinary::bindSystemDataToSymbol": 0x8011ba08,
		"bindSystemDataToSymbol": 0x8011ba08,
		"TSpcBinary::searchSymbol": 0x8011bae4,
		"searchSymbol": 0x8011bae4,
		"TSpcBinary::initUserBuiltin": 0x8011bb9c,
		"TSpcBinary::init": 0x8011bba0,
		"TSpcBinary::~TSpcBinary": 0x8011be40,
		"TSpcBinary::TSpcBinary": 0x8011be8c,
		"Strategic::spcTypeof": 0x8011bea0,
		"spcTypeof": 0x8011bea0,
		"Strategic::spcFloat": 0x8011c074,
		"spcFloat": 0x8011c074,
		"Strategic::spcInt": 0x8011c250,
		"spcInt": 0x8011c250,
		"Strategic::spcDump": 0x8011c410,
		"spcDump": 0x8011c410,
		"Strategic::spcPrint": 0x8011c4f0,
		"spcPrint": 0x8011c4f0,
		"Strategic::spcUnlock": 0x8011c6e8,
		"spcUnlock": 0x8011c6e8,
		"Strategic::spcLock": 0x8011c7cc,
		"spcLock": 0x8011c7cc,
		"Strategic::spcExit": 0x8011c8b0,
		"spcExit": 0x8011c8b0,
		"Strategic::spcYield": 0x8011c998,
		"spcYield": 0x8011c998,
		"TStrategy::~TStrategy": 0x8011ca7c,
		"TStrategy::perform": 0x8011caf0,
		"TStrategy::searchF": 0x8011cc78,
		"TStrategy::loadAfter": 0x8011cd08,
		"TStrategy::load": 0x8011cd7c,
		"TStrategy::TStrategy": 0x8011ce94,
		"TIdxGroupObj::loadSuper": 0x8011cf4c,
		"TIdxGroupObj::~TIdxGroupObj": 0x8011cf94,
		"TQuestionManager::~TQuestionManager": 0x8011d030,
		"TQuestionManager::perform": 0x8011d0a4,
		"TQuestionManager::draw": 0x8011d19c,
		"TQuestionManager::makeDL": 0x8011d310,
		"TQuestionManager::request": 0x8011d438,
		"TQuestionManager::load": 0x8011d4cc,
		"TQuestionRequest::TQuestionRequest": 0x8011d5bc,
		"TSMSSmplChara::~TSMSSmplChara": 0x8011d5c0,
		"TSMSSmplChara::getRes": 0x8011d640,
		"TSMSSmplChara::load": 0x8011d684,
		"THitActor::THitActor": 0x8011d6cc,
		"THitActor::initHitActor": 0x8011d7f8,
		"initHitActor": 0x8011d7f8,
		"THitActor::perform": 0x8011d8c4,
		"THitActor::calcEntryRadius": 0x8011d8e4,
		"calcEntryRadius": 0x8011d8e4,
		"TBinder::~TBinder": 0x8011d968,
		"TBinder::TBinder": 0x8011d9b4,
		"TSharedParts::perform": 0x8011da38,
		"TSharedParts::getConnectedMtx": 0x8011dafc,
		"getConnectedMtx": 0x8011dafc,
		"TMirrorActor::~TMirrorActor": 0x8011de00,
		"TMirrorActor::TMirrorActor": 0x8011de74,
		"TMirrorActor::init": 0x8011deec,
		"TMirrorActor::entryMirrorDrawBufferAlways": 0x8011e0e8,
		"entryMirrorDrawBufferAlways": 0x8011e0e8,
		"TMirrorActor::perform": 0x8011e1dc,
		"TMirrorActor::checkIsInMirror": 0x8011e318,
		"checkIsInMirror": 0x8011e318,
		"Strategic::__sinit_MirrorActor_cpp": 0x8011e4cc,
		"__sinit_MirrorActor_cpp": 0x8011e4cc,
		"Player::__sinit_Atom_cpp": 0x8011e7d8,
		"__sinit_Atom_cpp": 0x8011e7d8,
		"TMario::actnMain": 0x8011e7f4,
		"actnMain": 0x8011e7f4,
		"TMario::taking": 0x8011ea4c,
		"taking": 0x8011ea4c,
		"Player::__sinit_MarioAction_cpp": 0x8011eb70,
		"__sinit_MarioAction_cpp": 0x8011eb70,
		"TMario::demoMain": 0x8011ee6c,
		"demoMain": 0x8011ee6c,
		"TMario::footDowning": 0x8011f1ac,
		"footDowning": 0x8011f1ac,
		"TMario::electricDamage": 0x8011f2f4,
		"electricDamage": 0x8011f2f4,
		"TMario::warpOut": 0x8011f47c,
		"warpOut": 0x8011f47c,
		"TMario::toroccoStart": 0x8011f738,
		"toroccoStart": 0x8011f738,
		"TMario::waitingStart": 0x8011f7fc,
		"waitingStart": 0x8011f7fc,
		"TMario::returnStart": 0x8011f8fc,
		"returnStart": 0x8011f8fc,
		"TMario::rollingStart": 0x8011fa94,
		"rollingStart": 0x8011fa94,
		"TMario::isUnUsualStageStart": 0x8011fb98,
		"isUnUsualStageStart": 0x8011fb98,
		"TMario::warpIn": 0x8011fd5c,
		"warpIn": 0x8011fd5c,
		"TMario::jumpingDemoCommon": 0x80120228,
		"jumpingDemoCommon": 0x80120228,
		"TMario::readBillboard": 0x801202b0,
		"readBillboard": 0x801202b0,
		"TMario::winDemo": 0x801204b8,
		"winDemo": 0x801204b8,
		"Player::__sinit_MarioAutodemo_cpp": 0x8012059c,
		"__sinit_MarioAutodemo_cpp": 0x8012059c,
		"M3UModelMario::updateOut": 0x80120898,
		"M3UModelMario::updateIn": 0x801208e0,
		"M3UModelMario::updateInMotion": 0x80120914,
		"M3UModelMario::changeMtxCalcSIAnmBQAnmTransform": 0x80120a70,
		"changeMtxCalcSIAnmBQAnmTransform": 0x80120a70,
		"TMarioCap::mtxEffectHide": 0x80120adc,
		"mtxEffectHide": 0x80120adc,
		"TMarioCap::mtxEffectShow": 0x80120b50,
		"mtxEffectShow": 0x80120b50,
		"TMarioCap::perform": 0x80120bc4,
		"TMarioCap::createMirrorCap": 0x80121248,
		"createMirrorCap": 0x80121248,
		"TMarioCap::TMarioCap": 0x801212c8,
		"TMario::considerTake": 0x80121758,
		"considerTake": 0x80121758,
		"TMario::damageExec": 0x8012194c,
		"JGeometry::TVec3<float><float>::operator*=": 0x80121ee4,
		"operator*=": 0x80121ee4,
		"TMario::calcDamagePos": 0x80121f78,
		"calcDamagePos": 0x80121f78,
		"TMario::loserExec": 0x8012228c,
		"loserExec": 0x8012228c,
		"TMario::normalizeNozzle": 0x801223dc,
		"normalizeNozzle": 0x801223dc,
		"TMario::resetNozzle": 0x80122444,
		"resetNozzle": 0x80122444,
		"TMario::trampleExec": 0x80122448,
		"trampleExec": 0x80122448,
		"TMario::canTake": 0x801226e0,
		"canTake": 0x801226e0,
		"TMario::isTakeSituation": 0x8012272c,
		"isTakeSituation": 0x8012272c,
		"TMario::dropObject": 0x8012292c,
		"dropObject": 0x8012292c,
		"TMario::getAttackAngle": 0x80122980,
		"getAttackAngle": 0x80122980,
		"TMario::decHP": 0x801229b8,
		"decHP": 0x801229b8,
		"TMario::incHP": 0x80122ab8,
		"incHP": 0x80122ab8,
		"TMario::rumbleStart": 0x80122bd0,
		"rumbleStart": 0x80122bd0,
		"Player::SMS_EasyEmitParticle": 0x80122c04,
		"Player::__sinit_MarioCollision_cpp": 0x80122c84,
		"__sinit_MarioCollision_cpp": 0x80122c84,
		"TMario::addDamageFog": 0x80122f80,
		"addDamageFog": 0x80122f80,
		"TMario::addDirty": 0x8012327c,
		"addDirty": 0x8012327c,
		"TMario::boxDrawPrepare": 0x8012339c,
		"boxDrawPrepare": 0x8012339c,
		"TMario::drawLogic": 0x80123598,
		"drawLogic": 0x80123598,
		"TMario::drawSpecial": 0x80123730,
		"drawSpecial": 0x80123730,
		"TMario::entryModels": 0x8012379c,
		"entryModels": 0x8012379c,
		"TMario::calcView": 0x801238d0,
		"calcView": 0x801238d0,
		"TMario::calcAnim": 0x80123a10,
		"TMario::addUpper": 0x80124084,
		"addUpper": 0x80124084,
		"TMario::setUpperDamageRun": 0x80124238,
		"setUpperDamageRun": 0x80124238,
		"TMario::addCallBack": 0x801242d0,
		"addCallBack": 0x801242d0,
		"TMario::calcBaseMtx": 0x80124660,
		"calcBaseMtx": 0x80124660,
		"TMario::considerWaist": 0x80125284,
		"considerWaist": 0x80125284,
		"TMario::isUpperPumpingStyle": 0x8012561c,
		"isUpperPumpingStyle": 0x8012561c,
		"TMario::finalDrawInitialize": 0x80125640,
		"finalDrawInitialize": 0x80125640,
		"TMario::initMirrorModel": 0x80125710,
		"initMirrorModel": 0x80125710,
		"TMario::initModel": 0x8012582c,
		"TMario::loadAnmTexPattern": 0x801267e0,
		"loadAnmTexPattern": 0x801267e0,
		"TMario::loadBas": 0x80126844,
		"loadBas": 0x80126844,
		"TMario::setReverseAnimation": 0x8012688c,
		"setReverseAnimation": 0x8012688c,
		"TMario::setAnimation": 0x80126948,
		"TMario::changeHand": 0x80126cec,
		"changeHand": 0x80126cec,
		"TMario::isAnimeLoopOrStop": 0x801270ec,
		"isAnimeLoopOrStop": 0x801270ec,
		"TMario::isLast1AnimeFrame": 0x80127110,
		"isLast1AnimeFrame": 0x80127110,
		"TMario::getMotionFrameCtrl": 0x80127160,
		"getMotionFrameCtrl": 0x80127160,
		"TMario::getCurrentFrame": 0x8012716c,
		"getCurrentFrame": 0x8012716c,
		"TMario::getTakenMtx": 0x80127184,
		"getTakenMtx": 0x80127184,
		"TMario::getTakingMtx": 0x80127194,
		"TMario::getTrampleCt": 0x801271b0,
		"getTrampleCt": 0x801271b0,
		"TMario::setPositions": 0x801271f8,
		"setPositions": 0x801271f8,
		"TMario::takeOffGlass": 0x8012729c,
		"takeOffGlass": 0x8012729c,
		"TMario::wearGlass": 0x801272e8,
		"wearGlass": 0x801272e8,
		"TMario::isWearingHelm": 0x80127334,
		"isWearingHelm": 0x80127334,
		"TMario::isWearingCap": 0x80127364,
		"isWearingCap": 0x80127364,
		"TMario::setDivHelm": 0x80127394,
		"setDivHelm": 0x80127394,
		"TMario::getWallAngle": 0x801273ec,
		"getWallAngle": 0x801273ec,
		"TMario::getPumpFrame": 0x8012741c,
		"getPumpFrame": 0x8012741c,
		"TMario::getCenterAnmMtx": 0x8012742c,
		"getCenterAnmMtx": 0x8012742c,
		"TMario::getRootAnmMtx": 0x80127448,
		"getRootAnmMtx": 0x80127448,
		"Player::MarioFootDirLCtrl": 0x80127458,
		"MarioFootDirLCtrl": 0x80127458,
		"Player::MarioFootPosLCtrl": 0x801276e8,
		"MarioFootPosLCtrl": 0x801276e8,
		"Player::MarioFootDirRCtrl": 0x80127820,
		"MarioFootDirRCtrl": 0x80127820,
		"Player::MarioFootPosRCtrl": 0x80127ab0,
		"MarioFootPosRCtrl": 0x80127ab0,
		"Player::MarioWaistCtrl": 0x80127be8,
		"MarioWaistCtrl": 0x80127be8,
		"Player::MarioHeadCtrl": 0x80127e64,
		"MarioHeadCtrl": 0x80127e64,
		"TMarioAnimeData::isPumpOK": 0x801282d8,
		"isPumpOK": 0x801282d8,
		"Player::__sinit_MarioDraw_cpp": 0x80128310,
		"__sinit_MarioDraw_cpp": 0x80128310,
		"TMario::jumpMain": 0x8012860c,
		"jumpMain": 0x8012860c,
		"TMario::diving": 0x8012968c,
		"diving": 0x8012968c,
		"TMario::hipAttacking": 0x80129a88,
		"hipAttacking": 0x80129a88,
		"TMario::rocketing": 0x8012a044,
		"rocketing": 0x8012a044,
		"TMario::rocketCheck": 0x8012a4f4,
		"rocketCheck": 0x8012a4f4,
		"TMario::boardJumping": 0x8012a678,
		"boardJumping": 0x8012a678,
		"TMario::thrownDowning": 0x8012a7d4,
		"thrownDowning": 0x8012a7d4,
		"TMario::fireDowning": 0x8012a99c,
		"fireDowning": 0x8012a99c,
		"TMario::slipFalling": 0x8012ac04,
		"slipFalling": 0x8012ac04,
		"TMario::catchStop": 0x8012aeac,
		"catchStop": 0x8012aeac,
		"TMario::stayWall": 0x8012afac,
		"stayWall": 0x8012afac,
		"TMario::jumpDownCommon": 0x8012b294,
		"jumpDownCommon": 0x8012b294,
		"TMario::jumpCatch": 0x8012b38c,
		"jumpCatch": 0x8012b38c,
		"TMario::landing": 0x8012b644,
		"landing": 0x8012b644,
		"TMario::checkBackTrig": 0x8012b7ac,
		"checkBackTrig": 0x8012b7ac,
		"TMario::considerJumpRotate": 0x8012b848,
		"considerJumpRotate": 0x8012b848,
		"TMario::jumpingBasic": 0x8012b8bc,
		"jumpingBasic": 0x8012b8bc,
		"TMario::doJumping": 0x8012bf2c,
		"doJumping": 0x8012bf2c,
		"TMario::startJumpWall": 0x8012c284,
		"startJumpWall": 0x8012c284,
		"Player::__sinit_MarioJump_cpp": 0x8012c354,
		"__sinit_MarioJump_cpp": 0x8012c354,
		"TMario::perform": 0x8012c77c,
		"TMario::isMario": 0x8012cfe0,
		"isMario": 0x8012cfe0,
		"Player::__sinit_MarioMain_cpp": 0x8012cffc,
		"__sinit_MarioMain_cpp": 0x8012cffc,
		"TMario::playerControl": 0x8012d30c,
		"TYoshi::onYoshi": 0x8012d7b8,
		"TMario::gunExec": 0x8012d7d4,
		"gunExec": 0x8012d7d4,
		"TMario::checkWet": 0x8012dc1c,
		"checkWet": 0x8012dc1c,
		"TBGCheckData::isMarioThrough": 0x8012de24,
		"isMarioThrough": 0x8012de24,
		"TMario::thinkYoshiHeadCollision": 0x8012de78,
		"thinkYoshiHeadCollision": 0x8012de78,
		"TMario::getOffYoshi": 0x8012e040,
		"getOffYoshi": 0x8012e040,
		"TMario::thinkParams": 0x8012e128,
		"thinkParams": 0x8012e128,
		"TMario::thinkSand": 0x8012e42c,
		"thinkSand": 0x8012e42c,
		"TMario::thinkWaterSurface": 0x8012e4c8,
		"thinkWaterSurface": 0x8012e4c8,
		"TMario::thinkSituation": 0x8012ed54,
		"thinkSituation": 0x8012ed54,
		"TMario::calcGroundMtx": 0x8012f350,
		"calcGroundMtx": 0x8012f350,
		"TMario::stateMachine": 0x8012f508,
		"stateMachine": 0x8012f508,
		"TMario::checkPlayerAction": 0x8012f5ec,
		"checkPlayerAction": 0x8012f5ec,
		"TMario::checkRideReCalc": 0x8012f658,
		"checkRideReCalc": 0x8012f658,
		"TMario::checkRideMovement": 0x8012f704,
		"checkRideMovement": 0x8012f704,
		"TMario::checkCurrentPlane": 0x8012f9d4,
		"checkCurrentPlane": 0x8012f9d4,
		"TMario::getDmgMapCode": 0x80130490,
		"getDmgMapCode": 0x80130490,
		"TMario::checkGroundPlane": 0x80130508,
		"checkGroundPlane": 0x80130508,
		"TMario::makeHistory": 0x8013062c,
		"makeHistory": 0x8013062c,
		"TMario::checkStickRotate": 0x80130758,
		"checkStickRotate": 0x80130758,
		"TMario::checkController": 0x801308e8,
		"TMario::checkThrowObject": 0x80131670,
		"checkThrowObject": 0x80131670,
		"TMario::checkReturn": 0x801316c4,
		"TMario::checkEnforceJump": 0x801317e4,
		"checkEnforceJump": 0x801317e4,
		"MSound::startForceJumpSound": 0x8013191c,
		"startForceJumpSound": 0x8013191c,
		"TMario::checkSink": 0x801319fc,
		"checkSink": 0x801319fc,
		"TMario::thinkHeight": 0x80131d18,
		"thinkHeight": 0x80131d18,
		"TMario::thinkDirty": 0x80131e64,
		"thinkDirty": 0x80131e64,
		"TMario::dirtyLimitCheck": 0x80132010,
		"dirtyLimitCheck": 0x80132010,
		"TMario::checkGraffito": 0x8013203c,
		"checkGraffito": 0x8013203c,
		"TMario::checkGraffitoElec": 0x80132614,
		"checkGraffitoElec": 0x80132614,
		"TMario::checkGraffitoSlip": 0x801327cc,
		"checkGraffitoSlip": 0x801327cc,
		"TMario::checkGraffitoFire": 0x80132a50,
		"checkGraffitoFire": 0x80132a50,
		"TMario::checkAllMotions": 0x80132cd0,
		"checkAllMotions": 0x80132cd0,
		"TMario::changePlayerDropping": 0x80132e00,
		"changePlayerDropping": 0x80132e00,
		"TMario::changePlayerJumping": 0x80132e58,
		"changePlayerJumping": 0x80132e58,
		"TMario::changePlayerTriJump": 0x80133144,
		"changePlayerTriJump": 0x80133144,
		"TMario::changePlayerStatus": 0x80133424,
		"changePlayerStatus": 0x80133424,
		"TMario::throwMario": 0x801335f0,
		"TMario::setStatusToJumping": 0x80133790,
		"setStatusToJumping": 0x80133790,
		"TMario::checkPlayerAround": 0x801342e8,
		"checkPlayerAround": 0x801342e8,
		"TMario::getSlideStopCatch": 0x8013435c,
		"getSlideStopCatch": 0x8013435c,
		"TMario::getSlideStopNormal": 0x801344dc,
		"getSlideStopNormal": 0x801344dc,
		"TMario::canSlipJump": 0x80134654,
		"canSlipJump": 0x80134654,
		"TMario::isSlipStart": 0x801347f0,
		"isSlipStart": 0x801347f0,
		"TMario::isFrontSlip": 0x80134960,
		"isFrontSlip": 0x80134960,
		"TMario::checkRoofPlane": 0x801349b0,
		"checkRoofPlane": 0x801349b0,
		"TMario::checkWallPlane": 0x801349ec,
		"checkWallPlane": 0x801349ec,
		"TMario::setPlayerVelocity": 0x80134b24,
		"setPlayerVelocity": 0x80134b24,
		"TMario::setNormalAttackArea": 0x80134b84,
		"setNormalAttackArea": 0x80134b84,
		"TMario::canBendBody": 0x80134bc8,
		"canBendBody": 0x80134bc8,
		"TMario::considerRotateJumpStart": 0x80134c08,
		"considerRotateJumpStart": 0x80134c08,
		"TMario::addVelocity": 0x80134c94,
		"addVelocity": 0x80134c94,
		"TMario::onYoshi": 0x80134cb8,
		"TMario::windMove": 0x80134d00,
		"windMove": 0x80134d00,
		"TMario::flowMove": 0x80134d34,
		"flowMove": 0x80134d34,
		"TMario::warpRequest": 0x80134d8c,
		"warpRequest": 0x80134d8c,
		"TMario::moveRequest": 0x80134e7c,
		"TMario::isForceSlip": 0x80135108,
		"isForceSlip": 0x80135108,
		"TMario::getRidingMtx": 0x801351b0,
		"getRidingMtx": 0x801351b0,
		"TMario::isWallInFront": 0x8013522c,
		"isWallInFront": 0x8013522c,
		"TMario::isInvincible": 0x80135294,
		"isInvincible": 0x80135294,
		"TMario::isUnderWater": 0x80135348,
		"isUnderWater": 0x80135348,
		"TMario::canSquat": 0x80135390,
		"canSquat": 0x80135390,
		"TMario::getJumpSlideControl": 0x8013541c,
		"getJumpSlideControl": 0x8013541c,
		"TMario::getJumpAccelControl": 0x801354b8,
		"getJumpAccelControl": 0x801354b8,
		"Player::__sinit_MarioMove_cpp": 0x801354d4,
		"__sinit_MarioMove_cpp": 0x801354d4,
		"TMario::jumpProcess": 0x801357d0,
		"jumpProcess": 0x801357d0,
		"TMario::fallProcess": 0x8013593c,
		"fallProcess": 0x8013593c,
		"TMario::checkGroundAtJumping": 0x80135a84,
		"checkGroundAtJumping": 0x80135a84,
		"TMario::hangonCheck": 0x80136064,
		"hangonCheck": 0x80136064,
		"TMario::barProcess": 0x80136254,
		"barProcess": 0x80136254,
		"TMario::walkProcess": 0x801364b4,
		"walkProcess": 0x801364b4,
		"TMario::waitProcess": 0x80136574,
		"waitProcess": 0x80136574,
		"TMario::stopProcess": 0x80136694,
		"stopProcess": 0x80136694,
		"TMario::checkGroundAtWalking": 0x801366e4,
		"checkGroundAtWalking": 0x801366e4,
		"TMario::checkDescent": 0x80136980,
		"checkDescent": 0x80136980,
		"TMario::playerRefrection": 0x80136f50,
		"playerRefrection": 0x80136f50,
		"Player::__sinit_MarioPhysics_cpp": 0x80136fe8,
		"__sinit_MarioPhysics_cpp": 0x80136fe8,
		"TMarioInputReplay::reset": 0x801372e4,
		"TMarioInputReplay::play": 0x80137344,
		"TMarioInputReplay::init": 0x80137428,
		"TRecordValueManager<unsigned_char><unsigned_char>::reset": 0x80137518,
		"TRecordValueManager<unsigned_char><unsigned_char>::get": 0x80137538,
		"TRecordValueManager<unsigned_short><unsigned_short>::reset": 0x80137590,
		"TRecordValueManager<unsigned_short><unsigned_short>::get": 0x801375b0,
		"TRecordValueManager<short><short>::reset": 0x80137608,
		"TRecordValueManager<short><short>::get": 0x80137628,
		"TRecordValueManager<float><float>::reset": 0x80137680,
		"TRecordValueManager<float><float>::get": 0x801376a0,
		"TMario::moveMain": 0x801376f8,
		"moveMain": 0x801376f8,
		"TMario::jumpSlipEvents": 0x80138114,
		"jumpSlipEvents": 0x80138114,
		"TMario::jumpSlipCommon": 0x8013824c,
		"jumpSlipCommon": 0x8013824c,
		"TMario::loserDown": 0x80138384,
		"loserDown": 0x80138384,
		"TMario::downingCommon": 0x801384a8,
		"downingCommon": 0x801384a8,
		"TMario::oilSlip": 0x801385f8,
		"oilSlip": 0x801385f8,
		"TMario::oilRun": 0x80138828,
		"oilRun": 0x80138828,
		"TMario::catching": 0x80138afc,
		"catching": 0x80138afc,
		"TMario::slipBackCommon": 0x80138c50,
		"slipBackCommon": 0x80138c50,
		"TMario::slipForeCommon": 0x80138d30,
		"slipForeCommon": 0x80138d30,
		"TMario::slippingBasic": 0x80138df8,
		"slippingBasic": 0x80138df8,
		"TMario::fireDashing": 0x80139114,
		"fireDashing": 0x80139114,
		"TMario::walkEnd": 0x8013929c,
		"walkEnd": 0x8013929c,
		"TMario::surfing": 0x80139588,
		"surfing": 0x80139588,
		"TMario::turnEnd": 0x80139830,
		"turnEnd": 0x80139830,
		"TMario::turnning": 0x80139a94,
		"turnning": 0x80139a94,
		"TMario::rotating": 0x80139e80,
		"rotating": 0x80139e80,
		"TMario::running": 0x80139fa8,
		"running": 0x80139fa8,
		"TMario::doPushingAnimation": 0x8013a738,
		"doPushingAnimation": 0x8013a738,
		"TMario::doSurfing": 0x8013a890,
		"doSurfing": 0x8013a890,
		"TMario::getSurfingParamsWater": 0x8013aca0,
		"getSurfingParamsWater": 0x8013aca0,
		"TMario::doRunning": 0x8013acd4,
		"doRunning": 0x8013acd4,
		"TMario::slopeProcess": 0x8013afc0,
		"slopeProcess": 0x8013afc0,
		"TMario::doSliding": 0x8013b134,
		"doSliding": 0x8013b134,
		"TMario::slideProcess": 0x8013b520,
		"slideProcess": 0x8013b520,
		"TMario::getSlideStickMult": 0x8013b8e8,
		"getSlideStickMult": 0x8013b8e8,
		"TMario::getChangeAngleSpeed": 0x8013b990,
		"getChangeAngleSpeed": 0x8013b990,
		"TMario::getSlopeSlideAccele": 0x8013bb44,
		"getSlopeSlideAccele": 0x8013bb44,
		"TMario::getSlopeNormalAccele": 0x8013bca0,
		"getSlopeNormalAccele": 0x8013bca0,
		"TMario::doRunningAnimation": 0x8013bdfc,
		"doRunningAnimation": 0x8013bdfc,
		"TMario::isRunningInWater": 0x8013c0d0,
		"isRunningInWater": 0x8013c0d0,
		"TMario::considerRotateStart": 0x8013c118,
		"considerRotateStart": 0x8013c118,
		"Player::__sinit_MarioRun_cpp": 0x8013c228,
		"__sinit_MarioRun_cpp": 0x8013c228,
		"TMario::specMain": 0x8013c524,
		"specMain": 0x8013c524,
		"TMario::fencePunch": 0x8013d2f0,
		"fencePunch": 0x8013d2f0,
		"TMario::fenceMove": 0x8013d5a8,
		"fenceMove": 0x8013d5a8,
		"TMario::pulling": 0x8013dd68,
		"pulling": 0x8013dd68,
		"TMario::getCurrentPullParams": 0x8013e26c,
		"getCurrentPullParams": 0x8013e26c,
		"TMario::wireRolling": 0x8013e328,
		"wireRolling": 0x8013e328,
		"TMario::wireHanging": 0x8013ead4,
		"wireHanging": 0x8013ead4,
		"TMario::changeWireHanging": 0x8013f13c,
		"changeWireHanging": 0x8013f13c,
		"TMario::wireSWait": 0x8013f1c8,
		"wireSWait": 0x8013f1c8,
		"TMario::wireWait": 0x8013f554,
		"wireWait": 0x8013f554,
		"TMario::wireMove": 0x8013f9a4,
		"wireMove": 0x8013f9a4,
		"TMario::getOnWirePosAngle": 0x8013fadc,
		"getOnWirePosAngle": 0x8013fadc,
		"TMario::hanging": 0x8013fcc4,
		"hanging": 0x8013fcc4,
		"TMario::startHangLanding": 0x801406f0,
		"startHangLanding": 0x801406f0,
		"TMario::moveRoof": 0x801407c8,
		"moveRoof": 0x801407c8,
		"TMario::roofCommonEvents": 0x80140a2c,
		"roofCommonEvents": 0x80140a2c,
		"TMario::doRoofMovingProcess": 0x80140b2c,
		"doRoofMovingProcess": 0x80140b2c,
		"TMario::hangingCheckRoof": 0x80140c8c,
		"hangingCheckRoof": 0x80140c8c,
		"TMario::barClimb": 0x80140e28,
		"barClimb": 0x80140e28,
		"TMario::barWait": 0x801410f4,
		"barWait": 0x801410f4,
		"Player::__sinit_MarioSpecial_cpp": 0x80141558,
		"__sinit_MarioSpecial_cpp": 0x80141558,
		"TMario::stateMachineUpper": 0x80141854,
		"stateMachineUpper": 0x80141854,
		"TMario::checkPumpEnable": 0x80141acc,
		"checkPumpEnable": 0x80141acc,
		"TMario::checkPumping": 0x80141c98,
		"checkPumping": 0x80141c98,
		"Player::__sinit_MarioUpper_cpp": 0x80141db0,
		"__sinit_MarioUpper_cpp": 0x80141db0,
		"TMario::askJumpIntoWaterEffectExist": 0x801420ac,
		"askJumpIntoWaterEffectExist": 0x801420ac,
		"TMario::sinkInSandEffect": 0x801420e0,
		"sinkInSandEffect": 0x801420e0,
		"TMario::kickFruitEffect": 0x8014213c,
		"kickFruitEffect": 0x8014213c,
		"TMario::toroccoEffect": 0x801421e0,
		"toroccoEffect": 0x801421e0,
		"TMario::sleepingEffectKill": 0x80142300,
		"sleepingEffectKill": 0x80142300,
		"TMario::sleepingEffect": 0x80142340,
		"sleepingEffect": 0x80142340,
		"TMario::kickRoofEffect": 0x80142374,
		"kickRoofEffect": 0x80142374,
		"TMario::elecEndEffect": 0x80142408,
		"elecEndEffect": 0x80142408,
		"TMario::elecEffect": 0x8014243c,
		"elecEffect": 0x8014243c,
		"TMario::rocketEffectStart": 0x801424ac,
		"rocketEffectStart": 0x801424ac,
		"TMario::meltInWaterEffect": 0x80142578,
		"meltInWaterEffect": 0x80142578,
		"TMario::emitSandEffect": 0x80142624,
		"emitSandEffect": 0x80142624,
		"TMario::emitDirtyFootPrint": 0x8014264c,
		"emitDirtyFootPrint": 0x8014264c,
		"TMario::emitFootPrintWithEffect": 0x80142674,
		"emitFootPrintWithEffect": 0x80142674,
		"TMario::emitRotateShootEffect": 0x80142910,
		"emitRotateShootEffect": 0x80142910,
		"TMario::emitBlurSpinJump": 0x80142968,
		"emitBlurSpinJump": 0x80142968,
		"TMario::emitBlurHipDropSuper": 0x80142a1c,
		"emitBlurHipDropSuper": 0x80142a1c,
		"TMario::emitBlurHipDrop": 0x80142ac0,
		"emitBlurHipDrop": 0x80142ac0,
		"TMario::warpOutEffect": 0x80142b04,
		"warpOutEffect": 0x80142b04,
		"TMario::warpInLight": 0x80142d90,
		"warpInLight": 0x80142d90,
		"TMario::warpInEffect": 0x80142dc4,
		"warpInEffect": 0x80142dc4,
		"TWarpInCallBack::execute": 0x80142f40,
		"TMario::surfingEffect": 0x801430c4,
		"surfingEffect": 0x801430c4,
		"TMario::frontSlipEffect": 0x80143270,
		"frontSlipEffect": 0x80143270,
		"TMario::treeSlipEffect": 0x801433e4,
		"treeSlipEffect": 0x801433e4,
		"TMario::wallSlipEffect": 0x80143494,
		"wallSlipEffect": 0x80143494,
		"TMario::blurEffect": 0x801434c8,
		"blurEffect": 0x801434c8,
		"TMario::runningRippleEffect": 0x80143508,
		"runningRippleEffect": 0x80143508,
		"TMario::swimmingBubbleEffect": 0x80143560,
		"swimmingBubbleEffect": 0x80143560,
		"TMario::bubbleFromBody": 0x80143634,
		"bubbleFromBody": 0x80143634,
		"TMario::bubbleFromMouth": 0x801436f8,
		"bubbleFromMouth": 0x801436f8,
		"TBubbleCallBack::execute": 0x80143768,
		"TMario::inOutWaterEffect": 0x8014380c,
		"inOutWaterEffect": 0x8014380c,
		"TMario::rippleEffect": 0x801439c4,
		"rippleEffect": 0x801439c4,
		"TMario::smallTouchDownEffect": 0x80143a60,
		"smallTouchDownEffect": 0x80143a60,
		"TMario::strongTouchDownEffect": 0x80143b04,
		"strongTouchDownEffect": 0x80143b04,
		"TMario::emitGetCoinEffect": 0x80143b74,
		"emitGetCoinEffect": 0x80143b74,
		"TMario::emitGetWaterEffect": 0x80143bcc,
		"emitGetWaterEffect": 0x80143bcc,
		"TMario::emitGetEffect": 0x80143c00,
		"emitGetEffect": 0x80143c00,
		"TMario::emitSweatSometimes": 0x80143c4c,
		"emitSweatSometimes": 0x80143c4c,
		"TMario::emitSweat": 0x80143c80,
		"emitSweat": 0x80143c80,
		"TMario::emitSmoke": 0x80143d54,
		"emitSmoke": 0x80143d54,
		"TMario::moveParticle": 0x80143ea8,
		"moveParticle": 0x80143ea8,
		"TMario::initParticle": 0x80143f14,
		"Player::__sinit_MarioParticle_cpp": 0x80143fec,
		"__sinit_MarioParticle_cpp": 0x80143fec,
		"TMario::waitMain": 0x80144300,
		"waitMain": 0x80144300,
		"TMario::jumpEndEvents": 0x80144bd8,
		"jumpEndEvents": 0x80144bd8,
		"TMario::jumpEndCommon": 0x80144c50,
		"jumpEndCommon": 0x80144c50,
		"TMario::squatStandup": 0x80144cd0,
		"squatStandup": 0x80144cd0,
		"TMario::squating": 0x80144dec,
		"squating": 0x80144dec,
		"TMario::getSideWalkValues": 0x801451a8,
		"getSideWalkValues": 0x801451a8,
		"TMario::sleeping": 0x80145278,
		"sleeping": 0x80145278,
		"TMario::sleepily": 0x8014540c,
		"sleepily": 0x8014540c,
		"TMario::waiting": 0x8014552c,
		"waiting": 0x8014552c,
		"TMario::changeMontemanWaitingAnim": 0x801457cc,
		"changeMontemanWaitingAnim": 0x801457cc,
		"TMario::stopCommon": 0x801457ec,
		"stopCommon": 0x801457ec,
		"TMario::waitingCommonEvents": 0x801458a8,
		"waitingCommonEvents": 0x801458a8,
		"TMario::canPut": 0x80145ac8,
		"canPut": 0x80145ac8,
		"TMario::canSleep": 0x80145b88,
		"canSleep": 0x80145b88,
		"TMario::startTalking": 0x80145d44,
		"startTalking": 0x80145d44,
		"Player::__sinit_MarioWait_cpp": 0x80145dcc,
		"__sinit_MarioWait_cpp": 0x80145dcc,
		"TSplashManager::~TSplashManager": 0x801460c8,
		"TSplashManager::perform": 0x80146168,
		"TSplashManager::draw": 0x801461e8,
		"TSplashManager::makeDL": 0x80146408,
		"TSplashManager::move": 0x80146590,
		"TSplashManager::newSplash": 0x80146650,
		"newSplash": 0x80146650,
		"TSplashManager::load": 0x801466f4,
		"Player::__sinit_SplashManager_cpp": 0x8014688c,
		"__sinit_SplashManager_cpp": 0x8014688c,
		"TYoshiTongue::getTakingMtx": 0x80146c24,
		"TYoshiTongue::checkTaking": 0x80146c30,
		"checkTaking": 0x80146c30,
		"TYoshiTongue::checkTaken": 0x80146c34,
		"checkTaken": 0x80146c34,
		"TYoshiTongue::entry": 0x80146c38,
		"TYoshiTongue::viewCalc": 0x80146c94,
		"TYoshiTongue::calcAnim": 0x80146cf0,
		"TYoshiTongue::movement": 0x80146f6c,
		"JGeometry::TVec3<float><float>::operator_-=": 0x8014780c,
		"operator_-=": 0x8014780c,
		"TYoshiTongue::findTarget": 0x80147840,
		"findTarget": 0x80147840,
		"TYoshiTongue::canGo": 0x80147b70,
		"canGo": 0x80147b70,
		"TYoshiTongue::emit": 0x80147cac,
		"TYoshiTongue::initInLoadAfter": 0x80147e40,
		"TYoshiTongue::init": 0x80147f4c,
		"Player::__sinit_Tongue_cpp": 0x80148140,
		"__sinit_Tongue_cpp": 0x80148140,
		"TWaterGun::changeBackup": 0x80148444,
		"changeBackup": 0x80148444,
		"TWaterGun::damage": 0x801484f0,
		"damage": 0x801484f0,
		"TWaterGun::suck": 0x80148540,
		"suck": 0x80148540,
		"TWaterGun::emit": 0x80148658,
		"TWaterGun::triggerPressureMovement": 0x801488fc,
		"triggerPressureMovement": 0x801488fc,
		"TWaterGun::rotateProp": 0x80148994,
		"rotateProp": 0x80148994,
		"TWaterGun::getEmitPosDirSpeed": 0x80148a48,
		"getEmitPosDirSpeed": 0x80148a48,
		"TWaterGun::getPressureMax": 0x80148b08,
		"getPressureMax": 0x80148b08,
		"TWaterGun::getPressure": 0x80148b74,
		"getPressure": 0x80148b74,
		"TWaterGun::isPressureOn": 0x80148be0,
		"isPressureOn": 0x80148be0,
		"TWaterGun::setAmountToRate": 0x80148c5c,
		"setAmountToRate": 0x80148c5c,
		"TWaterGun::getCurrentNozzle": 0x80148ccc,
		"getCurrentNozzle": 0x80148ccc,
		"TWaterGun::perform": 0x80148ce0,
		"TWaterGun::calcAnimation": 0x80148e2c,
		"calcAnimation": 0x80148e2c,
		"TWaterGun::setBaseTRMtx": 0x801490b8,
		"setBaseTRMtx": 0x801490b8,
		"TWaterGun::movement": 0x801491a4,
		"TWaterGun::changeNozzle": 0x801496e8,
		"changeNozzle": 0x801496e8,
		"TWaterGun::getNozzleMtx": 0x80149828,
		"getNozzleMtx": 0x80149828,
		"TWaterGun::getEmitMtx": 0x80149844,
		"getEmitMtx": 0x80149844,
		"TWaterGun::initInLoadAfter": 0x8014993c,
		"TWaterGun::init": 0x80149940,
		"TWaterGun::TWaterGun": 0x80149fc4,
		"TNozzleDeform::animation": 0x8014a370,
		"TNozzleDeform::emit": 0x8014aa7c,
		"TNozzleDeform::movement": 0x8014ae24,
		"TNozzleTrigger::animation": 0x8014af4c,
		"TNozzleTrigger::emit": 0x8014b440,
		"TNozzleTrigger::movement": 0x8014b748,
		"TNozzleTrigger::init": 0x8014bb3c,
		"TNozzleBase::animation": 0x8014bb5c,
		"TNozzleBase::emit": 0x8014bf94,
		"TNozzleBase::emitCommon": 0x8014c260,
		"emitCommon": 0x8014c260,
		"TNozzleBase::movement": 0x8014c3f8,
		"TNozzleBase::calcGunAngle": 0x8014c4c0,
		"calcGunAngle": 0x8014c4c0,
		"TNozzleBase::init": 0x8014c5f4,
		"TNozzleBase::TNozzleBase": 0x8014c618,
		"Player::WaterGunDivingCtrlR": 0x8014ce18,
		"WaterGunDivingCtrlR": 0x8014ce18,
		"Player::WaterGunDivingCtrlL": 0x8014cea8,
		"WaterGunDivingCtrlL": 0x8014cea8,
		"Player::RotateCtrl": 0x8014cf38,
		"RotateCtrl": 0x8014cf38,
		"Player::NozzleCtrl": 0x8014cfbc,
		"NozzleCtrl": 0x8014cfbc,
		"TNozzleBase::getWaistAngle": 0x8014d068,
		"getWaistAngle": 0x8014d068,
		"TNozzleDeform::getNozzleKind": 0x8014d070,
		"Player::__sinit_WaterGun_cpp": 0x8014d080,
		"__sinit_WaterGun_cpp": 0x8014d080,
		"TYoshi::entry": 0x8014d37c,
		"TYoshi::viewCalc": 0x8014d638,
		"TYoshi::calcAnim": 0x8014d6b8,
		"TYoshi::movement": 0x8014daf4,
		"TYoshi::thinkHoldOut": 0x8014e794,
		"thinkHoldOut": 0x8014e794,
		"TYoshi::doEat": 0x8014e8f4,
		"doEat": 0x8014e8f4,
		"TYoshi::doSearch": 0x8014ea18,
		"doSearch": 0x8014ea18,
		"TYoshi::thinkUpper": 0x8014ef78,
		"thinkUpper": 0x8014ef78,
		"TYoshi::thinkAnimation": 0x8014f1a0,
		"thinkAnimation": 0x8014f1a0,
		"TYoshi::getOff": 0x8014f594,
		"getOff": 0x8014f594,
		"TYoshi::ride": 0x8014f744,
		"ride": 0x8014f744,
		"TYoshi::kill": 0x8014f834,
		"TYoshi::disappear": 0x8014f94c,
		"disappear": 0x8014f94c,
		"TYoshi::appearFromEgg": 0x8014fa60,
		"appearFromEgg": 0x8014fa60,
		"TYoshi::setEggYoshiPtr": 0x8014fbe8,
		"setEggYoshiPtr": 0x8014fbe8,
		"TYoshi::getEmitPosDir": 0x8014fbf0,
		"getEmitPosDir": 0x8014fbf0,
		"TYoshi::changeAnimation": 0x8014fc3c,
		"changeAnimation": 0x8014fc3c,
		"TYoshi::thinkBtp": 0x8014fcd8,
		"thinkBtp": 0x8014fcd8,
		"TYoshi::initInLoadAfter": 0x8014fd88,
		"TYoshi::init": 0x8014fe5c,
		"TYoshi::getMtxPtrFootR": 0x801508e8,
		"getMtxPtrFootR": 0x801508e8,
		"TYoshi::getMtxPtrFootL": 0x80150904,
		"getMtxPtrFootL": 0x80150904,
		"TYoshi::getFrameCtrl": 0x80150920,
		"Player::YoshiHeadCtrl": 0x80150948,
		"YoshiHeadCtrl": 0x80150948,
		"Player::__sinit_Yoshi_cpp": 0x801509d4,
		"__sinit_Yoshi_cpp": 0x801509d4,
		"TMarioEffect::perform": 0x80150d54,
		"TMarioEffect::setJumpIntoWaterEffectSmall": 0x80151034,
		"setJumpIntoWaterEffectSmall": 0x80151034,
		"TMarioEffect::setJumpIntoWaterEffect": 0x801511d0,
		"setJumpIntoWaterEffect": 0x801511d0,
		"TMarioEffect::init": 0x80151408,
		"Player::__sinit_MarioEffect_cpp": 0x80151618,
		"__sinit_MarioEffect_cpp": 0x80151618,
		"TMario::swimMain": 0x8015191c,
		"swimMain": 0x8015191c,
		"TMario::swimPaddle": 0x80152014,
		"swimPaddle": 0x80152014,
		"TMario::checkSwimJump": 0x80152144,
		"checkSwimJump": 0x80152144,
		"TMario::doSwimming": 0x801522b4,
		"doSwimming": 0x801522b4,
		"Player::__sinit_MarioSwim_cpp": 0x80152638,
		"__sinit_MarioSwim_cpp": 0x80152638,
		"Player::SMS_IsMarioRoofing": 0x80152934,
		"SMS_IsMarioRoofing": 0x80152934,
		"Player::SMS_IsMarioFencing": 0x80152960,
		"SMS_IsMarioFencing": 0x80152960,
		"Player::SMS_GetMarioRfPlane": 0x80152994,
		"SMS_GetMarioRfPlane": 0x80152994,
		"Player::SMS_GetMarioWlPlane": 0x801529a0,
		"SMS_GetMarioWlPlane": 0x801529a0,
		"Player::SMS_GetMarioGrPlane": 0x801529ac,
		"SMS_GetMarioGrPlane": 0x801529ac,
		"Player::SMS_WindMoveMario": 0x801529c4,
		"SMS_WindMoveMario": 0x801529c4,
		"Player::SMS_FlowMoveMario": 0x801529ec,
		"SMS_FlowMoveMario": 0x801529ec,
		"Player::SMS_MarioWarpRequest": 0x80152a14,
		"SMS_MarioWarpRequest": 0x80152a14,
		"Player::SMS_MarioMoveRequest": 0x80152a3c,
		"SMS_MarioMoveRequest": 0x80152a3c,
		"Player::SMS_IsMarioDashing": 0x80152a70,
		"SMS_IsMarioDashing": 0x80152a70,
		"Player::SMS_IsMarioOnYoshi": 0x80152aa4,
		"SMS_IsMarioOnYoshi": 0x80152aa4,
		"Player::SMS_IsMarioOpeningDoor": 0x80152ad8,
		"SMS_IsMarioOpeningDoor": 0x80152ad8,
		"Player::SMS_IsMarioOnWire": 0x80152b00,
		"SMS_IsMarioOnWire": 0x80152b00,
		"Player::SMS_IsMarioTouchGround4cm": 0x80152b48,
		"SMS_IsMarioTouchGround4cm": 0x80152b48,
		"Player::SMS_ThrowMario": 0x80152b8c,
		"SMS_ThrowMario": 0x80152b8c,
		"Player::SMS_SendMessageToMario": 0x80152bb4,
		"SMS_SendMessageToMario": 0x80152bb4,
		"Player::SMS_GetMarioWaterGun": 0x80152c04,
		"SMS_GetMarioWaterGun": 0x80152c04,
		"Player::SMS_GetMarioGravity": 0x80152c10,
		"SMS_GetMarioGravity": 0x80152c10,
		"Player::SMS_GetMarioGrLevel": 0x80152c1c,
		"SMS_GetMarioGrLevel": 0x80152c1c,
		"Player::SMS_GetMarioDamageRadius": 0x80152c28,
		"SMS_GetMarioDamageRadius": 0x80152c28,
		"Player::SMS_GetMarioHP": 0x80152c34,
		"SMS_GetMarioHP": 0x80152c34,
		"Player::SMS_IsMarioHeadSlideAttack": 0x80152c40,
		"SMS_IsMarioHeadSlideAttack": 0x80152c40,
		"Player::SMS_IsMarioStatusElecDamage": 0x80152c6c,
		"SMS_IsMarioStatusElecDamage": 0x80152c6c,
		"Player::SMS_IsMarioStatusThrownDown": 0x80152c90,
		"SMS_IsMarioStatusThrownDown": 0x80152c90,
		"Player::SMS_IsMarioStatusHipDrop": 0x80152cb4,
		"SMS_IsMarioStatusHipDrop": 0x80152cb4,
		"Player::SMS_IsMarioStatusTypeSwimming": 0x80152cd8,
		"SMS_IsMarioStatusTypeSwimming": 0x80152cd8,
		"Player::SMS_IsMarioStatusTypeJumping": 0x80152cf8,
		"SMS_IsMarioStatusTypeJumping": 0x80152cf8,
		"Player::SMS_GetMarioLiveActor": 0x80152d18,
		"SMS_GetMarioLiveActor": 0x80152d18,
		"Player::SMS_GetMarioHitActor": 0x80152d20,
		"SMS_GetMarioHitActor": 0x80152d20,
		"Player::SMS_AskJumpIntoWaterEffectExist": 0x80152d28,
		"SMS_AskJumpIntoWaterEffectExist": 0x80152d28,
		"Player::SMS_GetYoshi": 0x80152d4c,
		"SMS_GetYoshi": 0x80152d4c,
		"Player::SMS_SetMarioAccessParams": 0x80152d58,
		"SMS_SetMarioAccessParams": 0x80152d58,
		"TMario::TSurfingParams::TSurfingParams": 0x80152e90,
		"TMario::TDirtyParams::TDirtyParams": 0x801532ec,
		"TMario::TGraffitoParams::TGraffitoParams": 0x80153770,
		"TMario::TWireParams::TWireParams": 0x80153b74,
		"TMario::TSwimParams::TSwimParams": 0x80153ea0,
		"TMario::TRunParams::TRunParams": 0x80154408,
		"TMario::TJumpParams::TJumpParams": 0x8015482c,
		"TMario::TDeParams::TDeParams": 0x80155084,
		"TMario::setGamePad": 0x80155a0c,
		"setGamePad": 0x80155a0c,
		"TMario::resetHistory": 0x80155a14,
		"resetHistory": 0x80155a14,
		"TMario::initValues": 0x80155ad0,
		"TMario::loadAfter": 0x80155ef0,
		"TMario::load": 0x80155fe4,
		"TMario::TMario": 0x801560c8,
		"Player::__sinit_MarioInit_cpp": 0x8015af38,
		"__sinit_MarioInit_cpp": 0x8015af38,
		"TModelWaterManager::~TModelWaterManager": 0x8015b258,
		"TModelWaterManager::perform": 0x8015b2cc,
		"TModelWaterManager::drawRefracAndSpec": 0x8015b548,
		"drawRefracAndSpec": 0x8015b548,
		"TModelWaterManager::drawShineShadowVolume": 0x8015ba98,
		"drawShineShadowVolume": 0x8015ba98,
		"TModelWaterManager::drawMirror": 0x8015c048,
		"drawMirror": 0x8015c048,
		"TModelWaterManager::drawWaterVolume": 0x8015c834,
		"drawWaterVolume": 0x8015c834,
		"TModelWaterManager::drawSilhouette": 0x8015d11c,
		"drawSilhouette": 0x8015d11c,
		"TModelWaterManager::drawTouching": 0x8015d508,
		"drawTouching": 0x8015d508,
		"TModelWaterManager::calcVMAll": 0x8015d638,
		"calcVMAll": 0x8015d638,
		"TModelWaterManager::calcVMMtxWall": 0x8015d7c0,
		"calcVMMtxWall": 0x8015d7c0,
		"TModelWaterManager::calcVMMtxGround": 0x8015d8d4,
		"calcVMMtxGround": 0x8015d8d4,
		"TModelWaterManager::calcDrawVtx": 0x8015da10,
		"calcDrawVtx": 0x8015da10,
		"TModelWaterManager::calcWorldMinMax": 0x8015dcfc,
		"calcWorldMinMax": 0x8015dcfc,
		"TModelWaterManager::move": 0x8015de64,
		"TBGCheckData::isWaterSlip": 0x8015eeb8,
		"isWaterSlip": 0x8015eeb8,
		"TModelWaterManager::garbageCollect": 0x8015eeec,
		"garbageCollect": 0x8015eeec,
		"TModelWaterManager::wind": 0x8015f004,
		"wind": 0x8015f004,
		"TModelWaterManager::askDoWaterHitCheck": 0x8015f078,
		"askDoWaterHitCheck": 0x8015f078,
		"TModelWaterManager::emitRequest": 0x8015f0a0,
		"emitRequest": 0x8015f0a0,
		"TModelWaterManager::makeEmit": 0x8015f144,
		"makeEmit": 0x8015f144,
		"TModelWaterManager::askHitWaterParticleOnGround": 0x8015f410,
		"askHitWaterParticleOnGround": 0x8015f410,
		"TModelWaterManager::loadAfter": 0x8015f4a4,
		"TModelWaterManager::load": 0x8015f5a0,
		"TWaterEmitInfo::TWaterEmitInfo": 0x8015fb10,
		"Player::__sinit_ModelWaterManager_cpp": 0x8015fef8,
		"__sinit_ModelWaterManager_cpp": 0x8015fef8,
		"TMarioPositionObj::~TMarioPositionObj": 0x801602c4,
		"TMarioPositionObj::perform": 0x80160338,
		"TMarioPositionObj::load": 0x8016033c,
		"TMario::checkCollision": 0x80160480,
		"checkCollision": 0x80160480,
		"TMario::hangPole": 0x801617e4,
		"hangPole": 0x801617e4,
		"TMario::hitNormal": 0x80161a78,
		"hitNormal": 0x80161a78,
		"Player::__sinit_MarioCheckCol_cpp": 0x80161c88,
		"__sinit_MarioCheckCol_cpp": 0x80161c88,
		"TMario::receiveMessage": 0x80161f84,
		"TMario::getGesso": 0x80164248,
		"getGesso": 0x80164248,
		"Player::__sinit_MarioReceiveMsg_cpp": 0x8016436c,
		"__sinit_MarioReceiveMsg_cpp": 0x8016436c,
		"TMarioSoundValues::TMarioSoundValues": 0x80164668,
		"TMario::startSoundActor": 0x801646bc,
		"TMario::stopVoice": 0x80164720,
		"stopVoice": 0x80164720,
		"TMario::startVoiceIfNoVoice": 0x80164768,
		"startVoiceIfNoVoice": 0x80164768,
		"TMario::startVoice": 0x8016480c,
		"startVoice": 0x8016480c,
		"TMario::getVoiceStatus": 0x80164888,
		"getVoiceStatus": 0x80164888,
		"TMario::soundTorocco": 0x801648f4,
		"soundTorocco": 0x801648f4,
		"TMario::animSound": 0x801649e8,
		"animSound": 0x801649e8,
		"TMario::soundMovement": 0x80164ccc,
		"soundMovement": 0x80164ccc,
		"Player::__sinit_MarioSound_cpp": 0x80166850,
		"__sinit_MarioSound_cpp": 0x80166850,
		"TBaseNPC::monteMESetAnmWhenNear": 0x80166b4c,
		"monteMESetAnmWhenNear": 0x80166b4c,
		"TBaseNPC::monteMESetAnmWhenFar": 0x80166d70,
		"monteMESetAnmWhenFar": 0x80166d70,
		"TBaseNPC::sunflowerReviving": 0x80166f90,
		"sunflowerReviving": 0x80166f90,
		"TBaseNPC::sunflowerReviveIn": 0x8016705c,
		"sunflowerReviveIn": 0x8016705c,
		"TBaseNPC::sunflowerDownIn_": 0x80167138,
		"sunflowerDownIn_": 0x80167138,
		"TBaseNPC::peachTiredIn_": 0x80167174,
		"peachTiredIn_": 0x80167174,
		"TBaseNPC::peachParasolOut_": 0x80167230,
		"peachParasolOut_": 0x80167230,
		"TBaseNPC::peachParasolIn_": 0x80167260,
		"peachParasolIn_": 0x80167260,
		"TBaseNPC::npcMareStanding": 0x80167290,
		"npcMareStanding": 0x80167290,
		"TBaseNPC::npcMareStandIn": 0x801673ec,
		"npcMareStandIn": 0x801673ec,
		"TBaseNPC::npcBlowning": 0x80167540,
		"npcBlowning": 0x80167540,
		"TBaseNPC::npcBlownIn": 0x8016756c,
		"npcBlownIn": 0x8016756c,
		"TBaseNPC::npcMadding": 0x80167648,
		"npcMadding": 0x80167648,
		"TBaseNPC::npcMadIn": 0x80167910,
		"npcMadIn": 0x80167910,
		"TBaseNPC::npcThrowing": 0x80167a1c,
		"npcThrowing": 0x80167a1c,
		"TBaseNPC::npcThrowIn": 0x80167acc,
		"npcThrowIn": 0x80167acc,
		"TBaseNPC::npcSinking": 0x80167ba0,
		"npcSinking": 0x80167ba0,
		"TBaseNPC::npcWetting": 0x80167ce4,
		"npcWetting": 0x80167ce4,
		"TBaseNPC::npcWetIn": 0x8016894c,
		"npcWetIn": 0x8016894c,
		"TBaseNPC::npcHappyIn": 0x80168c44,
		"npcHappyIn": 0x80168c44,
		"TBaseNPC::npcDanceIn": 0x80168d28,
		"npcDanceIn": 0x80168d28,
		"TBaseNPC::npcTakenIn": 0x80168e08,
		"npcTakenIn": 0x80168e08,
		"TBaseNPC::npcTalkOut": 0x80168edc,
		"npcTalkOut": 0x80168edc,
		"TBaseNPC::npcTalking": 0x801690a8,
		"npcTalking": 0x801690a8,
		"TBaseNPC::npcTalkIn": 0x80169248,
		"npcTalkIn": 0x80169248,
		"TBaseNPC::npcStepIn": 0x801693dc,
		"npcStepIn": 0x801693dc,
		"TBaseNPC::npcRecoverAfterIn": 0x801694b0,
		"npcRecoverAfterIn": 0x801694b0,
		"TBaseNPC::npcRecoverFromSinking": 0x80169584,
		"npcRecoverFromSinking": 0x80169584,
		"TBaseNPC::npcFallIn": 0x80169764,
		"npcFallIn": 0x80169764,
		"TBaseNPC::npcWaitIn": 0x80169838,
		"npcWaitIn": 0x80169838,
		"TBaseNPC::getNpcWaitAnmBase_": 0x80169a10,
		"getNpcWaitAnmBase_": 0x80169a10,
		"TBaseNPC::walkAnmRateChange_": 0x80169a78,
		"walkAnmRateChange_": 0x80169a78,
		"TBaseNPC::randomizeBckAndBtpFrame_": 0x80169ea4,
		"randomizeBckAndBtpFrame_": 0x80169ea4,
		"TBaseNPC::requestTalkAnm_": 0x80169ffc,
		"requestTalkAnm_": 0x80169ffc,
		"TBaseNPC::setKeepAnm_": 0x8016a0c8,
		"setKeepAnm_": 0x8016a0c8,
		"TBaseNPC::requestNpcAnm_": 0x8016a120,
		"requestNpcAnm_": 0x8016a120,
		"TBaseNPC::setNpcAnm_": 0x8016a1c0,
		"setNpcAnm_": 0x8016a1c0,
		"NPC::CLBLinearInbetween": 0x8016a634,
		"NPC::CLBChaseConstantSpecifyFrame": 0x8016a668,
		"NPC::CLBPalFrame": 0x8016a714,
		"NPC::__sinit_NpcAnm_cpp": 0x8016a7a0,
		"__sinit_NpcAnm_cpp": 0x8016a7a0,
		"TBaseNPC::getPtrInitPollutionColor": 0x8016abc8,
		"getPtrInitPollutionColor": 0x8016abc8,
		"TBaseNPC::setBalloonMessage": 0x8016ad00,
		"setBalloonMessage": 0x8016ad00,
		"TBaseNPC::setDummyConnectActor": 0x8016ad24,
		"setDummyConnectActor": 0x8016ad24,
		"TBaseNPC::perform": 0x8016ad74,
		"TBaseNPC::getAnmOffDist_": 0x8016b55c,
		"getAnmOffDist_": 0x8016b55c,
		"TBaseNPC::updateForbidCount_": 0x8016b660,
		"updateForbidCount_": 0x8016b660,
		"TBaseNPC::calcRootMatrix": 0x8016b6a0,
		"TBaseNPC::execMotionBlend_": 0x8016b7c8,
		"execMotionBlend_": 0x8016b7c8,
		"TBaseNPC::moveObject": 0x8016b85c,
		"TBaseNPC::receiveMessage": 0x8016bcc0,
		"TBaseNPC::getFocalPoint": 0x8016bedc,
		"TBaseNPC::getCursorPos": 0x8016bf10,
		"getCursorPos": 0x8016bf10,
		"TBaseNPC::isInMadSearchRange": 0x8016bf44,
		"isInMadSearchRange": 0x8016bf44,
		"TBaseNPC::isInBodyTurnSearchRange": 0x8016bfb0,
		"isInBodyTurnSearchRange": 0x8016bfb0,
		"TBaseNPC::isNeedNeckStraight": 0x8016c01c,
		"isNeedNeckStraight": 0x8016c01c,
		"TBaseNPC::isPartsAnmNpc": 0x8016c16c,
		"isPartsAnmNpc": 0x8016c16c,
		"TBaseNPC::isBehaveToWaterNpc": 0x8016c1e8,
		"isBehaveToWaterNpc": 0x8016c1e8,
		"TBaseNPC::isMadNpc": 0x8016c220,
		"isMadNpc": 0x8016c220,
		"TBaseNPC::isBeTrampledNpc": 0x8016c2f4,
		"isBeTrampledNpc": 0x8016c2f4,
		"TBaseNPC::isPollutionNpc": 0x8016c49c,
		"isPollutionNpc": 0x8016c49c,
		"TBaseNPC::isSmallNpc": 0x8016c4d4,
		"isSmallNpc": 0x8016c4d4,
		"TBaseNPC::isChild": 0x8016c60c,
		"isChild": 0x8016c60c,
		"TBaseNPC::isSunflower": 0x8016c644,
		"isSunflower": 0x8016c644,
		"TBaseNPC::isJellyFishMare": 0x8016c670,
		"isJellyFishMare": 0x8016c670,
		"TBaseNPC::isSpecialMareW": 0x8016c6a0,
		"isSpecialMareW": 0x8016c6a0,
		"TBaseNPC::isSpecialMareM": 0x8016c6cc,
		"isSpecialMareM": 0x8016c6cc,
		"TBaseNPC::isNormalMareW": 0x8016c6f8,
		"isNormalMareW": 0x8016c6f8,
		"TBaseNPC::isNormalMareM": 0x8016c718,
		"isNormalMareM": 0x8016c718,
		"TBaseNPC::isSpecialMonteW": 0x8016c738,
		"isSpecialMonteW": 0x8016c738,
		"TBaseNPC::isSpecialMonteM": 0x8016c758,
		"isSpecialMonteM": 0x8016c758,
		"TBaseNPC::isNormalMonteW": 0x8016c784,
		"isNormalMonteW": 0x8016c784,
		"TBaseNPC::isNormalMonteM": 0x8016c7b0,
		"isNormalMonteM": 0x8016c7b0,
		"TBaseNPC::loadAfter": 0x8016c7dc,
		"TBaseNPC::load": 0x8016c864,
		"TBaseNPC::TBaseNPC": 0x8016c940,
		"NPC::CLBSquared": 0x8016cc44,
		"NPC::__sinit_NpcBase_cpp": 0x8016cc80,
		"__sinit_NpcBase_cpp": 0x8016cc80,
		"NPC::NPCNeckCallBack": 0x8016cf84,
		"NPCNeckCallBack": 0x8016cf84,
		"NPC::CLBEaseOutInbetween": 0x8016d3ac,
		"NPC::CLBTwoDegreeGeneralInbetween": 0x8016d3f4,
		"NPC::CLBPalIntSpeed": 0x8016d534,
		"CLBPalIntSpeed": 0x8016d534,
		"TSunflowerSManager::~TSunflowerSManager": 0x8016d588,
		"TSunflowerSManager::createModelData": 0x8016d5fc,
		"TSunflowerLManager::createModelData": 0x8016d630,
		"TRaccoonDogManager::createModelData": 0x8016d664,
		"TPeachManager::createModelData": 0x8016d698,
		"TKinojiiManager::createModelData": 0x8016d6cc,
		"TKinopioManager::createModelData": 0x8016d700,
		"TMareWBaseManager::createModelData": 0x8016d770,
		"TMareMBaseManager::createModelData": 0x8016d7dc,
		"TMonteWCManager::createModelData": 0x8016d848,
		"TMonteWBManager::createModelData": 0x8016d8b0,
		"TMonteWAManager::createModelData": 0x8016d91c,
		"TMonteWManager::createModelData": 0x8016d9c0,
		"TMonteMHManager::createModelData": 0x8016da64,
		"TMonteMGManager::createModelData": 0x8016dacc,
		"TMonteMFManager::createModelData": 0x8016db34,
		"TMonteMEManager::createModelData": 0x8016db9c,
		"TMonteMDManager::createModelData": 0x8016dbd0,
		"TMonteMCManager::createModelData": 0x8016dc3c,
		"TMonteMBManager::createModelData": 0x8016dce0,
		"TMonteMAManager::createModelData": 0x8016dd4c,
		"TMonteMManager::createModelData": 0x8016ddf0,
		"TSunflowerLManager::load": 0x8016de94,
		"TRaccoonDogManager::load": 0x8016ded0,
		"TPeachManager::load": 0x8016df44,
		"TKinojiiManager::load": 0x8016dfb8,
		"TKinopioManager::load": 0x8016e02c,
		"TMareWBManager::load": 0x8016e0a0,
		"TMareWAManager::load": 0x8016e114,
		"TMareMDManager::load": 0x8016e188,
		"TMareMCManager::load": 0x8016e1fc,
		"TMareMBManager::load": 0x8016e270,
		"TMareMAManager::load": 0x8016e2e4,
		"TMonteWCManager::load": 0x8016e358,
		"TMonteMHManager::load": 0x8016e3cc,
		"TMonteMGManager::load": 0x8016e440,
		"TMonteMFManager::load": 0x8016e4b4,
		"TMonteWSpecialManager::createAnmData": 0x8016e528,
		"TMonteMSpecialManager::createAnmData": 0x8016e548,
		"TMonteWBaseManager::createAnmData": 0x8016e568,
		"TMonteMBaseManager::createAnmData": 0x8016e5c4,
		"TMareBaseManager::getBmt_": 0x8016e620,
		"TMareWBaseManager::TMareWBaseManager": 0x8016e638,
		"TMareBaseManager::~TMareBaseManager": 0x8016e72c,
		"TMareMBaseManager::TMareMBaseManager": 0x8016e7a0,
		"TMonteWBaseManager::TMonteWBaseManager": 0x8016e894,
		"TMonteMBaseManager::TMonteMBaseManager": 0x8016e938,
		"TNPCManager::perform": 0x8016e9dc,
		"TNPCManager::clipEnemies": 0x8016eb48,
		"TNPCManager::getPartsSDLModelData": 0x8016ed08,
		"getPartsSDLModelData": 0x8016ed08,
		"TNPCManager::getBmt_": 0x8016ed7c,
		"TNPCManager::makePartsModelData_": 0x8016ed84,
		"makePartsModelData_": 0x8016ed84,
		"TNPCManager::load": 0x8016eed4,
		"TNPCManager::TNPCManager": 0x8016ef08,
		"TMareJellyFishManager::createModelData": 0x8016f028,
		"TMareJellyFishManager::perform": 0x8016f104,
		"TMareJellyFishManager::TMareJellyFishManager": 0x8016f108,
		"TBoardNpcManager::createModelData": 0x8016f148,
		"TBoardNpcManager::clipActors": 0x8016f17c,
		"TMonteWBManager::~TMonteWBManager": 0x8016f1a8,
		"TMonteWAManager::~TMonteWAManager": 0x8016f22c,
		"TMonteWManager::~TMonteWManager": 0x8016f2b0,
		"TMonteMEManager::~TMonteMEManager": 0x8016f334,
		"TMonteMDManager::~TMonteMDManager": 0x8016f3c8,
		"TMonteMCManager::~TMonteMCManager": 0x8016f44c,
		"TMonteMBManager::~TMonteMBManager": 0x8016f4d0,
		"TMonteMAManager::~TMonteMAManager": 0x8016f554,
		"TMonteMManager::~TMonteMManager": 0x8016f5d8,
		"TSunflowerLManager::~TSunflowerLManager": 0x8016f65c,
		"TRaccoonDogManager::~TRaccoonDogManager": 0x8016f6d0,
		"TPeachManager::~TPeachManager": 0x8016f744,
		"TKinojiiManager::~TKinojiiManager": 0x8016f7b8,
		"TKinopioManager::~TKinopioManager": 0x8016f82c,
		"TMareWBManager::~TMareWBManager": 0x8016f8a0,
		"TMareWAManager::~TMareWAManager": 0x8016f934,
		"TMareMDManager::~TMareMDManager": 0x8016f9c8,
		"TMareMCManager::~TMareMCManager": 0x8016fa5c,
		"TMareMBManager::~TMareMBManager": 0x8016faf0,
		"TMareMAManager::~TMareMAManager": 0x8016fb84,
		"TMonteWCManager::~TMonteWCManager": 0x8016fc18,
		"TMonteMHManager::~TMonteMHManager": 0x8016fcac,
		"TMonteMGManager::~TMonteMGManager": 0x8016fd40,
		"TMonteMFManager::~TMonteMFManager": 0x8016fdd4,
		"TMareJellyFishManager::~TMareJellyFishManager": 0x8016fe68,
		"TBoardNpcManager::~TBoardNpcManager": 0x8016feec,
		"TNerveNPCMareStand::~TNerveNPCMareStand": 0x8016ff80,
		"TNerveNPCMareStand::execute": 0x8016ffdc,
		"TNerveNPCMareStand::theNerve": 0x80170034,
		"TNerveNPCBlown::execute": 0x801700e4,
		"TNerveNPCBlown::theNerve": 0x801701f8,
		"TNerveNPCBlown::~TNerveNPCBlown": 0x8017025c,
		"TNerveNPCMad::execute": 0x801702b8,
		"TNerveNPCMad::theNerve": 0x80170310,
		"TNerveNPCMad::~TNerveNPCMad": 0x80170374,
		"TNerveNPCThrow::execute": 0x801703d0,
		"TNerveNPCThrow::theNerve": 0x80170428,
		"TNerveNPCThrow::~TNerveNPCThrow": 0x8017048c,
		"TNerveNPCTalk::execute": 0x801704e8,
		"TNerveNPCTalk::theNerve": 0x80170598,
		"TNerveNPCTalk::~TNerveNPCTalk": 0x801705fc,
		"TNerveNPCSetPosAfterSinkBottom::execute": 0x80170658,
		"TNerveNPCSetPosAfterSinkBottom::theNerve": 0x80170680,
		"TNerveNPCSetPosAfterSinkBottom::~TNerveNPCSetPosAfterSinkBottom": 0x801706e4,
		"TNerveNPCRecoverAfter::execute": 0x80170740,
		"TNerveNPCRecoverAfter::theNerve": 0x801707ac,
		"TNerveNPCRecoverAfter::~TNerveNPCRecoverAfter": 0x80170810,
		"TNerveNPCRecoverFromSink::execute": 0x8017086c,
		"TNerveNPCRecoverFromSink::theNerve": 0x80170928,
		"TNerveNPCRecoverFromSink::~TNerveNPCRecoverFromSink": 0x8017098c,
		"TNerveNPCSink::execute": 0x801709e8,
		"TNerveNPCSink::theNerve": 0x80170a10,
		"TNerveNPCSink::~TNerveNPCSink": 0x80170a74,
		"TNerveNPCWet::execute": 0x80170ad0,
		"TNerveNPCWet::theNerve": 0x80170b28,
		"TNerveNPCWet::~TNerveNPCWet": 0x80170b8c,
		"TNerveNPCTurnToMario::execute": 0x80170be8,
		"TNerveNPCWaitMarioApproach::~TNerveNPCWaitMarioApproach": 0x80170f50,
		"TNerveNPCTurnToMario::theNerve": 0x80170fac,
		"TNerveNPCTurnToMario::~TNerveNPCTurnToMario": 0x80171010,
		"TNerveNPCWaitMarioApproach::execute": 0x8017106c,
		"TNerveNPCWaitMarioApproach::theNerve": 0x80171230,
		"TNerveNPCWaitContinue::execute": 0x80171294,
		"TNerveNPCWaitContinue::theNerve": 0x801712dc,
		"TNerveNPCWaitContinue::~TNerveNPCWaitContinue": 0x80171340,
		"TNerveNPCGraphWait::execute": 0x8017139c,
		"TNerveNPCGraphWander::~TNerveNPCGraphWander": 0x8017151c,
		"TNerveNPCGraphWait::theNerve": 0x80171578,
		"TNerveNPCGraphWait::~TNerveNPCGraphWait": 0x801715dc,
		"TNerveNPCUTurn::execute": 0x80171638,
		"TNerveNPCUTurn::theNerve": 0x80171714,
		"TNerveNPCUTurn::~TNerveNPCUTurn": 0x80171778,
		"TNerveNPCGraphWander::execute": 0x801717d4,
		"TGraphTracer::getCurGraphIndex": 0x80171b90,
		"getCurGraphIndex": 0x80171b90,
		"TNerveNPCGraphWander::theNerve": 0x80171c50,
		"TNpcParams::TNpcParams": 0x80171cb4,
		"TNpcSaveIndividual::TNpcSaveIndividual": 0x80171dd4,
		"TNpcSaveNormal::TNpcSaveNormal": 0x80172608,
		"TNpcSaveStageFarClip::TNpcSaveStageFarClip": 0x80172c04,
		"TNpcEvent::reviveOneSunflower": 0x80172eb8,
		"reviveOneSunflower": 0x80172eb8,
		"NPC::ReviveSunflowerCallBack": 0x8017300c,
		"ReviveSunflowerCallBack": 0x8017300c,
		"TNpcEvent::initDownSunflowerNum": 0x80173094,
		"initDownSunflowerNum": 0x80173094,
		"TNpcEvent::initNpcBuiltin": 0x801730dc,
		"initNpcBuiltin": 0x801730dc,
		"NPC::evCheckMonteClear": 0x8017328c,
		"evCheckMonteClear": 0x8017328c,
		"NPC::evIsDemoMode": 0x8017343c,
		"evIsDemoMode": 0x8017343c,
		"NPC::evFireStartDemoCamera": 0x801734fc,
		"evFireStartDemoCamera": 0x801734fc,
		"NPC::evSetFruitType": 0x8017364c,
		"evSetFruitType": 0x8017364c,
		"NPC::evGetFruitNum": 0x8017392c,
		"evGetFruitNum": 0x8017392c,
		"NPC::evResetFruitNum": 0x80173b60,
		"evResetFruitNum": 0x80173b60,
		"NPC::evNpcDanceOffHappyOn": 0x80173c9c,
		"evNpcDanceOffHappyOn": 0x80173c9c,
		"NPC::evNpcDanceOn": 0x80173de8,
		"evNpcDanceOn": 0x80173de8,
		"NPC::evSetNpcTalkForbidCount": 0x80173f24,
		"evSetNpcTalkForbidCount": 0x80173f24,
		"NPC::evSetNpcBalloonMessage": 0x80174110,
		"evSetNpcBalloonMessage": 0x80174110,
		"NPC::evOnTalkToDummyNpc": 0x801743b4,
		"evOnTalkToDummyNpc": 0x801743b4,
		"NPC::evConnectDummyNpc": 0x801744ac,
		"evConnectDummyNpc": 0x801744ac,
		"NPC::ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x8017466c,
		"ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x8017466c,
		"NPC::ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x80174850,
		"ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x80174850,
		"NPC::evIsGameModeNormal": 0x80174a64,
		"evIsGameModeNormal": 0x80174a64,
		"NPC::evIsNpcSinkBottom": 0x80174b0c,
		"evIsNpcSinkBottom": 0x80174b0c,
		"NPC::evCheckLatestNerve4Npc": 0x80174c14,
		"evCheckLatestNerve4Npc": 0x80174c14,
		"NPC::evCheckCurNerve4Npc": 0x80174e04,
		"evCheckCurNerve4Npc": 0x80174e04,
		"NPC::evGetAddressFromViewObjName": 0x80174fd4,
		"evGetAddressFromViewObjName": 0x80174fd4,
		"NPC::__sinit_NpcEvent_cpp": 0x80175128,
		"__sinit_NpcEvent_cpp": 0x80175128,
		"NPC::SMSGetNpcInitData": 0x80175424,
		"SMSGetNpcInitData": 0x80175424,
		"NPC::__sinit_NpcInitData_cpp": 0x8017543c,
		"__sinit_NpcInitData_cpp": 0x8017543c,
		"TBaseNPC::setIndividualDifference_": 0x80175458,
		"setIndividualDifference_": 0x80175458,
		"TBaseNPC::init": 0x80175d3c,
		"TNpcInbetween::execMotionBlend": 0x80176450,
		"execMotionBlend": 0x80176450,
		"TNpcInbetween::execPosInbetween": 0x8017662c,
		"execPosInbetween": 0x8017662c,
		"TNpcParts::partsPerform": 0x80176708,
		"partsPerform": 0x80176708,
		"TNpcParts::partsFrameUpdate": 0x80176934,
		"partsFrameUpdate": 0x80176934,
		"TNpcParts::getPartsMActor": 0x8017699c,
		"getPartsMActor": 0x8017699c,
		"TNpcParts::setPartsAnmFrame": 0x801769c0,
		"setPartsAnmFrame": 0x801769c0,
		"TNpcParts::addJellyFishParts": 0x80176b44,
		"addJellyFishParts": 0x80176b44,
		"TNpcParts::TNpcParts": 0x80176cbc,
		"NPC::SMS_InitChangeNpcColor": 0x801770ec,
		"SMS_InitChangeNpcColor": 0x801770ec,
		"TBaseNPC::getBasNameTable": 0x8017731c,
		"TBaseNPC::kill": 0x801774a4,
		"TBaseNPC::setPosAndInitAfterSinkBottom": 0x801774a8,
		"setPosAndInitAfterSinkBottom": 0x801774a8,
		"TBaseNPC::changeNerveProc_": 0x801778a4,
		"changeNerveProc_": 0x801778a4,
		"TBaseNPC::isNowCanTaken": 0x80177f14,
		"isNowCanTaken": 0x80177f14,
		"TBaseNPC::isStateGoToMad_": 0x80178044,
		"isStateGoToMad_": 0x80178044,
		"TBaseNPC::behaveToSandBomb_": 0x801780b8,
		"behaveToSandBomb_": 0x801780b8,
		"TBaseNPC::behaveToHitObject_": 0x801782d4,
		"behaveToHitObject_": 0x801782d4,
		"TBaseNPC::behaveToBeTrampled_": 0x80178744,
		"behaveToBeTrampled_": 0x80178744,
		"TBaseNPC::behaveToBeTaken_": 0x80178c4c,
		"behaveToBeTaken_": 0x80178c4c,
		"TBaseNPC::releaseTaken_": 0x80178d38,
		"releaseTaken_": 0x80178d38,
		"TBaseNPC::changeNerveToMad_": 0x80178e2c,
		"changeNerveToMad_": 0x80178e2c,
		"TBaseNPC::changeNerveFromTalk_": 0x80178ef0,
		"changeNerveFromTalk_": 0x80178ef0,
		"TBaseNPC::isNerveCanGoToMad": 0x801790d8,
		"isNerveCanGoToMad": 0x801790d8,
		"TBaseNPC::isNerveCanGoToTalk": 0x8017917c,
		"isNerveCanGoToTalk": 0x8017917c,
		"TBaseNPC::isNerveMaybeDontCalcAnim1": 0x801792ac,
		"isNerveMaybeDontCalcAnim1": 0x801792ac,
		"TBaseNPC::isNerveMaybeDontCalcAnim0": 0x80179320,
		"isNerveMaybeDontCalcAnim0": 0x80179320,
		"TBaseNPC::isNerveMaybeDontMovement": 0x80179388,
		"isNerveMaybeDontMovement": 0x80179388,
		"TBaseNPC::isNerveWalk": 0x801793fc,
		"isNerveWalk": 0x801793fc,
		"NPC::__sinit_NpcChange_cpp": 0x80179470,
		"__sinit_NpcChange_cpp": 0x80179470,
		"TNpcThrow::throwMario": 0x8017976c,
		"TNpcTrample::updateTrample": 0x801798b0,
		"updateTrample": 0x801798b0,
		"TNpcTrample::startTrample": 0x801799a4,
		"startTrample": 0x801799a4,
		"TBaseNPC::emitParticle_": 0x80179a04,
		"TBaseNPC::isPolWaitCEffectEmitTime_": 0x8017a124,
		"isPolWaitCEffectEmitTime_": 0x8017a124,
		"TBaseNPC::emitHappyEffect_": 0x8017a274,
		"emitHappyEffect_": 0x8017a274,
		"TBaseNPC::emitSinkEffect_": 0x8017a3d8,
		"emitSinkEffect_": 0x8017a3d8,
		"TBaseNPC::getEffectScale_": 0x8017a430,
		"getEffectScale_": 0x8017a430,
		"NPC::IsCheckPassFrame": 0x8017a484,
		"IsCheckPassFrame": 0x8017a484,
		"TBaseNPC::setSmokeEffectMtxPtr_": 0x8017a510,
		"setSmokeEffectMtxPtr_": 0x8017a510,
		"TBaseNPC::setPollutionEffectMtxPtr_": 0x8017a59c,
		"setPollutionEffectMtxPtr_": 0x8017a59c,
		"TBaseNPC::setNoteEffectMtxPtr_": 0x8017a6f4,
		"setNoteEffectMtxPtr_": 0x8017a6f4,
		"TBaseNPC::setHappyEffectMtxPtr_": 0x8017a79c,
		"setHappyEffectMtxPtr_": 0x8017a79c,
		"NPC::SMSGetNpcInitAnmData": 0x8017aa20,
		"SMSGetNpcInitAnmData": 0x8017aa20,
		"TBaseNPC::setKinoActionFlag_": 0x8017aa34,
		"setKinoActionFlag_": 0x8017aa34,
		"TBaseNPC::setMareActionFlag_": 0x8017aa68,
		"setMareActionFlag_": 0x8017aa68,
		"TBaseNPC::setMonteActionFlag_": 0x8017aa9c,
		"setMonteActionFlag_": 0x8017aa9c,
		"TNpcCoin::updateCoin": 0x8017aad0,
		"updateCoin": 0x8017aad0,
		"TNpcCoin::requestAppearCoin": 0x8017ac6c,
		"requestAppearCoin": 0x8017ac6c,
		"TNpcCoin::TNpcCoin": 0x8017aee0,
		"NPC::__sinit_NpcCoin_cpp": 0x8017af58,
		"__sinit_NpcCoin_cpp": 0x8017af58,
		"TNpcBalloon::updateBalloon": 0x8017b254,
		"updateBalloon": 0x8017b254,
		"TNpcBalloon::setNextMessage": 0x8017b2c0,
		"setNextMessage": 0x8017b2c0,
		"TBaseNPC::isTurnToMarioWhenApproach": 0x8017b2cc,
		"isTurnToMarioWhenApproach": 0x8017b2cc,
		"TBaseNPC::isTurnToMarioWhenTalk": 0x8017b330,
		"isTurnToMarioWhenTalk": 0x8017b330,
		"TBaseNPC::isNeedTurnToFirstState": 0x8017b3a4,
		"isNeedTurnToFirstState": 0x8017b3a4,
		"TBaseNPC::execTurnToFirstState": 0x8017b48c,
		"execTurnToFirstState": 0x8017b48c,
		"TBaseNPC::execUTurn": 0x8017b570,
		"execUTurn": 0x8017b570,
		"TBaseNPC::execWalk": 0x8017b750,
		"TBaseNPC::bind": 0x8017bb40,
		"TBaseNPC::setVariableDamageRadius_": 0x8017bd58,
		"setVariableDamageRadius_": 0x8017bd58,
		"TBaseNPC::execNpcObjCollision_": 0x8017be34,
		"execNpcObjCollision_": 0x8017be34,
		"TBaseNPC::initNpcObjCollision_": 0x8017c160,
		"initNpcObjCollision_": 0x8017c160,
		"MAnmSoundNPC::startAnimSound": 0x8017c23c,
		"MAnmSound::setSpeedModifySound": 0x8017c494,
		"MAnmSound::startAnimSound": 0x8017c510,
		"MAnmSound::animeLoop": 0x8017c608,
		"animeLoop": 0x8017c608,
		"MAnmSound::initAnmSound": 0x8017c64c,
		"MAnmSound::MAnmSound": 0x8017c66c,
		"MSound::__sinit_MAnmSound_cpp": 0x8017c6b0,
		"__sinit_MAnmSound_cpp": 0x8017c6b0,
		"MSound::getMapInfoGround": 0x8017c9ac,
		"MSound::getSwitch": 0x8017c9b4,
		"getSwitch": 0x8017c9b4,
		"MSound::getBstSwitch": 0x8017ca14,
		"getBstSwitch": 0x8017ca14,
		"MSound::gateCheck": 0x8017ca50,
		"MSound::cameraLooksAtMario": 0x8017caa0,
		"cameraLooksAtMario": 0x8017caa0,
		"MSound::startSoundActorSpecial": 0x8017caf8,
		"startSoundActorSpecial": 0x8017caf8,
		"MSound::startBeeSe": 0x8017cc68,
		"startBeeSe": 0x8017cc68,
		"MSound::getWallSound": 0x8017ce18,
		"getWallSound": 0x8017ce18,
		"MSound::checkMarioVoicePlaying": 0x8017ce78,
		"checkMarioVoicePlaying": 0x8017ce78,
		"MSound::stopMarioVoice": 0x8017ce9c,
		"stopMarioVoice": 0x8017ce9c,
		"MSound::getMarioVoiceID": 0x8017cf0c,
		"getMarioVoiceID": 0x8017cf0c,
		"MSound::startMarioVoice": 0x8017cf44,
		"startMarioVoice": 0x8017cf44,
		"MSound::playTimer": 0x8017d610,
		"playTimer": 0x8017d610,
		"MSound::setSeExtParameter": 0x8017d6fc,
		"MSoundSESystem::MSRandVol::getRandomVolumeNormal": 0x8017d7e4,
		"getRandomVolumeNormal": 0x8017d7e4,
		"MSound::stopAllSound": 0x8017d838,
		"stopAllSound": 0x8017d838,
		"MSound::fadeOutAllSound": 0x8017d8c8,
		"fadeOutAllSound": 0x8017d8c8,
		"MSound::resetAudioAll": 0x8017d9e0,
		"resetAudioAll": 0x8017d9e0,
		"MSound::setCategoryVOLs": 0x8017dab4,
		"setCategoryVOLs": 0x8017dab4,
		"MSound::talkModeOut": 0x8017db70,
		"talkModeOut": 0x8017db70,
		"MSound::talkModeIn": 0x8017dcb8,
		"talkModeIn": 0x8017dcb8,
		"MSound::demoModeOut": 0x8017ddb4,
		"demoModeOut": 0x8017ddb4,
		"MSound::demoModeIn": 0x8017decc,
		"demoModeIn": 0x8017decc,
		"MSound::pauseOff": 0x8017dfa0,
		"pauseOff": 0x8017dfa0,
		"MSound::pauseOn": 0x8017e1c0,
		"pauseOn": 0x8017e1c0,
		"MSound::initSound": 0x8017e304,
		"initSound": 0x8017e304,
		"MSound::startSoundSetGrp": 0x8017e418,
		"MSound::startSoundSet": 0x8017e4a4,
		"MSound::mainLoop": 0x8017e530,
		"mainLoop": 0x8017e530,
		"MSound::MSound": 0x8017e618,
		"JAICamera::JAICamera": 0x8017e938,
		"MSound::getDistFromCamera": 0x8017e94c,
		"getDistFromCamera": 0x8017e94c,
		"MSound::setPlayerInfo": 0x8017e978,
		"setPlayerInfo": 0x8017e978,
		"MSound::setCameraInfo": 0x8017ea74,
		"MSound::checkWaveOnAram": 0x8017eac8,
		"checkWaveOnAram": 0x8017eac8,
		"MSound::exitStage": 0x8017ebec,
		"exitStage": 0x8017ebec,
		"MSound::enterStage": 0x8017ed2c,
		"enterStage": 0x8017ed2c,
		"MSound::loadWave": 0x8017ed88,
		"MSound::loadGroupWave": 0x8017edd8,
		"MSound::setRegisterTrackCallback": 0x8017ee9c,
		"MSound::makeSound": 0x8017eec4,
		"MSHandle::MSHandle": 0x8017ef58,
		"MSSeCallBack::setParameterSeqSync": 0x8017ef94,
		"MSSeCallBack::setWaterCameraFir": 0x8017f4b8,
		"setWaterCameraFir": 0x8017f4b8,
		"MSound::__sinit_MSound_cpp": 0x8017f770,
		"__sinit_MSound_cpp": 0x8017f770,
		"MSBgm::setStageBgmYoshiPercussion": 0x8017fa6c,
		"setStageBgmYoshiPercussion": 0x8017fa6c,
		"MSBgm::setDolby": 0x8017fb20,
		"MSBgm::setPan": 0x8017fb68,
		"MSBgm::setVolume": 0x8017fbb0,
		"MSBgm::setTrackVolume": 0x8017fc1c,
		"setTrackVolume": 0x8017fc1c,
		"MSBgm::stopTrackBGMs": 0x8017fc64,
		"stopTrackBGMs": 0x8017fc64,
		"MSBgm::stopTrackBGM": 0x8017fd10,
		"stopTrackBGM": 0x8017fd10,
		"MSBgm::stopBGM": 0x8017fd90,
		"stopBGM": 0x8017fd90,
		"MSBgm::getHandle": 0x8017fe70,
		"getHandle": 0x8017fe70,
		"MSBgm::startBGM": 0x8017fe9c,
		"startBGM": 0x8017fe9c,
		"MSBgm::getSceneNo": 0x8017ffe4,
		"getSceneNo": 0x8017ffe4,
		"MSBgm::init": 0x80180184,
		"JALList<MSBgm>::JALList": 0x8018020c,
		"JALList": 0x8018020c,
		"JALListS<MSBgm,unsigned_long><MSBgm,unsigned_long>::search": 0x80180268,
		"MSound::__sinit_MSoundBGM_cpp": 0x8018029c,
		"__sinit_MSoundBGM_cpp": 0x8018029c,
		"JADPrm<unsigned_char><unsigned_char>::JADPrm": 0x80180598,
		"MSound::__sinit_MSoundDebug_cpp": 0x801805a0,
		"__sinit_MSoundDebug_cpp": 0x801805a0,
		"MSSceneSE::sortMaxTrans": 0x8018089c,
		"sortMaxTrans": 0x8018089c,
		"MSSceneSE::frameLoop": 0x80180a70,
		"frameLoop": 0x80180a70,
		"MSSceneSE::MSSceneSE": 0x80180e88,
		"MSound::__sinit_MSoundScene_cpp": 0x80181004,
		"__sinit_MSoundScene_cpp": 0x80181004,
		"MSoundSESystem::MSoundSE::checkMonoSound": 0x80181300,
		"checkMonoSound": 0x80181300,
		"MSoundSESystem::MSoundSE::startSoundNpcActor": 0x801813d4,
		"startSoundNpcActor": 0x801813d4,
		"MSoundSESystem::MSoundSE::getNewIDBySurfaceCode": 0x801814e4,
		"getNewIDBySurfaceCode": 0x801814e4,
		"MSoundSESystem::MSoundSE::startSoundActorInner": 0x801815fc,
		"startSoundActorInner": 0x801815fc,
		"MSoundSESystem::MSoundSE::checkSoundArea": 0x801819bc,
		"checkSoundArea": 0x801819bc,
		"MSoundSESystem::MSoundSE::startSoundActorWithInfo": 0x80181b18,
		"startSoundActorWithInfo": 0x80181b18,
		"MSoundSESystem::MSoundSE::startSoundSystemSE": 0x80181d88,
		"MSoundSESystem::MSoundSE::startSoundActor": 0x80181ef8,
		"MSoundSESystem::MSoundSE::getRandomID": 0x80181f38,
		"getRandomID": 0x80181f38,
		"MSoundSESystem::MSoundSE::construct": 0x801821a4,
		"construct": 0x801821a4,
		"MSoundSESystem::MSRandPlay::randPlay": 0x8018347c,
		"randPlay": 0x8018347c,
		"MSoundSESystem::MSRandPlay::MSRandPlay": 0x80183640,
		"MSoundSESystem::MSRandPlay::startSeRandPlay": 0x801836e0,
		"startSeRandPlay": 0x801836e0,
		"MSoundSESystem::MSRandPlayVec::~MSRandPlayVec": 0x80183740,
		"MSoundSESystem::MSRandPlayVec::MSRandPlayVec": 0x801837a0,
		"MSoundSESystem::MSRandPlay::createRandPlayVec": 0x801837f8,
		"createRandPlayVec": 0x801837f8,
		"MSoundSESystem::MSRandPlay::registerTrans": 0x8018389c,
		"registerTrans": 0x8018389c,
		"MSoundSESystem::MSRandVol::getRandVol": 0x801838f0,
		"getRandVol": 0x801838f0,
		"MSoundSESystem::MSRandVol::MSRandVol": 0x8018396c,
		"MSound::__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x80183a14,
		"__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x80183a14,
		"MSSetSoundTL<MSSetSoundGrp>::MSSetSoundTL": 0x80183a84,
		"JALListFrameLoop<MSSetSoundGrp>::frameLoopDyna": 0x80183cdc,
		"MSound::__ct__9JADPrm<l>FlPCc": 0x80183ce0,
		"__ct__9JADPrm<l>FlPCc": 0x80183ce0,
		"MSound::__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x80183ce8,
		"__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x80183ce8,
		"MSound::__sinit_MSoundSE_cpp": 0x80183d3c,
		"__sinit_MSoundSE_cpp": 0x80183d3c,
		"JSUList<MSoundSESystem::MSRandPlay>::~JSUList": 0x80184094,
		"JSUList<MSoundSESystem::MSRandVol>::~JSUList": 0x801840ec,
		"MSSetSoundGrp::startSoundSetGrp": 0x8018414c,
		"MSSetSound::startSoundSet": 0x801841ec,
		"MSSetSound::init": 0x80184350,
		"JALListGrp<MSSetSoundGrp,unsigned_long,MSSetSoundMember><MSSetSoundGrp,unsigned_long,MSSetSoundMember>::searchGroup": 0x801848e0,
		"MSSetSoundTL<MSSetSound>::startSoundSetDyna": 0x8018493c,
		"JALListD<MSSetSoundMember,unsigned_long><MSSetSoundMember,unsigned_long>::searchD": 0x80185088,
		"searchD": 0x80185088,
		"MSSetSoundTL<MSSetSound>::MSSetSoundTL": 0x801850b4,
		"MSSetSoundTL<MSSetSoundGrp>::startSoundSetDyna": 0x8018530c,
		"JALListFrameLoop<MSSetSound>::frameLoopDyna": 0x80185a58,
		"MSound::__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x80185a5c,
		"__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x80185a5c,
		"MSound::__sinit_MSoundStruct_cpp": 0x80185ab0,
		"__sinit_MSoundStruct_cpp": 0x80185ab0,
		"MSHandle::calcVolume": 0x80185db4,
		"calcVolume": 0x80185db4,
		"MSHandle::setDistanceVolumeCommon": 0x80185e94,
		"MSHandle::setSeDistanceVolume": 0x80185f38,
		"MSHandle::calcDolby": 0x80186030,
		"calcDolby": 0x80186030,
		"MSHandle::setSeDistanceDolby": 0x80186120,
		"MSHandle::calcPan": 0x80186174,
		"MSHandle::setSeDistancePan": 0x80186294,
		"MSHandle::setSeDistancePitch": 0x80186334,
		"MSHandle::setSeDistanceParameters": 0x80186448,
		"MSHandle::MSACos": 0x80186598,
		"MSACos": 0x80186598,
		"MSound::__sinit_MSHandle_cpp": 0x801865f4,
		"__sinit_MSHandle_cpp": 0x801865f4,
		"MSBgmXFade::xFadeBgmForce": 0x801868f0,
		"xFadeBgmForce": 0x801868f0,
		"MSBgmXFade::xFadeBgm": 0x801869cc,
		"xFadeBgm": 0x801869cc,
		"MSModBgm::changeTempo": 0x80186adc,
		"changeTempo": 0x80186adc,
		"MSModBgm::loop": 0x80186b64,
		"loop": 0x80186b64,
		"MSModBgm::modBgm": 0x80186ba0,
		"modBgm": 0x80186ba0,
		"MSound::__sinit_MSModBgm_cpp": 0x80186c9c,
		"__sinit_MSModBgm_cpp": 0x80186c9c,
		"TWoodBarrel::getFlushTime": 0x80187034,
		"TMapObjGeneral::getLivingTime": 0x8018703c,
		"TMapObjGeneral::checkIllegalAttr": 0x80187044,
		"TWoodBarrel::TWoodBarrel": 0x80187048,
		"TWoodBarrel::load": 0x80187094,
		"TWoodBarrel::loadAfter": 0x801870ec,
		"TWoodBarrel::control": 0x80187154,
		"TWoodBarrel::receiveMessage": 0x801871f8,
		"TWoodBarrel::touchActor": 0x80187238,
		"TWoodBarrel::touchPlayer": 0x80187304,
		"TWoodBarrel::touchGround": 0x80187350,
		"TWoodBarrel::touchWall": 0x801873d4,
		"TWoodBarrel::appear": 0x80187400,
		"TWoodBarrel::appeared": 0x80187480,
		"TWoodBarrel::kill": 0x80187534,
		"TWoodBarrel::breaking": 0x801875dc,
		"TWoodBarrel::hold": 0x8018765c,
		"TWoodBarrel::put": 0x801876b4,
		"MoveBG::__sinit_WoodBarrel_cpp": 0x80187778,
		"__sinit_WoodBarrel_cpp": 0x80187778,
		"TMapObjBase::TMapObjBase": 0x80187a7c,
		"TMapObjBase::load": 0x80187b24,
		"TMapObjBase::loadAfter": 0x80187c08,
		"TMapObjBase::initAndRegister": 0x80187c48,
		"initAndRegister": 0x80187c48,
		"TMapObjBase::receiveMessage": 0x80187d18,
		"TMapObjBase::calcRootMatrix": 0x80187d74,
		"TMapObjBase::getRootJointMtx": 0x80187e20,
		"TMapObjBase::getShadowType": 0x80187e54,
		"TMapObjBase::perform": 0x80187f1c,
		"TMapObjBase::setGroundCollision": 0x80188348,
		"TMapObjBase::control": 0x801884d4,
		"TMapObjBase::ensureTakeSituation": 0x8018864c,
		"TMapObjBase::touchActor": 0x801886ac,
		"TMapObjBase::touchPlayer": 0x80188758,
		"TMapObjBase::touchEnemy": 0x80188794,
		"TMapObjBase::touchBoss": 0x801887d0,
		"touchBoss": 0x801887d0,
		"TMapObjBase::makeObjAppeared": 0x8018880c,
		"TMapObjBase::makeObjDead": 0x80188b40,
		"TMapObjBase::makeObjDefault": 0x80188d0c,
		"TMapObjBase::startAnim": 0x80188dec,
		"startAnim": 0x80188dec,
		"TMapObjBase::startBck": 0x80188fe0,
		"startBck": 0x80188fe0,
		"TMapObjBase::startControlAnim": 0x80189010,
		"startControlAnim": 0x80189010,
		"TMapObjBase::animIsFinished": 0x8018908c,
		"animIsFinished": 0x8018908c,
		"TMapObjBase::hasAnim": 0x8018910c,
		"hasAnim": 0x8018910c,
		"TMapObjBase::hasModelOrAnimData": 0x80189154,
		"hasModelOrAnimData": 0x80189154,
		"TMapObjBase::startSound": 0x801891a8,
		"startSound": 0x801891a8,
		"TMapObjBase::soundBas": 0x801892a0,
		"soundBas": 0x801892a0,
		"TMapObjBase::setUpMapCollision": 0x80189344,
		"setUpMapCollision": 0x80189344,
		"TMapObjBase::setUpCurrentMapCollision": 0x80189470,
		"setUpCurrentMapCollision": 0x80189470,
		"TMapObjBase::removeMapCollision": 0x80189548,
		"removeMapCollision": 0x80189548,
		"TMapObjBase::setObjHitData": 0x801895a4,
		"setObjHitData": 0x801895a4,
		"TMapObjBase::sleep": 0x80189650,
		"TMapObjBase::awake": 0x801896c4,
		"TMapObjBase::getSDLModelFlag": 0x80189708,
		"TMapObjBase::changeObjSRT": 0x80189710,
		"changeObjSRT": 0x80189710,
		"TMapObjBase::changeObjMtx": 0x80189780,
		"changeObjMtx": 0x80189780,
		"MoveBG::__sinit_MapObjBase_cpp": 0x80189878,
		"__sinit_MapObjBase_cpp": 0x80189878,
		"TMapObjGeneral::getFlushTime": 0x80189b7c,
		"TMapObjManager::initKeyCode": 0x80189b84,
		"initKeyCode": 0x80189b84,
		"TMapObjGeneral::initMapObj": 0x80189bf4,
		"TMapObjBase::initMapObj": 0x80189c3c,
		"TMapObjBase::initActorData": 0x80189ee8,
		"initActorData": 0x80189ee8,
		"TMapObjBase::initModelData": 0x8018a04c,
		"initModelData": 0x8018a04c,
		"TMapObjBase::makeMActors": 0x8018a17c,
		"TMapObjBase::initMActor": 0x8018a488,
		"initMActor": 0x8018a488,
		"TMapObjBase::initBckMoveData": 0x8018a534,
		"initBckMoveData": 0x8018a534,
		"TMapObjBase::initObjCollisionData": 0x8018a61c,
		"initObjCollisionData": 0x8018a61c,
		"TMapObjBase::initMapCollisionData": 0x8018a7a4,
		"TMapObjBase::checkIllegalAttr": 0x8018a860,
		"TMapObjBase::initUnique": 0x8018a864,
		"MoveBG::__sinit_MapObjInit_cpp": 0x8018b0a8,
		"__sinit_MapObjInit_cpp": 0x8018b0a8,
		"TMapObjGeneral::TMapObjGeneral": 0x8018b3ac,
		"TMapObjGeneral::loadAfter": 0x8018b408,
		"TMapObjGeneral::receiveMessage": 0x8018b474,
		"TMapObjGeneral::perform": 0x8018b77c,
		"TMapObjGeneral::calcRootMatrix": 0x8018b874,
		"TMapObjGeneral::control": 0x8018ba10,
		"TMapObjGeneral::bind": 0x8018bad0,
		"TMapObjGeneral::calcVelocity": 0x8018bd50,
		"TMapObjGeneral::checkGroundCollision": 0x8018bef4,
		"TMapObjGeneral::touchGround": 0x8018bfa4,
		"TMapObjGeneral::checkRoofCollision": 0x8018c17c,
		"checkRoofCollision": 0x8018c17c,
		"TMapObjGeneral::touchRoof": 0x8018c208,
		"TMapObjGeneral::checkWallCollision": 0x8018c214,
		"TMapObjGeneral::touchWall": 0x8018c2fc,
		"TMapObjGeneral::work": 0x8018c344,
		"work": 0x8018c344,
		"TMapObjGeneral::appear": 0x8018c434,
		"TMapObjGeneral::kill": 0x8018c52c,
		"TMapObjGeneral::ensureTakeSituation": 0x8018c5ac,
		"TMapObjGeneral::hold": 0x8018c618,
		"TMapObjGeneral::recover": 0x8018c68c,
		"recover": 0x8018c68c,
		"TMapObjGeneral::touchPlayer": 0x8018c794,
		"TMapObjGeneral::touchWater": 0x8018c7e8,
		"TMapObjGeneral::receiveMessageFromPlayer": 0x8018c864,
		"receiveMessageFromPlayer": 0x8018c864,
		"TMapObjGeneral::makeObjBuried": 0x8018c888,
		"makeObjBuried": 0x8018c888,
		"TMapObjGeneral::makeObjRecovered": 0x8018c8f4,
		"makeObjRecovered": 0x8018c8f4,
		"TMapObjGeneral::appeared": 0x8018c940,
		"TMapObjGeneral::appearing": 0x8018c998,
		"TMapObjGeneral::breaking": 0x8018ca5c,
		"TMapObjGeneral::sinking": 0x8018cadc,
		"sinking": 0x8018cadc,
		"TMapObjGeneral::recovering": 0x8018cbfc,
		"recovering": 0x8018cbfc,
		"TMapObjGeneral::holding": 0x8018cd10,
		"holding": 0x8018cd10,
		"TMapObjGeneral::touchingPlayer": 0x8018cd68,
		"touchingPlayer": 0x8018cd68,
		"TMapObjGeneral::touchingWater": 0x8018cdbc,
		"touchingWater": 0x8018cdbc,
		"TMapObjGeneral::thrown": 0x8018ce10,
		"TMapObjGeneral::put": 0x8018cff4,
		"TMapObjGeneral::sink": 0x8018d104,
		"sink": 0x8018d104,
		"TMapObjGeneral::waitToAppear": 0x8018d16c,
		"waitToAppear": 0x8018d16c,
		"TMapObjGeneral::waitingToRecover": 0x8018d190,
		"waitingToRecover": 0x8018d190,
		"TMapObjGeneral::waitingToAppear": 0x8018d1e8,
		"TMapObjGeneral::isPollutedGround": 0x8018d348,
		"isPollutedGround": 0x8018d348,
		"MoveBG::__sinit_MapObjGeneral_cpp": 0x8018d43c,
		"__sinit_MapObjGeneral_cpp": 0x8018d43c,
		"TMapObjBaseManager::~TMapObjBaseManager": 0x8018d738,
		"TMapObjBaseManager::TMapObjBaseManager": 0x8018d7cc,
		"TMapObjBaseManager::load": 0x8018d814,
		"TMapObjBaseManager::getObjNumWithActorType": 0x8018d86c,
		"getObjNumWithActorType": 0x8018d86c,
		"TMapObjBaseManager::createModelData": 0x8018d8c0,
		"TMapObjBaseManager::clipActors": 0x8018d8f4,
		"TMapObjBaseManager::getActorTypeByEventID": 0x8018d928,
		"getActorTypeByEventID": 0x8018d928,
		"TMapObjBaseManager::newAndRegisterObjByEventID": 0x8018da28,
		"newAndRegisterObjByEventID": 0x8018da28,
		"TMapObjBaseManager::newAndRegisterObj": 0x8018e09c,
		"newAndRegisterObj": 0x8018e09c,
		"MoveBG::newUniqueObjByName": 0x8018e1c8,
		"newUniqueObjByName": 0x8018e1c8,
		"MoveBG::newItemByName": 0x8018ee2c,
		"newItemByName": 0x8018ee2c,
		"TMapObjBaseManager::makeObjAppeared": 0x8018eec0,
		"TMapObjManager::TMapObjManager": 0x8018f208,
		"TMapObjManager::load": 0x8018f338,
		"TMapObjManager::loadAfter": 0x8018f7f8,
		"TMapObjManager::entryStaticDrawBufferSun": 0x8018f9d4,
		"entryStaticDrawBufferSun": 0x8018f9d4,
		"TMapObjManager::entryStaticDrawBufferShadow": 0x8018fa24,
		"entryStaticDrawBufferShadow": 0x8018fa24,
		"TMerryPole::getRootJointMtx": 0x8018faf8,
		"TMapObjManager::~TMapObjManager": 0x8018fb00,
		"TMapObjManager::hasMapCollision": 0x8018fb94,
		"MoveBG::__sinit_MapObjManager_cpp": 0x8018fb9c,
		"__sinit_MapObjManager_cpp": 0x8018fb9c,
		"TMapObjTurn::TMapObjTurn": 0x8018ff3c,
		"TMapObjTurn::initMapObj": 0x8018ffa4,
		"TMapObjTurn::loadAfter": 0x80190014,
		"TMapObjTurn::receiveMessage": 0x80190054,
		"TMapObjTurn::control": 0x801900f0,
		"TMapObjTurn::turn": 0x80190678,
		"turn": 0x80190678,
		"TMapObjTurn::touchWater": 0x8019076c,
		"TMapObjMessenger::TMapObjMessenger": 0x80190900,
		"TMapObjMessenger::receiveMessage": 0x8019094c,
		"TMapObjLibWave::TMapObjLibWave": 0x8019097c,
		"TMapObjLibWave::movement": 0x80190a24,
		"TMapObjLibWave::getCurrentHeight": 0x80190a7c,
		"getCurrentHeight": 0x80190a7c,
		"TMapObjLibWave::push": 0x80190ab4,
		"TMapObjBase::emitAndBindScale": 0x80190b58,
		"emitAndBindScale": 0x80190b58,
		"TMapObjBase::emitAndRotateScale": 0x80190c4c,
		"emitAndRotateScale": 0x80190c4c,
		"TMapObjBase::emitAndSRT": 0x80190d3c,
		"emitAndSRT": 0x80190d3c,
		"TMapObjBase::emitColumnWater": 0x80190e1c,
		"emitColumnWater": 0x80190e1c,
		"TMapObjBase::marioHipAttack": 0x80190e70,
		"marioHipAttack": 0x80190e70,
		"TMapObjBase::marioHeadAttack": 0x80190ee0,
		"marioHeadAttack": 0x80190ee0,
		"TMapObjBase::sendMsg": 0x80190fe4,
		"sendMsg": 0x80190fe4,
		"TMapObjBase::waterHitPlane": 0x80191074,
		"waterHitPlane": 0x80191074,
		"TMapObjBase::getWaterPos": 0x80191100,
		"getWaterPos": 0x80191100,
		"TMapObjBase::getWaterSpeed": 0x80191118,
		"getWaterSpeed": 0x80191118,
		"TMapObjBase::getWaterPlane": 0x80191130,
		"getWaterPlane": 0x80191130,
		"TMapObjBase::getWaterID": 0x80191148,
		"getWaterID": 0x80191148,
		"TMapObjBase::getDistance": 0x80191150,
		"getDistance": 0x80191150,
		"TMapObjBase::getDistanceXZ": 0x801911cc,
		"getDistanceXZ": 0x801911cc,
		"TMapObjBase::getRotYFromAxisZ": 0x80191230,
		"getRotYFromAxisZ": 0x80191230,
		"TMapObjBase::getRotYFromAxisX": 0x8019126c,
		"getRotYFromAxisX": 0x8019126c,
		"TMapObjBase::makeVecToLocalZ": 0x801912a8,
		"makeVecToLocalZ": 0x801912a8,
		"TMapObjBase::getNormalVecFromTarget": 0x80191314,
		"getNormalVecFromTarget": 0x80191314,
		"TMapObjBase::getNormalVecFromTargetXZ": 0x80191358,
		"getNormalVecFromTargetXZ": 0x80191358,
		"TMapObjBase::rotateVecByAxisY": 0x8019139c,
		"rotateVecByAxisY": 0x8019139c,
		"TMapObjBase::getVerticalVecToTargetXZ": 0x801915b8,
		"getVerticalVecToTargetXZ": 0x801915b8,
		"JGeometry::SMatrix33C<float><float>::at": 0x80191724,
		"at": 0x80191724,
		"JGeometry::SMatrix33C<float><float>::SMatrix33C": 0x80191738,
		"SMatrix33C": 0x80191738,
		"TMapObjBase::calcReflectingVelocity": 0x8019173c,
		"calcReflectingVelocity": 0x8019173c,
		"TMapObjBase::makeObjMtxRotByAxis": 0x801917a8,
		"makeObjMtxRotByAxis": 0x801917a8,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setRotate": 0x8019193c,
		"TMapObjBase::makeMtxRotByAxis": 0x80191a90,
		"makeMtxRotByAxis": 0x80191a90,
		"TMapObjBase::concatOnlyRotFromRight": 0x80191c34,
		"concatOnlyRotFromRight": 0x80191c34,
		"TMapObjBase::concatOnlyRotFromLeft": 0x80191ca0,
		"concatOnlyRotFromLeft": 0x80191ca0,
		"TMapObjBase::updateObjMtx": 0x80191d0c,
		"updateObjMtx": 0x80191d0c,
		"TMapObjBase::updateRootMtxTrans": 0x80191dc4,
		"updateRootMtxTrans": 0x80191dc4,
		"TMapObjBase::makeRootMtxRotX": 0x80191e14,
		"makeRootMtxRotX": 0x80191e14,
		"TMapObjBase::setRootMtxRotY": 0x80191ec4,
		"setRootMtxRotY": 0x80191ec4,
		"TMapObjBase::makeRootMtxRotY": 0x80191f78,
		"makeRootMtxRotY": 0x80191f78,
		"TMapObjBase::setRootMtxRotZ": 0x80192028,
		"setRootMtxRotZ": 0x80192028,
		"TMapObjBase::makeRootMtxRotZ": 0x801920dc,
		"makeRootMtxRotZ": 0x801920dc,
		"TMapObjBase::makeLowerStr": 0x8019218c,
		"makeLowerStr": 0x8019218c,
		"TMapObjBase::moveJoint": 0x801921e0,
		"moveJoint": 0x801921e0,
		"TMapObjBase::getJointTransX": 0x80192250,
		"getJointTransX": 0x80192250,
		"TMapObjBase::getJointTransZ": 0x80192258,
		"getJointTransZ": 0x80192258,
		"TMapObjBase::setJointTransX": 0x80192260,
		"setJointTransX": 0x80192260,
		"TMapObjBase::setJointTransY": 0x801922b0,
		"setJointTransY": 0x801922b0,
		"TMapObjBase::setJointTransZ": 0x80192300,
		"setJointTransZ": 0x80192300,
		"TMapObjBase::getJointScaleY": 0x80192350,
		"getJointScaleY": 0x80192350,
		"TMapObjBase::setJointScaleY": 0x80192358,
		"setJointScaleY": 0x80192358,
		"TMapObjBase::calcMap": 0x801923a8,
		"calcMap": 0x801923a8,
		"TMapObjBase::getBuildingJointObj": 0x801923e8,
		"getBuildingJointObj": 0x801923e8,
		"TMapObjBase::getBuildingJoint": 0x80192410,
		"getBuildingJoint": 0x80192410,
		"TMapObjBase::newAndInitBuildingCollisionMove": 0x8019243c,
		"newAndInitBuildingCollisionMove": 0x8019243c,
		"TMapObjBase::newAndInitBuildingCollisionWarp": 0x801924d0,
		"newAndInitBuildingCollisionWarp": 0x801924d0,
		"TMapObjBase::joinToGroup": 0x80192564,
		"joinToGroup": 0x80192564,
		"TMapObjBase::startAllAnim": 0x80192608,
		"startAllAnim": 0x80192608,
		"TMapObjBase::initPacketMatColor": 0x80192738,
		"initPacketMatColor": 0x80192738,
		"TMapObjBase::isFruit": 0x801927b4,
		"isFruit": 0x801927b4,
		"TMapObjBase::isCoin": 0x80192888,
		"isCoin": 0x80192888,
		"TMapObjBase::throwObjFromPointWithRot": 0x801928fc,
		"throwObjFromPointWithRot": 0x801928fc,
		"TMapObjBase::throwObjToFrontFromPoint": 0x801929c0,
		"throwObjToFrontFromPoint": 0x801929c0,
		"TMapObjBase::throwObjToFront": 0x80192ad4,
		"throwObjToFront": 0x80192ad4,
		"TMapObjBase::checkOnManhole": 0x80192bec,
		"checkOnManhole": 0x80192bec,
		"TMapObjBase::loadHideObjInfo": 0x80192c74,
		"loadHideObjInfo": 0x80192c74,
		"TMapObjBase::isDemo": 0x80192d50,
		"isDemo": 0x80192d50,
		"TMapObjBase::isHideObj": 0x80192da8,
		"isHideObj": 0x80192da8,
		"MoveBG::__sinit_MapObjLib_cpp": 0x80192f40,
		"__sinit_MapObjLib_cpp": 0x80192f40,
		"TNozzleBox::TNozzleBox": 0x801932e8,
		"TNozzleBox::load": 0x8019336c,
		"TNozzleBox::loadAfter": 0x80193584,
		"TNozzleBox::control": 0x8019375c,
		"TNozzleBox::touchPlayer": 0x801937b4,
		"TNozzleBox::receiveMessage": 0x80193884,
		"TNozzleBox::breaking": 0x801939f4,
		"TNozzleBox::makeModelValid": 0x80193a3c,
		"makeModelValid": 0x80193a3c,
		"TItemNozzle::load": 0x80193acc,
		"TItemNozzle::initMapObj": 0x80193b90,
		"TItemNozzle::control": 0x80193bd4,
		"TItemNozzle::appearing": 0x80193bf4,
		"TItemNozzle::receiveMessage": 0x80193c18,
		"TItemNozzle::put": 0x80193cdc,
		"TItemNozzle::touchPlayer": 0x80193cf4,
		"TEggYoshi::TEggYoshi": 0x80193e84,
		"TEggYoshi::load": 0x80193ed8,
		"TEggYoshi::receiveMessage": 0x80194114,
		"TEggYoshi::startFruit": 0x80194380,
		"startFruit": 0x80194380,
		"TEggYoshi::perform": 0x80194450,
		"TEggYoshi::control": 0x80194590,
		"TEggYoshi::touchActor": 0x801947ac,
		"TEggYoshi::touchFruit": 0x80194880,
		"TEggYoshi::decideRandomLoveFruit": 0x80194a04,
		"decideRandomLoveFruit": 0x80194a04,
		"TShine::TShine": 0x80194b3c,
		"TShine::loadBeforeInit": 0x80194c00,
		"TShine::loadAfter": 0x80194cf0,
		"TShine::initMapObj": 0x80194d58,
		"TShine::makeMActors": 0x80194dbc,
		"TShine::kill": 0x80194eb8,
		"TShine::appearWithDemo": 0x80194eec,
		"appearWithDemo": 0x80194eec,
		"TShine::appearSimple": 0x80194f98,
		"appearSimple": 0x80194f98,
		"TShine::appearWithTimeCallback": 0x80195094,
		"appearWithTimeCallback": 0x80195094,
		"TShine::appearWithTime": 0x801950fc,
		"appearWithTime": 0x801950fc,
		"TShine::touchPlayer": 0x80195304,
		"TShine::receiveMessage": 0x801953ac,
		"TShine::perform": 0x80195560,
		"TShine::control": 0x801955c0,
		"TShine::movingCircle": 0x80195b74,
		"movingCircle": 0x80195b74,
		"TShine::calc": 0x80195ce4,
		"TCoinBlue::TCoinBlue": 0x80195fc4,
		"TCoinBlue::load": 0x80196044,
		"TCoinBlue::loadBeforeInit": 0x801960b0,
		"TCoinBlue::taken": 0x80196104,
		"TCoinBlue::makeObjAppeared": 0x801961d0,
		"TCoinRed::TCoinRed": 0x80196238,
		"TCoinRed::taken": 0x801962c8,
		"TCoinEmpty::TCoinEmpty": 0x801963c8,
		"TCoinEmpty::kill": 0x80196448,
		"TCoinEmpty::makeObjAppeared": 0x8019644c,
		"TCoinEmpty::appear": 0x80196450,
		"TFlowerCoin::load": 0x80196454,
		"TCoin::TCoin": 0x801964a8,
		"TCoin::initMapObj": 0x80196514,
		"TCoin::loadAfter": 0x80196584,
		"TCoin::perform": 0x8019666c,
		"TCoin::makeObjAppeared": 0x801968cc,
		"TCoin::appear": 0x80196910,
		"TCoin::appearWithoutSound": 0x80196a48,
		"appearWithoutSound": 0x80196a48,
		"TCoin::makeObjDead": 0x80196ae4,
		"TCoin::taken": 0x80196b28,
		"TItem::TItem": 0x80196cb4,
		"TItem::load": 0x80196d08,
		"TItem::initMapObj": 0x80196d40,
		"TItem::perform": 0x80196d7c,
		"TItem::appear": 0x80196e08,
		"TItem::killByTimer": 0x80196e54,
		"TItem::appearing": 0x80196e88,
		"TItem::calc": 0x80196f6c,
		"TItem::calcRootMatrix": 0x80197088,
		"TItem::receiveMessage": 0x801970b4,
		"TItem::touchPlayer": 0x80197104,
		"TItem::taken": 0x80197180,
		"TItem::appeared": 0x8019720c,
		"TEggYoshi::getHitObjNumMax": 0x80197438,
		"MoveBG::__sinit_Item_cpp": 0x8019774c,
		"__sinit_Item_cpp": 0x8019774c,
		"TItemManager::~TItemManager": 0x80197a98,
		"TItemManager::hasMapCollision": 0x80197b2c,
		"TItemManager::TItemManager": 0x80197b34,
		"TItemManager::load": 0x80197bc0,
		"TItemManager::loadAfter": 0x80197c40,
		"TItemManager::newAndRegisterCoinReal": 0x80197d14,
		"newAndRegisterCoinReal": 0x80197d14,
		"TItemManager::perform": 0x80197d64,
		"TItemManager::newAndRegisterCoin": 0x80197e28,
		"newAndRegisterCoin": 0x80197e28,
		"TItemManager::makeShineAppearWithDemoOffset": 0x80197f10,
		"makeShineAppearWithDemoOffset": 0x80197f10,
		"TItemManager::makeShineAppearWithDemo": 0x80197fd0,
		"makeShineAppearWithDemo": 0x80197fd0,
		"TItemManager::makeShineAppearWithTime": 0x80198078,
		"makeShineAppearWithTime": 0x80198078,
		"TItemManager::resetNozzleBoxesModel": 0x80198128,
		"resetNozzleBoxesModel": 0x80198128,
		"MoveBG::__sinit_ItemManager_cpp": 0x80198238,
		"__sinit_ItemManager_cpp": 0x80198238,
		"TBasketReverse::initMapObj": 0x801985b8,
		"TBasketReverse::kill": 0x801985e8,
		"TRedCoinSwitch::TRedCoinSwitch": 0x801986a0,
		"TRedCoinSwitch::load": 0x80198700,
		"TRedCoinSwitch::loadAfter": 0x801987b4,
		"TRedCoinSwitch::control": 0x80198858,
		"TRedCoinSwitch::receiveMessage": 0x80198910,
		"TMapObjSwitch::TMapObjSwitch": 0x801989d0,
		"TMapObjSwitch::load": 0x80198a64,
		"TMapObjSwitch::receiveMessage": 0x80198b6c,
		"TMapObjSwitch::control": 0x80198c8c,
		"THideObjInfo::THideObjInfo": 0x80198ce4,
		"THideObjInfo::load": 0x80198df4,
		"THideObjInfo::action": 0x80198e70,
		"TMapObjWaterSpray::TMapObjWaterSpray": 0x80198f10,
		"TMapObjWaterSpray::load": 0x80198f8c,
		"TMapObjWaterSpray::calc": 0x80199148,
		"TDamageObj::load": 0x80199258,
		"TDamageObj::init": 0x80199374,
		"TDamageObj::perform": 0x801993e4,
		"TMapObjStartDemo::load": 0x8019943c,
		"TMapObjStartDemo::touchPlayer": 0x8019948c,
		"TMapObjChangeStageHipDrop::initMapObj": 0x801994bc,
		"TMapObjChangeStageHipDrop::touchPlayer": 0x80199518,
		"TMapObjChangeStage::load": 0x80199594,
		"TMapObjChangeStage::touchPlayer": 0x801995e4,
		"TMapObjBillboard::touchWater": 0x80199660,
		"TMapObjBillboard::touchActor": 0x8019986c,
		"TManhole::TManhole": 0x80199954,
		"TManhole::initMapObj": 0x801999c0,
		"TManhole::loadAfter": 0x80199a34,
		"TManhole::makeManholeUnuseful": 0x80199a74,
		"makeManholeUnuseful": 0x80199a74,
		"TManhole::setGroundCollision": 0x80199ad8,
		"TManhole::calc": 0x80199bc4,
		"TManhole::appeared": 0x80199c9c,
		"TManhole::animationFinished": 0x80199e5c,
		"animationFinished": 0x80199e5c,
		"TManhole::touchPlayer": 0x80199fe0,
		"TDoor::TDoor": 0x8019a2f4,
		"TDoor::load": 0x8019a340,
		"TDoor::touchPlayer": 0x8019a39c,
		"MoveBG::__sinit_MapObjTown_cpp": 0x8019a9e8,
		"__sinit_MapObjTown_cpp": 0x8019a9e8,
		"TSuperHipDropBlock::loadAfter": 0x8019ade0,
		"TSuperHipDropBlock::receiveMessage": 0x8019ae64,
		"TTelesaBlock::setGroundCollision": 0x8019af04,
		"TTelesaBlock::perform": 0x8019af58,
		"TTelesaBlock::initMapObj": 0x8019b0f4,
		"TJuiceBlock::kill": 0x8019b114,
		"TJuiceBlock::moveObject": 0x8019b148,
		"TJuiceBlock::initMapObj": 0x8019b1a0,
		"TBrickBlock::initMapObj": 0x8019b1f4,
		"TBrickBlock::receiveMessage": 0x8019b2bc,
		"TBrickBlock::kill": 0x8019b398,
		"TIceBlock::initMapObj": 0x8019b468,
		"TIceBlock::calc": 0x8019b4f8,
		"TIceBlock::control": 0x8019b55c,
		"TIceBlock::touchWater": 0x8019b73c,
		"TIceBlock::getSDLModelFlag": 0x8019b8c4,
		"TLeanBlock::TLeanBlock": 0x8019b8cc,
		"TLeanBlock::initMapObj": 0x8019b974,
		"TLeanBlock::calcDefaultMtx": 0x8019b9f4,
		"TLeanBlock::calcLeanMtx": 0x8019ba60,
		"calcLeanMtx": 0x8019ba60,
		"TLeanBlock::control": 0x8019bbb0,
		"TLeanBlock::touchPlayer": 0x8019bd1c,
		"TSandBlock::initMapObj": 0x8019bdc0,
		"TSandBlock::control": 0x8019be74,
		"TSandBlock::touchPlayer": 0x8019c0d0,
		"TBreakableBlock::touchPlayer": 0x8019c120,
		"MoveBG::__sinit_MapObjBlock_cpp": 0x8019c458,
		"__sinit_MapObjBlock_cpp": 0x8019c458,
		"TWoodLog::control": 0x8019c830,
		"TBellWatermill::TBellWatermill": 0x8019c928,
		"TBellWatermill::loadAfter": 0x8019c9a4,
		"TBellWatermill::control": 0x8019cad4,
		"TBellWatermill::touchWater": 0x8019d2b0,
		"TBiancoBell::TBiancoBell": 0x8019d318,
		"TBiancoBell::initMapObj": 0x8019d368,
		"TBiancoBell::touchPlayer": 0x8019d3fc,
		"TBiancoBell::touchWater": 0x8019d51c,
		"TLampSeesawMain::TLampSeesawMain": 0x8019d640,
		"TLampSeesawMain::loadAfter": 0x8019d74c,
		"TLampSeesawMain::control": 0x8019d810,
		"TLampSeesawMain::touchPlayer": 0x8019d9fc,
		"TLampSeesawMain::pushDown": 0x8019da48,
		"TLampSeesaw::TLampSeesaw": 0x8019da60,
		"TLampSeesaw::load": 0x8019dab4,
		"TLampSeesaw::touchPlayer": 0x8019db2c,
		"TLampSeesaw::pushDown": 0x8019db7c,
		"TLeafBoatRotten::TLeafBoatRotten": 0x8019db80,
		"TLeafBoatRotten::load": 0x8019dc64,
		"TLeafBoatRotten::perform": 0x8019dcd0,
		"TLeafBoatRotten::control": 0x8019dcf0,
		"TLeafBoat::TLeafBoat": 0x8019dfac,
		"TLeafBoat::initMapObj": 0x8019e044,
		"TLeafBoat::calc": 0x8019e08c,
		"TLeafBoat::control": 0x8019e164,
		"TLeafBoat::bind": 0x8019e328,
		"TLeafBoat::touchWall": 0x8019e570,
		"TLeafBoat::touchActor": 0x8019e6a8,
		"TBiancoMiniWindmill::TBiancoMiniWindmill": 0x8019e858,
		"TBiancoMiniWindmill::initMapObj": 0x8019e924,
		"TBiancoMiniWindmill::control": 0x8019ea40,
		"TBiancoMiniWindmill::calc": 0x8019eab0,
		"TBiancoMiniWindmill::touchWater": 0x8019ec28,
		"TBiancoWatermillVertical::TBiancoWatermillVertical": 0x8019ed44,
		"TBiancoWatermillVertical::load": 0x8019eda8,
		"TBiancoWatermillVertical::loadAfter": 0x8019ee08,
		"TBiancoWatermillVertical::control": 0x8019eecc,
		"TBiancoWatermillVertical::setGroundCollision": 0x8019f094,
		"TBiancoWatermillVertical::touchWater": 0x8019f108,
		"TBiancoWatermill::TBiancoWatermill": 0x8019f280,
		"TBiancoWatermill::initMapObj": 0x8019f2d4,
		"TBiancoWatermill::control": 0x8019f344,
		"TBiancoWatermill::touchWater": 0x8019f3c8,
		"TBiancoWatermill::turnByEnemy": 0x8019f3d0,
		"turnByEnemy": 0x8019f3d0,
		"TMapObjRootPakkun::initMapObj": 0x8019f3d4,
		"TMapObjRootPakkun::drawObject": 0x8019f434,
		"TBigWindmill::load": 0x8019f4c8,
		"TBigWindmill::control": 0x8019f5a8,
		"MoveBG::__sinit_MapObjBianco_cpp": 0x8019fc50,
		"__sinit_MapObjBianco_cpp": 0x8019fc50,
		"TWaterHitPictureHideObj::getObjAppearPos": 0x801a0048,
		"TPictureTelesa::control": 0x801a0050,
		"TPictureTelesa::touchActor": 0x801a009c,
		"TPictureTelesa::afterFinishedAnim": 0x801a0200,
		"TPanelRevolve::control": 0x801a02a8,
		"TPanelRevolve::touchPlayer": 0x801a0314,
		"TPanelRevolve::receiveMessage": 0x801a03b4,
		"TChestRevolve::control": 0x801a044c,
		"TChestRevolve::touchWater": 0x801a04b0,
		"TWarpAreaActor::TWarpAreaActor": 0x801a051c,
		"TWarpAreaActor::load": 0x801a056c,
		"TWarpAreaActor::perform": 0x801a0628,
		"TSirenaCasinoRoof::getSDLModelFlag": 0x801a06c4,
		"TSirenaCasinoRoof::perform": 0x801a06cc,
		"TSirenaCasinoRoof::initMapObj": 0x801a072c,
		"TSirenabossWall::getSDLModelFlag": 0x801a0800,
		"TSirenabossWall::drawObject": 0x801a0808,
		"TSirenabossWall::perform": 0x801a083c,
		"TSirenabossWall::initMapObj": 0x801a089c,
		"TSakuCasino::calcRootMatrix": 0x801a0960,
		"TSakuCasino::loadAfter": 0x801a0a94,
		"TSakuCasino::initMapObj": 0x801a0af8,
		"TSakuCasino::TSakuCasino": 0x801a0c08,
		"TCloset::touchWater": 0x801a0c64,
		"TCloset::calcRootMatrix": 0x801a0dc4,
		"TCloset::moveObject": 0x801a0ef0,
		"TCloset::initMapObj": 0x801a127c,
		"TCloset::TCloset": 0x801a1474,
		"TDonchou::touchWater": 0x801a1520,
		"TDonchou::calcRootMatrix": 0x801a154c,
		"TDonchou::loadAfter": 0x801a1750,
		"TDonchou::initMapObj": 0x801a1818,
		"TDonchou::TDonchou": 0x801a1930,
		"TCasinoPanelGate::touchWater": 0x801a198c,
		"TCasinoPanelGate::calcRootMatrix": 0x801a1c10,
		"TCasinoPanelGate::moveObject": 0x801a1cdc,
		"TCasinoPanelGate::initMapObj": 0x801a20f0,
		"TCasinoPanelGate::TCasinoPanelGate": 0x801a21f0,
		"TItemSlotDrum::getResultFromAng": 0x801a229c,
		"TItemSlotDrum::getForcastResult": 0x801a22e0,
		"TItemSlotDrum::generateItem": 0x801a2428,
		"TItemSlotDrum::touchWater": 0x801a2914,
		"TItemSlotDrum::calcRootMatrix": 0x801a2aa4,
		"TItemSlotDrum::moveObject": 0x801a2bd4,
		"TItemSlotDrum::loadAfter": 0x801a3140,
		"TItemSlotDrum::TItemSlotDrum": 0x801a31ec,
		"TSlotDrum::touchWater": 0x801a327c,
		"TSlotDrum::calcRootMatrix": 0x801a33a4,
		"TSlotDrum::moveObject": 0x801a3454,
		"TSlotDrum::initNeonMatColor": 0x801a3854,
		"TSlotDrum::initMapObj": 0x801a3914,
		"TSlotDrum::TSlotDrum": 0x801a3aa4,
		"TSirenaRollMapObj::TSirenaRollMapObj": 0x801a3b48,
		"MoveBG::partsRollCallback": 0x801a3bd4,
		"partsRollCallback": 0x801a3bd4,
		"TRoulette::switchStop": 0x801a3d34,
		"switchStop": 0x801a3d34,
		"TRoulette::setRollSp": 0x801a3e54,
		"setRollSp": 0x801a3e54,
		"TRoulette::calcRootMatrix": 0x801a3e78,
		"TRoulette::moveObject": 0x801a3f1c,
		"TRoulette::perform": 0x801a4010,
		"TRoulette::initMapObj": 0x801a4070,
		"TRoulette::TRoulette": 0x801a4234,
		"TRouletteSw::perform": 0x801a4308,
		"TRouletteSw::receiveMessage": 0x801a433c,
		"TCloset::getRollAngY": 0x801a4710,
		"TCasinoPanelGate::getRollAngX": 0x801a4840,
		"MoveBG::__sinit_MapObjSirena_cpp": 0x801a4980,
		"__sinit_MapObjSirena_cpp": 0x801a4980,
		"TFruitLauncher::loadAfter": 0x801a4d70,
		"TFruitLauncher::fireObj": 0x801a4fc4,
		"fireObj": 0x801a4fc4,
		"TLiveActor::getMActor": 0x801a5590,
		"TFruitSwitch::receiveMessage": 0x801a5598,
		"TSurfGesoObj::initMapObj": 0x801a5618,
		"TRiccoWatermill::TRiccoWatermill": 0x801a5728,
		"TRiccoWatermill::loadAfter": 0x801a5794,
		"TRiccoWatermill::calc": 0x801a5874,
		"TRiccoWatermill::control": 0x801a5894,
		"TRiccoWatermill::touchWater": 0x801a5c9c,
		"TCraneCargo::calc": 0x801a5d8c,
		"TCraneCargo::control": 0x801a5dd0,
		"TCraneUpDown::initMapObj": 0x801a5e00,
		"TCraneUpDown::control": 0x801a5f20,
		"TCraneRotY::load": 0x801a6224,
		"TCraneRotY::control": 0x801a62e0,
		"TCraneRotY::calc": 0x801a647c,
		"MoveBG::__sinit_MapObjRicco_cpp": 0x801a67e4,
		"__sinit_MapObjRicco_cpp": 0x801a67e4,
		"TSandEgg::getSDLModelFlag": 0x801a6bc4,
		"TMammaMirrorMapOperator::TMammaMirrorMapOperator": 0x801a6bcc,
		"TMammaMirrorMapOperator::loadAfter": 0x801a6d68,
		"TMammaMirrorMapOperator::perform": 0x801a7024,
		"TGoalWatermelon::TGoalWatermelon": 0x801a7274,
		"TGoalWatermelon::load": 0x801a72d4,
		"TGoalWatermelon::loadAfter": 0x801a734c,
		"TGoalWatermelon::control": 0x801a73fc,
		"TGoalWatermelon::touchActor": 0x801a747c,
		"TSandBird::TSandBird": 0x801a7580,
		"TSandBird::initMapObj": 0x801a7654,
		"TSandBird::nameIsObj": 0x801a76e4,
		"TSandBird::makeObjFromJointName": 0x801a7720,
		"TSandBird::control": 0x801a77ac,
		"TMammaYacht::initMapObj": 0x801a79f8,
		"TMammaYacht::control": 0x801a7acc,
		"TMammaBlockRotate::TMammaBlockRotate": 0x801a7b6c,
		"TMammaBlockRotate::load": 0x801a7bc4,
		"TMammaBlockRotate::initMapObj": 0x801a7c8c,
		"TMammaBlockRotate::control": 0x801a7e04,
		"TMammaBlockRotate::touchWater": 0x801a8064,
		"TShiningStone::TShiningStone": 0x801a80b4,
		"TShiningStone::load": 0x801a811c,
		"TShiningStone::perform": 0x801a836c,
		"TShiningStone::putOnLight": 0x801a8444,
		"putOnLight": 0x801a8444,
		"TLeanMirror::TLeanMirror": 0x801a86e4,
		"TLeanMirror::load": 0x801a87a4,
		"TLeanMirror::initMapObj": 0x801a88e0,
		"TLeanMirror::getSDLModelFlag": 0x801a89b8,
		"TLeanMirror::loadAfter": 0x801a89c0,
		"TLeanMirror::control": 0x801a8ae8,
		"TLeanMirror::controlShake": 0x801a8cf4,
		"controlShake": 0x801a8cf4,
		"TLeanMirror::controlGoTarget": 0x801a9028,
		"controlGoTarget": 0x801a9028,
		"MoveBG::startCameraShakeSE": 0x801a91e0,
		"startCameraShakeSE": 0x801a91e0,
		"TLeanMirror::release": 0x801a9248,
		"TLeanMirror::touchEnemy": 0x801a9498,
		"TLeanMirror::touchPlayer": 0x801a9578,
		"TLeanMirror::receiveMessage": 0x801a968c,
		"TLeanMirror::draw": 0x801a98a8,
		"TSandCastle::TSandCastle": 0x801a9a08,
		"TSandCastle::initMapObj": 0x801a9b40,
		"TSandCastle::loadAfter": 0x801a9b84,
		"TSandCastle::findTriggerActor": 0x801a9c38,
		"TSandCastle::calcRootMatrix": 0x801a9c98,
		"TSandCastle::waitBeforeExplode": 0x801a9cd8,
		"MoveBG::SandCastleCallBack": 0x801a9d58,
		"SandCastleCallBack": 0x801a9d58,
		"TSandCastle::explode": 0x801a9dec,
		"TSandCastle::expanded": 0x801a9f54,
		"TSandCastle::withering": 0x801aa048,
		"TSandBombBase::TSandBombBase": 0x801aa188,
		"TSandBombBase::initMapObj": 0x801aa208,
		"TSandBombBase::loadAfter": 0x801aa338,
		"TSandBombBase::findTriggerActor": 0x801aa390,
		"TSandBombBase::control": 0x801aa3d8,
		"TSandBombBase::grow": 0x801aa670,
		"TSandBombBase::waitBeforeExplode": 0x801aa67c,
		"TSandBombBase::explode": 0x801aa690,
		"TSandBombBase::exploding": 0x801aa7d0,
		"exploding": 0x801aa7d0,
		"TSandBombBase::expanded": 0x801aa954,
		"TSandBombBase::withered": 0x801aaa14,
		"withered": 0x801aaa14,
		"TSandBomb::initMapObj": 0x801aaa48,
		"TSandBomb::getSDLModelFlag": 0x801aaa68,
		"TSandBomb::touchWater": 0x801aaa70,
		"TSandBomb::makeObjAppeared": 0x801aabbc,
		"TSandLeafBase::initMapObj": 0x801aac00,
		"TSandLeafBase::control": 0x801aac94,
		"TSandLeafBase::grow": 0x801aae54,
		"TSandBase::TSandBase": 0x801aafe0,
		"TSandBase::withering": 0x801ab038,
		"TSandLeaf::control": 0x801ab0e4,
		"TSandLeaf::touchWater": 0x801ab13c,
		"TMammaMirrorMapOperator::~TMammaMirrorMapOperator": 0x801ab170,
		"TMapObjBall::getDepthAtFloating": 0x801ab268,
		"MoveBG::__sinit_MapObjMamma_cpp": 0x801ab6f0,
		"__sinit_MapObjMamma_cpp": 0x801ab6f0,
		"TPinnaCoaster::TPinnaCoaster": 0x801abad8,
		"TPinnaCoaster::initMapObj": 0x801abb34,
		"TPinnaCoaster::control": 0x801abc2c,
		"TAmiKing::touchPlayer": 0x801abdc4,
		"TAmiKing::bind": 0x801abde8,
		"TAmiKing::calcRootMatrix": 0x801abe40,
		"TAmiKing::moveObject": 0x801abfc4,
		"TAmiKing::initMapObj": 0x801ac32c,
		"TAmiKing::loadAfter": 0x801ac3b4,
		"TWaterRecoverObj::touchPlayer": 0x801ac410,
		"TPinnaEntrance::loadAfter": 0x801ac4a0,
		"TBalloonKoopaJr::load": 0x801ac508,
		"TBalloonKoopaJr::kill": 0x801ac628,
		"TBalloonKoopaJr::touchActor": 0x801ac6d4,
		"TChangeStageMerrygoround::calc": 0x801ac700,
		"TChangeStageMerrygoround::touchPlayer": 0x801ac764,
		"TMerrygoround::TMerrygoround": 0x801ac838,
		"TMerrygoround::initMapObj": 0x801ac934,
		"TMerrygoround::draw": 0x801acc20,
		"TMerrygoround::control": 0x801acc24,
		"TShellCup::TShellCup": 0x801acddc,
		"TPinnaShell::TPinnaShell": 0x801acedc,
		"TShellCup::initMapObj": 0x801acf84,
		"TShellCup::loadAfter": 0x801ad1d4,
		"TShellCup::perform": 0x801ad34c,
		"MoveBG::MsMtxSetRotX": 0x801ad498,
		"MsMtxSetRotX": 0x801ad498,
		"TShellCup::control": 0x801ad514,
		"TPinnaShell::control": 0x801ad578,
		"TPinnaShell::receiveMessage": 0x801ad928,
		"TViking::TViking": 0x801ad9d8,
		"TViking::initMapObj": 0x801adae0,
		"TViking::loadAfter": 0x801adba0,
		"TViking::reset": 0x801adbe0,
		"TViking::control": 0x801adc14,
		"TViking::roll": 0x801add78,
		"roll": 0x801add78,
		"THorizontalViking::initMapObj": 0x801ae11c,
		"THorizontalViking::reset": 0x801ae174,
		"THorizontalViking::control": 0x801ae1a8,
		"TFerrisWheel::TFerrisWheel": 0x801ae2cc,
		"TFerrisWheel::initMapObj": 0x801ae324,
		"TFerrisWheel::control": 0x801ae448,
		"TFerrisWheel::becomeCalmlyCallback": 0x801ae5e0,
		"becomeCalmlyCallback": 0x801ae5e0,
		"TAmiKing::touchWater": 0x801ae6e4,
		"MoveBG::__sinit_MapObjPinna_cpp": 0x801aeb70,
		"__sinit_MapObjPinna_cpp": 0x801aeb70,
		"TGateShadow::~TGateShadow": 0x801aeecc,
		"TGateShadow::perform": 0x801aef40,
		"MoveBG::__sinit_MapObjSample_cpp": 0x801aef44,
		"__sinit_MapObjSample_cpp": 0x801aef44,
		"TMareEventPoint::load": 0x801af2c4,
		"TMareEventPoint::receiveMessage": 0x801af318,
		"TMareCork::drawObject": 0x801af40c,
		"TMareCork::getTakingMtx": 0x801af4f0,
		"TMareCork::calcRootMatrix": 0x801af504,
		"TMareCork::moveObject": 0x801af5fc,
		"TMareCork::loadAfter": 0x801af670,
		"TMareFall::load": 0x801af7bc,
		"TMareFall::calc": 0x801af84c,
		"TMuddyBoat::TMuddyBoat": 0x801af90c,
		"TMuddyBoat::initMapObj": 0x801af9a8,
		"TMuddyBoat::getSDLModelFlag": 0x801afa78,
		"TMuddyBoat::calc": 0x801afa80,
		"TMuddyBoat::control": 0x801afc38,
		"TMuddyBoat::bind": 0x801afed0,
		"TMapObjBase::getObjCollisionHeightOffset": 0x801b0424,
		"getObjCollisionHeightOffset": 0x801b0424,
		"TMuddyBoat::kill": 0x801b042c,
		"TMuddyBoat::calcRootMatrix": 0x801b0514,
		"TMuddyBoat::moveByWater": 0x801b0518,
		"moveByWater": 0x801b0518,
		"TMapObjPuncher::load": 0x801b06c8,
		"TMapObjPuncher::control": 0x801b0748,
		"TMapObjPuncher::touchPlayer": 0x801b083c,
		"TWireBell::TWireBell": 0x801b09b0,
		"TWireBell::loadAfter": 0x801b0a2c,
		"TWireBell::control": 0x801b0a68,
		"TWireBell::draw": 0x801b0b08,
		"TWireBell::initDraw": 0x801b0c6c,
		"TMapObjGrowTree::TMapObjGrowTree": 0x801b0e78,
		"TMapObjGrowTree::initMapObj": 0x801b0ed8,
		"TMapObjGrowTree::loadAfter": 0x801b0f3c,
		"TMapObjGrowTree::control": 0x801b0f70,
		"TMapObjGrowTree::touchWater": 0x801b1244,
		"TMapObjElasticCode::initMapObj": 0x801b152c,
		"TMapObjElasticCode::control": 0x801b1578,
		"TMapObjElasticCode::draw": 0x801b1688,
		"TCogwheel::TCogwheel": 0x801b187c,
		"TCogwheel::initMapObj": 0x801b1908,
		"TCogwheel::control": 0x801b1b94,
		"TCogwheel::calc": 0x801b1d4c,
		"TCogwheel::draw": 0x801b1e10,
		"TCogwheel::initDraw": 0x801b209c,
		"TCogwheelScale::TCogwheelScale": 0x801b22a8,
		"TCogwheelScale::control": 0x801b2320,
		"TCogwheelScale::touchPlayer": 0x801b23d0,
		"TCogwheelScale::receiveMessage": 0x801b24d8,
		"TCogwheelScale::touchWater": 0x801b2524,
		"MoveBG::__sinit_MapObjMare_cpp": 0x801b29ec,
		"__sinit_MapObjMare_cpp": 0x801b29ec,
		"TMapObjFlagManager::~TMapObjFlagManager": 0x801b2d50,
		"TMapObjFlagManager::TMapObjFlagManager": 0x801b2dc4,
		"TMapObjFlagManager::TMapObjFlagInfo::TMapObjFlagInfo": 0x801b2e50,
		"TMapObjFlagManager::load": 0x801b2e60,
		"TMapObjFlagManager::registerObj": 0x801b2ef4,
		"registerObj": 0x801b2ef4,
		"TMapObjFlagManager::perform": 0x801b351c,
		"TMapObjFlagManager::initDraw": 0x801b371c,
		"TMapObjFlag::TMapObjFlag": 0x801b38e4,
		"TMapObjFlag::load": 0x801b39d8,
		"TMapObjFlag::init": 0x801b3a2c,
		"TMapObjFlag::updateVertex": 0x801b3d0c,
		"updateVertex": 0x801b3d0c,
		"TMapObjFlag::draw": 0x801b3e44,
		"MoveBG::__sinit_MapObjFlag_cpp": 0x801b4180,
		"__sinit_MapObjFlag_cpp": 0x801b4180,
		"TMapObjWave::~TMapObjWave": 0x801b4484,
		"TMapObjWave::TMapObjWave": 0x801b44f8,
		"TMapObjWave::load": 0x801b4700,
		"TMapObjWave::perform": 0x801b48d0,
		"TMapObjWave::updateTime": 0x801b4958,
		"updateTime": 0x801b4958,
		"TMapObjWave::updateHeightAndAlpha": 0x801b49fc,
		"updateHeightAndAlpha": 0x801b49fc,
		"TMapObjWave::draw": 0x801b4d14,
		"TMapObjWave::noWave": 0x801b5040,
		"noWave": 0x801b5040,
		"TMapObjWave::getHeight": 0x801b5060,
		"TMapObjWave::getWaveHeight": 0x801b518c,
		"getWaveHeight": 0x801b518c,
		"TMapObjWave::initDraw": 0x801b5218,
		"MoveBG::__sinit_MapObjWave_cpp": 0x801b5544,
		"__sinit_MapObjWave_cpp": 0x801b5544,
		"TMapObjFloatOnSea::TMapObjFloatOnSea": 0x801b5848,
		"TMapObjFloatOnSea::initMapObj": 0x801b58b0,
		"TMapObjFloatOnSea::calc": 0x801b59d0,
		"TMapObjFloatOnSea::control": 0x801b5a74,
		"TMapObjFloatOnSea::touchPlayer": 0x801b5af4,
		"MoveBG::__sinit_MapObjFloat_cpp": 0x801b5b38,
		"__sinit_MapObjFloat_cpp": 0x801b5b38,
		"TMapObjPlane::hasMapCollision": 0x801b5ec0,
		"TSandPlane::load": 0x801b5ec8,
		"TRockPlane::load": 0x801b5f44,
		"TMapObjPlane::TMapObjPlane": 0x801b5fc0,
		"TMapObjPlane::load": 0x801b6034,
		"TMapObjPlane::makeMountain": 0x801b61a0,
		"makeMountain": 0x801b61a0,
		"TMapObjPlane::perform": 0x801b62fc,
		"TMapObjPlane::receiveMessage": 0x801b6348,
		"TMapObjPlane::depress": 0x801b63a8,
		"depress": 0x801b63a8,
		"TMapObjPlane::calcNrm": 0x801b6658,
		"calcNrm": 0x801b6658,
		"TMapObjPlane::updateCheckData": 0x801b6b1c,
		"updateCheckData": 0x801b6b1c,
		"TMapObjPlane::draw": 0x801b6cec,
		"TMapObjPlane::initDraw": 0x801b6ec4,
		"MoveBG::__sinit_MapObjPlane_cpp": 0x801b71e0,
		"__sinit_MapObjPlane_cpp": 0x801b71e0,
		"TRideCloud::perform": 0x801b7590,
		"TRideCloud::control": 0x801b75c8,
		"TRideCloud::getShadowType": 0x801b78cc,
		"TRideCloud::load": 0x801b78d4,
		"TRideCloud::initMapObj": 0x801b7a20,
		"TRideCloud::calcRootMatrix": 0x801b7a54,
		"TRideCloud::setGroundCollision": 0x801b7b00,
		"TRideCloud::touchWater": 0x801b7b78,
		"TRideCloud::TRideCloud": 0x801b7ba0,
		"MoveBG::__sinit_MapObjCloud_cpp": 0x801b7cac,
		"__sinit_MapObjCloud_cpp": 0x801b7cac,
		"TBigWatermelon::TBigWatermelon": 0x801b804c,
		"TBigWatermelon::initMapObj": 0x801b8140,
		"TBigWatermelon::loadAfter": 0x801b8294,
		"TBigWatermelon::receiveMessage": 0x801b8310,
		"TBigWatermelon::checkWallCollision": 0x801b844c,
		"TBigWatermelon::startEvent": 0x801b846c,
		"TBigWatermelon::control": 0x801b868c,
		"TBigWatermelon::appearing": 0x801b891c,
		"TBigWatermelon::kill": 0x801b8a2c,
		"TBigWatermelon::touchActor": 0x801b8b8c,
		"TBigWatermelon::touchGround": 0x801b8e84,
		"TBigWatermelon::rebound": 0x801b8ea4,
		"TBigWatermelon::touchWall": 0x801b90a8,
		"TBigWatermelon::touchWaterSurface": 0x801b90c8,
		"TCoverFruit::loadAfter": 0x801b9138,
		"TCoverFruit::receiveMessage": 0x801b9190,
		"TCoverFruit::calcRootMatrix": 0x801b9230,
		"TRandomFruit::TRandomFruit": 0x801b9374,
		"TRandomFruit::initMapObj": 0x801b94a4,
		"TResetFruit::TResetFruit": 0x801b95e4,
		"TResetFruit::initMapObj": 0x801b964c,
		"TResetFruit::receiveMessage": 0x801b9690,
		"TResetFruit::getLivingTime": 0x801b9a6c,
		"TResetFruit::makeObjAppeared": 0x801b9a74,
		"TResetFruit::killByTimer": 0x801b9ba4,
		"TResetFruit::perform": 0x801b9bc0,
		"TResetFruit::control": 0x801b9da4,
		"TResetFruit::appearing": 0x801ba3d4,
		"TResetFruit::breaking": 0x801ba4d4,
		"TResetFruit::kicked": 0x801ba5f0,
		"TResetFruit::makeObjLiving": 0x801ba894,
		"makeObjLiving": 0x801ba894,
		"TResetFruit::touchGround": 0x801ba914,
		"TResetFruit::touchActor": 0x801baa3c,
		"TResetFruit::touchWater": 0x801bab70,
		"TResetFruit::touchWaterSurface": 0x801bacc0,
		"TResetFruit::touchPollution": 0x801badc4,
		"TResetFruit::hold": 0x801baef0,
		"TResetFruit::thrown": 0x801baff4,
		"TResetFruit::makeObjWaitingToAppear": 0x801bb028,
		"makeObjWaitingToAppear": 0x801bb028,
		"TResetFruit::waitingToAppear": 0x801bb0f4,
		"TResetFruit::checkGroundCollision": 0x801bb230,
		"TMapObjBall::TMapObjBall": 0x801bb3c8,
		"TMapObjBall::initMapObj": 0x801bb470,
		"TMapObjBall::receiveMessage": 0x801bb964,
		"TMapObjBall::control": 0x801bba5c,
		"TMapObjBall::makeObjAppeared": 0x801bbb6c,
		"TMapObjBall::makeObjDefault": 0x801bbc64,
		"TMapObjBall::checkWallCollision": 0x801bbcbc,
		"TMapObjBall::calcCurrentMtx": 0x801bbd98,
		"calcCurrentMtx": 0x801bbd98,
		"TMapObjBall::touchActor": 0x801bc1c8,
		"TMapObjBall::boundByActor": 0x801bc31c,
		"boundByActor": 0x801bc31c,
		"TMapObjBall::touchWater": 0x801bc870,
		"TMapObjBall::kicked": 0x801bc970,
		"TMapObjBall::hold": 0x801bcb8c,
		"TMapObjBall::put": 0x801bcc24,
		"TMapObjBall::touchGround": 0x801bcc64,
		"TMapObjBall::rebound": 0x801bcfbc,
		"TMapObjBall::touchWaterSurface": 0x801bd144,
		"TMapObjBall::touchPollution": 0x801bd170,
		"TMapObjBall::touchWall": 0x801bd19c,
		"TMapObjBall::touchRoof": 0x801bd500,
		"MoveBG::__sinit_MapObjBall_cpp": 0x801bd66c,
		"__sinit_MapObjBall_cpp": 0x801bd66c,
		"TAirportEventSink::~TAirportEventSink": 0x801bd990,
		"TAirportEventSink::TAirportEventSink": 0x801bdaa8,
		"TAirportEventSink::loadAfter": 0x801bdb0c,
		"TAirportEventSink::watch": 0x801bdba0,
		"TAirportEventSink::control": 0x801bdc48,
		"TAirportEventSink::finishControl": 0x801bdcbc,
		"TAirportSwitch::TAirportSwitch": 0x801bdd4c,
		"TAirportSwitch::loadAfter": 0x801bdd98,
		"TAirportSwitch::breaking": 0x801bde0c,
		"MoveBG::__sinit_MapObjAirport_cpp": 0x801bdf74,
		"__sinit_MapObjAirport_cpp": 0x801bdf74,
		"TTurboNozzleDoor::touchPlayer": 0x801be2fc,
		"TTurboNozzleDoor::loadAfter": 0x801be468,
		"TDemoCannon::perform": 0x801be5c4,
		"TDemoCannon::startDemo": 0x801be80c,
		"TDemoCannon::initMapObj": 0x801be89c,
		"TDemoCannon::loadAfter": 0x801be9f8,
		"TMareGate::loadAfter": 0x801beb4c,
		"TMareGate::control": 0x801beba4,
		"TMapObjSmoke::load": 0x801bec0c,
		"TMapObjSmoke::control": 0x801bec68,
		"TMapObjSmoke::touchWater": 0x801bec94,
		"TDptMonteFence::touchPlayer": 0x801bece8,
		"TBellDolpic::control": 0x801bed90,
		"TBellDolpic::receiveMessage": 0x801befa0,
		"TBellDolpic::touchPlayer": 0x801bf118,
		"TBellDolpic::ring": 0x801bf13c,
		"ring": 0x801bf13c,
		"TBellDolpic::calcRootMatrix": 0x801bf2d8,
		"TBellDolpic::initMapObj": 0x801bf340,
		"TBellDolpic::TBellDolpic": 0x801bf410,
		"TMonumentShine::control": 0x801bf498,
		"TMonumentShine::receiveMessage": 0x801bf734,
		"TMonumentShine::hitByWater": 0x801bf878,
		"hitByWater": 0x801bf878,
		"TMonumentShine::initMapObj": 0x801bfa04,
		"TMonumentShine::TMonumentShine": 0x801bfab4,
		"MoveBG::__sinit_MapObjDolpic_cpp": 0x801bfe4c,
		"__sinit_MapObjDolpic_cpp": 0x801bfe4c,
		"TMapObjRevivalPollution::~TMapObjRevivalPollution": 0x801c0180,
		"TMapObjRevivalPollution::TMapObjRevivalPollution": 0x801c01f4,
		"TMapObjRevivalPollution::load": 0x801c0264,
		"TMapObjRevivalPollution::loadAfter": 0x801c034c,
		"TMapObjRevivalPollution::perform": 0x801c03f8,
		"TRevivalPolluter::TRevivalPolluter": 0x801c0458,
		"TPolluterBase::TPolluterBase": 0x801c0480,
		"TPolluterBase::load": 0x801c04cc,
		"TPolluterBase::perform": 0x801c05ec,
		"MoveBG::__sinit_MapObjPollution_cpp": 0x801c06cc,
		"__sinit_MapObjPollution_cpp": 0x801c06cc,
		"TMapObjGrassManager::~TMapObjGrassManager": 0x801c09d0,
		"TMapObjGrassManager::TMapObjGrassManager": 0x801c0a44,
		"TMapObjGrassManager::load": 0x801c0b08,
		"TMapObjGrassManager::perform": 0x801c0b58,
		"TMapObjGrassManager::initDrawNear": 0x801c0d90,
		"initDrawNear": 0x801c0d90,
		"TMapObjGrassGroup::TMapObjGrassGroup": 0x801c0fdc,
		"TMapObjGrassGroup::load": 0x801c1040,
		"TMapObjGrassGroup::drawFar": 0x801c12c8,
		"drawFar": 0x801c12c8,
		"TMapObjGrassGroup::drawNear": 0x801c13f0,
		"drawNear": 0x801c13f0,
		"MoveBG::__sinit_MapObjGrass_cpp": 0x801c1598,
		"__sinit_MapObjGrass_cpp": 0x801c1598,
		"TMapObjPoleManager::~TMapObjPoleManager": 0x801c18ac,
		"TMapObjPoleManager::TMapObjPoleManager": 0x801c1920,
		"TMapObjPoleManager::TMapObjPoleInfo::TMapObjPoleInfo": 0x801c19ac,
		"TMapObjPoleManager::load": 0x801c19bc,
		"TMapObjPoleManager::perform": 0x801c19f8,
		"TMapObjPoleManager::initDraw": 0x801c1aa4,
		"TMapObjPole::draw": 0x801c1c74,
		"MoveBG::__sinit_MapObjPole_cpp": 0x801c1dcc,
		"__sinit_MapObjPole_cpp": 0x801c1dcc,
		"TMapObjWaterFilter::TMapObjWaterFilter": 0x801c2134,
		"TMapObjWaterFilter::init": 0x801c223c,
		"TMapObjWaterFilter::perform": 0x801c2288,
		"TMapObjSeaIndirect::TMapObjSeaIndirect": 0x801c241c,
		"TMapObjSeaIndirect::init": 0x801c2514,
		"TMapObjSeaIndirect::perform": 0x801c263c,
		"MoveBG::__sinit_MapObjWater_cpp": 0x801c26ac,
		"__sinit_MapObjWater_cpp": 0x801c26ac,
		"TModelGate::getTakingMtx": 0x801c2a54,
		"TModelGate::perform": 0x801c2a5c,
		"TModelGate::receiveMessage": 0x801c3504,
		"TModelGate::screenBlur": 0x801c36ac,
		"screenBlur": 0x801c36ac,
		"TModelGate::startOpen": 0x801c38fc,
		"startOpen": 0x801c38fc,
		"TModelGate::loadAfter": 0x801c3970,
		"MoveBG::__sinit_ModelGate_cpp": 0x801c41e8,
		"__sinit_ModelGate_cpp": 0x801c41e8,
		"TRailFence::TRailFence": 0x801c4588,
		"TRailFence::load": 0x801c4614,
		"TRailFence::initMapCollisionData": 0x801c46b4,
		"TRailFence::control": 0x801c46d4,
		"TRailFence::goOnRail": 0x801c4890,
		"goOnRail": 0x801c4890,
		"TRailFence::receiveMessage": 0x801c4aac,
		"TFenceWaterH::changeStatusToWait": 0x801c4b38,
		"TFenceWaterH::changeStatusToGo": 0x801c4b70,
		"TFenceWaterH::control": 0x801c4be0,
		"TFenceWater::initMapObj": 0x801c4ea8,
		"TFenceWater::initMapCollisionData": 0x801c5000,
		"TFenceWater::control": 0x801c5020,
		"TFenceWater::controlRotation": 0x801c5114,
		"controlRotation": 0x801c5114,
		"TFenceWater::changeStatusToWait": 0x801c5248,
		"TFenceWater::changeStatusToGo": 0x801c5260,
		"TFenceWater::receiveMessage": 0x801c52c4,
		"TFenceWater::draw": 0x801c533c,
		"TRevolvingFenceInner::initMapObj": 0x801c5340,
		"TRevolvingFenceInner::initMapCollisionData": 0x801c5424,
		"TRevolvingFenceInner::control": 0x801c54d4,
		"TRevolvingFenceInner::setGroundCollision": 0x801c5520,
		"TRevolvingFenceInner::controlGroundRoof": 0x801c5628,
		"controlGroundRoof": 0x801c5628,
		"TRevolvingFenceInner::controlWall": 0x801c572c,
		"controlWall": 0x801c572c,
		"MoveBG::MsMtxSetRotY": 0x801c59ec,
		"MsMtxSetRotY": 0x801c59ec,
		"TRevolvingFenceInner::receiveMessage": 0x801c5ab0,
		"TRevolvingFenceOuter::initMapCollisionData": 0x801c5d4c,
		"TRevolvingFenceOuter::receiveMessage": 0x801c5ecc,
		"TFence::initMapObj": 0x801c5f28,
		"TFence::initMapCollisionData": 0x801c5f74,
		"TFence::receiveMessage": 0x801c60ec,
		"MoveBG::__sinit_MapObjFence_cpp": 0x801c62fc,
		"__sinit_MapObjFence_cpp": 0x801c62fc,
		"TMapObjOptionWall::TMapObjOptionWall": 0x801c66ac,
		"TMapObjOptionWall::init": 0x801c66f8,
		"TMapObjOptionWall::offCollision": 0x801c6768,
		"offCollision": 0x801c6768,
		"TMapObjOptionWall::onCollision": 0x801c6798,
		"onCollision": 0x801c6798,
		"TFileLoadBlock::TFileLoadBlock": 0x801c67c8,
		"TFileLoadBlock::initMapObj": 0x801c682c,
		"TFileLoadBlock::loadAfter": 0x801c6914,
		"TFileLoadBlock::receiveMessage": 0x801c6a94,
		"TFileLoadBlock::touchPlayer": 0x801c6b88,
		"TFileLoadBlock::makeBlockRock": 0x801c6c78,
		"makeBlockRock": 0x801c6c78,
		"TFileLoadBlock::makeBlockNormal": 0x801c6cb0,
		"makeBlockNormal": 0x801c6cb0,
		"MoveBG::__sinit_MapObjOption_cpp": 0x801c6d6c,
		"__sinit_MapObjOption_cpp": 0x801c6d6c,
		"TWoodBlock::load": 0x801c7114,
		"TWoodBlock::calcRecycle": 0x801c7248,
		"TWoodBlock::TWoodBlock": 0x801c74a8,
		"TRollBlock::control": 0x801c75dc,
		"TRollBlock::calcRootMatrix": 0x801c7650,
		"TRollBlock::getRootJointMtx": 0x801c778c,
		"TRollBlock::setGroundCollision": 0x801c77b0,
		"TRollBlock::load": 0x801c7810,
		"TRollBlock::TRollBlock": 0x801c78b8,
		"TRailBlock::control": 0x801c7908,
		"TRailBlock::calcRootMatrix": 0x801c7eb4,
		"TRailBlock::getRootJointMtx": 0x801c7f4c,
		"TRailBlock::initMapObj": 0x801c7f70,
		"TRailBlock::TRailBlock": 0x801c7ff0,
		"TNormalLift::perform": 0x801c80ac,
		"TNormalLift::setGroundCollision": 0x801c8108,
		"TNormalLift::control": 0x801c81c4,
		"TNormalLift::initMapObj": 0x801c8378,
		"TNormalLift::readRailFlag": 0x801c83bc,
		"TNormalLift::load": 0x801c84b0,
		"TNormalLift::resetPosition": 0x801c85ec,
		"TNormalLift::TNormalLift": 0x801c86a4,
		"TRailMapObj::perform": 0x801c8744,
		"TRailMapObj::control": 0x801c877c,
		"TRailMapObj::readRailFlag": 0x801c8898,
		"TRailMapObj::getShadowType": 0x801c88f0,
		"TRailMapObj::setGroundCollision": 0x801c88f8,
		"TRailMapObj::load": 0x801c8994,
		"TRailMapObj::initMapObj": 0x801c8a70,
		"TRailMapObj::resetPosition": 0x801c8ab4,
		"TRailMapObj::calcRecycle": 0x801c8b60,
		"TRailMapObj::checkMarioRiding": 0x801c8cb4,
		"TRailMapObj::moveToNextNode": 0x801c8dac,
		"moveToNextNode": 0x801c8dac,
		"TRailMapObj::resetStep": 0x801c9064,
		"resetStep": 0x801c9064,
		"TRailMapObj::initGraphTracer": 0x801c90e4,
		"initGraphTracer": 0x801c90e4,
		"TRailMapObj::TRailMapObj": 0x801c9258,
		"TFluffManager::TFluffManager": 0x801c9494,
		"TFluffManager::load": 0x801c9510,
		"TFluffManager::loadAfter": 0x801c96a4,
		"TFluffManager::control": 0x801c9a68,
		"TFluff::TFluff": 0x801c9dd4,
		"TFluff::initMapObj": 0x801c9e60,
		"TFluff::appear": 0x801c9e9c,
		"TFluff::control": 0x801ca090,
		"TFluff::kill": 0x801ca3c0,
		"TFluff::move": 0x801ca41c,
		"TFluff::touchWater": 0x801ca624,
		"TGoalFlag::initMapObj": 0x801ca6b0,
		"TGoalFlag::touchActor": 0x801ca6d0,
		"TSwingBoard::TSwingBoard": 0x801ca7b4,
		"TSwingBoard::load": 0x801ca85c,
		"TSwingBoard::control": 0x801caa78,
		"TSwingBoard::draw": 0x801cad6c,
		"TSwingBoard::initDraw": 0x801cae80,
		"TSwingBoard::drawOneRope": 0x801cb08c,
		"THangingBridge::THangingBridge": 0x801cb228,
		"THangingBridge::loadAfter": 0x801cb2ac,
		"THangingBridge::perform": 0x801cb81c,
		"THangingBridge::initDraw": 0x801cb8fc,
		"THangingBridge::drawRopeBetweenBoards": 0x801cbb50,
		"drawRopeBetweenBoards": 0x801cbb50,
		"THangingBridge::drawUpper": 0x801cc28c,
		"THangingBridge::drawLowerPlus": 0x801cc470,
		"drawLowerPlus": 0x801cc470,
		"THangingBridge::drawLowerMinus": 0x801cc6ec,
		"drawLowerMinus": 0x801cc6ec,
		"THangingBridgeBoard::THangingBridgeBoard": 0x801cc960,
		"THangingBridgeBoard::initMapObj": 0x801cc9fc,
		"THangingBridgeBoard::setGroundCollision": 0x801cca40,
		"THangingBridgeBoard::calcDefaultMtx": 0x801ccb34,
		"THangingBridgeBoard::control": 0x801ccb9c,
		"THangingBridgeBoard::drawOneRope": 0x801cce14,
		"TJumpMushroom::load": 0x801ccf84,
		"TJumpMushroom::receiveMessage": 0x801ccfe8,
		"TMapObjMonteRoot::initMapObj": 0x801cd010,
		"TFluff::getRadiusAtY": 0x801cd0e8,
		"TGoalFlag::getRadiusAtY": 0x801cd174,
		"THangingBridge::~THangingBridge": 0x801cd200,
		"MoveBG::__sinit_MapObjMonte_cpp": 0x801cd418,
		"__sinit_MapObjMonte_cpp": 0x801cd418,
		"TMapObjTree::getRadiusAtY": 0x801cd7e8,
		"TMapObjTreeScale::TMapObjTreeScale": 0x801cd814,
		"TMapObjTreeScale::loadAfter": 0x801cda9c,
		"TMapObjTreeScale::control": 0x801cdbd8,
		"TMapObjTreeScale::touchWater": 0x801cdf94,
		"TMapObjTree::TMapObjTree": 0x801ce020,
		"TMapObjTree::initMapObj": 0x801ce098,
		"TMapObjTree::initEach": 0x801ce248,
		"initEach": 0x801ce248,
		"TMapObjTree::perform": 0x801ce3bc,
		"TMapObjTree::controlLeaf": 0x801ce458,
		"controlLeaf": 0x801ce458,
		"TMapObjTree::touchPlayer": 0x801ce614,
		"TMapObjLeaf::TMapObjLeaf": 0x801ce6d8,
		"MoveBG::__sinit_MapObjTree_cpp": 0x801ce770,
		"__sinit_MapObjTree_cpp": 0x801ce770,
		"MoveBG::__sinit_MapObjTumblePole_cpp": 0x801cea88,
		"__sinit_MapObjTumblePole_cpp": 0x801cea88,
		"TMapObjSteam::load": 0x801cee2c,
		"TMapObjSteam::control": 0x801cee88,
		"TJointCoin::TJointCoin": 0x801ceeb4,
		"TJointCoin::initMapObj": 0x801cef0c,
		"TJointCoin::nameIsObj": 0x801cf0d8,
		"TJointCoin::loadAfter": 0x801cf114,
		"TJointCoin::makeObjFromJointName": 0x801cf1f4,
		"TJointCoin::makeObj": 0x801cf318,
		"makeObj": 0x801cf318,
		"TJointCoin::control": 0x801cf4bc,
		"TMapObjNail::TMapObjNail": 0x801cf5d8,
		"TMapObjNail::receiveMessage": 0x801cf624,
		"MoveBG::__sinit_MapObjEx_cpp": 0x801cf804,
		"__sinit_MapObjEx_cpp": 0x801cf804,
		"TPoolManager::TPoolManager": 0x801cfb18,
		"TPoolManager::subWaterLevel": 0x801cfb58,
		"subWaterLevel": 0x801cfb58,
		"TPoolManager::getWaterLevel": 0x801cfc00,
		"getWaterLevel": 0x801cfc00,
		"TPool::TPool": 0x801cfc68,
		"TPool::load": 0x801cfce4,
		"TPool::makeObjAppeared": 0x801cfd28,
		"TPool::draw": 0x801cfd5c,
		"TPoolManager::~TPoolManager": 0x801cff5c,
		"MoveBG::__sinit_Pool_cpp": 0x801cfff0,
		"__sinit_Pool_cpp": 0x801cfff0,
		"TBathtub::getNumKillerBurstable": 0x801d0378,
		"getNumKillerBurstable": 0x801d0378,
		"TBathtub::isKillerAttackable": 0x801d0524,
		"isKillerAttackable": 0x801d0524,
		"TBathtub::getNumKillerLaunchable": 0x801d0540,
		"getNumKillerLaunchable": 0x801d0540,
		"TBathtub::TBathtub": 0x801d0684,
		"JGeometry::SMatrix33R<float><float>::SMatrix33R": 0x801d0774,
		"SMatrix33R": 0x801d0774,
		"TBathtub::load": 0x801d0778,
		"TBathtub::updatePosture_": 0x801d0c50,
		"updatePosture_": 0x801d0c50,
		"TBathtub::getNextGrip": 0x801d12b4,
		"getNextGrip": 0x801d12b4,
		"TBathtub::getNextJuncture": 0x801d1560,
		"getNextJuncture": 0x801d1560,
		"TBathtub::getNearGrip": 0x801d17a0,
		"getNearGrip": 0x801d17a0,
		"TBathtub::calcRootMatrix": 0x801d196c,
		"TBathtub::allowsTumble": 0x801d1aa0,
		"allowsTumble": 0x801d1aa0,
		"TBathtub::startDemo": 0x801d1d1c,
		"TBathtub::setupCollisions_": 0x801d1fbc,
		"setupCollisions_": 0x801d1fbc,
		"TBathtub::calcBathtubData": 0x801d2450,
		"calcBathtubData": 0x801d2450,
		"TBathtub::control": 0x801d2804,
		"TBathtub::perform": 0x801d2cb0,
		"TBathtub::getRootJointMtx": 0x801d2fd0,
		"TBathtub::receiveMessage": 0x801d300c,
		"TBathtub::getKoopaJrMtxInDemo": 0x801d30cc,
		"getKoopaJrMtxInDemo": 0x801d30cc,
		"TBathtub::getPeachMtxInDemo": 0x801d30e8,
		"getPeachMtxInDemo": 0x801d30e8,
		"TBathtub::getSubmarineMtxInDemo": 0x801d3104,
		"getSubmarineMtxInDemo": 0x801d3104,
		"TBathtub::getTakingMtx": 0x801d3120,
		"TBathtub::tumble": 0x801d313c,
		"tumble": 0x801d313c,
		"TBathtub::getNumGripsDead": 0x801d31c4,
		"getNumGripsDead": 0x801d31c4,
		"TBathtub::quake": 0x801d3248,
		"quake": 0x801d3248,
		"TBathtub::hipdrop": 0x801d3384,
		"hipdrop": 0x801d3384,
		"TBathtub::loadAfter": 0x801d3468,
		"TBathtubGrip::control": 0x801d355c,
		"TBathtubGrip::calcRootMatrix": 0x801d38f0,
		"TBathtubGrip::getRootJointMtx": 0x801d3aec,
		"TBathtubGrip::receiveMessage": 0x801d3b10,
		"TBathtubGrip::perform": 0x801d3e34,
		"TBathtubGrip::TBathtubGrip": 0x801d3f04,
		"TBathtubGrip::kill": 0x801d42ec,
		"TBathtubGripPartsHard::receiveMessage": 0x801d439c,
		"TBathtubGripPartsFragile::receiveMessage": 0x801d43d8,
		"TBathtubGripParts::getRootJointMtx": 0x801d4408,
		"TBathtubParams::TBathtubParams": 0x801d4450,
		"MoveBG::__sinit_MapObjCorona_cpp": 0x801d4ac4,
		"__sinit_MapObjCorona_cpp": 0x801d4ac4,
		"TJumpBase::control": 0x801d4e6c,
		"TJumpBase::calcRootMatrix": 0x801d5370,
		"TJumpBase::getRootJointMtx": 0x801d5420,
		"TJumpBase::receiveMessage": 0x801d5430,
		"TJumpBase::ensureTakeSituation": 0x801d5598,
		"TJumpBase::initMapObj": 0x801d55dc,
		"TJumpBase::TJumpBase": 0x801d564c,
		"TMushroom1up::perform": 0x801d5698,
		"TMushroom1up::control": 0x801d5778,
		"TMushroom1up::load": 0x801d5bf0,
		"TMushroom1up::initMapObj": 0x801d5c2c,
		"TMushroom1up::makeObjAppeared": 0x801d5cac,
		"TMushroom1up::touchPlayer": 0x801d5dc0,
		"TMushroom1up::TMushroom1up": 0x801d5e58,
		"MoveBG::__sinit_MapObjItem2_cpp": 0x801d5f48,
		"__sinit_MapObjItem2_cpp": 0x801d5f48,
		"TWoodBox::TWoodBox": 0x801d62f0,
		"TWoodBox::loadAfter": 0x801d6380,
		"TWoodBox::kill": 0x801d6480,
		"TBreakHideObj::initMapObj": 0x801d6768,
		"TBreakHideObj::control": 0x801d6820,
		"TBreakHideObj::receiveMessage": 0x801d689c,
		"TBreakHideObj::kill": 0x801d6968,
		"THideObjPictureTwin::THideObjPictureTwin": 0x801d69c8,
		"THideObjPictureTwin::initMapObj": 0x801d6aa4,
		"THideObjPictureTwin::loadAfter": 0x801d6aec,
		"THideObjPictureTwin::afterFinishedAnim": 0x801d6bc4,
		"TWaterHitPictureHideObj::TWaterHitPictureHideObj": 0x801d6d78,
		"TWaterHitPictureHideObj::load": 0x801d6e24,
		"TWaterHitPictureHideObj::loadAfter": 0x801d6fe0,
		"TWaterHitPictureHideObj::receiveMessage": 0x801d7344,
		"TWaterHitPictureHideObj::control": 0x801d74dc,
		"TWaterHitPictureHideObj::touchActor": 0x801d75b4,
		"TWaterHitPictureHideObj::touchWater": 0x801d75e4,
		"TWaterHitPictureHideObj::forward": 0x801d7738,
		"forward": 0x801d7738,
		"TWaterHitPictureHideObj::afterFinishedAnim": 0x801d7814,
		"THipDropHideObj::touchPlayer": 0x801d7900,
		"TFruitBasketEvent::TFruitBasketEvent": 0x801d7960,
		"TFruitBasketEvent::reset": 0x801d7a84,
		"TFruitBasketEvent::getFruitNum": 0x801d7aa0,
		"getFruitNum": 0x801d7aa0,
		"TFruitBasketEvent::countFruit": 0x801d7ab0,
		"TFruitBasket::loadAfter": 0x801d7b94,
		"TFruitBasket::touchFruit": 0x801d7cbc,
		"TFruitBasket::countFruit": 0x801d7d58,
		"TFruitHitHideObj::load": 0x801d7f04,
		"TFruitHitHideObj::touchActor": 0x801d7f90,
		"TFruitHitHideObj::touchFruit": 0x801d7fec,
		"TWaterHitHideObj::load": 0x801d8080,
		"TWaterHitHideObj::touchWater": 0x801d810c,
		"THideObj::touchPlayer": 0x801d8170,
		"THideObjBase::THideObjBase": 0x801d81dc,
		"THideObjBase::load": 0x801d8244,
		"THideObjBase::loadAfter": 0x801d82d0,
		"THideObjBase::receiveMessage": 0x801d83c8,
		"THideObjBase::emitEffect": 0x801d845c,
		"THideObjBase::appearObjFromPoint": 0x801d8494,
		"appearObjFromPoint": 0x801d8494,
		"THideObjBase::appearObj": 0x801d85ec,
		"appearObj": 0x801d85ec,
		"THideObjPictureTwin::getObjAppearPos": 0x801d86d4,
		"MoveBG::__sinit_MapObjHide_cpp": 0x801d8950,
		"__sinit_MapObjHide_cpp": 0x801d8950,
		"TLampTrapIron::perform": 0x801d8d28,
		"TLampTrapIron::control": 0x801d8dcc,
		"TLampTrapIron::receiveMessage": 0x801d8e54,
		"TLampTrapIron::loadAfter": 0x801d8ef8,
		"TLampTrapIron::initMapObj": 0x801d9028,
		"TLampTrapIron::TLampTrapIron": 0x801d9070,
		"TLampTrapIronHit::perform": 0x801d90c4,
		"TLampTrapIronHit::receiveMessage": 0x801d91a0,
		"TLampTrapSpike::perform": 0x801d91d0,
		"TLampTrapSpike::control": 0x801d9230,
		"TLampTrapSpike::receiveMessage": 0x801d967c,
		"TLampTrapSpike::loadAfter": 0x801d969c,
		"TLampTrapSpike::initMapObj": 0x801d97cc,
		"TLampTrapSpike::TLampTrapSpike": 0x801d9804,
		"TLampTrapSpikeHit::perform": 0x801d985c,
		"TLampTrapSpikeHit::receiveMessage": 0x801d9940,
		"MoveBG::__sinit_MapObjTrap_cpp": 0x801d9afc,
		"__sinit_MapObjTrap_cpp": 0x801d9afc,
		"TJointModel::getJ3DModelDataFlag": 0x801d9e18,
		"TJointObj::newJointObj": 0x801d9e20,
		"TJointModel::TJointModel": 0x801d9e60,
		"TJointModel::initJointModel": 0x801d9eb0,
		"TJointModel::initActor": 0x801d9efc,
		"initActor": 0x801d9efc,
		"TJointModel::perform": 0x801da040,
		"Map::__sinit_JointModel_cpp": 0x801da084,
		"__sinit_JointModel_cpp": 0x801da084,
		"TJointModelManager::~TJointModelManager": 0x801da380,
		"JGadget::TList<16MActorSubAnmInfo,Q27JGadget30TAllocator<16MActorSubAnmInfo>>::iterator::iterator": 0x801da504,
		"TJointModelManager::newJointModel": 0x801da50c,
		"TJointModelManager::TJointModelManager": 0x801da54c,
		"TJointModelManager::initJointModel": 0x801da5d0,
		"TJointModelManager::perform": 0x801da6b8,
		"Map::__sinit_JointModelManager_cpp": 0x801da728,
		"__sinit_JointModelManager_cpp": 0x801da728,
		"TJointObj::TJointObj": 0x801daa24,
		"TJointObj::initJointObj": 0x801daa54,
		"initJointObj": 0x801daa54,
		"TJointObj::initChildren": 0x801dab08,
		"initChildren": 0x801dab08,
		"TJointObj::kill": 0x801dabf0,
		"TJointObj::alive": 0x801dacd8,
		"alive": 0x801dacd8,
		"TJointObj::sleep": 0x801dada0,
		"TJointObj::awake": 0x801dae98,
		"TJointObj::sit": 0x801daf74,
		"sit": 0x801daf74,
		"TJointObj::stand": 0x801db044,
		"stand": 0x801db044,
		"Map::__sinit_JointObj_cpp": 0x801db114,
		"__sinit_JointObj_cpp": 0x801db114,
		"TMap::~TMap": 0x801db410,
		"TMap::TMap": 0x801db484,
		"TMap::load": 0x801db584,
		"TMap::loadAfter": 0x801db608,
		"TMap::perform": 0x801db62c,
		"TMap::changeModel": 0x801db710,
		"TMap::checkGroundExactY": 0x801db798,
		"checkGroundExactY": 0x801db798,
		"TMap::checkGroundIgnoreWaterThrough": 0x801db82c,
		"checkGroundIgnoreWaterThrough": 0x801db82c,
		"TMap::checkRoofIgnoreWaterThrough": 0x801db8b8,
		"checkRoofIgnoreWaterThrough": 0x801db8b8,
		"TMap::isTouchedWallsAndMoveXZ": 0x801db8e4,
		"isTouchedWallsAndMoveXZ": 0x801db8e4,
		"TMap::isTouchedOneWallAndMoveXZ": 0x801db91c,
		"isTouchedOneWallAndMoveXZ": 0x801db91c,
		"TMap::isTouchedOneWall": 0x801db9c8,
		"isTouchedOneWall": 0x801db9c8,
		"TMap::intersectLine": 0x801dba68,
		"TMap::isInArea": 0x801dba8c,
		"TMap::getIllegalCheckData": 0x801dbad0,
		"getIllegalCheckData": 0x801dbad0,
		"TMap::update": 0x801dbadc,
		"Map::initStage": 0x801dbd40,
		"initStage": 0x801dbd40,
		"Map::initStageCommon": 0x801dbef0,
		"initStageCommon": 0x801dbef0,
		"Map::initPinnaParco": 0x801dc1d0,
		"initPinnaParco": 0x801dc1d0,
		"Map::initMare": 0x801dc2b4,
		"initMare": 0x801dc2b4,
		"Map::initMonte": 0x801dc5a4,
		"initMonte": 0x801dc5a4,
		"Map::__sinit_Map_cpp": 0x801dc764,
		"__sinit_Map_cpp": 0x801dc764,
		"TMapCollisionData::polygonIsInGrid": 0x801dca60,
		"polygonIsInGrid": 0x801dca60,
		"Map::checkLinesCollision": 0x801dd098,
		"checkLinesCollision": 0x801dd098,
		"TMapCollisionData::intersectLine": 0x801dd170,
		"Map::bgIntersectLine": 0x801ddcd0,
		"bgIntersectLine": 0x801ddcd0,
		"TMapCollisionData::checkGround": 0x801de098,
		"TMapCollisionData::checkGroundList": 0x801de240,
		"checkGroundList": 0x801de240,
		"TMapCollisionData::checkRoof": 0x801de3d8,
		"TMapCollisionData::checkRoofList": 0x801de534,
		"checkRoofList": 0x801de534,
		"TMapCollisionData::checkWalls": 0x801de67c,
		"TMapCollisionData::checkWallList": 0x801de79c,
		"checkWallList": 0x801de79c,
		"Map::__sinit_MapCheck_cpp": 0x801debd8,
		"__sinit_MapCheck_cpp": 0x801debd8,
		"TMapCollisionData::TMapCollisionData": 0x801deed4,
		"TMapCollisionData::init": 0x801defc0,
		"TBGCheckListRoot::TBGCheckListRoot": 0x801df3e8,
		"TMapCollisionData::initMoveCollision": 0x801df42c,
		"initMoveCollision": 0x801df42c,
		"TBGCheckListWarp::TBGCheckListWarp": 0x801df468,
		"TBGCheckList::TBGCheckList": 0x801df49c,
		"TBGCheckListWarp::setPreNode": 0x801df4b8,
		"TBGCheckList::setPreNode": 0x801df4c0,
		"Map::__sinit_MapCollisionData_cpp": 0x801df4c4,
		"__sinit_MapCollisionData_cpp": 0x801df4c4,
		"TMapCollisionWarp::TMapCollisionWarp": 0x801df7c8,
		"TMapCollisionWarp::init": 0x801df858,
		"TMapCollisionWarp::remove": 0x801df8c4,
		"TMapCollisionWarp::setUpTrans": 0x801df934,
		"TMapCollisionWarp::setUp": 0x801df9cc,
		"TMapCollisionMove::TMapCollisionMove": 0x801dfa9c,
		"TMapCollisionMove::moveTrans": 0x801dfc30,
		"TMapCollisionMove::move": 0x801dfc94,
		"TMapCollisionStatic::TMapCollisionStatic": 0x801dfd38,
		"TMapCollisionStatic::init": 0x801dfdc4,
		"TMapCollisionStatic::setUp": 0x801dfe40,
		"TMapCollisionBase::init": 0x801dfe94,
		"TMapCollisionBase::setAllActor": 0x801e004c,
		"setAllActor": 0x801e004c,
		"TMapCollisionBase::setAllData": 0x801e007c,
		"setAllData": 0x801e007c,
		"TMapCollisionBase::setAllBGType": 0x801e00ac,
		"setAllBGType": 0x801e00ac,
		"TMapCollisionBase::setVertexData": 0x801e00d8,
		"setVertexData": 0x801e00d8,
		"TMapCollisionMove::moveSRT": 0x801e0138,
		"TMapCollisionStatic::remove": 0x801e02d0,
		"TMapCollisionManager::TMapCollisionManager": 0x801e02d4,
		"TMapCollisionManager::init": 0x801e034c,
		"TMapCollisionManager::createCollision": 0x801e04b4,
		"createCollision": 0x801e04b4,
		"TMapCollisionManager::changeCollision": 0x801e0598,
		"changeCollision": 0x801e0598,
		"TMapDrawWall::~TMapDrawWall": 0x801e0610,
		"TMap::draw": 0x801e0684,
		"TMapDrawWall::TMapDrawWall": 0x801e0688,
		"TMapDrawWall::load": 0x801e0708,
		"TMapDrawWall::perform": 0x801e0744,
		"Map::__sinit_MapDraw_cpp": 0x801e0a6c,
		"__sinit_MapDraw_cpp": 0x801e0a6c,
		"TMapEvent::startControl": 0x801e0d68,
		"TMapEvent::getBuilding": 0x801e0d74,
		"TMapEvent::TMapEvent": 0x801e0d90,
		"TMapEvent::load": 0x801e0ddc,
		"TMapEvent::perform": 0x801e0e1c,
		"TMapEvent::finishControl": 0x801e0f08,
		"TMapEvent::isFinishedAll": 0x801e0f5c,
		"Map::__sinit_MapEvent_cpp": 0x801e0f8c,
		"__sinit_MapEvent_cpp": 0x801e0f8c,
		"TMapEventSinkShadowMario::~TMapEventSinkShadowMario": 0x801e1288,
		"TMapEventSink::watch": 0x801e131c,
		"TMapEventSinkShadowMario::initWithBuildingNum": 0x801e1324,
		"TMapEventSinkShadowMario::initBuilding": 0x801e13f4,
		"TMapEventSinkShadowMario::loadAfter": 0x801e14b4,
		"TMapEventSinkShadowMario::raiseBuilding": 0x801e157c,
		"raiseBuilding": 0x801e157c,
		"TMapEventSinkShadowMario::rising": 0x801e15ac,
		"J3DTransformInfo::operator_=": 0x801e1638,
		"TMapEventSinkBianco::load": 0x801e1684,
		"TMapEventSinkBianco::loadAfter": 0x801e177c,
		"TMapEventSinkBianco::watch": 0x801e18f4,
		"TMapEventSinkBianco::startControl": 0x801e1a08,
		"TMapEventSinkBianco::control": 0x801e1b68,
		"TMapEventSinkBianco::rising": 0x801e1bec,
		"TMapEventSinkBianco::finishControl": 0x801e1c78,
		"TMapEventSinkInPollutionReset::loadAfter": 0x801e1e4c,
		"TMapEventSinkInPollutionReset::makeBuildingRecovered": 0x801e1f80,
		"TMapEventSinkInPollution::loadAfter": 0x801e211c,
		"TMapEventSinkInPollution::initBuriedBuilding": 0x801e21b4,
		"initBuriedBuilding": 0x801e21b4,
		"TMapEventSinkInPollution::watch": 0x801e225c,
		"TMapEventSink::TMapEventSink": 0x801e230c,
		"TMapEventSink::load": 0x801e23a8,
		"TMapEventSink::initWithBuildingNum": 0x801e24b4,
		"TMapEventSink::initBuilding": 0x801e2564,
		"TMapEventSink::startControl": 0x801e2614,
		"TMapEventSink::control": 0x801e27d0,
		"TMapEventSink::rising": 0x801e2930,
		"TMapEventSink::finishControl": 0x801e29cc,
		"TMapEventSink::makeBuildingRecovered": 0x801e2a50,
		"TMapEventSink::isFinishedAll": 0x801e2b80,
		"TMapEventSink::getPollutionObj": 0x801e2bbc,
		"getPollutionObj": 0x801e2bbc,
		"TMapEventSink::getSinkOffsetY": 0x801e2bf0,
		"getSinkOffsetY": 0x801e2bf0,
		"TMapEventSink::isBuried": 0x801e2c04,
		"isBuried": 0x801e2c04,
		"TMapEventSink::getBuilding": 0x801e2c20,
		"TMapEventSinkBianco::~TMapEventSinkBianco": 0x801e2c44,
		"Map::__sinit_MapEventSink_cpp": 0x801e2cd8,
		"__sinit_MapEventSink_cpp": 0x801e2cd8,
		"TMapCollisionBase::initCheckData": 0x801e2fd4,
		"initCheckData": 0x801e2fd4,
		"TMapCollisionBase::initAllCheckData": 0x801e3088,
		"initAllCheckData": 0x801e3088,
		"TMapCollisionBase::update": 0x801e32c4,
		"TMapCollisionBase::updateTrans": 0x801e3358,
		"updateTrans": 0x801e3358,
		"TMapCollisionBase::setCheckData": 0x801e34f0,
		"setCheckData": 0x801e34f0,
		"TMapCollisionMove::setList": 0x801e3754,
		"setList": 0x801e3754,
		"TBGCheckData::setVertex": 0x801e37b8,
		"setVertex": 0x801e37b8,
		"Map::__sinit_MapMakeData_cpp": 0x801e3980,
		"__sinit_MapMakeData_cpp": 0x801e3980,
		"TMapCollisionData::removeCheckListData": 0x801e3c7c,
		"removeCheckListData": 0x801e3c7c,
		"TMapCollisionData::updateCheckListNode": 0x801e3edc,
		"updateCheckListNode": 0x801e3edc,
		"TMapCollisionData::addCheckDataToGrid": 0x801e3fdc,
		"addCheckDataToGrid": 0x801e3fdc,
		"TMapCollisionData::getGridArea": 0x801e4554,
		"getGridArea": 0x801e4554,
		"Map::addGroundNode": 0x801e4734,
		"addGroundNode": 0x801e4734,
		"Map::addRoofNode": 0x801e477c,
		"addRoofNode": 0x801e477c,
		"Map::addWallNode": 0x801e47c4,
		"addWallNode": 0x801e47c4,
		"Map::addAfterPreNode": 0x801e480c,
		"addAfterPreNode": 0x801e480c,
		"TMapCollisionData::allocCheckList": 0x801e48a0,
		"allocCheckList": 0x801e48a0,
		"TMapCollisionData::getEntryID": 0x801e490c,
		"getEntryID": 0x801e490c,
		"TMapCollisionData::allocCheckData": 0x801e4950,
		"allocCheckData": 0x801e4950,
		"TMirrorMapDrawBuf::~TMirrorMapDrawBuf": 0x801e496c,
		"TMirrorMapDrawBuf::perform": 0x801e49f0,
		"TMirrorModelManager::TMirrorModelManager": 0x801e4a3c,
		"TMirrorModelManager::load": 0x801e4ac4,
		"TMirrorModelManager::loadAfter": 0x801e4c70,
		"TMirrorModelManager::perform": 0x801e4d80,
		"JGeometry::TVec3<float><float>::scaleAdd": 0x801e51b8,
		"scaleAdd": 0x801e51b8,
		"TMirrorModel::calc": 0x801e51ec,
		"TMirrorModelManager::isInMirror": 0x801e5200,
		"isInMirror": 0x801e5200,
		"TMirrorModelManager::isUpperThanMirrorPlane": 0x801e5244,
		"isUpperThanMirrorPlane": 0x801e5244,
		"TMirrorModel::getD": 0x801e5324,
		"getD": 0x801e5324,
		"TMirrorModel::getNormalVec": 0x801e532c,
		"getNormalVec": 0x801e532c,
		"TMirrorModelObj::init": 0x801e5334,
		"TMirrorModelObj::calc": 0x801e5484,
		"TMirrorModelObj::setPlane": 0x801e54b8,
		"TMirrorModel::TMirrorModel": 0x801e556c,
		"TMirrorModel::init": 0x801e55a8,
		"TMirrorModel::initPlaneInfo": 0x801e56d0,
		"initPlaneInfo": 0x801e56d0,
		"TMirrorModel::setPlane": 0x801e58b4,
		"TMirrorCamera::TMirrorCamera": 0x801e5954,
		"TMirrorCamera::drawSetting": 0x801e5bfc,
		"drawSetting": 0x801e5bfc,
		"TMirrorCamera::perform": 0x801e5c98,
		"TMirrorModelManager::~TMirrorModelManager": 0x801e5d50,
		"Map::__sinit_MapMirror_cpp": 0x801e5e30,
		"__sinit_MapMirror_cpp": 0x801e5e30,
		"TMapModel::getJ3DModelDataFlag": 0x801e6134,
		"TMapModelManager::TMapModelManager": 0x801e613c,
		"TMapModelManager::init": 0x801e6180,
		"TMapModel::initJointModel": 0x801e6210,
		"TMapModel::initUnderpass": 0x801e62a0,
		"initUnderpass": 0x801e62a0,
		"TMapModel::perform": 0x801e6444,
		"TMapModelManager::~TMapModelManager": 0x801e65e4,
		"TMapModelManager::newJointModel": 0x801e6680,
		"Map::__sinit_MapModel_cpp": 0x801e66e8,
		"__sinit_MapModel_cpp": 0x801e66e8,
		"TMapWarp::TMapWarp": 0x801e69e4,
		"TMapWarp::init": 0x801e6a00,
		"TMapWarp::TMapWarpInfo::TMapWarpInfo": 0x801e6d28,
		"TMapWarp::initModel": 0x801e6d2c,
		"TMapWarp::watchToWarp": 0x801e6dc4,
		"watchToWarp": 0x801e6dc4,
		"TMapWarp::changeModel": 0x801e70e4,
		"Map::__sinit_MapWarp_cpp": 0x801e7180,
		"__sinit_MapWarp_cpp": 0x801e7180,
		"TMapObjSoundGroup::~TMapObjSoundGroup": 0x801e747c,
		"TMapObjSoundGroup::TMapObjSoundGroup": 0x801e74f0,
		"TMapObjSoundGroup::load": 0x801e7564,
		"TMapObjSoundGroup::perform": 0x801e7658,
		"Map::MsPerpendicFootToLineR": 0x801e77e8,
		"TMapModelActor::perform": 0x801e7930,
		"TMapStaticObj::TMapStaticObj": 0x801e7a0c,
		"TMapStaticObj::load": 0x801e7a6c,
		"TMapStaticObj::loadAfter": 0x801e7ab0,
		"TMapStaticObj::init": 0x801e7af4,
		"TMapStaticObj::initModel": 0x801e7eec,
		"TMapStaticObj::initUnique": 0x801e801c,
		"TMapStaticObj::perform": 0x801e81bc,
		"TMapStaticObj::getModelData": 0x801e8478,
		"getModelData": 0x801e8478,
		"Map::__sinit_MapStaticObject_cpp": 0x801e8590,
		"__sinit_MapStaticObject_cpp": 0x801e8590,
		"TMapWire::TMapWire": 0x801e889c,
		"TMapWire::init": 0x801e8918,
		"TMapWire::getPointPosOnWire": 0x801e9034,
		"getPointPosOnWire": 0x801e9034,
		"TMapWire::getPosInWire": 0x801e91c4,
		"TMapWire::move": 0x801e9360,
		"TMapWire::calcViewAndDBEntry": 0x801e95e0,
		"calcViewAndDBEntry": 0x801e95e0,
		"TMapWire::setFootPointsAtHanged": 0x801e9630,
		"setFootPointsAtHanged": 0x801e9630,
		"TMapWire::getPointPosAtHanged": 0x801e98c8,
		"getPointPosAtHanged": 0x801e98c8,
		"TMapWire::release": 0x801e996c,
		"TMapWire::getPointPowerAtReleased": 0x801e9db0,
		"getPointPowerAtReleased": 0x801e9db0,
		"TMapWire::drawUpper": 0x801e9dec,
		"TMapWire::drawLower": 0x801e9f1c,
		"drawLower": 0x801e9f1c,
		"TMapWirePoint::TMapWirePoint": 0x801ea128,
		"Map::__sinit_MapWire_cpp": 0x801ea150,
		"__sinit_MapWire_cpp": 0x801ea150,
		"TMapWireManager::~TMapWireManager": 0x801ea44c,
		"TMapWireManager::TMapWireManager": 0x801ea4c0,
		"TMapWireManager::load": 0x801ea574,
		"TMapWireManager::loadAfter": 0x801ea724,
		"JGadget::TList_pointer<THitActor*>::insert": 0x801ea82c,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::getChildren": 0x801ea89c,
		"getChildren": 0x801ea89c,
		"JDrama::TNameRef::search": 0x801ea8a4,
		"JDrama::TNameRefGen::getRootNameRef": 0x801ea8fc,
		"getRootNameRef": 0x801ea8fc,
		"JDrama::TNameRefGen::getInstance": 0x801ea904,
		"getInstance": 0x801ea904,
		"TMapWireManager::perform": 0x801ea9a8,
		"TMapWireManager::getPointPosInNthWire": 0x801eab60,
		"getPointPosInNthWire": 0x801eab60,
		"TMapWireManager::getWireNo": 0x801eabc0,
		"getWireNo": 0x801eabc0,
		"TMapWireActorManager::doActorToWire": 0x801eabe4,
		"doActorToWire": 0x801eabe4,
		"Map::initDraw": 0x801eadc8,
		"TMapWireActor::TMapWireActor": 0x801eaf10,
		"TMapWireActor::receiveMessage": 0x801eaf7c,
		"TMapWireActor::getTipPoints": 0x801eafb0,
		"getTipPoints": 0x801eafb0,
		"TMapWireActor::getPosInWire": 0x801eafec,
		"TMapWireActor::getTakingMtx": 0x801eb194,
		"Map::__sinit_MapWireManager_cpp": 0x801eb19c,
		"__sinit_MapWireManager_cpp": 0x801eb19c,
		"TMapXlu::TMapXlu": 0x801eb4ac,
		"TMapXlu::init": 0x801eb4bc,
		"TMapXlu::changeXluJoint": 0x801eb5d0,
		"changeXluJoint": 0x801eb5d0,
		"TMapXlu::changeNormalJoint": 0x801eb6e8,
		"changeNormalJoint": 0x801eb6e8,
		"Map::__sinit_MapXlu_cpp": 0x801eb7e8,
		"__sinit_MapXlu_cpp": 0x801eb7e8,
		"TPollutionLayer::action": 0x801ebae4,
		"TPollutionLayer::getPlaneType": 0x801ebeb0,
		"TPollutionLayer::fire": 0x801ebeb8,
		"fire": 0x801ebeb8,
		"TPollutionLayer::getPollutedPos": 0x801ec008,
		"getPollutedPos": 0x801ec008,
		"TPollutionLayer::getPollutedPosNear": 0x801ec130,
		"getPollutedPosNear": 0x801ec130,
		"TPollutionLayer::getTexPosS": 0x801ec374,
		"TPollutionLayer::isInArea": 0x801ec3a0,
		"Map::__sinit_PollutionAction_cpp": 0x801ec3e0,
		"__sinit_PollutionAction_cpp": 0x801ec3e0,
		"TPollutionRevivalTexStamp::TPollutionRevivalTexStamp": 0x801ec6dc,
		"TPollutionTexStamp::TPollutionTexStamp": 0x801ec708,
		"TPollutionLayerTaskInfo::TPollutionLayerTaskInfo": 0x801ec728,
		"TPollutionTexStamp::pushTask": 0x801ec744,
		"pushTask": 0x801ec744,
		"TPollutionCounterLayer::TPollutionCounterLayer": 0x801ec7c0,
		"TPollutionJointObjTaskInfo::TPollutionJointObjTaskInfo": 0x801ec890,
		"TPollutionModelTaskInfo::TPollutionModelTaskInfo": 0x801ec8a4,
		"TPollutionCounterLayer::init": 0x801ec8b4,
		"TPollutionCounterLayer::offLayer": 0x801ecb38,
		"offLayer": 0x801ecb38,
		"TPollutionCounterLayer::stampIsCleanType": 0x801ecb58,
		"stampIsCleanType": 0x801ecb58,
		"TPollutionCounterLayer::registerLayer": 0x801ecb80,
		"registerLayer": 0x801ecb80,
		"TPollutionCounterLayer::registerTexStamp": 0x801ecbcc,
		"registerTexStamp": 0x801ecbcc,
		"TPollutionCounterLayer::registerRevivalTexStamp": 0x801ecc70,
		"registerRevivalTexStamp": 0x801ecc70,
		"TPollutionCounterLayer::pushModelStampTask": 0x801eccb8,
		"pushModelStampTask": 0x801eccb8,
		"TPollutionCounterLayer::calcViewMtx": 0x801ecd04,
		"calcViewMtx": 0x801ecd04,
		"TPollutionCounterLayer::pushJointObjStampTask": 0x801ece84,
		"pushJointObjStampTask": 0x801ece84,
		"TPollutionCounterLayer::resetTask": 0x801ececc,
		"resetTask": 0x801ececc,
		"TPollutionCounterLayer::countTexDegree": 0x801ecf38,
		"countTexDegree": 0x801ecf38,
		"TPollutionCounterLayer::cleanProhibitArea": 0x801ed18c,
		"cleanProhibitArea": 0x801ed18c,
		"TPollutionCounterLayer::drawRevivalTexStamp": 0x801ed370,
		"drawRevivalTexStamp": 0x801ed370,
		"Map::initGXforStamp": 0x801ed65c,
		"initGXforStamp": 0x801ed65c,
		"Map::doTask": 0x801ed928,
		"doTask": 0x801ed928,
		"TPollutionCounterLayer::drawJointObjStamp": 0x801edb18,
		"drawJointObjStamp": 0x801edb18,
		"Map::initGXforPollutionLayer": 0x801edda0,
		"initGXforPollutionLayer": 0x801edda0,
		"Map::drawTex": 0x801ee160,
		"drawTex": 0x801ee160,
		"TPollutionCounterObj::TPollutionCounterObj": 0x801ee244,
		"TPollutionCounterObj::init": 0x801ee284,
		"TPollutionCounterObj::registerPollutionObj": 0x801ee508,
		"registerPollutionObj": 0x801ee508,
		"TPollutionCounterObj::countObjDegree": 0x801ee5b0,
		"countObjDegree": 0x801ee5b0,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setEular": 0x801ee884,
		"Map::initDrawObjGX": 0x801ee92c,
		"initDrawObjGX": 0x801ee92c,
		"TPollutionCounterBase::drawSyncCallback": 0x801eeae4,
		"Map::drawBlack": 0x801eeb6c,
		"drawBlack": 0x801eeb6c,
		"TPollutionCounterObj::getCounterNo": 0x801eecf8,
		"TPollutionCounterObj::getTokenNo": 0x801eed00,
		"TPollutionCounterLayer::getCounterNo": 0x801eed08,
		"TPollutionCounterLayer::getTokenNo": 0x801eed10,
		"Map::__sinit_PollutionCount_cpp": 0x801eed18,
		"__sinit_PollutionCount_cpp": 0x801eed18,
		"TPollutionManager::~TPollutionManager": 0x801ef014,
		"TPollutionManager::TPollutionManager": 0x801ef0b0,
		"TPollutionManager::load": 0x801ef124,
		"TPollutionManager::setDataAddress": 0x801ef288,
		"setDataAddress": 0x801ef288,
		"TPollutionManager::newJointModel": 0x801ef2d4,
		"TPollutionManager::perform": 0x801ef460,
		"TPollutionManager::cleanedAll": 0x801ef4f8,
		"cleanedAll": 0x801ef4f8,
		"TPollutionManager::isPolluted": 0x801ef604,
		"TPollutionManager::getPollutionDegree": 0x801ef6b8,
		"getPollutionDegree": 0x801ef6b8,
		"TPollutionManager::getPollutionType": 0x801ef7b0,
		"getPollutionType": 0x801ef7b0,
		"TPollutionManager::stampGround": 0x801ef86c,
		"stampGround": 0x801ef86c,
		"TPollutionManager::clean": 0x801ef94c,
		"clean": 0x801ef94c,
		"TPollutionManager::stamp": 0x801efa1c,
		"TPollutionManager::stampModel": 0x801efadc,
		"TPollutionLayerWallMinusX::getPlaneType": 0x801efb7c,
		"TPollutionLayerWallMinusX::getTexPosS": 0x801efb84,
		"TPollutionLayerWallPlusX::isInArea": 0x801efbb0,
		"TPollutionLayerWallPlusX::isInAreaSize": 0x801efbf0,
		"TPollutionLayerWallBase::getTexPosT": 0x801efc40,
		"TPollutionLayer::getTexResource": 0x801efc6c,
		"TPollutionLayer::newJointObj": 0x801efc7c,
		"TPollutionLayer::getJ3DModelDataFlag": 0x801efcbc,
		"TPollutionLayerWallMinusZ::getPlaneType": 0x801efcc4,
		"TPollutionLayerWallMinusZ::getTexPosS": 0x801efccc,
		"TPollutionLayerWallPlusZ::isInArea": 0x801efcf8,
		"TPollutionLayerWallPlusZ::isInAreaSize": 0x801efd38,
		"Map::__sinit_PollutionManager_cpp": 0x801efd88,
		"__sinit_PollutionManager_cpp": 0x801efd88,
		"TPollutionObj::TPollutionObj": 0x801f0084,
		"TPollutionObj::initAreaInfo": 0x801f00dc,
		"initAreaInfo": 0x801f00dc,
		"TPollutionLayer::getTexPosT": 0x801f0228,
		"TPollutionObj::isCleaned": 0x801f0254,
		"isCleaned": 0x801f0254,
		"TPollutionObj::updateDepthMap": 0x801f0274,
		"updateDepthMap": 0x801f0274,
		"TPollutionObj::getDepthFromMap": 0x801f0318,
		"getDepthFromMap": 0x801f0318,
		"TPollutionObj::newJointObj": 0x801f054c,
		"Map::__sinit_PollutionObj_cpp": 0x801f05b4,
		"__sinit_PollutionObj_cpp": 0x801f05b4,
		"TPollutionPos::TPollutionPos": 0x801f08b0,
		"TPollutionPos::init": 0x801f08e0,
		"TPollutionPos::worldToTexSize": 0x801f0928,
		"worldToTexSize": 0x801f0928,
		"TPollutionPos::worldToDepth": 0x801f0948,
		"worldToDepth": 0x801f0948,
		"TPollutionPos::isProhibit": 0x801f0970,
		"isProhibit": 0x801f0970,
		"TPollutionPos::isSame": 0x801f09ec,
		"TPollutionPos::getDepthWorld": 0x801f0ac0,
		"getDepthWorld": 0x801f0ac0,
		"TPollutionPos::getEdgeDegree": 0x801f0b3c,
		"getEdgeDegree": 0x801f0b3c,
		"Map::__sinit_PollutionPos_cpp": 0x801f0c90,
		"__sinit_PollutionPos_cpp": 0x801f0c90,
		"TShimmer::TShimmer": 0x801f0ff8,
		"TShimmer::load": 0x801f1144,
		"TShimmer::loadAfter": 0x801f12d8,
		"TShimmer::perform": 0x801f13d4,
		"Map::__sinit_Shimmer_cpp": 0x801f165c,
		"__sinit_Shimmer_cpp": 0x801f165c,
		"TSky::TSky": 0x801f19cc,
		"TSky::load": 0x801f1ae4,
		"TSky::perform": 0x801f1b7c,
		"Map::__sinit_Sky_cpp": 0x801f1ed4,
		"__sinit_Sky_cpp": 0x801f1ed4,
		"TMapEventSirenaSink::~TMapEventSirenaSink": 0x801f21d8,
		"TMapEventSirenaSink::initPollution": 0x801f226c,
		"initPollution": 0x801f226c,
		"TMapEventSirenaSink::makePollutionRecovered": 0x801f2270,
		"makePollutionRecovered": 0x801f2270,
		"TMapEventSirenaSink::TMapEventSirenaSink": 0x801f2274,
		"TMapEventSirenaSink::load": 0x801f22d8,
		"TMapEventSirenaSink::loadAfter": 0x801f23d0,
		"TMapEventSirenaSink::watch": 0x801f2474,
		"Map::__sinit_MapEventSirena_cpp": 0x801f258c,
		"__sinit_MapEventSirena_cpp": 0x801f258c,
		"TPollutionLayer::isInAreaSize": 0x801f2888,
		"TPollutionLayer::TPollutionLayer": 0x801f28d8,
		"TPollutionLayer::initJointModel": 0x801f2998,
		"TPollutionLayer::initLayerInfo": 0x801f2b4c,
		"TPollutionLayer::initTexImage": 0x801f2c44,
		"initTexImage": 0x801f2c44,
		"TPollutionLayer::perform": 0x801f2e18,
		"TPollutionLayer::isPolluted": 0x801f2e78,
		"TPollutionLayer::stamp": 0x801f2fd0,
		"TPollutionLayer::cleaned": 0x801f311c,
		"cleaned": 0x801f311c,
		"TPollutionLayer::appearItem": 0x801f34f0,
		"appearItem": 0x801f34f0,
		"TPollutionLayer::stampModel": 0x801f34f4,
		"TPollutionLayerWallBase::TPollutionLayerWallBase": 0x801f356c,
		"TPollutionLayerWallPlusX::initLayerInfo": 0x801f35b4,
		"TPollutionLayerWallPlusX::stamp": 0x801f3608,
		"TPollutionLayerWallPlusX::getTexPosS": 0x801f3708,
		"TPollutionLayerWallPlusZ::initLayerInfo": 0x801f3734,
		"TPollutionLayerWallPlusZ::stamp": 0x801f3778,
		"TPollutionLayerWave::initJointModel": 0x801f3878,
		"TPollutionLayerWave::getTexResource": 0x801f398c,
		"TPollutionLayerWave::perform": 0x801f39cc,
		"TPollutionLayerWave::draw": 0x801f3a0c,
		"TPollutionLayerWave::initGX": 0x801f3b90,
		"initGX": 0x801f3b90,
		"TPollutionLayerWallPlusX::getPlaneType": 0x801f3db0,
		"TPollutionLayerWallPlusZ::getPlaneType": 0x801f3db8,
		"TPollutionLayerWave::getPlaneType": 0x801f3dc0,
		"Map::__sinit_PollutionLayer_cpp": 0x801f3dc8,
		"__sinit_PollutionLayer_cpp": 0x801f3dc8,
		"TPollutionTest::loadAfter": 0x801f40c4,
		"TPollutionTest::~TPollutionTest": 0x801f40e4,
		"TPollutionTest::perform": 0x801f4158,
		"Map::__sinit_PollutionEvent_cpp": 0x801f415c,
		"__sinit_PollutionEvent_cpp": 0x801f415c,
		"TMapCheckGroundPlane::TMapCheckGroundPlane": 0x801f4458,
		"TMapCheckGroundPlane::init": 0x801f4480,
		"TMapCheckGroundPlane::checkPlaneGround": 0x801f4548,
		"checkPlaneGround": 0x801f4548,
		"TMapCheckGroundPlane::getCheckData": 0x801f467c,
		"getCheckData": 0x801f467c,
		"Map::__sinit_MapCollisionPlane_cpp": 0x801f46a0,
		"__sinit_MapCollisionPlane_cpp": 0x801f46a0,
		"TMarineSnow::perform": 0x801f4a08,
		"TMarineSnow::loadAfter": 0x801f4a64,
		"TMarineSnow::TMarineSnow": 0x801f4abc,
		"TBGCheckData::TBGCheckData": 0x801f4bc8,
		"TBGCheckData::getPlaneType": 0x801f4c20,
		"TBGCheckData::getActiveJumpPower": 0x801f4cb4,
		"getActiveJumpPower": 0x801f4cb4,
		"Map::__sinit_MapData_cpp": 0x801f4d18,
		"__sinit_MapData_cpp": 0x801f4d18,
		"TDolpicEventRiccoMammaGate::~TDolpicEventRiccoMammaGate": 0x801f5014,
		"TDolpicEventRiccoMammaGate::TDolpicEventRiccoMammaGate": 0x801f50a8,
		"TDolpicEventRiccoMammaGate::load": 0x801f5130,
		"TDolpicEventRiccoMammaGate::loadAfter": 0x801f53b0,
		"TDolpicEventRiccoMammaGate::watch": 0x801f5488,
		"TDolpicEventRiccoMammaGate::control": 0x801f5670,
		"TDolpicEventRiccoMammaGate::isFinishedAll": 0x801f5860,
		"TDolpicEventBiancoGate::TDolpicEventBiancoGate": 0x801f5890,
		"TDolpicEventBiancoGate::loadAfter": 0x801f58dc,
		"TDolpicEventBiancoGate::watch": 0x801f5968,
		"TDolpicEventBiancoGate::control": 0x801f59d8,
		"TDolpicEventBiancoGate::isFinishedAll": 0x801f5a8c,
		"TDolpicEventBiancoGate::~TDolpicEventBiancoGate": 0x801f5abc,
		"Map::__sinit_MapEventDolpic_cpp": 0x801f5b50,
		"__sinit_MapEventDolpic_cpp": 0x801f5b50,
		"TMareEventBumpyWall::TMareEventBumpyWall": 0x801f5ed0,
		"TMareEventBumpyWall::load": 0x801f5f38,
		"TMareEventBumpyWall::control": 0x801f6044,
		"TMareEventBumpyWall::bumpUpX": 0x801f60f0,
		"bumpUpX": 0x801f60f0,
		"TMareEventBumpyWall::bumpDownX": 0x801f6240,
		"bumpDownX": 0x801f6240,
		"TMareEventBumpyWall::bumpUpZ": 0x801f6394,
		"bumpUpZ": 0x801f6394,
		"TMareEventBumpyWall::bumpDownZ": 0x801f64e4,
		"bumpDownZ": 0x801f64e4,
		"TMareEventBumpyWall::touchWater": 0x801f6634,
		"TMareEventDepressWall::TMareEventDepressWall": 0x801f66e0,
		"TMareEventDepressWall::init1stEvent": 0x801f6784,
		"init1stEvent": 0x801f6784,
		"TMareEventDepressWall::init2ndEvent": 0x801f6838,
		"init2ndEvent": 0x801f6838,
		"TMareEventDepressWall::init3rdEvent": 0x801f68ec,
		"init3rdEvent": 0x801f68ec,
		"TMareEventDepressWall::initCommon": 0x801f6a74,
		"initCommon": 0x801f6a74,
		"TMareEventDepressWall::startEvent": 0x801f6eec,
		"TMareEventDepressWall::perform": 0x801f6fa4,
		"TMareEventDepressWall::depressing": 0x801f70c0,
		"depressing": 0x801f70c0,
		"TMareEventDepressWall::rising": 0x801f750c,
		"TMareEventWallRock::TMareEventWallRock": 0x801f7874,
		"TMareEventWallRock::load": 0x801f78e8,
		"TMareWallRock::TMareWallRock": 0x801f7a68,
		"TMareWallRock::load": 0x801f7af4,
		"TMareWallRock::loadAfter": 0x801f7b14,
		"TMareWallRock::initEffect": 0x801f7cd4,
		"initEffect": 0x801f7cd4,
		"TMareWallRock::perform": 0x801f7e58,
		"TMareWallRock::movement": 0x801f7eb8,
		"TMareWallRock::appear": 0x801f8240,
		"TMareEventDepressWall::~TMareEventDepressWall": 0x801f83d8,
		"TMareEventWallRock::~TMareEventWallRock": 0x801f844c,
		"TMareEventWallRock::perform": 0x801f84c0,
		"Map::__sinit_MapEventMare_cpp": 0x801f84c4,
		"__sinit_MapEventMare_cpp": 0x801f84c4,
		"TBathWaterManager::~TBathWaterManager": 0x801f87d0,
		"TBathWaterManager::perform": 0x801f887c,
		"JGeometry::TBox<JGeometry::TVec3<float><float>>::operator_=": 0x801f9bdc,
		"TBathtubData::getPos": 0x801f9c10,
		"getPos": 0x801f9c10,
		"JMath::TRandom_fast_::get_ufloat_1": 0x801f9db0,
		"get_ufloat_1": 0x801f9db0,
		"JGeometry::TVec3<float><float>::setMax": 0x801f9df4,
		"setMax": 0x801f9df4,
		"JGeometry::TVec3<float><float>::setMin": 0x801f9e40,
		"setMin": 0x801f9e40,
		"TBathWater::TDrop::calcBathtub": 0x801f9e8c,
		"calcBathtub": 0x801f9e8c,
		"TBathtubData::getGravityDir": 0x801fa680,
		"getGravityDir": 0x801fa680,
		"TBathWaterManager::throwMario": 0x801fa8bc,
		"TBathWaterManager::getWaterHeight": 0x801fabb4,
		"getWaterHeight": 0x801fabb4,
		"TBathWaterManager::initializeIfYet_": 0x801fac00,
		"initializeIfYet_": 0x801fac00,
		"TBathWaterManager::loadAfter": 0x801fb8bc,
		"TBathWaterMeshRenderer::clearHeightMap": 0x801fbca4,
		"clearHeightMap": 0x801fbca4,
		"TBathWaterManager::load": 0x801fbe60,
		"TBathWaterManager::TBathWaterManager": 0x801fbef0,
		"TBathWater::TDrop::TDrop": 0x801fc074,
		"TBathWaterPreprocessor::~TBathWaterPreprocessor": 0x801fc078,
		"TBathWaterPreprocessor::perform": 0x801fc0ec,
		"Map::init_tobj_resource": 0x801fc154,
		"init_tobj_resource": 0x801fc154,
		"Map::draw_mist": 0x801fc210,
		"draw_mist": 0x801fc210,
		"@unnamed@::clearEFB_alpha": 0x801fc9dc,
		"clearEFB_alpha": 0x801fc9dc,
		"Map::drawCap": 0x801fcce8,
		"drawCap": 0x801fcce8,
		"TBathWaterGlobalParams::TBathWaterGlobalParams": 0x801fcde8,
		"TBathWaterParams::TBathWaterParams": 0x801fd2d4,
		"TBathWaterMeshRenderer::getHeight": 0x801fd730,
		"TBathWaterMeshRenderer::prerender": 0x801fd7f8,
		"JGeometry::SMatrix44C<float><float>::SMatrix44C": 0x801fe238,
		"SMatrix44C": 0x801fe238,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setLookDir": 0x801fe23c,
		"setLookDir": 0x801fe23c,
		"TBathWaterMeshRenderer::render": 0x801fe41c,
		"TBathWaterMeshRenderer::calcCoord": 0x801ff240,
		"calcCoord": 0x801ff240,
		"TBathWaterMeshRenderer::makeNormalMap": 0x801ff674,
		"makeNormalMap": 0x801ff674,
		"TBathWaterMeshRenderer::makeHeightMap": 0x801ff884,
		"makeHeightMap": 0x801ff884,
		"TBathWaterFlatRenderer::prerender": 0x801ff994,
		"TBathWaterFlatRenderer::getHeight": 0x801ff998,
		"TBathWaterFlatRenderer::render": 0x801ff9a0,
		"Map::__sinit_BathWaterManager_cpp": 0x80200308,
		"__sinit_BathWaterManager_cpp": 0x80200308,
		"TStickyStainManager::~TStickyStainManager": 0x8020060c,
		"TStickyStainManager::perform": 0x80200680,
		"GC2D::CLBCalcRatio": 0x80200684,
		"TCoord2D::update": 0x802006e0,
		"TCoord2D::setValue": 0x80200788,
		"setValue": 0x80200788,
		"TCoord2D::TCoord2D": 0x80200800,
		"TExPane::update": 0x80200820,
		"TExPane::TExPane": 0x80200abc,
		"TFlashPane::~TFlashPane": 0x80200b90,
		"TFlashPane::perform": 0x80200c04,
		"TMenuPlane::perform": 0x80200c74,
		"TMenuPlane::TMenuPlane": 0x80200e00,
		"TMenuBase::perform": 0x80200fd0,
		"TMenuPlane::~TMenuPlane": 0x80201068,
		"TMenuBase::~TMenuBase": 0x802010dc,
		"TSMSFader::setFadeStatus": 0x80201150,
		"setFadeStatus": 0x80201150,
		"TSMSFader::setDisplaySize": 0x80201198,
		"setDisplaySize": 0x80201198,
		"TSMSFader::load": 0x802011c0,
		"TSMSFader::setColor": 0x802012d8,
		"TSMSFader::startFadeoutT": 0x80201320,
		"startFadeoutT": 0x80201320,
		"TSMSFader::startFadeinT": 0x8020134c,
		"startFadeinT": 0x8020134c,
		"TSMSFader::startWipe": 0x80201378,
		"startWipe": 0x80201378,
		"TSMSFader::requestWipe": 0x80201388,
		"requestWipe": 0x80201388,
		"TSMSFader::drawFadeinout": 0x8020156c,
		"drawFadeinout": 0x8020156c,
		"TSMSFader::draw": 0x802017a0,
		"TSMSFader::update": 0x8020193c,
		"TSMSFader::perform": 0x80201a98,
		"TSMSFader::TSMSFader": 0x80201b20,
		"@unnamed@::draw_wipe_box": 0x80201be4,
		"draw_wipe_box": 0x80201be4,
		"@unnamed@::fill_rect": 0x80201ea8,
		"fill_rect": 0x80201ea8,
		"GC2D::__sinit_ScrnFader_cpp": 0x80201fe4,
		"__sinit_ScrnFader_cpp": 0x80201fe4,
		"TGCConsole2::~TGCConsole2": 0x802022e0,
		"TGCConsole2::perform": 0x80202354,
		"TGCConsole2::drawWater": 0x80206a00,
		"drawWater": 0x80206a00,
		"TGCConsole2::drawJuice": 0x80207060,
		"drawJuice": 0x80207060,
		"TGCConsole2::processDisappearBalloon": 0x802075a4,
		"processDisappearBalloon": 0x802075a4,
		"TGCConsole2::processAppearBalloon": 0x802076c0,
		"processAppearBalloon": 0x802076c0,
		"TGCConsole2::processAppearTimer": 0x802077d4,
		"processAppearTimer": 0x802077d4,
		"TGCConsole2::processAppearRed": 0x80207c60,
		"processAppearRed": 0x80207c60,
		"TGCConsole2::processAppearJet": 0x80207f78,
		"processAppearJet": 0x80207f78,
		"TGCConsole2::checkChangeTelopArray": 0x80208240,
		"checkChangeTelopArray": 0x80208240,
		"TGCConsole2::processDrawTelop": 0x80208524,
		"processDrawTelop": 0x80208524,
		"TGCConsole2::processAppearMario": 0x802085cc,
		"processAppearMario": 0x802085cc,
		"TGCConsole2::processAppearCoin": 0x802088f0,
		"processAppearCoin": 0x802088f0,
		"TGCConsole2::processAppearTank": 0x80208c54,
		"processAppearTank": 0x80208c54,
		"TGCConsole2::processDownCoin": 0x80208edc,
		"processDownCoin": 0x80208edc,
		"TGCConsole2::processAppearStar": 0x8020924c,
		"processAppearStar": 0x8020924c,
		"TBlendPane::setPaneBlend": 0x80209974,
		"setPaneBlend": 0x80209974,
		"TExPane::setPaneOffset": 0x80209a24,
		"setPaneOffset": 0x80209a24,
		"TCoord2D::roundf": 0x80209af0,
		"roundf": 0x80209af0,
		"TGCConsole2::processInsertLife": 0x80209b24,
		"processInsertLife": 0x80209b24,
		"TGCConsole2::processAppearLife": 0x80209ce8,
		"processAppearLife": 0x80209ce8,
		"TGCConsole2::getFinishedTime": 0x80209de0,
		"getFinishedTime": 0x80209de0,
		"TGCConsole2::stopMoveTimer": 0x80209de8,
		"stopMoveTimer": 0x80209de8,
		"TGCConsole2::startMoveTimer": 0x80209e00,
		"startMoveTimer": 0x80209e00,
		"TGCConsole2::setTimer": 0x80209e14,
		"setTimer": 0x80209e14,
		"TGCConsole2::processMoveNozzle": 0x8020a27c,
		"processMoveNozzle": 0x8020a27c,
		"TGCConsole2::startAppearMario": 0x8020a3bc,
		"startAppearMario": 0x8020a3bc,
		"TGCConsole2::startDisappearMario": 0x8020a5b0,
		"startDisappearMario": 0x8020a5b0,
		"TGCConsole2::drawWaterBack": 0x8020a6fc,
		"drawWaterBack": 0x8020a6fc,
		"TGCConsole2::startAppearStar": 0x8020af58,
		"startAppearStar": 0x8020af58,
		"TGCConsole2::startDisappearStar": 0x8020b324,
		"startDisappearStar": 0x8020b324,
		"TGCConsole2::startAppearBalloon": 0x8020b644,
		"startAppearBalloon": 0x8020b644,
		"TGCConsole2::startDisappearBalloon": 0x8020b900,
		"startDisappearBalloon": 0x8020b900,
		"TGCConsole2::pauseOut": 0x8020b958,
		"pauseOut": 0x8020b958,
		"TGCConsole2::pauseIn": 0x8020bcec,
		"pauseIn": 0x8020bcec,
		"TGCConsole2::startAppearRedCoin": 0x8020be18,
		"startAppearRedCoin": 0x8020be18,
		"TGCConsole2::startInsertJetBalloon": 0x8020bfbc,
		"startInsertJetBalloon": 0x8020bfbc,
		"TGCConsole2::startAppearJetBalloon": 0x8020c160,
		"startAppearJetBalloon": 0x8020c160,
		"TGCConsole2::startInsertTimer": 0x8020c28c,
		"startInsertTimer": 0x8020c28c,
		"TGCConsole2::startAppearTimer": 0x8020c428,
		"startAppearTimer": 0x8020c428,
		"TGCConsole2::startDisappearTimer": 0x8020c634,
		"startDisappearTimer": 0x8020c634,
		"TGCConsole2::startDisappearTelop": 0x8020c764,
		"startDisappearTelop": 0x8020c764,
		"TGCConsole2::startAppearTelop": 0x8020c8ac,
		"startAppearTelop": 0x8020c8ac,
		"TGCConsole2::startDownLeftBot": 0x8020ca84,
		"startDownLeftBot": 0x8020ca84,
		"TGCConsole2::startAppearLife": 0x8020ce48,
		"startAppearLife": 0x8020ce48,
		"TGCConsole2::resetLife": 0x8020d3b0,
		"resetLife": 0x8020d3b0,
		"TGCConsole2::startInsertLife": 0x8020d4b8,
		"startInsertLife": 0x8020d4b8,
		"TGCConsole2::startDisappearCoin": 0x8020d964,
		"startDisappearCoin": 0x8020d964,
		"TGCConsole2::startAppearCoin": 0x8020dc34,
		"startAppearCoin": 0x8020dc34,
		"TGCConsole2::startAppearTank": 0x8020dd70,
		"startAppearTank": 0x8020dd70,
		"TGCConsole2::endCameraDemo": 0x8020de94,
		"endCameraDemo": 0x8020de94,
		"TGCConsole2::startCameraDemo": 0x8020e0f8,
		"startCameraDemo": 0x8020e0f8,
		"TGCConsole2::entryHelpActor": 0x8020ed60,
		"entryHelpActor": 0x8020ed60,
		"TGCConsole2::loadAfter": 0x8020ee40,
		"TGCConsole2::load": 0x8021020c,
		"TGCConsole2::TGCConsole2": 0x802110cc,
		"JUTPoint::JUTPoint": 0x80211588,
		"GC2D::__sinit_GCConsole2_cpp": 0x802115d8,
		"__sinit_GCConsole2_cpp": 0x802115d8,
		"TTalk2D2::~TTalk2D2": 0x80211958,
		"TTalk2D2::openWindow": 0x802119cc,
		"openWindow": 0x802119cc,
		"TTalk2D2::setTagParam": 0x80211e98,
		"setTagParam": 0x80211e98,
		"TTalk2D2::setupTextBox": 0x80212a50,
		"setupTextBox": 0x80212a50,
		"TTalk2D2::setupBoardTextBox": 0x80212e28,
		"setupBoardTextBox": 0x80212e28,
		"TTalk2D2::perform": 0x802130a8,
		"TTalk2D2::eraseBoardWindow": 0x80213708,
		"eraseBoardWindow": 0x80213708,
		"TTalk2D2::eraseNormalWindow": 0x802137a0,
		"eraseNormalWindow": 0x802137a0,
		"TTalk2D2::closeNormalWindow": 0x802139ec,
		"closeNormalWindow": 0x802139ec,
		"TTalk2D2::checkControler": 0x80213bcc,
		"checkControler": 0x80213bcc,
		"TTalk2D2::moveTalkWindow": 0x80213ee8,
		"moveTalkWindow": 0x80213ee8,
		"TTalk2D2::checkBoardControler": 0x802141c0,
		"checkBoardControler": 0x802141c0,
		"TTalk2D2::moveBoardWindow": 0x80214378,
		"moveBoardWindow": 0x80214378,
		"TTalk2D2::openNormalWindow": 0x80214420,
		"openNormalWindow": 0x80214420,
		"TTalk2D2::openBoardWindow": 0x802146f0,
		"openBoardWindow": 0x802146f0,
		"TTalk2D2::makeBoxLine": 0x802147d4,
		"makeBoxLine": 0x802147d4,
		"TTalk2D2::openTalkWindow": 0x80214cf0,
		"openTalkWindow": 0x80214cf0,
		"TTalk2D2::forceCloseTalk": 0x80214f04,
		"forceCloseTalk": 0x80214f04,
		"TTalk2D2::setMessageID": 0x80214fa4,
		"setMessageID": 0x80214fa4,
		"TTalk2D2::loadAfter": 0x802153c0,
		"TTalk2D2::load": 0x80215930,
		"TTalk2D2::TTalk2D2": 0x80215cd8,
		"GC2D::__sinit_Talk2D2_cpp": 0x80215e78,
		"__sinit_Talk2D2_cpp": 0x80215e78,
		"TBoundPane::update": 0x80216174,
		"TBoundPane::setPaneSize": 0x802164f4,
		"TBoundPane::setPanePosition": 0x80216568,
		"setPanePosition": 0x80216568,
		"TBoundPane::TBoundPane": 0x802165dc,
		"TPauseMenu2::~TPauseMenu2": 0x802166e0,
		"TPauseMenu2::drawAppearPane": 0x80216754,
		"drawAppearPane": 0x80216754,
		"TPauseMenu2::setDrawEnd": 0x8021697c,
		"setDrawEnd": 0x8021697c,
		"TPauseMenu2::setDrawStart": 0x802169d4,
		"setDrawStart": 0x802169d4,
		"TPauseMenu2::getNextState": 0x80216ba4,
		"TPauseMenu2::perform": 0x80216c64,
		"TPauseMenu2::disappearWindow": 0x802175a4,
		"disappearWindow": 0x802175a4,
		"TPauseMenu2::appearWindow": 0x802179e0,
		"appearWindow": 0x802179e0,
		"TPauseMenu2::loadAfter": 0x80217d98,
		"TPauseMenu2::load": 0x80217fe8,
		"TPauseMenu2::TPauseMenu2": 0x80218318,
		"GC2D::__sinit_PauseMenu2_cpp": 0x8021842c,
		"__sinit_PauseMenu2_cpp": 0x8021842c,
		"TMessageLoader::getMessageEntry": 0x80218728,
		"getMessageEntry": 0x80218728,
		"TMessageLoader::parseBlock": 0x80218754,
		"parseBlock": 0x80218754,
		"JSUIosBase::JSUIosBase": 0x80218990,
		"TMessageLoader::loadMessageData": 0x802189a8,
		"loadMessageData": 0x802189a8,
		"TSwitchHelpActor::check": 0x80218b34,
		"TSwitchHelpActor::TSwitchHelpActor": 0x80218b68,
		"THelpActor::check": 0x80218c5c,
		"THelpActor::perform": 0x80218c7c,
		"THelpActor::loadAfter": 0x80218dd4,
		"THelpActor::load": 0x80218e80,
		"THelpActor::THelpActor": 0x80218f28,
		"GC2D::SMSGetMessageData": 0x80218f94,
		"SMSGetMessageData": 0x80218f94,
		"GC2D::SMSMakeTextBuffer": 0x8021927c,
		"SMSMakeTextBuffer": 0x8021927c,
		"TCardSave::~TCardSave": 0x8021935c,
		"TCardSave::getNextState": 0x802193d0,
		"TCardSave::execMovement_": 0x80219410,
		"execMovement_": 0x80219410,
		"TCardSave::waitForAnyKeyBM": 0x8021c6d0,
		"TCardSave::waitForSelect3": 0x8021cebc,
		"waitForSelect3": 0x8021cebc,
		"TCardSave::waitForSelect2": 0x8021d81c,
		"waitForSelect2": 0x8021d81c,
		"TCardSave::waitForSelectOver": 0x8021df14,
		"waitForSelectOver": 0x8021df14,
		"TCardSave::waitForAnyKey": 0x8021e52c,
		"TCardSave::drawMessageBM": 0x8021ea34,
		"TCardSave::drawMessage": 0x8021ef18,
		"TCardSave::waitForChoiceBM": 0x8021f230,
		"TCardSave::waitForChoice": 0x80220c74,
		"TCardSave::waitForStop": 0x80222628,
		"waitForStop": 0x80222628,
		"TCardSave::perform": 0x80222fb0,
		"TCardSave::init": 0x80223094,
		"TCardSave::initData": 0x80223160,
		"TCardSave::load": 0x80223ef4,
		"TCardSave::TCardSave": 0x80223f34,
		"TCardSave::changeMode": 0x80224134,
		"GC2D::__sinit_CardSave_cpp": 0x802241e4,
		"__sinit_CardSave_cpp": 0x802241e4,
		"TCardLoad::~TCardLoad": 0x802244e0,
		"TCardLoad::changeScene": 0x80224554,
		"changeScene": 0x80224554,
		"TCardLoad::setSelected": 0x80225b70,
		"setSelected": 0x80225b70,
		"TCardLoad::selectFunction": 0x80225be4,
		"selectFunction": 0x80225be4,
		"TCardLoad::selectBookmark": 0x802274f4,
		"selectBookmark": 0x802274f4,
		"TCardLoad::drawMessageBM": 0x802283e8,
		"TCardLoad::drawMessage": 0x80228bc0,
		"TCardLoad::waitForStart": 0x802290cc,
		"waitForStart": 0x802290cc,
		"TCardLoad::waitForAnyKeyBM": 0x80229a54,
		"TCardLoad::waitForAnyKey": 0x8022a2b4,
		"TCardLoad::waitForChoiceBM": 0x8022a810,
		"TCardLoad::waitForChoice": 0x8022b938,
		"TCardLoad::changeMode": 0x8022c7b0,
		"TCardLoad::titleDraw": 0x8022c88c,
		"titleDraw": 0x8022c88c,
		"TCardLoad::perform": 0x8022d1d4,
		"JSUInputStream::JSUInputStream": 0x8022df34,
		"TCardLoad::loadAfter": 0x8022df58,
		"TCardLoad::setupScoreScreen": 0x8022e05c,
		"setupScoreScreen": 0x8022e05c,
		"TCardLoad::load": 0x8022eaa8,
		"TCardLoad::TCardLoad": 0x8022fd84,
		"GC2D::__sinit_CardLoad_cpp": 0x80230004,
		"__sinit_CardLoad_cpp": 0x80230004,
		"TConsoleStr::~TConsoleStr": 0x80230300,
		"TConsoleStr::startOpenWipe": 0x80230374,
		"startOpenWipe": 0x80230374,
		"TConsoleStr::startCloseWipe": 0x80230534,
		"startCloseWipe": 0x80230534,
		"TConsoleStr::processScenario": 0x80230ac8,
		"processScenario": 0x80230ac8,
		"TConsoleStr::processMiss": 0x80230b98,
		"processMiss": 0x80230b98,
		"TConsoleStr::processShineGet": 0x80230ef8,
		"processShineGet": 0x80230ef8,
		"TConsoleStr::processGo": 0x80231200,
		"processGo": 0x80231200,
		"TConsoleStr::processReady": 0x80231894,
		"processReady": 0x80231894,
		"TConsoleStr::startAppearScenario": 0x80231dcc,
		"startAppearScenario": 0x80231dcc,
		"TConsoleStr::startAppearMiss": 0x80231f10,
		"startAppearMiss": 0x80231f10,
		"TConsoleStr::startAppearShineGet": 0x80232048,
		"startAppearShineGet": 0x80232048,
		"TConsoleStr::startAppearGo": 0x80232070,
		"startAppearGo": 0x80232070,
		"TConsoleStr::startAppearReady": 0x802320e4,
		"startAppearReady": 0x802320e4,
		"TConsoleStr::perform": 0x80232158,
		"TConsoleStr::loadAfter": 0x80232894,
		"TConsoleStr::load": 0x802328d0,
		"TConsoleStr::getWipeCloseTime": 0x80232c90,
		"getWipeCloseTime": 0x80232c90,
		"TConsoleStr::TConsoleStr": 0x80232cb8,
		"GC2D::__sinit_ConsoleStr_cpp": 0x80232d6c,
		"__sinit_ConsoleStr_cpp": 0x80232d6c,
		"TSelectMenu::~TSelectMenu": 0x80232dd4,
		"TSelectMenu::startOpenWindow": 0x80232e48,
		"startOpenWindow": 0x80232e48,
		"TSelectMenu::getPrevIndex": 0x80233094,
		"getPrevIndex": 0x80233094,
		"TSelectMenu::getNextIndex": 0x802330ec,
		"getNextIndex": 0x802330ec,
		"TSelectMenu::perform": 0x80233148,
		"TSelectMenu::startMove": 0x80234954,
		"startMove": 0x80234954,
		"TSelectMenu::initData": 0x802349b4,
		"TSelectMenu::TSelectMenu": 0x80235998,
		"TSelectGrad::perform": 0x80235b28,
		"TSelectGrad::setStageColor": 0x80235ee4,
		"setStageColor": 0x80235ee4,
		"TSelectGrad::TSelectGrad": 0x80236014,
		"TSelectGrad::~TSelectGrad": 0x8023611c,
		"GC2D::__sinit_SelectMenu_cpp": 0x80236190,
		"__sinit_SelectMenu_cpp": 0x80236190,
		"TSelectDir::direct": 0x8023648c,
		"TSelectDir::changeOrder": 0x80236750,
		"changeOrder": 0x80236750,
		"TSelectDir::rsetup": 0x80236778,
		"TSelectDir::setupThreadFunc": 0x802378a8,
		"TSelectDir::setup": 0x802378c8,
		"TSelectDir::TSelectDir": 0x80237a00,
		"GC2D::__sinit_SelectDir_cpp": 0x80237ac8,
		"__sinit_SelectDir_cpp": 0x80237ac8,
		"TSelectShine::~TSelectShine": 0x80237dcc,
		"TSelectShine::move": 0x80237e18,
		"TSelectShine::TSelectShine": 0x802382e8,
		"TSelectShineManager::perform": 0x802385a0,
		"JGeometry::TVec2<float><float>::sub": 0x80238a3c,
		"GC2D::JMASSin": 0x80238a70,
		"GC2D::JMASCos": 0x80238a8c,
		"TSelectShineManager::startDecrease": 0x80238aa8,
		"startDecrease": 0x80238aa8,
		"TSelectShineManager::startIncrease": 0x80238bac,
		"startIncrease": 0x80238bac,
		"TSelectShineManager::startClose": 0x80238cb0,
		"startClose": 0x80238cb0,
		"TSelectShineManager::initData": 0x80238dcc,
		"TSelectShineManager::TSelectShineManager": 0x80239334,
		"TSelectShineManager::~TSelectShineManager": 0x802393f8,
		"GC2D::__sinit_SelectShine2_cpp": 0x8023946c,
		"__sinit_SelectShine2_cpp": 0x8023946c,
		"TBlendPane::update": 0x8023948c,
		"TBlendPane::TBlendPane": 0x8023958c,
		"TGuide::~TGuide": 0x802395dc,
		"TGuide::perform": 0x80239650,
		"TExPane::setPaneSize": 0x80239d70,
		"TExPane::setPaneAlpha": 0x80239e34,
		"setPaneAlpha": 0x80239e34,
		"TGuide::appearGuidePane": 0x80239ed4,
		"appearGuidePane": 0x80239ed4,
		"TGuide::placeMario": 0x8023a28c,
		"placeMario": 0x8023a28c,
		"TGuide::changeBotStatus": 0x8023a4e0,
		"changeBotStatus": 0x8023a4e0,
		"TGuide::checkPoint": 0x8023ab3c,
		"checkPoint": 0x8023ab3c,
		"TGuide::linkSelect": 0x8023ac70,
		"linkSelect": 0x8023ac70,
		"TGuide::startMoveCursor": 0x8023b8d0,
		"startMoveCursor": 0x8023b8d0,
		"TGuide::setup": 0x8023b8e4,
		"TGuide::resetScore": 0x8023b940,
		"resetScore": 0x8023b940,
		"TGuide::resetObjects": 0x8023c278,
		"resetObjects": 0x8023c278,
		"TGuide::load": 0x8023c600,
		"TGuide::TGuide": 0x8023d004,
		"GC2D::__sinit_Guide_cpp": 0x8023d148,
		"__sinit_Guide_cpp": 0x8023d148,
		"TSunShine::~TSunShine": 0x8023d444,
		"TSunShine::loadAfter": 0x8023d4c8,
		"TSunShine::perform": 0x8023d524,
		"TSunGlass::load": 0x8023d600,
		"TSunGlass::loadAfter": 0x8023d63c,
		"TSunGlass::perform": 0x8023d6e4,
		"TSunGlass::draw": 0x8023d7d4,
		"TSunGlass::startFade": 0x8023d9f4,
		"startFade": 0x8023d9f4,
		"TShineFader::~TShineFader": 0x8023db6c,
		"TShineFader::load": 0x8023dc00,
		"TShineFader::registFadeout": 0x8023dc20,
		"registFadeout": 0x8023dc20,
		"TShineFader::perform": 0x8023dc64,
		"TShineFader::update": 0x8023dce0,
		"TProgSelect::~TProgSelect": 0x8023dd7c,
		"TProgSelect::perform": 0x8023ddf0,
		"TProgSelect::TProgSelect": 0x8023e108,
		"GC2D::Hx_Test5": 0x8023e2fc,
		"Hx_Test5": 0x8023e2fc,
		"GC2D::Hx_Test4": 0x8023e7f4,
		"Hx_Test4": 0x8023e7f4,
		"GC2D::Hxs1_Test2": 0x8023eb98,
		"Hxs1_Test2": 0x8023eb98,
		"GC2D::Hx_Test2R": 0x8023ee78,
		"Hx_Test2R": 0x8023ee78,
		"GC2D::Hx_Test2": 0x8023f2a4,
		"Hx_Test2": 0x8023f2a4,
		"GC2D::Hxs1_Test1": 0x8023f694,
		"Hxs1_Test1": 0x8023f694,
		"GC2D::Hx_Test1": 0x8023f8a8,
		"Hx_Test1": 0x8023f8a8,
		"GC2D::Hx_MovieStartSyncEx": 0x8023fa48,
		"Hx_MovieStartSyncEx": 0x8023fa48,
		"GC2D::Hx_Logo": 0x8023faec,
		"Hx_Logo": 0x8023faec,
		"GC2D::Hxs_PenDraw": 0x8023fed8,
		"Hxs_PenDraw": 0x8023fed8,
		"GC2D::Hxs_Logo_MagDraw": 0x802400b0,
		"Hxs_Logo_MagDraw": 0x802400b0,
		"GC2D::Hxs_Logo_TexDraw": 0x80240258,
		"Hxs_Logo_TexDraw": 0x80240258,
		"GC2D::Hxs_Logo_TexSetup": 0x80240484,
		"Hxs_Logo_TexSetup": 0x80240484,
		"GC2D::Hxs_Logo_ExtraDraw": 0x8024060c,
		"Hxs_Logo_ExtraDraw": 0x8024060c,
		"GC2D::Hx_GameOver": 0x80240794,
		"Hx_GameOver": 0x80240794,
		"GC2D::Hxs_GameOver": 0x80240bac,
		"Hxs_GameOver": 0x80240bac,
		"GC2D::Hx_Door": 0x80241108,
		"Hx_Door": 0x80241108,
		"GC2D::Hxs_FrBufferMorf2B": 0x802412ec,
		"Hxs_FrBufferMorf2B": 0x802412ec,
		"GC2D::Hxs_FrBufferMorf2": 0x802414f8,
		"Hxs_FrBufferMorf2": 0x802414f8,
		"GC2D::Hxs2_Circle": 0x8024175c,
		"Hxs2_Circle": 0x8024175c,
		"GC2D::Hxs1_Circle": 0x80241b2c,
		"Hxs1_Circle": 0x80241b2c,
		"GC2D::Hx_Circle": 0x80241e3c,
		"Hx_Circle": 0x80241e3c,
		"GC2D::Hx_MotionUpdate": 0x802420fc,
		"Hx_MotionUpdate": 0x802420fc,
		"GC2D::Hx_MotionSet": 0x80242168,
		"Hx_MotionSet": 0x80242168,
		"GC2D::Hx_TimerCountDown": 0x802421e0,
		"Hx_TimerCountDown": 0x802421e0,
		"GC2D::Hx_UpdateWipe": 0x80242208,
		"Hx_UpdateWipe": 0x80242208,
		"GC2D::Hx_GetWipeType": 0x80242348,
		"Hx_GetWipeType": 0x80242348,
		"GC2D::dummy_handler": 0x8024235c,
		"dummy_handler": 0x8024235c,
		"GC2D::Hx_StartWipe": 0x80242360,
		"Hx_StartWipe": 0x80242360,
		"GC2D::Hx_RemoveResource": 0x802423fc,
		"Hx_RemoveResource": 0x802423fc,
		"GC2D::Hx_ProvideResourceEx": 0x80242468,
		"Hx_ProvideResourceEx": 0x80242468,
		"GC2D::Hx_ProvideResource": 0x802424c0,
		"Hx_ProvideResource": 0x802424c0,
		"GC2D::Hx_ResetWipe": 0x80242548,
		"Hx_ResetWipe": 0x80242548,
		"GC2D::Hx_Warning": 0x80242584,
		"Hx_Warning": 0x80242584,
		"GC2D::Frb2_RendBox": 0x80242588,
		"Frb2_RendBox": 0x80242588,
		"GC2D::Frb2_InitBlackBox": 0x80242638,
		"Frb2_InitBlackBox": 0x80242638,
		"GC2D::Frb2_InitGx": 0x802426c0,
		"Frb2_InitGx": 0x802426c0,
		"GC2D::Hx_FrBufferMorf": 0x80242800,
		"Hx_FrBufferMorf": 0x80242800,
		"GC2D::__Hx_FrBufferMorf": 0x8024283c,
		"__Hx_FrBufferMorf": 0x8024283c,
		"GC2D::Hx_SetVFilter": 0x80242aac,
		"Hx_SetVFilter": 0x80242aac,
		"GC2D::Hx_GetFrBuffer": 0x80242da8,
		"Hx_GetFrBuffer": 0x80242da8,
		"GC2D::Hgx_ReadTexture": 0x80242e58,
		"Hgx_ReadTexture": 0x80242e58,
		"GC2D::Hgx_init_tobj_resource": 0x80242ee0,
		"Hgx_init_tobj_resource": 0x80242ee0,
		"GC2D::Hx_GxInit": 0x80242f80,
		"Hx_GxInit": 0x80242f80,
		"GC2D::Hx_CameraInit": 0x802430e8,
		"Hx_CameraInit": 0x802430e8,
		"TMovieSubTitle::~TMovieSubTitle": 0x802432bc,
		"TMovieSubTitle::setCurMessage": 0x80243330,
		"setCurMessage": 0x80243330,
		"TMovieSubTitle::perform": 0x802433c8,
		"TMovieSubTitle::setupResource": 0x8024355c,
		"setupResource": 0x8024355c,
		"TMovieSubTitle::TMovieSubTitle": 0x802436f0,
		"TOptionControl::resetChangedSetting": 0x80243778,
		"resetChangedSetting": 0x80243778,
		"TOptionControl::isChangedSetting": 0x802437e4,
		"isChangedSetting": 0x802437e4,
		"MSound::startSoundSystemSE": 0x80243874,
		"TOptionControl::setType": 0x802438e0,
		"setType": 0x802438e0,
		"TOptionControl::movementOption2Card": 0x802439e8,
		"movementOption2Card": 0x802439e8,
		"TOptionControl::movementOption": 0x80243ae0,
		"movementOption": 0x80243ae0,
		"JGeometry::TUtil<int><int>::mod": 0x80243dcc,
		"JGeometry::TUtil<long><long>::clamp": 0x80243e0c,
		"clamp": 0x80243e0c,
		"TOptionControl::movementCard2Option": 0x80243e2c,
		"movementCard2Option": 0x80243e2c,
		"TOptionControl::draw": 0x80243f50,
		"TOptionControl::loadSetting": 0x80243f80,
		"loadSetting": 0x80243f80,
		"TOptionControl::load": 0x80244350,
		"TOptionSoundUnit::setInfluencedAlphaRecursive": 0x8024450c,
		"JSUTree<J2DPane>::getObject": 0x802445f8,
		"getObject": 0x802445f8,
		"TOptionSoundUnit::adjustSound": 0x80244600,
		"adjustSound": 0x80244600,
		"TOptionSoundUnit::adjustView": 0x802446a0,
		"TOptionSoundUnit::setState": 0x80244ab4,
		"TOptionSoundUnit::typeToFlag": 0x80244fc0,
		"typeToFlag": 0x80244fc0,
		"TOptionSoundUnit::flagToType": 0x80244ffc,
		"flagToType": 0x80244ffc,
		"TOptionSoundUnit::adjust": 0x80245038,
		"TOptionSoundUnit::update": 0x80245094,
		"TOptionSoundUnit::initSurroundAnm": 0x80245368,
		"initSurroundAnm": 0x80245368,
		"TOptionSoundUnit::initSteleoAnm": 0x802456e0,
		"initSteleoAnm": 0x802456e0,
		"TOptionSoundUnit::TOptionSoundUnit": 0x80245910,
		"@unnamed@::ArrayWrapper<TPatternAnmControl*>::ArrayWrapper": 0x80245ed4,
		"ArrayWrapper": 0x80245ed4,
		"TOptionRumbleUnit::setInfluencedAlphaRecursive": 0x80245ee4,
		"TOptionRumbleUnit::setState": 0x80245fd0,
		"TOptionRumbleUnit::adjustView": 0x80246534,
		"TOptionRumbleUnit::adjust": 0x80246648,
		"TOptionRumbleUnit::update": 0x80246794,
		"TOptionRumbleUnit::TOptionRumbleUnit": 0x80246b58,
		"TToggleControl::toggle": 0x8024717c,
		"toggle": 0x8024717c,
		"TPatternAnmControl::hide": 0x80247214,
		"hide": 0x80247214,
		"TPatternAnmControl::show": 0x80247290,
		"show": 0x80247290,
		"TPatternAnmControl::update": 0x80247330,
		"TPatternAnmControl::setupAnm": 0x80247440,
		"setupAnm": 0x80247440,
		"GC2D::__sinit_Option_cpp": 0x8024756c,
		"__sinit_Option_cpp": 0x8024756c,
		"TMovieRumble::~TMovieRumble": 0x80247868,
		"TMovieRumble::checkRumbleOff": 0x802478dc,
		"checkRumbleOff": 0x802478dc,
		"TMovieRumble::perform": 0x802479e8,
		"TMovieRumble::init": 0x80247a68,
		"TMovieRumble::TMovieRumble": 0x80247bc8,
		"TConductor::perform": 0x80247c44,
		"TConductor::searchF": 0x802480b4,
		"TConductor::genEnemyFromPollution": 0x802482c8,
		"genEnemyFromPollution": 0x802482c8,
		"TConductor::killEnemiesWithin": 0x80248614,
		"killEnemiesWithin": 0x80248614,
		"TConductor::makeOneEnemyAppear": 0x802486ec,
		"makeOneEnemyAppear": 0x802486ec,
		"TConductor::makeEnemyAppear": 0x80248880,
		"makeEnemyAppear": 0x80248880,
		"TConductor::isBossDefeated": 0x80248aac,
		"isBossDefeated": 0x80248aac,
		"TConductor::getManagerByName": 0x80248c8c,
		"getManagerByName": 0x80248c8c,
		"TConductor::getGraphByName": 0x80248d48,
		"TConductor::init": 0x80248d7c,
		"TConductor::registerEnemyInfoTable": 0x80248eac,
		"registerEnemyInfoTable": 0x80248eac,
		"TConductor::registerSDLModelData": 0x80248eb4,
		"registerSDLModelData": 0x80248eb4,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::insert": 0x80248efc,
		"TConductor::registerAreaCylinderManager": 0x80248fb4,
		"registerAreaCylinderManager": 0x80248fb4,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::insert": 0x80248ffc,
		"TConductor::registerGenerator": 0x802490b4,
		"registerGenerator": 0x802490b4,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::insert": 0x802490fc,
		"TConductor::registerOtherObj": 0x802491b4,
		"registerOtherObj": 0x802491b4,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::insert": 0x802491fc,
		"TConductor::registerAloneActor": 0x802492b4,
		"registerAloneActor": 0x802492b4,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::insert": 0x802492fc,
		"TConductor::registerEnemyManager": 0x802493b4,
		"registerEnemyManager": 0x802493b4,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::insert": 0x802493fc,
		"TConductor::registerManager": 0x802494b4,
		"registerManager": 0x802494b4,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::insert": 0x802494fc,
		"TConductor::initGraphGroup": 0x802495b4,
		"TConductor::makeGraphGroup": 0x802495d8,
		"makeGraphGroup": 0x802495d8,
		"TConductor::~TConductor": 0x80249634,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::erase": 0x80249a58,
		"JGadget::TList<P12TLiveManager,Q27JGadget27TAllocator<P12TLiveManager>>::iterator::iterator": 0x80249ac4,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::erase": 0x80249ae4,
		"JGadget::TList<P13TEnemyManager,Q27JGadget28TAllocator<P13TEnemyManager>>::iterator::iterator": 0x80249b50,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::erase": 0x80249b70,
		"JGadget::TList<P10TLiveActor,Q27JGadget25TAllocator<P10TLiveActor>>::iterator::iterator": 0x80249bdc,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::erase": 0x80249bfc,
		"JGadget::TList<PQ26JDrama8TViewObj,Q27JGadget31TAllocator<PQ26JDrama8TViewObj>>::iterator::iterator": 0x80249c68,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::erase": 0x80249c88,
		"JGadget::TList<P20TAreaCylinderManager,Q27JGadget35TAllocator<P20TAreaCylinderManager>>::iterator::iterator": 0x80249cf4,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::erase": 0x80249d14,
		"JGadget::TList<P10TGenerator,Q27JGadget25TAllocator<P10TGenerator>>::iterator::iterator": 0x80249d80,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::erase": 0x80249da0,
		"JGadget::TList<P12SDLModelData,Q27JGadget27TAllocator<P12SDLModelData>>::iterator::iterator": 0x80249e0c,
		"TConductor::TConductor": 0x80249e14,
		"TEffectModel::control": 0x8024a078,
		"TEffectExplosion::generate": 0x8024a100,
		"TEffectExplosion::reset": 0x8024a260,
		"TEffectExplosion::init": 0x8024a384,
		"TEffectExplosionManager::createModelData": 0x8024a4a8,
		"TEffectExplosionManager::createEnemyInstance": 0x8024a4dc,
		"TEffectExplosionManager::loadAfter": 0x8024a54c,
		"TEffectExplosionManager::load": 0x8024a610,
		"TEffectExplosionManager::TEffectExplosionManager": 0x8024a67c,
		"TEffectModelManager::~TEffectModelManager": 0x8024a6c4,
		"TEffectColumSand::generate": 0x8024a728,
		"TEffectColumSand::reset": 0x8024a7e0,
		"TEffectColumSand::init": 0x8024a914,
		"TEffectColumSandManager::createModelData": 0x8024a9dc,
		"TEffectColumSandManager::createEnemyInstance": 0x8024aa10,
		"TEffectColumSandManager::loadAfter": 0x8024aa80,
		"TEffectColumSandManager::load": 0x8024aad8,
		"TEffectColumSandManager::TEffectColumSandManager": 0x8024ab44,
		"TEffectBombColumWater::generate": 0x8024ab8c,
		"TEffectBombColumWater::reset": 0x8024acf0,
		"TEffectBombColumWater::init": 0x8024ae44,
		"TEffectBombColumWaterManager::createModelData": 0x8024af18,
		"TEffectBombColumWaterManager::createEnemyInstance": 0x8024af4c,
		"TEffectBombColumWaterManager::loadAfter": 0x8024afbc,
		"TEffectBombColumWaterManager::load": 0x8024b080,
		"TEffectBombColumWaterManager::TEffectBombColumWaterManager": 0x8024b0ec,
		"TEffectColumWater::generate": 0x8024b134,
		"TEffectColumWater::reset": 0x8024b26c,
		"TEffectColumWater::init": 0x8024b3c0,
		"TEffectColumWaterManager::createModelData": 0x8024b494,
		"TEffectColumWaterManager::createEnemyInstance": 0x8024b4c8,
		"TEffectColumWaterManager::loadAfter": 0x8024b538,
		"TEffectColumWaterManager::load": 0x8024b5c4,
		"TEffectColumWaterManager::TEffectColumWaterManager": 0x8024b630,
		"TEffectModel::calcRootMatrix": 0x8024b678,
		"TEffectModel::moveObject": 0x8024b76c,
		"TEffectModel::reset": 0x8024b7d0,
		"TEffectModel::init": 0x8024b894,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::insert": 0x8024b900,
		"TEffectObjManager::perform": 0x8024b9b8,
		"TEffectObjManager::load": 0x8024ba8c,
		"TEffectObjManager::TEffectObjManager": 0x8024baac,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::erase": 0x8024bbc4,
		"TEffectObjBase::behaveToWater": 0x8024bc30,
		"TEffectObjBase::moveObject": 0x8024bd18,
		"TEffectObjBase::receiveMessage": 0x8024bee8,
		"TEffectObjBase::perform": 0x8024bf28,
		"TEffectObjBase::reset": 0x8024bf80,
		"TEffectObjBase::init": 0x8024bfac,
		"TEffectObjBase::load": 0x8024c00c,
		"TEffectObjBase::TEffectObjBase": 0x8024c094,
		"TEffectBiancoFunsui::emitEffect": 0x8024c0ec,
		"TEffectBiancoFunsui::loadAfter": 0x8024c1bc,
		"TEffectPinnaFunsui::emitEffect": 0x8024c22c,
		"TEffectPinnaFunsui::loadAfter": 0x8024c2fc,
		"TSimpleEffect::perform": 0x8024c36c,
		"TEffectExplosionManager::~TEffectExplosionManager": 0x8024c3a0,
		"TEffectColumSandManager::~TEffectColumSandManager": 0x8024c498,
		"TEffectBombColumWaterManager::~TEffectBombColumWaterManager": 0x8024c590,
		"TEffectColumWaterManager::~TEffectColumWaterManager": 0x8024c688,
		"TEffectObjManager::~TEffectObjManager": 0x8024c6fc,
		"JGadget::TList<P14TEffectObjBase,Q27JGadget29TAllocator<P14TEffectObjBase>>::iterator::iterator": 0x8024c808,
		"Enemy::__sinit_effectObj_cpp": 0x8024c99c,
		"__sinit_effectObj_cpp": 0x8024c99c,
		"TEMarioManager::~TEMarioManager": 0x8024cce0,
		"TEMarioManager::createEnemyInstance": 0x8024cd44,
		"TEMarioManager::load": 0x8024cda0,
		"TEMarioManager::TEMarioManager": 0x8024ce0c,
		"TEMario::perform": 0x8024ce48,
		"TEMario::forceDisappear": 0x8024d138,
		"forceDisappear": 0x8024d138,
		"TEMario::startGateDrawing": 0x8024d160,
		"TEMario::startMonteReplay": 0x8024d184,
		"TEMario::startRunAway": 0x8024d1a8,
		"TEMario::isDownWaitingToTalk": 0x8024d1cc,
		"isDownWaitingToTalk": 0x8024d1cc,
		"TEMario::isReachedToGate": 0x8024d1ec,
		"isReachedToGate": 0x8024d1ec,
		"TEMario::isGoal": 0x8024d20c,
		"isGoal": 0x8024d20c,
		"TEMario::kill": 0x8024d22c,
		"TEMario::receiveMessage": 0x8024d26c,
		"TEMario::init": 0x8024d300,
		"TEMario::loadAfter": 0x8024d4b4,
		"TEMario::load": 0x8024d510,
		"TEMario::TEMario": 0x8024d7e0,
		"Enemy::__sinit_emario_cpp": 0x8024d890,
		"__sinit_emario_cpp": 0x8024d890,
		"TSpineEnemy::perform": 0x8024db94,
		"TSpineEnemy::checkCurAnmEnd": 0x8024dc58,
		"checkCurAnmEnd": 0x8024dc58,
		"TSpineEnemy::getCurAnmFrameNo": 0x8024dcf4,
		"getCurAnmFrameNo": 0x8024dcf4,
		"TSpineEnemy::doShortCut": 0x8024dd90,
		"doShortCut": 0x8024dd90,
		"TSpineEnemy::zigzagToCurPathNode": 0x8024e0b0,
		"zigzagToCurPathNode": 0x8024e0b0,
		"TSpineEnemy::walkToCurPathNode": 0x8024e5e0,
		"walkToCurPathNode": 0x8024e5e0,
		"TSpineEnemy::turnToCurPathNode": 0x8024eac4,
		"turnToCurPathNode": 0x8024eac4,
		"TSpineEnemy::goToDirLimitedNextGraphNode": 0x8024eca8,
		"goToDirLimitedNextGraphNode": 0x8024eca8,
		"TSpineEnemy::goToDirectedNextGraphNode": 0x8024ee58,
		"goToDirectedNextGraphNode": 0x8024ee58,
		"TSpineEnemy::goToExclusiveNextGraphNode": 0x8024ef6c,
		"goToExclusiveNextGraphNode": 0x8024ef6c,
		"JGeometry::TVec3<float><float>::operator_=": 0x8024f1b8,
		"TSpineEnemy::goToRandomEscapeGraphNode": 0x8024f1d4,
		"goToRandomEscapeGraphNode": 0x8024f1d4,
		"TSpineEnemy::goToRandomNextGraphNode": 0x8024f2dc,
		"goToRandomNextGraphNode": 0x8024f2dc,
		"TSpineEnemy::jumpToNextGraphNode": 0x8024f3e0,
		"jumpToNextGraphNode": 0x8024f3e0,
		"TSpineEnemy::goToShortestNextGraphNode": 0x8024f500,
		"goToShortestNextGraphNode": 0x8024f500,
		"TSpineEnemy::setGoalPathFromGraph": 0x8024f624,
		"setGoalPathFromGraph": 0x8024f624,
		"TSpineEnemy::isInSight": 0x8024f6d0,
		"isInSight": 0x8024f6d0,
		"TSpineEnemy::receiveMessage": 0x8024f704,
		"TSpineEnemy::updateSquareToMario": 0x8024f764,
		"updateSquareToMario": 0x8024f764,
		"TSpineEnemy::calcTurnSpeedToReach": 0x8024f79c,
		"calcTurnSpeedToReach": 0x8024f79c,
		"TSpineEnemy::calcMinimumTurnRadius": 0x8024f87c,
		"calcMinimumTurnRadius": 0x8024f87c,
		"TSpineEnemy::resetSRTV": 0x8024f910,
		"resetSRTV": 0x8024f910,
		"TSpineEnemy::resetToPosition": 0x8024fa5c,
		"resetToPosition": 0x8024fa5c,
		"TSpineEnemy::getSaveParam": 0x8024fb68,
		"TSpineEnemy::calcRootMatrix": 0x8024fb74,
		"TSpineEnemy::calcEnemyRootMatrix": 0x8024fc10,
		"calcEnemyRootMatrix": 0x8024fc10,
		"TSpineEnemy::load": 0x8024ffcc,
		"TSpineEnemy::reset": 0x80250090,
		"TSpineEnemy::init": 0x80250148,
		"TSpineEnemy::TSpineEnemy": 0x80250238,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::~TSolidStack": 0x802503c4,
		"TSolidStack<TPathNode>::~TSolidStack": 0x80250410,
		"TPathNode::TPathNode": 0x8025045c,
		"TSpineBase<TLiveActor>::~TSpineBase": 0x80250478,
		"~TSpineBase": 0x80250478,
		"Enemy::__sinit_enemy_cpp": 0x802504d8,
		"__sinit_enemy_cpp": 0x802504d8,
		"TEnemyPolluteModel::~TEnemyPolluteModel": 0x802507dc,
		"TEnemyPolluteModel::setAnm": 0x80250850,
		"TEnemyPolluteModel::perform": 0x80250854,
		"TEnemyPolluteModel::TEnemyPolluteModel": 0x80250938,
		"TEnemyPolluteModelManager::generatePolluteModel": 0x80250a08,
		"generatePolluteModel": 0x80250a08,
		"TEnemyPolluteModelManager::perform": 0x80250b90,
		"TEnemyPolluteModelManager::init": 0x80250ca0,
		"TEnemyAttachment::perform": 0x80250cd8,
		"TEnemyAttachment::behaveToHost": 0x80250dfc,
		"TEnemyAttachment::calcRootMatrix": 0x80250e00,
		"TEnemyAttachment::sendMessage": 0x80250ea4,
		"TEnemyAttachment::moveObject": 0x80250f58,
		"TEnemyAttachment::set": 0x80250fdc,
		"TEnemyAttachment::kill": 0x80251018,
		"TEnemyAttachment::rebirth": 0x80251034,
		"TEnemyAttachment::bind": 0x80251058,
		"TEnemyAttachment::setBehavior": 0x802512d8,
		"TEnemyAttachment::getNowGravity": 0x802512dc,
		"TEnemyAttachment::recoverScale": 0x802512e4,
		"TEnemyAttachment::forceKill": 0x80251330,
		"TEnemyAttachment::behaveToHitWall": 0x802513e8,
		"TEnemyAttachment::behaveToHitGround": 0x80251414,
		"TEnemyAttachment::loadInit": 0x80251468,
		"TEnemyAttachment::TEnemyAttachment": 0x802514e4,
		"TEnemyPolluteModelManager::~TEnemyPolluteModelManager": 0x80251544,
		"TEnemyAttachment::appear": 0x80251624,
		"TEnemyAttachment::receiveMessage": 0x80251640,
		"TEnemyManager::copyAnmMtx": 0x80251650,
		"copyAnmMtx": 0x80251650,
		"TEnemyManager::countLivingEnemy": 0x80251804,
		"countLivingEnemy": 0x80251804,
		"TEnemyManager::killChildrenWithin": 0x8025186c,
		"killChildrenWithin": 0x8025186c,
		"TEnemyManager::killChildren": 0x80251944,
		"killChildren": 0x80251944,
		"TEnemyManager::getFarOutEnemy": 0x8025197c,
		"getFarOutEnemy": 0x8025197c,
		"TEnemyManager::getDeadEnemy": 0x80251a1c,
		"getDeadEnemy": 0x80251a1c,
		"TEnemyManager::getNearestEnemy": 0x80251a84,
		"getNearestEnemy": 0x80251a84,
		"TEnemyManager::perform": 0x80251b44,
		"TEnemyManager::performShared": 0x80251dc8,
		"performShared": 0x80251dc8,
		"TEnemyManager::copyFromShared": 0x802521bc,
		"copyFromShared": 0x802521bc,
		"TEnemyManager::updateAnmSoundShared": 0x8025242c,
		"updateAnmSoundShared": 0x8025242c,
		"TEnemyManager::setSharedFlags": 0x80252584,
		"setSharedFlags": 0x80252584,
		"TEnemyManager::clipEnemies": 0x80252664,
		"TEnemyManager::createEnemies": 0x802526a8,
		"TEnemyManager::createEnemyInstance": 0x802527fc,
		"TEnemyManager::load": 0x80252804,
		"TEnemyManager::getSharedMActorSet": 0x80252860,
		"getSharedMActorSet": 0x80252860,
		"TEnemyManager::createSharedMActorSet": 0x802528a8,
		"createSharedMActorSet": 0x802528a8,
		"TSharedMActorSet::TSharedMActorSet": 0x80252994,
		"TEnemyManager::~TEnemyManager": 0x802529a8,
		"TEnemyManager::TEnemyManager": 0x80252a3c,
		"TSharedMActorSet::init": 0x80252ab4,
		"TSpineEnemyParams::TSpineEnemyParams": 0x80252c1c,
		"Enemy::__sinit_enemymanager_cpp": 0x80252e00,
		"__sinit_enemymanager_cpp": 0x80252e00,
		"TEnemyMario::perform": 0x802531d8,
		"TEnemyMario::drawHPMeter": 0x80253778,
		"drawHPMeter": 0x80253778,
		"TEnemyMario::damageExec": 0x80253a1c,
		"TEnemyMario::playerControl": 0x80253a20,
		"TEnemyMario::checkController": 0x80253ac0,
		"TEnemyMario::checkReturn": 0x8025407c,
		"TEnemyMario::reachGoal": 0x802541b4,
		"reachGoal": 0x802541b4,
		"TEnemyMario::thinkTrample": 0x802541d4,
		"thinkTrample": 0x802541d4,
		"TEnemyMario::hitWater": 0x80254230,
		"TEnemyMario::consider": 0x802543e4,
		"consider": 0x802543e4,
		"JGeometry::TRotation3<JGeometry::TMatrix44<JGeometry::SMatrix44C<float><float>>>::TRotation3": 0x80254c3c,
		"TPathNode::getPoint": 0x80254c40,
		"TEnemyMario::startGateDrawing": 0x80254c5c,
		"TEnemyMario::emWaitingToInviteMario": 0x80254cc0,
		"emWaitingToInviteMario": 0x80254cc0,
		"TEnemyMario::decideDoingAfterCarry": 0x80254e5c,
		"decideDoingAfterCarry": 0x80254e5c,
		"TEnemyMario::emRunAwayToNearestNode": 0x80254fc0,
		"emRunAwayToNearestNode": 0x80254fc0,
		"TEnemyMario::findRunAwayNearestNode": 0x802554a0,
		"findRunAwayNearestNode": 0x802554a0,
		"TEnemyMario::startRunAway": 0x80255744,
		"TEnemyMario::emDownAnimation": 0x80255758,
		"emDownAnimation": 0x80255758,
		"TEnemyMario::emReplayJumpToNearestNode": 0x80255884,
		"emReplayJumpToNearestNode": 0x80255884,
		"TEnemyMario::emReplay": 0x80256068,
		"emReplay": 0x80256068,
		"TEnemyMario::emDisappearToGate": 0x8025629c,
		"emDisappearToGate": 0x8025629c,
		"TEnemyMario::startDisappear": 0x80256408,
		"startDisappear": 0x80256408,
		"TEnemyMario::emWalkAround": 0x802564c4,
		"emWalkAround": 0x802564c4,
		"TEnemyMario::emJumping": 0x8025668c,
		"emJumping": 0x8025668c,
		"TEnemyMario::emWaiting": 0x802567e8,
		"emWaiting": 0x802567e8,
		"TEnemyMario::tryTake": 0x80256900,
		"tryTake": 0x80256900,
		"TEnemyMario::changeEMDoing": 0x802569f0,
		"changeEMDoing": 0x802569f0,
		"TEnemyMario::startMonteReplay": 0x80256a00,
		"TEnemyMario::initEnemyValues": 0x80256b48,
		"initEnemyValues": 0x80256b48,
		"TEnemyMario::initModel": 0x80257c98,
		"TEnemyMario::initValues": 0x802582b0,
		"Enemy::__sinit_enemyMario_cpp": 0x8025859c,
		"__sinit_enemyMario_cpp": 0x8025859c,
		"TMtxCalcFootInv::TMtxCalcFootInv": 0x80258a00,
		"Enemy::FeetInvCalc": 0x80258b3c,
		"FeetInvCalc": 0x80258b3c,
		"TNerveGessoTurn::~TNerveGessoTurn": 0x802595c4,
		"TNerveGessoTurn::execute": 0x80259620,
		"TNerveGessoLand::execute": 0x80259724,
		"TNerveGessoLand::~TNerveGessoLand": 0x80259798,
		"TNerveGessoFindMario::execute": 0x802597f4,
		"TNerveGessoFindMario::~TNerveGessoFindMario": 0x80259860,
		"TNerveGessoRolling::execute": 0x802598bc,
		"TNerveGessoRolling::~TNerveGessoRolling": 0x80259990,
		"TNerveGessoFall::execute": 0x802599ec,
		"TNerveGessoFall::~TNerveGessoFall": 0x8025a0fc,
		"TNerveGessoPollute::execute": 0x8025a158,
		"TNerveGessoPollute::~TNerveGessoPollute": 0x8025a2b4,
		"TNerveGessoPunch::execute": 0x8025a310,
		"TNerveGessoPunch::~TNerveGessoPunch": 0x8025a37c,
		"TNerveGessoFreeze::execute": 0x8025a3d8,
		"TNerveGessoFreeze::~TNerveGessoFreeze": 0x8025a824,
		"TNerveGessoStay::execute": 0x8025a880,
		"TNerveGessoStay::~TNerveGessoStay": 0x8025aa9c,
		"TGessoPolluteObj::sendMessage": 0x8025aaf8,
		"TGessoPolluteObj::calcRootMatrix": 0x8025ab9c,
		"TGessoPolluteObj::set": 0x8025ac1c,
		"TGessoPolluteObj::rebirth": 0x8025ad5c,
		"TGessoPolluteObj::pollute": 0x8025aea4,
		"TGessoPolluteObj::getNowGravity": 0x8025af18,
		"TGessoPolluteObj::loadInit": 0x8025af38,
		"TLandGesso::load": 0x8025b044,
		"TSurfGesso::perform": 0x8025b08c,
		"TSurfGesso::load": 0x8025b0c0,
		"TGesso::getBasNameTable": 0x8025b108,
		"TGesso::initAttacker": 0x8025b114,
		"TGesso::rollCheck": 0x8025b164,
		"rollCheck": 0x8025b164,
		"TGesso::behaveToFindMario": 0x8025b47c,
		"TGesso::genRandomItem": 0x8025b6dc,
		"TGesso::calcRootMatrix": 0x8025b750,
		"TGesso::kill": 0x8025b8b8,
		"TGesso::bind": 0x8025b908,
		"TGesso::setWaitAnm": 0x8025bbc0,
		"TGesso::setWalkAnm": 0x8025bc44,
		"TGesso::getGravityY": 0x8025bc74,
		"TGesso::setDeadAnm": 0x8025bca8,
		"TGesso::setAfterDeadEffect": 0x8025bd70,
		"TGesso::pollute": 0x8025bdb4,
		"TGesso::setPolluteGoal": 0x8025bf98,
		"setPolluteGoal": 0x8025bf98,
		"TGesso::setBehavior": 0x8025c174,
		"TGesso::attackToMario": 0x8025c338,
		"TGesso::doKeepDistance": 0x8025c5f4,
		"TGesso::isResignationAttack": 0x8025c640,
		"TGesso::walkBehavior": 0x8025c674,
		"TGesso::behaveToWater": 0x8025c8c0,
		"TGesso::load": 0x8025cc94,
		"TGesso::reset": 0x8025cd6c,
		"TGesso::init": 0x8025cf08,
		"TGesso::TGesso": 0x8025d070,
		"Enemy::GessoBodyCallback": 0x8025d100,
		"GessoBodyCallback": 0x8025d100,
		"TGessoManager::createModelData": 0x8025d2b0,
		"TGessoManager::initSetEnemies": 0x8025d2e4,
		"TGessoManager::perform": 0x8025d3a0,
		"TGessoManager::clipEnemies": 0x8025d460,
		"TGessoManager::createEnemyInstance": 0x8025d588,
		"TGessoManager::loadAfter": 0x8025d5d0,
		"TGessoManager::load": 0x8025d5f0,
		"TGessoManager::TGessoManager": 0x8025d648,
		"TGessoPolluteModel::setAnm": 0x8025d690,
		"TGessoPolluteModelManager::init": 0x8025d6e0,
		"TGessoSaveLoadParams::TGessoSaveLoadParams": 0x8025d7a8,
		"TGesso::setRunAnm": 0x8025db44,
		"TSmallEnemy::isEatenByYosshi": 0x8025db70,
		"TSmallEnemy::jumpBehavior": 0x8025db78,
		"jumpBehavior": 0x8025db78,
		"TSmallEnemy::behaveToTaken": 0x8025db7c,
		"TSmallEnemy::behaveToRelease": 0x8025db80,
		"TSmallEnemy::setGenerateAnm": 0x8025db84,
		"TSmallEnemy::setFreezeAnm": 0x8025db88,
		"TSmallEnemy::setMeltAnm": 0x8025db8c,
		"TSmallEnemy::isHitValid": 0x8025db90,
		"TSmallEnemy::isInhibitedForceMove": 0x8025dbac,
		"TSmallEnemy::endHitWaterJump": 0x8025dbb4,
		"TSmallEnemy::setDeadEffect": 0x8025dbb8,
		"setDeadEffect": 0x8025dbb8,
		"TSurfGesso::isFindMario": 0x8025dcc4,
		"TGessoManager::~TGessoManager": 0x8025dd68,
		"TGessoPolluteModel::~TGessoPolluteModel": 0x8025dddc,
		"TGessoPolluteModelManager::~TGessoPolluteModelManager": 0x8025de60,
		"Enemy::__sinit_gesso_cpp": 0x8025dee4,
		"__sinit_gesso_cpp": 0x8025dee4,
		"TGraphTracer::traceSpline": 0x8025e200,
		"traceSpline": 0x8025e200,
		"TGraphTracer::calcSplineSpeed": 0x8025e3c4,
		"calcSplineSpeed": 0x8025e3c4,
		"TGraphTracer::moveTo": 0x8025e634,
		"moveTo": 0x8025e634,
		"TGraphTracer::setTo": 0x8025e6f4,
		"setTo": 0x8025e6f4,
		"TGraphTracer::TGraphTracer": 0x8025e7a0,
		"TGraphGroup::perform": 0x8025e7d0,
		"TGraphGroup::getGraphByName": 0x8025e828,
		"TGraphGroup::initGraphGroup": 0x8025e8cc,
		"TGraphGroup::TGraphGroup": 0x8025eab0,
		"TGraphWeb::getNeighborNodeIndexByFlag": 0x8025ebfc,
		"getNeighborNodeIndexByFlag": 0x8025ebfc,
		"TGraphWeb::getNearestPosOnGraphLink": 0x8025ecf0,
		"getNearestPosOnGraphLink": 0x8025ecf0,
		"TGraphWeb::isDummy": 0x8025efb8,
		"isDummy": 0x8025efb8,
		"TGraphWeb::indexToPoint": 0x8025efdc,
		"indexToPoint": 0x8025efdc,
		"TGraphWeb::startIsEnd": 0x8025f068,
		"startIsEnd": 0x8025f068,
		"TGraphWeb::initGoalIndex": 0x8025f0e0,
		"initGoalIndex": 0x8025f0e0,
		"TGraphWeb::calcGraphDirection": 0x8025f1a4,
		"calcGraphDirection": 0x8025f1a4,
		"TGraphWeb::findNearestVisibleIndex": 0x8025f258,
		"findNearestVisibleIndex": 0x8025f258,
		"TGraphWeb::findNearestNodeIndex": 0x8025f410,
		"findNearestNodeIndex": 0x8025f410,
		"TGraphWeb::getEscapeDirLimited": 0x8025f50c,
		"getEscapeDirLimited": 0x8025f50c,
		"TGraphWeb::getRandomButDirLimited": 0x8025f988,
		"getRandomButDirLimited": 0x8025f988,
		"TGraphWeb::getAimToDirNextIndex": 0x8025fdb4,
		"getAimToDirNextIndex": 0x8025fdb4,
		"TGraphWeb::getEscapeFromMarioIndex": 0x8025ffd4,
		"getEscapeFromMarioIndex": 0x8025ffd4,
		"TGraphWeb::getRandomNextIndex": 0x80260224,
		"getRandomNextIndex": 0x80260224,
		"TGraphWeb::getShortestNextIndex": 0x8026037c,
		"getShortestNextIndex": 0x8026037c,
		"TGraphWeb::translateNodes": 0x80260558,
		"translateNodes": 0x80260558,
		"TGraphWeb::filterRailNode": 0x8026074c,
		"filterRailNode": 0x8026074c,
		"TGraphWeb::~TGraphWeb": 0x80260898,
		"TGraphWeb::TGraphWeb": 0x802608e4,
		"TSplineRail::getPosAndRot": 0x80260a48,
		"getPosAndRot": 0x80260a48,
		"TSplinePath::getPoint": 0x80260c7c,
		"TSplineRail::TSplineRail": 0x80260d5c,
		"TGraphNode::getPoint": 0x80261308,
		"TGraphNode::TGraphNode": 0x8026137c,
		"TNerveDoroHanePrepareAttack::~TNerveDoroHanePrepareAttack": 0x8026139c,
		"TNerveDoroHanePrepareAttack::execute": 0x802613f8,
		"TNerveDoroHaneHitWater::execute": 0x80261478,
		"TNerveDoroHaneHitWater::~TNerveDoroHaneHitWater": 0x802615f0,
		"TNerveDoroHaneRise::execute": 0x8026164c,
		"TNerveDoroHaneRise::~TNerveDoroHaneRise": 0x802617e8,
		"TNerveFireHamuKuriRecover::execute": 0x80261844,
		"TFireHamuKuri::setBckAnm": 0x80261928,
		"TNerveFireHamuKuriRecover::~TNerveFireHamuKuriRecover": 0x80261948,
		"TNerveDoroHamuKuriRobCap::execute": 0x802619a4,
		"TNerveDoroHamuKuriRobCap::~TNerveDoroHamuKuriRobCap": 0x80261b48,
		"TNerveHaneHamuKuriMoveOnGraph::execute": 0x80261ba4,
		"TNerveHaneHamuKuriMoveOnGraph::~TNerveHaneHamuKuriMoveOnGraph": 0x80261ea4,
		"TNerveHaneHamuKuriUpWait::execute": 0x80261f00,
		"TNerveHaneHamuKuriUpWait::~TNerveHaneHamuKuriUpWait": 0x80262088,
		"TNerveDangoHamuKuriWait::execute": 0x802620e4,
		"TNerveDangoHamuKuriWait::~TNerveDangoHamuKuriWait": 0x80262198,
		"TNerveHamuKuriJitabata::execute": 0x802621f4,
		"TNerveHamuKuriJitabata::~TNerveHamuKuriJitabata": 0x80262324,
		"TNerveHamuKuriLand::execute": 0x80262380,
		"TNerveHamuKuriLand::~TNerveHamuKuriLand": 0x80262400,
		"TNerveHamuKuriWallDie::execute": 0x8026245c,
		"TNerveHamuKuriWallDie::~TNerveHamuKuriWallDie": 0x802626fc,
		"TNerveHamuKuriBoundFreeze::execute": 0x80262758,
		"TNerveHamuKuriBoundFreeze::~TNerveHamuKuriBoundFreeze": 0x80262a6c,
		"TNerveHamuKuriGoForSearchActor::execute": 0x80262ac8,
		"TNerveHamuKuriGoForSearchActor::~TNerveHamuKuriGoForSearchActor": 0x80262cb4,
		"TDoroHamuKuri::isCollidMove": 0x80262d10,
		"TDoroHamuKuri::onHaveCap": 0x802630cc,
		"TDoroHamuKuri::setBehavior": 0x802630ec,
		"TDoroHamuKuri::attackToMario": 0x8026335c,
		"TDoroHamuKuri::setMActorAndKeeper": 0x80263440,
		"TDoroHamuKuri::kill": 0x802634ac,
		"TDoroHamuKuri::reset": 0x802634cc,
		"TDoroHamuKuri::init": 0x80263544,
		"TDoroHamuKuri::TDoroHamuKuri": 0x802636a0,
		"TFireHamuKuri::changeTevColor": 0x80263780,
		"changeTevColor": 0x80263780,
		"TFireHamuKuri::sendAttackMsgToMario": 0x8026394c,
		"TFireHamuKuri::setWalkAnm": 0x80263988,
		"TFireHamuKuri::isHitValid": 0x802639b8,
		"TFireHamuKuri::walkBehavior": 0x80263a48,
		"TFireHamuKuri::calcRootMatrix": 0x80263bc4,
		"TFireHamuKuri::moveObject": 0x80263d98,
		"TFireHamuKuri::setMActorAndKeeper": 0x80263dcc,
		"TFireHamuKuri::reset": 0x80263e6c,
		"TFireHamuKuri::behaveToWater": 0x80263f24,
		"THamuKuri::canDoJitabata": 0x80264304,
		"TFireHamuKuri::init": 0x80264328,
		"TFireHamuKuri::TFireHamuKuri": 0x80264404,
		"TBossDangoHamuKuri::generateBody": 0x80264458,
		"generateBody": 0x80264458,
		"TBossDangoHamuKuri::genEventCoin": 0x802645e4,
		"TBossDangoHamuKuri::moveObject": 0x802646c0,
		"TBossDangoHamuKuri::setGenerateAnm": 0x80264718,
		"TBossDangoHamuKuri::reset": 0x80264788,
		"TBossDangoHamuKuri::perform": 0x8026485c,
		"TBossDangoHamuKuri::init": 0x8026487c,
		"TBossDangoHamuKuri::TBossDangoHamuKuri": 0x802649b8,
		"TDangoHamuKuri::swingBody": 0x80264ae4,
		"swingBody": 0x80264ae4,
		"TDangoHamuKuri::behaveToWater": 0x80264cb8,
		"TDangoHamuKuri::forceKill": 0x80265158,
		"TDangoHamuKuri::isHitValid": 0x802652b8,
		"TDangoHamuKuri::receiveMessage": 0x802652e0,
		"TDangoHamuKuri::reset": 0x802654e0,
		"TDangoHamuKuri::calcRootMatrix": 0x802655a4,
		"TDangoHamuKuri::setRunAnm": 0x80265780,
		"TDangoHamuKuri::getTakingMtx": 0x802657d4,
		"TDangoHamuKuri::attackToMario": 0x8026589c,
		"TDangoHamuKuri::isCollidMove": 0x802659fc,
		"TDangoHamuKuri::updateAnmSound": 0x80265a1c,
		"TDangoHamuKuri::moveObject": 0x80265a60,
		"TDangoHamuKuri::changeByJuice": 0x80265ab8,
		"TDangoHamuKuri::perform": 0x80265aec,
		"TDangoHamuKuri::init": 0x80265b78,
		"TDangoHamuKuri::TDangoHamuKuri": 0x80265c78,
		"THaneHamuKuri2::isReachedToGoal": 0x80265cf0,
		"THaneHamuKuri2::walkBehavior": 0x80265d98,
		"THaneHamuKuri2::sendAttackMsgToMario": 0x80265f04,
		"THaneHamuKuri2::reset": 0x80265f24,
		"THaneHamuKuri2::THaneHamuKuri2": 0x80266010,
		"TDoroHaneKuri::isCollidMove": 0x80266120,
		"TDoroHaneKuri::setBehavior": 0x802661e8,
		"TDoroHaneKuri::behaveToWater": 0x802662b0,
		"TDoroHaneKuri::setMActorAndKeeper": 0x802663d0,
		"TDoroHaneKuri::attackToMario": 0x8026643c,
		"TDoroHaneKuri::onHaveCap": 0x802665f8,
		"TDoroHaneKuri::reset": 0x80266614,
		"TDoroHaneKuri::init": 0x802666a4,
		"TDoroHaneKuri::TDoroHaneKuri": 0x80266874,
		"THaneHamuKuri::getBasNameTable": 0x802668f0,
		"THaneHamuKuri::isHitValid": 0x802668fc,
		"THaneHamuKuri::isCollidMove": 0x80266918,
		"THaneHamuKuri::setDeadAnm": 0x80266938,
		"THaneHamuKuri::setBckAnm": 0x80266a10,
		"THaneHamuKuri::setCrashAnm": 0x80266a30,
		"THaneHamuKuri::behaveToWater": 0x80266a60,
		"THaneHamuKuri::setRollAnm": 0x80266aa4,
		"THaneHamuKuri::setRunAnm": 0x80266ad4,
		"THaneHamuKuri::setWalkAnm": 0x80266b04,
		"THaneHamuKuri::setWaitAnm": 0x80266b34,
		"THaneHamuKuri::setMActorAndKeeper": 0x80266b64,
		"THaneHamuKuri::attackToMario": 0x80266bd0,
		"THaneHamuKuri::isReachedToGoal": 0x80266c40,
		"THaneHamuKuri::bind": 0x80266ce8,
		"THaneHamuKuri::walkBehavior": 0x80266ec8,
		"THaneHamuKuri::reset": 0x80267768,
		"THaneHamuKuri::moveObject": 0x802677dc,
		"THaneHamuKuri::init": 0x802677fc,
		"THaneHamuKuri::THaneHamuKuri": 0x802678e0,
		"THamuKuri::forceRoll": 0x80267940,
		"forceRoll": 0x80267940,
		"THamuKuri::isCollidMove": 0x80267b44,
		"THamuKuri::isHitValid": 0x80267ffc,
		"THamuKuri::isResignationAttack": 0x80268128,
		"THamuKuri::getTakingMtx": 0x80268214,
		"THamuKuri::getBasNameTable": 0x80268314,
		"THamuKuri::initAttacker": 0x80268320,
		"THamuKuri::walkBehavior": 0x802683a4,
		"THamuKuri::setCrashAnm": 0x802683e4,
		"THamuKuri::setRollAnm": 0x802684e8,
		"THamuKuri::setRunAnm": 0x80268518,
		"THamuKuri::setWaitAnm": 0x80268548,
		"THamuKuri::setDeadAnm": 0x80268578,
		"THamuKuri::setWalkAnm": 0x802686c8,
		"THamuKuri::setGenerateAnm": 0x802686f8,
		"THamuKuri::setBckAnm": 0x80268728,
		"THamuKuri::endHitWaterJump": 0x80268748,
		"THamuKuri::setAfterDeadEffect": 0x80268794,
		"THamuKuri::genRandomItem": 0x80268974,
		"THamuKuri::getGravityY": 0x80268994,
		"THamuKuri::makeCapFly": 0x80268a04,
		"makeCapFly": 0x80268a04,
		"THamuKuri::onHaveCap": 0x80268d68,
		"THamuKuri::selectCapHolder": 0x80268d74,
		"selectCapHolder": 0x80268d74,
		"THamuKuri::setBehavior": 0x80268e24,
		"THamuKuri::moveObject": 0x80268f98,
		"THamuKuri::attackToMario": 0x80269158,
		"THamuKuri::behaveToFindMario": 0x8026923c,
		"THamuKuri::jumpToSearchActor": 0x80269298,
		"jumpToSearchActor": 0x80269298,
		"THamuKuri::isFindMario": 0x8026944c,
		"THamuKuri::behaveToWater": 0x802694d4,
		"THamuKuri::bind": 0x80269710,
		"THamuKuri::reset": 0x80269970,
		"THamuKuri::setMActorAndKeeper": 0x802699c4,
		"THamuKuri::init": 0x80269aa8,
		"THamuKuri::THamuKuri": 0x80269b38,
		"TDoroHamuKuriManager::perform": 0x80269bb8,
		"TDoroHamuKuriManager::createModelData": 0x80269c64,
		"TDoroHamuKuriManager::createEnemyInstance": 0x80269c98,
		"TDoroHamuKuriManager::loadAfter": 0x80269cf4,
		"TDoroHamuKuriManager::load": 0x80269e4c,
		"TDoroHamuKuriManager::TDoroHamuKuriManager": 0x80269eb8,
		"THamuKuriManager::~THamuKuriManager": 0x80269f1c,
		"TDoroHige::perform": 0x80269f90,
		"TFireHamuKuriManager::createModelData": 0x80269fe4,
		"TFireHamuKuriManager::initSetEnemies": 0x8026a018,
		"TFireHamuKuriManager::createEnemyInstance": 0x8026a1ac,
		"TFireHamuKuriManager::load": 0x8026a218,
		"TFireHamuKuriManager::TFireHamuKuriManager": 0x8026a2c8,
		"TBossDangoHamuKuriManager::createEnemyInstance": 0x8026a328,
		"TBossDangoHamuKuriManager::load": 0x8026a38c,
		"TBossDangoHamuKuriManager::TBossDangoHamuKuriManager": 0x8026a43c,
		"TDangoHamuKuriManager::~TDangoHamuKuriManager": 0x8026a4ac,
		"TDoroHaneKuriManager::perform": 0x8026a530,
		"TDangoHamuKuriManager::createModelDataArray": 0x8026a5dc,
		"TDangoHamuKuriManager::createEnemyInstance": 0x8026a64c,
		"TDangoHamuKuriManager::load": 0x8026a694,
		"TDangoHamuKuriManager::TDangoHamuKuriManager": 0x8026a700,
		"TDoroHaneKuriManager::createModelData": 0x8026a760,
		"TDoroHaneKuriManager::createEnemyInstance": 0x8026a794,
		"TDoroHaneKuriManager::loadAfter": 0x8026a7f8,
		"TDoroHaneKuriManager::load": 0x8026a950,
		"TDoroHaneKuriManager::TDoroHaneKuriManager": 0x8026aab0,
		"THaneHamuKuriManager::~THaneHamuKuriManager": 0x8026ab20,
		"THaneHamuKuriManager::createAnmData": 0x8026aba4,
		"THaneHamuKuriManager::createModelData": 0x8026abc4,
		"THaneHamuKuriManager::createEnemyInstance": 0x8026abf8,
		"THaneHamuKuriManager::load": 0x8026ac40,
		"THaneHamuKuriManager::THaneHamuKuriManager": 0x8026ada0,
		"THamuKuriManager::createEnemyInstance": 0x8026ae00,
		"THamuKuriManager::checkSerialKill": 0x8026ae48,
		"checkSerialKill": 0x8026ae48,
		"THamuKuriManager::requestSerialKill": 0x8026afb8,
		"requestSerialKill": 0x8026afb8,
		"THamuKuriManager::setSearchHamuKuri": 0x8026b0a8,
		"setSearchHamuKuri": 0x8026b0a8,
		"THamuKuriManager::perform": 0x8026b36c,
		"THamuKuriManager::createAnmData": 0x8026b3f4,
		"THamuKuriManager::createModelData": 0x8026b454,
		"THamuKuriManager::loadAfter": 0x8026b488,
		"THamuKuriManager::load": 0x8026b59c,
		"THamuKuriManager::THamuKuriManager": 0x8026b608,
		"THamuKuriSaveLoadParams::THamuKuriSaveLoadParams": 0x8026b65c,
		"THamuKuriLauncher::stateLaunch": 0x8026b920,
		"THamuKuriLauncher::drawObject": 0x8026baf0,
		"TBossDangoHamuKuri::changeByJuice": 0x8026bc48,
		"TBossDangoHamuKuri::isFindMario": 0x8026bc50,
		"THaneHamuKuri2::forceKill": 0x8026bcf4,
		"THaneHamuKuri2::isHitValid": 0x8026bcf8,
		"THaneHamuKuri2::behaveToWater": 0x8026bd00,
		"THaneHamuKuri::setBehavior": 0x8026bd04,
		"THaneHamuKuri::setGenerateAnm": 0x8026bd08,
		"THaneHamuKuri::canDoJitabata": 0x8026bd0c,
		"TDoroHamuKuriManager::~TDoroHamuKuriManager": 0x8026be4c,
		"TSmallEnemyManager::initSetEnemies": 0x8026bed0,
		"TDoroHige::~TDoroHige": 0x8026bed4,
		"TFireHamuKuriManager::~TFireHamuKuriManager": 0x8026bf58,
		"TBossDangoHamuKuriManager::~TBossDangoHamuKuriManager": 0x8026bfdc,
		"TBossDangoHamuKuriManager::clipEnemies": 0x8026c070,
		"TDangoHamuKuriManager::clipEnemies": 0x8026c074,
		"TDoroHaneKuriManager::~TDoroHaneKuriManager": 0x8026c078,
		"Enemy::__sinit_hamukuri_cpp": 0x8026c190,
		"__sinit_hamukuri_cpp": 0x8026c190,
		"TNerveHino2WaitAnm::~TNerveHino2WaitAnm": 0x8026c56c,
		"TNerveHino2WaitAnm::execute": 0x8026c5c8,
		"TNerveHino2Freeze::execute": 0x8026c60c,
		"TNerveHino2Freeze::~TNerveHino2Freeze": 0x8026c698,
		"TNerveHino2Stamp::execute": 0x8026c6f4,
		"TNerveHino2GraphWander::~TNerveHino2GraphWander": 0x8026c968,
		"TNerveHino2Stamp::~TNerveHino2Stamp": 0x8026c9c4,
		"TNerveHino2Die::execute": 0x8026ca20,
		"TNerveHino2Die::~TNerveHino2Die": 0x8026cc4c,
		"TNerveHino2Burst::execute": 0x8026cca8,
		"TNerveHino2Burst::~TNerveHino2Burst": 0x8026cf08,
		"TNerveHino2Squat::execute": 0x8026cf64,
		"TNerveHino2Squat::~TNerveHino2Squat": 0x8026d0b4,
		"TNerveHino2Damage::execute": 0x8026d110,
		"TNerveHino2Damage::~TNerveHino2Damage": 0x8026d544,
		"TNerveHino2Pollute::execute": 0x8026d5a0,
		"TNerveHino2Pollute::~TNerveHino2Pollute": 0x8026d950,
		"TNerveHino2PrePol::execute": 0x8026d9ac,
		"TNerveHino2PrePol::~TNerveHino2PrePol": 0x8026dbb0,
		"TNerveHino2Turn::execute": 0x8026dc0c,
		"TNerveHino2Turn::~TNerveHino2Turn": 0x8026deb8,
		"TNerveHino2Landing::execute": 0x8026df14,
		"TNerveHino2Landing::~TNerveHino2Landing": 0x8026dfd4,
		"TNerveHino2JumpIn::execute": 0x8026e030,
		"TNerveHino2Fly::~TNerveHino2Fly": 0x8026e19c,
		"TNerveHino2JumpIn::~TNerveHino2JumpIn": 0x8026e1f8,
		"TNerveHino2Fly::execute": 0x8026e254,
		"TNerveHino2GraphWander::execute": 0x8026e39c,
		"TNerveHino2Appear::execute": 0x8026e87c,
		"TNerveHino2Appear::~TNerveHino2Appear": 0x8026e96c,
		"THinokuri2::perform": 0x8026e9c8,
		"THinokuri2::moveObject": 0x8026ec00,
		"THinokuri2::receiveMessage": 0x8026f314,
		"THinokuri2::receiveMessageLv2": 0x8026f388,
		"receiveMessageLv2": 0x8026f388,
		"THinokuri2::receiveMessageLv1": 0x8026f718,
		"receiveMessageLv1": 0x8026f718,
		"THinokuri2::receiveMessageLv0": 0x8026f9ac,
		"receiveMessageLv0": 0x8026f9ac,
		"THinokuri2::changeBck": 0x8026fc2c,
		"THinokuri2::updateAnmSound": 0x8026fe48,
		"THinokuri2::setLevel": 0x8026feb0,
		"setLevel": 0x8026feb0,
		"THinokuri2::kill": 0x8026ffd8,
		"THinokuri2::reset": 0x80270044,
		"THinokuri2::init": 0x80270224,
		"THinokuri2::THinokuri2": 0x80270784,
		"Enemy::Hino2HeadCallback": 0x80270a2c,
		"Hino2HeadCallback": 0x80270a2c,
		"THino2Mask::perform": 0x80270c20,
		"THino2Mask::THino2Mask": 0x80270f08,
		"THino2Hit::receiveMessage": 0x80270fc0,
		"THino2Hit::perform": 0x802710e8,
		"THinokuri2Manager::createEnemyInstance": 0x802715e0,
		"THinokuri2Manager::load": 0x80271628,
		"THinokuri2Manager::createModelData": 0x80271694,
		"THinokuri2Manager::THinokuri2Manager": 0x802716c8,
		"THino2Params::THino2Params": 0x80271704,
		"THinokuri2Manager::~THinokuri2Manager": 0x80271f24,
		"Enemy::__sinit_hinokuri2_cpp": 0x80271f88,
		"__sinit_hinokuri2_cpp": 0x80271f88,
		"TNerveMameGessoWait::~TNerveMameGessoWait": 0x8027231c,
		"TNerveMameGessoWait::execute": 0x80272378,
		"TNerveMameGessoGraphJumpWander::~TNerveMameGessoGraphJumpWander": 0x802724cc,
		"TNerveMameGessoObject::execute": 0x80272528,
		"TNerveMameGessoObject::~TNerveMameGessoObject": 0x80272854,
		"TNerveMameGessoThrown::execute": 0x802728b0,
		"TNerveMameGessoThrown::~TNerveMameGessoThrown": 0x80272af8,
		"TNerveMameGessoPickUp::execute": 0x80272b54,
		"TNerveMameGessoPickUp::~TNerveMameGessoPickUp": 0x80272c08,
		"TNerveMameGessoTrample::execute": 0x80272c64,
		"TNerveMameGessoTrample::~TNerveMameGessoTrample": 0x80272d58,
		"TNerveMameGessoJitabata::execute": 0x80272db4,
		"TNerveMameGessoJitabata::~TNerveMameGessoJitabata": 0x80272fb0,
		"TNerveMameGessoDamage::execute": 0x8027300c,
		"TNerveMameGessoDamage::~TNerveMameGessoDamage": 0x80273348,
		"TNerveMameGessoGraphJumpWander::execute": 0x802733a4,
		"TMameGesso::getBasNameTable": 0x802739f0,
		"TMameGesso::doKeepDistance": 0x802739fc,
		"TMameGesso::isInhibitedForceMove": 0x80273a2c,
		"TMameGesso::calcObjCollision": 0x80273a34,
		"calcObjCollision": 0x80273a34,
		"TMameGesso::isCollidMove": 0x80273ba4,
		"TMameGesso::behaveToRelease": 0x80273c50,
		"TMameGesso::behaveToTaken": 0x80273d74,
		"TMameGesso::behaveToWater": 0x80273e8c,
		"TMameGesso::setDeadAnm": 0x80274004,
		"TMameGesso::setFreezeAnm": 0x80274010,
		"TMameGesso::setWaitAnm": 0x80274048,
		"TMameGesso::getGravityY": 0x802740f0,
		"TMameGesso::kill": 0x802741e8,
		"TMameGesso::isHitValid": 0x8027459c,
		"TMameGesso::reset": 0x802746b8,
		"TMameGesso::calcRootMatrix": 0x802747a8,
		"TMameGesso::attackToMario": 0x802748c4,
		"TMameGesso::setMActorAndKeeper": 0x8027495c,
		"TMameGesso::moveObject": 0x802749c8,
		"TMameGesso::init": 0x80274a5c,
		"TMameGesso::load": 0x80274b78,
		"TMameGesso::TMameGesso": 0x80274bc0,
		"TMameGessoManager::perform": 0x80274c54,
		"TMameGessoManager::initSetEnemies": 0x80274d10,
		"TMameGessoManager::createEnemyInstance": 0x80274d14,
		"TMameGessoManager::loadAfter": 0x80274d5c,
		"TMameGessoManager::load": 0x80274d7c,
		"TMameGessoManager::TMameGessoManager": 0x80274dd4,
		"TMameGessoSaveLoadParams::TMameGessoSaveLoadParams": 0x80274e10,
		"TMameGesso::changeByJuice": 0x802750e4,
		"TMameGesso::isEatenByYosshi": 0x802750ec,
		"TMameGesso::forceKill": 0x802750f4,
		"TSmallEnemy::setBehavior": 0x802750f8,
		"TSmallEnemy::setWalkAnm": 0x802750fc,
		"TSmallEnemy::setRunAnm": 0x80275100,
		"TMameGessoManager::~TMameGessoManager": 0x802751a0,
		"Enemy::__sinit_mameGesso_cpp": 0x80275214,
		"__sinit_mameGesso_cpp": 0x80275214,
		"TNerveNKFollowMario::~TNerveNKFollowMario": 0x80275488,
		"TNerveNKFollowMario::execute": 0x802754e4,
		"TNerveNameKuriJumpAttackPrepare::~TNerveNameKuriJumpAttackPrepare": 0x80275670,
		"TNerveNKFollowMario::theNerve": 0x802756cc,
		"TNerveNameKuriDrawPollute::execute": 0x80275730,
		"TNerveNameKuriDrawPollute::theNerve": 0x80275738,
		"TNerveNameKuriDrawPollute::~TNerveNameKuriDrawPollute": 0x8027579c,
		"TNerveNameKuriDiffuse::execute": 0x802757f8,
		"TNerveNameKuriDiffuse::theNerve": 0x8027582c,
		"TNerveNameKuriDiffuse::~TNerveNameKuriDiffuse": 0x80275890,
		"TNerveNameKuriExplosion::execute": 0x802758ec,
		"TNerveNameKuriExplosion::theNerve": 0x80275960,
		"TNerveNameKuriExplosion::~TNerveNameKuriExplosion": 0x802759c4,
		"TNerveNameKuriJumpAttackPrepare::execute": 0x80275a20,
		"TNerveNameKuriJumpAttack::~TNerveNameKuriJumpAttack": 0x80275c0c,
		"TNerveNameKuriJumpAttackPrepare::theNerve": 0x80275c68,
		"TNerveNameKuriJumpAttack::execute": 0x80275ccc,
		"TNerveNameKuriJumpAttack::theNerve": 0x802761b4,
		"TNerveNameKuriLand::execute": 0x80276218,
		"TNerveNameKuriLand::theNerve": 0x802762a8,
		"TNerveNameKuriLand::~TNerveNameKuriLand": 0x8027630c,
		"TDiffusionNameKuriManager::createEnemyInstance": 0x80276368,
		"TDiffusionNameKuriManager::load": 0x80276460,
		"TNameKuri::getBasNameTable": 0x80276704,
		"TNameKuri::isCollidMove": 0x80276710,
		"TNameKuri::isHitValid": 0x8027680c,
		"TNameKuri::endHitWaterJump": 0x80276840,
		"TNameKuri::behaveToFindMario": 0x80276854,
		"TNameKuri::attackToMario": 0x80276930,
		"TNameKuri::reset": 0x80276a00,
		"TNameKuri::setMActorAndKeeper": 0x80276b38,
		"TNameKuri::setMeltAnm": 0x80276ba4,
		"TNameKuri::setWaitAnm": 0x80276cfc,
		"TNameKuri::setAfterDeadEffect": 0x80276d2c,
		"TNameKuri::setDeadAnm": 0x80276da8,
		"TNameKuri::setWalkAnm": 0x80276f00,
		"TNameKuri::setGenerateAnm": 0x80276f30,
		"TNameKuri::setBckAnm": 0x80276f94,
		"TNameKuri::getGravityY": 0x80276fb4,
		"TNameKuri::behaveToWater": 0x80277058,
		"TNameKuri::setBehavior": 0x80277198,
		"TNameKuri::moveObject": 0x8027719c,
		"TNameKuri::perform": 0x802773c8,
		"TNameKuri::calcRootMatrix": 0x8027746c,
		"TNameKuri::init": 0x8027780c,
		"TNameKuri::TNameKuri": 0x802779c0,
		"Enemy::NameKuriScaleCallback": 0x80277a34,
		"NameKuriScaleCallback": 0x80277a34,
		"Enemy::NameKuriAttackCallback": 0x80277b24,
		"NameKuriAttackCallback": 0x80277b24,
		"TNameIndParCallback::draw": 0x80277cb8,
		"TNameIndParCallback::execute": 0x80277cbc,
		"TNameKuriManager::perform": 0x80278074,
		"TNameKuriManager::createModelData": 0x80278094,
		"TNameKuriManager::createEnemyInstance": 0x802780c8,
		"TNameKuriManager::initSetEnemies": 0x80278154,
		"TNameKuriManager::loadAfter": 0x802782c8,
		"TNameKuriManager::load": 0x8027832c,
		"TNameKuriManager::TNameKuriManager": 0x802785d0,
		"TNameKuriLauncher::stateLaunch": 0x8027861c,
		"TDiffusionNameKuriManager::~TDiffusionNameKuriManager": 0x802787ac,
		"Enemy::__sinit_namekuri_cpp": 0x802788b4,
		"__sinit_namekuri_cpp": 0x802788b4,
		"TNerveStayPakkunAppear::~TNerveStayPakkunAppear": 0x80278bc8,
		"TNerveStayPakkunAppear::execute": 0x80278c24,
		"TNervePakkunStay::~TNervePakkunStay": 0x80278dd8,
		"TNerveStayPakkunHide::execute": 0x80278e34,
		"TNerveStayPakkunHide::~TNerveStayPakkunHide": 0x802790e4,
		"TNervePakkunFreeze::execute": 0x80279140,
		"TNervePakkunFreeze::~TNervePakkunFreeze": 0x80279278,
		"TNervePakkunShoot::execute": 0x802792d4,
		"TNervePakkunShoot::~TNervePakkunShoot": 0x80279434,
		"TNervePakkunHide::execute": 0x80279490,
		"TNervePakkunAppear::~TNervePakkunAppear": 0x802795f8,
		"TNervePakkunHide::~TNervePakkunHide": 0x80279654,
		"TNervePakkunAppear::execute": 0x802796b0,
		"TNervePakkunStay::execute": 0x802797c4,
		"TNervePakkunGenerate::execute": 0x8027a278,
		"TNervePakkunGenerate::~TNervePakkunGenerate": 0x8027a474,
		"TStayPakkun::getSaveParam": 0x8027a4d0,
		"TStayPakkun::shoot": 0x8027a4dc,
		"TStayPakkun::kill": 0x8027a50c,
		"TStayPakkun::shootIn": 0x8027a58c,
		"TStayPakkun::isHitValid": 0x8027a6ac,
		"TStayPakkun::setBehavior": 0x8027a8bc,
		"TStayPakkun::calcRootMatrix": 0x8027a9f8,
		"TStayPakkun::genRandomItem": 0x8027aa1c,
		"TStayPakkun::setDeadAnm": 0x8027ab78,
		"TStayPakkun::reset": 0x8027aba8,
		"TStayPakkun::init": 0x8027ac10,
		"TStayPakkun::load": 0x8027ad44,
		"TPakkunSeed::forceKill": 0x8027ae28,
		"TPakkunSeed::set": 0x8027af10,
		"TPakkunSeed::rebirth": 0x8027afb8,
		"TPakkunSeed::shoot": 0x8027b1dc,
		"TPakkunSeed::appear": 0x8027b238,
		"TPakkunSeed::getNowGravity": 0x8027b260,
		"TPakkunSeed::behaveToHitGround": 0x8027b2b0,
		"TPakkunSeed::calcRootMatrix": 0x8027b3cc,
		"TPakkunSeed::behaveToHitWall": 0x8027b434,
		"TPakkunSeed::behaveToHost": 0x8027b4b8,
		"TPakkunSeed::moveObject": 0x8027b4dc,
		"TPakkunSeed::loadInit": 0x8027b5e0,
		"TPakkun::getBasNameTable": 0x8027b760,
		"TPakkun::shoot": 0x8027b76c,
		"TPakkun::shootIn": 0x8027b79c,
		"TPakkun::reset": 0x8027b7ec,
		"TPakkun::setMActorAndKeeper": 0x8027b834,
		"TPakkun::behaveToWater": 0x8027b8a0,
		"TPakkun::onShootLiner": 0x8027badc,
		"onShootLiner": 0x8027badc,
		"TPakkun::perform": 0x8027bc38,
		"TPakkun::setDeadAnm": 0x8027bda0,
		"TPakkun::setFreezeAnm": 0x8027bddc,
		"TPakkun::setWaitAnm": 0x8027be0c,
		"TPakkun::kill": 0x8027be3c,
		"TPakkun::isInhibitedForceMove": 0x8027be7c,
		"TPakkun::init": 0x8027be84,
		"TPakkun::load": 0x8027c12c,
		"TPakkun::TPakkun": 0x8027c1ec,
		"TPakkunManager::clipEnemies": 0x8027c250,
		"TPakkunManager::createEnemyInstance": 0x8027c43c,
		"TPakkunManager::createModelData": 0x8027c484,
		"TPakkunManager::loadAfter": 0x8027c4b8,
		"TPakkunManager::load": 0x8027c4d8,
		"TPakkunManager::TPakkunManager": 0x8027ca0c,
		"Enemy::PakkunRootCallback2": 0x8027ca60,
		"PakkunRootCallback2": 0x8027ca60,
		"Enemy::PakkunRootCallback": 0x8027cb14,
		"PakkunRootCallback": 0x8027cb14,
		"Enemy::PakkunSeedCallback": 0x8027cc78,
		"PakkunSeedCallback": 0x8027cc78,
		"TStayPakkun::setAfterDeadEffect": 0x8027cd88,
		"TPakkun::isCollidMove": 0x8027cd8c,
		"TPakkun::decHpByWater": 0x8027cd94,
		"TSmallEnemy::initAttacker": 0x8027cd98,
		"TPakkunManager::~TPakkunManager": 0x8027cec4,
		"Enemy::__sinit_pakkun_cpp": 0x8027cf38,
		"__sinit_pakkun_cpp": 0x8027cf38,
		"TNerveSmallEnemyChange::~TNerveSmallEnemyChange": 0x8027d24c,
		"TNerveSmallEnemyChange::execute": 0x8027d2a8,
		"TNerveSmallEnemyChange::theNerve": 0x8027d38c,
		"TNerveSmallEnemyWait::execute": 0x8027d3f0,
		"TSmallEnemy::setWaitAnm": 0x8027d488,
		"TNerveSmallEnemyWait::theNerve": 0x8027d48c,
		"TNerveSmallEnemyWait::~TNerveSmallEnemyWait": 0x8027d4f0,
		"TNerveSmallEnemyHitWaterJump::execute": 0x8027d54c,
		"TNerveSmallEnemyHitWaterJump::theNerve": 0x8027d754,
		"TNerveSmallEnemyHitWaterJump::~TNerveSmallEnemyHitWaterJump": 0x8027d7b8,
		"TNerveSmallEnemyJump::execute": 0x8027d814,
		"TNerveSmallEnemyJump::theNerve": 0x8027d924,
		"TNerveSmallEnemyJump::~TNerveSmallEnemyJump": 0x8027d988,
		"TNerveSmallEnemyFreeze::execute": 0x8027d9e4,
		"TNerveSmallEnemyFreeze::theNerve": 0x8027da84,
		"TNerveSmallEnemyFreeze::~TNerveSmallEnemyFreeze": 0x8027dae8,
		"TNerveSmallEnemyDie::execute": 0x8027db44,
		"TNerveSmallEnemyDie::~TNerveSmallEnemyDie": 0x8027de8c,
		"TSmallEnemy::setDeadAnm": 0x8027dee8,
		"TNerveSmallEnemyDie::theNerve": 0x8027deec,
		"TSmallEnemy::perform": 0x8027df50,
		"TSmallEnemy::behaveToHitOthers": 0x8027dfcc,
		"behaveToHitOthers": 0x8027dfcc,
		"TSmallEnemy::isHitWallInBound": 0x8027e114,
		"isHitWallInBound": 0x8027e114,
		"TSmallEnemy::isEaten": 0x8027e24c,
		"isEaten": 0x8027e24c,
		"TSmallEnemy::expandCollision": 0x8027e2e8,
		"expandCollision": 0x8027e2e8,
		"TSmallEnemy::setBckAnm": 0x8027e424,
		"TSmallEnemy::generateEffectColumWater": 0x8027e498,
		"TSmallEnemy::isFindMarioFromParam": 0x8027e528,
		"isFindMarioFromParam": 0x8027e528,
		"TSmallEnemy::isMarioInWater": 0x8027e5e4,
		"isMarioInWater": 0x8027e5e4,
		"TSmallEnemy::isFindMario": 0x8027e6b4,
		"TSmallEnemy::kill": 0x8027e820,
		"TSmallEnemy::decHpByWater": 0x8027e9b0,
		"TSmallEnemy::changeOut": 0x8027e9fc,
		"TSmallEnemy::scalingChangeActor": 0x8027ead8,
		"TSmallEnemy::changeMove": 0x8027eb6c,
		"changeMove": 0x8027eb6c,
		"TSmallEnemy::getChangeBlockTime": 0x8027efb0,
		"TSmallEnemy::changeByJuice": 0x8027efb8,
		"TSmallEnemy::receiveMessage": 0x8027f220,
		"TSmallEnemy::updateAnmSound": 0x8027f450,
		"TSmallEnemy::moveObject": 0x8027f470,
		"TSmallEnemy::isCollidMove": 0x8027f8cc,
		"TSmallEnemy::generateItem": 0x8027f938,
		"TSmallEnemy::setAfterDeadEffect": 0x8027fa40,
		"TSmallEnemy::genEventCoin": 0x8027fb38,
		"TSmallEnemy::genRandomItem": 0x8027fe3c,
		"TSmallEnemy::forceKill": 0x8027fecc,
		"TSmallEnemy::reset": 0x802800f0,
		"TSmallEnemy::attackToMario": 0x80280524,
		"TSmallEnemy::sendAttackMsgToMario": 0x80280634,
		"TSmallEnemy::behaveToWater": 0x80280658,
		"TSmallEnemy::loadAfter": 0x802807d0,
		"TSmallEnemy::load": 0x80280804,
		"TSmallEnemy::init": 0x80280874,
		"TSmallEnemy::setMActorAndKeeper": 0x80280c00,
		"TSmallEnemy::TSmallEnemy": 0x80280c68,
		"TSmallEnemyManager::getHolder": 0x80280cf4,
		"getHolder": 0x80280cf4,
		"TSmallEnemyManager::createEnemies": 0x80280d68,
		"TSmallEnemyManager::loadAfter": 0x80280da8,
		"TSmallEnemyManager::load": 0x80280e00,
		"TSmallEnemyManager::createModelData": 0x80280e20,
		"TSmallEnemyManager::TSmallEnemyManager": 0x80280e54,
		"TSmallEnemyParams::TSmallEnemyParams": 0x80280ea0,
		"Enemy::__sinit_smallEnemy_cpp": 0x802813e4,
		"__sinit_smallEnemy_cpp": 0x802813e4,
		"TSpider::bind": 0x802816e8,
		"TSpider::~TSpider": 0x80281c5c,
		"TSpider::TSpider": 0x80281cc0,
		"TSplinePath::calcSpline": 0x80281d14,
		"calcSpline": 0x80281d14,
		"TSplinePath::calcTable": 0x80281df8,
		"calcTable": 0x80281df8,
		"TSplinePath::makeTable": 0x80281f58,
		"makeTable": 0x80281f58,
		"TSplinePath::TSplinePath": 0x802822bc,
		"TNerveTypicalGraphWander::~TNerveTypicalGraphWander": 0x802823d4,
		"TNerveTypicalGraphWander::execute": 0x80282430,
		"TNerveTypicalGraphWander::theNerve": 0x80282534,
		"TTypicalManager::createEnemyInstance": 0x80282598,
		"TTypicalManager::load": 0x80282620,
		"TTypicalManager::TTypicalManager": 0x802826e0,
		"TTypicalEnemy::init": 0x8028271c,
		"TTypicalEnemy::TTypicalEnemy": 0x802827d4,
		"TTypicalManager::~TTypicalManager": 0x8028283c,
		"TWalker::setMode": 0x80282914,
		"setMode": 0x80282914,
		"TWalker::bind": 0x80282980,
		"TWalker::reset": 0x802835e4,
		"TWalker::~TWalker": 0x80283604,
		"TWalker::TWalker": 0x8028367c,
		"TSolidStack<TBGCheckData_const*>::~TSolidStack": 0x80283738,
		"Enemy::calcFarthestVertex": 0x80283784,
		"calcFarthestVertex": 0x80283784,
		"TNerveWalkerTraceMario::~TNerveWalkerTraceMario": 0x8028394c,
		"TNerveWalkerTraceMario::execute": 0x802839a8,
		"TNerveWalkerTraceMario::theNerve": 0x80283c64,
		"TNerveWalkerEscape::execute": 0x80283cc8,
		"TNerveWalkerEscape::theNerve": 0x80283e28,
		"TNerveWalkerEscape::~TNerveWalkerEscape": 0x80283e8c,
		"TNerveWalkerPostAttack::execute": 0x80283ee8,
		"TNerveWalkerPostAttack::theNerve": 0x80283f80,
		"TNerveWalkerPostAttack::~TNerveWalkerPostAttack": 0x80283fe4,
		"TNerveWalkerAttack::execute": 0x80284040,
		"TNerveWalkerAttack::theNerve": 0x802841bc,
		"TNerveWalkerAttack::~TNerveWalkerAttack": 0x80284220,
		"TNerveWalkerGraphWander::execute": 0x8028427c,
		"TNerveWalkerGraphWander::theNerve": 0x80284358,
		"TNerveWalkerGraphWander::~TNerveWalkerGraphWander": 0x802843bc,
		"TNerveWalkerGenerate::execute": 0x80284418,
		"TNerveWalkerGenerate::theNerve": 0x802844f8,
		"TNerveWalkerGenerate::~TNerveWalkerGenerate": 0x8028455c,
		"TWalkerEnemy::initialGraphNode": 0x802845b8,
		"initialGraphNode": 0x802845b8,
		"TWalkerEnemy::isReachedToGoalXZ": 0x802845e4,
		"TWalkerEnemy::isResignationAttack": 0x802846ac,
		"TWalkerEnemy::initAttacker": 0x80284788,
		"TWalkerEnemy::behaveToFindMario": 0x802847ac,
		"TWalkerEnemy::walkBehavior": 0x80284ac4,
		"TWalkerEnemy::reset": 0x80284bd8,
		"TWalkerEnemy::attackToMario": 0x80284d3c,
		"TWalkerEnemy::moveObject": 0x80284ef0,
		"TWalkerEnemy::init": 0x802850c0,
		"TWalkerEnemy::TWalkerEnemy": 0x802851ec,
		"TWalkerEnemyParams::TWalkerEnemyParams": 0x80285230,
		"Enemy::__sinit_walkerEnemy_cpp": 0x80285374,
		"__sinit_walkerEnemy_cpp": 0x80285374,
		"TNerveBGRoll::~TNerveBGRoll": 0x80285678,
		"TNerveBGRoll::execute": 0x802856d4,
		"MActorAnmEach<J3DAnmTransformKey>::setFrameCtrl": 0x80285df0,
		"setFrameCtrl": 0x80285df0,
		"MActorAnmDataEach<J3DAnmTransformKey>::getAnmPtr": 0x80285e7c,
		"getAnmPtr": 0x80285e7c,
		"TMActorKeeper::getMActorAnmData": 0x80285ea0,
		"TNerveBGRoll::theNerve": 0x80285ea8,
		"TNerveBGPolDrop::execute": 0x80285f0c,
		"TNerveBGPolDrop::~TNerveBGPolDrop": 0x80286248,
		"TNerveBGPolDrop::theNerve": 0x802862a4,
		"TNerveBGPollute::execute": 0x80286308,
		"TNerveBGPollute::theNerve": 0x80286578,
		"TNerveBGPollute::~TNerveBGPollute": 0x802865dc,
		"TNerveBGDie::execute": 0x80286638,
		"TNerveBGDie::theNerve": 0x80286d4c,
		"TNerveBGDie::~TNerveBGDie": 0x80286db0,
		"TNerveBGTug::execute": 0x80286e0c,
		"TNerveBGTug::theNerve": 0x802872a8,
		"TNerveBGTug::~TNerveBGTug": 0x8028730c,
		"TNerveBGTentacleDamage::execute": 0x80287368,
		"TNerveBGTentacleDamage::~TNerveBGTentacleDamage": 0x80287630,
		"TNerveBGTentacleDamage::theNerve": 0x8028768c,
		"TNerveBGBeakDamage::execute": 0x802876f0,
		"TNerveBGBeakDamage::theNerve": 0x80287bd8,
		"TNerveBGBeakDamage::~TNerveBGBeakDamage": 0x80287c3c,
		"TNerveBGEyeDamage::execute": 0x80287c98,
		"TNerveBGEyeDamage::theNerve": 0x80287f3c,
		"TNerveBGEyeDamage::~TNerveBGEyeDamage": 0x80287fa0,
		"TNerveBGWait::execute": 0x80287ffc,
		"TNerveBGWait::theNerve": 0x80288400,
		"TNerveBGWait::~TNerveBGWait": 0x80288464,
		"TBossGessoManager::load": 0x802884c0,
		"TBossGessoManager::initJParticle": 0x80288534,
		"TBossGessoManager::createModelData": 0x80288a18,
		"TBossGessoManager::TBossGessoManager": 0x80288a4c,
		"TBossGesso::perform": 0x80288a88,
		"TBossGesso::calcRootMatrix": 0x80289468,
		"TBossGesso::reset": 0x80289630,
		"TBossGesso::moveObject": 0x802896f8,
		"Enemy::MsGetRotFromZaxisY": 0x80289dfc,
		"MsGetRotFromZaxisY": 0x80289dfc,
		"Enemy::SMS_GetMarioPos": 0x80289ec4,
		"SMS_GetMarioPos": 0x80289ec4,
		"TBossGesso::doAttackShoot": 0x80289ecc,
		"doAttackShoot": 0x80289ecc,
		"TBossGesso::doAttackUnison": 0x8028a0d8,
		"doAttackUnison": 0x8028a0d8,
		"TBossGesso::doAttackSkipRope": 0x8028a388,
		"doAttackSkipRope": 0x8028a388,
		"TBossGesso::doAttackDouble": 0x8028a564,
		"doAttackDouble": 0x8028a564,
		"TBossGesso::doAttackSingle": 0x8028a818,
		"doAttackSingle": 0x8028a818,
		"TBossGesso::receiveMessage": 0x8028b270,
		"TBossGesso::getBasNameTable": 0x8028b2c8,
		"TBossGesso::beakHeld": 0x8028b2d4,
		"beakHeld": 0x8028b2d4,
		"TBossGesso::tentacleHeld": 0x8028b2f0,
		"tentacleHeld": 0x8028b2f0,
		"TBossGesso::launchPolDrop": 0x8028b358,
		"TBossGesso::changeAllTentacleState": 0x8028b454,
		"changeAllTentacleState": 0x8028b454,
		"TBossGesso::gotTentacleDamage": 0x8028b4f8,
		"gotTentacleDamage": 0x8028b4f8,
		"TBossGesso::changeAttackMode": 0x8028b684,
		"changeAttackMode": 0x8028b684,
		"TBossGesso::stopIfRoll": 0x8028bca0,
		"stopIfRoll": 0x8028bca0,
		"TBossGesso::is2ndFightNow": 0x8028bdbc,
		"is2ndFightNow": 0x8028bdbc,
		"TBossGesso::showMessage": 0x8028bddc,
		"TBossGesso::lenFromToeToMario": 0x8028be68,
		"lenFromToeToMario": 0x8028be68,
		"TBossGesso::rumblePad": 0x8028c004,
		"TBossGesso::init": 0x8028c164,
		"TBossGesso::TBossGesso": 0x8028ca24,
		"TBGBinder::bind": 0x8028caf8,
		"TBGBodyHit::perform": 0x8028d14c,
		"TBGBodyHit::receiveMessage": 0x8028d1b4,
		"TBGEyeHit::perform": 0x8028d21c,
		"TBGEyeHit::receiveMessage": 0x8028d26c,
		"TBGBeakHit::perform": 0x8028d528,
		"TBGBeakHit::receiveMessage": 0x8028db78,
		"TBGBeakHit::moveRequest": 0x8028e2c8,
		"TBGBeakHit::getTakingMtx": 0x8028e478,
		"TBossGessoParams::TBossGessoParams": 0x8028e480,
		"TBossGessoManager::~TBossGessoManager": 0x8028ea2c,
		"TBGBinder::~TBGBinder": 0x8028eafc,
		"TBossGessoMtxCalc::~TBossGessoMtxCalc": 0x8028eb60,
		"Enemy::__sinit_bossgesso_cpp": 0x8028edb0,
		"__sinit_bossgesso_cpp": 0x8028edb0,
		"TNerveElecCarapaceReturn::~TNerveElecCarapaceReturn": 0x8028f108,
		"TNerveElecCarapaceReturn::execute": 0x8028f164,
		"TNerveElecNokonokoFreeze::~TNerveElecNokonokoFreeze": 0x8028f4f4,
		"TNerveElecCarapaceWait::execute": 0x8028f550,
		"TNerveElecCarapaceWait::~TNerveElecCarapaceWait": 0x8028f56c,
		"TNerveElecCarapaceMove::execute": 0x8028f5c8,
		"TNerveElecNokonokoCollect::~TNerveElecNokonokoCollect": 0x8028fac0,
		"TNerveElecCarapaceMove::~TNerveElecCarapaceMove": 0x8028fb1c,
		"TNerveElecNokonokoAttack::execute": 0x8028fb78,
		"TNerveElecNokonokoAttack::~TNerveElecNokonokoAttack": 0x8028fc04,
		"TNerveElecNokonokoRebirth::execute": 0x8028fc60,
		"TNerveElecNokonokoRebirth::~TNerveElecNokonokoRebirth": 0x8028fd78,
		"TNerveElecNokonokoFreeze::execute": 0x8028fdd4,
		"TNerveElecNokonokoTurn::execute": 0x802900d8,
		"TNerveElecNokonokoTurn::~TNerveElecNokonokoTurn": 0x802902fc,
		"TNerveElecNokonokoCollect::execute": 0x80290358,
		"TNerveElecNokonokoShoot::execute": 0x80290634,
		"TNerveElecNokonokoShoot::~TNerveElecNokonokoShoot": 0x8029082c,
		"TElecCarapace::reflect": 0x80290888,
		"reflect": 0x80290888,
		"TElecCarapace::receiveMessage": 0x80290a9c,
		"TElecCarapace::sendMessage": 0x80290b2c,
		"TElecCarapace::calcRootMatrix": 0x80290d24,
		"TElecCarapace::bind": 0x80290f20,
		"TElecCarapace::shoot": 0x80290f60,
		"TElecCarapace::appear": 0x80291254,
		"TElecCarapace::getNowGravity": 0x802912bc,
		"TElecCarapace::behaveToHitWall": 0x802912f0,
		"TElecCarapace::kill": 0x802913f0,
		"TElecCarapace::behaveToHitGround": 0x80291410,
		"TElecCarapace::setBehavior": 0x802914d0,
		"TElecCarapace::perform": 0x80291538,
		"TElecCarapace::loadInit": 0x80291688,
		"TElecCarapace::TElecCarapace": 0x80291878,
		"TElecNokonoko::genRandomItem": 0x802918f4,
		"TElecNokonoko::setMeltAnm": 0x802919a8,
		"TElecNokonoko::setDeadAnm": 0x80291a7c,
		"TElecNokonoko::setRunAnm": 0x80291aac,
		"TElecNokonoko::setWalkAnm": 0x80291afc,
		"TElecNokonoko::setWaitAnm": 0x80291b4c,
		"TElecNokonoko::getBasNameTable": 0x80291b84,
		"TElecNokonoko::behaveToWater": 0x80291b90,
		"TElecNokonoko::behaveToFindMario": 0x80291d38,
		"TElecNokonoko::isResignationAttack": 0x80291ecc,
		"TElecNokonoko::receiveMessage": 0x80292024,
		"TElecNokonoko::sendAttackMsgToMario": 0x80292194,
		"TElecNokonoko::calcRootMatrix": 0x802921d0,
		"TElecNokonoko::attackToMario": 0x8029256c,
		"TElecNokonoko::moveObject": 0x8029277c,
		"TElecNokonoko::setMActorAndKeeper": 0x802927f4,
		"TElecNokonoko::load": 0x8029288c,
		"TElecNokonoko::rest": 0x802928cc,
		"rest": 0x802928cc,
		"TElecNokonoko::init": 0x80292900,
		"TElecNokonoko::TElecNokonoko": 0x80292a78,
		"TElecNokonokoManager::perform": 0x80292acc,
		"TElecNokonokoManager::clipEnemies": 0x80292b6c,
		"TElecNokonokoManager::createModelData": 0x80292c94,
		"TElecNokonokoManager::createEnemyInstance": 0x80292cc8,
		"TElecNokonokoManager::initSetEnemies": 0x80292d34,
		"TElecNokonokoManager::load": 0x80292d38,
		"TElecNokonokoManager::TElecNokonokoManager": 0x80292f04,
		"TElecCarapace::rebirth": 0x80292fc4,
		"TElecCarapace::recoverScale": 0x80292fc8,
		"TElecCarapace::getPhaseShift": 0x80292fcc,
		"TElecNokonokoManager::~TElecNokonokoManager": 0x80293084,
		"Enemy::__sinit_elecNokonoko_cpp": 0x802930f8,
		"__sinit_elecNokonoko_cpp": 0x802930f8,
		"TNerveKageMarioModokiWait::~TNerveKageMarioModokiWait": 0x80293404,
		"TNerveKageMarioModokiWait::execute": 0x80293460,
		"TKageMarioModoki::init": 0x802935fc,
		"TKageMarioModoki::load": 0x80293700,
		"TKageMarioModokiManager::createModelData": 0x80293740,
		"TKageMarioModokiManager::createEnemyInstance": 0x80293774,
		"TKageMarioModokiManager::load": 0x802937d0,
		"TNerveTelesaTrample::execute": 0x8029383c,
		"TNerveTelesaTrample::~TNerveTelesaTrample": 0x8029389c,
		"TNerveTelesaAttackMario::execute": 0x802938f8,
		"TNerveTelesaAttackMario::~TNerveTelesaAttackMario": 0x80293bc4,
		"TNerveTelesaFreeze::execute": 0x80293c20,
		"TNerveTelesaFreeze::~TNerveTelesaFreeze": 0x80293e40,
		"TNerveTelesaDie::execute": 0x80293e9c,
		"TNerveTelesaDie::~TNerveTelesaDie": 0x80294100,
		"TNerveTelesaImitate::execute": 0x8029415c,
		"TNerveTelesaImitate::~TNerveTelesaImitate": 0x8029450c,
		"TMarioModokiTelesa::init": 0x80294568,
		"TMarioModokiTelesa::load": 0x802945fc,
		"TMarioModokiTelesa::TMarioModokiTelesa": 0x802949b8,
		"TBoxTelesa::isHitValid": 0x80294aa0,
		"TBoxTelesa::reset": 0x80294bd8,
		"TBoxTelesa::load": 0x80294e84,
		"TBoxTelesa::TBoxTelesa": 0x80294f8c,
		"TLoopTelesa::load": 0x80294fd0,
		"TLoopTelesa::TLoopTelesa": 0x80295048,
		"TSeeTelesa::load": 0x8029508c,
		"TSeeTelesa::TSeeTelesa": 0x80295114,
		"TTelesa::changeTevKColor": 0x80295158,
		"changeTevKColor": 0x80295158,
		"TTelesa::isCollidMove": 0x80295370,
		"TTelesa::setAttacker": 0x80295390,
		"setAttacker": 0x80295390,
		"TTelesa::initItemAttacker": 0x80295504,
		"initItemAttacker": 0x80295504,
		"TTelesa::initAttacker": 0x80295770,
		"TTelesa::kill": 0x80295a54,
		"TTelesa::forceKill": 0x80295b90,
		"TTelesa::getGravityY": 0x80295c68,
		"TTelesa::reduceFlyForce": 0x80295c8c,
		"reduceFlyForce": 0x80295c8c,
		"TTelesa::setWaitAnm": 0x80295d28,
		"TTelesa::setWalkAnm": 0x80295d58,
		"TTelesa::getBasNameTable": 0x80295dcc,
		"TTelesa::changeOut": 0x80295dd8,
		"TTelesa::scalingChangeActor": 0x80295eb4,
		"TTelesa::changeByJuice": 0x80295f30,
		"TTelesa::isReachedToGoal": 0x80296150,
		"TTelesa::bind": 0x80296218,
		"TTelesa::moveObject": 0x8029655c,
		"TTelesa::calcRootMatrix": 0x80296590,
		"TTelesa::walkBehavior": 0x80296798,
		"TTelesa::behaveToWater": 0x80296958,
		"TTelesa::attackToMario": 0x80296be8,
		"TTelesa::setBehavior": 0x80296c64,
		"TTelesa::drawObject": 0x80296dc8,
		"TTelesa::perform": 0x80296df4,
		"TTelesa::reset": 0x80296f50,
		"TTelesa::setMActorAndKeeper": 0x802971f4,
		"TTelesa::init": 0x80297260,
		"TTelesa::load": 0x802974f8,
		"TTelesa::TTelesa": 0x80297558,
		"TTelesaManager::setFlagOutOfCube": 0x802975f8,
		"TTelesaManager::telesaForceKill": 0x802976cc,
		"telesaForceKill": 0x802976cc,
		"TTelesaManager::createModelData": 0x80297794,
		"TTelesaManager::createEnemies": 0x802977c8,
		"TTelesaManager::createEnemyInstance": 0x802978a8,
		"TTelesaManager::load": 0x802978ec,
		"TTelesaManager::TTelesaManager": 0x8029799c,
		"TTelesaSaveLoadParams::TTelesaSaveLoadParams": 0x802979e8,
		"TKageMarioModokiManager::~TKageMarioModokiManager": 0x80297dc8,
		"TTelesa::isFindMario": 0x80297e3c,
		"TTelesa::decHpByWater": 0x80297e44,
		"TTelesa::isInhibitedForceMove": 0x80297e48,
		"TTelesa::getChangeBlockTime": 0x80297e50,
		"TBoxTelesa::isEatenByYosshi": 0x80297ef4,
		"TTelesaManager::~TTelesaManager": 0x802980d0,
		"Enemy::__sinit_telesa_cpp": 0x80298144,
		"__sinit_telesa_cpp": 0x80298144,
		"TNerveFireWanwanEscape::~TNerveFireWanwanEscape": 0x80298470,
		"TNerveFireWanwanEscape::execute": 0x802984cc,
		"TNerveFireWanwanRecover::~TNerveFireWanwanRecover": 0x8029876c,
		"TNerveFireWanwanEscape::theNerve": 0x802987c8,
		"TNerveFireWanwanFreeze::execute": 0x8029882c,
		"TNerveFireWanwanFreeze::theNerve": 0x8029899c,
		"TNerveFireWanwanFreeze::~TNerveFireWanwanFreeze": 0x80298a00,
		"TNerveFireWanwanFly::execute": 0x80298a5c,
		"TNerveFireWanwanFly::~TNerveFireWanwanFly": 0x80298d58,
		"TNerveFireWanwanHungTail::execute": 0x80298db4,
		"TNerveFireWanwanHungTail::~TNerveFireWanwanHungTail": 0x8029901c,
		"TNerveFireWanwanDie::execute": 0x80299078,
		"TNerveFireWanwanDie::theNerve": 0x802992dc,
		"TNerveFireWanwanDie::~TNerveFireWanwanDie": 0x80299340,
		"TNerveFireWanwanRecover::execute": 0x8029939c,
		"TNerveFireWanwanRecover::theNerve": 0x802995e0,
		"TNerveFireWanwanRecoverGraph::execute": 0x80299644,
		"TNerveFireWanwanGraphWander::~TNerveFireWanwanGraphWander": 0x80299be8,
		"JGeometry::TQuat4<float><float>::slerp": 0x80299c90,
		"slerp": 0x80299c90,
		"TNerveFireWanwanRecoverGraph::~TNerveFireWanwanRecoverGraph": 0x8029a034,
		"TNerveFireWanwanTired::execute": 0x8029a090,
		"TNerveFireWanwanFindMario::~TNerveFireWanwanFindMario": 0x8029a258,
		"TNerveFireWanwanTired::~TNerveFireWanwanTired": 0x8029a2b4,
		"TNerveFireWanwanAttack::execute": 0x8029a310,
		"TNerveFireWanwanAttack::~TNerveFireWanwanAttack": 0x8029a5c0,
		"TNerveFireWanwanFindMario::execute": 0x8029a61c,
		"TNerveFireWanwanTurn::execute": 0x8029ab30,
		"TNerveFireWanwanTurn::theNerve": 0x8029ad4c,
		"TNerveFireWanwanTurn::~TNerveFireWanwanTurn": 0x8029adb0,
		"TNerveFireWanwanGraphWander::execute": 0x8029ae0c,
		"TNerveFireWanwanGraphWander::theNerve": 0x8029afa4,
		"TFireWanwan::isCollidMove": 0x8029b008,
		"TFireWanwan::doKeepDistance": 0x8029b010,
		"TFireWanwan::getBasNameTable": 0x8029b024,
		"TFireWanwan::getGravityY": 0x8029b030,
		"TFireWanwan::checkWalls": 0x8029b158,
		"TFireWanwan::bindPoint": 0x8029b374,
		"bindPoint": 0x8029b374,
		"TFireWanwan::bindBody": 0x8029b74c,
		"bindBody": 0x8029b74c,
		"TFireWanwan::bind": 0x8029bac4,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setQuat": 0x8029c2c8,
		"setQuat": 0x8029c2c8,
		"TFireWanwan::attackToMario": 0x8029c368,
		"TFireWanwan::sendAttackMsgToMario": 0x8029c544,
		"TTakeActor::isTaken": 0x8029c548,
		"isTaken": 0x8029c548,
		"TFireWanwan::initEscapeNextGraphNode": 0x8029c564,
		"initEscapeNextGraphNode": 0x8029c564,
		"TFireWanwan::checkHitActors": 0x8029c768,
		"TFireWanwan::emitEffects": 0x8029ca34,
		"TFireWanwan::updatePollute": 0x8029cf90,
		"updatePollute": 0x8029cf90,
		"TFireWanwan::updateRumble": 0x8029d158,
		"updateRumble": 0x8029d158,
		"TFireWanwan::moveObject": 0x8029d350,
		"TFireWanwan::calcRootMatrix": 0x8029da38,
		"TFireWanwan::perform": 0x8029dc00,
		"TFireWanwan::isHitValid": 0x8029dd48,
		"TFireWanwan::kill": 0x8029dd50,
		"TFireWanwan::behaveToWater": 0x8029de68,
		"TFireWanwan::receiveMessage": 0x8029e1f0,
		"TFireWanwan::isMissMario": 0x8029e348,
		"isMissMario": 0x8029e348,
		"TFireWanwan::isFindMario": 0x8029e508,
		"TFireWanwan::reset": 0x8029e574,
		"TFireWanwan::setMActorAndKeeper": 0x8029e6c8,
		"TFireWanwan::init": 0x8029e734,
		"TFireWanwan::TFireWanwan": 0x8029ea2c,
		"TFireWanwanTailHit::getHostPos": 0x8029ea88,
		"getHostPos": 0x8029ea88,
		"TFireWanwanTailHit::moveRequest": 0x8029ea94,
		"TFireWanwanTailHit::getTakingMtx": 0x8029ebb8,
		"TFireWanwanTailHit::movementBody": 0x8029ebc0,
		"movementBody": 0x8029ebc0,
		"TFireWanwanTailHit::performNodes": 0x8029efd4,
		"performNodes": 0x8029efd4,
		"TFireWanwanTailHit::perform": 0x8029f29c,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::operator_[]": 0x8029f8f8,
		"operator_[]": 0x8029f8f8,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::size": 0x8029f908,
		"size": 0x8029f908,
		"TFireWanwanTailHit::init": 0x8029f910,
		"TTailRubber::Node::Node": 0x8029fde8,
		"TFireWanwanTailHit::receiveMessage": 0x8029fdec,
		"TFireWanwanTailNode::perform": 0x802a0070,
		"TFireWanwanManager::perform": 0x802a0260,
		"TFireWanwanManager::createModelData": 0x802a0508,
		"TFireWanwanManager::load": 0x802a053c,
		"TFireWanwanManager::TFireWanwanManager": 0x802a0594,
		"TFireWanwanSaveLoadParams::TFireWanwanSaveLoadParams": 0x802a05f0,
		"TTailRubber::getLength": 0x802a0ba8,
		"TTailRubber::restrict": 0x802a0c88,
		"restrict": 0x802a0c88,
		"TTailRubber::adjust": 0x802a10fc,
		"TTailRubber::bindOne": 0x802a15b4,
		"bindOne": 0x802a15b4,
		"TFireWanwanManager::~TFireWanwanManager": 0x802a1808,
		"MyUtil::value_lerp": 0x802a187c,
		"value_lerp": 0x802a187c,
		"Enemy::__sinit_fireWanwan_cpp": 0x802a19d4,
		"__sinit_fireWanwan_cpp": 0x802a19d4,
		"TStageEnemyInfo::~TStageEnemyInfo": 0x802a1ce0,
		"TStageEnemyInfoTable::getMatchedInfo": 0x802a1d44,
		"getMatchedInfo": 0x802a1d44,
		"TStageEnemyInfoTable::TStageEnemyInfoTable": 0x802a1e58,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::~TNameRefPtrAryT": 0x802a1ee4,
		"TStageEnemyInfo::load": 0x802a1f5c,
		"TStageEnemyInfoTable::~TStageEnemyInfoTable": 0x802a1fe8,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::loadAfter": 0x802a2070,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::searchF": 0x802a20d0,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::load": 0x802a216c,
		"TOneShotGenerator::receiveMessage": 0x802a2300,
		"TOneShotGenerator::loadAfter": 0x802a23f8,
		"TOneShotGenerator::load": 0x802a252c,
		"TOneShotGenerator::TOneShotGenerator": 0x802a257c,
		"TGenerator::perform": 0x802a25dc,
		"TGenerator::load": 0x802a26fc,
		"TGenerator::TGenerator": 0x802a28a4,
		"TGenerator::~TGenerator": 0x802a2928,
		"TNerveBPCannonL::~TNerveBPCannonL": 0x802a29a4,
		"TNerveBPCannonL::execute": 0x802a2a00,
		"TNerveBPWaitL::~TNerveBPWaitL": 0x802a2b38,
		"TNerveBPCannonL::theNerve": 0x802a2b94,
		"TNerveBPWaitL::execute": 0x802a2bf8,
		"TNerveBPWaitL::theNerve": 0x802a2e2c,
		"TNerveBPBreakSleep::execute": 0x802a2e90,
		"TNerveBPTakeOff::~TNerveBPTakeOff": 0x802a2f84,
		"TNerveBPBreakSleep::theNerve": 0x802a2fe0,
		"TNerveBPBreakSleep::~TNerveBPBreakSleep": 0x802a3044,
		"TNerveBPSleep::execute": 0x802a30a0,
		"TNerveBPSleep::theNerve": 0x802a30d8,
		"TNerveBPSleep::~TNerveBPSleep": 0x802a313c,
		"TNerveBPFall::execute": 0x802a3198,
		"TNerveBPTornado::~TNerveBPTornado": 0x802a36b4,
		"TNerveBPWait::~TNerveBPWait": 0x802a3710,
		"TNerveBPVomit::~TNerveBPVomit": 0x802a376c,
		"TNerveBPFall::theNerve": 0x802a37c8,
		"TNerveBPFall::~TNerveBPFall": 0x802a382c,
		"TNerveBPHover::execute": 0x802a3888,
		"TNerveBPFly::~TNerveBPFly": 0x802a3c10,
		"TNerveBPFlyPivot::~TNerveBPFlyPivot": 0x802a3c6c,
		"TNerveBPFlyCannon::~TNerveBPFlyCannon": 0x802a3cc8,
		"TNerveBPHover::~TNerveBPHover": 0x802a3d24,
		"TNerveBPHover::theNerve": 0x802a3d80,
		"TNerveBPFlyPivot::execute": 0x802a3de4,
		"TNerveBPFlyPivot::theNerve": 0x802a3e90,
		"TNerveBPFlyCannon::execute": 0x802a3ef4,
		"TNerveBPFlyCannon::theNerve": 0x802a3f88,
		"TNerveBPTouchDown::execute": 0x802a3fec,
		"TNerveBPTouchDown::theNerve": 0x802a417c,
		"TNerveBPTouchDown::~TNerveBPTouchDown": 0x802a41e0,
		"TNerveBPFly::execute": 0x802a423c,
		"TNerveBPFly::theNerve": 0x802a4508,
		"TNerveBPTakeOff::execute": 0x802a456c,
		"TNerveBPTakeOff::theNerve": 0x802a4794,
		"TNerveBPDie::execute": 0x802a47f8,
		"TNerveBPDie::theNerve": 0x802a4910,
		"TNerveBPDie::~TNerveBPDie": 0x802a4974,
		"TNerveBPPreDie::execute": 0x802a49d0,
		"TNerveBPPreDie::theNerve": 0x802a4ba8,
		"TNerveBPPreDie::~TNerveBPPreDie": 0x802a4c0c,
		"TNerveBPJumpReact::execute": 0x802a4c68,
		"TNerveBPJumpReact::theNerve": 0x802a4ccc,
		"TNerveBPJumpReact::~TNerveBPJumpReact": 0x802a4d30,
		"TNerveBPStompReact::execute": 0x802a4d8c,
		"TNerveBPStompReact::theNerve": 0x802a4ec8,
		"TNerveBPStompReact::~TNerveBPStompReact": 0x802a4f2c,
		"TNerveBPSwing::execute": 0x802a4f88,
		"TNerveBPSwing::theNerve": 0x802a5038,
		"TNerveBPSwing::~TNerveBPSwing": 0x802a509c,
		"TNerveBPGetUp::execute": 0x802a50f8,
		"TNerveBPGetUp::theNerve": 0x802a51b0,
		"TNerveBPGetUp::~TNerveBPGetUp": 0x802a5214,
		"TNerveBPTumbleOut::execute": 0x802a5270,
		"TNerveBPTumbleOut::theNerve": 0x802a54ec,
		"TNerveBPTumbleOut::~TNerveBPTumbleOut": 0x802a5550,
		"TNerveBPTumble::execute": 0x802a55ac,
		"TNerveBPTumble::theNerve": 0x802a5724,
		"TNerveBPTumble::~TNerveBPTumble": 0x802a5788,
		"TNerveBPTumbleIn::execute": 0x802a57e4,
		"TNerveBPTumbleIn::theNerve": 0x802a5938,
		"TNerveBPTumbleIn::~TNerveBPTumbleIn": 0x802a599c,
		"TNerveBPSwallow::execute": 0x802a59f8,
		"TNerveBPSwallow::theNerve": 0x802a5be8,
		"TNerveBPSwallow::~TNerveBPSwallow": 0x802a5c4c,
		"TNerveBPPivot::execute": 0x802a5ca8,
		"TNerveBPPivot::theNerve": 0x802a5e00,
		"TNerveBPPivot::~TNerveBPPivot": 0x802a5e64,
		"TNerveBPTornado::execute": 0x802a5ec0,
		"TNerveBPTornado::theNerve": 0x802a603c,
		"TNerveBPVomit::execute": 0x802a60a0,
		"TNerveBPVomit::theNerve": 0x802a6410,
		"TNerveBPCannon::execute": 0x802a6474,
		"TNerveBPCannon::theNerve": 0x802a6598,
		"TNerveBPCannon::~TNerveBPCannon": 0x802a65fc,
		"TNerveBPWait::execute": 0x802a6658,
		"TNerveBPWait::theNerve": 0x802a72b0,
		"TBossPakkunManager::load": 0x802a7314,
		"TBossPakkunManager::createModelData": 0x802a75d8,
		"TBossPakkunManager::TBossPakkunManager": 0x802a7634,
		"TBossPakkun::perform": 0x802a7680,
		"TBossPakkun::receiveMessage": 0x802a7e50,
		"TBossPakkun::kill": 0x802a80a0,
		"TBossPakkun::setGroundCollision": 0x802a8120,
		"TBossPakkun::getBasNameTable": 0x802a8204,
		"TBossPakkun::changeBck": 0x802a8210,
		"TBossPakkun::launchPolDrop": 0x802a8588,
		"TBossPakkun::gotHipDropDamage": 0x802a8790,
		"gotHipDropDamage": 0x802a8790,
		"TBossPakkun::showMessage": 0x802a8d38,
		"TBossPakkun::rumblePad": 0x802a8dac,
		"TBossPakkun::checkMarioRiding": 0x802a8f0c,
		"TBossPakkun::init": 0x802a8fb4,
		"TBossPakkun::TBossPakkun": 0x802a9774,
		"TBossPakkunMtxCalc::calcHeadDir": 0x802a9894,
		"calcHeadDir": 0x802a9894,
		"TBossPakkunMtxCalc::calcBellyScale": 0x802a9c58,
		"calcBellyScale": 0x802a9c58,
		"TBPNavel::perform": 0x802a9ec8,
		"TBPNavel::receiveMessage": 0x802a9f30,
		"TBPHeadHit::perform": 0x802aa040,
		"TBPHeadHit::throwActor": 0x802aa104,
		"throwActor": 0x802aa104,
		"TBPHeadHit::receiveMessage": 0x802aa354,
		"TBPTornado::perform": 0x802aa920,
		"TBPTornado::TBPTornado": 0x802ab04c,
		"TBPVomit::perform": 0x802ab140,
		"TBPPolDrop::perform": 0x802ab210,
		"TBPPolDrop::move": 0x802ab484,
		"TBPPolDrop::TBPPolDrop": 0x802ab790,
		"TBossPakkunParams::TBossPakkunParams": 0x802ab8cc,
		"TBossPakkunManager::~TBossPakkunManager": 0x802abd24,
		"TBossPakkunMtxCalc::~TBossPakkunMtxCalc": 0x802abdf4,
		"TBPVomit::~TBPVomit": 0x802ac02c,
		"Enemy::__sinit_bosspakkun_cpp": 0x802ac124,
		"__sinit_bosspakkun_cpp": 0x802ac124,
		"TNerveTobiPukuSwimWander::~TNerveTobiPukuSwimWander": 0x802ac45c,
		"TNerveTobiPukuSwimWander::execute": 0x802ac4b8,
		"TNerveTobiPukuReturnLaunch::execute": 0x802ac56c,
		"TNerveTobiPukuPrepareFly::~TNerveTobiPukuPrepareFly": 0x802ac7c0,
		"TNerveTobiPukuReturnLaunch::~TNerveTobiPukuReturnLaunch": 0x802ac81c,
		"TNerveTobiPukuPrepareFly::execute": 0x802ac878,
		"TNerveTobiPukuBound::execute": 0x802aca20,
		"TNerveTobiPukuLand::~TNerveTobiPukuLand": 0x802acbe8,
		"TNerveTobiPukuBound::~TNerveTobiPukuBound": 0x802acc44,
		"TNerveTobiPukuLand::execute": 0x802acca0,
		"TNerveTobiPukuPitiPiti::~TNerveTobiPukuPitiPiti": 0x802ad248,
		"TNerveTobiPukuDie::execute": 0x802ad2a4,
		"TNerveTobiPukuDie::~TNerveTobiPukuDie": 0x802ad4a0,
		"TNerveTobiPukuPitiPiti::execute": 0x802ad4fc,
		"TNerveTobiPukuFall::execute": 0x802ad614,
		"TNerveTobiPukuFall::~TNerveTobiPukuFall": 0x802ad7f8,
		"TNerveTobiPukuHitWater::execute": 0x802ad854,
		"TNerveTobiPukuHitWater::~TNerveTobiPukuHitWater": 0x802adaa4,
		"TNerveTobiPukuAttack::execute": 0x802adb00,
		"TNerveTobiPukuAttack::~TNerveTobiPukuAttack": 0x802adc98,
		"TNerveTobiPukuFly::execute": 0x802adcf4,
		"TNerveTobiPukuFly::~TNerveTobiPukuFly": 0x802ade88,
		"TNerveTobiPukuGenerate::execute": 0x802adee4,
		"TNerveTobiPukuGenerate::~TNerveTobiPukuGenerate": 0x802ae090,
		"TMoePuku::getBasNameTable": 0x802ae0ec,
		"TMoePuku::generateEffectColumWater": 0x802ae0f8,
		"TMoePuku::setJumpStartAnm": 0x802ae264,
		"TMoePuku::setFallEndLandAnm": 0x802ae2b4,
		"TMoePuku::setDeadAnm": 0x802ae2e4,
		"TMoePuku::setDownLandAnm": 0x802ae314,
		"TMoePuku::setDownAirAnm": 0x802ae344,
		"TMoePuku::setFallAnm": 0x802ae374,
		"TMoePuku::setPichiAnm": 0x802ae3a4,
		"TMoePuku::setAttackAnm": 0x802ae3d4,
		"TMoePuku::setSwimAnm": 0x802ae404,
		"TMoePuku::setJumpAnm": 0x802ae434,
		"TMoePuku::isJumpStartBck": 0x802ae464,
		"TMoePuku::isFallEndLandBck": 0x802ae494,
		"TMoePuku::isAttackBck": 0x802ae4c4,
		"TMoePuku::isDeadBck": 0x802ae4f4,
		"TMoePuku::isJumpBck": 0x802ae524,
		"TMoePuku::isPichiEffect": 0x802ae554,
		"TMoePuku::hitWater": 0x802ae584,
		"TMoePuku::calcRootMatrix": 0x802ae644,
		"TPukuPuku::reset": 0x802ae88c,
		"TPukuPuku::init": 0x802ae9c8,
		"TPukuPuku::load": 0x802aea9c,
		"TPukuPuku::TPukuPuku": 0x802aeae4,
		"TTobiPuku::getBasNameTable": 0x802aeb28,
		"TTobiPuku::scalingChangeActor": 0x802aeb34,
		"TTobiPuku::initAttacker": 0x802aebc8,
		"TTobiPuku::changeOut": 0x802aecac,
		"TTobiPuku::genEventCoin": 0x802aed4c,
		"TTobiPuku::forceKill": 0x802aed78,
		"TTobiPuku::kill": 0x802aeed0,
		"TTobiPuku::hitWater": 0x802af04c,
		"TTobiPuku::getGravityY": 0x802af1a0,
		"TTobiPuku::attackToMario": 0x802af1c0,
		"TTobiPuku::generateEffectColumWater": 0x802af33c,
		"TTobiPuku::isReachedToGoalXZ": 0x802af458,
		"TTobiPuku::swimEffect": 0x802af520,
		"TTobiPuku::walkBehavior": 0x802af5d0,
		"TTobiPuku::behaveToWater": 0x802af6a0,
		"TTobiPuku::setJumpStartAnm": 0x802af7ec,
		"TTobiPuku::setFallEndLandAnm": 0x802af83c,
		"TTobiPuku::setDeadAnm": 0x802af86c,
		"TTobiPuku::setDownLandAnm": 0x802af89c,
		"TTobiPuku::setDownAirAnm": 0x802af8cc,
		"TTobiPuku::setFallAnm": 0x802af8fc,
		"TTobiPuku::setPichiAnm": 0x802af92c,
		"TTobiPuku::setAttackAnm": 0x802af95c,
		"TTobiPuku::setSwimAnm": 0x802af98c,
		"TTobiPuku::setJumpAnm": 0x802af9bc,
		"TTobiPuku::isJumpStartBck": 0x802af9ec,
		"TTobiPuku::isFallEndLandBck": 0x802afa1c,
		"TTobiPuku::isAttackBck": 0x802afa4c,
		"TTobiPuku::isDeadBck": 0x802afa7c,
		"TTobiPuku::isJumpBck": 0x802afaac,
		"TTobiPuku::isPichiEffect": 0x802afadc,
		"TTobiPuku::calcRootMatrix": 0x802afb0c,
		"TTobiPuku::hitWall": 0x802afc60,
		"hitWall": 0x802afc60,
		"TTobiPuku::moveObject": 0x802afdbc,
		"TTobiPuku::reset": 0x802afe2c,
		"TTobiPuku::init": 0x802aff04,
		"TTobiPuku::TTobiPuku": 0x802aff70,
		"TMoePukuLaunchPad::launch": 0x802b0024,
		"TTobiPukuLaunchPad::forceLaunch": 0x802b0084,
		"forceLaunch": 0x802b0084,
		"TTobiPukuLaunchPad::launch": 0x802b0268,
		"TTobiPukuLaunchPad::reset": 0x802b02c8,
		"TTobiPukuLaunchPad::load": 0x802b0300,
		"TTobiPukuLaunchPad::init": 0x802b0380,
		"TTobiPukuLaunchPad::perform": 0x802b03d0,
		"TTobiPukuLaunchPad::TTobiPukuLaunchPad": 0x802b048c,
		"TMoePukuManager::createEnemyInstance": 0x802b04e4,
		"TTobiPukuManager::createEnemyInstance": 0x802b0540,
		"TTobiPukuManager::load": 0x802b0588,
		"TTobiPukuManager::TTobiPukuManager": 0x802b06f8,
		"TMoePukuLaunchPadManager::createEnemyInstance": 0x802b0734,
		"TTobiPukuLaunchPadManager::perform": 0x802b07b8,
		"TTobiPukuLaunchPadManager::createEnemyInstance": 0x802b0850,
		"TTobiPukuLaunchPadManager::load": 0x802b08c0,
		"TTobiPukuLaunchPadManager::TTobiPukuLaunchPadManager": 0x802b0a30,
		"Enemy::TobiPukuRollCallback": 0x802b0a74,
		"TobiPukuRollCallback": 0x802b0a74,
		"TMoePuku::swimEffect": 0x802b0c98,
		"TTobiPuku::isInhibitedForceMove": 0x802b0c9c,
		"TMoePukuManager::~TMoePukuManager": 0x802b0e8c,
		"TMoePukuLaunchPadManager::~TMoePukuLaunchPadManager": 0x802b0f10,
		"Enemy::__sinit_tobiPuku_cpp": 0x802b0f94,
		"__sinit_tobiPuku_cpp": 0x802b0f94,
		"TNerveTinKoopaBreak::~TNerveTinKoopaBreak": 0x802b12b8,
		"TNerveTinKoopaBreak::execute": 0x802b1314,
		"TNerveTinKoopaDamage::execute": 0x802b16fc,
		"TNerveTinKoopaDamage::~TNerveTinKoopaDamage": 0x802b1878,
		"TNerveTinKoopaWait::execute": 0x802b18d4,
		"TNerveTinKoopaWait::~TNerveTinKoopaWait": 0x802b19b4,
		"TTinKoopaManager::createEnemyInstance": 0x802b1a10,
		"TTinKoopaManager::loadAfter": 0x802b1a18,
		"TTinKoopaManager::load": 0x802b1b1c,
		"TTinKoopaManager::createModelData": 0x802b1b74,
		"TTinKoopaManager::TTinKoopaManager": 0x802b1ba8,
		"TTinKoopa::emitTinKoopaEffects": 0x802b1be4,
		"emitTinKoopaEffects": 0x802b1be4,
		"TTinKoopa::checkTinKoopaFirstFlameMessage": 0x802b27e8,
		"checkTinKoopaFirstFlameMessage": 0x802b27e8,
		"TTinKoopa::checkTinKoopaKillerApproachingMessage": 0x802b28fc,
		"checkTinKoopaKillerApproachingMessage": 0x802b28fc,
		"TTinKoopa::launchKiller": 0x802b2a80,
		"TTinKoopa::hitParts": 0x802b2b84,
		"hitParts": 0x802b2b84,
		"TTinKoopa::receiveMessage": 0x802b2ddc,
		"TTinKoopa::getBasNameTable": 0x802b2e18,
		"TTinKoopa::perform": 0x802b2e24,
		"TTinKoopa::resetTinKoopa": 0x802b30b4,
		"resetTinKoopa": 0x802b30b4,
		"TTinKoopa::reset": 0x802b31c8,
		"TTinKoopa::calcCoasterDistance": 0x802b3444,
		"calcCoasterDistance": 0x802b3444,
		"TTinKoopa::TTinKoopa": 0x802b34f0,
		"TTinKoopaPartsBase::perform": 0x802b3580,
		"TTinKoopaPartsBase::receiveMessage": 0x802b3674,
		"TTinKoopaPartsBase::emitPartsTrackEffects": 0x802b38f4,
		"emitPartsTrackEffects": 0x802b38f4,
		"TTinKoopaPartsBase::startBreaking": 0x802b39d0,
		"startBreaking": 0x802b39d0,
		"TTinKoopaPartsBase::reset": 0x802b3b30,
		"TTinKoopaPartsBase::initTinKoopaPartsBase": 0x802b3b7c,
		"initTinKoopaPartsBase": 0x802b3b7c,
		"TTinKoopaLaunchOrder::checkOrder": 0x802b3d5c,
		"checkOrder": 0x802b3d5c,
		"TTinKoopaFlame::emitFlameEffects": 0x802b3ec8,
		"emitFlameEffects": 0x802b3ec8,
		"TTinKoopaFlame::perform": 0x802b40fc,
		"TTinKoopaFlame::receiveMessage": 0x802b4244,
		"TTinKoopa::makeLaunchSchedule": 0x802b432c,
		"makeLaunchSchedule": 0x802b432c,
		"TTinKoopa::init": 0x802b4508,
		"TTinKoopaParams::TTinKoopaParams": 0x802b4aec,
		"TTinKoopaManager::~TTinKoopaManager": 0x802b4df0,
		"TTinKoopaManager::hasMapCollision": 0x802b4e54,
		"TTinKoopaMtxCalc::~TTinKoopaMtxCalc": 0x802b4e5c,
		"TTinKoopa::hasMapCollision": 0x802b5064,
		"Enemy::__sinit_tinkoopa_cpp": 0x802b506c,
		"__sinit_tinkoopa_cpp": 0x802b506c,
		"TCommonLauncherManager::~TCommonLauncherManager": 0x802b5394,
		"TCommonLauncherManager::load": 0x802b5408,
		"TCommonLauncherManager::createModelData": 0x802b5428,
		"TCommonLauncherManager::TCommonLauncherManager": 0x802b545c,
		"TCommonLauncher::perform": 0x802b54a4,
		"TCommonLauncher::getBasNameTable": 0x802b5610,
		"TCommonLauncher::stateDie": 0x802b561c,
		"TCommonLauncher::stateLaunch": 0x802b5810,
		"TCommonLauncher::stateNormal": 0x802b59b0,
		"TCommonLauncher::stateHitByWater": 0x802b5a58,
		"TCommonLauncher::stateInitial": 0x802b5b0c,
		"TCommonLauncher::load": 0x802b5b3c,
		"TCommonLauncher::init": 0x802b5b90,
		"TCommonLauncher::TCommonLauncher": 0x802b5ed8,
		"TLauncherManager::load": 0x802b5f58,
		"TLauncherManager::TLauncherManager": 0x802b6018,
		"TLauncher::stateDie": 0x802b6054,
		"TLauncher::stateLaunch": 0x802b60e4,
		"TLauncher::stateNormal": 0x802b6160,
		"TLauncher::stateHitByWater": 0x802b61a8,
		"TLauncher::stateInitial": 0x802b6228,
		"TLauncher::changeState": 0x802b6264,
		"TLauncher::getProperEnemy": 0x802b626c,
		"getProperEnemy": 0x802b626c,
		"TLauncher::resetLaunchTimer": 0x802b62d0,
		"resetLaunchTimer": 0x802b62d0,
		"TLauncher::control": 0x802b6324,
		"TLauncher::bind": 0x802b641c,
		"TLauncher::receiveMessage": 0x802b6420,
		"TLauncher::init": 0x802b6508,
		"TLauncher::TLauncher": 0x802b6654,
		"Enemy::__sinit_launcher_cpp": 0x802b6740,
		"__sinit_launcher_cpp": 0x802b6740,
		"TNerveBWFall::~TNerveBWFall": 0x802b6a4c,
		"TNerveBWFall::execute": 0x802b6aa8,
		"TNerveBWGraphWander::~TNerveBWGraphWander": 0x802b6ca8,
		"TNerveBWFall::theNerve": 0x802b6d04,
		"TNerveBWShake::execute": 0x802b6d68,
		"TNerveBWShake::theNerve": 0x802b6f00,
		"TNerveBWShake::~TNerveBWShake": 0x802b6f64,
		"TNerveBWJumpAway::execute": 0x802b6fc0,
		"TNerveBWJumpAway::theNerve": 0x802b724c,
		"TNerveBWJumpAway::~TNerveBWJumpAway": 0x802b72b0,
		"TNerveBWDie::execute": 0x802b730c,
		"TNerveBWDie::~TNerveBWDie": 0x802b7740,
		"TNerveBWDie::theNerve": 0x802b779c,
		"TNerveBWJumpToBath::execute": 0x802b7800,
		"TNerveBWJumpToBath::theNerve": 0x802b7b34,
		"TNerveBWJumpToBath::~TNerveBWJumpToBath": 0x802b7b98,
		"TNerveBWWakeup::execute": 0x802b7bf4,
		"TNerveBWWakeup::theNerve": 0x802b7d88,
		"TNerveBWWakeup::~TNerveBWWakeup": 0x802b7dec,
		"TNerveBWStun::execute": 0x802b7e48,
		"TNerveBWStun::theNerve": 0x802b815c,
		"TNerveBWStun::~TNerveBWStun": 0x802b81c0,
		"TNerveBWJump::execute": 0x802b821c,
		"TNerveBWJump::theNerve": 0x802b839c,
		"TNerveBWJump::~TNerveBWJump": 0x802b8400,
		"TNerveBWBark::execute": 0x802b845c,
		"TNerveBWBark::theNerve": 0x802b86dc,
		"TNerveBWBark::~TNerveBWBark": 0x802b8740,
		"TNerveBWRoll::execute": 0x802b879c,
		"TNerveBWRoll::~TNerveBWRoll": 0x802b88dc,
		"TNerveBWRoll::theNerve": 0x802b8948,
		"TNerveBWGraphWander::execute": 0x802b89ac,
		"TNerveBWGraphWander::theNerve": 0x802b939c,
		"TBossWanwanManager::load": 0x802b9400,
		"TBossWanwanManager::createModelData": 0x802b95f8,
		"TBossWanwanManager::createEnemyInstance": 0x802b962c,
		"TBossWanwanManager::TBossWanwanManager": 0x802b9674,
		"TBossWanwan::perform": 0x802b96b0,
		"TBossWanwan::emitEffects": 0x802b9f1c,
		"TBossWanwan::control": 0x802ba3a0,
		"TBossWanwan::slideToCurPathNode": 0x802ba6bc,
		"slideToCurPathNode": 0x802ba6bc,
		"TBossWanwan::calcRootMatrix": 0x802ba974,
		"TBossWanwan::receiveMessage": 0x802baa58,
		"TBossWanwan::shakeCamera": 0x802baca8,
		"shakeCamera": 0x802baca8,
		"TBossWanwan::init": 0x802bae24,
		"TBossWanwan::TBossWanwan": 0x802bb5b4,
		"TBWBinder::bind": 0x802bb8bc,
		"TBWHit::perform": 0x802bc2c4,
		"TBWHit::receiveMessage": 0x802bc380,
		"TBWPicket::perform": 0x802bc3b0,
		"TBWPicket::getTakingMtx": 0x802bc8e0,
		"TBWPicket::moveRequest": 0x802bc8e8,
		"TBWPicket::receiveMessage": 0x802bcaa0,
		"TBWLeash::perform": 0x802bcbd4,
		"TBWLeash::TBWLeash": 0x802bd108,
		"TBWLeashNode::perform": 0x802bd444,
		"TBWLeashNode::calcMatrix": 0x802bd670,
		"calcMatrix": 0x802bd670,
		"TBWLeashNode::calcTemperature": 0x802bd934,
		"calcTemperature": 0x802bd934,
		"TBWParams::TBWParams": 0x802bd9d8,
		"TBossWanwanManager::~TBossWanwanManager": 0x802bdd50,
		"TBossWanwan::kill": 0x802bde20,
		"TBossWanwanMtxCalc::~TBossWanwanMtxCalc": 0x802bde24,
		"TBWBinder::~TBWBinder": 0x802bded0,
		"TBWLeash::~TBWLeash": 0x802be054,
		"Enemy::__sinit_bosswanwan_cpp": 0x802be14c,
		"__sinit_bosswanwan_cpp": 0x802be14c,
		"TNerveChuuHanaWait::~TNerveChuuHanaWait": 0x802be4c4,
		"TNerveChuuHanaWait::execute": 0x802be520,
		"TNerveChuuHanaJumpPrepare::execute": 0x802be58c,
		"TNerveChuuHanaJumpPrepare::~TNerveChuuHanaJumpPrepare": 0x802be730,
		"TNerveChuuHanaAttack::execute": 0x802be78c,
		"TNerveChuuHanaFall2::~TNerveChuuHanaFall2": 0x802beb8c,
		"TNerveChuuHanaWalkOnPanel::~TNerveChuuHanaWalkOnPanel": 0x802bebe8,
		"TNerveChuuHanaAttack::~TNerveChuuHanaAttack": 0x802bec44,
		"TNerveChuuHanaObject::execute": 0x802beca0,
		"TNerveChuuHanaObject::~TNerveChuuHanaObject": 0x802beca8,
		"TNerveChuuHanaFall2::execute": 0x802bed04,
		"TNerveChuuHanaFall::execute": 0x802bee30,
		"TNerveChuuHanaFall::~TNerveChuuHanaFall": 0x802bee38,
		"TNerveChuuHanaRoll::execute": 0x802bee94,
		"TNerveChuuHanaKeepBalance::~TNerveChuuHanaKeepBalance": 0x802bf0b4,
		"TNerveChuuHanaRoll::~TNerveChuuHanaRoll": 0x802bf110,
		"TNerveChuuHanaStick::execute": 0x802bf16c,
		"TNerveChuuHanaStick::~TNerveChuuHanaStick": 0x802bf414,
		"TNerveChuuHanaKeepBalance::execute": 0x802bf470,
		"TNerveChuuHanaForceJumped::execute": 0x802bf84c,
		"TNerveChuuHanaForceJumped::~TNerveChuuHanaForceJumped": 0x802bfafc,
		"TNerveChuuHanaWalkOnPanel::execute": 0x802bfb58,
		"TChuuHana::getBasNameTable": 0x802bfde0,
		"TChuuHana::checkStretchType": 0x802bfdec,
		"checkStretchType": 0x802bfdec,
		"TChuuHana::setGoal": 0x802c02ac,
		"setGoal": 0x802c02ac,
		"TChuuHana::willFall": 0x802c0414,
		"willFall": 0x802c0414,
		"TChuuHana::getGravityY": 0x802c0614,
		"TChuuHana::forceKill": 0x802c0878,
		"TChuuHana::kill": 0x802c099c,
		"TChuuHana::setWalkAnm": 0x802c0a10,
		"TChuuHana::receiveMessage": 0x802c0ab4,
		"TChuuHana::bind": 0x802c0c44,
		"TChuuHana::calcRootMatrix": 0x802c0f2c,
		"TChuuHana::isCollidMove": 0x802c11b0,
		"TChuuHana::moveObject": 0x802c15ac,
		"TChuuHana::attackToMario": 0x802c1938,
		"TChuuHana::behaveToWater": 0x802c1b9c,
		"TChuuHana::setBckAnm": 0x802c21a4,
		"TChuuHana::reset": 0x802c2230,
		"TChuuHana::perform": 0x802c23b4,
		"TChuuHana::setMActorAndKeeper": 0x802c2470,
		"TChuuHana::init": 0x802c24dc,
		"TChuuHana::TChuuHana": 0x802c262c,
		"TChuuHanaAseParCallback::draw": 0x802c26e0,
		"TChuuHanaAseParCallback::execute": 0x802c26e4,
		"Enemy::ChuuHanaBodyCallback": 0x802c2758,
		"ChuuHanaBodyCallback": 0x802c2758,
		"TChuuHanaManager::initSetEnemies": 0x802c29fc,
		"TChuuHanaManager::createEnemyInstance": 0x802c2b84,
		"TChuuHanaManager::perform": 0x802c2bcc,
		"TChuuHanaManager::load": 0x802c2bec,
		"TChuuHanaManager::TChuuHanaManager": 0x802c2c44,
		"TChuuHanaSaveLoadParams::TChuuHanaSaveLoadParams": 0x802c2c94,
		"TChuuHana::isFindMario": 0x802c3178,
		"TChuuHanaManager::~TChuuHanaManager": 0x802c321c,
		"Enemy::__sinit_chuuhana_cpp": 0x802c3290,
		"__sinit_chuuhana_cpp": 0x802c3290,
		"TNerveGorogoroDie::~TNerveGorogoroDie": 0x802c3594,
		"TNerveGorogoroDie::execute": 0x802c35f0,
		"TNerveGorogoroRollOnGraph::execute": 0x802c3824,
		"TNerveGorogoroRollOnGraph::~TNerveGorogoroRollOnGraph": 0x802c38e4,
		"TGorogoro::generateByGateKeeper": 0x802c3940,
		"generateByGateKeeper": 0x802c3940,
		"TGorogoro::setMActorAndKeeper": 0x802c3ec4,
		"TGorogoro::isRolling": 0x802c3f30,
		"TGorogoro::getBasNameTable": 0x802c3fdc,
		"TGorogoro::bound": 0x802c3fe8,
		"TGorogoro::setMeltAnm": 0x802c4050,
		"TGorogoro::setDeadAnm": 0x802c4148,
		"TGorogoro::flagJump": 0x802c4214,
		"TGorogoro::walkBehavior": 0x802c42ec,
		"TGorogoro::boundSE": 0x802c45e0,
		"TGorogoro::rollSE": 0x802c4658,
		"TGorogoro::behaveToWater": 0x802c46d0,
		"TGorogoro::forceKill": 0x802c4924,
		"TGorogoro::kill": 0x802c4b10,
		"TGorogoro::reset": 0x802c4c64,
		"TGorogoro::calcRootMatrix": 0x802c4cbc,
		"TGorogoro::perform": 0x802c4eb0,
		"TGorogoro::init": 0x802c4f3c,
		"TGorogoroManager::perform": 0x802c519c,
		"TGorogoroManager::createModelData": 0x802c56c0,
		"TGorogoroManager::initSetEnemies": 0x802c56f4,
		"TGorogoroManager::createEnemyInstance": 0x802c585c,
		"TGorogoroManager::loadAfter": 0x802c58e4,
		"TGorogoroManager::load": 0x802c5980,
		"TGorogoroManager::TGorogoroManager": 0x802c5af0,
		"TGorogoroPolluteModel::setAnm": 0x802c5b48,
		"TGorogoroPolluteModelManager::init": 0x802c5b98,
		"TNerveIgaigaShootFromCannon::execute": 0x802c5c68,
		"TNerveIgaigaRollOnGraph::~TNerveIgaigaRollOnGraph": 0x802c5de0,
		"TNerveIgaigaShootFromCannon::~TNerveIgaigaShootFromCannon": 0x802c5e3c,
		"TNerveIgaigaWaterHit::execute": 0x802c5e98,
		"TNerveIgaigaWaterHit::~TNerveIgaigaWaterHit": 0x802c6108,
		"TNerveIgaigaRollOnGraph::execute": 0x802c6164,
		"TIgaiga::shoot": 0x802c6284,
		"TIgaiga::bound": 0x802c634c,
		"TIgaiga::isHitValid": 0x802c63f0,
		"TIgaiga::getBasNameTable": 0x802c6410,
		"TIgaiga::setMeltAnm": 0x802c641c,
		"TIgaiga::setDeadAnm": 0x802c6680,
		"TIgaiga::setWalkAnm": 0x802c67e8,
		"TIgaiga::isReachedToGoalXZ": 0x802c6818,
		"TIgaiga::walkBehavior": 0x802c68d4,
		"TIgaiga::boundSE": 0x802c6a70,
		"TIgaiga::rollSE": 0x802c6ae8,
		"TIgaiga::moveObject": 0x802c6b30,
		"TIgaiga::kill": 0x802c6dbc,
		"TIgaiga::reset": 0x802c6de4,
		"TIgaiga::behaveToWater": 0x802c6f24,
		"TIgaiga::isRolling": 0x802c7070,
		"TIgaiga::calcRootMatrix": 0x802c71b0,
		"TIgaiga::perform": 0x802c71d4,
		"TIgaiga::setMActorAndKeeper": 0x802c71f4,
		"TIgaiga::init": 0x802c7260,
		"TIgaiga::TIgaiga": 0x802c7368,
		"Enemy::RollEnemyBodyCallback": 0x802c740c,
		"RollEnemyBodyCallback": 0x802c740c,
		"TRollEnemy::isRolling": 0x802c753c,
		"TIgaigaManager::perform": 0x802c7544,
		"TIgaigaManager::initSetEnemies": 0x802c75a4,
		"TIgaigaManager::createEnemyInstance": 0x802c7660,
		"TIgaigaManager::createModelData": 0x802c76a8,
		"TIgaigaManager::load": 0x802c76dc,
		"TIgaigaManager::TIgaigaManager": 0x802c7860,
		"TIgaigaPolluteModel::setAnm": 0x802c78ac,
		"TIgaigaPolluteModelManager::init": 0x802c78fc,
		"TRollEnemy::setBehavior": 0x802c79cc,
		"TRollEnemy::isReachedToGoalXZ": 0x802c7bf4,
		"TRollEnemy::isCollidMove": 0x802c7ca8,
		"TRollEnemy::flagJump": 0x802c7d28,
		"TRollEnemy::attackToMario": 0x802c7e00,
		"TRollEnemy::behaveToWater": 0x802c7e24,
		"TRollEnemy::walkBehavior": 0x802c7fbc,
		"TRollEnemy::rollSE": 0x802c81c8,
		"TRollEnemy::boundSE": 0x802c81cc,
		"TRollEnemy::bound": 0x802c81d0,
		"TRollEnemy::reset": 0x802c81d4,
		"TRollEnemy::TRollEnemy": 0x802c83cc,
		"TRollEnemy::setAfterDeadEffect": 0x802c843c,
		"TGorogoroManager::~TGorogoroManager": 0x802c84dc,
		"TGorogoroPolluteModel::~TGorogoroPolluteModel": 0x802c8550,
		"TGorogoroPolluteModelManager::~TGorogoroPolluteModelManager": 0x802c85d4,
		"TIgaigaManager::~TIgaigaManager": 0x802c86f4,
		"TIgaigaPolluteModel::~TIgaigaPolluteModel": 0x802c8768,
		"TIgaigaPolluteModelManager::~TIgaigaPolluteModelManager": 0x802c87ec,
		"Enemy::__sinit_igaiga_cpp": 0x802c8870,
		"__sinit_igaiga_cpp": 0x802c8870,
		"TNervePoihanaTrapped::~TNervePoihanaTrapped": 0x802c8b84,
		"TNervePoihanaTrapped::execute": 0x802c8be0,
		"TNervePoihanaFreeze::~TNervePoihanaFreeze": 0x802c90b0,
		"TNervePoihanaThrow::execute": 0x802c910c,
		"TNervePoihanaThrow::~TNervePoihanaThrow": 0x802c92d8,
		"TNervePoihanaFreeze::execute": 0x802c9334,
		"TNervePoihanaSleep::execute": 0x802c9534,
		"TNervePoihanaSleep::~TNervePoihanaSleep": 0x802c9868,
		"TSleepPoiHana::load": 0x802c98c4,
		"TSleepPoiHana::TSleepPoiHana": 0x802c990c,
		"TPoiHanaRed::attackToMario": 0x802c9994,
		"TPoiHanaRed::init": 0x802c9bbc,
		"TPoiHana::getBasNameTable": 0x802c9c08,
		"TPoiHana::changeByJuice": 0x802c9c14,
		"TPoiHana::genEventCoin": 0x802c9c64,
		"TPoiHana::isMoving": 0x802c9d94,
		"isMoving": 0x802c9d94,
		"TPoiHana::getGravityY": 0x802c9e78,
		"TPoiHana::generateItem": 0x802c9f14,
		"TPoiHana::calcRootMatrix": 0x802c9f2c,
		"TPoiHana::doKeepDistance": 0x802ca2bc,
		"TPoiHana::isInhibitedForceMove": 0x802ca2f0,
		"TPoiHana::walkBehavior": 0x802ca30c,
		"TPoiHana::isCollidMove": 0x802ca484,
		"TPoiHana::isHitValid": 0x802ca680,
		"TPoiHana::setDeadAnm": 0x802ca740,
		"TPoiHana::setFreezeAnm": 0x802ca988,
		"TPoiHana::setRunAnm": 0x802ca9b8,
		"TPoiHana::setWaitAnm": 0x802ca9e8,
		"TPoiHana::setWalkAnm": 0x802caa18,
		"TPoiHana::attackToMario": 0x802caa48,
		"TPoiHana::behaveToWater": 0x802cac54,
		"TPoiHana::bind": 0x802cad64,
		"TPoiHana::perform": 0x802cae84,
		"TPoiHana::moveObject": 0x802caed8,
		"TPoiHana::reset": 0x802cb1b4,
		"TPoiHana::setMActorAndKeeper": 0x802cb204,
		"TPoiHana::init": 0x802cb270,
		"TPoiHana::load": 0x802cb4f4,
		"TPoiHana::TPoiHana": 0x802cb534,
		"TPoiHanaCollision::receiveMessage": 0x802cb5a8,
		"TPoiHanaManager::initSetEnemies": 0x802cb5d8,
		"TPoiHanaManager::perform": 0x802cb678,
		"TPoiHanaManager::createEnemyInstance": 0x802cb698,
		"TPoiHanaManager::load": 0x802cb6fc,
		"TPoiHanaManager::TPoiHanaManager": 0x802cb910,
		"TPoiHanaManager::~TPoiHanaManager": 0x802cbb08,
		"Enemy::__sinit_poihana_cpp": 0x802cbb7c,
		"__sinit_poihana_cpp": 0x802cbb7c,
		"TNerveTamaNokoWait::~TNerveTamaNokoWait": 0x802cbe98,
		"TNerveTamaNokoWait::execute": 0x802cbef4,
		"TNerveTamaNokoHitWater::execute": 0x802cc07c,
		"TNerveTamaNokoSleep::~TNerveTamaNokoSleep": 0x802cc3b4,
		"TNerveTamaNokoHitWater::~TNerveTamaNokoHitWater": 0x802cc410,
		"TNerveTamaNokoSink::execute": 0x802cc46c,
		"TNerveTamaNokoSink::~TNerveTamaNokoSink": 0x802cc684,
		"TNerveTamaNokoThrown::execute": 0x802cc6e0,
		"TNerveTamaNokoThrown::~TNerveTamaNokoThrown": 0x802cc7ec,
		"TNerveTamaNokoPickUp::execute": 0x802cc848,
		"TNerveTamaNokoPickUp::~TNerveTamaNokoPickUp": 0x802cc8fc,
		"TNerveTamaNokoDown::execute": 0x802cc958,
		"TNerveTamaNokoDown::~TNerveTamaNokoDown": 0x802ccbdc,
		"TNerveTamaNokoAttack::execute": 0x802ccc38,
		"TNerveTamaNokoAttack::~TNerveTamaNokoAttack": 0x802cd3e8,
		"TNerveTamaNokoSleep::execute": 0x802cd444,
		"TTamaNoko::isCollidMove": 0x802cd4ec,
		"TTamaNoko::isReachedToGoal": 0x802cd5b8,
		"TTamaNoko::setDeadAnm": 0x802cd680,
		"TTamaNoko::setWalkAnm": 0x802cd6b0,
		"TTamaNoko::getGravityY": 0x802cd6e0,
		"TTamaNoko::getBasNameTable": 0x802cd7d4,
		"TTamaNoko::setAfterDeadEffect": 0x802cd7e0,
		"TTamaNoko::landEffect": 0x802cd8e0,
		"landEffect": 0x802cd8e0,
		"TTamaNoko::requestShadow": 0x802cdc08,
		"TTamaNoko::calcRootMatrix": 0x802cdde4,
		"TTamaNoko::doKeepDistance": 0x802ce20c,
		"TTamaNoko::attackToMario": 0x802ce298,
		"TTamaNoko::isHitValid": 0x802ce358,
		"TTamaNoko::receiveMessage": 0x802ce3ec,
		"TTamaNoko::changeByJuice": 0x802ce544,
		"TTamaNoko::behaveToRelease": 0x802ce54c,
		"TTamaNoko::behaveToTaken": 0x802ce670,
		"TTamaNoko::walkBehavior": 0x802ce788,
		"TTamaNoko::behaveToWater": 0x802cecb4,
		"TTamaNoko::behaveToFindMario": 0x802cee94,
		"TTamaNoko::moveObject": 0x802cef38,
		"TTamaNoko::perform": 0x802cefcc,
		"TTamaNoko::reset": 0x802cf038,
		"TTamaNoko::setMActorAndKeeper": 0x802cf090,
		"TTamaNoko::init": 0x802cf0fc,
		"TTamaNoko::load": 0x802cf1f4,
		"TTamaNoko::TTamaNoko": 0x802cf234,
		"TTamaNokoManager::createModelData": 0x802cf294,
		"TTamaNokoManager::createEnemyInstance": 0x802cf2c8,
		"TTamaNokoManager::initSetEnemies": 0x802cf310,
		"TTamaNokoManager::loadAfter": 0x802cf43c,
		"TTamaNokoManager::load": 0x802cf498,
		"TTamaNokoManager::TTamaNokoManager": 0x802cf6ac,
		"TTamaNokoFlower::perform": 0x802cf6e8,
		"TTamaNoko::forceKill": 0x802cfa90,
		"TTamaNokoManager::~TTamaNokoManager": 0x802cfb30,
		"TTamaNokoFlower::~TTamaNokoFlower": 0x802cfba4,
		"Enemy::__sinit_tamaNoko_cpp": 0x802cfc28,
		"__sinit_tamaNoko_cpp": 0x802cfc28,
		"TNerveBossTelesaFallDemo::~TNerveBossTelesaFallDemo": 0x802cff2c,
		"TNerveBossTelesaFallDemo::execute": 0x802cff88,
		"TNerveBossTelesaHideWait::~TNerveBossTelesaHideWait": 0x802d0174,
		"TNerveBossTelesaFreeze::execute": 0x802d01d0,
		"TNerveBossTelesaFreeze::~TNerveBossTelesaFreeze": 0x802d0380,
		"TNerveBossTelesaPrepareSlot::execute": 0x802d03dc,
		"TNerveBossTelesaHide::~TNerveBossTelesaHide": 0x802d0a44,
		"TNerveBossTelesaPrepareSlot::~TNerveBossTelesaPrepareSlot": 0x802d0aa0,
		"TNerveBossTelesaSpitSlotItem::execute": 0x802d0afc,
		"TNerveBossTelesaSpitSlotItem::~TNerveBossTelesaSpitSlotItem": 0x802d0d4c,
		"TNerveBossTelesaSlotStart::execute": 0x802d0da8,
		"TNerveBossTelesaSlotStart::~TNerveBossTelesaSlotStart": 0x802d105c,
		"TNerveBossTelesaAppear::execute": 0x802d10b8,
		"TNerveBossTelesaAppear::~TNerveBossTelesaAppear": 0x802d1484,
		"TNerveBossTelesaHideWait::execute": 0x802d14e0,
		"TNerveBossTelesaHide::execute": 0x802d16e0,
		"TNerveBossTelesaSpit::execute": 0x802d18b8,
		"TNerveBossTelesaSpit::~TNerveBossTelesaSpit": 0x802d19e8,
		"TNerveBossTelesaDie::execute": 0x802d1a44,
		"TNerveBossTelesaDie::~TNerveBossTelesaDie": 0x802d230c,
		"TBossTelesa::forceHide": 0x802d2368,
		"forceHide": 0x802d2368,
		"TBossTelesa::forceAllItemKill": 0x802d2504,
		"forceAllItemKill": 0x802d2504,
		"TBossTelesa::generateSlotItem": 0x802d25f8,
		"generateSlotItem": 0x802d25f8,
		"TBossTelesa::rouletteStart": 0x802d314c,
		"rouletteStart": 0x802d314c,
		"TBossTelesa::genAttacker": 0x802d3408,
		"genAttacker": 0x802d3408,
		"TBossTelesa::getBasNameTable": 0x802d377c,
		"TBossTelesa::flashItem": 0x802d3788,
		"flashItem": 0x802d3788,
		"TBossTelesa::slotFall": 0x802d3a0c,
		"slotFall": 0x802d3a0c,
		"TBossTelesa::rouletteFall": 0x802d3b54,
		"rouletteFall": 0x802d3b54,
		"TBossTelesa::damageRecover": 0x802d3cbc,
		"damageRecover": 0x802d3cbc,
		"TBossTelesa::setSpicy": 0x802d3f3c,
		"setSpicy": 0x802d3f3c,
		"TBossTelesa::checkHitObject": 0x802d40d8,
		"checkHitObject": 0x802d40d8,
		"TBossTelesa::receiveMessage": 0x802d43a8,
		"TBossTelesa::perform": 0x802d43b0,
		"TBossTelesa::calcRootMatrix": 0x802d4504,
		"TBossTelesa::getTakingMtx": 0x802d4a64,
		"TBossTelesa::kill": 0x802d4acc,
		"TBossTelesa::moveObject": 0x802d4be4,
		"TBossTelesa::reset": 0x802d54c8,
		"TBossTelesa::loadAfter": 0x802d55f0,
		"TBossTelesa::init": 0x802d62fc,
		"TBossTelesa::TBossTelesa": 0x802d6a88,
		"TTelesaSlot::getResultFromAng": 0x802d6b44,
		"TTelesaSlot::getForcastResult": 0x802d6bec,
		"TTelesaSlot::getSlotResult": 0x802d6d08,
		"getSlotResult": 0x802d6d08,
		"TTelesaSlot::isRollDrum": 0x802d6d94,
		"isRollDrum": 0x802d6d94,
		"TTelesaSlot::forceStopSlot": 0x802d6de0,
		"forceStopSlot": 0x802d6de0,
		"TTelesaSlot::touchWater": 0x802d6f5c,
		"TTelesaSlot::moveStart": 0x802d6f64,
		"moveStart": 0x802d6f64,
		"TTelesaSlot::moveObject": 0x802d7008,
		"TTelesaSlot::calcRootMatrix": 0x802d7460,
		"TTelesaSlot::randomReset": 0x802d7524,
		"randomReset": 0x802d7524,
		"TTelesaSlot::initMapObj": 0x802d7610,
		"TBossTelesaKillSmallEnemy::checkHit": 0x802d7794,
		"TBossTelesaTongue::receiveMessage": 0x802d78cc,
		"TBossTelesaBody::receiveMessage": 0x802d79f0,
		"TBossTelesaManager::perform": 0x802d7c38,
		"TBossTelesaManager::createModelData": 0x802d7c58,
		"TBossTelesaManager::createEnemyInstance": 0x802d7c8c,
		"TBossTelesaManager::load": 0x802d7cd4,
		"TBossTelesaManager::TBossTelesaManager": 0x802d7d40,
		"TBossTelesaSaveLoadParams::TBossTelesaSaveLoadParams": 0x802d7d7c,
		"TNerveBubbleSplit::execute": 0x802d811c,
		"TNerveBubbleSplit::~TNerveBubbleSplit": 0x802d81dc,
		"TNerveBubbleLive::execute": 0x802d8238,
		"TBubble::appendEnemy": 0x802d8620,
		"appendEnemy": 0x802d8620,
		"TNerveBubbleLive::~TNerveBubbleLive": 0x802d8834,
		"TBubble::getBasNameTable": 0x802d8890,
		"TBubble::getTakingMtx": 0x802d889c,
		"TBubble::setDeadAnm": 0x802d88ac,
		"TBubble::calcRootMatrix": 0x802d88dc,
		"TBubble::attackToMario": 0x802d89a4,
		"TBubble::behaveToWater": 0x802d89f0,
		"TBubble::kill": 0x802d8adc,
		"TBubble::getGravityY": 0x802d8c00,
		"TBubble::split": 0x802d8c30,
		"split": 0x802d8c30,
		"TBubble::reset": 0x802d8de8,
		"TBubble::init": 0x802d8efc,
		"TBubbleManager::createModelData": 0x802d9024,
		"TBubbleManager::createEnemyInstance": 0x802d9058,
		"TBubbleManager::load": 0x802d90e8,
		"TBubbleManager::TBubbleManager": 0x802d9284,
		"TTelesaSlot::initNeonMatColor": 0x802d944c,
		"TBossTelesaManager::~TBossTelesaManager": 0x802d9558,
		"TBossTelesaManager::clipEnemies": 0x802d95bc,
		"TBubble::setAfterDeadEffect": 0x802d95c0,
		"TBubbleManager::~TBubbleManager": 0x802d9660,
		"Enemy::__sinit_bosstelesa_cpp": 0x802d96d4,
		"__sinit_bosstelesa_cpp": 0x802d96d4,
		"TNerveRHGraphWander::~TNerveRHGraphWander": 0x802d9a00,
		"TNerveRHGraphWander::execute": 0x802d9a5c,
		"TRiccoHookManager::createEnemyInstance": 0x802d9d3c,
		"TRiccoHookManager::load": 0x802d9d44,
		"TRiccoHookManager::createModelData": 0x802d9e70,
		"TRiccoHookManager::TRiccoHookManager": 0x802d9ea4,
		"TRiccoHook::perform": 0x802d9ee0,
		"TRiccoHook::receiveMessage": 0x802d9f5c,
		"TRiccoHook::kill": 0x802d9f64,
		"TRiccoHook::init": 0x802d9f68,
		"TRiccoHook::TRiccoHook": 0x802da1c4,
		"THookTake::perform": 0x802da214,
		"THookTake::receiveMessage": 0x802da2f8,
		"THookTake::getRadiusAtY": 0x802da340,
		"THookTake::getTakingMtx": 0x802da374,
		"TRiccoHookManager::~TRiccoHookManager": 0x802da37c,
		"TNerveBombHeiExplosion::~TNerveBombHeiExplosion": 0x802da4f8,
		"TNerveBombHeiExplosion::execute": 0x802da554,
		"TNerveBombHeiThrown::execute": 0x802da7dc,
		"TNerveBombHeiThrown::~TNerveBombHeiThrown": 0x802da990,
		"TNerveBombHeiPickUp::execute": 0x802da9ec,
		"TNerveBombHeiPickUp::~TNerveBombHeiPickUp": 0x802daa18,
		"TNerveBombHeiWaitExplosion::execute": 0x802daa74,
		"TNerveBombHeiWaitExplosion::~TNerveBombHeiWaitExplosion": 0x802dace4,
		"TNerveBombHeiWalkExplosion::execute": 0x802dad40,
		"TNerveBombHeiWalkExplosion::~TNerveBombHeiWalkExplosion": 0x802daef0,
		"TNerveBombHeiAttack::execute": 0x802daf4c,
		"TNerveBombHeiAttack::~TNerveBombHeiAttack": 0x802db03c,
		"TNerveBombHeiGenerate::execute": 0x802db098,
		"TNerveBombHeiGenerate::~TNerveBombHeiGenerate": 0x802db2a4,
		"TBombHei::getBasNameTable": 0x802db300,
		"TBombHei::isDamageToCannon": 0x802db30c,
		"isDamageToCannon": 0x802db30c,
		"TBombHei::forceKill": 0x802db3fc,
		"TBombHei::isCollidMove": 0x802db608,
		"TBombHei::moveObject": 0x802db94c,
		"TBombHei::walkBehavior": 0x802dbbb0,
		"TBombHei::getGravityY": 0x802dbc34,
		"TBombHei::reset": 0x802dbcc4,
		"TBombHei::behaveToRelease": 0x802dbd1c,
		"TBombHei::behaveToTaken": 0x802dbe9c,
		"TBombHei::attackToMario": 0x802dbff0,
		"TBombHei::calcRootMatrix": 0x802dc07c,
		"TBombHei::setDeadAnm": 0x802dc138,
		"TBombHei::setFreezeAnm": 0x802dc214,
		"TBombHei::setWalkAnm": 0x802dc244,
		"TBombHei::genEventCoin": 0x802dc274,
		"TBombHei::kill": 0x802dc384,
		"TBombHei::isHitValid": 0x802dc518,
		"TBombHei::changeOut": 0x802dc570,
		"TBombHei::behaveToWater": 0x802dc664,
		"TBombHei::setMActorAndKeeper": 0x802dc778,
		"TBombHei::init": 0x802dc7f8,
		"TBombHei::TBombHei": 0x802dc8f0,
		"TBombHeiManager::createEnemyInstance": 0x802dc94c,
		"TBombHeiManager::createModelData": 0x802dc9bc,
		"TBombHeiManager::load": 0x802dc9f0,
		"TBombHeiManager::TBombHeiManager": 0x802dcb80,
		"TBombHei::setAfterDeadEffect": 0x802dcbc4,
		"TBombHei::doKeepDistance": 0x802dcbc8,
		"TBombHeiManager::~TBombHeiManager": 0x802dcc7c,
		"Enemy::__sinit_bombhei_cpp": 0x802dccf0,
		"__sinit_bombhei_cpp": 0x802dccf0,
		"TNerveCannonObject::~TNerveCannonObject": 0x802dcff4,
		"TNerveCannonObject::execute": 0x802dd050,
		"TNerveCannonDamageDemo::execute": 0x802dd230,
		"TNerveCannonDamageDemo::~TNerveCannonDamageDemo": 0x802dd45c,
		"TNerveCannonDamage::execute": 0x802dd4b8,
		"TNerveCannonSearch::~TNerveCannonSearch": 0x802ddacc,
		"TNerveCannonDamage::~TNerveCannonDamage": 0x802ddb28,
		"TNerveCannonClose::execute": 0x802ddb84,
		"TNerveCannonOpen::~TNerveCannonOpen": 0x802ddebc,
		"TNerveCannonClose::~TNerveCannonClose": 0x802ddf18,
		"TNerveCannonForceBombShoot::execute": 0x802ddf74,
		"TNerveCannonForceBombShoot::~TNerveCannonForceBombShoot": 0x802de220,
		"TNerveCannonShoot::execute": 0x802de27c,
		"TNerveCannonShoot::~TNerveCannonShoot": 0x802de618,
		"TNerveCannonSearch::execute": 0x802de674,
		"TNerveCannonOpen::execute": 0x802ded38,
		"TCannon::startChorobeiShout": 0x802def00,
		"startChorobeiShout": 0x802def00,
		"TCannon::isObject": 0x802def04,
		"isObject": 0x802def04,
		"TCannon::setKillerGoalPoint": 0x802def5c,
		"setKillerGoalPoint": 0x802def5c,
		"TCannon::killerShoot": 0x802df19c,
		"killerShoot": 0x802df19c,
		"TCannon::bombShoot": 0x802dfa94,
		"bombShoot": 0x802dfa94,
		"TCannon::bombSet": 0x802dfc60,
		"bombSet": 0x802dfc60,
		"TCannon::getTakingMtx": 0x802dfec4,
		"TCannon::calcRootMatrix": 0x802dff6c,
		"TCannon::perform": 0x802e03f8,
		"TCannon::getBasNameTable": 0x802e0894,
		"TCannon::receiveMessage": 0x802e08a0,
		"TCannon::moveObject": 0x802e08e8,
		"TCannon::reset": 0x802e0bc4,
		"TCannon::init": 0x802e0cec,
		"TCannon::loadAfter": 0x802e12d0,
		"TCannon::load": 0x802e1480,
		"TCannon::TCannon": 0x802e1528,
		"TCannonDom::perform": 0x802e15f0,
		"TCannonDom::TCannonDom": 0x802e16e8,
		"TChorobei::receiveMessage": 0x802e17f8,
		"TChorobei::checkHit": 0x802e1800,
		"TChorobei::perform": 0x802e1a8c,
		"TChorobei::TChorobei": 0x802e1bb4,
		"TCannonManager::createEnemyInstance": 0x802e1cc8,
		"TCannonManager::load": 0x802e1d0c,
		"TCannonManager::TCannonManager": 0x802e1d64,
		"TCannonSaveLoadParams::TCannonSaveLoadParams": 0x802e1da0,
		"TCannon::isCollidMove": 0x802e2044,
		"TCannon::isHitVallid": 0x802e204c,
		"isHitVallid": 0x802e204c,
		"TCannon::isInhibitedForceMove": 0x802e2054,
		"TCannonDom::~TCannonDom": 0x802e20e0,
		"TCannonManager::~TCannonManager": 0x802e21e8,
		"TCannonManager::clipEnemies": 0x802e225c,
		"Enemy::__sinit_cannon_cpp": 0x802e2260,
		"__sinit_cannon_cpp": 0x802e2260,
		"TNerveBossEelSleepOnBottom::~TNerveBossEelSleepOnBottom": 0x802e256c,
		"TNerveBossEelSleepOnBottom::execute": 0x802e25c8,
		"TNerveBossEelSleepOnBottom::theNerve": 0x802e275c,
		"TNerveBossEelMouthOpenWait::execute": 0x802e27c0,
		"TNerveBossEelEat::~TNerveBossEelEat": 0x802e2cc8,
		"TNerveBossEelMouthOpenWait::theNerve": 0x802e2d24,
		"TNerveBossEelMouthOpenWait::~TNerveBossEelMouthOpenWait": 0x802e2d88,
		"TNerveBossEelDie::execute": 0x802e2de4,
		"TNerveBossEelDie::theNerve": 0x802e326c,
		"TNerveBossEelDie::~TNerveBossEelDie": 0x802e32d0,
		"TNerveBossEelEat::execute": 0x802e332c,
		"TNerveBossEelQuickBack::~TNerveBossEelQuickBack": 0x802e3968,
		"TNerveBossEelEat::theNerve": 0x802e39c4,
		"TNerveBossEelQuickBack::execute": 0x802e3a28,
		"TNerveBossEelQuickBack::theNerve": 0x802e3b4c,
		"TNerveBossEelSlowBack::execute": 0x802e3bb0,
		"TNerveBossEelSlowBack::theNerve": 0x802e3bd8,
		"TNerveBossEelSlowBack::~TNerveBossEelSlowBack": 0x802e3c3c,
		"Enemy::ExecBackNerve_Sub": 0x802e3c98,
		"ExecBackNerve_Sub": 0x802e3c98,
		"TNerveBossEelSecondSpin::~TNerveBossEelSecondSpin": 0x802e4044,
		"TNerveBossEelOutWait::execute": 0x802e40a0,
		"TNerveBossEelOutWait::~TNerveBossEelOutWait": 0x802e4654,
		"TNerveBossEelOutWait::theNerve": 0x802e46b0,
		"TNerveBossEelAppear::execute": 0x802e4714,
		"TNerveBossEelAppear::theNerve": 0x802e4a64,
		"TNerveBossEelAppear::~TNerveBossEelAppear": 0x802e4ac8,
		"TNerveBossEelSecondSpin::execute": 0x802e4b24,
		"TNerveBossEelSecondSpin::theNerve": 0x802e4f48,
		"TNerveBossEelFirstSpin::execute": 0x802e4fac,
		"TNerveBossEelFirstSpin::theNerve": 0x802e5308,
		"TNerveBossEelFirstSpin::~TNerveBossEelFirstSpin": 0x802e536c,
		"TNerveBossEelWaitAppear::execute": 0x802e53c8,
		"TNerveBossEelWaitAppear::theNerve": 0x802e55b8,
		"TNerveBossEelWaitAppear::~TNerveBossEelWaitAppear": 0x802e561c,
		"TBossEel::getBasNameTable": 0x802e5678,
		"Enemy::hoseiDiveCameraCallback": 0x802e5684,
		"hoseiDiveCameraCallback": 0x802e5684,
		"TBossEel::isInBossEelMoguDemo": 0x802e56e4,
		"isInBossEelMoguDemo": 0x802e56e4,
		"TBossEel::perform": 0x802e5740,
		"TBossEel::collideToMario": 0x802e6374,
		"collideToMario": 0x802e6374,
		"TBossEel::forceShedTears": 0x802e6744,
		"forceShedTears": 0x802e6744,
		"TBossEel::shedTears": 0x802e6868,
		"shedTears": 0x802e6868,
		"TBossEel::updateTearsCnt": 0x802e69d0,
		"updateTearsCnt": 0x802e69d0,
		"TBossEel::getTakingMtx": 0x802e6c64,
		"TBossEel::init": 0x802e6c78,
		"TBossEelTearsRecoverCollision::perform": 0x802e77fc,
		"TBossEelTearsRecoverCollision::behaveToMario": 0x802e78ac,
		"TBossEelTearsRecoverCollision::initCollision": 0x802e78f0,
		"TBossEelBarrierCollision::behaveToMario": 0x802e7944,
		"TBossEelBarrierCollision::initCollision": 0x802e79b0,
		"TBossEelAwaCollision::perform": 0x802e7a04,
		"TBossEelAwaCollision::behaveToMario": 0x802e7b38,
		"TBossEelAwaCollision::initCollision": 0x802e7bb4,
		"TBossEelBodyCollision::initCollision": 0x802e7c08,
		"TBossEelCollision::behaveToMario": 0x802e7c64,
		"TBossEelCollision::initCollision": 0x802e7e8c,
		"TBossEelCollision::perform": 0x802e7ecc,
		"TNerveBEelTearsMarioRecover::~TNerveBEelTearsMarioRecover": 0x802e7fa8,
		"TBossEel::TBossEel": 0x802e8004,
		"TBossEelHeartCoin::generate": 0x802e80ec,
		"TBossEelHeartCoin::perform": 0x802e81b8,
		"TBossEelEye::perform": 0x802e8418,
		"TBossEelEye::TBossEelEye": 0x802e86c8,
		"TBossEelVortex::reset": 0x802e8810,
		"TBossEelVortex::perform": 0x802e8834,
		"TBossEelTooth::perform": 0x802e8b84,
		"TBossEelTooth::receiveMessage": 0x802e9194,
		"TBossEelTooth::TBossEelTooth": 0x802e94e8,
		"TBossEelManager::clipEnemies": 0x802e9710,
		"TBossEelManager::createModelData": 0x802e9738,
		"TBossEelManager::loadAfter": 0x802e976c,
		"TBossEelSaveParams::TBossEelSaveParams": 0x802e9a10,
		"TNerveOilBallStay::execute": 0x802ea084,
		"TNerveOilBallStay::theNerve": 0x802ea110,
		"TNerveOilBallStay::~TNerveOilBallStay": 0x802ea174,
		"TOilBall::calcRootMatrix": 0x802ea1d0,
		"TOilBall::moveObject": 0x802ea1f0,
		"TNerveBEelTearsSplit::~TNerveBEelTearsSplit": 0x802ea55c,
		"TNerveBEelTearsMoveUp::~TNerveBEelTearsMoveUp": 0x802ea5b8,
		"TOilBall::reset": 0x802ea614,
		"TNerveBEelTearsGenerate::~TNerveBEelTearsGenerate": 0x802ea7a4,
		"TOilBall::load": 0x802ea800,
		"TNerveBEelTearsSplit::execute": 0x802ea860,
		"TNerveBEelTearsSplit::theNerve": 0x802eaab8,
		"TNerveBEelTearsMarioRecover::execute": 0x802eab1c,
		"TNerveBEelTearsMarioRecover::theNerve": 0x802eac7c,
		"TNerveBEelTearsWaterHit::execute": 0x802eace0,
		"TNerveBEelTearsWaterHit::theNerve": 0x802eafac,
		"TNerveBEelTearsWaterHit::~TNerveBEelTearsWaterHit": 0x802eb010,
		"TNerveBEelTearsMoveUp::execute": 0x802eb06c,
		"TNerveBEelTearsMoveUp::theNerve": 0x802eb0d8,
		"TNerveBEelTearsGenerate::execute": 0x802eb13c,
		"TNerveBEelTearsGenerate::theNerve": 0x802eb234,
		"TBEelTears::getBasNameTable": 0x802eb298,
		"TBEelTears::reset": 0x802eb2a4,
		"TBEelTears::kill": 0x802eb390,
		"TBEelTears::receiveMessage": 0x802eb3bc,
		"TBEelTears::perform": 0x802eb5b8,
		"TBEelTears::calcRootMatrix": 0x802eb704,
		"TBEelTears::moveObject": 0x802eb86c,
		"TBEelTears::setMActorAndKeeper": 0x802ebc34,
		"TBEelTears::init": 0x802ebcb4,
		"TBEelTears::TBEelTears": 0x802ebfd0,
		"TBEelTearsManager::splitTears": 0x802ec030,
		"splitTears": 0x802ec030,
		"TBEelTearsManager::createEnemies": 0x802ec2ac,
		"TBEelTearsManager::createEnemyInstance": 0x802ec364,
		"TBEelTearsManager::perform": 0x802ec3dc,
		"TBEelTearsManager::createModelData": 0x802ec4d8,
		"TBEelTearsManager::loadAfter": 0x802ec50c,
		"TBEelTearsManager::load": 0x802ec5d0,
		"TBEelTearsManager::TBEelTearsManager": 0x802ec63c,
		"TBEelTearsSaveLoadParams::TBEelTearsSaveLoadParams": 0x802ec678,
		"TBEelTearsDrop::perform": 0x802eca20,
		"TBEelTearsDrop::TBEelTearsDrop": 0x802ecb70,
		"TBossEel::hasMapCollision": 0x802ece08,
		"TBossEel::receiveMessage": 0x802ece10,
		"TBossEelHeartCoin::~TBossEelHeartCoin": 0x802ed088,
		"TBossEelEye::~TBossEelEye": 0x802ed10c,
		"TBossEelManager::~TBossEelManager": 0x802ed298,
		"TBEelTearsManager::~TBEelTearsManager": 0x802ed380,
		"Enemy::__sinit_bosseel_cpp": 0x802ed468,
		"__sinit_bosseel_cpp": 0x802ed468,
		"TNerveKillerExplosion::~TNerveKillerExplosion": 0x802ed7bc,
		"TNerveKillerExplosion::execute": 0x802ed818,
		"TKiller::isFindMario": 0x802edabc,
		"TKiller::calcRootMatrix": 0x802edb74,
		"TKiller::bind": 0x802edf3c,
		"TNerveFlyEnemyChaseFly::~TNerveFlyEnemyChaseFly": 0x802ee334,
		"TKiller::setColorType": 0x802ee390,
		"setColorType": 0x802ee390,
		"TKiller::reset": 0x802ee3d4,
		"TKiller::changeOut": 0x802ee4e8,
		"TKiller::flyBehavior": 0x802ee5dc,
		"TKiller::isCollidMove": 0x802ee694,
		"TKiller::isRollFly": 0x802ee7f8,
		"isRollFly": 0x802ee7f8,
		"TKiller::setChaseFlyAnm": 0x802ee8a4,
		"TKiller::setNormalFlyAnm": 0x802ee8d4,
		"TKiller::getBasNameTable": 0x802ee938,
		"TKiller::attackToMario": 0x802ee944,
		"TKiller::setDeadAnm": 0x802eea94,
		"TKiller::isHitValid": 0x802eeb38,
		"TKiller::genEventCoin": 0x802eebac,
		"TKiller::behaveToWater": 0x802eed90,
		"TNerveFlyEnemyNormalFly::~TNerveFlyEnemyNormalFly": 0x802eefa0,
		"TKiller::setMActorAndKeeper": 0x802eeffc,
		"TKiller::init": 0x802ef150,
		"TKiller::TKiller": 0x802ef2f0,
		"Enemy::KillerBodyCallback": 0x802ef400,
		"KillerBodyCallback": 0x802ef400,
		"TKillerManager::createEnemyInstance": 0x802ef5f8,
		"TFlyEnemy::TFlyEnemy": 0x802ef660,
		"TKillerManager::createModelData": 0x802ef6c0,
		"TKillerManager::load": 0x802ef6f4,
		"TKillerManager::TKillerManager": 0x802ef8c8,
		"TNerveFlyEnemyChaseFly::execute": 0x802ef90c,
		"TFlyEnemy::flyBehavior": 0x802efe54,
		"Enemy::MsSin": 0x802efe68,
		"MsSin": 0x802efe68,
		"Enemy::MsCos": 0x802efea0,
		"MsCos": 0x802efea0,
		"TFlyEnemy::setChaseFlyAnm": 0x802eff20,
		"TNerveFlyEnemyNormalFly::execute": 0x802eff24,
		"TFlyEnemy::setNormalFlyAnm": 0x802f0174,
		"TFlyEnemy::bind": 0x802f0178,
		"TFlyEnemy::calcChaseParam": 0x802f021c,
		"calcChaseParam": 0x802f021c,
		"TFlyEnemy::fly": 0x802f044c,
		"fly": 0x802f044c,
		"TFlyEnemy::reset": 0x802f0690,
		"TFlyEnemy::getGravityY": 0x802f06e0,
		"TFlyEnemy::init": 0x802f0770,
		"TKiller::forceKill": 0x802f07b4,
		"TFlyEnemy::setAfterDeadEffect": 0x802f07b8,
		"TKillerManager::~TKillerManager": 0x802f0858,
		"Enemy::__sinit_killer_cpp": 0x802f08cc,
		"__sinit_killer_cpp": 0x802f08cc,
		"TBeamManager::~TBeamManager": 0x802f0bd8,
		"TBeamManager::perform": 0x802f0c4c,
		"TBeamManager::requestCone": 0x802f0d7c,
		"requestCone": 0x802f0d7c,
		"TBeamManager::setupMaterial": 0x802f0e74,
		"setupMaterial": 0x802f0e74,
		"TBeamManager::TBeamManager": 0x802f0f4c,
		"TConeBeam::drawConeBeam": 0x802f0ff8,
		"drawConeBeam": 0x802f0ff8,
		"TConeBeam::calcVertices": 0x802f1174,
		"calcVertices": 0x802f1174,
		"TConeBeam::drawConeBeamAux": 0x802f1804,
		"drawConeBeamAux": 0x802f1804,
		"TConeBeam::TConeBeam": 0x802f19d0,
		"TNerveSamboHeadHitWall::~TNerveSamboHeadHitWall": 0x802f1a50,
		"TNerveSamboHeadHitWall::execute": 0x802f1aac,
		"TNerveSamboHeadRecoverWater::execute": 0x802f1cc0,
		"TNerveSamboHeadRecoverWater::~TNerveSamboHeadRecoverWater": 0x802f1d4c,
		"TNerveSamboHeadHitWater::execute": 0x802f1da8,
		"TNerveSamboHeadAttack::~TNerveSamboHeadAttack": 0x802f22a8,
		"TNerveSamboHeadHitWater::~TNerveSamboHeadHitWater": 0x802f2304,
		"TNerveSamboHeadHide::execute": 0x802f2360,
		"TNerveSamboHeadAppear::~TNerveSamboHeadAppear": 0x802f25a0,
		"TNerveSamboHeadHide::~TNerveSamboHeadHide": 0x802f25fc,
		"TNerveSamboHeadAttack::execute": 0x802f2658,
		"TNerveSamboHeadAppear::execute": 0x802f29d8,
		"TSamboHead::getBasNameTable": 0x802f2c58,
		"TSamboHead::genEventCoin": 0x802f2c64,
		"TSamboHead::calcRootMatrix": 0x802f2f30,
		"TSamboHead::setAfterDeadEffect": 0x802f2f54,
		"TSamboHead::setDeadAnm": 0x802f3084,
		"TSamboHead::getGravityY": 0x802f30b4,
		"TSamboHead::attackToMario": 0x802f31ac,
		"TSamboHead::behaveToWater": 0x802f3330,
		"TSamboHead::kill": 0x802f3658,
		"TSamboHead::reset": 0x802f3718,
		"TSamboHead::setMActorAndKeeper": 0x802f376c,
		"TSamboHead::init": 0x802f37d8,
		"TSamboHead::load": 0x802f3928,
		"TSamboHead::TSamboHead": 0x802f39e8,
		"TSamboHeadManager::createEnemyInstance": 0x802f3a48,
		"TSamboHeadManager::createModelData": 0x802f3ac0,
		"TSamboHeadManager::load": 0x802f3af4,
		"TSamboHeadManager::TSamboHeadManager": 0x802f3d8c,
		"Enemy::SamboHeadRollCallback": 0x802f3dd0,
		"SamboHeadRollCallback": 0x802f3dd0,
		"TNerveHanaSamboFreeze::execute": 0x802f40d4,
		"TNerveHanaSamboFreeze::~TNerveHanaSamboFreeze": 0x802f41d0,
		"TNerveHanaSamboDie::execute": 0x802f422c,
		"TNerveHanaSamboDie::~TNerveHanaSamboDie": 0x802f4468,
		"TNerveHanaSamboHide::execute": 0x802f44c4,
		"TNerveHanaSamboAppear::~TNerveHanaSamboAppear": 0x802f4758,
		"TNerveHanaSamboHide::~TNerveHanaSamboHide": 0x802f47b4,
		"TNerveHanaSamboAttack::execute": 0x802f4810,
		"TNerveHanaSamboWait::~TNerveHanaSamboWait": 0x802f4a04,
		"TNerveHanaSamboAttack::~TNerveHanaSamboAttack": 0x802f4a60,
		"TNerveHanaSamboWait::execute": 0x802f4abc,
		"TNerveHanaSamboAppear::execute": 0x802f4cc8,
		"THanaSambo::createPollen": 0x802f4f18,
		"createPollen": 0x802f4f18,
		"THanaSambo::perform": 0x802f50c0,
		"THanaSambo::getBasNameTable": 0x802f5120,
		"THanaSambo::setDeadAnm": 0x802f512c,
		"THanaSambo::setWaitAnm": 0x802f51cc,
		"THanaSambo::reset": 0x802f5210,
		"THanaSambo::kill": 0x802f525c,
		"THanaSambo::drawObject": 0x802f541c,
		"THanaSambo::moveObject": 0x802f545c,
		"THanaSambo::setMActorAndKeeper": 0x802f5574,
		"THanaSambo::init": 0x802f55f4,
		"THanaSambo::load": 0x802f58a4,
		"THanaSambo::THanaSambo": 0x802f5964,
		"THanaSamboHead::receiveMessage": 0x802f59e0,
		"THanaSamboManager::createModelData": 0x802f5b58,
		"THanaSamboManager::createEnemyInstance": 0x802f5b8c,
		"THanaSamboManager::load": 0x802f5c20,
		"THanaSamboManager::THanaSamboManager": 0x802f5e34,
		"TSamboFlower::drawObject": 0x802f5e70,
		"TSamboFlower::moveObject": 0x802f5f28,
		"TSamboFlower::reset": 0x802f60d0,
		"TSamboFlower::receiveMessage": 0x802f613c,
		"TSamboFlower::setMActorAndKeeper": 0x802f6228,
		"TSamboFlower::init": 0x802f62c0,
		"TSamboFlower::loadAfter": 0x802f63d4,
		"TSamboFlower::load": 0x802f6458,
		"TSamboFlowerManager::dropLeaf": 0x802f64d8,
		"dropLeaf": 0x802f64d8,
		"TSamboFlowerManager::perform": 0x802f6708,
		"TSamboFlowerManager::loadAfter": 0x802f67c0,
		"TSamboFlowerManager::createEnemyInstance": 0x802f6b78,
		"TSamboFlowerManager::createModelData": 0x802f6bc0,
		"TSamboFlowerManager::load": 0x802f6bf4,
		"TSamboFlowerSaveLoadParams::TSamboFlowerSaveLoadParams": 0x802f6c60,
		"TSamboLeaf::perform": 0x802f6f00,
		"TSamboFlowerCoinUnit::checkGenCoin": 0x802f7124,
		"checkGenCoin": 0x802f7124,
		"TSamboHeadManager::~TSamboHeadManager": 0x802f7514,
		"THanaSambo::behaveToWater": 0x802f7588,
		"THanaSambo::isHitValid": 0x802f758c,
		"THanaSambo::isCollidMove": 0x802f75a4,
		"THanaSamboManager::~THanaSamboManager": 0x802f76b4,
		"TSamboFlower::control": 0x802f7728,
		"TSamboFlowerManager::~TSamboFlowerManager": 0x802f7798,
		"TSamboLeaf::~TSamboLeaf": 0x802f77fc,
		"Enemy::__sinit_hanasambo_cpp": 0x802f7870,
		"__sinit_hanasambo_cpp": 0x802f7870,
		"TNervePopoThrown::~TNervePopoThrown": 0x802f7b8c,
		"TNervePopoThrown::execute": 0x802f7be8,
		"TNervePopoWait::execute": 0x802f7c80,
		"TNervePopoWait::~TNervePopoWait": 0x802f7d70,
		"TNervePopoExplosion::execute": 0x802f7dcc,
		"TNervePopoExplosion::~TNervePopoExplosion": 0x802f7fa0,
		"TNervePopoFly::execute": 0x802f7ffc,
		"TNervePopoFly::~TNervePopoFly": 0x802f82e0,
		"TNervePopoAttack::execute": 0x802f833c,
		"TNervePopoAttack::~TNervePopoAttack": 0x802f84d4,
		"TNervePopoPossessedNozzle::execute": 0x802f8530,
		"TNervePopoPossessedNozzle::~TNervePopoPossessedNozzle": 0x802f8700,
		"TPopo::getBasNameTable": 0x802f875c,
		"TPopo::thrownByChorobei": 0x802f8768,
		"thrownByChorobei": 0x802f8768,
		"TPopo::possessedIn": 0x802f87f4,
		"possessedIn": 0x802f87f4,
		"TPopo::explosion": 0x802f8908,
		"explosion": 0x802f8908,
		"TPopo::flyBehavior": 0x802f8a54,
		"TPopo::isCollidMove": 0x802f8c18,
		"TPopo::isFindMario": 0x802f8d68,
		"TPopo::isHitValid": 0x802f8e38,
		"TPopo::bind": 0x802f8f18,
		"TPopo::forceKill": 0x802f9304,
		"TPopo::kill": 0x802f9528,
		"TPopo::calcRootMatrix": 0x802f9568,
		"TPopo::attackToMario": 0x802f9a2c,
		"TPopo::walkBehavior": 0x802f9cd4,
		"TPopo::behaveToFindMario": 0x802fa1b4,
		"TPopo::getGravityY": 0x802fa3a0,
		"TPopo::behaveToWater": 0x802fa554,
		"TPopo::checkTrigger": 0x802fa7fc,
		"checkTrigger": 0x802fa7fc,
		"TPopo::reset": 0x802fab0c,
		"TPopo::setMActorAndKeeper": 0x802fac50,
		"TPopo::perform": 0x802facd0,
		"TPopo::init": 0x802fad24,
		"TPopo::load": 0x802faf70,
		"TPopo::TPopo": 0x802fafd0,
		"Enemy::PopoNonScaleCallback": 0x802fb04c,
		"PopoNonScaleCallback": 0x802fb04c,
		"Enemy::PopoPossessedCallback": 0x802fb1e8,
		"PopoPossessedCallback": 0x802fb1e8,
		"Enemy::PopoRollCallback": 0x802fb598,
		"PopoRollCallback": 0x802fb598,
		"TPopoCollision::receiveMessage": 0x802fb7c8,
		"TPopoManager::perform": 0x802fb8a4,
		"TPopoManager::createModelData": 0x802fb964,
		"TPopoManager::initSetEnemies": 0x802fb998,
		"TPopoManager::createEnemyInstance": 0x802fb9d8,
		"TPopoManager::load": 0x802fba1c,
		"TPopoManager::TPopoManager": 0x802fbac0,
		"TPopoSaveLoadParams::TPopoSaveLoadParams": 0x802fbb18,
		"TPopoManager::~TPopoManager": 0x802fbf38,
		"Enemy::__sinit_popo_cpp": 0x802fbfac,
		"__sinit_popo_cpp": 0x802fbfac,
		"TNerveSBH_Fall::~TNerveSBH_Fall": 0x802fc2b8,
		"TNerveSBH_Fall::execute": 0x802fc314,
		"TNerveSBH_SleepContinue::~TNerveSBH_SleepContinue": 0x802fc450,
		"TNerveSBH_Fall::theNerve": 0x802fc4ac,
		"TNerveSBH_SleepContinue::execute": 0x802fc510,
		"TNerveSBH_SleepContinue::theNerve": 0x802fc518,
		"TSleepBossHanachan::startFall": 0x802fc57c,
		"startFall": 0x802fc57c,
		"TSleepBossHanachan::getBasNameTable": 0x802fc668,
		"TSleepBossHanachan::calcRootMatrix": 0x802fc670,
		"TSleepBossHanachan::init": 0x802fc674,
		"TSleepBossHanachanManager::createModelData": 0x802fc834,
		"TSleepBossHanachanManager::~TSleepBossHanachanManager": 0x802fc8ec,
		"TDemoBossHanachan::receiveMessage": 0x802fc968,
		"TDemoBossHanachan::initBase": 0x802fc970,
		"initBase": 0x802fc970,
		"TDemoBossHanachanManager::clipEnemies": 0x802fca70,
		"TDemoBossHanachanSaveParams::TDemoBossHanachanSaveParams": 0x802fca9c,
		"TNerveFruitsBoatBckTrace::~TNerveFruitsBoatBckTrace": 0x802fcb70,
		"TNerveFruitsBoatBckTrace::execute": 0x802fcbcc,
		"TNerveFruitsBoatGraphWander::execute": 0x802fcd2c,
		"TNerveFruitsBoatGraphWander::~TNerveFruitsBoatGraphWander": 0x802fd150,
		"TFruitsBoatManager::createEnemyInstance": 0x802fd1f4,
		"TFruitsBoatManager::load": 0x802fd1fc,
		"TFruitsBoatManager::createModelData": 0x802fd2fc,
		"TFruitsBoatManager::TFruitsBoatManager": 0x802fd3a0,
		"TFruitsBoat::requestShadow": 0x802fd3f0,
		"TFruitsBoat::moveObject": 0x802fd550,
		"TFruitsBoat::calcRootMatrix": 0x802fdd70,
		"TFruitsBoat::setGroundCollision": 0x802fde20,
		"TFruitsBoat::receiveMessage": 0x802fdfc4,
		"TFruitsBoat::init": 0x802fdfcc,
		"TFruitsBoat::load": 0x802fe470,
		"TFruitsBoat::getRootJointMtx": 0x802fe5c8,
		"TFruitsBoat::setBckTrack": 0x802fe5d8,
		"setBckTrack": 0x802fe5d8,
		"TFruitsBoat::TFruitsBoat": 0x802fe6f0,
		"TFruitsBoatManager::~TFruitsBoatManager": 0x802fe778,
		"Enemy::__sinit_fruitsboat_cpp": 0x802fe848,
		"__sinit_fruitsboat_cpp": 0x802fe848,
		"TSphereLink::setDegreeZAndRevisionPosXZ": 0x802feb4c,
		"setDegreeZAndRevisionPosXZ": 0x802feb4c,
		"TSphereLink::moveHead": 0x802fed68,
		"TBGCheckData::isIllegalData": 0x802ff13c,
		"isIllegalData": 0x802ff13c,
		"TSphereLink::TSphereLink": 0x802ff158,
		"TSpherePoint::TSpherePoint": 0x802ff338,
		"TWaterHitActor::receiveMessage": 0x802ff33c,
		"TWaterHitActor::onWaterHitCounter": 0x802ff3ac,
		"onWaterHitCounter": 0x802ff3ac,
		"Enemy::BHSCalcRevisionDistXZByRotateZ": 0x802ff3b8,
		"BHSCalcRevisionDistXZByRotateZ": 0x802ff3b8,
		"Enemy::BHSCalcCentrifugalForce": 0x802ff444,
		"BHSCalcCentrifugalForce": 0x802ff444,
		"TBossHanachan::hasMapCollision": 0x802ff760,
		"TBossHanachan::removeAllMapCollision": 0x802ff768,
		"removeAllMapCollision": 0x802ff768,
		"TBossHanachan::execDamage": 0x802ff7ec,
		"execDamage": 0x802ff7ec,
		"TBossHanachan::goToInitialRecoverGraphNode": 0x802ffacc,
		"goToInitialRecoverGraphNode": 0x802ffacc,
		"TBossHanachan::execSlip": 0x802ffb64,
		"execSlip": 0x802ffb64,
		"TBossHanachan::execWalk": 0x802fff04,
		"TBossHanachan::getBodyMaxRotateZ": 0x80300108,
		"getBodyMaxRotateZ": 0x80300108,
		"TBossHanachan::checkFallDecideAndSetup": 0x80300210,
		"checkFallDecideAndSetup": 0x80300210,
		"TBossHanachan::isTumbleCompletelyAllBody": 0x80300318,
		"isTumbleCompletelyAllBody": 0x80300318,
		"TBossHanachan::perform": 0x80300414,
		"TBossHanachan::moveObject": 0x80301c3c,
		"TBossHanachan::bind": 0x80301d10,
		"TBossHanachan::kill": 0x8030201c,
		"Enemy::CalcRevisionPosByRotateZ": 0x80302020,
		"CalcRevisionPosByRotateZ": 0x80302020,
		"TBossHanachan::throwMario_": 0x803020f0,
		"throwMario_": 0x803020f0,
		"TBossHanachan::init": 0x80302470,
		"TBossHanachan::setRandomWeakBodyIndex": 0x803029b8,
		"setRandomWeakBodyIndex": 0x803029b8,
		"TBossHanachan::TBossHanachan": 0x80302a20,
		"TBossHanachanManager::hasMapCollision": 0x80302b08,
		"TBossHanachanManager::clipEnemies": 0x80302b10,
		"TBossHanachanManager::loadAfter": 0x80302b3c,
		"TBossHanachanManager::createModelData": 0x80302bc8,
		"TBossHanachanManager::TBossHanachanManager": 0x80302c20,
		"TBossHanachanManager::~TBossHanachanManager": 0x80302d08,
		"Enemy::__sinit_BossHanachanMain_cpp": 0x80302d6c,
		"__sinit_BossHanachanMain_cpp": 0x80302d6c,
		"TNerveBossHanachanDead::~TNerveBossHanachanDead": 0x80303070,
		"TNerveBossHanachanDead::execute": 0x803030cc,
		"TNerveBossHanachanDead::theNerve": 0x80303138,
		"TNerveBossHanachanSnort::execute": 0x8030319c,
		"TNerveBossHanachanGraphWander::~TNerveBossHanachanGraphWander": 0x803032f4,
		"TNerveBossHanachanSnort::theNerve": 0x80303350,
		"TNerveBossHanachanSnort::~TNerveBossHanachanSnort": 0x803033b4,
		"TNerveBossHanachanDamage::execute": 0x80303410,
		"TNerveBossHanachanGetUp::~TNerveBossHanachanGetUp": 0x80303508,
		"TNerveBossHanachanDamage::theNerve": 0x80303564,
		"TNerveBossHanachanDamage::~TNerveBossHanachanDamage": 0x803035c8,
		"TNerveBossHanachanGetUp::execute": 0x80303624,
		"TNerveBossHanachanGetUp::theNerve": 0x80303708,
		"TNerveBossHanachanDown::execute": 0x8030376c,
		"TNerveBossHanachanDown::theNerve": 0x8030384c,
		"TNerveBossHanachanDown::~TNerveBossHanachanDown": 0x803038b0,
		"TNerveBossHanachanTumble::execute": 0x8030390c,
		"TNerveBossHanachanTumble::theNerve": 0x80303a2c,
		"TNerveBossHanachanTumble::~TNerveBossHanachanTumble": 0x80303a90,
		"TNerveBossHanachanGraphWander::execute": 0x80303aec,
		"TNerveBossHanachanGraphWander::theNerve": 0x80303bdc,
		"Enemy::__sinit_BossHanachanNerve_cpp": 0x80303c40,
		"__sinit_BossHanachanNerve_cpp": 0x80303c40,
		"TBossHanachan::changeAnmRateAndFrameUpdate_": 0x80303f3c,
		"changeAnmRateAndFrameUpdate_": 0x80303f3c,
		"TBossHanachan::isAllBckAlreadyEnd": 0x803045a8,
		"isAllBckAlreadyEnd": 0x803045a8,
		"TBossHanachan::isFinishedGetUp": 0x80304660,
		"isFinishedGetUp": 0x80304660,
		"TBossHanachan::considerSetAnm": 0x803046bc,
		"considerSetAnm": 0x803046bc,
		"TBossHanachan::setAnmTimerWhenDead": 0x80304730,
		"setAnmTimerWhenDead": 0x80304730,
		"TBossHanachan::setAnmTimerWhenDamage": 0x8030487c,
		"setAnmTimerWhenDamage": 0x8030487c,
		"TBossHanachan::setAnmTimerWhenSnort": 0x803049c8,
		"setAnmTimerWhenSnort": 0x803049c8,
		"TBossHanachan::setAnmTimerWhenGetUp": 0x80304a40,
		"setAnmTimerWhenGetUp": 0x80304a40,
		"TBossHanachan::setTumbleAnm": 0x80304ab4,
		"setTumbleAnm": 0x80304ab4,
		"TBossHanachan::setHeadAndBodyAnm": 0x80304c58,
		"setHeadAndBodyAnm": 0x80304c58,
		"TBossHanachanPartsHead::receiveMessage": 0x80304dfc,
		"TBossHanachanPartsBody::receiveMessage": 0x80304f94,
		"TBossHanachanPartsHead::setAnm_": 0x803051b8,
		"TBossHanachanPartsBody::setAnm_": 0x803052d4,
		"TBossHanachanPartsBase::considerSetAnm_": 0x80305408,
		"considerSetAnm_": 0x80305408,
		"TBossHanachanPartsBase::calcRotateZWhenGetUp_": 0x80305b3c,
		"calcRotateZWhenGetUp_": 0x80305b3c,
		"TBossHanachanPartsBase::getSandActor_": 0x80305bf0,
		"getSandActor_": 0x80305bf0,
		"TBossHanachanPartsBase::copyFrameFromOldAnmToNewAnm_": 0x80305c44,
		"copyFrameFromOldAnmToNewAnm_": 0x80305c44,
		"TBossHanachanPartsBase::isCurBckAlreadyEnd_": 0x80305cd8,
		"isCurBckAlreadyEnd_": 0x80305cd8,
		"TBossHanachanPartsBase::setDamageFog_": 0x80305db0,
		"setDamageFog_": 0x80305db0,
		"TBossHanachanPartsBase::entryCircleShadow_": 0x80305ea0,
		"entryCircleShadow_": 0x80305ea0,
		"TBossHanachanPartsBase::moveMapCollision_": 0x80305f68,
		"moveMapCollision_": 0x80305f68,
		"TBossHanachanPartsBase::changeTumbleAnmRate_": 0x80305fb8,
		"changeTumbleAnmRate_": 0x80305fb8,
		"TBossHanachanPartsBody::initFootHitActor_": 0x80306074,
		"initFootHitActor_": 0x80306074,
		"TBossHanachanPartsBase::initMapCollisionAndHitActor_": 0x80306218,
		"initMapCollisionAndHitActor_": 0x80306218,
		"TBossHanachanPartsHead::TBossHanachanPartsHead": 0x80306438,
		"TBossHanachanPartsBody::TBossHanachanPartsBody": 0x80306564,
		"TBossHanachanPartsBase::TBossHanachanPartsBase": 0x80306668,
		"Enemy::CLBPalFrame": 0x8030695c,
		"Enemy::__sinit_BossHanachanParts_cpp": 0x803069b8,
		"__sinit_BossHanachanParts_cpp": 0x803069b8,
		"TBossHanachanChangeSaveParams::TBossHanachanChangeSaveParams": 0x80306ccc,
		"TBossHanachanCommonSaveParams::TBossHanachanCommonSaveParams": 0x80307314,
		"TNerveAmiNokoFreeze::~TNerveAmiNokoFreeze": 0x80307894,
		"TNerveAmiNokoFreeze::execute": 0x803078f0,
		"TNerveAmiNokoDie::execute": 0x80307a0c,
		"TNerveAmiNokoDie::~TNerveAmiNokoDie": 0x80307ea4,
		"TNerveAmiNokoTurn::execute": 0x80307f00,
		"TNerveAmiNokoWalkOnFence::~TNerveAmiNokoWalkOnFence": 0x80308260,
		"TNerveAmiNokoTurn::~TNerveAmiNokoTurn": 0x803082bc,
		"TNerveAmiNokoWalkOnFence::execute": 0x80308318,
		"TAmiNoko::getBasNameTable": 0x803085e0,
		"TAmiNoko::creepToCurPathNode": 0x803085ec,
		"creepToCurPathNode": 0x803085ec,
		"TAmiNoko::getGravityY": 0x803087b8,
		"TAmiNoko::perform": 0x80308844,
		"TAmiNoko::bind": 0x803088a4,
		"TAmiNoko::calcRootMatrix": 0x80308ad0,
		"TAmiNoko::isHitValid": 0x803095e8,
		"TAmiNoko::setWalkAnm": 0x80309740,
		"TAmiNoko::attackToMario": 0x80309794,
		"TAmiNoko::behaveToWater": 0x803099bc,
		"TAmiNoko::reset": 0x80309adc,
		"TAmiNoko::setMActorAndKeeper": 0x80309afc,
		"TAmiNoko::init": 0x80309b68,
		"TAmiNoko::load": 0x80309d84,
		"TAmiNoko::TAmiNoko": 0x80309dcc,
		"TAmiHit::perform": 0x80309e74,
		"TAmiHit::receiveMessage": 0x8030a030,
		"TAmiNokoManager::createEnemyInstance": 0x8030a060,
		"TAmiNokoManager::createModelData": 0x8030a068,
		"TAmiNokoManager::load": 0x8030a09c,
		"TAmiNokoManager::TAmiNokoManager": 0x8030a178,
		"TAmiNoko::isCollidMove": 0x8030a250,
		"TAmiNokoManager::~TAmiNokoManager": 0x8030a2dc,
		"Enemy::__sinit_amiNoko_cpp": 0x8030a350,
		"__sinit_amiNoko_cpp": 0x8030a350,
		"TNerveBGKLaunchName::~TNerveBGKLaunchName": 0x8030a65c,
		"TNerveBGKLaunchName::execute": 0x8030a6b8,
		"TNerveBGKAppear::~TNerveBGKAppear": 0x8030a7dc,
		"TNerveBGKLaunchGoro::execute": 0x8030a838,
		"TNerveBGKSleep::~TNerveBGKSleep": 0x8030aa0c,
		"TNerveBGKLaunchGoro::~TNerveBGKLaunchGoro": 0x8030aa68,
		"TNerveBGKDive::execute": 0x8030aac4,
		"TNerveBGKDive::~TNerveBGKDive": 0x8030accc,
		"TNerveBGKDie::execute": 0x8030ad28,
		"TNerveBGKDie::~TNerveBGKDie": 0x8030b100,
		"TNerveBGKAwakeDamage::execute": 0x8030b15c,
		"TNerveBGKWait::~TNerveBGKWait": 0x8030b35c,
		"TNerveBGKWait2::~TNerveBGKWait2": 0x8030b3b8,
		"TNerveBGKAwakeDamage::~TNerveBGKAwakeDamage": 0x8030b414,
		"TNerveBGKSleepDamage::execute": 0x8030b470,
		"TNerveBGKSleepDamage::~TNerveBGKSleepDamage": 0x8030b644,
		"TNerveBGKWait2::execute": 0x8030b6a0,
		"TNerveBGKWait::execute": 0x8030ba64,
		"TNerveBGKAppear::execute": 0x8030c024,
		"TNerveBGKSleep::execute": 0x8030c2b0,
		"TBiancoGateKeeper::perform": 0x8030c5a4,
		"TBiancoGateKeeper::controlCollision": 0x8030c8f8,
		"TBiancoGateKeeper::emitParticles": 0x8030ca74,
		"emitParticles": 0x8030ca74,
		"TBiancoGateKeeper::getBasNameTable": 0x8030cc30,
		"TBiancoGateKeeper::isDamageFogSituation": 0x8030cc3c,
		"isDamageFogSituation": 0x8030cc3c,
		"TBiancoGateKeeper::isHeadHitActive": 0x8030cda8,
		"isHeadHitActive": 0x8030cda8,
		"TBiancoGateKeeper::getRumblePow": 0x8030ce94,
		"getRumblePow": 0x8030ce94,
		"TBiancoGateKeeper::launchNamekuri": 0x8030cf70,
		"launchNamekuri": 0x8030cf70,
		"TBiancoGateKeeper::changeBck": 0x8030d26c,
		"TBiancoGateKeeper::kill": 0x8030d528,
		"TBiancoGateKeeper::init": 0x8030d564,
		"TBiancoGateKeeper::TBiancoGateKeeper": 0x8030dcc4,
		"TBiancoGateKeeperManager::createModelData": 0x8030e2b0,
		"TBiancoGateKeeperManager::load": 0x8030e2e4,
		"TBiancoGateKeeperManager::initJParticle": 0x8030e420,
		"TBiancoGateKeeperManager::TBiancoGateKeeperManager": 0x8030e5a4,
		"TGateKeeperBase::perform": 0x8030e5e0,
		"TGateKeeperBase::receiveMessage": 0x8030e718,
		"TGateKeeperBase::kill": 0x8030e7b8,
		"TGKHitObj::perform": 0x8030e7c8,
		"TGKHitObj::receiveMessage": 0x8030e854,
		"TBGKMtxCalc::~TBGKMtxCalc": 0x8030ea14,
		"TBiancoGateKeeperManager::~TBiancoGateKeeperManager": 0x8030eac0,
		"Enemy::__sinit_gatekeeper_cpp": 0x8030eba8,
		"__sinit_gatekeeper_cpp": 0x8030eba8,
		"TBossHanachan::emitCamShake_": 0x8030eed8,
		"emitCamShake_": 0x8030eed8,
		"TBossHanachan::emitOneTimeSandPillar_": 0x8030f16c,
		"emitOneTimeSandPillar_": 0x8030f16c,
		"TBossHanachan::emitParticle_": 0x8030f2a0,
		"TBossHanachan::staticLoadParticle": 0x8030f6b4,
		"staticLoadParticle": 0x8030f6b4,
		"Enemy::__sinit_BossHanachanEffect_cpp": 0x8030f9e8,
		"__sinit_BossHanachanEffect_cpp": 0x8030f9e8,
		"TEggGenManager::~TEggGenManager": 0x8030fce4,
		"TEggGenManager::load": 0x8030fd48,
		"TEggGenManager::createModelData": 0x8030fdb4,
		"TEggGenManager::TEggGenManager": 0x8030fde8,
		"TEggGenerator::control": 0x8030fe24,
		"TEggGenerator::init": 0x8030fe9c,
		"TEggGenerator::TEggGenerator": 0x8030ff8c,
		"TNerveSealDie::~TNerveSealDie": 0x8031005c,
		"TNerveSealDie::execute": 0x803100b8,
		"TNerveSealSleep::~TNerveSealSleep": 0x803102a4,
		"TNerveSealWait::execute": 0x80310300,
		"TNerveSealWait::~TNerveSealWait": 0x8031043c,
		"TNerveSealSleep::execute": 0x80310498,
		"TSealManager::load": 0x803105c4,
		"TSealManager::createModelData": 0x803105e4,
		"TSealManager::TSealManager": 0x80310618,
		"TSeal::perform": 0x80310654,
		"TSeal::calcRootMatrix": 0x80310778,
		"TSeal::receiveMessage": 0x8031081c,
		"TSeal::init": 0x80310a1c,
		"TSeal::TSeal": 0x80310cf4,
		"TSealManager::~TSealManager": 0x80310d4c,
		"Enemy::__sinit_seal_cpp": 0x80310e1c,
		"__sinit_seal_cpp": 0x80310e1c,
		"TBGPolDrop::perform": 0x8031118c,
		"TBGPolDrop::launch": 0x803113c0,
		"TBGPolDrop::move": 0x8031141c,
		"TBGPolDrop::TBGPolDrop": 0x8031166c,
		"Enemy::__sinit_bgpoldrop_cpp": 0x80311788,
		"__sinit_bgpoldrop_cpp": 0x80311788,
		"TBGTentacle::~TBGTentacle": 0x80311a8c,
		"TBGTentacle::perform": 0x80311b00,
		"TBGTentacle::resetAllNodes": 0x80311e80,
		"resetAllNodes": 0x80311e80,
		"TBGTentacle::calcAttackGuideAnm": 0x80311ff4,
		"calcAttackGuideAnm": 0x80311ff4,
		"TBGTentacle::decideAtkColExists": 0x80312474,
		"decideAtkColExists": 0x80312474,
		"TBGTentacle::calcAtkParticleAndSE": 0x80312634,
		"calcAtkParticleAndSE": 0x80312634,
		"TBGTentacle::decideOwnState": 0x80312ac4,
		"decideOwnState": 0x80312ac4,
		"TBGTentacle::moveConstraint": 0x80312df4,
		"moveConstraint": 0x80312df4,
		"TBGTentacle::moveNode": 0x80313280,
		"moveNode": 0x80313280,
		"TBGTentacle::changeStateAndFixNodes": 0x80313be0,
		"changeStateAndFixNodes": 0x80313be0,
		"TBGTentacle::setAttackTarget": 0x80313eac,
		"setAttackTarget": 0x80313eac,
		"TBGTentacle::beatNode": 0x80314318,
		"beatNode": 0x80314318,
		"TBGTentacle::TBGTentacle": 0x803144b4,
		"TBGTentacle::TNode::calcPosition": 0x80314a28,
		"calcPosition": 0x80314a28,
		"TBGTentacle::TNode::calcVelocity": 0x80314d70,
		"TBGTentacle::TNode::TNode": 0x80315158,
		"TBGAttackHit::perform": 0x8031518c,
		"TBGTakeHit::perform": 0x803155a4,
		"TBGTakeHit::receiveMessage": 0x80315cdc,
		"TBGTakeHit::moveRequest": 0x80315e24,
		"TBGTakeHit::getTakingMtx": 0x8031610c,
		"TBGTentacle::TTentacleParams::TTentacleParams": 0x803168d0,
		"Enemy::__sinit_bgtentacle_cpp": 0x80316e84,
		"__sinit_bgtentacle_cpp": 0x80316e84,
		"TEffectEnemy::setDeadAnm": 0x803172b4,
		"TEffectEnemy::sendAttackMsgToMario": 0x80317330,
		"TEffectEnemy::behaveToWater": 0x803173b4,
		"TEffectEnemy::reset": 0x803173f4,
		"TEffectEnemy::perform": 0x80317414,
		"TEffectEnemy::forceKill": 0x80317564,
		"TEffectEnemy::kill": 0x8031768c,
		"TEffectEnemy::setMActorAndKeeper": 0x803176dc,
		"TEffectEnemy::init": 0x80317748,
		"TEffectEnemy::TEffectEnemy": 0x80317780,
		"TEffectEnemyManager::initSetEnemies": 0x803177cc,
		"TEffectEnemyManager::createEnemyInstance": 0x803177d0,
		"TEffectEnemyManager::loadAfter": 0x80317834,
		"TEffectEnemyManager::load": 0x80317854,
		"TEffectEnemyManager::~TEffectEnemyManager": 0x803178ac,
		"Enemy::__sinit_effectEnemy_cpp": 0x80317920,
		"__sinit_effectEnemy_cpp": 0x80317920,
		"TNerveHauntLegHaunt::~TNerveHauntLegHaunt": 0x80317c24,
		"TNerveHauntLegHaunt::execute": 0x80317c80,
		"THauntLeg::getTakingMtx": 0x80317f74,
		"THauntLeg::getBasNameTable": 0x80318014,
		"THauntLeg::isCollidMove": 0x80318020,
		"THauntLeg::attackToMario": 0x80318174,
		"THauntLeg::setDeadAnm": 0x803181c4,
		"THauntLeg::setRunAnm": 0x8031822c,
		"THauntLeg::setWalkAnm": 0x8031825c,
		"THauntLeg::setWaitAnm": 0x8031828c,
		"THauntLeg::setGenerateAnm": 0x803182bc,
		"THauntLeg::calcRootMatrix": 0x803182ec,
		"THauntLeg::reset": 0x803186f4,
		"THauntLeg::setMActorAndKeeper": 0x80318728,
		"THauntLeg::init": 0x80318794,
		"THauntedObject::receiveMessage": 0x80318900,
		"THauntLegManager::createModelData": 0x80318954,
		"THauntLegManager::initSetEnemies": 0x80318988,
		"THauntLegManager::createEnemyInstance": 0x80318b4c,
		"THauntLegManager::load": 0x80318bc0,
		"THauntLegManager::THauntLegManager": 0x80318c18,
		"Enemy::HauntLegCallback": 0x80318c5c,
		"HauntLegCallback": 0x80318c5c,
		"THauntLegManager::~THauntLegManager": 0x80318eec,
		"Enemy::__sinit_hauntLeg_cpp": 0x80318f60,
		"__sinit_hauntLeg_cpp": 0x80318f60,
		"TAreaCylinderManager::~TAreaCylinderManager": 0x8031926c,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::erase": 0x80319378,
		"JGadget::TList<P13TAreaCylinder,Q27JGadget28TAllocator<P13TAreaCylinder>>::iterator::iterator": 0x803193e4,
		"TAreaCylinderManager::perform": 0x803193ec,
		"TAreaCylinderManager::getCylinderContains": 0x803193f0,
		"getCylinderContains": 0x803193f0,
		"TAreaCylinderManager::contain": 0x803194b8,
		"contain": 0x803194b8,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::insert": 0x80319584,
		"TAreaCylinder::perform": 0x8031963c,
		"TAreaCylinder::load": 0x80319640,
		"TAreaCylinder::TAreaCylinder": 0x8031989c,
		"TAreaCylinder::~TAreaCylinder": 0x80319918,
		"TNerveWireTrapGoWait::~TNerveWireTrapGoWait": 0x8031998c,
		"TNerveWireTrapGoWait::execute": 0x803199e8,
		"TNerveWireTrapWait::execute": 0x80319a40,
		"TNerveWireTrapWait::~TNerveWireTrapWait": 0x80319a64,
		"TNerveWireTrapSearch::execute": 0x80319ac0,
		"TNerveWireTrapSearch::~TNerveWireTrapSearch": 0x80319d48,
		"TNerveWireTrapOnewayMoveEnd::execute": 0x80319da4,
		"TNerveWireTrapOnewayMoveEnd::~TNerveWireTrapOnewayMoveEnd": 0x80319e90,
		"TNerveWireTrapOnewayMove::execute": 0x80319eec,
		"TNerveWireTrapOnewayMoveStart::~TNerveWireTrapOnewayMoveStart": 0x8031a27c,
		"TNerveWireTrapOnewayMove::~TNerveWireTrapOnewayMove": 0x8031a2d8,
		"TNerveWireTrapOnewayMoveStart::execute": 0x8031a334,
		"TNerveWireTrapReturnMove::execute": 0x8031a3f0,
		"TNerveWireTrapReturnMove::~TNerveWireTrapReturnMove": 0x8031a5d8,
		"TWireTrapManager::createModelData": 0x8031a634,
		"TWireTrapManager::load": 0x8031a668,
		"TWireTrapManager::TWireTrapManager": 0x8031a778,
		"TWireTrap::getWireBinder": 0x8031a7b4,
		"getWireBinder": 0x8031a7b4,
		"TWireTrap::getNerveFromMode": 0x8031a7bc,
		"getNerveFromMode": 0x8031a7bc,
		"TWireTrap::getWireDir": 0x8031a8e0,
		"getWireDir": 0x8031a8e0,
		"TWireTrap::checkHitActors": 0x8031a8ec,
		"TWireBinder::getDir": 0x8031ae8c,
		"getDir": 0x8031ae8c,
		"TWireTrap::moveObject": 0x8031ae94,
		"TWireTrap::calcRootMatrix": 0x8031af64,
		"TWireTrap::kill": 0x8031b540,
		"TWireTrap::receiveMessage": 0x8031b648,
		"TWireTrap::load": 0x8031b854,
		"TWireTrap::init": 0x8031ba84,
		"TWireTrap::TWireTrap": 0x8031bc2c,
		"TWireTrapManager::~TWireTrapManager": 0x8031bc7c,
		"Enemy::__sinit_wireTrap_cpp": 0x8031bd4c,
		"__sinit_wireTrap_cpp": 0x8031bd4c,
		"TBossHanachanPartsBase::getBasNameTable": 0x8031c050,
		"TNerveRocketWait::~TNerveRocketWait": 0x8031c064,
		"TNerveRocketWait::execute": 0x8031c0c0,
		"TNerveRocketFly::execute": 0x8031c110,
		"TNerveRocketFly::~TNerveRocketFly": 0x8031c3a8,
		"TNerveRocketPossessedNozzle::execute": 0x8031c404,
		"TNerveRocketPossessedNozzle::~TNerveRocketPossessedNozzle": 0x8031c6a0,
		"TRocket::getBasNameTable": 0x8031c6fc,
		"TRocket::isAttack": 0x8031c708,
		"TRocket::isCollidMove": 0x8031c794,
		"TRocket::getGravityY": 0x8031c85c,
		"TRocket::setDeadAnm": 0x8031c8f4,
		"TRocket::bind": 0x8031c9e0,
		"TRocket::behaveToWater": 0x8031cc28,
		"TRocket::attackToMario": 0x8031cc54,
		"TRocket::reset": 0x8031cd80,
		"TRocket::setMActorAndKeeper": 0x8031ce60,
		"TRocket::calcRootMatrix": 0x8031cecc,
		"TRocket::init": 0x8031d298,
		"TRocket::load": 0x8031d360,
		"TRocket::TRocket": 0x8031d3c0,
		"TRocketManager::perform": 0x8031d410,
		"TRocketManager::createModelData": 0x8031d4c4,
		"TRocketManager::initSetEnemies": 0x8031d4f8,
		"TRocketManager::createEnemyInstance": 0x8031d65c,
		"TRocketManager::loadAfter": 0x8031d6c4,
		"TRocketManager::load": 0x8031d6e4,
		"TRocketManager::TRocketManager": 0x8031d810,
		"TRocketManager::~TRocketManager": 0x8031d8e4,
		"TRocketManager::clipEnemies": 0x8031d958,
		"Enemy::__sinit_rocket_cpp": 0x8031d95c,
		"__sinit_rocket_cpp": 0x8031d95c,
		"TNerveKazekunHitWater::~TNerveKazekunHitWater": 0x8031dc60,
		"TNerveKazekunHitWater::execute": 0x8031dcbc,
		"TNerveKazekunDisappear::~TNerveKazekunDisappear": 0x8031de20,
		"TNerveKazekunHitWater::theNerve": 0x8031de7c,
		"TNerveKazekunWait::execute": 0x8031dee0,
		"TNerveKazekunSearch::~TNerveKazekunSearch": 0x8031dfcc,
		"TNerveKazekunWait::~TNerveKazekunWait": 0x8031e028,
		"TNerveKazekunDisappear::execute": 0x8031e084,
		"TNerveKazekunAttack::execute": 0x8031e1c0,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::getQuat": 0x8031e754,
		"TNerveKazekunAttack::theNerve": 0x8031ea14,
		"TNerveKazekunAttack::~TNerveKazekunAttack": 0x8031ea78,
		"TNerveKazekunPreAttack::execute": 0x8031ead4,
		"TNerveKazekunPreAttack::theNerve": 0x8031ed0c,
		"TNerveKazekunPreAttack::~TNerveKazekunPreAttack": 0x8031ed70,
		"TNerveKazekunTurn::execute": 0x8031edcc,
		"TNerveKazekunTurn::~TNerveKazekunTurn": 0x8031f004,
		"TNerveKazekunAppear::execute": 0x8031f060,
		"TNerveKazekunAppear::~TNerveKazekunAppear": 0x8031f178,
		"TNerveKazekunSearch::execute": 0x8031f1d4,
		"TKazekunManager::createModelData": 0x8031f2e0,
		"TKazekunManager::load": 0x8031f314,
		"TKazekunManager::TKazekunManager": 0x8031f3a8,
		"TKazekunParams::TKazekunParams": 0x8031f3e4,
		"TKazekun::doAttackPose": 0x8031f6e4,
		"doAttackPose": 0x8031f6e4,
		"TKazekun::flyAroundMario": 0x8031fc08,
		"flyAroundMario": 0x8031fc08,
		"TKazekun::setDeadAnm": 0x8031ff9c,
		"TKazekun::isCollidMove": 0x8031ffec,
		"TKazekun::attackToMario": 0x8031fff4,
		"TKazekun::getBasNameTable": 0x803200dc,
		"TKazekun::behaveToWater": 0x803200e8,
		"TKazekun::bind": 0x8032023c,
		"TKazekun::calcRootMatrix": 0x80320270,
		"TKazekun::reset": 0x803204b4,
		"TKazekun::init": 0x8032052c,
		"TKazekun::TKazekun": 0x80320730,
		"Enemy::SMS_CalcToDirMatrix": 0x80320788,
		"SMS_CalcToDirMatrix": 0x80320788,
		"TKazekunManager::~TKazekunManager": 0x803209c4,
		"Enemy::__sinit_Kazekun_cpp": 0x80320abc,
		"__sinit_Kazekun_cpp": 0x80320abc,
		"TBossMantaManager::~TBossMantaManager": 0x80320dc0,
		"TBossMantaParams::TBossMantaParams": 0x80320e24,
		"TBossMantaManager::spawn": 0x8032116c,
		"spawn": 0x8032116c,
		"TBossMantaManager::createEnemies": 0x80321368,
		"TBossMantaManager::setupEfbAlpha": 0x803214bc,
		"setupEfbAlpha": 0x803214bc,
		"TBossMantaManager::perform": 0x80321770,
		"TBossMantaManager::updateMantaEscape": 0x80321804,
		"updateMantaEscape": 0x80321804,
		"TBossMantaManager::drawMantaShadow": 0x8032195c,
		"drawMantaShadow": 0x8032195c,
		"TBossMantaManager::createEnemyInstance": 0x8032200c,
		"TBossMantaManager::createModelData": 0x80322054,
		"TBossMantaManager::loadAfter": 0x80322088,
		"TBossMantaManager::load": 0x80322234,
		"TBossMantaManager::TBossMantaManager": 0x803222a0,
		"TBossMantaAdditionalCollision::perform": 0x80322374,
		"TBossMantaAdditionalCollision::receiveMessage": 0x80322514,
		"TBossMantaAdditionalCollisionSet::update": 0x80322554,
		"TBossMantaAdditionalCollisionSet::adapt": 0x80322734,
		"adapt": 0x80322734,
		"TBossMantaAdditionalCollisionSet::TBossMantaAdditionalCollisionSet": 0x80322808,
		"TBossMantaManager::TMantaMessageState::update": 0x8032294c,
		"TNerveMantaSpawn::~TNerveMantaSpawn": 0x80322b0c,
		"TBossMantaManager::TMantaBattleState::update": 0x80322b68,
		"TBossManta::updateAttractor": 0x80322e7c,
		"updateAttractor": 0x80322e7c,
		"TBossManta::getPolluteRadius": 0x8032354c,
		"getPolluteRadius": 0x8032354c,
		"TNerveMantaMove::~TNerveMantaMove": 0x803235c8,
		"TBossManta::calcRootMatrix": 0x80323624,
		"TBossManta::control": 0x80323744,
		"TBossManta::initNthGeneration": 0x803239a0,
		"initNthGeneration": 0x803239a0,
		"TNerveMantaAppearDemo::~TNerveMantaAppearDemo": 0x80324148,
		"TBossManta::receiveMessage": 0x803241a4,
		"TBossManta::collidedWithWater": 0x803241f4,
		"collidedWithWater": 0x803241f4,
		"TNerveMantaDeath::~TNerveMantaDeath": 0x80324680,
		"TNerveMantaHitWater::~TNerveMantaHitWater": 0x803246dc,
		"TBossManta::moveObject": 0x80324738,
		"TBossManta::init": 0x80324918,
		"TBossManta::getIntoGraphVec": 0x80324bac,
		"getIntoGraphVec": 0x80324bac,
		"TBossManta::TBossManta": 0x80324e3c,
		"TNerveMantaAppearDemo::execute": 0x80324ed8,
		"TNerveMantaDeath::execute": 0x80325084,
		"TNerveMantaSpawn::execute": 0x80325170,
		"TNerveMantaHitWater::execute": 0x8032530c,
		"TNerveMantaMove::execute": 0x803254fc,
		"TNerveMantaHitWater::theNerve": 0x80325eb0,
		"TBossManta::drawObject": 0x80326004,
		"TBossManta::reset": 0x80326008,
		"Enemy::__sinit_bossManta_cpp": 0x8032600c,
		"__sinit_bossManta_cpp": 0x8032600c,
		"TWireBinder::~TWireBinder": 0x80326318,
		"TWireBinder::isEndWire": 0x8032637c,
		"isEndWire": 0x8032637c,
		"TWireBinder::isOnWire": 0x803263e4,
		"isOnWire": 0x803263e4,
		"TWireBinder::getDirAtPos": 0x803264b8,
		"getDirAtPos": 0x803264b8,
		"TWireBinder::bind": 0x803265f4,
		"TMapWireManager::getWire": 0x803268ac,
		"getWire": 0x803268ac,
		"TWireBinder::init": 0x803268bc,
		"TNerveYumboFreeze::~TNerveYumboFreeze": 0x803269c8,
		"TNerveYumboFreeze::execute": 0x80326a24,
		"TNerveYumboDancing::~TNerveYumboDancing": 0x80326b54,
		"TNerveYumboAttack::execute": 0x80326bb0,
		"TNerveYumboAppearing::~TNerveYumboAppearing": 0x80326de0,
		"TNerveYumboAttack::theNerve": 0x80326e3c,
		"TNerveYumboAttack::~TNerveYumboAttack": 0x80326ea0,
		"TNerveYumboAppearing::execute": 0x80326efc,
		"TNerveYumboHiding::execute": 0x8032712c,
		"TNerveYumboHiding::theNerve": 0x803272d8,
		"TNerveYumboHiding::~TNerveYumboHiding": 0x8032733c,
		"TNerveYumboDancing::execute": 0x80327398,
		"TYumbo::getBasNameTable": 0x80327648,
		"TYumboManager::createModelData": 0x80327654,
		"TYumboManager::load": 0x80327688,
		"TYumboManager::TYumboManager": 0x80327854,
		"TYumbo::attackToMario": 0x80327898,
		"TYumbo::doKeepDistance": 0x80327944,
		"TYumbo::setDeadAnm": 0x803279d4,
		"TYumbo::shotSeeds": 0x80327a04,
		"shotSeeds": 0x80327a04,
		"TYumbo::behaveToWater": 0x80327efc,
		"TYumbo::perform": 0x80328054,
		"TYumbo::moveObject": 0x803280d4,
		"TYumbo::receiveMessage": 0x803282b4,
		"TYumbo::reset": 0x803283bc,
		"TYumbo::init": 0x803283c0,
		"TYumbo::TYumbo": 0x803285fc,
		"TYumboSeed::perform": 0x8032864c,
		"TYumboSeed::init": 0x80328850,
		"TYumboManager::~TYumboManager": 0x803289a8,
		"Enemy::__sinit_yunbo_cpp": 0x80328aa0,
		"__sinit_yunbo_cpp": 0x80328aa0,
		"TKoopaJrSubmarineManager::~TKoopaJrSubmarineManager": 0x80328dac,
		"TKoopaJrSubmarineManager::createEnemyInstance": 0x80328e10,
		"TKoopaJrSubmarineManager::loadAfter": 0x80328e58,
		"TKoopaJrSubmarineManager::load": 0x80328e8c,
		"TKoopaJrSubmarineManager::createModelData": 0x80328ef8,
		"TKoopaJrSubmarineManager::TKoopaJrSubmarineManager": 0x80328f2c,
		"TNerveKoopaJrSubmarineLaunchKiller::execute": 0x80328f68,
		"TNerveKoopaJrSubmarineLaunchKiller::~TNerveKoopaJrSubmarineLaunchKiller": 0x80328fcc,
		"TNerveKoopaJrSubmarineCannonOpenClose::execute": 0x80329028,
		"TNerveKoopaJrSubmarineCannonOpenClose::~TNerveKoopaJrSubmarineCannonOpenClose": 0x803290cc,
		"TNerveKoopaJrSubmarineWait::execute": 0x80329128,
		"TNerveKoopaJrSubmarineWait::~TNerveKoopaJrSubmarineWait": 0x803291b0,
		"TKoopaJrSubmarine::checkNerve": 0x8032920c,
		"checkNerve": 0x8032920c,
		"TNerveKoopaJrWait::~TNerveKoopaJrWait": 0x80329584,
		"JGeometry::TUtil<float><float>::mod": 0x803295e0,
		"TKoopaJrSubmarine::makeRoundVelocity": 0x8032963c,
		"makeRoundVelocity": 0x8032963c,
		"TKoopaJrSubmarine::makeRelativeAngle": 0x80329918,
		"makeRelativeAngle": 0x80329918,
		"TKoopaJrSubmarine::getBasNameTable": 0x80329b10,
		"TKoopaJrSubmarine::makeKillerVelocity": 0x80329b18,
		"makeKillerVelocity": 0x80329b18,
		"TKoopaJrSubmarine::launchKiller": 0x8032a224,
		"TKoopaJrSubmarine::appearShineKiller": 0x8032a35c,
		"appearShineKiller": 0x8032a35c,
		"TKoopaJrSubmarine::receiveMessage": 0x8032a4a0,
		"TKoopaJrSubmarine::calcRootMatrix": 0x8032a520,
		"TKoopaJrSubmarine::bind": 0x8032a960,
		"TKoopaJrSubmarine::moveSwing": 0x8032aa54,
		"moveSwing": 0x8032aa54,
		"TKoopaJrSubmarine::makeCollisionPositions": 0x8032ad2c,
		"makeCollisionPositions": 0x8032ad2c,
		"TKoopaJrSubmarine::perform": 0x8032ae08,
		"TKoopaJrSubmarine::resetKoopaJrSubmarine": 0x8032afa8,
		"resetKoopaJrSubmarine": 0x8032afa8,
		"TKoopaJrSubmarine::reset": 0x8032b0cc,
		"TKoopaJrSubmarine::init": 0x8032b100,
		"TKoopaJrSubmarine::TKoopaJrSubmarine": 0x8032b548,
		"TKoopaJrManager::createEnemyInstance": 0x8032b5bc,
		"TKoopaJrManager::loadAfter": 0x8032b5c4,
		"TKoopaJrManager::load": 0x8032b620,
		"TKoopaJrManager::createModelData": 0x8032b678,
		"TKoopaJrManager::TKoopaJrManager": 0x8032b6ac,
		"TNerveKoopaJrYahoo::execute": 0x8032b6e8,
		"TNerveKoopaJrYahoo::~TNerveKoopaJrYahoo": 0x8032b778,
		"TNerveKoopaJrLaunch::execute": 0x8032b7d4,
		"TNerveKoopaJrLaunch::~TNerveKoopaJrLaunch": 0x8032b864,
		"TNerveKoopaJrDemo::execute": 0x8032b8c0,
		"TNerveKoopaJrDemo::~TNerveKoopaJrDemo": 0x8032b934,
		"TNerveKoopaJrDamage::execute": 0x8032b990,
		"TNerveKoopaJrDamage::theNerve": 0x8032ba2c,
		"TNerveKoopaJrDamage::~TNerveKoopaJrDamage": 0x8032ba90,
		"TNerveKoopaJrWait::execute": 0x8032baec,
		"TKoopaJr::checkNerveKillerHit": 0x8032bb98,
		"checkNerveKillerHit": 0x8032bb98,
		"TKoopaJr::checkNerveKillerLaunchFast": 0x8032bcc4,
		"checkNerveKillerLaunchFast": 0x8032bcc4,
		"TKoopaJr::checkNerveKillerLaunchNormal": 0x8032bea8,
		"checkNerveKillerLaunchNormal": 0x8032bea8,
		"TSpineBase<TLiveActor>::pushNerve": 0x8032c08c,
		"pushNerve": 0x8032c08c,
		"TKoopaJr::receiveMessage": 0x8032c0e0,
		"TKoopaJr::getBasNameTable": 0x8032c2e0,
		"TKoopaJr::calcRootMatrix": 0x8032c2ec,
		"TKoopaJr::perform": 0x8032c3e8,
		"TKoopaJr::reset": 0x8032c8b8,
		"TKoopaJr::init": 0x8032c924,
		"TKoopaJr::TKoopaJr": 0x8032cb6c,
		"TCallbackHitActor::receiveMessage": 0x8032cbe0,
		"TKoopaJrSubmarineParams::TKoopaJrSubmarineParams": 0x8032cc10,
		"TKoopaJrParams::TKoopaJrParams": 0x8032d17c,
		"TDirectionCalc::r2d": 0x8032d37c,
		"r2d": 0x8032d37c,
		"TDirectionCalc::d2r": 0x8032d390,
		"d2r": 0x8032d390,
		"TDirectionCalc::absDirection": 0x8032d3a4,
		"absDirection": 0x8032d3a4,
		"TDirectionCalc::calcDirectionVector": 0x8032d448,
		"calcDirectionVector": 0x8032d448,
		"TDirectionCalc::makeDirection": 0x8032d4ac,
		"makeDirection": 0x8032d4ac,
		"TDirectionCalc::calcTurnDirection": 0x8032d4e4,
		"calcTurnDirection": 0x8032d4e4,
		"TDirectionCalc::sub": 0x8032d5e8,
		"TDirectionCalc::calcNearerDirection": 0x8032d688,
		"calcNearerDirection": 0x8032d688,
		"TKoopaJrManager::~TKoopaJrManager": 0x8032d7fc,
		"Enemy::__sinit_koopajr_cpp": 0x8032d950,
		"__sinit_koopajr_cpp": 0x8032d950,
		"TNerveKumokunPreFly::~TNerveKumokunPreFly": 0x8032dc64,
		"TNerveKumokunPreFly::execute": 0x8032dcc0,
		"TNerveKumokunFly::~TNerveKumokunFly": 0x8032ddfc,
		"TNerveKumokunFly::execute": 0x8032de58,
		"TBGCheckData::getNormal": 0x8032e294,
		"getNormal": 0x8032e294,
		"TNerveKumokunPostFreeze::execute": 0x8032e29c,
		"TNerveKumokunSearch::~TNerveKumokunSearch": 0x8032e45c,
		"TNerveKumokunPostFreeze::~TNerveKumokunPostFreeze": 0x8032e4b8,
		"TNerveKumokunFreeze::execute": 0x8032e514,
		"TNerveKumokunFreeze::~TNerveKumokunFreeze": 0x8032e784,
		"TNerveKumokunWait::execute": 0x8032e7e0,
		"JGeometry::TQuat4<float><float>::rotate": 0x8032ebe4,
		"rotate": 0x8032ebe4,
		"JGeometry::TVec3<float><float>::negate": 0x8032ec7c,
		"negate": 0x8032ec7c,
		"JGeometry::TVec4<float><float>::xyz": 0x8032eca4,
		"xyz": 0x8032eca4,
		"TKumokun::getQuat": 0x8032eccc,
		"TNerveKumokunWait::theNerve": 0x8032ecd4,
		"TNerveKumokunWait::~TNerveKumokunWait": 0x8032ed38,
		"TNerveKumokunSearch::execute": 0x8032ed94,
		"TNerveKumokunPreWalk::~TNerveKumokunPreWalk": 0x8032f36c,
		"TNerveKumokunSearch::theNerve": 0x8032f3dc,
		"TNerveKumokunPostWalk::execute": 0x8032f440,
		"TNerveKumokunPostWalk::theNerve": 0x8032f600,
		"TNerveKumokunPostWalk::~TNerveKumokunPostWalk": 0x8032f664,
		"TNerveKumokunWalk::execute": 0x8032f6c0,
		"TNerveKumokunWalk::~TNerveKumokunWalk": 0x8032f8c4,
		"TNerveKumokunPreWalk::execute": 0x8032f920,
		"TNerveKumokunPreWalk::theNerve": 0x8032fafc,
		"TKumokunManager::createModelData": 0x8032fb60,
		"TKumokunManager::load": 0x8032fb94,
		"TKumokunManager::TKumokunManager": 0x8032fd7c,
		"TKumokun::getPlaneNormal": 0x8032fdb8,
		"getPlaneNormal": 0x8032fdb8,
		"TKumokun::isCollidMove": 0x8032fdf4,
		"TKumokun::doKeepDistance": 0x8032fdfc,
		"TKumokun::isAttack": 0x8033019c,
		"TKumokun::isOnSamePlaneWithMario": 0x8033032c,
		"isOnSamePlaneWithMario": 0x8033032c,
		"TKumokun::rotateGoalDirToLocal": 0x803306b0,
		"rotateGoalDirToLocal": 0x803306b0,
		"TKumokun::decideTargetAtDir": 0x803307f4,
		"decideTargetAtDir": 0x803307f4,
		"TKumokun::attackToMario": 0x80330b1c,
		"TKumokun::calcRootMatrix": 0x80330cdc,
		"TKumokun::setDeadAnm": 0x80331074,
		"TKumokun::changeBck": 0x803312b4,
		"TKumokun::behaveToWater": 0x803313bc,
		"TKumokun::receiveMessage": 0x80331468,
		"TKumokun::control": 0x803318ec,
		"TKumokun::moveObject": 0x80331934,
		"TKumokun::bindOnFlying": 0x80331a18,
		"bindOnFlying": 0x80331a18,
		"TKumokun::checkOnMovingRoof": 0x80331cd4,
		"checkOnMovingRoof": 0x80331cd4,
		"TKumokun::checkOnMovingFloor": 0x8033206c,
		"checkOnMovingFloor": 0x8033206c,
		"TKumokun::checkOnMovingWall": 0x80332300,
		"checkOnMovingWall": 0x80332300,
		"TKumokun::bind": 0x80332674,
		"TKumokun::reset": 0x80332d68,
		"TKumokun::initAttachPlane": 0x80332d6c,
		"initAttachPlane": 0x80332d6c,
		"TKumokun::init": 0x80333184,
		"TKumokun::getBasNameTable": 0x80333364,
		"TKumokun::TKumokun": 0x803333dc,
		"TSolidStack<char_const*>::~TSolidStack": 0x8033346c,
		"TWallAtGraph::init": 0x803334b8,
		"JGeometry::TPartition3<float><float>::TPartition3": 0x803337d8,
		"TPartition3": 0x803337d8,
		"TKumokunManager::~TKumokunManager": 0x803337dc,
		"TKoopaManager::~TKoopaManager": 0x803338f4,
		"TKoopaManager::loadAfter": 0x80333958,
		"TKoopaManager::load": 0x80333ab0,
		"TKoopaManager::createModelData": 0x803340ac,
		"TKoopaManager::createEnemyInstance": 0x803340e0,
		"TKoopaManager::TKoopaManager": 0x803340e8,
		"TKoopa::calcRootMatrix": 0x80334124,
		"TKoopa::receiveMessage": 0x80334430,
		"TKoopa::perform": 0x80334450,
		"TNerveKoopaTumble::~TNerveKoopaTumble": 0x80334914,
		"TNerveKoopaTurn::~TNerveKoopaTurn": 0x80334980,
		"TKoopa::reset": 0x803349dc,
		"TKoopa::getBasNameTable": 0x80334ac0,
		"TKoopa::init": 0x80334acc,
		"TNerveKoopaProvoke::~TNerveKoopaProvoke": 0x80334f08,
		"TKoopa::loadAfter": 0x80334f64,
		"TKoopa::load": 0x80335184,
		"TKoopa::TKoopa": 0x803351a4,
		"TKoopa::updateAnmSound": 0x8033520c,
		"TKoopa::fall": 0x803352d4,
		"fall": 0x803352d4,
		"TNerveKoopaFall::~TNerveKoopaFall": 0x8033536c,
		"TKoopa::getTargetDir": 0x803353c8,
		"getTargetDir": 0x803353c8,
		"TKoopa::stagger": 0x803354c4,
		"stagger": 0x803354c4,
		"TNerveKoopaStagger::~TNerveKoopaStagger": 0x803357b8,
		"TNerveKoopaGetShowered::~TNerveKoopaGetShowered": 0x80335814,
		"TNerveKoopaGetDown::~TNerveKoopaGetDown": 0x80335870,
		"TNerveKoopaFlame::~TNerveKoopaFlame": 0x803358cc,
		"TKoopa::getShowered": 0x80335938,
		"getShowered": 0x80335938,
		"TNerveKoopaWait::~TNerveKoopaWait": 0x80335d78,
		"TKoopa::effectsTumble": 0x80335de4,
		"effectsTumble": 0x80335de4,
		"TKoopa::getDown": 0x80335e90,
		"getDown": 0x80335e90,
		"TKoopa::allowsLaunch": 0x803361d8,
		"allowsLaunch": 0x803361d8,
		"TKoopa::getNeckFocus": 0x80336270,
		"getNeckFocus": 0x80336270,
		"TKoopa::isFlaming": 0x8033655c,
		"isFlaming": 0x8033655c,
		"TKoopa::getFlameDirRate": 0x803365a4,
		"getFlameDirRate": 0x803365a4,
		"TKoopa::changeAnm": 0x80336704,
		"changeAnm": 0x80336704,
		"TKoopa::setUpHitActors": 0x803367e4,
		"TKoopa::getFlameDirDegree": 0x80337650,
		"getFlameDirDegree": 0x80337650,
		"TKoopaBody::attack_": 0x803376ac,
		"TKoopaBody::receiveMessage": 0x80337724,
		"TKoopaHead::attack_": 0x803379d8,
		"TKoopaHead::receiveMessage": 0x80337a50,
		"TKoopaHand::attack_": 0x80337d68,
		"TKoopaHand::receiveMessage": 0x80337da4,
		"TKoopaFlame::attack_": 0x80337dac,
		"TKoopaFlame::receiveMessage": 0x80337e70,
		"TKoopaFlame::control": 0x80337e8c,
		"TKoopaParts::perform": 0x80337f7c,
		"TKoopaParts::control": 0x80338014,
		"TKoopaParts::TKoopaParts": 0x80338018,
		"TNerveKoopaGetDown::execute": 0x80338170,
		"TNerveKoopaGetShowered::execute": 0x80338514,
		"TNerveKoopaStagger::execute": 0x80338610,
		"TNerveKoopaProvoke::execute": 0x8033870c,
		"TNerveKoopaFlame::execute": 0x80338874,
		"TNerveKoopaTurnR::~TNerveKoopaTurnR": 0x80339328,
		"TNerveKoopaTurnL::~TNerveKoopaTurnL": 0x80339394,
		"TEnemyManager::getSaveParam": 0x80339400,
		"TNerveKoopaFall::execute": 0x80339418,
		"TNerveKoopaTumble::execute": 0x803394ec,
		"TNerveKoopaWait::execute": 0x803396bc,
		"TNerveKoopaTurnR::execute": 0x80339f98,
		"TNerveKoopaTurnL::execute": 0x8033a128,
		"Enemy::__sinit_Koopa_cpp": 0x8033a59c,
		"__sinit_Koopa_cpp": 0x8033a59c,
		"TNerveKukkuRecoverGraph::~TNerveKukkuRecoverGraph": 0x8033a8c8,
		"TNerveKukkuRecoverGraph::execute": 0x8033a924,
		"TNerveKukkuGraphWander::~TNerveKukkuGraphWander": 0x8033aa90,
		"TNerveKukkuPostFall::execute": 0x8033aaec,
		"TNerveKukkuPostFall::theNerve": 0x8033ac28,
		"TNerveKukkuPostFall::~TNerveKukkuPostFall": 0x8033ac8c,
		"TNerveKukkuFall::execute": 0x8033ace8,
		"TNerveKukkuFall::theNerve": 0x8033af80,
		"TNerveKukkuFall::~TNerveKukkuFall": 0x8033afe4,
		"TNerveKukkuGraphWander::execute": 0x8033b040,
		"TKukku::getBasNameTable": 0x8033b428,
		"TKukkuManager::createModelData": 0x8033b434,
		"TKukkuManager::load": 0x8033b468,
		"TKukkuManager::TKukkuManager": 0x8033b708,
		"TKukku::setAfterDeadEffect": 0x8033b744,
		"TKukku::setDeadAnm": 0x8033b790,
		"TKukku::dropCoins": 0x8033b7d0,
		"dropCoins": 0x8033b7d0,
		"TKukku::calcMomentum": 0x8033bc10,
		"calcMomentum": 0x8033bc10,
		"TKukku::updateRotation": 0x8033bd2c,
		"updateRotation": 0x8033bd2c,
		"TKukku::behaveToWater": 0x8033bf74,
		"TKukku::perform": 0x8033c124,
		"TKukku::bind": 0x8033c1a4,
		"TKukku::calcRootMatrix": 0x8033c1c4,
		"TKukku::control": 0x8033c59c,
		"TKukku::receiveMessage": 0x8033c5d4,
		"TKukku::reset": 0x8033c664,
		"TKukku::init": 0x8033c694,
		"TKukku::TKukku": 0x8033c910,
		"TKukkuBall::perform": 0x8033c95c,
		"TKukkuBall::init": 0x8033cc00,
		"TKukkuManager::~TKukkuManager": 0x8033cda4,
		"Enemy::__sinit_Kukku_cpp": 0x8033ce9c,
		"__sinit_Kukku_cpp": 0x8033ce9c,
		"TNerveAmenboHitWater::~TNerveAmenboHitWater": 0x8033d1a8,
		"TNerveAmenboHitWater::execute": 0x8033d204,
		"TNerveAmenboSearch::~TNerveAmenboSearch": 0x8033d49c,
		"TNerveAmenboWalk::execute": 0x8033d4f8,
		"TNerveAmenboWalk::~TNerveAmenboWalk": 0x8033d850,
		"TNerveAmenboPreAttack::execute": 0x8033d8ac,
		"TNerveAmenboPreAttack::~TNerveAmenboPreAttack": 0x8033da2c,
		"TNerveAmenboTurn::execute": 0x8033da88,
		"TNerveAmenboTurn::~TNerveAmenboTurn": 0x8033dd48,
		"TNerveAmenboSearch::execute": 0x8033dda4,
		"JGeometry::TVec4<float><float>::operator_=": 0x8033e338,
		"TAmenbo::getQuat": 0x8033e35c,
		"TAmenbo::getBasNameTable": 0x8033e374,
		"TAmenboManager::createModelData": 0x8033e380,
		"TAmenboManager::load": 0x8033e3b4,
		"TAmenboManager::TAmenboManager": 0x8033e628,
		"TAmenbo::deactivateJumpBase": 0x8033e664,
		"deactivateJumpBase": 0x8033e664,
		"TAmenbo::isFindOutMario": 0x8033e704,
		"isFindOutMario": 0x8033e704,
		"TAmenbo::changeByJuice": 0x8033e888,
		"TAmenbo::setDeadAnm": 0x8033e8d8,
		"TAmenbo::attackToMario": 0x8033e928,
		"TAmenbo::doKeepDistance": 0x8033ea0c,
		"TAmenbo::isCollidMove": 0x8033eae0,
		"TAmenbo::forceKill": 0x8033eaf0,
		"TAmenbo::calcRootMatrix": 0x8033eb70,
		"TAmenbo::behaveToWater": 0x8033ecd0,
		"TAmenbo::receiveMessage": 0x8033ed9c,
		"TMapCollisionBase::isSetUp": 0x8033edec,
		"isSetUp": 0x8033edec,
		"TAmenbo::perform": 0x8033ee1c,
		"TAmenbo::control": 0x8033eea8,
		"TAmenbo::bind": 0x8033f29c,
		"TAmenbo::kill": 0x8033f574,
		"TAmenbo::reset": 0x8033f5a4,
		"TAmenbo::init": 0x8033f5a8,
		"TAmenbo::TAmenbo": 0x8033f808,
		"TAmenbo::EffectOnJoint::EffectOnJoint": 0x8033f87c,
		"TAmenboManager::~TAmenboManager": 0x8033f904,
		"TBathtubPeachManager::~TBathtubPeachManager": 0x8033f980,
		"TBathtubPeachManager::load": 0x8033f9e4,
		"TBathtubPeachManager::createModelData": 0x8033fb5c,
		"TBathtubPeachManager::createEnemyInstance": 0x8033fb90,
		"TBathtubPeachManager::TBathtubPeachManager": 0x8033fb98,
		"TBathtubPeach::calcRootMatrix": 0x8033fbd4,
		"TBathtubPeach::receiveMessage": 0x8033fc80,
		"TBathtubPeach::getRootJointMtx": 0x8033fca0,
		"TBathtubPeach::perform": 0x8033fcc4,
		"TBathtubPeach::reset": 0x8033fce4,
		"TBathtubPeach::init": 0x8033fe18,
		"TNervePeachEscape::~TNervePeachEscape": 0x8033fed4,
		"TBathtubPeach::getBasNameTable": 0x8033ff30,
		"TBathtubPeach::TBathtubPeach": 0x8033ff3c,
		"TNervePeachEscape::execute": 0x8033ffb4,
		"JGeometry::TVec2<float><float>::dot": 0x803404e0,
		"TNervePeachStagger::~TNervePeachStagger": 0x803404fc,
		"TNervePeachStagger::execute": 0x80340558,
		"Enemy::__sinit_BathtubPeach_cpp": 0x803406c0,
		"__sinit_BathtubPeach_cpp": 0x803406c0,
		"TBathtubKillerManager::~TBathtubKillerManager": 0x803409c4,
		"TBathtubKillerManager::createEnemyInstance": 0x80340a38,
		"TBathtubKillerManager::createModelData": 0x80340aac,
		"TBathtubKillerManager::countActiveKillers": 0x80340ae0,
		"countActiveKillers": 0x80340ae0,
		"TBathtubKillerManager::loadAfter": 0x80340b4c,
		"TBathtubKillerManager::load": 0x80340c68,
		"TBathtubKillerManager::TBathtubKillerManager": 0x80340cd4,
		"TNerveBathtubKillerExplosion::execute": 0x80340d10,
		"TNerveBathtubKillerExplosion::theNerve": 0x80340eac,
		"TNerveBathtubKillerExplosion::~TNerveBathtubKillerExplosion": 0x80340f10,
		"TNerveBathtubKillerBreak::execute": 0x80340f6c,
		"TNerveBathtubKillerBreak::theNerve": 0x80341088,
		"TNerveBathtubKillerBreak::~TNerveBathtubKillerBreak": 0x803410ec,
		"TNerveBathtubKillerStraight::execute": 0x80341148,
		"TNerveBathtubKillerStraight::~TNerveBathtubKillerStraight": 0x803412d8,
		"TNerveBathtubKillerChaseStraight::execute": 0x80341334,
		"TNerveBathtubKillerChase::~TNerveBathtubKillerChase": 0x80341774,
		"TNerveBathtubKillerChaseStraight::~TNerveBathtubKillerChaseStraight": 0x803417d0,
		"TNerveBathtubKillerChase::execute": 0x8034182c,
		"TNerveBathtubKillerWander::execute": 0x80341bbc,
		"TNerveBathtubKillerWander::~TNerveBathtubKillerWander": 0x80341f74,
		"TBathtubKiller::isAboided": 0x80341fd0,
		"isAboided": 0x80341fd0,
		"TBathtubKiller::getBasNameTable": 0x80342314,
		"TBathtubKiller::behaveToWater": 0x80342320,
		"TBathtubKiller::isCollidMove": 0x80342438,
		"TBathtubKiller::attackToMario": 0x80342864,
		"TBathtubKiller::receiveMessage": 0x803429f8,
		"TBathtubKiller::calcRootMatrix": 0x80342c64,
		"TBathtubKiller::getGravityY": 0x80342cf4,
		"TBathtubKiller::makeQuat": 0x80342d24,
		"makeQuat": 0x80342d24,
		"TBathtubKiller::moveChasing": 0x80343320,
		"moveChasing": 0x80343320,
		"TBathtubKiller::makeInitialVelocity": 0x8034357c,
		"makeInitialVelocity": 0x8034357c,
		"TBathtubKiller::perform": 0x80343920,
		"TBathtubKiller::bind": 0x80343dac,
		"TBathtubKiller::generateItemBathtubKiller": 0x80344198,
		"generateItemBathtubKiller": 0x80344198,
		"TBathtubKiller::resetBathtubKiller": 0x80344424,
		"resetBathtubKiller": 0x80344424,
		"TBathtubKiller::reset": 0x8034478c,
		"TBathtubKiller::setMActorAndKeeper": 0x803447fc,
		"TBathtubKiller::init": 0x8034496c,
		"TBathtubKiller::TBathtubKiller": 0x803449ec,
		"TBathtubKillerParams::TBathtubKillerParams": 0x80344a38,
		"Enemy::__sinit_BathtubKiller_cpp": 0x803451e4,
		"__sinit_BathtubKiller_cpp": 0x803451e4,
		"TCoasterKillerManager::~TCoasterKillerManager": 0x803454e8,
		"TCoasterKillerManager::createEnemyInstance": 0x8034555c,
		"TCoasterKillerManager::createModelData": 0x80345690,
		"TCoasterKillerManager::loadAfter": 0x803456c4,
		"TCoasterKillerManager::load": 0x803456f8,
		"TCoasterKillerManager::TCoasterKillerManager": 0x8034581c,
		"TNerveCoasterKillerExplosion::execute": 0x80345860,
		"TNerveCoasterKillerExplosion::~TNerveCoasterKillerExplosion": 0x803459e0,
		"TCoasterKiller::setDeadAnm": 0x80345a3c,
		"TCoasterKiller::setNormalFlyAnm": 0x80345af0,
		"TCoasterKiller::getBasNameTable": 0x80345b44,
		"TCoasterKiller::behaveToWater": 0x80345b50,
		"TCoasterKiller::isCollidMove": 0x80345c68,
		"TCoasterKiller::attackToMario": 0x80345e94,
		"TCoasterKiller::setMActorAndKeeper": 0x80345fc8,
		"TCoasterKiller::perform": 0x8034611c,
		"TCoasterKiller::reset": 0x80346284,
		"TCoasterKiller::init": 0x803462d4,
		"TNerveCoasterEnemyWander::~TNerveCoasterEnemyWander": 0x80346414,
		"TCoasterKiller::TCoasterKiller": 0x80346470,
		"TNerveCoasterEnemyWander::execute": 0x803464d0,
		"TCoasterEnemy::setWalkAnm": 0x80346608,
		"TCoasterEnemy::setNormalFlyAnm": 0x80346634,
		"TCoasterEnemy::calcRootMatrix": 0x80346638,
		"TCoasterEnemy::moveCoaster": 0x803466c8,
		"moveCoaster": 0x803466c8,
		"TCoasterEnemy::makeCoasterGoalPath": 0x80346d78,
		"makeCoasterGoalPath": 0x80346d78,
		"TCoasterEnemy::getGravityY": 0x80346db4,
		"TCoasterEnemy::perform": 0x80346dbc,
		"TCoasterEnemy::reset": 0x80346de8,
		"TCoasterEnemy::bind": 0x80346e38,
		"TCoasterEnemy::moveObject": 0x80346f14,
		"TCoasterEnemy::init": 0x80346f34,
		"Enemy::__sinit_coasterkiller_cpp": 0x803470b8,
		"__sinit_coasterkiller_cpp": 0x803470b8,
		"TNerveDebuTelesaWait::~TNerveDebuTelesaWait": 0x803473c4,
		"TNerveDebuTelesaWait::execute": 0x80347420,
		"TDebuTelesaManager::clipEnemies": 0x80347470,
		"TDebuTelesaManager::createModelData": 0x80347558,
		"TDebuTelesaManager::load": 0x8034758c,
		"TDebuTelesaManager::TDebuTelesaManager": 0x8034763c,
		"TDebuTelesa::setDeadAnm": 0x80347678,
		"TDebuTelesa::doKeepDistance": 0x803476a8,
		"TDebuTelesa::isCollidMove": 0x803476b0,
		"TDebuTelesa::attackToMario": 0x803476b8,
		"TDebuTelesa::behaveToWater": 0x803476e4,
		"TDebuTelesa::getBasNameTable": 0x803476e8,
		"TDebuTelesa::receiveMessage": 0x803476f0,
		"TDebuTelesa::kill": 0x803477a0,
		"TDebuTelesa::calcRootMatrix": 0x803477c0,
		"TDebuTelesa::reset": 0x803478d0,
		"TDebuTelesa::init": 0x803478d4,
		"TDebuTelesa::TDebuTelesa": 0x80347a00,
		"TDebuTelesaManager::~TDebuTelesaManager": 0x80347a50,
		"TDebuTelesa::changeByJuice": 0x80347b48,
		"Enemy::__sinit_DebuTelesa_cpp": 0x80347b50,
		"__sinit_DebuTelesa_cpp": 0x80347b50,
		"TNerveTabePukuDrag::~TNerveTabePukuDrag": 0x80347e54,
		"TNerveTabePukuDrag::execute": 0x80347eb0,
		"TNerveTabePukuRecoverGraph::~TNerveTabePukuRecoverGraph": 0x80348210,
		"TNerveTabePukuDrag::theNerve": 0x8034827c,
		"TNerveTabePukuDive::execute": 0x803482e0,
		"TNerveTabePukuDive::theNerve": 0x803484a4,
		"TNerveTabePukuDive::~TNerveTabePukuDive": 0x80348508,
		"TNerveTabePukuBite::execute": 0x80348564,
		"TNerveTabePukuBite::theNerve": 0x8034865c,
		"TNerveTabePukuBite::~TNerveTabePukuBite": 0x803486c0,
		"TNerveTabePukuAttack::execute": 0x8034871c,
		"TNerveTabePukuAttack::~TNerveTabePukuAttack": 0x80348aac,
		"TNerveTabePukuRecoverGraph::execute": 0x80348b08,
		"TNerveTabePukuGraphWander::~TNerveTabePukuGraphWander": 0x80348d0c,
		"TNerveTabePukuRecoverGraph::theNerve": 0x80348d68,
		"TNerveTabePukuFound::execute": 0x80348dcc,
		"TNerveTabePukuFound::~TNerveTabePukuFound": 0x80349074,
		"TNerveTabePukuGraphWander::execute": 0x803490d0,
		"TTabePukuManager::createModelData": 0x803492b8,
		"TTabePukuManager::load": 0x803492ec,
		"TTabePukuManager::TTabePukuManager": 0x80349528,
		"TTabePuku::swimTo": 0x80349564,
		"swimTo": 0x80349564,
		"TTabePuku::doKeepDistance": 0x80349d78,
		"TTabePuku::isFindMario": 0x80349e84,
		"TTabePuku::forceKill": 0x80349ea4,
		"TTabePuku::behaveToWater": 0x80349ea8,
		"TTabePuku::attackToMario": 0x80349eac,
		"TTabePuku::getBasNameTable": 0x8034a084,
		"TTabePuku::getTakingMtx": 0x8034a090,
		"TTabePuku::receiveMessage": 0x8034a214,
		"TTabePuku::calcRootMatrix": 0x8034a250,
		"TTabePuku::bind": 0x8034a410,
		"TTabePuku::control": 0x8034a5bc,
		"TTabePuku::perform": 0x8034a708,
		"TTabePuku::reset": 0x8034a76c,
		"TTabePuku::init": 0x8034a778,
		"TTabePuku::TTabePuku": 0x8034a928,
		"TTPHitActor::bind": 0x8034a978,
		"TTPHitActor::updateTerrainCollsion": 0x8034ac18,
		"updateTerrainCollsion": 0x8034ac18,
		"TTPHitActor::receiveMessage": 0x8034adbc,
		"TTPHitActor::init": 0x8034adec,
		"TTabePukuManager::~TTabePukuManager": 0x8034aedc,
		"Enemy::__sinit_TabePuku_cpp": 0x8034b058,
		"__sinit_TabePuku_cpp": 0x8034b058,
		"TBathtubBinder::float_": 0x8034b37c,
		"float_": 0x8034b37c,
		"TBathtubBinder::bind": 0x8034b7f8,
		"TBathtubBinder::init": 0x8034b830,
		"TBathtubBinder::~TBathtubBinder": 0x8034b958,
		"TBathtubBinder::TBathtubBinder": 0x8034b9bc,
		"TLimitKoopaManager::~TLimitKoopaManager": 0x8034ba04,
		"TLimitKoopaManager::loadAfter": 0x8034ba68,
		"TLimitKoopaManager::load": 0x8034bb90,
		"TLimitKoopaManager::createModelData": 0x8034c154,
		"TLimitKoopaManager::createEnemyInstance": 0x8034c188,
		"TLimitKoopaManager::TLimitKoopaManager": 0x8034c190,
		"TNerveLimitKoopaStagger::~TNerveLimitKoopaStagger": 0x8034c1cc,
		"TNerveLimitKoopaGetShowered::~TNerveLimitKoopaGetShowered": 0x8034c228,
		"TNerveLimitKoopaGetDown::~TNerveLimitKoopaGetDown": 0x8034c284,
		"TNerveLimitKoopaTumble::~TNerveLimitKoopaTumble": 0x8034c2e0,
		"TNerveLimitKoopaTurn::~TNerveLimitKoopaTurn": 0x8034c34c,
		"TLimitKoopa::setUpHitActors": 0x8034c3a8,
		"TLimitKoopa::calcRootMatrix": 0x8034c7e8,
		"TLimitKoopa::receiveMessage": 0x8034c83c,
		"TLimitKoopa::getGravityY": 0x8034c85c,
		"TLimitKoopa::startHipDrop": 0x8034c86c,
		"startHipDrop": 0x8034c86c,
		"TLimitKoopa::bind": 0x8034ca74,
		"TLimitKoopa::perform": 0x8034cbdc,
		"TLimitKoopa::reset": 0x8034cf44,
		"TLimitKoopa::init": 0x8034cfe8,
		"TNerveLimitKoopaWait::~TNerveLimitKoopaWait": 0x8034d1b0,
		"TLimitKoopa::loadAfter": 0x8034d21c,
		"TLimitKoopa::load": 0x8034d748,
		"TLimitKoopa::TLimitKoopa": 0x8034d768,
		"TLimitKoopaBody::attack_": 0x8034d7f0,
		"TLimitKoopaBody::receiveMessage": 0x8034d82c,
		"TLimitKoopaHead::attack_": 0x8034d834,
		"TLimitKoopaHead::receiveMessage": 0x8034d870,
		"TLimitKoopaHand::attack_": 0x8034da64,
		"TLimitKoopaHand::receiveMessage": 0x8034daa0,
		"TLimitKoopaFlame::attack_": 0x8034daa8,
		"TLimitKoopaFlame::receiveMessage": 0x8034db48,
		"TLimitKoopaParts::perform": 0x8034db64,
		"TNerveLimitKoopaGetDown::execute": 0x8034dbe8,
		"TNerveLimitKoopaGetShowered::execute": 0x8034dd6c,
		"TNerveLimitKoopaStagger::execute": 0x8034de08,
		"TNerveLimitKoopaTumble::execute": 0x8034dea4,
		"TNerveLimitKoopaWait::execute": 0x8034df40,
		"TNerveLimitKoopaHipDropStart::~TNerveLimitKoopaHipDropStart": 0x8034e168,
		"TNerveLimitKoopaHipDropStart::execute": 0x8034e1f8,
		"TNerveLimitKoopaHipDropJump::~TNerveLimitKoopaHipDropJump": 0x8034e320,
		"TNerveLimitKoopaHipDropJump::execute": 0x8034e37c,
		"Enemy::__sinit_limitkoopa_cpp": 0x8034e6ec,
		"__sinit_limitkoopa_cpp": 0x8034e6ec,
		"TLimitKoopaJrManager::~TLimitKoopaJrManager": 0x8034ea18,
		"TLimitKoopaJrManager::createEnemyInstance": 0x8034ea7c,
		"TLimitKoopaJrManager::loadAfter": 0x8034ea84,
		"TLimitKoopaJrManager::load": 0x8034ea88,
		"TLimitKoopaJrManager::createModelData": 0x8034eae0,
		"TLimitKoopaJrManager::TLimitKoopaJrManager": 0x8034eb14,
		"TNerveLimitKoopaJrYahoo::execute": 0x8034eb50,
		"TNerveLimitKoopaJrWait::~TNerveLimitKoopaJrWait": 0x8034ec68,
		"TNerveLimitKoopaJrYahoo::~TNerveLimitKoopaJrYahoo": 0x8034ecc4,
		"TNerveLimitKoopaJrLaunch::execute": 0x8034ed20,
		"TNerveLimitKoopaJrLaunch::~TNerveLimitKoopaJrLaunch": 0x8034ee54,
		"TNerveLimitKoopaJrWait::execute": 0x8034eeb0,
		"TNerveLimitKoopaJrRun::~TNerveLimitKoopaJrRun": 0x8034f224,
		"TNerveLimitKoopaJrRun::execute": 0x8034f280,
		"TLimitKoopaJr::moveRun": 0x8034f428,
		"moveRun": 0x8034f428,
		"TLimitKoopaJr::receiveMessage": 0x8034f7cc,
		"TLimitKoopaJr::getBasNameTable": 0x8034f7e4,
		"TLimitKoopaJr::calcRootMatrix": 0x8034f7f0,
		"TLimitKoopaJr::bind": 0x8034f8c4,
		"TLimitKoopaJr::perform": 0x8034f8c8,
		"TLimitKoopaJr::reset": 0x8034fa64,
		"TLimitKoopaJr::init": 0x8034fae0,
		"TLimitKoopaJr::TLimitKoopaJr": 0x8034fce8,
		"TLimitKoopaJrParams::TLimitKoopaJrParams": 0x8034fd64,
		"Enemy::__sinit_limitkoopajr_cpp": 0x80350088,
		"__sinit_limitkoopajr_cpp": 0x80350088,
		"CPolarSubCamera::execGroundCheck_": 0x8035038c,
		"execGroundCheck_": 0x8035038c,
		"CPolarSubCamera::execRoofCheck_": 0x803504dc,
		"execRoofCheck_": 0x803504dc,
		"CPolarSubCamera::execWallCheck_": 0x80350620,
		"execWallCheck_": 0x80350620,
		"CPolarSubCamera::isNeedWallCheck_": 0x80350854,
		"isNeedWallCheck_": 0x80350854,
		"CPolarSubCamera::isNeedRoofCheck_": 0x80350914,
		"isNeedRoofCheck_": 0x80350914,
		"CPolarSubCamera::isNeedGroundCheck_": 0x803509d4,
		"isNeedGroundCheck_": 0x803509d4,
		"CPolarSubCamera::calcInHouseNo_": 0x80350b40,
		"calcInHouseNo_": 0x80350b40,
		"CPolarSubCamera::execCameraModeChangeProc_": 0x80351180,
		"execCameraModeChangeProc_": 0x80351180,
		"CPolarSubCamera::isChangeToParallelCameraCByMoveBG_": 0x80351aec,
		"isChangeToParallelCameraCByMoveBG_": 0x80351aec,
		"CPolarSubCamera::isChangeToParallelCameraByMoveBG_": 0x80351b34,
		"isChangeToParallelCameraByMoveBG_": 0x80351b34,
		"CPolarSubCamera::isChangeToCancanCamera_": 0x80351c30,
		"isChangeToCancanCamera_": 0x80351c30,
		"CPolarSubCamera::isChangeToBossGesoCamera_": 0x80351c5c,
		"isChangeToBossGesoCamera_": 0x80351c5c,
		"CPolarSubCamera::doLButtonCameraOff_": 0x80351cec,
		"doLButtonCameraOff_": 0x80351cec,
		"CPolarSubCamera::execFrontRotate_": 0x80351e14,
		"execFrontRotate_": 0x80351e14,
		"CPolarSubCamera::changeCamModeSpecifyCamMapToolAndFrame_": 0x80351ef8,
		"changeCamModeSpecifyCamMapToolAndFrame_": 0x80351ef8,
		"CPolarSubCamera::changeCamModeSpecifyCamMapTool_": 0x80351f4c,
		"changeCamModeSpecifyCamMapTool_": 0x80351f4c,
		"CPolarSubCamera::changeCamModeSpecifyFrame_": 0x80351fc8,
		"changeCamModeSpecifyFrame_": 0x80351fc8,
		"CPolarSubCamera::changeCamModeSub_": 0x80351ffc,
		"changeCamModeSub_": 0x80351ffc,
		"TTargetCamera::operator_=": 0x80352670,
		"CPolarSubCamera::setUpFromLButtonCamera_": 0x80352704,
		"setUpFromLButtonCamera_": 0x80352704,
		"CPolarSubCamera::setUpToLButtonCamera_": 0x80352714,
		"setUpToLButtonCamera_": 0x80352714,
		"CPolarSubCamera::getCameraInbetweenFrame_": 0x80352798,
		"getCameraInbetweenFrame_": 0x80352798,
		"Camera::__sinit_CameraChange_cpp": 0x80352a5c,
		"__sinit_CameraChange_cpp": 0x80352a5c,
		"CPolarSubCamera::controlByCameraCode_": 0x80352d58,
		"controlByCameraCode_": 0x80352d58,
		"CPolarSubCamera::getFinalAngleZ": 0x80352f44,
		"getFinalAngleZ": 0x80352f44,
		"CPolarSubCamera::getOffsetAngleY": 0x80352f58,
		"getOffsetAngleY": 0x80352f58,
		"CPolarSubCamera::getOffsetAngleX": 0x80352f64,
		"getOffsetAngleX": 0x80352f64,
		"CPolarSubCamera::perform": 0x80352f70,
		"JGeometry::TUtil<float><float>::one": 0x80353354,
		"one": 0x80353354,
		"Camera::MsSqrtf": 0x8035336c,
		"MsSqrtf": 0x8035336c,
		"CPolarSubCamera::ctrlGameCamera_": 0x803533b0,
		"ctrlGameCamera_": 0x803533b0,
		"CPolarSubCamera::calcFinalPosAndAt_": 0x80353818,
		"calcFinalPosAndAt_": 0x80353818,
		"CPolarSubCamera::calcPosAndAt_": 0x803539a8,
		"calcPosAndAt_": 0x803539a8,
		"CPolarSubCamera::calcSlopeAngleX_": 0x8035494c,
		"calcSlopeAngleX_": 0x8035494c,
		"TMario::checkStatusType": 0x80354c44,
		"checkStatusType": 0x80354c44,
		"CPolarSubCamera::isMomentDefinite_": 0x80354c60,
		"isMomentDefinite_": 0x80354c60,
		"CPolarSubCamera::execInvalidAutoChase_": 0x80354ce8,
		"execInvalidAutoChase_": 0x80354ce8,
		"CPolarSubCamera::isMarioCrabWalk_": 0x80354cf8,
		"isMarioCrabWalk_": 0x80354cf8,
		"CPolarSubCamera::isMarioAimWithGun_": 0x80354d98,
		"isMarioAimWithGun_": 0x80354d98,
		"CPolarSubCamera::onMoveApproach_": 0x80354e38,
		"onMoveApproach_": 0x80354e38,
		"CPolarSubCamera::offMoveApproach_": 0x80354ef8,
		"offMoveApproach_": 0x80354ef8,
		"CPolarSubCamera::rotateY_ByStickX_": 0x80354f08,
		"rotateY_ByStickX_": 0x80354f08,
		"CPolarSubCamera::rotateX_ByStickY_": 0x80354f98,
		"rotateX_ByStickY_": 0x80354f98,
		"CPolarSubCamera::calcNowTargetFromPosAndAt_": 0x8035505c,
		"calcNowTargetFromPosAndAt_": 0x8035505c,
		"CPolarSubCamera::calcDistFromXRotRatio_": 0x803551a0,
		"calcDistFromXRotRatio_": 0x803551a0,
		"CPolarSubCamera::calcAngleXFromXRotRatio_": 0x803551d0,
		"calcAngleXFromXRotRatio_": 0x803551d0,
		"CPolarSubCamera::getUsualLookat": 0x80355200,
		"getUsualLookat": 0x80355200,
		"CPolarSubCamera::getToroccoMtx_": 0x8035526c,
		"getToroccoMtx_": 0x8035526c,
		"CPolarSubCamera::isNowInbetween": 0x80355284,
		"isNowInbetween": 0x80355284,
		"CPolarSubCamera::loadAfter": 0x803552a4,
		"Camera::JetCoasterDemoCallBack": 0x80355ad4,
		"JetCoasterDemoCallBack": 0x80355ad4,
		"CPolarSubCamera::CPolarSubCamera": 0x80355b4c,
		"CPolarSubCamera::killHeightPan_": 0x8035602c,
		"killHeightPan_": 0x8035602c,
		"CPolarSubCamera::execHeightPan_": 0x80356058,
		"execHeightPan_": 0x80356058,
		"CPolarSubCamera::isNotHeightPanCamMode_": 0x803562a4,
		"isNotHeightPanCamMode_": 0x803562a4,
		"CPolarSubCamera::killHeightPanWhenChangeCamMode_": 0x80356334,
		"killHeightPanWhenChangeCamMode_": 0x80356334,
		"TCameraInbetween::execCameraInbetween": 0x80356428,
		"execCameraInbetween": 0x80356428,
		"TCameraInbetween::initCameraInbetween": 0x803567c0,
		"initCameraInbetween": 0x803567c0,
		"TCameraInbetween::startCameraInbetween": 0x80356860,
		"startCameraInbetween": 0x80356860,
		"TCameraInbetween::addMoveCameraAndMario": 0x803568c8,
		"TCameraInbetween::warpPosAndAt": 0x803569b0,
		"TCameraInbetween::TCameraInbetween": 0x80356a38,
		"TCameraKindParam::inbetweenData": 0x80356a80,
		"inbetweenData": 0x80356a80,
		"TCameraKindParam::copySaveParam": 0x80356fa0,
		"copySaveParam": 0x80356fa0,
		"Camera::CLBCalcNearNinePos": 0x8035711c,
		"CLBCalcNearNinePos": 0x8035711c,
		"JGeometry::TRotation3<JGeometry::TMatrix33<JGeometry::SMatrix33C<float><float>>>::setRotate": 0x80357848,
		"Camera::CLBCalcScaleTranslateMatrix": 0x8035799c,
		"CLBCalcScaleTranslateMatrix": 0x8035799c,
		"Camera::CLBCalcRotateZXYTranslateMatrix": 0x803579ec,
		"CLBCalcRotateZXYTranslateMatrix": 0x803579ec,
		"Camera::CLBCalcPointInCubeRatio": 0x80357b3c,
		"CLBCalcPointInCubeRatio": 0x80357b3c,
		"Camera::CLBIsPointInCube": 0x80357d10,
		"CLBIsPointInCube": 0x80357d10,
		"Camera::CLBRotatePosAndUp": 0x80357f0c,
		"CLBRotatePosAndUp": 0x80357f0c,
		"Camera::CLBRevisionLookatByAngleX": 0x80358384,
		"CLBRevisionLookatByAngleX": 0x80358384,
		"Camera::CLBPolarToCross": 0x8035854c,
		"CLBPolarToCross": 0x8035854c,
		"Camera::CLBCrossToPolar": 0x803585e4,
		"CLBCrossToPolar": 0x803585e4,
		"Camera::CLBChaseSpecialDecrease": 0x803586ec,
		"CLBChaseSpecialDecrease": 0x803586ec,
		"Camera::CLBChaseDecrease": 0x8035876c,
		"CLBChaseDecrease": 0x8035876c,
		"Camera::CLBChaseAngleDecrease": 0x803587e0,
		"CLBChaseAngleDecrease": 0x803587e0,
		"Camera::CLBCalc2DFPos": 0x80358844,
		"CLBCalc2DFPos": 0x80358844,
		"Camera::__sinit_cameralib_cpp": 0x803589b4,
		"__sinit_cameralib_cpp": 0x803589b4,
		"TCameraMarioData::isMarioClimb": 0x803589d0,
		"isMarioClimb": 0x803589d0,
		"TCameraMarioData::isMarioLeanMirror": 0x80358a0c,
		"isMarioLeanMirror": 0x80358a0c,
		"TCameraMarioData::isMarioSlider": 0x80358a68,
		"isMarioSlider": 0x80358a68,
		"TCameraMarioData::isMarioIndoor": 0x80358ad0,
		"isMarioIndoor": 0x80358ad0,
		"TCameraMarioData::isMarioRocketing": 0x80358b40,
		"isMarioRocketing": 0x80358b40,
		"TCameraMarioData::isMarioGoDown": 0x80358b94,
		"isMarioGoDown": 0x80358b94,
		"TCameraMarioData::calcAndSetMarioData": 0x80358bd0,
		"calcAndSetMarioData": 0x80358bd0,
		"TCameraMarioData::TCameraMarioData": 0x80358d34,
		"CPolarSubCamera::ctrlLButtonCamera_": 0x80358d60,
		"ctrlLButtonCamera_": 0x80358d60,
		"CPolarSubCamera::getNozzleTopPos_": 0x80358f70,
		"getNozzleTopPos_": 0x80358f70,
		"CPolarSubCamera::calcNoticeTargetYrot_": 0x80359080,
		"calcNoticeTargetYrot_": 0x80359080,
		"CPolarSubCamera::execNoticeOnOffProc_": 0x80359284,
		"execNoticeOnOffProc_": 0x80359284,
		"CPolarSubCamera::getNoticeActor_": 0x80359348,
		"getNoticeActor_": 0x80359348,
		"CPolarSubCamera::setNoticeInfo": 0x80359680,
		"setNoticeInfo": 0x80359680,
		"CPolarSubCamera::ctrlNormalOrTowerCamera_": 0x803598e4,
		"ctrlNormalOrTowerCamera_": 0x803598e4,
		"CPolarSubCamera::calcTowerCenterPos_": 0x80359d98,
		"calcTowerCenterPos_": 0x80359d98,
		"TCamSaveKindParam::TCamSaveKindParam": 0x80359f08,
		"TCamSaveEx::TCamSaveEx": 0x8035b2e8,
		"TCamSaveJetCoaster::TCamSaveJetCoaster": 0x8035b7d8,
		"TCamSaveShake::TCamSaveShake": 0x8035b934,
		"TCamSaveNotice::TCamSaveNotice": 0x8035bacc,
		"TCameraShake::execShake": 0x8035bce0,
		"execShake": 0x8035bce0,
		"TCameraShake::keepShake": 0x8035c238,
		"keepShake": 0x8035c238,
		"TCameraShake::startShake": 0x8035c4bc,
		"startShake": 0x8035c4bc,
		"TCameraShake::getUseShakeData_": 0x8035c5e8,
		"getUseShakeData_": 0x8035c5e8,
		"TCameraShake::TCameraShake": 0x8035c8ac,
		"CPolarSubCamera::ctrlTalkCamera_": 0x8035ca40,
		"ctrlTalkCamera_": 0x8035ca40,
		"CPolarSubCamera::makeMtxForPrevTalk": 0x8035ca88,
		"makeMtxForPrevTalk": 0x8035ca88,
		"CPolarSubCamera::makeMtxForTalk": 0x8035cb20,
		"makeMtxForTalk": 0x8035cb20,
		"TLensFlare::~TLensFlare": 0x8035cc00,
		"TLensFlare::perform": 0x8035cc74,
		"TLensFlare::TLensFlare": 0x8035d25c,
		"Camera::CLBEaseOutInbetween": 0x8035d3a4,
		"TLensGlow::~TLensGlow": 0x8035d3c8,
		"TLensGlow::perform": 0x8035d468,
		"TLensGlow::TLensGlow": 0x8035d998,
		"TSunMgr::~TSunMgr": 0x8035dc74,
		"TSunMgr::getAddColor": 0x8035dd20,
		"getAddColor": 0x8035dd20,
		"TSunMgr::perform": 0x8035dd50,
		"TSunMgr::load": 0x8035defc,
		"TSunMgr::TSunMgr": 0x8035e0c4,
		"Camera::__sinit_sunmgr_cpp": 0x8035e16c,
		"__sinit_sunmgr_cpp": 0x8035e16c,
		"TSunModel::getZBufValue": 0x8035e4f0,
		"getZBufValue": 0x8035e4f0,
		"TSunModel::perform": 0x8035e58c,
		"TSunModel::calcDispRatioAndScreenPos_": 0x8035e9ac,
		"calcDispRatioAndScreenPos_": 0x8035e9ac,
		"Camera::CLBScreenFPosToSPos": 0x8035ead0,
		"CLBScreenFPosToSPos": 0x8035ead0,
		"TSunModel::calcOtherFPosFromCenterAndRadius_": 0x8035ebe4,
		"calcOtherFPosFromCenterAndRadius_": 0x8035ebe4,
		"TSunModel::load": 0x8035eca0,
		"TSunModel::TSunModel": 0x8035eff0,
		"JGeometry::TVec2<short><short>::TVec2": 0x8035f244,
		"Camera::SMS_IsInSameCameraCube": 0x8035f260,
		"SMS_IsInSameCameraCube": 0x8035f260,
		"Camera::SMS_IsInOtherFastCube": 0x8035f378,
		"SMS_IsInOtherFastCube": 0x8035f378,
		"TCubeManagerArea::isInAreaCube": 0x8035f4a0,
		"isInAreaCube": 0x8035f4a0,
		"TCubeManagerBase::calcPointInCubeRatio": 0x8035f5ec,
		"calcPointInCubeRatio": 0x8035f5ec,
		"TCubeManagerBase::isInCube": 0x8035f638,
		"isInCube": 0x8035f638,
		"TCubeManagerBase::getInCubeNo": 0x8035f6a8,
		"getInCubeNo": 0x8035f6a8,
		"TCubeManagerBase::getDataNo": 0x8035f740,
		"getDataNo": 0x8035f740,
		"TCubeManagerBase::perform": 0x8035f774,
		"TCubeManagerBase::load": 0x8035f778,
		"TCameraMapTool::calcPosAndAt": 0x8035fa5c,
		"calcPosAndAt": 0x8035fa5c,
		"TCameraMapTool::load": 0x8035fb30,
		"TCubeStreamInfo::~TCubeStreamInfo": 0x8035fc0c,
		"TCubeStreamInfo::load": 0x8035fc80,
		"TCubeCameraInfo::load": 0x8035fe20,
		"TCubeGeneralInfo::load": 0x8035ff84,
		"TCubeCameraInfo::~TCubeCameraInfo": 0x803600b8,
		"CPolarSubCamera::ctrlMultiPlayerCamera_": 0x8036012c,
		"ctrlMultiPlayerCamera_": 0x8036012c,
		"CPolarSubCamera::removeMultiPlayer": 0x803604a0,
		"removeMultiPlayer": 0x803604a0,
		"CPolarSubCamera::addMultiPlayer": 0x80360538,
		"addMultiPlayer": 0x80360538,
		"CPolarSubCamera::createMultiPlayer": 0x80360594,
		"createMultiPlayer": 0x80360594,
		"TMultiPlayerData::TMultiPlayerData": 0x8036062c,
		"TCameraJetCoaster::TCameraJetCoaster": 0x80360644,
		"CPolarSubCamera::ctrlJetCoasterCamera_": 0x803606ec,
		"ctrlJetCoasterCamera_": 0x803606ec,
		"Camera::__sinit_CameraJetCoaster_cpp": 0x803611e0,
		"__sinit_CameraJetCoaster_cpp": 0x803611e0,
		"TCameraBck::setFrame": 0x803614dc,
		"setFrame": 0x803614dc,
		"TCameraBck::updateDemo": 0x80361550,
		"updateDemo": 0x80361550,
		"TCameraBck::endDemo": 0x80361714,
		"endDemo": 0x80361714,
		"TCameraBck::getTotalDemoFrames": 0x8036173c,
		"getTotalDemoFrames": 0x8036173c,
		"TCameraBck::startDemo": 0x8036179c,
		"TCameraBck::isFileExist": 0x803617dc,
		"isFileExist": 0x803617dc,
		"TCameraBck::TCameraBck": 0x80361804,
		"TCameraOption::moveToDown": 0x80361908,
		"moveToDown": 0x80361908,
		"TCameraOption::moveToUp": 0x80361930,
		"moveToUp": 0x80361930,
		"TCameraOption::moveToLoadFromTitle": 0x80361958,
		"moveToLoadFromTitle": 0x80361958,
		"TCameraOption::TCameraOption": 0x8036198c,
		"CPolarSubCamera::ctrlOptionCamera_": 0x80361b00,
		"ctrlOptionCamera_": 0x80361b00,
		"CPolarSubCamera::isNormalDeadDemo": 0x80361e88,
		"isNormalDeadDemo": 0x80361e88,
		"CPolarSubCamera::isHellDeadDemo": 0x80361ea8,
		"isHellDeadDemo": 0x80361ea8,
		"CPolarSubCamera::execDeadDemoProc_": 0x80361ec8,
		"execDeadDemoProc_": 0x80361ec8,
		"CPolarSubCamera::ctrlNormalDeadDemo_": 0x80361f9c,
		"ctrlNormalDeadDemo_": 0x80361f9c,
		"CPolarSubCamera::getRestDemoFrames": 0x80362140,
		"getRestDemoFrames": 0x80362140,
		"CPolarSubCamera::isSimpleDemoCamera": 0x8036214c,
		"isSimpleDemoCamera": 0x8036214c,
		"CPolarSubCamera::endDemoCamera": 0x80362198,
		"endDemoCamera": 0x80362198,
		"CPolarSubCamera::startDemoCamera": 0x803622e0,
		"startDemoCamera": 0x803622e0,
		"CPolarSubCamera::startGateDemoCamera": 0x80362438,
		"startGateDemoCamera": 0x80362438,
		"CPolarSubCamera::updateGateDemoCamera_": 0x80362550,
		"updateGateDemoCamera_": 0x80362550,
		"CPolarSubCamera::updateDemoCamera_": 0x80362634,
		"updateDemoCamera_": 0x80362634,
		"CPolarSubCamera::addMoveCameraAndMario": 0x80362988,
		"CPolarSubCamera::isSlopeCameraMode": 0x80362f94,
		"isSlopeCameraMode": 0x80362f94,
		"CPolarSubCamera::isOverHipAttackSpecifyMode": 0x80362fc4,
		"isOverHipAttackSpecifyMode": 0x80362fc4,
		"CPolarSubCamera::isDefiniteCameraSpecifyMode": 0x80363070,
		"isDefiniteCameraSpecifyMode": 0x80363070,
		"CPolarSubCamera::isFixCameraSpecifyMode": 0x803630a4,
		"isFixCameraSpecifyMode": 0x803630a4,
		"CPolarSubCamera::isRailCameraSpecifyMode": 0x803630cc,
		"isRailCameraSpecifyMode": 0x803630cc,
		"CPolarSubCamera::isFollowCameraSpecifyMode": 0x803630d4,
		"isFollowCameraSpecifyMode": 0x803630d4,
		"CPolarSubCamera::isTowerCameraSpecifyMode": 0x80363110,
		"isTowerCameraSpecifyMode": 0x80363110,
		"CPolarSubCamera::isNormalCameraCompletely": 0x80363144,
		"isNormalCameraCompletely": 0x80363144,
		"CPolarSubCamera::isNormalCameraSpecifyMode": 0x803631d4,
		"isNormalCameraSpecifyMode": 0x803631d4,
		"CPolarSubCamera::isTalkCameraInbetween": 0x80363200,
		"isTalkCameraInbetween": 0x80363200,
		"CPolarSubCamera::isTalkCameraSpecifyMode": 0x803632f8,
		"isTalkCameraSpecifyMode": 0x803632f8,
		"CPolarSubCamera::isJetCoaster1stCamera": 0x80363344,
		"isJetCoaster1stCamera": 0x80363344,
		"CPolarSubCamera::isLButtonCameraInbetween": 0x80363378,
		"isLButtonCameraInbetween": 0x80363378,
		"CPolarSubCamera::isLButtonCameraSpecifyMode": 0x80363400,
		"isLButtonCameraSpecifyMode": 0x80363400,
		"CPolarSubCamera::execSecureView_": 0x80363414,
		"execSecureView_": 0x80363414,
		"CPolarSubCamera::calcSecureViewTarget_": 0x80363614,
		"calcSecureViewTarget_": 0x80363614,
		"TBoidLeader::~TBoidLeader": 0x80363734,
		"TBoidLeader::calcForces": 0x803637a8,
		"calcForces": 0x803637a8,
		"TBoidLeader::calcGoalForce": 0x80363b1c,
		"calcGoalForce": 0x80363b1c,
		"TBoidLeader::perform": 0x80363d80,
		"TBoidLeader::setGraph": 0x80363ee8,
		"setGraph": 0x80363ee8,
		"TBoidLeader::calcBoids": 0x80363fcc,
		"calcBoids": 0x80363fcc,
		"JGeometry::TVec3<float><float>::div": 0x8036489c,
		"div": 0x8036489c,
		"TBoidLeader::TBoidLeader": 0x803648cc,
		"TBoid::TBoid": 0x80364a38,
		"TFishoidManager::~TFishoidManager": 0x80364ac8,
		"TFishoidManager::createModelData": 0x80364b2c,
		"TFishoidManager::TFishoidManager": 0x80364b60,
		"TFishoid::createRealoidActor": 0x80364b9c,
		"TFishoid::load": 0x80364ce8,
		"TFishoid::init": 0x80364f10,
		"TFishoid::perform": 0x80364fdc,
		"TFishoid::TFishoid": 0x80365164,
		"TFish::init": 0x80365254,
		"TRealoid::perform": 0x80365264,
		"TRealoid::clipBoids": 0x803653dc,
		"clipBoids": 0x803653dc,
		"TRealoid::loadDefault": 0x803654b0,
		"loadDefault": 0x803654b0,
		"TRealoid::TRealoid": 0x8036565c,
		"TRealoidActor::getTakingMtx": 0x803656b4,
		"TRealoidActor::checkHitActors": 0x803656bc,
		"TRealoidActor::calcRootMatrix": 0x80365754,
		"TRealoidActor::perform": 0x803659cc,
		"TRealoidActor::TRealoidActor": 0x80365a44,
		"TAnimalBase::execWalk": 0x80365c6c,
		"Animal::MsClamp": 0x80366078,
		"TAnimalBase::getRotationFlyToDir": 0x803660e0,
		"getRotationFlyToDir": 0x803660e0,
		"TAnimalBase::resetRandomCurPathNode": 0x803662d0,
		"resetRandomCurPathNode": 0x803662d0,
		"TAnimalBase::perform": 0x803664ec,
		"TAnimalBase::receiveMessage": 0x80366824,
		"TAnimalBase::calcRootMatrix": 0x8036682c,
		"TAnimalBase::loadAfter": 0x80366830,
		"TAnimalBase::load": 0x80366878,
		"TAnimalBase::initNoLoad_": 0x80366918,
		"initNoLoad_": 0x80366918,
		"TAnimalBase::init": 0x80366ba0,
		"TAnimalBase::TAnimalBase": 0x80366e30,
		"Animal::SMS_Eular2Quat": 0x80366e88,
		"SMS_Eular2Quat": 0x80366e88,
		"Animal::__sinit_AnimalBase_cpp": 0x80367030,
		"__sinit_AnimalBase_cpp": 0x80367030,
		"TMewManager::~TMewManager": 0x80367334,
		"TMewManager::createModelData": 0x803673a8,
		"TMewManager::loadAfter": 0x803673dc,
		"TMewManager::load": 0x80367418,
		"TAnimalManagerBase::clipEnemies": 0x80367494,
		"TAnimalManagerBase::TAnimalManagerBase": 0x80367594,
		"Animal::__sinit_AnimalManager_cpp": 0x803675e4,
		"__sinit_AnimalManager_cpp": 0x803675e4,
		"TAnimalSaveIndividual::TAnimalSaveIndividual": 0x803678e0,
		"TNerveAnimalGraphWander::~TNerveAnimalGraphWander": 0x80367af0,
		"TNerveAnimalGraphWander::execute": 0x80367b4c,
		"TNerveAnimalGraphWander::theNerve": 0x80368084,
		"TNerveAnimalBirdLanding::~TNerveAnimalBirdLanding": 0x803680e8,
		"TNerveAnimalBirdLanding::execute": 0x80368144,
		"TNerveAnimalBirdWaitOnGround::~TNerveAnimalBirdWaitOnGround": 0x803683f8,
		"TNerveAnimalBirdGraphWander::~TNerveAnimalBirdGraphWander": 0x80368454,
		"TNerveAnimalBirdPreLanding::execute": 0x803684b0,
		"TNerveAnimalBirdPreLanding::theNerve": 0x80368720,
		"TNerveAnimalBirdPreLanding::~TNerveAnimalBirdPreLanding": 0x80368784,
		"TNerveAnimalBirdComeback::execute": 0x803687e0,
		"TNerveAnimalBirdComeback::theNerve": 0x80368a9c,
		"TNerveAnimalBirdComeback::~TNerveAnimalBirdComeback": 0x80368b00,
		"TNerveAnimalBirdChangeToCoin::execute": 0x80368b5c,
		"TNerveAnimalBirdChangeToCoin::theNerve": 0x80368c94,
		"TNerveAnimalBirdChangeToCoin::~TNerveAnimalBirdChangeToCoin": 0x80368cf8,
		"TNerveAnimalBirdGraphWander::execute": 0x80368d54,
		"TNerveAnimalBirdTakeoff::execute": 0x80369074,
		"TNerveAnimalBirdTakeoff::~TNerveAnimalBirdTakeoff": 0x803691e4,
		"TNerveAnimalBirdWalkOnGround::execute": 0x80369240,
		"TNerveAnimalBirdWalkOnGround::theNerve": 0x80369618,
		"TNerveAnimalBirdWalkOnGround::~TNerveAnimalBirdWalkOnGround": 0x8036967c,
		"TNerveAnimalBirdActionOnGround::execute": 0x803696d8,
		"TNerveAnimalBirdActionOnGround::theNerve": 0x80369994,
		"TNerveAnimalBirdActionOnGround::~TNerveAnimalBirdActionOnGround": 0x803699f8,
		"TNerveAnimalBirdWaitOnGround::execute": 0x80369a54,
		"TNerveAnimalBirdWaitOnGround::theNerve": 0x80369cfc,
		"TAnimalBirdManager::createModelData": 0x80369d60,
		"TAnimalBirdManager::loadAfter": 0x80369d94,
		"TAnimalBirdManager::load": 0x80369de0,
		"TAnimalBirdManager::TAnimalBirdManager": 0x80369e4c,
		"TAnimalBirdParams::TAnimalBirdParams": 0x80369e88,
		"TAnimalBird::doLanding": 0x8036a200,
		"doLanding": 0x8036a200,
		"TAnimalBird::doFlyToCurPathNode": 0x8036a5c4,
		"doFlyToCurPathNode": 0x8036a5c4,
		"TAnimalBird::isFindMario": 0x8036a944,
		"TAnimalBird::getBasNameTable": 0x8036aa3c,
		"TAnimalBird::bind": 0x8036aa48,
		"TAnimalBird::moveObject": 0x8036ab44,
		"TAnimalBird::calcRootMatrix": 0x8036af00,
		"TAnimalBird::receiveMessage": 0x8036af8c,
		"TAnimalBird::loadAfter": 0x8036b330,
		"TAnimalBird::load": 0x8036b374,
		"TAnimalBird::initParams": 0x8036b4c8,
		"initParams": 0x8036b4c8,
		"TAnimalBird::init": 0x8036b618,
		"TAnimalBird::TAnimalBird": 0x8036b750,
		"TAnimalBirdManager::~TAnimalBirdManager": 0x8036b7a0,
		"Animal::__sinit_Bird_cpp": 0x8036b870,
		"__sinit_Bird_cpp": 0x8036b870,
		"TNerveBeeHiveReset::~TNerveBeeHiveReset": 0x8036bb74,
		"TNerveBeeHiveReset::execute": 0x8036bbd0,
		"TNerveBeeHiveWait::~TNerveBeeHiveWait": 0x8036bd20,
		"TNerveBeeHiveMarioWaterIn::execute": 0x8036bd7c,
		"TNerveBeeHiveAttack::~TNerveBeeHiveAttack": 0x8036c068,
		"TNerveBeeHiveMarioWaterIn::~TNerveBeeHiveMarioWaterIn": 0x8036c0d4,
		"TNerveBeeHiveAttack::execute": 0x8036c130,
		"TNerveBeeHiveBreak::execute": 0x8036c4c0,
		"TNerveBeeHiveBreak::~TNerveBeeHiveBreak": 0x8036c754,
		"TNerveBeeHiveFall::execute": 0x8036c7b0,
		"TNerveBeeHiveFall::~TNerveBeeHiveFall": 0x8036ca34,
		"TNerveBeeHiveWait::execute": 0x8036ca90,
		"TBeeHiveManager::createModelData": 0x8036cd10,
		"TBeeHiveManager::load": 0x8036cd44,
		"TBeeHiveManager::TBeeHiveManager": 0x8036cf5c,
		"TBeeHive::getCenterOfGravity": 0x8036cf98,
		"getCenterOfGravity": 0x8036cf98,
		"TBeeHive::appearBee": 0x8036d2c4,
		"appearBee": 0x8036d2c4,
		"TBeeHive::doWait": 0x8036d328,
		"doWait": 0x8036d328,
		"TBeeHive::calcRootMatrix": 0x8036d9b4,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setSQ": 0x8036db64,
		"setSQ": 0x8036db64,
		"TBeeHive::controlSound": 0x8036dc64,
		"controlSound": 0x8036dc64,
		"TBeeHive::controlCollision": 0x8036dd30,
		"TBeeHive::bind": 0x8036ddf0,
		"TBeeHive::control": 0x8036e050,
		"TBeeHive::perform": 0x8036e08c,
		"TBeeHive::receiveMessage": 0x8036e0e0,
		"TBeeHive::createRealoidActor": 0x8036e478,
		"TBeeHive::load": 0x8036e4ec,
		"TBeeHive::receiveMessageFromChild": 0x8036e6dc,
		"receiveMessageFromChild": 0x8036e6dc,
		"TBeeHive::reset": 0x8036e7d4,
		"TBeeHive::init": 0x8036eb7c,
		"TBeeHive::TBeeHive": 0x8036ec78,
		"TBee::receiveMessage": 0x8036ecc4,
		"TBee::init": 0x8036ed78,
		"TBeeHiveManager::~TBeeHiveManager": 0x8036ee5c,
		"Animal::__sinit_BeeHive_cpp": 0x8036efe0,
		"__sinit_BeeHive_cpp": 0x8036efe0,
		"TButterfloidManager::~TButterfloidManager": 0x8036f2f4,
		"TButterfloidManager::createModelData": 0x8036f358,
		"TButterfloidManager::TButterfloidManager": 0x8036f38c,
		"TButterfloid::createRealoidActor": 0x8036f3c8,
		"TButterfloid::load": 0x8036f43c,
		"TButterfloid::init": 0x8036f6bc,
		"TButterfloid::TButterfloid": 0x8036f788,
		"TButterfly::receiveMessage": 0x8036f7ec,
		"TButterfly::init": 0x8036f968,
		"Runtime.PPCEABI.H::__init_cpp_exceptions_reference": 0x8036fba0,
		"__init_cpp_exceptions_reference": 0x8036fba0,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions_reference": 0x8036ff84,
		"__fini_cpp_exceptions_reference": 0x8036ff84,
		"JSystem::@1727": 0x8036ffa0,
		"@1727": 0x8036ffa0,
		"JSystem::@1728": 0x8036ffb4,
		"@1728": 0x8036ffb4,
		"JSystem::@114": 0x8036ffd0,
		"JSystem::@447": 0x8036fffc,
		"@447": 0x8036fffc,
		"JSystem::@548": 0x8037001c,
		"@548": 0x8037001c,
		"JSystem::@1809": 0x80370088,
		"JSystem::@1810": 0x8037009c,
		"JSystem::@1811": 0x803700bc,
		"JSystem::@438": 0x803700d8,
		"@438": 0x803700d8,
		"JSystem::@439": 0x803700ec,
		"@439": 0x803700ec,
		"JSystem::@302": 0x80370130,
		"JSystem::@593": 0x803701ec,
		"@593": 0x803701ec,
		"JSystem::@594": 0x80370218,
		"@594": 0x80370218,
		"JSystem::@595": 0x80370244,
		"@595": 0x80370244,
		"JSystem::@596": 0x8037026c,
		"@596": 0x8037026c,
		"JSystem::@597": 0x8037029c,
		"@597": 0x8037029c,
		"JSystem::@606": 0x803702c4,
		"JSystem::@607": 0x803702d4,
		"JSystem::@688": 0x803702f0,
		"JSystem::@689": 0x80370314,
		"JSystem::@720": 0x80370324,
		"@720": 0x80370324,
		"JSystem::@721": 0x8037035c,
		"@721": 0x8037035c,
		"JSystem::@723": 0x8037036c,
		"@723": 0x8037036c,
		"JSystem::@727": 0x803703d0,
		"@727": 0x803703d0,
		"JSystem::@729": 0x803703e0,
		"@729": 0x803703e0,
		"JSystem::@799": 0x80370428,
		"JSystem::@800": 0x80370458,
		"JSystem::@801": 0x8037046c,
		"JSystem::@802": 0x80370478,
		"JSystem::@803": 0x80370494,
		"JSystem::@805": 0x803704bc,
		"JSystem::@806": 0x803704d0,
		"JSystem::@1643": 0x80370520,
		"JSystem::@1644": 0x80370534,
		"JSystem::@288": 0x80370550,
		"JSystem::@305": 0x803705b8,
		"JSystem::@365": 0x80370688,
		"@365": 0x80370688,
		"JSystem::@366": 0x803706a0,
		"@366": 0x803706a0,
		"JSystem::@367": 0x803706b4,
		"@367": 0x803706b4,
		"JSystem::@368": 0x803706c8,
		"@368": 0x803706c8,
		"JSystem::@1545": 0x803706e8,
		"JSystem::@1558": 0x80370714,
		"JSystem::@1560": 0x80370738,
		"JSystem::@1495": 0x80370820,
		"@1495": 0x80370820,
		"JSystem::@1496": 0x80370834,
		"@1496": 0x80370834,
		"JSystem::@1497": 0x80370840,
		"@1497": 0x80370840,
		"JSystem::@1498": 0x80370854,
		"@1498": 0x80370854,
		"JSystem::@1499": 0x80370868,
		"@1499": 0x80370868,
		"JSystem::@1566": 0x803708a8,
		"JSystem::@1567": 0x803708bc,
		"JSystem::@1628": 0x803708c8,
		"JSystem::@1701": 0x803708f0,
		"JSystem::@1702": 0x80370918,
		"@1702": 0x80370918,
		"JSystem::@1709": 0x80370964,
		"JSystem::@1710": 0x80370984,
		"JSystem::@1711": 0x803709a0,
		"JSystem::@1722": 0x803709bc,
		"@1722": 0x803709bc,
		"JSystem::@1723": 0x803709e4,
		"JSystem::@1724": 0x80370a0c,
		"@1724": 0x80370a0c,
		"JSystem::@1757": 0x80370a28,
		"JSystem::@1775": 0x80370a40,
		"@1775": 0x80370a40,
		"JSystem::@1776": 0x80370a6c,
		"@1776": 0x80370a6c,
		"JSystem::@1777": 0x80370a7c,
		"@1777": 0x80370a7c,
		"JSystem::@1778": 0x80370a90,
		"JSystem::@1795": 0x80370ab8,
		"JSystem::@2006": 0x80370ad4,
		"JSystem::@2007": 0x80370b0c,
		"JSystem::@2193": 0x80370b30,
		"JSystem::@83": 0x80370b60,
		"JSystem::@84": 0x80370b70,
		"JSystem::@321": 0x80370b90,
		"JSystem::@1454": 0x80370be8,
		"@1454": 0x80370be8,
		"JSystem::@894": 0x80370bf8,
		"@894": 0x80370bf8,
		"JSystem::@914": 0x80370c04,
		"@914": 0x80370c04,
		"JSystem::@1249": 0x80370c10,
		"@1249": 0x80370c10,
		"JSystem::@1251": 0x80370c1c,
		"@1251": 0x80370c1c,
		"JSystem::@329": 0x80370c28,
		"JSystem::@838": 0x80370c38,
		"@838": 0x80370c38,
		"JSystem::@839": 0x80370c48,
		"@839": 0x80370c48,
		"JSystem::@885": 0x80370c70,
		"@885": 0x80370c70,
		"JSystem::@813": 0x80370ce0,
		"@813": 0x80370ce0,
		"JSystem::@999": 0x80370d40,
		"@999": 0x80370d40,
		"JSystem::@95": 0x80370d50,
		"JSystem::@96": 0x80370d60,
		"JSystem::@97": 0x80370d70,
		"JSystem::@98": 0x80370d84,
		"JSystem::@99": 0x80370d94,
		"JSystem::@110": 0x80370da8,
		"JSystem::@272": 0x80370dc0,
		"@272": 0x80370dc0,
		"JSystem::@289": 0x80370de0,
		"JSystem::halftofull$376": 0x80370df4,
		"halftofull$376": 0x80370df4,
		"JSystem::@258": 0x80370eb8,
		"@258": 0x80370eb8,
		"JSystem::@903": 0x80370f00,
		"JSystem::@881": 0x80370f10,
		"@881": 0x80370f10,
		"JSystem::@882": 0x80370f20,
		"@882": 0x80370f20,
		"JSystem::@632": 0x80370f38,
		"@632": 0x80370f38,
		"JSystem::@753": 0x80370f44,
		"JSystem::@1461": 0x80370f5c,
		"@1461": 0x80370f5c,
		"JSystem::@1462": 0x80370f68,
		"@1462": 0x80370f68,
		"JSystem::@1463": 0x80370f7c,
		"@1463": 0x80370f7c,
		"JSystem::@1464": 0x80370f88,
		"@1464": 0x80370f88,
		"JSystem::@1465": 0x80370f94,
		"@1465": 0x80370f94,
		"JSystem::@1468": 0x80370fa0,
		"@1468": 0x80370fa0,
		"JSystem::@1473": 0x80370fb0,
		"@1473": 0x80370fb0,
		"JSystem::@1474": 0x80370fbc,
		"@1474": 0x80370fbc,
		"JSystem::@1475": 0x80370fc8,
		"@1475": 0x80370fc8,
		"JSystem::@1476": 0x80370fd4,
		"@1476": 0x80370fd4,
		"JSystem::@1480": 0x80370fe4,
		"@1480": 0x80370fe4,
		"JSystem::@1481": 0x80370ff0,
		"@1481": 0x80370ff0,
		"JSystem::@1482": 0x80370ffc,
		"@1482": 0x80370ffc,
		"JSystem::@49": 0x80371098,
		"@49": 0x80371098,
		"JSystem::@50": 0x803710ac,
		"@50": 0x803710ac,
		"JSystem::@61": 0x803710c4,
		"JSystem::@293": 0x803710e0,
		"JSystem::@1143": 0x80371100,
		"@1143": 0x80371100,
		"JSystem::@1144": 0x80371110,
		"@1144": 0x80371110,
		"JSystem::@1578": 0x80371120,
		"JSystem::@395": 0x80371130,
		"@395": 0x80371130,
		"JSystem::@415": 0x8037113c,
		"@415": 0x8037113c,
		"JSystem::@416": 0x80371178,
		"@416": 0x80371178,
		"JSystem::@417": 0x80371188,
		"@417": 0x80371188,
		"JSystem::@463": 0x803711e8,
		"JSystem::@530": 0x803711f8,
		"@530": 0x803711f8,
		"JSystem::@537": 0x80371240,
		"@537": 0x80371240,
		"JASystem::Driver::polys_table": 0x80371260,
		"polys_table": 0x80371260,
		"JSystem::@119": 0x80371270,
		"@119": 0x80371270,
		"JSystem::@211": 0x8037127c,
		"@211": 0x8037127c,
		"JASystem::Driver::relTableSampleCell": 0x80371288,
		"relTableSampleCell": 0x80371288,
		"JASystem::Driver::relTableSqRoot": 0x803712cc,
		"relTableSqRoot": 0x803712cc,
		"JASystem::Driver::relTableSquare": 0x80371310,
		"relTableSquare": 0x80371310,
		"JSystem::@197": 0x80371358,
		"JSystem::@216": 0x80371364,
		"@216": 0x80371364,
		"JASystem::Arglist": 0x80371370,
		"Arglist": 0x80371370,
		"JSystem::@351": 0x8037148c,
		"@351": 0x8037148c,
		"JSystem::@442": 0x803714d0,
		"@442": 0x803714d0,
		"JSystem::@444": 0x803714f8,
		"@444": 0x803714f8,
		"JSystem::@445": 0x8037150c,
		"@445": 0x8037150c,
		"JSystem::@451": 0x80371560,
		"@451": 0x80371560,
		"Runtime.PPCEABI.H::__ptmf_null": 0x80371570,
		"__ptmf_null": 0x80371570,
		"Runtime.PPCEABI.H::__constants": 0x80371580,
		"__constants": 0x80371580,
		"MSL_C.PPCEABI.bare.H::__ctype_map": 0x80371620,
		"__ctype_map": 0x80371620,
		"MSL_C.PPCEABI.bare.H::__lower_map": 0x80371720,
		"__lower_map": 0x80371720,
		"MSL_C.PPCEABI.bare.H::__upper_map": 0x80371820,
		"__upper_map": 0x80371820,
		"MSL_C.PPCEABI.bare.H::@stringBase0": 0x80371920,
		"@stringBase0": 0x80371920,
		"MSL_C.PPCEABI.bare.H::atan_coeff$96": 0x803719c8,
		"atan_coeff$96": 0x803719c8,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_hi$97": 0x803719e4,
		"onep_one_over_xisqr_hi$97": 0x803719e4,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_lo$98": 0x803719fc,
		"onep_one_over_xisqr_lo$98": 0x803719fc,
		"MSL_C.PPCEABI.bare.H::atan_xi_hi$99": 0x80371a14,
		"atan_xi_hi$99": 0x80371a14,
		"MSL_C.PPCEABI.bare.H::atan_xi_lo$100": 0x80371a30,
		"atan_xi_lo$100": 0x80371a30,
		"MSL_C.PPCEABI.bare.H::one_over_xi_hi$101": 0x80371a4c,
		"one_over_xi_hi$101": 0x80371a4c,
		"MSL_C.PPCEABI.bare.H::one_over_xi_lo$102": 0x80371a64,
		"one_over_xi_lo$102": 0x80371a64,
		"MSL_C.PPCEABI.bare.H::tmp_float": 0x80371a80,
		"tmp_float": 0x80371a80,
		"MSL_C.PPCEABI.bare.H::__two_to_log2e_m1_tI": 0x80371a90,
		"__two_to_log2e_m1_tI": 0x80371a90,
		"MSL_C.PPCEABI.bare.H::__one_over_F": 0x80371d58,
		"__one_over_F": 0x80371d58,
		"MSL_C.PPCEABI.bare.H::__sincos_on_quadrant": 0x80371f5c,
		"__sincos_on_quadrant": 0x80371f5c,
		"MSL_C.PPCEABI.bare.H::__sincos_poly": 0x80371f7c,
		"__sincos_poly": 0x80371f7c,
		"MSL_C.PPCEABI.bare.H::__log2_F": 0x80371fa8,
		"__log2_F": 0x80371fa8,
		"MSL_C.PPCEABI.bare.H::__two_to_x": 0x803721ac,
		"__two_to_x": 0x803721ac,
		"MSL_C.PPCEABI.bare.H::__exp_to_x$105": 0x803721d0,
		"__exp_to_x$105": 0x803721d0,
		"TRK_MINNOW_DOLPHIN::@40": 0x803721f0,
		"TRK_MINNOW_DOLPHIN::gTRKMemMap": 0x80372210,
		"gTRKMemMap": 0x80372210,
		"TRK_MINNOW_DOLPHIN::@233": 0x80372220,
		"@233": 0x80372220,
		"TRK_MINNOW_DOLPHIN::@238": 0x80372234,
		"@238": 0x80372234,
		"TRK_MINNOW_DOLPHIN::@243": 0x80372248,
		"@243": 0x80372248,
		"thp::__THPJpegNaturalOrder": 0x80372260,
		"__THPJpegNaturalOrder": 0x80372260,
		"MarioUtil::@2036": 0x803722f0,
		"MarioUtil::@2195": 0x803722fc,
		"MarioUtil::@3559": 0x8037230c,
		"MarioUtil::lightName$1906": 0x8037233c,
		"lightName$1906": 0x8037233c,
		"MarioUtil::ambName$1907": 0x80372350,
		"ambName$1907": 0x80372350,
		"MarioUtil::lightName$1917": 0x80372370,
		"lightName$1917": 0x80372370,
		"MarioUtil::ambName$1918": 0x80372388,
		"ambName$1918": 0x80372388,
		"MarioUtil::lightName$1928": 0x803723ac,
		"lightName$1928": 0x803723ac,
		"MarioUtil::ambName$1929": 0x803723c4,
		"ambName$1929": 0x803723c4,
		"MarioUtil::@1931": 0x803723e8,
		"MarioUtil::@1932": 0x803723fc,
		"MarioUtil::lightName$1942": 0x80372410,
		"lightName$1942": 0x80372410,
		"MarioUtil::ambName$1943": 0x80372428,
		"ambName$1943": 0x80372428,
		"MarioUtil::@1945": 0x8037244c,
		"MarioUtil::@1946": 0x80372460,
		"MarioUtil::@2007": 0x80372474,
		"MarioUtil::@2223": 0x8037248c,
		"MarioUtil::@2224": 0x803724a0,
		"MarioUtil::@2225": 0x803724b8,
		"MarioUtil::@2296": 0x803724f4,
		"MarioUtil::@2477": 0x80372504,
		"MarioUtil::@2843": 0x80372514,
		"MarioUtil::@1819": 0x80372534,
		"MarioUtil::@1820": 0x80372540,
		"MarioUtil::@1846": 0x80372550,
		"@1846": 0x80372550,
		"MarioUtil::@2544": 0x8037255c,
		"MarioUtil::@2545": 0x80372570,
		"MarioUtil::@2546": 0x8037257c,
		"MarioUtil::@2547": 0x80372588,
		"MarioUtil::@2548": 0x80372594,
		"MarioUtil::@2549": 0x803725a0,
		"MarioUtil::@2556": 0x803725ac,
		"MarioUtil::@1831": 0x803725b8,
		"MarioUtil::@1809": 0x803725dc,
		"MarioUtil::@1974": 0x803725f0,
		"MarioUtil::@1975": 0x80372600,
		"MarioUtil::@2149": 0x80372610,
		"MarioUtil::@2150": 0x80372634,
		"MarioUtil::calctablex$2412": 0x80372658,
		"calctablex$2412": 0x80372658,
		"MarioUtil::calctablez$2413": 0x80372668,
		"calctablez$2413": 0x80372668,
		"MarioUtil::@4135": 0x80372678,
		"MarioUtil::@4136": 0x80372694,
		"MarioUtil::@4137": 0x803726b0,
		"MarioUtil::@4138": 0x803726c8,
		"MarioUtil::@17": 0x803726e0,
		"MarioUtil::@18": 0x803727b0,
		"MarioUtil::@19": 0x803727c0,
		"@19": 0x803727c0,
		"MarioUtil::@20": 0x803727d0,
		"@20": 0x803727d0,
		"MarioUtil::@21": 0x803727e0,
		"@21": 0x803727e0,
		"MarioUtil::@22": 0x803727f4,
		"MarioUtil::@23": 0x80372808,
		"@23": 0x80372808,
		"MarioUtil::@24": 0x80372818,
		"@24": 0x80372818,
		"MarioUtil::@25": 0x80372828,
		"MarioUtil::@26": 0x80372838,
		"@26": 0x80372838,
		"MarioUtil::@27": 0x80372848,
		"@27": 0x80372848,
		"MarioUtil::@28": 0x8037285c,
		"MarioUtil::@29": 0x8037286c,
		"@29": 0x8037286c,
		"MarioUtil::@30": 0x8037287c,
		"MarioUtil::@31": 0x8037288c,
		"MarioUtil::@32": 0x8037289c,
		"MarioUtil::@33": 0x803728ac,
		"MarioUtil::@34": 0x803728bc,
		"MarioUtil::@35": 0x803728cc,
		"MarioUtil::@36": 0x803728dc,
		"MarioUtil::@37": 0x803728ec,
		"MarioUtil::@38": 0x803728fc,
		"MarioUtil::@39": 0x80372908,
		"MarioUtil::@40": 0x80372914,
		"MarioUtil::@66": 0x8037292c,
		"System::@1664": 0x80372940,
		"System::@1711": 0x8037294c,
		"System::prmarray$2214": 0x80372960,
		"prmarray$2214": 0x80372960,
		"System::envarray$2215": 0x80372978,
		"envarray$2215": 0x80372978,
		"System::@2200": 0x803729b0,
		"System::@2201": 0x803729e0,
		"System::@2202": 0x80372a18,
		"System::@2203": 0x80372a4c,
		"System::@2728": 0x80372a70,
		"System::@3457": 0x80372ac8,
		"System::@3471": 0x80372ad8,
		"System::@3708": 0x80372ae8,
		"System::@3709": 0x80372af8,
		"System::@3710": 0x80372b08,
		"System::@3711": 0x80372b1c,
		"System::@3712": 0x80372b2c,
		"System::@3713": 0x80372b38,
		"System::@3714": 0x80372b4c,
		"System::@3715": 0x80372b60,
		"System::@3716": 0x80372b70,
		"System::@3717": 0x80372b84,
		"System::@3718": 0x80372b94,
		"System::@3719": 0x80372ba0,
		"System::@3720": 0x80372bb0,
		"System::@3721": 0x80372bc0,
		"System::@3722": 0x80372bcc,
		"System::@3723": 0x80372be4,
		"System::@3724": 0x80372bfc,
		"System::@3725": 0x80372c0c,
		"System::@3726": 0x80372c20,
		"System::@3727": 0x80372c34,
		"System::@3728": 0x80372c48,
		"System::@3729": 0x80372c5c,
		"System::@3730": 0x80372c70,
		"System::@3731": 0x80372c80,
		"System::@3732": 0x80372c94,
		"System::@3733": 0x80372cb0,
		"System::@3734": 0x80372cbc,
		"System::@3735": 0x80372cd0,
		"System::@3736": 0x80372ce0,
		"System::@3737": 0x80372cf0,
		"System::@3738": 0x80372cfc,
		"System::@3739": 0x80372d10,
		"System::@3740": 0x80372d28,
		"System::@3741": 0x80372d38,
		"System::@3742": 0x80372d50,
		"System::@3743": 0x80372d68,
		"System::@3744": 0x80372d84,
		"System::@3745": 0x80372d98,
		"System::@3746": 0x80372db0,
		"System::@3747": 0x80372dc8,
		"System::@3748": 0x80372ddc,
		"System::@3750": 0x80372e04,
		"System::@3751": 0x80372e14,
		"System::@3752": 0x80372e20,
		"System::@3829": 0x803730fc,
		"System::@3834": 0x8037311c,
		"System::@4300": 0x8037314c,
		"System::@4824": 0x80373160,
		"System::@4846": 0x8037316c,
		"System::@5584": 0x8037319c,
		"@5584": 0x8037319c,
		"System::@5774": 0x803731a8,
		"System::@2396": 0x803732c4,
		"System::@2397": 0x803732d0,
		"System::@2399": 0x803732dc,
		"System::@2182": 0x80373304,
		"System::@2358": 0x80373318,
		"System::@2359": 0x80373348,
		"System::@2360": 0x80373380,
		"System::@2361": 0x803733b4,
		"System::@4266": 0x803734d0,
		"System::@1491": 0x80373508,
		"System::@2268": 0x80373528,
		"System::@2452": 0x803735e8,
		"System::@2453": 0x80373614,
		"System::@2454": 0x80373644,
		"System::@3076": 0x80373668,
		"System::@1701": 0x80373684,
		"System::@1784": 0x80373698,
		"System::@1785": 0x803736c8,
		"System::@1786": 0x80373700,
		"System::@1787": 0x80373734,
		"System::@2388": 0x80373778,
		"System::@2732": 0x80373790,
		"System::@2733": 0x803737a4,
		"System::@2734": 0x803737b8,
		"System::@2735": 0x803737c8,
		"System::@2736": 0x803737d4,
		"System::@2737": 0x803737e0,
		"System::@2743": 0x803737f0,
		"System::@2744": 0x803737fc,
		"System::@2746": 0x80373824,
		"System::@2747": 0x80373838,
		"System::@2748": 0x80373844,
		"System::@2749": 0x80373854,
		"System::@2750": 0x80373864,
		"System::@2751": 0x80373874,
		"System::@2810": 0x80373884,
		"System::@2811": 0x80373894,
		"System::@2971": 0x803738a0,
		"System::@2972": 0x803738b0,
		"System::@2973": 0x803738c0,
		"System::@2974": 0x803738d0,
		"System::@1615": 0x80373934,
		"System::@1616": 0x8037394c,
		"System::@1617": 0x80373960,
		"System::@1620": 0x8037398c,
		"System::@1621": 0x8037399c,
		"System::@1622": 0x803739a8,
		"System::@1623": 0x803739b8,
		"System::@1624": 0x803739c8,
		"System::@1625": 0x803739e8,
		"System::@1627": 0x80373a08,
		"System::@1628": 0x80373a28,
		"System::@1629": 0x80373a48,
		"System::@1630": 0x80373a5c,
		"System::@1631": 0x80373a6c,
		"System::@1638": 0x80373ae8,
		"System::@1639": 0x80373afc,
		"System::@1640": 0x80373b14,
		"System::@1641": 0x80373b2c,
		"System::@1642": 0x80373b40,
		"System::@2205": 0x80373b78,
		"System::@2206": 0x80373ba8,
		"System::@2207": 0x80373be0,
		"System::@2208": 0x80373c14,
		"System::@2694": 0x80373c38,
		"@unnamed@::cDispExceptionCommand": 0x80373d50,
		"cDispExceptionCommand": 0x80373d50,
		"System::@1503": 0x80373d68,
		"@1503": 0x80373d68,
		"System::@2117": 0x80373d84,
		"System::@2174": 0x80373dc8,
		"System::@2175": 0x80373e00,
		"System::@2176": 0x80373e34,
		"System::@4634": 0x80373ea4,
		"System::@4635": 0x80373eb0,
		"System::@4636": 0x80373ec8,
		"System::@4637": 0x80373ed4,
		"System::@4638": 0x80373ee4,
		"System::@4639": 0x80373ef0,
		"System::@4640": 0x80373f00,
		"System::@4641": 0x80373f14,
		"System::@4642": 0x80373f28,
		"System::@4643": 0x80373f34,
		"System::@4644": 0x80373f44,
		"System::@4645": 0x80373f50,
		"System::@4646": 0x80373f60,
		"System::@4647": 0x80373f6c,
		"System::@4648": 0x80373f78,
		"System::@4649": 0x80373f90,
		"System::@4650": 0x80373f9c,
		"System::@4651": 0x80373fb8,
		"System::@4653": 0x80373fd4,
		"System::@4654": 0x80373fe0,
		"System::@4655": 0x80373fec,
		"System::@4656": 0x80373ffc,
		"System::@4657": 0x80374010,
		"System::@4658": 0x80374024,
		"System::@4659": 0x80374030,
		"System::@4660": 0x80374040,
		"System::@4662": 0x80374050,
		"System::@4663": 0x8037405c,
		"System::@4671": 0x803740e0,
		"System::@4672": 0x803740f0,
		"System::@4675": 0x803740fc,
		"System::@4676": 0x8037410c,
		"@4676": 0x8037410c,
		"System::@4677": 0x80374120,
		"System::@4678": 0x80374134,
		"System::@4679": 0x80374148,
		"@4679": 0x80374148,
		"System::@4680": 0x80374154,
		"System::@4681": 0x80374164,
		"System::@4683": 0x80374170,
		"System::@4684": 0x8037417c,
		"System::@4685": 0x80374188,
		"System::@4686": 0x80374198,
		"System::@4687": 0x803741a4,
		"System::@4688": 0x803741b4,
		"System::@4689": 0x803741c0,
		"System::@4690": 0x803741cc,
		"System::@4691": 0x803741d8,
		"System::@4692": 0x803741e4,
		"System::@4693": 0x803741f4,
		"System::@4694": 0x80374200,
		"System::@4695": 0x80374210,
		"System::@4698": 0x80374240,
		"System::@4699": 0x80374250,
		"System::@4700": 0x8037425c,
		"System::@4701": 0x8037426c,
		"System::@4702": 0x80374278,
		"System::@4704": 0x80374290,
		"System::@4707": 0x8037429c,
		"System::@4708": 0x803742a8,
		"System::@4709": 0x803742b4,
		"System::@4710": 0x803742c0,
		"@4710": 0x803742c0,
		"System::@4711": 0x803742cc,
		"@4711": 0x803742cc,
		"System::@4713": 0x803742d8,
		"@4713": 0x803742d8,
		"System::@4714": 0x803742f0,
		"@4714": 0x803742f0,
		"System::@4715": 0x803742fc,
		"@4715": 0x803742fc,
		"System::@4716": 0x80374310,
		"System::@4717": 0x8037431c,
		"System::@4718": 0x80374338,
		"System::@4719": 0x80374344,
		"System::@4720": 0x8037435c,
		"System::@4721": 0x80374368,
		"System::@4722": 0x8037437c,
		"System::@4723": 0x80374388,
		"System::@4724": 0x803743a0,
		"System::@4725": 0x803743ac,
		"System::@4726": 0x803743c4,
		"System::@4727": 0x803743d0,
		"System::@4728": 0x803743e8,
		"System::@4729": 0x803743f4,
		"System::@4730": 0x8037440c,
		"System::@4731": 0x8037441c,
		"System::@4732": 0x80374440,
		"System::@4733": 0x80374450,
		"System::@4734": 0x80374474,
		"System::@4735": 0x8037448c,
		"System::@4736": 0x803744a0,
		"System::@4737": 0x803744c0,
		"System::@4738": 0x803744dc,
		"System::@4739": 0x803744f4,
		"System::@4740": 0x8037450c,
		"System::@4742": 0x8037452c,
		"System::@4743": 0x80374540,
		"System::@4744": 0x80374560,
		"System::@4745": 0x80374578,
		"System::@4746": 0x80374594,
		"System::@4747": 0x803745ac,
		"System::@4748": 0x803745cc,
		"System::@4749": 0x803745e4,
		"System::@4751": 0x803745f8,
		"System::@4752": 0x8037460c,
		"System::@4753": 0x80374628,
		"System::@4754": 0x80374640,
		"System::@4755": 0x80374658,
		"System::@4756": 0x80374668,
		"System::@4759": 0x80374698,
		"System::@4760": 0x803746a8,
		"System::@4761": 0x803746bc,
		"System::@4762": 0x803746d0,
		"System::@4763": 0x803746e8,
		"System::@4764": 0x803746fc,
		"System::@4765": 0x8037470c,
		"System::@4768": 0x80374720,
		"System::@4769": 0x80374730,
		"System::@4770": 0x80374744,
		"System::@4771": 0x8037475c,
		"System::@4772": 0x8037476c,
		"System::@4773": 0x80374780,
		"System::@4774": 0x8037479c,
		"System::@4775": 0x803747b8,
		"System::@4776": 0x803747c4,
		"System::@4777": 0x803747d0,
		"System::@4778": 0x803747e0,
		"System::@4779": 0x803747f4,
		"System::@4780": 0x80374808,
		"System::@4781": 0x80374814,
		"System::@4782": 0x80374824,
		"System::@4783": 0x80374838,
		"System::@4784": 0x80374844,
		"System::@4785": 0x80374850,
		"System::@4786": 0x80374864,
		"System::@4787": 0x80374878,
		"System::@4788": 0x80374884,
		"System::@4789": 0x80374894,
		"System::@4790": 0x803748a4,
		"System::@4791": 0x803748b4,
		"@4791": 0x803748b4,
		"System::@4792": 0x803748c0,
		"System::@4793": 0x803748d0,
		"@4793": 0x803748d0,
		"System::@4794": 0x803748dc,
		"@4794": 0x803748dc,
		"System::@4795": 0x803748ec,
		"System::@5549": 0x8037490c,
		"System::@5832": 0x80374920,
		"System::@2838": 0x80374990,
		"System::@2842": 0x803749c0,
		"System::@2843": 0x803749cc,
		"System::@2854": 0x80374a28,
		"System::@2857": 0x80374a40,
		"System::@2858": 0x80374a50,
		"System::@2859": 0x80374a60,
		"System::SceneParamsDir": 0x80374b60,
		"SceneParamsDir": 0x80374b60,
		"System::@1525": 0x80374b7c,
		"System::@2003": 0x80374c50,
		"System::@2004": 0x80374c64,
		"System::@2005": 0x80374c84,
		"System::@2006": 0x80374c90,
		"System::@2573": 0x80374cc0,
		"System::@1726": 0x80374fdc,
		"@1726": 0x80374fdc,
		"System::@1958": 0x8037508c,
		"System::@1959": 0x803750c0,
		"System::@3507": 0x80375240,
		"System::@3508": 0x80375250,
		"System::@3509": 0x80375264,
		"System::@3510": 0x8037527c,
		"System::@3515": 0x803752d4,
		"System::@3516": 0x803752f4,
		"System::@3521": 0x80375344,
		"System::@3522": 0x80375354,
		"System::@3523": 0x8037536c,
		"System::@3524": 0x80375394,
		"System::@3525": 0x803753a8,
		"System::@3526": 0x803753c4,
		"System::@3527": 0x803753d8,
		"System::@3528": 0x803753fc,
		"System::@3529": 0x8037540c,
		"System::@3530": 0x80375424,
		"System::@3531": 0x80375438,
		"System::@3532": 0x80375444,
		"System::@3533": 0x8037545c,
		"System::@3534": 0x80375478,
		"System::@3535": 0x80375488,
		"System::@3536": 0x80375498,
		"System::@3537": 0x803754ac,
		"System::@3538": 0x803754c8,
		"System::@3539": 0x803754d8,
		"System::@3540": 0x803754e8,
		"System::@3541": 0x803754f4,
		"System::@3542": 0x80375504,
		"System::@3543": 0x80375518,
		"System::@3544": 0x80375530,
		"System::@3545": 0x8037553c,
		"System::@3546": 0x8037554c,
		"System::@3547": 0x80375558,
		"System::@3548": 0x80375568,
		"System::@3549": 0x8037557c,
		"System::@3550": 0x80375598,
		"System::@3553": 0x803755d4,
		"System::@3554": 0x803755e0,
		"System::@3555": 0x803755f4,
		"System::@3556": 0x8037560c,
		"System::@3557": 0x8037561c,
		"System::@3560": 0x80375630,
		"System::@3561": 0x8037563c,
		"System::@3562": 0x80375648,
		"System::@3563": 0x8037565c,
		"System::@3922": 0x80375798,
		"System::@3924": 0x803757c0,
		"System::@3925": 0x803757d0,
		"System::@3926": 0x803757ec,
		"System::@3927": 0x803757f8,
		"System::@3928": 0x80375808,
		"System::@3929": 0x80375814,
		"System::@3930": 0x80375820,
		"System::@3933": 0x8037585c,
		"System::@3934": 0x80375870,
		"System::@3935": 0x80375884,
		"System::@3936": 0x80375898,
		"System::@3938": 0x803758a4,
		"System::@3940": 0x803758bc,
		"System::@3941": 0x803758cc,
		"System::@3942": 0x803758e0,
		"System::@3943": 0x803758fc,
		"System::@3944": 0x80375908,
		"System::@3945": 0x80375914,
		"System::@3946": 0x80375920,
		"System::@3947": 0x8037592c,
		"System::@3948": 0x80375938,
		"System::@3949": 0x80375944,
		"System::@3950": 0x80375950,
		"System::@3951": 0x8037595c,
		"System::@3952": 0x8037596c,
		"System::@3956": 0x803759a0,
		"System::@3957": 0x803759b8,
		"System::@3959": 0x803759c4,
		"System::@3961": 0x803759d0,
		"System::@3963": 0x803759dc,
		"System::@3965": 0x803759f0,
		"System::@3967": 0x80375a14,
		"System::@3968": 0x80375a28,
		"System::@3969": 0x80375a38,
		"System::@3970": 0x80375a58,
		"System::@3971": 0x80375a70,
		"System::@3972": 0x80375a8c,
		"System::@3973": 0x80375aa8,
		"System::@3974": 0x80375ac8,
		"System::@3975": 0x80375ae0,
		"System::@3976": 0x80375afc,
		"System::@3977": 0x80375b14,
		"System::@3978": 0x80375b30,
		"System::@3979": 0x80375b44,
		"System::@3980": 0x80375b60,
		"System::@3981": 0x80375b6c,
		"System::@3982": 0x80375b7c,
		"System::@3983": 0x80375b8c,
		"System::@3984": 0x80375ba8,
		"System::@3985": 0x80375bb8,
		"System::@3986": 0x80375bd0,
		"System::@3987": 0x80375bdc,
		"System::@3991": 0x80375c28,
		"System::@3992": 0x80375c38,
		"System::@3993": 0x80375c48,
		"System::@3994": 0x80375c58,
		"System::@3995": 0x80375c6c,
		"System::@3996": 0x80375c88,
		"System::@3997": 0x80375c98,
		"System::@3998": 0x80375ca8,
		"System::@3999": 0x80375cc0,
		"System::@4000": 0x80375cdc,
		"System::@4001": 0x80375cf8,
		"System::@4002": 0x80375d18,
		"System::@4003": 0x80375d2c,
		"System::@4004": 0x80375d40,
		"System::@4005": 0x80375d54,
		"System::@4006": 0x80375d6c,
		"System::@4007": 0x80375d7c,
		"System::@4008": 0x80375d88,
		"System::@4009": 0x80375d9c,
		"System::@4010": 0x80375db8,
		"System::@4014": 0x80375e00,
		"System::@4015": 0x80375e0c,
		"System::@4016": 0x80375e18,
		"System::@4017": 0x80375e34,
		"System::@4018": 0x80375e50,
		"System::@4019": 0x80375e60,
		"System::@4021": 0x80375e78,
		"System::@4023": 0x80375e90,
		"System::@4024": 0x80375ea0,
		"System::@4025": 0x80375eb4,
		"System::@4026": 0x80375ecc,
		"System::@4027": 0x80375ed8,
		"System::@4028": 0x80375ee4,
		"System::@4029": 0x80375ef8,
		"System::@4030": 0x80375f14,
		"System::@4031": 0x80375f20,
		"System::@4032": 0x80375f30,
		"System::@4033": 0x80375f40,
		"System::@4034": 0x80375f54,
		"System::@4035": 0x80375f68,
		"System::@4036": 0x80375f84,
		"System::@4037": 0x80375f90,
		"System::@4038": 0x80375fa0,
		"System::@4039": 0x80375fac,
		"System::@4044": 0x80375fe8,
		"System::@4045": 0x80375ff8,
		"System::@4047": 0x80376010,
		"System::@4049": 0x80376028,
		"System::@4050": 0x80376038,
		"System::@4051": 0x80376044,
		"System::@4052": 0x80376054,
		"System::@4054": 0x80376084,
		"System::@4055": 0x80376090,
		"System::@4056": 0x803760a0,
		"System::@4057": 0x803760b4,
		"System::@4058": 0x803760d0,
		"System::@4059": 0x803760e0,
		"System::@4060": 0x803760f0,
		"System::@4061": 0x80376100,
		"System::@4066": 0x8037612c,
		"System::@4067": 0x80376138,
		"System::@4068": 0x80376148,
		"System::@4069": 0x80376154,
		"@4069": 0x80376154,
		"System::@4070": 0x80376160,
		"System::@4071": 0x80376174,
		"@4071": 0x80376174,
		"System::@4072": 0x80376188,
		"System::@4073": 0x8037619c,
		"System::@4074": 0x803761b4,
		"System::@4075": 0x803761c0,
		"System::@4077": 0x803761dc,
		"System::@4079": 0x803761f4,
		"System::@4088": 0x80376294,
		"System::@4089": 0x803762a0,
		"System::@4090": 0x803762b4,
		"System::@4091": 0x803762d0,
		"System::@4092": 0x803762ec,
		"System::@4093": 0x80376300,
		"System::@4094": 0x80376310,
		"System::@4095": 0x80376328,
		"System::@4096": 0x80376344,
		"System::@4097": 0x80376358,
		"System::@4098": 0x80376368,
		"System::@4099": 0x80376378,
		"System::@4100": 0x80376390,
		"System::@4101": 0x803763a0,
		"System::@4102": 0x803763b8,
		"System::@4103": 0x803763c4,
		"System::@4105": 0x803763d0,
		"System::@4107": 0x803763ec,
		"System::@4108": 0x80376410,
		"System::@4109": 0x8037641c,
		"System::@4110": 0x80376434,
		"System::@4111": 0x80376444,
		"System::@4112": 0x80376460,
		"System::@4113": 0x8037646c,
		"System::@4114": 0x8037647c,
		"System::@4115": 0x8037648c,
		"System::@4117": 0x803764a4,
		"@4117": 0x803764a4,
		"System::@4135": 0x80376544,
		"System::@4137": 0x80376568,
		"System::@4138": 0x80376588,
		"System::@4139": 0x80376598,
		"System::@4140": 0x803765ac,
		"System::@4141": 0x803765bc,
		"System::@4142": 0x803765d0,
		"System::@4143": 0x803765e8,
		"System::@4144": 0x80376608,
		"System::@4145": 0x80376614,
		"System::@4146": 0x8037662c,
		"System::@4147": 0x80376640,
		"System::@4148": 0x8037665c,
		"System::@4150": 0x80376668,
		"System::@4152": 0x80376688,
		"System::@4153": 0x8037669c,
		"System::@4154": 0x803766b0,
		"System::@4155": 0x803766c8,
		"System::@4175": 0x8037681c,
		"System::@4177": 0x80376838,
		"System::@4179": 0x80376854,
		"System::@1723": 0x803768fc,
		"System::@1779": 0x80376910,
		"System::@1780": 0x80376940,
		"System::@1781": 0x80376978,
		"System::@1782": 0x803769ac,
		"System::@2095": 0x80376a0c,
		"System::@2096": 0x80376a18,
		"System::@2097": 0x80376a24,
		"@2097": 0x80376a24,
		"System::@2098": 0x80376a30,
		"System::@2099": 0x80376a40,
		"System::@2105": 0x80376a80,
		"System::@2106": 0x80376a8c,
		"System::@2107": 0x80376a98,
		"System::@1752": 0x80376abc,
		"System::@1808": 0x80376ad0,
		"System::@1810": 0x80376b38,
		"System::@1811": 0x80376b6c,
		"System::@2364": 0x80376b90,
		"System::@2366": 0x80376b9c,
		"System::@4980": 0x80376ba8,
		"System::@4981": 0x80376bb4,
		"System::@4982": 0x80376bc8,
		"System::@4983": 0x80376bd8,
		"System::@4985": 0x80376bec,
		"System::@4987": 0x80376bf8,
		"System::@4988": 0x80376c08,
		"System::@4989": 0x80376c14,
		"System::@4990": 0x80376c20,
		"System::@4991": 0x80376c34,
		"System::@4992": 0x80376c40,
		"System::@4993": 0x80376c50,
		"System::@4994": 0x80376c60,
		"System::@4995": 0x80376c74,
		"System::@4996": 0x80376c88,
		"System::@4997": 0x80376c98,
		"System::@4999": 0x80376cbc,
		"System::@5001": 0x80376ce8,
		"System::@5002": 0x80376cf4,
		"System::@5003": 0x80376d0c,
		"System::@5004": 0x80376d18,
		"System::@5005": 0x80376d2c,
		"System::@5006": 0x80376d3c,
		"System::@5007": 0x80376d4c,
		"System::@5009": 0x80376d60,
		"System::@5010": 0x80376d74,
		"System::@5011": 0x80376d80,
		"System::@5012": 0x80376d8c,
		"System::@5014": 0x80376d98,
		"System::@5016": 0x80376da4,
		"System::@5018": 0x80376db0,
		"System::@5020": 0x80376dc4,
		"System::@5021": 0x80376dd8,
		"System::@5023": 0x80376dfc,
		"System::@5024": 0x80376e10,
		"System::@5025": 0x80376e24,
		"System::@5026": 0x80376e40,
		"System::@5028": 0x80376e74,
		"System::@5030": 0x80376e94,
		"System::@5034": 0x80376ec8,
		"System::@5035": 0x80376ed8,
		"System::@5036": 0x80376ee4,
		"@5036": 0x80376ee4,
		"System::@5038": 0x80376ef8,
		"System::@5040": 0x80376f04,
		"@5040": 0x80376f04,
		"System::@5041": 0x80376f18,
		"System::@5042": 0x80376f2c,
		"System::@5047": 0x80376f38,
		"System::@5048": 0x80376f44,
		"System::@5049": 0x80376f54,
		"System::@5050": 0x80376f64,
		"System::@5054": 0x80376f8c,
		"System::@5055": 0x80376fa4,
		"System::@5056": 0x80376fb0,
		"System::@5062": 0x80376ff0,
		"@5062": 0x80376ff0,
		"System::@5065": 0x80376ffc,
		"@5065": 0x80376ffc,
		"System::@5067": 0x80377028,
		"@5067": 0x80377028,
		"System::@5068": 0x80377038,
		"@5068": 0x80377038,
		"System::@5069": 0x8037704c,
		"@5069": 0x8037704c,
		"System::@5070": 0x8037705c,
		"System::@5071": 0x80377070,
		"System::@5072": 0x8037707c,
		"System::@5073": 0x80377090,
		"System::@5076": 0x803770b8,
		"System::@5079": 0x803770fc,
		"@5079": 0x803770fc,
		"System::@5080": 0x80377108,
		"System::@5081": 0x80377118,
		"System::@5082": 0x80377128,
		"@5082": 0x80377128,
		"System::@5083": 0x80377134,
		"System::@5084": 0x80377144,
		"System::@5085": 0x80377150,
		"System::@5087": 0x8037715c,
		"System::@5090": 0x80377168,
		"System::@5091": 0x80377174,
		"System::@5092": 0x80377180,
		"System::@5093": 0x8037718c,
		"System::@5094": 0x80377198,
		"System::@5095": 0x803771a8,
		"System::@5096": 0x803771b8,
		"System::@5097": 0x803771c4,
		"System::@5098": 0x803771d0,
		"System::@5099": 0x803771e0,
		"System::@5104": 0x80377210,
		"System::@5105": 0x8037721c,
		"@5105": 0x8037721c,
		"System::@5106": 0x8037722c,
		"@5106": 0x8037722c,
		"System::@5107": 0x80377238,
		"@5107": 0x80377238,
		"System::@5109": 0x80377244,
		"System::@5111": 0x8037726c,
		"System::@5112": 0x8037727c,
		"System::@5113": 0x8037728c,
		"System::@5114": 0x803772a0,
		"System::@5117": 0x803772d4,
		"System::@5118": 0x803772e4,
		"System::@5120": 0x803772fc,
		"System::@5121": 0x8037730c,
		"System::@5123": 0x8037732c,
		"System::@5124": 0x80377340,
		"System::@5125": 0x8037734c,
		"System::@5126": 0x8037735c,
		"System::@5128": 0x80377368,
		"System::@5129": 0x80377378,
		"System::@5134": 0x803773c4,
		"System::@5135": 0x803773d0,
		"System::@5136": 0x803773dc,
		"System::@5137": 0x803773e8,
		"System::@5138": 0x803773fc,
		"System::@5139": 0x80377410,
		"System::@5140": 0x80377420,
		"@5140": 0x80377420,
		"System::@5142": 0x80377438,
		"System::@5143": 0x80377448,
		"System::@5144": 0x8037745c,
		"System::@5145": 0x8037746c,
		"System::@5146": 0x80377480,
		"System::@5148": 0x80377494,
		"System::@5149": 0x803774a0,
		"System::@5150": 0x803774b0,
		"@5150": 0x803774b0,
		"System::@5151": 0x803774c4,
		"System::@5152": 0x803774d4,
		"System::@5157": 0x80377530,
		"System::@5158": 0x80377540,
		"System::@5159": 0x80377554,
		"System::@5160": 0x80377564,
		"System::@5162": 0x80377580,
		"@5162": 0x80377580,
		"System::@5163": 0x80377598,
		"System::@5164": 0x803775a4,
		"System::@5165": 0x803775b0,
		"System::@5166": 0x803775c0,
		"System::@5167": 0x803775d4,
		"System::@5168": 0x803775e4,
		"System::@5169": 0x803775f8,
		"@5169": 0x803775f8,
		"System::@5170": 0x80377604,
		"System::@5171": 0x80377614,
		"@5171": 0x80377614,
		"System::@5172": 0x80377620,
		"System::@5173": 0x8037762c,
		"System::@5174": 0x80377638,
		"System::@5175": 0x80377648,
		"System::@5177": 0x80377658,
		"System::@5179": 0x80377664,
		"System::@5180": 0x80377678,
		"System::@5181": 0x8037768c,
		"System::@5182": 0x8037769c,
		"System::@5183": 0x803776a8,
		"System::@5184": 0x803776b8,
		"System::@5186": 0x803776c8,
		"System::@5187": 0x803776d8,
		"System::@5188": 0x803776e8,
		"System::@5189": 0x803776fc,
		"System::@5193": 0x80377714,
		"System::@5195": 0x80377730,
		"System::@5196": 0x8037773c,
		"System::@5197": 0x8037774c,
		"System::@5198": 0x8037775c,
		"System::@5199": 0x8037776c,
		"System::@5200": 0x80377780,
		"@5200": 0x80377780,
		"System::@5202": 0x8037779c,
		"System::@5203": 0x803777a8,
		"System::@5204": 0x803777b8,
		"System::@5205": 0x803777c4,
		"@5205": 0x803777c4,
		"System::@5208": 0x803777e4,
		"System::@5209": 0x803777f0,
		"System::@5210": 0x80377800,
		"System::@5211": 0x8037780c,
		"@5211": 0x8037780c,
		"System::@5213": 0x80377818,
		"System::@5214": 0x8037782c,
		"System::@5215": 0x80377838,
		"System::@5216": 0x80377848,
		"System::@5217": 0x80377854,
		"System::@5218": 0x80377860,
		"System::@5219": 0x80377874,
		"System::@5220": 0x80377880,
		"System::@5222": 0x8037788c,
		"System::@5224": 0x803778a4,
		"System::@5225": 0x803778b8,
		"System::@5226": 0x803778c4,
		"System::@5227": 0x803778d0,
		"System::@5229": 0x803778ec,
		"System::@5230": 0x803778fc,
		"System::@5231": 0x80377910,
		"System::@5232": 0x80377920,
		"System::@5233": 0x80377934,
		"System::@5234": 0x80377940,
		"System::@5235": 0x8037794c,
		"System::@5236": 0x80377958,
		"System::@5238": 0x8037797c,
		"System::@5239": 0x80377988,
		"System::@5240": 0x80377994,
		"System::@5241": 0x803779a4,
		"System::@5242": 0x803779b8,
		"System::@5243": 0x803779c4,
		"System::@5244": 0x803779d4,
		"System::@5246": 0x803779e0,
		"System::@5248": 0x803779f0,
		"System::@5249": 0x80377a00,
		"System::@5250": 0x80377a0c,
		"System::@5251": 0x80377a18,
		"System::@5252": 0x80377a28,
		"System::@5253": 0x80377a3c,
		"System::@5254": 0x80377a50,
		"System::@5255": 0x80377a60,
		"System::@5257": 0x80377a70,
		"System::@5258": 0x80377a80,
		"System::@5259": 0x80377a90,
		"System::@5260": 0x80377a9c,
		"System::@5262": 0x80377ab8,
		"System::@5264": 0x80377ad4,
		"System::@5266": 0x80377ae0,
		"System::@5267": 0x80377af0,
		"System::@5268": 0x80377b00,
		"System::@5270": 0x80377b10,
		"System::@5271": 0x80377b1c,
		"System::@5273": 0x80377b38,
		"System::@5274": 0x80377b48,
		"System::@5276": 0x80377b54,
		"System::@5277": 0x80377b60,
		"System::@5278": 0x80377b70,
		"System::@5279": 0x80377b8c,
		"System::@5280": 0x80377b9c,
		"System::@5282": 0x80377bb8,
		"System::@5283": 0x80377bc8,
		"System::@5288": 0x80377be0,
		"System::@5289": 0x80377bec,
		"System::@5290": 0x80377bf8,
		"System::@5292": 0x80377c10,
		"System::@5293": 0x80377c1c,
		"@5293": 0x80377c1c,
		"System::@5294": 0x80377c28,
		"@5294": 0x80377c28,
		"System::@5295": 0x80377c34,
		"System::@5296": 0x80377c40,
		"System::@5297": 0x80377c4c,
		"@5297": 0x80377c4c,
		"System::@5298": 0x80377c58,
		"@5298": 0x80377c58,
		"System::@5301": 0x80377c70,
		"System::@5304": 0x80377c98,
		"System::@5306": 0x80377ca4,
		"System::@5307": 0x80377cb0,
		"System::@5308": 0x80377cc8,
		"System::@5309": 0x80377cd4,
		"System::@5310": 0x80377ce4,
		"System::@5314": 0x80377cf4,
		"System::@5316": 0x80377d0c,
		"System::@5318": 0x80377d18,
		"System::@5319": 0x80377d28,
		"System::@5320": 0x80377d38,
		"System::@5322": 0x80377d5c,
		"System::@5323": 0x80377d6c,
		"System::@5324": 0x80377d84,
		"System::@5325": 0x80377d98,
		"System::@5326": 0x80377da8,
		"System::@5330": 0x80377dd4,
		"System::@5331": 0x80377de0,
		"System::@5332": 0x80377df0,
		"System::@5334": 0x80377dfc,
		"System::@5335": 0x80377e08,
		"System::@5336": 0x80377e18,
		"System::@5337": 0x80377e28,
		"System::@5338": 0x80377e38,
		"System::@5339": 0x80377e44,
		"System::@5340": 0x80377e54,
		"System::@5341": 0x80377e60,
		"System::@5342": 0x80377e74,
		"System::@5343": 0x80377e94,
		"System::@5345": 0x80377eb0,
		"@5345": 0x80377eb0,
		"System::@5346": 0x80377ec0,
		"System::@5347": 0x80377ed0,
		"System::@5348": 0x80377edc,
		"System::@5350": 0x80377efc,
		"System::@5351": 0x80377f10,
		"System::@5352": 0x80377f1c,
		"System::@2577": 0x80378020,
		"System::@2578": 0x8037802c,
		"System::@2594": 0x803780ec,
		"System::@2595": 0x803780f8,
		"System::@2596": 0x80378104,
		"System::@2597": 0x80378110,
		"System::CardFileName": 0x80378350,
		"CardFileName": 0x80378350,
		"System::@2155": 0x803783e4,
		"System::@2384": 0x803783f8,
		"System::@3129": 0x803785a8,
		"System::@3130": 0x803785bc,
		"System::@3131": 0x803785d0,
		"System::@3132": 0x803785e4,
		"System::@3133": 0x803785f0,
		"System::@3134": 0x80378604,
		"System::@3135": 0x80378618,
		"System::@3140": 0x8037867c,
		"System::@3141": 0x80378690,
		"System::@3142": 0x803786a4,
		"System::@3143": 0x803786b8,
		"System::@3144": 0x803786cc,
		"System::@3145": 0x803786e0,
		"System::@3146": 0x803786f8,
		"System::@3147": 0x80378710,
		"System::@3148": 0x80378724,
		"System::@3149": 0x8037873c,
		"System::@3150": 0x80378750,
		"System::@3151": 0x80378768,
		"System::@3152": 0x80378780,
		"System::@3153": 0x80378794,
		"System::@3154": 0x803787a8,
		"System::@3159": 0x80378814,
		"System::@3160": 0x80378828,
		"System::@3161": 0x8037883c,
		"System::@3162": 0x80378850,
		"System::@3163": 0x80378864,
		"System::@3164": 0x80378878,
		"System::@3165": 0x8037888c,
		"System::@3166": 0x803788a0,
		"System::@3167": 0x803788b4,
		"System::@3168": 0x803788c8,
		"System::@3169": 0x803788d8,
		"System::@3170": 0x803788ec,
		"System::@3171": 0x80378900,
		"System::@3172": 0x80378914,
		"System::@3173": 0x8037892c,
		"System::@3174": 0x80378944,
		"System::@3175": 0x8037895c,
		"System::@3176": 0x80378974,
		"System::@3177": 0x80378988,
		"System::@3178": 0x8037899c,
		"System::@3179": 0x803789b0,
		"System::@3180": 0x803789c4,
		"System::@3181": 0x803789d8,
		"System::@3182": 0x803789ec,
		"System::@3183": 0x80378a00,
		"System::@3184": 0x80378a14,
		"System::@3189": 0x80378a78,
		"System::@3190": 0x80378a8c,
		"System::@3191": 0x80378aa0,
		"System::@3192": 0x80378ab4,
		"System::@3193": 0x80378ac8,
		"System::@3194": 0x80378ad8,
		"System::@3195": 0x80378ae8,
		"System::@3218": 0x80378c9c,
		"System::@3219": 0x80378cb0,
		"System::@3220": 0x80378cc4,
		"System::@3221": 0x80378cd8,
		"System::@3222": 0x80378cec,
		"System::@3223": 0x80378d00,
		"System::@3224": 0x80378d14,
		"System::@3225": 0x80378d2c,
		"System::@3226": 0x80378d3c,
		"System::@3227": 0x80378d50,
		"System::@3228": 0x80378d64,
		"System::@3316": 0x803791dc,
		"System::@3317": 0x803791f0,
		"System::@3318": 0x80379204,
		"System::@3319": 0x80379218,
		"System::@3320": 0x80379228,
		"System::@3321": 0x8037923c,
		"System::@3322": 0x80379250,
		"System::@3323": 0x80379268,
		"System::@3324": 0x8037927c,
		"System::@3325": 0x80379294,
		"System::@3326": 0x803792a8,
		"System::@3327": 0x803792bc,
		"System::@3328": 0x803792d0,
		"System::@3329": 0x803792e4,
		"System::@3330": 0x803792f4,
		"System::@3331": 0x80379308,
		"System::@3332": 0x8037931c,
		"System::@3333": 0x80379330,
		"System::@3334": 0x80379344,
		"System::@3335": 0x80379358,
		"System::@3336": 0x80379370,
		"System::@3337": 0x80379388,
		"System::@3338": 0x8037939c,
		"System::@3339": 0x803793b0,
		"System::@3340": 0x803793c4,
		"System::@3341": 0x803793d8,
		"System::@3342": 0x803793e8,
		"System::@3343": 0x803793fc,
		"System::@3344": 0x80379410,
		"System::@3345": 0x80379420,
		"System::@3346": 0x80379430,
		"System::@3347": 0x80379444,
		"System::@3348": 0x80379454,
		"System::@3349": 0x80379468,
		"System::@3350": 0x80379478,
		"System::@3351": 0x8037948c,
		"System::@3352": 0x803794a0,
		"System::@3353": 0x803794b8,
		"System::@3354": 0x803794cc,
		"System::@3355": 0x803794e0,
		"System::@3356": 0x803794f0,
		"System::@3357": 0x80379504,
		"System::@3358": 0x80379518,
		"System::@3359": 0x8037952c,
		"System::@3360": 0x8037953c,
		"System::@3361": 0x80379550,
		"System::@3362": 0x80379564,
		"System::@3363": 0x80379578,
		"System::@3364": 0x80379588,
		"System::@3365": 0x8037959c,
		"System::@3366": 0x803795b0,
		"System::@3367": 0x803795c4,
		"System::@3368": 0x803795d8,
		"System::@3369": 0x803795ec,
		"System::@3370": 0x80379604,
		"System::@3371": 0x8037961c,
		"System::@3372": 0x80379630,
		"System::@3373": 0x80379640,
		"System::@3374": 0x80379654,
		"System::@3375": 0x8037966c,
		"System::@3376": 0x80379680,
		"System::@3377": 0x80379694,
		"System::@3378": 0x803796a8,
		"System::@3379": 0x803796bc,
		"System::@3381": 0x803796e4,
		"System::@3382": 0x803796f4,
		"System::@3383": 0x80379708,
		"System::@3384": 0x8037971c,
		"System::@3385": 0x80379734,
		"System::@3387": 0x8037975c,
		"System::@3388": 0x8037976c,
		"System::@3389": 0x8037977c,
		"System::@3390": 0x80379790,
		"System::@2033": 0x80379830,
		"System::@2034": 0x80379840,
		"System::@2035": 0x80379850,
		"System::@2036": 0x8037985c,
		"System::@2037": 0x8037986c,
		"System::@2038": 0x8037987c,
		"System::@2039": 0x80379890,
		"System::@2040": 0x8037989c,
		"System::@2041": 0x803798ac,
		"System::@2042": 0x803798b8,
		"System::@2043": 0x803798c8,
		"System::@2044": 0x803798d8,
		"System::@2045": 0x803798e4,
		"System::@2046": 0x803798f4,
		"System::@2048": 0x80379914,
		"System::@2049": 0x80379924,
		"System::@2050": 0x80379930,
		"System::@2051": 0x8037993c,
		"System::@2554": 0x80379958,
		"System::@2826": 0x80379978,
		"System::@2827": 0x8037998c,
		"System::@2828": 0x8037999c,
		"System::@2831": 0x803799bc,
		"System::@2832": 0x803799c8,
		"System::@2833": 0x803799d4,
		"System::@2834": 0x803799e4,
		"System::@2883": 0x80379a00,
		"System::@2884": 0x80379a10,
		"System::@2908": 0x80379a1c,
		"System::@1816": 0x80379a28,
		"System::@2110": 0x80379a4c,
		"System::@3796": 0x80379d40,
		"System::@3797": 0x80379d58,
		"System::@3798": 0x80379d70,
		"System::@3799": 0x80379d88,
		"System::@3800": 0x80379d98,
		"System::@3802": 0x80379dc4,
		"System::@3803": 0x80379dd4,
		"System::@3805": 0x80379de4,
		"System::@3806": 0x80379df8,
		"System::@3807": 0x80379e08,
		"System::@3808": 0x80379e1c,
		"System::@3809": 0x80379e2c,
		"System::@1681": 0x80379f20,
		"System::@1708": 0x80379f4c,
		"System::@1709": 0x80379f64,
		"Strategic::@2836": 0x80379f78,
		"Strategic::@2837": 0x80379f88,
		"Strategic::@3117": 0x80379fac,
		"Strategic::@1582": 0x80379ff0,
		"Strategic::@1583": 0x8037a020,
		"Strategic::@1584": 0x8037a058,
		"Strategic::@1585": 0x8037a08c,
		"Strategic::@2725": 0x8037a0b0,
		"Strategic::@2777": 0x8037a0c8,
		"Strategic::@2778": 0x8037a0e8,
		"Strategic::@2148": 0x8037a108,
		"Strategic::@1598": 0x8037a138,
		"Strategic::@1599": 0x8037a168,
		"Strategic::@1600": 0x8037a1a0,
		"Strategic::@1601": 0x8037a1d4,
		"Strategic::@1735": 0x8037a1f8,
		"Strategic::entry$1734": 0x8037a204,
		"entry$1734": 0x8037a204,
		"Strategic::@1948": 0x8037a220,
		"Strategic::@514": 0x8037a230,
		"@514": 0x8037a230,
		"Strategic::@515": 0x8037a24c,
		"@515": 0x8037a24c,
		"Strategic::@559": 0x8037a270,
		"@559": 0x8037a270,
		"Strategic::@560": 0x8037a294,
		"@560": 0x8037a294,
		"Strategic::@561": 0x8037a2bc,
		"@561": 0x8037a2bc,
		"Strategic::@610": 0x8037a2e0,
		"Strategic::@611": 0x8037a304,
		"@611": 0x8037a304,
		"Strategic::@612": 0x8037a334,
		"@612": 0x8037a334,
		"Strategic::@654": 0x8037a35c,
		"Strategic::@655": 0x8037a378,
		"Strategic::@725": 0x8037a398,
		"Strategic::@834": 0x8037a3c8,
		"@834": 0x8037a3c8,
		"Strategic::@915": 0x8037a400,
		"@915": 0x8037a400,
		"Strategic::@916": 0x8037a420,
		"@916": 0x8037a420,
		"Strategic::@917": 0x8037a430,
		"@917": 0x8037a430,
		"Strategic::@918": 0x8037a440,
		"@918": 0x8037a440,
		"Strategic::@919": 0x8037a450,
		"@919": 0x8037a450,
		"Strategic::@920": 0x8037a460,
		"Strategic::@921": 0x8037a470,
		"@921": 0x8037a470,
		"Strategic::@922": 0x8037a484,
		"@922": 0x8037a484,
		"Strategic::@923": 0x8037a49c,
		"@923": 0x8037a49c,
		"Strategic::@924": 0x8037a4b4,
		"@924": 0x8037a4b4,
		"Strategic::@925": 0x8037a4cc,
		"@925": 0x8037a4cc,
		"Strategic::@1000": 0x8037a500,
		"@1000": 0x8037a500,
		"Strategic::@1071": 0x8037a51c,
		"@1071": 0x8037a51c,
		"Strategic::@1072": 0x8037a538,
		"Strategic::@1078": 0x8037a564,
		"@1078": 0x8037a564,
		"Strategic::@2481": 0x8037a584,
		"Strategic::@2541": 0x8037a5a4,
		"Strategic::@2620": 0x8037a5cc,
		"Strategic::@1826": 0x8037a5f0,
		"@1826": 0x8037a5f0,
		"Strategic::@2112": 0x8037a61c,
		"Strategic::@2302": 0x8037a630,
		"Strategic::@2303": 0x8037a660,
		"Strategic::@2304": 0x8037a698,
		"Strategic::@2305": 0x8037a6cc,
		"Strategic::@2579": 0x8037a6f0,
		"Strategic::@2580": 0x8037a6fc,
		"Strategic::@2581": 0x8037a718,
		"Player::@1763": 0x8037a744,
		"Player::@2316": 0x8037a78c,
		"Player::@2479": 0x8037a79c,
		"Player::@2480": 0x8037a7b4,
		"Player::@2481": 0x8037a7cc,
		"Player::@2482": 0x8037a7f4,
		"Player::@2483": 0x8037a810,
		"Player::@2484": 0x8037a820,
		"Player::@2438": 0x8037a830,
		"Player::@1936": 0x8037a87c,
		"Player::@2446": 0x8037a8c0,
		"Player::@2447": 0x8037a8f8,
		"Player::@2448": 0x8037a92c,
		"Player::@2902": 0x8037aa14,
		"Player::@2903": 0x8037aa20,
		"Player::@2904": 0x8037aa2c,
		"Player::@2911": 0x8037aa84,
		"Player::@2912": 0x8037aa90,
		"Player::@2913": 0x8037aa9c,
		"Player::@2915": 0x8037aaa8,
		"Player::@2916": 0x8037aab4,
		"Player::@2919": 0x8037aacc,
		"Player::@2920": 0x8037aad8,
		"Player::@2921": 0x8037aae4,
		"Player::@2922": 0x8037aaf0,
		"Player::@2923": 0x8037aafc,
		"Player::@2924": 0x8037ab0c,
		"Player::@2925": 0x8037ab18,
		"Player::@2926": 0x8037ab28,
		"Player::@2928": 0x8037ab34,
		"Player::@2929": 0x8037ab40,
		"Player::@2931": 0x8037ab5c,
		"Player::@2932": 0x8037ab6c,
		"Player::@2933": 0x8037ab78,
		"Player::@2934": 0x8037ab88,
		"Player::@2935": 0x8037ab94,
		"Player::@2936": 0x8037aba4,
		"Player::@2937": 0x8037abb4,
		"Player::@2940": 0x8037abe0,
		"Player::@2941": 0x8037abf4,
		"Player::@2944": 0x8037ac28,
		"Player::@2945": 0x8037ac34,
		"Player::@2946": 0x8037ac40,
		"Player::@2950": 0x8037ac6c,
		"Player::@2960": 0x8037ace8,
		"Player::@2961": 0x8037acf8,
		"Player::@2962": 0x8037ad08,
		"Player::@3342": 0x8037b2b4,
		"Player::@5182": 0x8037b2c0,
		"Player::@5183": 0x8037b2cc,
		"Player::@5184": 0x8037b2dc,
		"Player::@5660": 0x8037b2ec,
		"Player::@5662": 0x8037b304,
		"@5662": 0x8037b304,
		"Player::@5663": 0x8037b310,
		"@5663": 0x8037b310,
		"Player::@5665": 0x8037b328,
		"Player::@5666": 0x8037b334,
		"Player::@5667": 0x8037b340,
		"Player::@5668": 0x8037b34c,
		"Player::@5669": 0x8037b358,
		"Player::@5670": 0x8037b364,
		"Player::@5671": 0x8037b370,
		"@5671": 0x8037b370,
		"Player::@5672": 0x8037b37c,
		"@5672": 0x8037b37c,
		"Player::@5674": 0x8037b388,
		"@5674": 0x8037b388,
		"Player::@5675": 0x8037b3a0,
		"@5675": 0x8037b3a0,
		"Player::@5676": 0x8037b3b8,
		"Player::@5677": 0x8037b3d0,
		"@5677": 0x8037b3d0,
		"Player::@5678": 0x8037b3e8,
		"@5678": 0x8037b3e8,
		"Player::@5679": 0x8037b400,
		"Player::@5681": 0x8037b430,
		"@5681": 0x8037b430,
		"Player::@5682": 0x8037b43c,
		"Player::@5683": 0x8037b448,
		"Player::@5684": 0x8037b460,
		"@5684": 0x8037b460,
		"Player::@5685": 0x8037b484,
		"@5685": 0x8037b484,
		"Player::@5686": 0x8037b4a0,
		"@5686": 0x8037b4a0,
		"Player::@5687": 0x8037b4cc,
		"@5687": 0x8037b4cc,
		"Player::@5688": 0x8037b4e8,
		"@5688": 0x8037b4e8,
		"Player::@4045": 0x8037b518,
		"Player::@2566": 0x8037b6c4,
		"Player::@2567": 0x8037b6fc,
		"Player::@2568": 0x8037b730,
		"Player::@2659": 0x8037b754,
		"Player::@2660": 0x8037b77c,
		"Player::@2661": 0x8037b7a4,
		"Player::cParticleIDs": 0x8037b7cc,
		"cParticleIDs": 0x8037b7cc,
		"Player::warpInEffectIDs": 0x8037b7d8,
		"warpInEffectIDs": 0x8037b7d8,
		"Player::@1937": 0x8037b824,
		"Player::@2386": 0x8037b8e4,
		"Player::@2442": 0x8037b8f8,
		"Player::@2443": 0x8037b928,
		"Player::@2444": 0x8037b960,
		"Player::@2694": 0x8037b9ec,
		"Player::@2696": 0x8037b9f8,
		"Player::@2746": 0x8037bab0,
		"Player::@2747": 0x8037bacc,
		"Player::@2748": 0x8037baf4,
		"Player::@2750": 0x8037bb38,
		"Player::@2751": 0x8037bb54,
		"Player::@3694": 0x8037bb7c,
		"Player::@3695": 0x8037bb88,
		"Player::@3696": 0x8037bb94,
		"Player::@3698": 0x8037bba0,
		"Player::@4027": 0x8037bbac,
		"Player::@4028": 0x8037bbc0,
		"Player::@4030": 0x8037bbd0,
		"Player::@4032": 0x8037bbe0,
		"Player::@4035": 0x8037bc04,
		"Player::@4037": 0x8037bc18,
		"Player::@4039": 0x8037bc40,
		"Player::@4041": 0x8037bc50,
		"Player::@4052": 0x8037bc60,
		"Player::@4053": 0x8037bc78,
		"Player::@4359": 0x8037bc9c,
		"Player::@4360": 0x8037bcb0,
		"Player::@4361": 0x8037bcc0,
		"Player::@4362": 0x8037bcd0,
		"Player::@4363": 0x8037bce0,
		"Player::@4364": 0x8037bcf8,
		"Player::@4365": 0x8037bd08,
		"Player::@4367": 0x8037bd28,
		"Player::@4369": 0x8037bd48,
		"Player::@4370": 0x8037bd58,
		"Player::@4371": 0x8037bd70,
		"Player::@4372": 0x8037bd88,
		"Player::@4416": 0x8037bd94,
		"Player::@4417": 0x8037bda0,
		"Player::@4420": 0x8037be10,
		"Player::@4421": 0x8037be1c,
		"Player::@4422": 0x8037be40,
		"Player::@4423": 0x8037be4c,
		"Player::@4424": 0x8037be74,
		"Player::@5867": 0x8037bebc,
		"Player::@5870": 0x8037bec8,
		"Player::@5872": 0x8037bed4,
		"Player::@5874": 0x8037bee0,
		"Player::@5875": 0x8037beec,
		"Player::@5877": 0x8037bef8,
		"Player::@5879": 0x8037bf08,
		"Player::@5880": 0x8037bf14,
		"Player::@5881": 0x8037bf24,
		"Player::@5882": 0x8037bf30,
		"@5882": 0x8037bf30,
		"Player::@5883": 0x8037bf3c,
		"@5883": 0x8037bf3c,
		"Player::@5884": 0x8037bf4c,
		"@5884": 0x8037bf4c,
		"Player::@5885": 0x8037bf58,
		"@5885": 0x8037bf58,
		"Player::@5886": 0x8037bf64,
		"@5886": 0x8037bf64,
		"Player::@5890": 0x8037bf7c,
		"@5890": 0x8037bf7c,
		"Player::@5891": 0x8037bf88,
		"@5891": 0x8037bf88,
		"Player::@5892": 0x8037bf98,
		"@5892": 0x8037bf98,
		"Player::@5893": 0x8037bfa4,
		"Player::@5894": 0x8037bfb0,
		"Player::@5895": 0x8037bfc0,
		"Player::@5896": 0x8037bfd4,
		"Player::@5898": 0x8037bfe8,
		"Player::@5899": 0x8037bff4,
		"Player::@5900": 0x8037c004,
		"@5900": 0x8037c004,
		"Player::@5901": 0x8037c010,
		"@5901": 0x8037c010,
		"Player::@5902": 0x8037c01c,
		"@5902": 0x8037c01c,
		"Player::@5904": 0x8037c02c,
		"@5904": 0x8037c02c,
		"Player::@5906": 0x8037c03c,
		"Player::@5907": 0x8037c04c,
		"@5907": 0x8037c04c,
		"Player::@5909": 0x8037c060,
		"Player::@5911": 0x8037c074,
		"Player::@5913": 0x8037c084,
		"Player::@5914": 0x8037c098,
		"Player::@5915": 0x8037c0ac,
		"Player::@5916": 0x8037c0c0,
		"Player::@5918": 0x8037c0d0,
		"Player::@2228": 0x8037c100,
		"Player::@2229": 0x8037c130,
		"Player::@2230": 0x8037c168,
		"Player::@2231": 0x8037c19c,
		"Player::bodyColor": 0x8037c1f4,
		"bodyColor": 0x8037c1f4,
		"Player::@4888": 0x8037c224,
		"@4888": 0x8037c224,
		"Player::@4889": 0x8037c23c,
		"Player::@4890": 0x8037c248,
		"Player::@4891": 0x8037c254,
		"Player::@4893": 0x8037c260,
		"Player::@4894": 0x8037c27c,
		"Player::@4895": 0x8037c298,
		"Player::@4896": 0x8037c2b0,
		"Player::@4897": 0x8037c2cc,
		"Player::@4912": 0x8037c328,
		"Player::@4913": 0x8037c34c,
		"Player::@4914": 0x8037c368,
		"Player::@4915": 0x8037c388,
		"Player::@4916": 0x8037c3a4,
		"Player::@4917": 0x8037c3c4,
		"Player::@4918": 0x8037c3e4,
		"Player::@4919": 0x8037c404,
		"Player::@4920": 0x8037c420,
		"Player::@4921": 0x8037c440,
		"Player::@4922": 0x8037c45c,
		"Player::@4923": 0x8037c478,
		"Player::@4924": 0x8037c494,
		"Player::@4925": 0x8037c4b4,
		"Player::@4926": 0x8037c4d4,
		"Player::@4927": 0x8037c4f4,
		"Player::@4928": 0x8037c510,
		"Player::@4929": 0x8037c530,
		"Player::@4930": 0x8037c54c,
		"Player::@2302": 0x8037c590,
		"Player::@2303": 0x8037c5c0,
		"Player::@2304": 0x8037c5f8,
		"Player::@2305": 0x8037c62c,
		"Player::@2367": 0x8037c74c,
		"Player::@2561": 0x8037c824,
		"Player::@2563": 0x8037c834,
		"Player::@2590": 0x8037c854,
		"Player::@2591": 0x8037c860,
		"Player::@2593": 0x8037c86c,
		"Player::@2597": 0x8037c878,
		"Player::@2616": 0x8037c888,
		"Player::@2618": 0x8037c894,
		"Player::@2620": 0x8037c8a4,
		"Player::@2622": 0x8037c8b0,
		"Player::@2635": 0x8037c8bc,
		"Player::@2722": 0x8037c8d4,
		"Player::@2725": 0x8037c8f0,
		"Player::@3140": 0x8037cf54,
		"Player::@3142": 0x8037cf80,
		"Player::@3146": 0x8037cfd4,
		"Player::@3147": 0x8037cfe8,
		"Player::@3149": 0x8037cff4,
		"Player::@3151": 0x8037d008,
		"Player::@3245": 0x8037d16c,
		"Player::@3247": 0x8037d178,
		"Player::@3322": 0x8037d1e8,
		"Player::@3324": 0x8037d204,
		"Player::@3326": 0x8037d22c,
		"Player::@3327": 0x8037d240,
		"Player::@3328": 0x8037d250,
		"Player::@3329": 0x8037d25c,
		"Player::@3330": 0x8037d268,
		"Player::@3336": 0x8037d2a4,
		"Player::@3337": 0x8037d2bc,
		"Player::@3338": 0x8037d2cc,
		"Player::@3375": 0x8037d360,
		"Player::@3468": 0x8037d394,
		"Player::@3469": 0x8037d3a8,
		"Player::@3470": 0x8037d3bc,
		"Player::@3472": 0x8037d3e4,
		"Player::@3477": 0x8037d430,
		"Player::@3481": 0x8037d45c,
		"Player::@3483": 0x8037d478,
		"Player::@3486": 0x8037d494,
		"Player::@3487": 0x8037d4ac,
		"Player::@3488": 0x8037d4b8,
		"Player::@3489": 0x8037d4c8,
		"Player::@3490": 0x8037d4d8,
		"Player::@3492": 0x8037d4e8,
		"Player::@3559": 0x8037d4f4,
		"Player::@3560": 0x8037d504,
		"Player::@3568": 0x8037d548,
		"Player::@3569": 0x8037d554,
		"Player::@3570": 0x8037d560,
		"Player::@3572": 0x8037d574,
		"Player::@3573": 0x8037d588,
		"Player::@3575": 0x8037d59c,
		"Player::@3577": 0x8037d5bc,
		"Player::@3578": 0x8037d5c8,
		"Player::@3579": 0x8037d5d8,
		"Player::@3581": 0x8037d5ec,
		"Player::@3582": 0x8037d5fc,
		"Player::@3583": 0x8037d610,
		"Player::@3584": 0x8037d620,
		"Player::@3585": 0x8037d62c,
		"Player::@3736": 0x8037d6cc,
		"Player::@3737": 0x8037d6e0,
		"Player::@3739": 0x8037d704,
		"Player::@3748": 0x8037d784,
		"Player::@3752": 0x8037d7c4,
		"Player::@3753": 0x8037d7d8,
		"Player::@3755": 0x8037d800,
		"Player::@3756": 0x8037d810,
		"Player::@3761": 0x8037d858,
		"Player::@3762": 0x8037d86c,
		"Player::@3764": 0x8037d87c,
		"Player::@3765": 0x8037d890,
		"Player::@3768": 0x8037d8b4,
		"Player::@3769": 0x8037d8c4,
		"Player::@3770": 0x8037d8d4,
		"Player::@3771": 0x8037d8e4,
		"Player::@3772": 0x8037d8f4,
		"Player::@3774": 0x8037d914,
		"Player::@3775": 0x8037d924,
		"Player::@3776": 0x8037d938,
		"Player::@3808": 0x8037d95c,
		"Player::@3971": 0x8037d968,
		"Player::@3973": 0x8037d97c,
		"Player::@3975": 0x8037d988,
		"Player::@3976": 0x8037d994,
		"Player::@3977": 0x8037d9a0,
		"Player::@3978": 0x8037d9ac,
		"Player::@3979": 0x8037d9bc,
		"Player::@3980": 0x8037d9cc,
		"Player::@3984": 0x8037da18,
		"Player::@3985": 0x8037da2c,
		"Player::@3986": 0x8037da40,
		"Player::@3987": 0x8037da4c,
		"Player::@3991": 0x8037da84,
		"Player::@3993": 0x8037da94,
		"Player::@3994": 0x8037daa4,
		"Player::@3995": 0x8037dab4,
		"Player::@3996": 0x8037dac4,
		"Player::@3997": 0x8037dad4,
		"Player::@3999": 0x8037dae4,
		"Player::@4001": 0x8037db04,
		"Player::@4002": 0x8037db18,
		"Player::@4003": 0x8037db2c,
		"Player::@4008": 0x8037db68,
		"Player::@4010": 0x8037db78,
		"Player::@4011": 0x8037db88,
		"Player::@4012": 0x8037db98,
		"Player::@4016": 0x8037dbd4,
		"Player::@4017": 0x8037dbe4,
		"Player::@4018": 0x8037dbfc,
		"Player::@4019": 0x8037dc08,
		"Player::@4020": 0x8037dc18,
		"Player::@4021": 0x8037dc28,
		"Player::@4022": 0x8037dc40,
		"Player::@4023": 0x8037dc54,
		"Player::@4024": 0x8037dc6c,
		"Player::@4025": 0x8037dc80,
		"Player::@4081": 0x8037dc94,
		"Player::@4082": 0x8037dcb0,
		"Player::@4083": 0x8037dcc8,
		"Player::@6516": 0x8037dcdc,
		"@6516": 0x8037dcdc,
		"Player::@6517": 0x8037dce8,
		"@6517": 0x8037dce8,
		"Player::@6518": 0x8037dd04,
		"Player::@6519": 0x8037dd24,
		"Player::@6520": 0x8037dd40,
		"Player::@6521": 0x8037dd5c,
		"Player::@6522": 0x8037dd78,
		"Player::@6523": 0x8037dd98,
		"Player::@6524": 0x8037ddc4,
		"Player::@6525": 0x8037dde8,
		"@6525": 0x8037dde8,
		"Player::@6526": 0x8037de04,
		"@6526": 0x8037de04,
		"Player::@6527": 0x8037de20,
		"@6527": 0x8037de20,
		"Player::@6528": 0x8037de40,
		"@6528": 0x8037de40,
		"Player::@6529": 0x8037de60,
		"@6529": 0x8037de60,
		"Player::@6530": 0x8037de80,
		"@6530": 0x8037de80,
		"Player::@6531": 0x8037dea0,
		"@6531": 0x8037dea0,
		"Player::@6532": 0x8037deb4,
		"@6532": 0x8037deb4,
		"Player::@6533": 0x8037dec8,
		"@6533": 0x8037dec8,
		"Player::@6534": 0x8037dee4,
		"@6534": 0x8037dee4,
		"Player::@6535": 0x8037defc,
		"@6535": 0x8037defc,
		"Player::@6536": 0x8037df14,
		"@6536": 0x8037df14,
		"Player::@6537": 0x8037df34,
		"@6537": 0x8037df34,
		"Player::@6538": 0x8037df4c,
		"@6538": 0x8037df4c,
		"Player::@6539": 0x8037df6c,
		"@6539": 0x8037df6c,
		"Player::@6540": 0x8037df8c,
		"@6540": 0x8037df8c,
		"Player::@6541": 0x8037dfa8,
		"@6541": 0x8037dfa8,
		"Player::@6542": 0x8037dfc0,
		"@6542": 0x8037dfc0,
		"Player::@6543": 0x8037dfdc,
		"@6543": 0x8037dfdc,
		"Player::@6544": 0x8037dff4,
		"@6544": 0x8037dff4,
		"Player::@6545": 0x8037e00c,
		"@6545": 0x8037e00c,
		"Player::@6546": 0x8037e024,
		"@6546": 0x8037e024,
		"Player::@6547": 0x8037e038,
		"@6547": 0x8037e038,
		"Player::@6548": 0x8037e054,
		"Player::@6549": 0x8037e06c,
		"Player::@6550": 0x8037e088,
		"Player::@6551": 0x8037e0a0,
		"@6551": 0x8037e0a0,
		"Player::@6552": 0x8037e0b8,
		"Player::@6553": 0x8037e0d4,
		"Player::@6554": 0x8037e0f0,
		"Player::@6555": 0x8037e10c,
		"Player::@6556": 0x8037e128,
		"@6556": 0x8037e128,
		"Player::@6557": 0x8037e144,
		"Player::@6558": 0x8037e164,
		"Player::@6559": 0x8037e180,
		"Player::@6560": 0x8037e19c,
		"Player::@6561": 0x8037e1c0,
		"@6561": 0x8037e1c0,
		"Player::@6562": 0x8037e1d8,
		"@6562": 0x8037e1d8,
		"Player::@6563": 0x8037e1f0,
		"@6563": 0x8037e1f0,
		"Player::@6564": 0x8037e208,
		"@6564": 0x8037e208,
		"Player::@6565": 0x8037e220,
		"@6565": 0x8037e220,
		"Player::@6566": 0x8037e238,
		"@6566": 0x8037e238,
		"Player::@6567": 0x8037e250,
		"@6567": 0x8037e250,
		"Player::@2239": 0x8037e2d4,
		"Player::@2297": 0x8037e350,
		"Player::@2298": 0x8037e384,
		"Player::@2665": 0x8037e3a8,
		"Player::@2666": 0x8037e3c0,
		"Player::@2667": 0x8037e3d8,
		"Player::@2668": 0x8037e3f0,
		"Player::@2669": 0x8037e40c,
		"Player::@2670": 0x8037e424,
		"Player::@2671": 0x8037e43c,
		"Player::@2672": 0x8037e454,
		"Player::@2673": 0x8037e46c,
		"Player::@2674": 0x8037e484,
		"Player::@2675": 0x8037e4a0,
		"Player::@2676": 0x8037e4b8,
		"Player::@2677": 0x8037e4d4,
		"Player::@2678": 0x8037e4f0,
		"Player::@2679": 0x8037e508,
		"Player::@2680": 0x8037e520,
		"Player::@2681": 0x8037e538,
		"Player::@3162": 0x8037e554,
		"Player::@4560": 0x8037e560,
		"Player::@4628": 0x8037e578,
		"Player::@4630": 0x8037e5b0,
		"Player::@4635": 0x8037e650,
		"Player::@4636": 0x8037e674,
		"Player::@4645": 0x8037e698,
		"Player::@4646": 0x8037e6a4,
		"Player::@4647": 0x8037e6b0,
		"Player::@4649": 0x8037e6bc,
		"Player::@4736": 0x8037e6c8,
		"Player::@4738": 0x8037e6d4,
		"Player::@4741": 0x8037e6e0,
		"Player::@4742": 0x8037e6f0,
		"Player::@4743": 0x8037e6fc,
		"Player::@4746": 0x8037e708,
		"Player::@4876": 0x8037e714,
		"Player::@4271": 0x8037e720,
		"NPC::@2255": 0x8037e750,
		"NPC::@2256": 0x8037e780,
		"NPC::@2257": 0x8037e7b8,
		"NPC::@2258": 0x8037e7ec,
		"NPC::@2440": 0x8037e810,
		"NPC::sIndividualPeachBck$2896": 0x8037e820,
		"sIndividualPeachBck$2896": 0x8037e820,
		"NPC::sIndividualPeachBtp$2897": 0x8037e838,
		"sIndividualPeachBtp$2897": 0x8037e838,
		"NPC::sIndividualPeachBck$2904": 0x8037e848,
		"sIndividualPeachBck$2904": 0x8037e848,
		"NPC::sIndividualPeachBtp$2905": 0x8037e858,
		"sIndividualPeachBtp$2905": 0x8037e858,
		"NPC::sIndividualSunflowerBck$2906": 0x8037e868,
		"sIndividualSunflowerBck$2906": 0x8037e868,
		"NPC::sIndividualSunflowerBtp$2907": 0x8037e880,
		"sIndividualSunflowerBtp$2907": 0x8037e880,
		"NPC::@2053": 0x8037e954,
		"NPC::entry$2229": 0x8037eb28,
		"entry$2229": 0x8037eb28,
		"NPC::@2236": 0x8037eb80,
		"NPC::@2237": 0x8037eb90,
		"NPC::entry$2231": 0x8037eba0,
		"entry$2231": 0x8037eba0,
		"NPC::entry$2335": 0x8037ec04,
		"entry$2335": 0x8037ec04,
		"NPC::entry$2337": 0x8037ec2c,
		"entry$2337": 0x8037ec2c,
		"NPC::entry$2339": 0x8037ec54,
		"entry$2339": 0x8037ec54,
		"NPC::entry$2341": 0x8037ec7c,
		"entry$2341": 0x8037ec7c,
		"NPC::entry$2343": 0x8037eca4,
		"entry$2343": 0x8037eca4,
		"NPC::entry$2345": 0x8037eccc,
		"entry$2345": 0x8037eccc,
		"NPC::entry$2347": 0x8037ece4,
		"entry$2347": 0x8037ece4,
		"NPC::entry$2348": 0x8037ecfc,
		"entry$2348": 0x8037ecfc,
		"NPC::entry$2349": 0x8037ed14,
		"entry$2349": 0x8037ed14,
		"NPC::entry$2350": 0x8037ed3c,
		"entry$2350": 0x8037ed3c,
		"NPC::entry$2352": 0x8037ed64,
		"entry$2352": 0x8037ed64,
		"NPC::entry$2354": 0x8037ed8c,
		"entry$2354": 0x8037ed8c,
		"NPC::entry$2356": 0x8037eda4,
		"entry$2356": 0x8037eda4,
		"NPC::entry$2357": 0x8037edc8,
		"entry$2357": 0x8037edc8,
		"NPC::entry$2359": 0x8037edec,
		"entry$2359": 0x8037edec,
		"NPC::entry$2361": 0x8037ee18,
		"entry$2361": 0x8037ee18,
		"NPC::entry$2363": 0x8037ee40,
		"entry$2363": 0x8037ee40,
		"NPC::entry$2365": 0x8037ee68,
		"entry$2365": 0x8037ee68,
		"NPC::entry$2367": 0x8037ee8c,
		"entry$2367": 0x8037ee8c,
		"NPC::entry$2369": 0x8037eeb4,
		"entry$2369": 0x8037eeb4,
		"NPC::entry$2371": 0x8037eedc,
		"entry$2371": 0x8037eedc,
		"NPC::@2416": 0x8037eef4,
		"NPC::@2459": 0x8037ef04,
		"NPC::@2467": 0x8037ef14,
		"NPC::@2475": 0x8037ef24,
		"NPC::@1968": 0x8037f0a4,
		"NPC::@1969": 0x8037f0b8,
		"NPC::@1973": 0x8037f108,
		"NPC::@1974": 0x8037f11c,
		"NPC::@1978": 0x8037f16c,
		"NPC::@1979": 0x8037f180,
		"NPC::@1982": 0x8037f1c8,
		"NPC::@1983": 0x8037f1dc,
		"NPC::@2160": 0x8037f1f0,
		"NPC::@2162": 0x8037f200,
		"NPC::@2164": 0x8037f210,
		"NPC::@2166": 0x8037f220,
		"NPC::@2168": 0x8037f234,
		"NPC::@2170": 0x8037f24c,
		"NPC::@2172": 0x8037f260,
		"NPC::@2174": 0x8037f274,
		"NPC::@2176": 0x8037f288,
		"NPC::@2178": 0x8037f29c,
		"NPC::@2179": 0x8037f2ac,
		"NPC::@2181": 0x8037f2bc,
		"NPC::@2183": 0x8037f2c8,
		"NPC::@2185": 0x8037f2d4,
		"NPC::@2186": 0x8037f2e4,
		"NPC::@2188": 0x8037f2f4,
		"NPC::@2190": 0x8037f304,
		"NPC::@2191": 0x8037f314,
		"NPC::@2192": 0x8037f324,
		"NPC::@2193": 0x8037f334,
		"NPC::@2195": 0x8037f348,
		"NPC::@2203": 0x8037f390,
		"NPC::@2205": 0x8037f3a8,
		"NPC::@2209": 0x8037f3d4,
		"NPC::@2228": 0x8037f498,
		"NPC::@2229": 0x8037f4a8,
		"NPC::@2231": 0x8037f4c0,
		"NPC::@2334": 0x8037f518,
		"NPC::@2335": 0x8037f52c,
		"NPC::@2337": 0x8037f548,
		"NPC::@2339": 0x8037f56c,
		"NPC::@2343": 0x8037f5b0,
		"NPC::@2345": 0x8037f5e4,
		"NPC::@2357": 0x8037f6b4,
		"NPC::@2359": 0x8037f6cc,
		"NPC::@2361": 0x8037f6f8,
		"NPC::@2363": 0x8037f70c,
		"NPC::@2365": 0x8037f71c,
		"NPC::@2367": 0x8037f72c,
		"NPC::@2369": 0x8037f758,
		"NPC::@2371": 0x8037f788,
		"NPC::@2373": 0x8037f7b4,
		"NPC::@2417": 0x8037f7d8,
		"NPC::@2418": 0x8037f7ec,
		"NPC::@2420": 0x8037f7fc,
		"NPC::@2421": 0x8037f810,
		"NPC::@2422": 0x8037f824,
		"NPC::@2423": 0x8037f838,
		"NPC::@2424": 0x8037f84c,
		"NPC::@2426": 0x8037f874,
		"NPC::@2427": 0x8037f888,
		"NPC::@2431": 0x8037f8dc,
		"NPC::@2627": 0x8037f9d0,
		"NPC::@2628": 0x8037f9e0,
		"NPC::@2629": 0x8037f9f0,
		"NPC::@2630": 0x8037fa00,
		"NPC::@2680": 0x8037fa20,
		"NPC::@2683": 0x8037fa2c,
		"NPC::@2684": 0x8037fa40,
		"NPC::@2721": 0x8037fa58,
		"NPC::@2722": 0x8037fa74,
		"NPC::@2723": 0x8037fa88,
		"NPC::@2724": 0x8037faa0,
		"NPC::@2734": 0x8037fb68,
		"NPC::@2735": 0x8037fb78,
		"NPC::@2736": 0x8037fb84,
		"NPC::@2737": 0x8037fb94,
		"NPC::@2775": 0x8037fbc4,
		"NPC::@2776": 0x8037fbe4,
		"NPC::@2777": 0x8037fbf0,
		"NPC::@3130": 0x8037fc0c,
		"NPC::@1530": 0x8037fc40,
		"@1530": 0x8037fc40,
		"NPC::@1535": 0x8037fc50,
		"NPC::@1536": 0x8037fc74,
		"NPC::sMonteM_HatAColorBuf0": 0x8037fc88,
		"sMonteM_HatAColorBuf0": 0x8037fc88,
		"NPC::sMonteM_HatAColorBuf1": 0x8037fcc0,
		"sMonteM_HatAColorBuf1": 0x8037fcc0,
		"NPC::@1537": 0x8037fcf8,
		"NPC::sMonteM_HatAColorChange": 0x8037fd04,
		"sMonteM_HatAColorChange": 0x8037fd04,
		"NPC::sMonteM_HatABeltColorBuf": 0x8037fd14,
		"sMonteM_HatABeltColorBuf": 0x8037fd14,
		"NPC::@1538": 0x8037fd4c,
		"NPC::sMonteM_HatABeltColorChange": 0x8037fd58,
		"sMonteM_HatABeltColorChange": 0x8037fd58,
		"NPC::@1540": 0x8037fd68,
		"NPC::sMonteM_HatAData": 0x8037fd78,
		"sMonteM_HatAData": 0x8037fd78,
		"NPC::sMonteM_HatBColorBuf": 0x8037fda4,
		"sMonteM_HatBColorBuf": 0x8037fda4,
		"NPC::sMonteM_HatBColorChange": 0x8037fdbc,
		"sMonteM_HatBColorChange": 0x8037fdbc,
		"NPC::sMonteM_HatBBeltColorBuf": 0x8037fdcc,
		"sMonteM_HatBBeltColorBuf": 0x8037fdcc,
		"NPC::sMonteM_HatBBeltColorChange": 0x8037fde4,
		"sMonteM_HatBBeltColorChange": 0x8037fde4,
		"NPC::@1541": 0x8037fdf4,
		"NPC::sMonteM_HatBData": 0x8037fe04,
		"sMonteM_HatBData": 0x8037fe04,
		"NPC::sMonteM_HatDColorBuf": 0x8037fe30,
		"sMonteM_HatDColorBuf": 0x8037fe30,
		"NPC::sMonteM_HatDColorChange": 0x8037fe40,
		"sMonteM_HatDColorChange": 0x8037fe40,
		"NPC::@1542": 0x8037fe50,
		"NPC::sMonteM_HatDData": 0x8037fe60,
		"sMonteM_HatDData": 0x8037fe60,
		"NPC::sMonteM_HatEColorBuf0": 0x8037fe8c,
		"sMonteM_HatEColorBuf0": 0x8037fe8c,
		"NPC::sMonteM_HatEColorBuf1": 0x8037fe9c,
		"sMonteM_HatEColorBuf1": 0x8037fe9c,
		"NPC::sMonteM_HatEColorChange": 0x8037feac,
		"sMonteM_HatEColorChange": 0x8037feac,
		"NPC::@1543": 0x8037febc,
		"NPC::sMonteM_HatEData": 0x8037fecc,
		"sMonteM_HatEData": 0x8037fecc,
		"NPC::sMonteM_HatFColorBuf0": 0x8037fef8,
		"sMonteM_HatFColorBuf0": 0x8037fef8,
		"NPC::sMonteM_HatFColorBuf1": 0x8037ff08,
		"sMonteM_HatFColorBuf1": 0x8037ff08,
		"NPC::sMonteM_HatFColorChange": 0x8037ff18,
		"sMonteM_HatFColorChange": 0x8037ff18,
		"NPC::@1544": 0x8037ff28,
		"NPC::sMonteM_HatFData": 0x8037ff38,
		"sMonteM_HatFData": 0x8037ff38,
		"NPC::sMonteM_HatGColorBuf0": 0x8037ff64,
		"sMonteM_HatGColorBuf0": 0x8037ff64,
		"NPC::sMonteM_HatGColorBuf1": 0x8037ff8c,
		"sMonteM_HatGColorBuf1": 0x8037ff8c,
		"NPC::sMonteM_HatGColorChange": 0x8037ffb4,
		"sMonteM_HatGColorChange": 0x8037ffb4,
		"NPC::@1545": 0x8037ffc4,
		"NPC::sMonteM_HatGData": 0x8037ffd4,
		"sMonteM_HatGData": 0x8037ffd4,
		"NPC::sMonteM_MustacheAColorBuf0": 0x80380000,
		"sMonteM_MustacheAColorBuf0": 0x80380000,
		"NPC::@1546": 0x80380020,
		"NPC::sMonteM_MustacheAColorChange": 0x8038002c,
		"sMonteM_MustacheAColorChange": 0x8038002c,
		"NPC::@1547": 0x8038003c,
		"NPC::sMonteM_MustacheAData": 0x8038004c,
		"sMonteM_MustacheAData": 0x8038004c,
		"NPC::@1548": 0x80380078,
		"NPC::sMonteM_GlassesAData": 0x8038008c,
		"sMonteM_GlassesAData": 0x8038008c,
		"NPC::sMonteM_GlassesBColorBuf0": 0x803800b8,
		"sMonteM_GlassesBColorBuf0": 0x803800b8,
		"NPC::@1549": 0x803800d0,
		"NPC::sMonteM_GlassesBColorChange": 0x803800dc,
		"sMonteM_GlassesBColorChange": 0x803800dc,
		"NPC::@1550": 0x803800ec,
		"NPC::sMonteM_GlassesBData": 0x80380100,
		"sMonteM_GlassesBData": 0x80380100,
		"NPC::sMonteM_LapelAColorBuf0": 0x8038012c,
		"sMonteM_LapelAColorBuf0": 0x8038012c,
		"NPC::sMonteM_LapelAColorBuf1": 0x8038013c,
		"sMonteM_LapelAColorBuf1": 0x8038013c,
		"NPC::@1551": 0x8038014c,
		"NPC::sMonteM_LapelAColorChange": 0x80380158,
		"sMonteM_LapelAColorChange": 0x80380158,
		"NPC::@1552": 0x80380168,
		"NPC::@1553": 0x80380174,
		"NPC::sMonteM_LapelAData": 0x80380184,
		"sMonteM_LapelAData": 0x80380184,
		"NPC::@1554": 0x803801b0,
		"NPC::sMonteM_TieBColorChange": 0x803801bc,
		"sMonteM_TieBColorChange": 0x803801bc,
		"NPC::@1555": 0x803801cc,
		"NPC::sMonteM_TieBData": 0x803801dc,
		"sMonteM_TieBData": 0x803801dc,
		"NPC::@1556": 0x80380208,
		"NPC::sMonteM_LuggageData": 0x8038021c,
		"sMonteM_LuggageData": 0x8038021c,
		"NPC::@1557": 0x80380248,
		"NPC::sMonteMF_TubeData": 0x80380258,
		"sMonteMF_TubeData": 0x80380258,
		"NPC::@1558": 0x80380284,
		"NPC::@1559": 0x80380290,
		"NPC::sMonteMG_MopData": 0x803802a0,
		"sMonteMG_MopData": 0x803802a0,
		"NPC::@1560": 0x803802cc,
		"NPC::sMonteMH_UkleleData": 0x803802e0,
		"sMonteMH_UkleleData": 0x803802e0,
		"NPC::sMonteW_FlowerInColorBuf": 0x8038030c,
		"sMonteW_FlowerInColorBuf": 0x8038030c,
		"NPC::@1561": 0x80380324,
		"NPC::sMonteW_FlowerInColorChange": 0x80380330,
		"sMonteW_FlowerInColorChange": 0x80380330,
		"NPC::sMonteW_FlowerOutColorBuf": 0x80380340,
		"sMonteW_FlowerOutColorBuf": 0x80380340,
		"NPC::@1562": 0x80380358,
		"NPC::sMonteW_FlowerOutColorChange": 0x80380364,
		"sMonteW_FlowerOutColorChange": 0x80380364,
		"NPC::@1563": 0x80380374,
		"NPC::@1564": 0x80380380,
		"NPC::sMonteW_FlowerData": 0x80380394,
		"sMonteW_FlowerData": 0x80380394,
		"NPC::sMonteW_HatAMainColorBuf0": 0x803803c0,
		"sMonteW_HatAMainColorBuf0": 0x803803c0,
		"NPC::sMonteW_HatAMainColorBuf1": 0x803803e0,
		"sMonteW_HatAMainColorBuf1": 0x803803e0,
		"NPC::sMonteW_HatAMainColorChange": 0x80380400,
		"sMonteW_HatAMainColorChange": 0x80380400,
		"NPC::sMonteW_HatABeltColorBuf": 0x80380410,
		"sMonteW_HatABeltColorBuf": 0x80380410,
		"NPC::sMonteW_HatABeltColorChange": 0x80380430,
		"sMonteW_HatABeltColorChange": 0x80380430,
		"NPC::@1565": 0x80380440,
		"NPC::sMonteW_HatAData": 0x80380450,
		"sMonteW_HatAData": 0x80380450,
		"NPC::sMonteW_GlassBColorBuf": 0x8038047c,
		"sMonteW_GlassBColorBuf": 0x8038047c,
		"NPC::sMonteW_GlassBColorChange": 0x80380494,
		"sMonteW_GlassBColorChange": 0x80380494,
		"NPC::@1566": 0x803804a4,
		"NPC::sMonteW_GlassBData": 0x803804b4,
		"sMonteW_GlassBData": 0x803804b4,
		"NPC::@1567": 0x803804e0,
		"NPC::sMonteW_ArrowRData": 0x803804f4,
		"sMonteW_ArrowRData": 0x803804f4,
		"NPC::@1568": 0x80380520,
		"NPC::sMonteW_ArrowLData": 0x80380534,
		"sMonteW_ArrowLData": 0x80380534,
		"NPC::@1569": 0x80380560,
		"NPC::sMonteWC_HatCData": 0x80380570,
		"sMonteWC_HatCData": 0x80380570,
		"NPC::@1570": 0x8038059c,
		"NPC::sMonteWC_BraceletRData": 0x803805b0,
		"sMonteWC_BraceletRData": 0x803805b0,
		"NPC::@1571": 0x803805dc,
		"NPC::@1572": 0x803805e8,
		"NPC::sMonteWC_BraceletLData": 0x803805fc,
		"sMonteWC_BraceletLData": 0x803805fc,
		"NPC::sMareM_HatAColorBuf0": 0x80380628,
		"sMareM_HatAColorBuf0": 0x80380628,
		"NPC::sMareM_HatAColorBuf1": 0x80380670,
		"sMareM_HatAColorBuf1": 0x80380670,
		"NPC::sMareM_HatAColorChange": 0x803806b8,
		"sMareM_HatAColorChange": 0x803806b8,
		"NPC::@1574": 0x803806c8,
		"NPC::sMareM_HatAData": 0x803806d8,
		"sMareM_HatAData": 0x803806d8,
		"NPC::sMareM_HatBColorBuf0": 0x80380704,
		"sMareM_HatBColorBuf0": 0x80380704,
		"NPC::sMareM_HatBColorBuf1": 0x80380734,
		"sMareM_HatBColorBuf1": 0x80380734,
		"NPC::sMareM_HatBColorChange": 0x80380764,
		"sMareM_HatBColorChange": 0x80380764,
		"NPC::@1575": 0x80380774,
		"NPC::sMareM_HatBData": 0x80380784,
		"sMareM_HatBData": 0x80380784,
		"NPC::sMareM_HatEColorBuf0": 0x803807b0,
		"sMareM_HatEColorBuf0": 0x803807b0,
		"NPC::sMareM_HatEColorBuf1": 0x80380808,
		"sMareM_HatEColorBuf1": 0x80380808,
		"NPC::sMareM_HatEColorChange": 0x80380860,
		"sMareM_HatEColorChange": 0x80380860,
		"NPC::@1576": 0x80380870,
		"NPC::sMareM_HatEData": 0x80380880,
		"sMareM_HatEData": 0x80380880,
		"NPC::sMareM_ShellAColorBuf0": 0x803808ac,
		"sMareM_ShellAColorBuf0": 0x803808ac,
		"NPC::sMareM_ShellAColorBuf1": 0x803808fc,
		"sMareM_ShellAColorBuf1": 0x803808fc,
		"NPC::sMareM_ShellAColorChange": 0x8038094c,
		"sMareM_ShellAColorChange": 0x8038094c,
		"NPC::@1578": 0x8038095c,
		"NPC::sMareM_ShellAData": 0x80380970,
		"sMareM_ShellAData": 0x80380970,
		"NPC::sMareM_ShellBColorBuf0": 0x8038099c,
		"sMareM_ShellBColorBuf0": 0x8038099c,
		"NPC::sMareM_ShellBColorBuf1": 0x803809ec,
		"sMareM_ShellBColorBuf1": 0x803809ec,
		"NPC::sMareM_ShellBColorChange": 0x80380a3c,
		"sMareM_ShellBColorChange": 0x80380a3c,
		"NPC::@1579": 0x80380a4c,
		"NPC::sMareM_ShellBData": 0x80380a60,
		"sMareM_ShellBData": 0x80380a60,
		"NPC::sMareM_BivalveBColorBuf0": 0x80380a8c,
		"sMareM_BivalveBColorBuf0": 0x80380a8c,
		"NPC::sMareM_BivalveBColorBuf1": 0x80380abc,
		"sMareM_BivalveBColorBuf1": 0x80380abc,
		"NPC::sMareM_BivalveBColorChange": 0x80380aec,
		"sMareM_BivalveBColorChange": 0x80380aec,
		"NPC::@1580": 0x80380afc,
		"NPC::sMareM_BivalveBData": 0x80380b10,
		"sMareM_BivalveBData": 0x80380b10,
		"NPC::sMareM_GlassColorBuf0": 0x80380b3c,
		"sMareM_GlassColorBuf0": 0x80380b3c,
		"NPC::sMareM_GlassColorBuf1": 0x80380b54,
		"sMareM_GlassColorBuf1": 0x80380b54,
		"NPC::@1581": 0x80380b6c,
		"NPC::sMareM_GlassColorChange": 0x80380b78,
		"sMareM_GlassColorChange": 0x80380b78,
		"NPC::@1582": 0x80380b88,
		"NPC::sMareM_GlassData": 0x80380b98,
		"sMareM_GlassData": 0x80380b98,
		"NPC::sMareMB_ElderMat1ColorChange": 0x80380bc4,
		"sMareMB_ElderMat1ColorChange": 0x80380bc4,
		"NPC::sMareMB_ElderMat2ColorChange": 0x80380bd4,
		"sMareMB_ElderMat2ColorChange": 0x80380bd4,
		"NPC::sMareMB_ElderMat3ColorChange": 0x80380be4,
		"sMareMB_ElderMat3ColorChange": 0x80380be4,
		"NPC::@1585": 0x80380bf4,
		"NPC::sMareMB_ElderData": 0x80380c04,
		"sMareMB_ElderData": 0x80380c04,
		"NPC::sMareMB_FishingRodMat1ColorChange": 0x80380c30,
		"sMareMB_FishingRodMat1ColorChange": 0x80380c30,
		"NPC::sMareMB_FishingRodMat2ColorChange": 0x80380c40,
		"sMareMB_FishingRodMat2ColorChange": 0x80380c40,
		"NPC::sMareMB_FishingRodMat3ColorChange": 0x80380c50,
		"sMareMB_FishingRodMat3ColorChange": 0x80380c50,
		"NPC::@1586": 0x80380c60,
		"NPC::sMareMC_HatFColorChange": 0x80380c74,
		"sMareMC_HatFColorChange": 0x80380c74,
		"NPC::@1587": 0x80380c84,
		"NPC::sMareMC_HatFData": 0x80380c94,
		"sMareMC_HatFData": 0x80380c94,
		"NPC::sMareMC_BeardColorChange": 0x80380cc0,
		"sMareMC_BeardColorChange": 0x80380cc0,
		"NPC::@1588": 0x80380cd0,
		"NPC::sMareMC_BeardData": 0x80380ce4,
		"sMareMC_BeardData": 0x80380ce4,
		"NPC::sMareMC_MustacheColorChange": 0x80380d10,
		"sMareMC_MustacheColorChange": 0x80380d10,
		"NPC::@1589": 0x80380d20,
		"NPC::sMareMC_MustacheData": 0x80380d34,
		"sMareMC_MustacheData": 0x80380d34,
		"NPC::sMareMD_PipeColorChange": 0x80380d60,
		"sMareMD_PipeColorChange": 0x80380d60,
		"NPC::@1591": 0x80380d70,
		"NPC::sMareMD_PipeData": 0x80380d84,
		"sMareMD_PipeData": 0x80380d84,
		"NPC::sMareW_PearlAColorBuf0": 0x80380db0,
		"sMareW_PearlAColorBuf0": 0x80380db0,
		"NPC::sMareW_PearlAColorBuf1": 0x80380de0,
		"sMareW_PearlAColorBuf1": 0x80380de0,
		"NPC::sMareW_PearlAColorChange": 0x80380e10,
		"sMareW_PearlAColorChange": 0x80380e10,
		"NPC::@1592": 0x80380e20,
		"NPC::sMareW_PearlAData": 0x80380e34,
		"sMareW_PearlAData": 0x80380e34,
		"NPC::sMareW_HatAColorBuf0": 0x80380e60,
		"sMareW_HatAColorBuf0": 0x80380e60,
		"NPC::sMareW_HatAColorBuf1": 0x80380e90,
		"sMareW_HatAColorBuf1": 0x80380e90,
		"NPC::sMareW_HatAColorChange": 0x80380ec0,
		"sMareW_HatAColorChange": 0x80380ec0,
		"NPC::@1593": 0x80380ed0,
		"NPC::sMareW_HatAData": 0x80380ee0,
		"sMareW_HatAData": 0x80380ee0,
		"NPC::sMareW_HatDColorBuf0": 0x80380f0c,
		"sMareW_HatDColorBuf0": 0x80380f0c,
		"NPC::sMareW_HatDColorBuf1": 0x80380f64,
		"sMareW_HatDColorBuf1": 0x80380f64,
		"NPC::sMareW_HatDColorChange": 0x80380fbc,
		"sMareW_HatDColorChange": 0x80380fbc,
		"NPC::@1594": 0x80380fcc,
		"NPC::sMareW_HatDData": 0x80380fdc,
		"sMareW_HatDData": 0x80380fdc,
		"NPC::sMareW_ShellAColorBuf0": 0x80381008,
		"sMareW_ShellAColorBuf0": 0x80381008,
		"NPC::sMareW_ShellAColorBuf1": 0x80381038,
		"sMareW_ShellAColorBuf1": 0x80381038,
		"NPC::sMareW_ShellAColorChange": 0x80381068,
		"sMareW_ShellAColorChange": 0x80381068,
		"NPC::@1595": 0x80381078,
		"NPC::sMareW_ShellAData": 0x80381088,
		"sMareW_ShellAData": 0x80381088,
		"NPC::sMareW_ShellBColorBuf0": 0x803810b4,
		"sMareW_ShellBColorBuf0": 0x803810b4,
		"NPC::sMareW_ShellBColorBuf1": 0x803810fc,
		"sMareW_ShellBColorBuf1": 0x803810fc,
		"NPC::sMareW_ShellBColorChange": 0x80381144,
		"sMareW_ShellBColorChange": 0x80381144,
		"NPC::@1596": 0x80381154,
		"NPC::sMareW_ShellBData": 0x80381164,
		"sMareW_ShellBData": 0x80381164,
		"NPC::sMareW_BivalveAColorBuf0": 0x80381190,
		"sMareW_BivalveAColorBuf0": 0x80381190,
		"NPC::sMareW_BivalveAColorBuf1": 0x803811c0,
		"sMareW_BivalveAColorBuf1": 0x803811c0,
		"NPC::sMareW_BivalveAColorChange": 0x803811f0,
		"sMareW_BivalveAColorChange": 0x803811f0,
		"NPC::@1597": 0x80381200,
		"NPC::sMareW_BivalveAData": 0x80381214,
		"sMareW_BivalveAData": 0x80381214,
		"NPC::sMareWB_BabyBodyColorChange": 0x80381240,
		"sMareWB_BabyBodyColorChange": 0x80381240,
		"NPC::@1599": 0x80381250,
		"NPC::sMareWB_BabyHatColorChange": 0x8038125c,
		"sMareWB_BabyHatColorChange": 0x8038125c,
		"NPC::@1600": 0x8038126c,
		"NPC::sMareWB_BabyBedColorChange": 0x80381278,
		"sMareWB_BabyBedColorChange": 0x80381278,
		"NPC::@1601": 0x80381288,
		"NPC::@1602": 0x80381298,
		"NPC::sKinopio_SunGlassesData": 0x803812b0,
		"sKinopio_SunGlassesData": 0x803812b0,
		"NPC::@1603": 0x803812dc,
		"NPC::@1604": 0x803812ec,
		"NPC::sKinojii_StickData": 0x80381300,
		"sKinojii_StickData": 0x80381300,
		"NPC::@1605": 0x8038132c,
		"NPC::sPeach_HairNormalData": 0x80381344,
		"sPeach_HairNormalData": 0x80381344,
		"NPC::@1606": 0x80381370,
		"NPC::@1607": 0x8038137c,
		"NPC::sPeach_Hand1LData": 0x80381390,
		"sPeach_Hand1LData": 0x80381390,
		"NPC::@1608": 0x803813bc,
		"NPC::@1609": 0x803813c8,
		"NPC::sPeach_Hand1RData": 0x803813dc,
		"sPeach_Hand1RData": 0x803813dc,
		"NPC::@1610": 0x80381408,
		"NPC::sPeach_HairPonytailData": 0x80381420,
		"sPeach_HairPonytailData": 0x80381420,
		"NPC::@1611": 0x8038144c,
		"NPC::sPeach_ParasolData": 0x80381460,
		"sPeach_ParasolData": 0x80381460,
		"NPC::@1612": 0x8038148c,
		"NPC::sPeach_Hand2LData": 0x803814a0,
		"sPeach_Hand2LData": 0x803814a0,
		"NPC::@1613": 0x803814cc,
		"@1613": 0x803814cc,
		"NPC::sPeach_Hand2RData": 0x803814e0,
		"sPeach_Hand2RData": 0x803814e0,
		"NPC::sRaccoonDog_TubeColorBuf0": 0x8038150c,
		"sRaccoonDog_TubeColorBuf0": 0x8038150c,
		"NPC::sRaccoonDog_TubeColorBuf1": 0x8038151c,
		"sRaccoonDog_TubeColorBuf1": 0x8038151c,
		"NPC::sRaccoonDog_TubeColorChange": 0x8038152c,
		"sRaccoonDog_TubeColorChange": 0x8038152c,
		"NPC::@1615": 0x8038153c,
		"NPC::@1616": 0x80381548,
		"NPC::sRaccoonDog_TubeData": 0x80381554,
		"sRaccoonDog_TubeData": 0x80381554,
		"NPC::sMonteM_BodyColorBuf": 0x80381580,
		"sMonteM_BodyColorBuf": 0x80381580,
		"NPC::@1617": 0x803815d0,
		"NPC::sMonteM_BodyColor": 0x803815dc,
		"sMonteM_BodyColor": 0x803815dc,
		"NPC::sMonteMA_ClothColorBuf0": 0x803815ec,
		"sMonteMA_ClothColorBuf0": 0x803815ec,
		"NPC::sMonteMA_ClothColorBuf1": 0x80381644,
		"sMonteMA_ClothColorBuf1": 0x80381644,
		"NPC::@1618": 0x8038169c,
		"NPC::sMonteMA_ClothColor": 0x803816a8,
		"sMonteMA_ClothColor": 0x803816a8,
		"NPC::sMonteMB_BodyColorBuf": 0x803816b8,
		"sMonteMB_BodyColorBuf": 0x803816b8,
		"NPC::sMonteMB_BodyColor": 0x803816d8,
		"sMonteMB_BodyColor": 0x803816d8,
		"NPC::sMonteMB_ClothColorBuf": 0x803816e8,
		"sMonteMB_ClothColorBuf": 0x803816e8,
		"NPC::sMonteMB_ClothColor": 0x80381718,
		"sMonteMB_ClothColor": 0x80381718,
		"NPC::sMonteMC_ClothColorBuf0": 0x80381728,
		"sMonteMC_ClothColorBuf0": 0x80381728,
		"NPC::sMonteMC_ClothColorBuf1": 0x80381780,
		"sMonteMC_ClothColorBuf1": 0x80381780,
		"NPC::sMonteMC_ClothColor": 0x803817d8,
		"sMonteMC_ClothColor": 0x803817d8,
		"NPC::sMonteMD_ClothColorBuf": 0x803817e8,
		"sMonteMD_ClothColorBuf": 0x803817e8,
		"NPC::sMonteMD_ClothColor": 0x80381810,
		"sMonteMD_ClothColor": 0x80381810,
		"NPC::sMonteW_ColorBuf": 0x80381820,
		"sMonteW_ColorBuf": 0x80381820,
		"NPC::sMonteW_BodyColor": 0x80381850,
		"sMonteW_BodyColor": 0x80381850,
		"NPC::sMonteWA_ClothColorBuf": 0x80381860,
		"sMonteWA_ClothColorBuf": 0x80381860,
		"NPC::sMonteWA_ClothColor": 0x80381890,
		"sMonteWA_ClothColor": 0x80381890,
		"NPC::sMonteWB_ClothColorBuf0": 0x803818a0,
		"sMonteWB_ClothColorBuf0": 0x803818a0,
		"NPC::sMonteWB_ClothColorBuf1": 0x803818e8,
		"sMonteWB_ClothColorBuf1": 0x803818e8,
		"NPC::sMonteWB_ClothColor": 0x80381930,
		"sMonteWB_ClothColor": 0x80381930,
		"NPC::sMareM_ColorBuf": 0x80381940,
		"sMareM_ColorBuf": 0x80381940,
		"NPC::sMareM_BodyColor": 0x80381970,
		"sMareM_BodyColor": 0x80381970,
		"NPC::sMareW_ColorBuf": 0x80381980,
		"sMareW_ColorBuf": 0x80381980,
		"NPC::sMareW_BodyColor": 0x803819b0,
		"sMareW_BodyColor": 0x803819b0,
		"NPC::sKinopio_BodyColorData0": 0x803819c0,
		"sKinopio_BodyColorData0": 0x803819c0,
		"NPC::sKinopio_BodyColorData1": 0x803819e8,
		"sKinopio_BodyColorData1": 0x803819e8,
		"NPC::@1619": 0x80381a10,
		"NPC::sKinopio_BodyColor": 0x80381a1c,
		"sKinopio_BodyColor": 0x80381a1c,
		"NPC::sKinopio_ClothColorData0": 0x80381a2c,
		"sKinopio_ClothColorData0": 0x80381a2c,
		"NPC::sKinopio_ClothColorData1": 0x80381a54,
		"sKinopio_ClothColorData1": 0x80381a54,
		"NPC::@1620": 0x80381a7c,
		"NPC::sKinopio_ClothColor": 0x80381a88,
		"sKinopio_ClothColor": 0x80381a88,
		"NPC::sRaccoonDog_ClothColorBuf0": 0x80381a98,
		"sRaccoonDog_ClothColorBuf0": 0x80381a98,
		"NPC::sRaccoonDog_ClothColorBuf1": 0x80381aa8,
		"sRaccoonDog_ClothColorBuf1": 0x80381aa8,
		"NPC::sRaccoonDog_ClothColor": 0x80381ab8,
		"sRaccoonDog_ClothColor": 0x80381ab8,
		"NPC::sMonteM_InitData": 0x80381ac8,
		"sMonteM_InitData": 0x80381ac8,
		"NPC::sMonteMA_InitData": 0x80381b1c,
		"sMonteMA_InitData": 0x80381b1c,
		"NPC::sMonteMB_InitData": 0x80381b70,
		"sMonteMB_InitData": 0x80381b70,
		"NPC::sMonteMC_InitData": 0x80381bc4,
		"sMonteMC_InitData": 0x80381bc4,
		"NPC::sMonteMD_InitData": 0x80381c18,
		"sMonteMD_InitData": 0x80381c18,
		"NPC::sMonteME_InitData": 0x80381c6c,
		"sMonteME_InitData": 0x80381c6c,
		"NPC::sMonteMF_InitData": 0x80381cc0,
		"sMonteMF_InitData": 0x80381cc0,
		"NPC::sMonteMG_InitData": 0x80381d14,
		"sMonteMG_InitData": 0x80381d14,
		"NPC::sMonteMH_InitData": 0x80381d68,
		"sMonteMH_InitData": 0x80381d68,
		"NPC::sMonteW_InitData": 0x80381dbc,
		"sMonteW_InitData": 0x80381dbc,
		"NPC::sMonteWA_InitData": 0x80381e10,
		"sMonteWA_InitData": 0x80381e10,
		"NPC::sMonteWB_InitData": 0x80381e64,
		"sMonteWB_InitData": 0x80381e64,
		"NPC::sMonteWC_InitData": 0x80381eb8,
		"sMonteWC_InitData": 0x80381eb8,
		"NPC::sMareM_InitData": 0x80381f0c,
		"sMareM_InitData": 0x80381f0c,
		"NPC::sMareMB_InitData": 0x80381f60,
		"sMareMB_InitData": 0x80381f60,
		"NPC::sMareMC_InitData": 0x80381fb4,
		"sMareMC_InitData": 0x80381fb4,
		"NPC::sMareMD_InitData": 0x80382008,
		"sMareMD_InitData": 0x80382008,
		"NPC::sMareW_InitData": 0x8038205c,
		"sMareW_InitData": 0x8038205c,
		"NPC::sMareWB_InitData": 0x803820b0,
		"sMareWB_InitData": 0x803820b0,
		"NPC::sKinopio_InitData": 0x80382104,
		"sKinopio_InitData": 0x80382104,
		"NPC::sKinojii_InitData": 0x80382158,
		"sKinojii_InitData": 0x80382158,
		"NPC::sPeach_InitData": 0x803821ac,
		"sPeach_InitData": 0x803821ac,
		"NPC::sRaccoonDog_InitData": 0x80382200,
		"sRaccoonDog_InitData": 0x80382200,
		"NPC::sSunflowerL_InitData": 0x80382254,
		"sSunflowerL_InitData": 0x80382254,
		"NPC::sSunflowerS_InitData": 0x803822a8,
		"sSunflowerS_InitData": 0x803822a8,
		"NPC::sBoardNpc_InitData": 0x803822fc,
		"sBoardNpc_InitData": 0x803822fc,
		"TBaseNPC::sMtxEffectInitData$localstatic1$setMtxEffect_": 0x803824c0,
		"sMtxEffectInitData$localstatic1$setMtxEffect_": 0x803824c0,
		"TBaseNPC::sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x803825a0,
		"sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x803825a0,
		"TBaseNPC::sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x803825b0,
		"sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x803825b0,
		"TBaseNPC::sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x803825e8,
		"sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x803825e8,
		"TBaseNPC::sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x80382600,
		"sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x80382600,
		"TBaseNPC::sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x80382630,
		"sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x80382630,
		"TBaseNPC::sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80382648,
		"sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80382648,
		"TBaseNPC::sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x80382658,
		"sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x80382658,
		"TBaseNPC::sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x80382668,
		"sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x80382668,
		"TBaseNPC::sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x80382678,
		"sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x80382678,
		"TBaseNPC::sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x80382688,
		"sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x80382688,
		"TBaseNPC::sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x80382698,
		"sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x80382698,
		"NPC::@2266": 0x80382788,
		"NPC::@2275": 0x80382798,
		"NPC::@2489": 0x803827c0,
		"NPC::@1938": 0x803828c0,
		"NPC::@1939": 0x803828e8,
		"NPC::@1940": 0x80382910,
		"NPC::@1941": 0x80382938,
		"NPC::@1942": 0x80382960,
		"NPC::@1943": 0x80382984,
		"NPC::@1944": 0x803829ac,
		"NPC::@1945": 0x803829d4,
		"NPC::@1946": 0x803829f8,
		"NPC::@1947": 0x80382a20,
		"NPC::@1948": 0x80382a48,
		"NPC::@1949": 0x80382a74,
		"NPC::@1950": 0x80382a9c,
		"NPC::@1951": 0x80382ac0,
		"NPC::@1952": 0x80382ae8,
		"NPC::@1953": 0x80382b14,
		"NPC::@1954": 0x80382b40,
		"NPC::@1955": 0x80382b68,
		"NPC::@1956": 0x80382b90,
		"NPC::@1957": 0x80382bb8,
		"NPC::@1958": 0x80382be0,
		"NPC::@1959": 0x80382c0c,
		"NPC::@1960": 0x80382c38,
		"NPC::@1984": 0x80382eb8,
		"NPC::@1985": 0x80382edc,
		"NPC::@1986": 0x80382f04,
		"NPC::@1989": 0x80382f2c,
		"NPC::@1990": 0x80382f54,
		"NPC::@1991": 0x80382f7c,
		"NPC::@1992": 0x80382fa4,
		"NPC::@1993": 0x80382fcc,
		"NPC::@1994": 0x80382ff0,
		"NPC::@1995": 0x80383018,
		"NPC::@1996": 0x8038303c,
		"NPC::@1997": 0x80383064,
		"NPC::@1998": 0x8038308c,
		"NPC::@1999": 0x803830b8,
		"NPC::@2000": 0x803830e4,
		"NPC::@2001": 0x8038310c,
		"NPC::@2002": 0x80383130,
		"NPC::@2003": 0x80383158,
		"NPC::@2004": 0x80383184,
		"NPC::@2005": 0x803831b0,
		"NPC::@2006": 0x803831d8,
		"NPC::@2007": 0x80383200,
		"NPC::@2008": 0x80383228,
		"NPC::@2009": 0x80383250,
		"NPC::@2010": 0x8038327c,
		"NPC::@2011": 0x803832a4,
		"NPC::@2012": 0x803832d0,
		"NPC::@2013": 0x803832f8,
		"NPC::@2014": 0x80383328,
		"NPC::@2015": 0x80383358,
		"NPC::@2016": 0x80383380,
		"NPC::@2017": 0x803833a8,
		"NPC::@2018": 0x803833d0,
		"NPC::@2021": 0x80383400,
		"NPC::@2022": 0x80383420,
		"NPC::@2023": 0x80383440,
		"NPC::@2026": 0x80383464,
		"NPC::@2027": 0x80383488,
		"NPC::@2028": 0x803834ac,
		"NPC::@2029": 0x803834cc,
		"NPC::@2030": 0x803834f0,
		"NPC::@2031": 0x80383510,
		"NPC::@2032": 0x80383534,
		"NPC::@2033": 0x80383554,
		"NPC::@2034": 0x80383578,
		"NPC::@2035": 0x8038359c,
		"NPC::@2036": 0x803835c4,
		"NPC::@2037": 0x803835e4,
		"NPC::@2038": 0x80383604,
		"NPC::@2039": 0x80383624,
		"NPC::@2040": 0x80383648,
		"NPC::@2041": 0x8038366c,
		"NPC::@2042": 0x80383690,
		"NPC::@2043": 0x803836b4,
		"NPC::@2044": 0x803836d8,
		"NPC::@2045": 0x803836fc,
		"NPC::@2046": 0x80383724,
		"NPC::@2047": 0x80383748,
		"NPC::@2048": 0x8038376c,
		"NPC::@2049": 0x80383794,
		"NPC::@2057": 0x80383824,
		"NPC::@2059": 0x80383848,
		"NPC::@2060": 0x8038386c,
		"NPC::@2061": 0x80383894,
		"NPC::@2062": 0x803838b8,
		"NPC::@2065": 0x803838dc,
		"NPC::@2066": 0x80383900,
		"NPC::@2073": 0x803839b0,
		"NPC::@2074": 0x803839d4,
		"NPC::@2075": 0x803839f4,
		"NPC::@2076": 0x80383a18,
		"NPC::@2077": 0x80383a3c,
		"NPC::@2078": 0x80383a64,
		"NPC::@2079": 0x80383a84,
		"NPC::@2080": 0x80383aa4,
		"NPC::@2081": 0x80383ac4,
		"NPC::@2083": 0x80383b0c,
		"NPC::@2084": 0x80383b30,
		"NPC::@2085": 0x80383b54,
		"NPC::@2086": 0x80383b78,
		"NPC::@2087": 0x80383ba0,
		"NPC::@2088": 0x80383bc4,
		"NPC::@2089": 0x80383be8,
		"NPC::@2090": 0x80383c10,
		"NPC::@2091": 0x80383c34,
		"NPC::@2092": 0x80383c58,
		"NPC::@2093": 0x80383c7c,
		"NPC::@2098": 0x80383ca0,
		"NPC::@2099": 0x80383cc8,
		"NPC::@2100": 0x80383cf4,
		"NPC::@2101": 0x80383d20,
		"NPC::@2102": 0x80383d48,
		"NPC::@2113": 0x80383ea8,
		"NPC::@2117": 0x80383f44,
		"NPC::@2120": 0x80383f70,
		"NPC::@2121": 0x80383f94,
		"NPC::@2122": 0x80383fbc,
		"NPC::@2123": 0x80383fe4,
		"NPC::@2124": 0x8038400c,
		"NPC::@2125": 0x80384034,
		"NPC::@2126": 0x80384058,
		"NPC::@2127": 0x8038407c,
		"NPC::@2130": 0x803840a0,
		"NPC::@2131": 0x803840c8,
		"NPC::@2132": 0x803840ec,
		"NPC::@2133": 0x80384114,
		"NPC::@2134": 0x8038413c,
		"NPC::@2135": 0x80384160,
		"NPC::@2136": 0x80384188,
		"NPC::@2139": 0x803841a8,
		"NPC::@2140": 0x803841d0,
		"NPC::@2141": 0x803841f8,
		"NPC::@2144": 0x80384220,
		"NPC::@2145": 0x8038424c,
		"NPC::@2146": 0x80384274,
		"NPC::@2150": 0x803842a0,
		"NPC::@2151": 0x803842cc,
		"NPC::@2152": 0x803842f8,
		"NPC::@1700": 0x80384334,
		"NPC::@2153": 0x80384348,
		"NPC::@2154": 0x80384378,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x80384418,
		"sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x80384418,
		"TBaseNPC::sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x80384434,
		"sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x80384434,
		"TBaseNPC::sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x80384440,
		"sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x80384440,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8038444c,
		"sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8038444c,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8038445c,
		"sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8038445c,
		"NPC::@2696": 0x8038446c,
		"NPC::sMonteM_AnmIndex": 0x803844d8,
		"sMonteM_AnmIndex": 0x803844d8,
		"NPC::sMonteME_AnmIndex": 0x803846a8,
		"sMonteME_AnmIndex": 0x803846a8,
		"NPC::sMonteMF_AnmIndex": 0x80384878,
		"sMonteMF_AnmIndex": 0x80384878,
		"NPC::sMonteMG_AnmIndex": 0x80384a48,
		"sMonteMG_AnmIndex": 0x80384a48,
		"NPC::sMonteMH_AnmIndex": 0x80384c18,
		"sMonteMH_AnmIndex": 0x80384c18,
		"NPC::sMonteW_AnmIndex": 0x80384de8,
		"sMonteW_AnmIndex": 0x80384de8,
		"NPC::sMonteWC_AnmIndex": 0x80384fb8,
		"sMonteWC_AnmIndex": 0x80384fb8,
		"NPC::sMareM_AnmIndex": 0x80385188,
		"sMareM_AnmIndex": 0x80385188,
		"NPC::sMareMA_AnmIndex": 0x80385358,
		"sMareMA_AnmIndex": 0x80385358,
		"NPC::sMareMB_AnmIndex": 0x80385528,
		"sMareMB_AnmIndex": 0x80385528,
		"NPC::sMareMC_AnmIndex": 0x803856f8,
		"sMareMC_AnmIndex": 0x803856f8,
		"NPC::sMareMD_AnmIndex": 0x803858c8,
		"sMareMD_AnmIndex": 0x803858c8,
		"NPC::sMareW_AnmIndex": 0x80385a98,
		"sMareW_AnmIndex": 0x80385a98,
		"NPC::sMareWA_AnmIndex": 0x80385c68,
		"sMareWA_AnmIndex": 0x80385c68,
		"NPC::sMareWB_AnmIndex": 0x80385e38,
		"sMareWB_AnmIndex": 0x80385e38,
		"NPC::sKinopio_AnmIndex": 0x80386008,
		"sKinopio_AnmIndex": 0x80386008,
		"NPC::sKinojii_AnmIndex": 0x803861d8,
		"sKinojii_AnmIndex": 0x803861d8,
		"NPC::sPeach_AnmIndex": 0x803863a8,
		"sPeach_AnmIndex": 0x803863a8,
		"NPC::sRaccoonDog_AnmIndex": 0x80386578,
		"sRaccoonDog_AnmIndex": 0x80386578,
		"NPC::sSunflowerL_AnmIndex": 0x80386748,
		"sSunflowerL_AnmIndex": 0x80386748,
		"NPC::sSunflowerS_AnmIndex": 0x80386918,
		"sSunflowerS_AnmIndex": 0x80386918,
		"NPC::sMonteMA_IndividualBtp": 0x80386ae8,
		"sMonteMA_IndividualBtp": 0x80386ae8,
		"NPC::sMonteMB_IndividualBtp": 0x80386b58,
		"sMonteMB_IndividualBtp": 0x80386b58,
		"NPC::sMonteMC_IndividualBtp": 0x80386bc8,
		"sMonteMC_IndividualBtp": 0x80386bc8,
		"NPC::sMonteMD_IndividualBtp": 0x80386c38,
		"sMonteMD_IndividualBtp": 0x80386c38,
		"NPC::sMonteWA_IndividualBtp": 0x80386ca8,
		"sMonteWA_IndividualBtp": 0x80386ca8,
		"NPC::sMonteWB_IndividualBtp": 0x80386d18,
		"sMonteWB_IndividualBtp": 0x80386d18,
		"NPC::sAllNpcInitAnmData$1577": 0x80386d88,
		"sAllNpcInitAnmData$1577": 0x80386d88,
		"NPC::sBaseActionFlagTable$1938": 0x80386e70,
		"sBaseActionFlagTable$1938": 0x80386e70,
		"NPC::sBaseActionFlagTable$1941": 0x80386ed4,
		"sBaseActionFlagTable$1941": 0x80386ed4,
		"NPC::sBaseActionFlagTable$1944": 0x80386f18,
		"sBaseActionFlagTable$1944": 0x80386f18,
		"MSound::@1912": 0x80386f58,
		"MSound::@3426": 0x80386f78,
		"MSound::@3427": 0x80386f90,
		"MSound::@3428": 0x80386fa8,
		"MSound::@3429": 0x80386fbc,
		"MSound::@3430": 0x80386fcc,
		"MSound::@1501": 0x80386fe0,
		"@1501": 0x80386fe0,
		"MSound::@2817": 0x80387000,
		"MSound::@2822": 0x8038701c,
		"MSound::@2826": 0x80387038,
		"MSound::@2832": 0x8038704c,
		"MSound::@2834": 0x80387064,
		"MSound::@2835": 0x80387078,
		"MSound::@2836": 0x80387090,
		"MSound::@2841": 0x8038709c,
		"MSound::@2844": 0x803870ac,
		"MSound::@2846": 0x803870c4,
		"MSound::@2862": 0x80387118,
		"MSound::@2872": 0x80387180,
		"MSound::@2876": 0x803871a8,
		"MSound::@2882": 0x803871fc,
		"MSound::@2887": 0x8038724c,
		"MSound::@2888": 0x8038725c,
		"MSound::@2894": 0x8038727c,
		"MSound::@2911": 0x80387318,
		"MSound::@2932": 0x80387394,
		"MSound::@2934": 0x803873a0,
		"MSound::@3288": 0x803873b4,
		"MSound::@3289": 0x803873c4,
		"MSound::@3290": 0x803873d4,
		"MSound::@3291": 0x803873e4,
		"MSound::@3292": 0x803873f0,
		"MSound::@3293": 0x803873fc,
		"MSound::@3294": 0x8038740c,
		"MSound::@3295": 0x8038741c,
		"MSound::@3296": 0x8038742c,
		"MSound::@3297": 0x80387444,
		"MSound::@3298": 0x80387458,
		"MSound::@3299": 0x80387468,
		"MSound::@3300": 0x80387488,
		"MSound::@3301": 0x803874a0,
		"MSound::@3302": 0x803874b0,
		"MSound::@3303": 0x803874cc,
		"MSound::@3304": 0x803874e4,
		"MSound::@1994": 0x80387500,
		"MSound::@2024": 0x80387530,
		"MSound::@2026": 0x8038753c,
		"MSound::@2028": 0x8038754c,
		"MSound::@2449": 0x8038755c,
		"MSound::@2450": 0x8038756c,
		"MSound::@2451": 0x8038757c,
		"MSound::@2452": 0x8038758c,
		"MSound::@2453": 0x80387598,
		"MSound::@2454": 0x803875a4,
		"MSound::@2455": 0x803875b4,
		"MSound::@2456": 0x803875c4,
		"MSound::@2457": 0x803875d4,
		"MSound::@2458": 0x803875ec,
		"MSound::@2461": 0x80387630,
		"MSound::@2463": 0x80387658,
		"MSound::@2464": 0x80387674,
		"MSound::@2465": 0x8038768c,
		"MoveBG::@2192": 0x80387774,
		"MoveBG::no_data_obj_hit_table": 0x803877b0,
		"no_data_obj_hit_table": 0x803877b0,
		"MoveBG::no_data_obj_hit_info": 0x803877c0,
		"no_data_obj_hit_info": 0x803877c0,
		"MoveBG::@2772": 0x803877ec,
		"MoveBG::@2774": 0x80387810,
		"MoveBG::billboard_dolphin_anim_data": 0x80387820,
		"billboard_dolphin_anim_data": 0x80387820,
		"MoveBG::billboard_hit_data_table": 0x8038785c,
		"billboard_hit_data_table": 0x8038785c,
		"MoveBG::billboard_obj_hit_info": 0x8038786c,
		"billboard_obj_hit_info": 0x8038786c,
		"MoveBG::@2776": 0x80387890,
		"MoveBG::@2777": 0x803878a8,
		"MoveBG::billboard_sun_anim_data": 0x803878bc,
		"billboard_sun_anim_data": 0x803878bc,
		"MoveBG::billboard_restaurant_anim_data": 0x80387920,
		"billboard_restaurant_anim_data": 0x80387920,
		"MoveBG::billboard_fish_anim_data": 0x80387988,
		"billboard_fish_anim_data": 0x80387988,
		"MoveBG::HideObj_hit_data_table": 0x803879d4,
		"HideObj_hit_data_table": 0x803879d4,
		"MoveBG::HideObj_obj_hit_info": 0x803879e4,
		"HideObj_obj_hit_info": 0x803879e4,
		"MoveBG::WaterHitHideObj_hit_data_table": 0x803879f4,
		"WaterHitHideObj_hit_data_table": 0x803879f4,
		"MoveBG::WaterHitHideObj_obj_hit_info": 0x80387a04,
		"WaterHitHideObj_obj_hit_info": 0x80387a04,
		"MoveBG::FruitHitHideObj_hit_data_table": 0x80387a24,
		"FruitHitHideObj_hit_data_table": 0x80387a24,
		"MoveBG::FruitHitHideObj_obj_hit_info": 0x80387a34,
		"FruitHitHideObj_obj_hit_info": 0x80387a34,
		"MoveBG::HipDropHideObj_hit_data_table": 0x80387a54,
		"HipDropHideObj_hit_data_table": 0x80387a54,
		"MoveBG::HipDropHideObj_obj_hit_info": 0x80387a64,
		"HipDropHideObj_obj_hit_info": 0x80387a64,
		"MoveBG::MonteChair_anim_data": 0x80387a9c,
		"MonteChair_anim_data": 0x80387a9c,
		"MoveBG::@2797": 0x80387b58,
		"MoveBG::door_anim_data": 0x80387b78,
		"door_anim_data": 0x80387b78,
		"MoveBG::door_hit_data_table": 0x80387bdc,
		"door_hit_data_table": 0x80387bdc,
		"MoveBG::door_obj_hit_info": 0x80387bec,
		"door_obj_hit_info": 0x80387bec,
		"MoveBG::doorHotel_anim_data": 0x80387c0c,
		"doorHotel_anim_data": 0x80387c0c,
		"MoveBG::@2800": 0x80387c70,
		"MoveBG::manhole_anim_data": 0x80387c88,
		"manhole_anim_data": 0x80387c88,
		"MoveBG::manhole_hit_data_table": 0x80387c9c,
		"manhole_hit_data_table": 0x80387c9c,
		"MoveBG::manhole_obj_hit_info": 0x80387cac,
		"manhole_obj_hit_info": 0x80387cac,
		"MoveBG::manhole_map_collision_data": 0x80387cbc,
		"manhole_map_collision_data": 0x80387cbc,
		"MoveBG::FruitBasket_anim_data": 0x80387cd8,
		"FruitBasket_anim_data": 0x80387cd8,
		"MoveBG::FruitBasket_hit_data_table": 0x80387d00,
		"FruitBasket_hit_data_table": 0x80387d00,
		"MoveBG::FruitBasket_obj_hit_info": 0x80387d10,
		"FruitBasket_obj_hit_info": 0x80387d10,
		"MoveBG::@2806": 0x80387d20,
		"MoveBG::BasketReverse_anim_data": 0x80387d2c,
		"BasketReverse_anim_data": 0x80387d2c,
		"MoveBG::BasketReverse_hit_data_table": 0x80387d40,
		"BasketReverse_hit_data_table": 0x80387d40,
		"MoveBG::BasketReverse_obj_hit_info": 0x80387d50,
		"BasketReverse_obj_hit_info": 0x80387d50,
		"MoveBG::CoconutJuice_hit_data_table": 0x80387d70,
		"CoconutJuice_hit_data_table": 0x80387d70,
		"MoveBG::CoconutJuice_obj_hit_info": 0x80387d80,
		"CoconutJuice_obj_hit_info": 0x80387d80,
		"MoveBG::Pile_hit_data_table": 0x80387da0,
		"Pile_hit_data_table": 0x80387da0,
		"MoveBG::Pile_obj_hit_info": 0x80387db0,
		"Pile_obj_hit_info": 0x80387db0,
		"MoveBG::ChangeStage_hit_data_table": 0x80387de0,
		"ChangeStage_hit_data_table": 0x80387de0,
		"MoveBG::ChangeStage_obj_hit_info": 0x80387df0,
		"ChangeStage_obj_hit_info": 0x80387df0,
		"MoveBG::StartDemo_hit_data_table": 0x80387e24,
		"StartDemo_hit_data_table": 0x80387e24,
		"MoveBG::StartDemo_obj_hit_info": 0x80387e34,
		"StartDemo_obj_hit_info": 0x80387e34,
		"MoveBG::ChipShine_anim_data": 0x80387e68,
		"ChipShine_anim_data": 0x80387e68,
		"MoveBG::ChipShine_hit_data_table": 0x80387e7c,
		"ChipShine_hit_data_table": 0x80387e7c,
		"MoveBG::ChipShine_obj_hit_info": 0x80387e8c,
		"ChipShine_obj_hit_info": 0x80387e8c,
		"MoveBG::KoopaJrSignM_anim_data": 0x80387ebc,
		"KoopaJrSignM_anim_data": 0x80387ebc,
		"MoveBG::KoopaJrSignM_hit_data_table": 0x80387ed0,
		"KoopaJrSignM_hit_data_table": 0x80387ed0,
		"MoveBG::KoopaJrSignM_obj_hit_info": 0x80387ee0,
		"KoopaJrSignM_obj_hit_info": 0x80387ee0,
		"MoveBG::SignCircle_anim_data": 0x80387f1c,
		"SignCircle_anim_data": 0x80387f1c,
		"MoveBG::SignCross_anim_data": 0x80387f4c,
		"SignCross_anim_data": 0x80387f4c,
		"MoveBG::SignTriangle_anim_data": 0x80387f7c,
		"SignTriangle_anim_data": 0x80387f7c,
		"MoveBG::ArrowBoardLR_hit_data_table": 0x80387fa0,
		"ArrowBoardLR_hit_data_table": 0x80387fa0,
		"MoveBG::ArrowBoardLR_obj_hit_info": 0x80387fb0,
		"ArrowBoardLR_obj_hit_info": 0x80387fb0,
		"MoveBG::ArrowBoardUp_hit_data_table": 0x80387fd0,
		"ArrowBoardUp_hit_data_table": 0x80387fd0,
		"MoveBG::ArrowBoardUp_obj_hit_info": 0x80387fe0,
		"ArrowBoardUp_obj_hit_info": 0x80387fe0,
		"MoveBG::@2826": 0x80387ff0,
		"MoveBG::ArrowBoardDown_hit_data_table": 0x80388000,
		"ArrowBoardDown_hit_data_table": 0x80388000,
		"MoveBG::ArrowBoardDown_obj_hit_info": 0x80388010,
		"ArrowBoardDown_obj_hit_info": 0x80388010,
		"MoveBG::GeneralHitObj_hit_data_table": 0x80388070,
		"GeneralHitObj_hit_data_table": 0x80388070,
		"MoveBG::GeneralHitObj_obj_hit_info": 0x80388080,
		"GeneralHitObj_obj_hit_info": 0x80388080,
		"MoveBG::item_hit_data_table": 0x803880a0,
		"item_hit_data_table": 0x803880a0,
		"MoveBG::item_obj_hit_info": 0x803880b0,
		"item_obj_hit_info": 0x803880b0,
		"MoveBG::WaterRecoverObj_hit_data_table": 0x8038810c,
		"WaterRecoverObj_hit_data_table": 0x8038810c,
		"MoveBG::WaterRecoverObj_obj_hit_info": 0x8038811c,
		"WaterRecoverObj_obj_hit_info": 0x8038811c,
		"MoveBG::nozzle_item_hit_data_table": 0x80388174,
		"nozzle_item_hit_data_table": 0x80388174,
		"MoveBG::nozzle_item_obj_hit_info": 0x80388184,
		"nozzle_item_obj_hit_info": 0x80388184,
		"MoveBG::coin_hit_data_table": 0x803881bc,
		"coin_hit_data_table": 0x803881bc,
		"MoveBG::coin_obj_hit_info": 0x803881cc,
		"coin_obj_hit_info": 0x803881cc,
		"MoveBG::coin_sound_data": 0x803881dc,
		"coin_sound_data": 0x803881dc,
		"MoveBG::mario_cap_anim_data": 0x80388254,
		"mario_cap_anim_data": 0x80388254,
		"MoveBG::mario_cap_hit_data_table": 0x80388268,
		"mario_cap_hit_data_table": 0x80388268,
		"MoveBG::mario_cap_obj_hit_info": 0x80388278,
		"mario_cap_obj_hit_info": 0x80388278,
		"MoveBG::coin_anim_data": 0x803882a0,
		"coin_anim_data": 0x803882a0,
		"MoveBG::@2854": 0x803882c0,
		"MoveBG::eggYoshi_anim_data": 0x80388328,
		"eggYoshi_anim_data": 0x80388328,
		"MoveBG::eggYoshi_hit_data_table": 0x80388378,
		"eggYoshi_hit_data_table": 0x80388378,
		"MoveBG::eggYoshi_obj_hit_info": 0x80388418,
		"eggYoshi_obj_hit_info": 0x80388418,
		"MoveBG::NozzleBox_anim_data": 0x8038848c,
		"NozzleBox_anim_data": 0x8038848c,
		"MoveBG::NozzleBox_hit_data_table": 0x803884dc,
		"NozzleBox_hit_data_table": 0x803884dc,
		"MoveBG::NozzleBox_obj_hit_info": 0x803884ec,
		"NozzleBox_obj_hit_info": 0x803884ec,
		"MoveBG::mushroom1up_anim_data": 0x80388518,
		"mushroom1up_anim_data": 0x80388518,
		"MoveBG::mushroom1up_hit_data_table": 0x8038852c,
		"mushroom1up_hit_data_table": 0x8038852c,
		"MoveBG::mushroom1up_obj_hit_info": 0x8038853c,
		"mushroom1up_obj_hit_info": 0x8038853c,
		"MoveBG::@2871": 0x80388578,
		"MoveBG::jumpbase_anim_data": 0x80388588,
		"jumpbase_anim_data": 0x80388588,
		"MoveBG::jumpbase_hit_data_table": 0x8038859c,
		"jumpbase_hit_data_table": 0x8038859c,
		"MoveBG::jumpbase_obj_hit_info": 0x803885ac,
		"jumpbase_obj_hit_info": 0x803885ac,
		"MoveBG::@2872": 0x803885bc,
		"MoveBG::fruit_hit_data_table": 0x803885c8,
		"fruit_hit_data_table": 0x803885c8,
		"MoveBG::fruit_obj_hit_info": 0x803885d8,
		"fruit_obj_hit_info": 0x803885d8,
		"MoveBG::coconut_hit_data_table": 0x803885e8,
		"coconut_hit_data_table": 0x803885e8,
		"MoveBG::coconut_obj_hit_info": 0x803885f8,
		"coconut_obj_hit_info": 0x803885f8,
		"MoveBG::fruit_sound_data": 0x80388608,
		"fruit_sound_data": 0x80388608,
		"MoveBG::@2873": 0x80388630,
		"MoveBG::@2874": 0x80388640,
		"MoveBG::papaya_hit_data_table": 0x8038864c,
		"papaya_hit_data_table": 0x8038864c,
		"MoveBG::papaya_obj_hit_info": 0x8038865c,
		"papaya_obj_hit_info": 0x8038865c,
		"MoveBG::@2875": 0x8038866c,
		"MoveBG::pine_hit_data_table": 0x80388678,
		"pine_hit_data_table": 0x80388678,
		"MoveBG::pine_obj_hit_info": 0x80388688,
		"pine_obj_hit_info": 0x80388688,
		"MoveBG::@2876": 0x80388698,
		"MoveBG::@2877": 0x803886a4,
		"MoveBG::CoverPine_anim_data": 0x803886b4,
		"CoverPine_anim_data": 0x803886b4,
		"MoveBG::cover_pine_hit_data_table": 0x80388740,
		"cover_pine_hit_data_table": 0x80388740,
		"MoveBG::cover_pine_obj_hit_info": 0x80388750,
		"cover_pine_obj_hit_info": 0x80388750,
		"MoveBG::@2878": 0x80388760,
		"MoveBG::durian_hit_data_table": 0x80388770,
		"durian_hit_data_table": 0x80388770,
		"MoveBG::durian_obj_hit_info": 0x80388780,
		"durian_obj_hit_info": 0x80388780,
		"MoveBG::durian_sound_data": 0x80388790,
		"durian_sound_data": 0x80388790,
		"MoveBG::@2879": 0x803887b8,
		"MoveBG::banana_hit_data_table": 0x803887c4,
		"banana_hit_data_table": 0x803887c4,
		"MoveBG::banana_obj_hit_info": 0x803887d4,
		"banana_obj_hit_info": 0x803887d4,
		"MoveBG::@2881": 0x803887f0,
		"MoveBG::@2882": 0x803887fc,
		"MoveBG::@2883": 0x8038880c,
		"MoveBG::fence3x3_anim_data": 0x8038881c,
		"fence3x3_anim_data": 0x8038881c,
		"MoveBG::@2885": 0x8038883c,
		"MoveBG::fence_revolve_outer_anim_data": 0x80388854,
		"fence_revolve_outer_anim_data": 0x80388854,
		"MoveBG::@2886": 0x80388868,
		"MoveBG::FenceInner_hit_data_table": 0x80388878,
		"FenceInner_hit_data_table": 0x80388878,
		"MoveBG::FenceInner_obj_hit_info": 0x80388888,
		"FenceInner_obj_hit_info": 0x80388888,
		"MoveBG::@2887": 0x80388898,
		"MoveBG::FenceWaterH_map_collision_data": 0x803888e8,
		"FenceWaterH_map_collision_data": 0x803888e8,
		"MoveBG::RailFence_anim_data": 0x8038890c,
		"RailFence_anim_data": 0x8038890c,
		"MoveBG::RailFence_map_collision_data": 0x80388948,
		"RailFence_map_collision_data": 0x80388948,
		"MoveBG::BambooRailFence_anim_data": 0x803889c8,
		"BambooRailFence_anim_data": 0x803889c8,
		"MoveBG::wood_barrel_anim_data": 0x80388a84,
		"wood_barrel_anim_data": 0x80388a84,
		"MoveBG::wood_barrel_hit_data_table": 0x80388b10,
		"wood_barrel_hit_data_table": 0x80388b10,
		"MoveBG::wood_barrel_obj_hit_info": 0x80388b40,
		"wood_barrel_obj_hit_info": 0x80388b40,
		"MoveBG::wood_barrel_map_collision_data": 0x80388b50,
		"wood_barrel_map_collision_data": 0x80388b50,
		"MoveBG::wood_barrel_sound_data": 0x80388b60,
		"wood_barrel_sound_data": 0x80388b60,
		"MoveBG::barrel_float_hit_data_table": 0x80388bec,
		"barrel_float_hit_data_table": 0x80388bec,
		"MoveBG::barrel_float_obj_hit_info": 0x80388bfc,
		"barrel_float_obj_hit_info": 0x80388bfc,
		"MoveBG::@2914": 0x80388c30,
		"MoveBG::@2915": 0x80388c4c,
		"MoveBG::drum_can_anim_data": 0x80388c5c,
		"drum_can_anim_data": 0x80388c5c,
		"MoveBG::drum_can_hit_data_table": 0x80388c98,
		"drum_can_hit_data_table": 0x80388c98,
		"MoveBG::drum_can_obj_hit_info": 0x80388ca8,
		"drum_can_obj_hit_info": 0x80388ca8,
		"MoveBG::drum_can_map_collision_data": 0x80388cd4,
		"drum_can_map_collision_data": 0x80388cd4,
		"MoveBG::@2918": 0x80388ce4,
		"MoveBG::@2919": 0x80388cf4,
		"MoveBG::barrel_oil_anim_data": 0x80388d1c,
		"barrel_oil_anim_data": 0x80388d1c,
		"MoveBG::barrel_oil_hit_data_table": 0x80388da8,
		"barrel_oil_hit_data_table": 0x80388da8,
		"MoveBG::barrel_oil_obj_hit_info": 0x80388db8,
		"barrel_oil_obj_hit_info": 0x80388db8,
		"MoveBG::@2920": 0x80388dc8,
		"MoveBG::@2925": 0x80388e24,
		"MoveBG::breakable_block_anim_data": 0x80388e3c,
		"breakable_block_anim_data": 0x80388e3c,
		"MoveBG::breakable_block_hit_data_table": 0x80388e78,
		"breakable_block_hit_data_table": 0x80388e78,
		"MoveBG::breakable_block_obj_hit_info": 0x80388e88,
		"breakable_block_obj_hit_info": 0x80388e88,
		"MoveBG::supermario_block_obj_hit_info": 0x80388ea8,
		"supermario_block_obj_hit_info": 0x80388ea8,
		"MoveBG::@2928": 0x80388ecc,
		"MoveBG::@2929": 0x80388ed8,
		"MoveBG::expand_block_hit_data_table": 0x80388ee8,
		"expand_block_hit_data_table": 0x80388ee8,
		"MoveBG::expand_block_obj_hit_info": 0x80388ef8,
		"expand_block_obj_hit_info": 0x80388ef8,
		"MoveBG::spread_block_hit_data_table": 0x80388f18,
		"spread_block_hit_data_table": 0x80388f18,
		"MoveBG::spread_block_obj_hit_info": 0x80388f28,
		"spread_block_obj_hit_info": 0x80388f28,
		"MoveBG::@2931": 0x80388f38,
		"MoveBG::water_roll_block_anim_data": 0x80388f60,
		"water_roll_block_anim_data": 0x80388f60,
		"MoveBG::water_roll_block_obj_hit_info": 0x80388f74,
		"water_roll_block_obj_hit_info": 0x80388f74,
		"MoveBG::@2935": 0x80388fa8,
		"MoveBG::sand_block_anim_data": 0x80388fb4,
		"sand_block_anim_data": 0x80388fb4,
		"MoveBG::sand_block_hit_data_table": 0x80388ff0,
		"sand_block_hit_data_table": 0x80388ff0,
		"MoveBG::sand_block_obj_hit_info": 0x80389000,
		"sand_block_obj_hit_info": 0x80389000,
		"MoveBG::sand_block_map_collision_data": 0x80389010,
		"sand_block_map_collision_data": 0x80389010,
		"MoveBG::@2937": 0x8038902c,
		"MoveBG::@2941": 0x80389084,
		"MoveBG::skate_block_hit_data_table": 0x803890a4,
		"skate_block_hit_data_table": 0x803890a4,
		"MoveBG::skate_block_obj_hit_info": 0x803890b4,
		"skate_block_obj_hit_info": 0x803890b4,
		"MoveBG::@2944": 0x803890d0,
		"MoveBG::@2945": 0x803890e4,
		"MoveBG::MoveCoin_anim_data": 0x803890f4,
		"MoveCoin_anim_data": 0x803890f4,
		"MoveBG::@2946": 0x80389108,
		"MoveBG::cluster_block_anim_data": 0x80389128,
		"cluster_block_anim_data": 0x80389128,
		"MoveBG::@2949": 0x8038914c,
		"MoveBG::ice_block_hit_data_table": 0x80389158,
		"ice_block_hit_data_table": 0x80389158,
		"MoveBG::ice_block_obj_hit_info": 0x80389168,
		"ice_block_obj_hit_info": 0x80389168,
		"MoveBG::@2950": 0x80389178,
		"MoveBG::@2951": 0x80389184,
		"MoveBG::@2952": 0x80389194,
		"MoveBG::BrickBlock_anim_data": 0x803891b8,
		"BrickBlock_anim_data": 0x803891b8,
		"MoveBG::@2955": 0x80389200,
		"MoveBG::@2956": 0x80389214,
		"MoveBG::WaterMelonBlock_anim_data": 0x80389248,
		"WaterMelonBlock_anim_data": 0x80389248,
		"MoveBG::WoodBlockPole_hit_data_table": 0x803892a0,
		"WoodBlockPole_hit_data_table": 0x803892a0,
		"MoveBG::WoodBlockPole_obj_hit_info": 0x803892b0,
		"WoodBlockPole_obj_hit_info": 0x803892b0,
		"MoveBG::@2963": 0x803892ec,
		"MoveBG::@2964": 0x80389300,
		"MoveBG::@2965": 0x80389310,
		"MoveBG::SuperHipDropBlock_anim_data": 0x80389334,
		"SuperHipDropBlock_anim_data": 0x80389334,
		"MoveBG::@2966": 0x80389370,
		"MoveBG::@2967": 0x8038937c,
		"MoveBG::tree_sound_data": 0x80389390,
		"tree_sound_data": 0x80389390,
		"MoveBG::@2968": 0x803893b8,
		"MoveBG::PalmNormal_anim_data": 0x803893c8,
		"PalmNormal_anim_data": 0x803893c8,
		"MoveBG::palmNormal_hit_data_table": 0x803893dc,
		"palmNormal_hit_data_table": 0x803893dc,
		"MoveBG::palmNormal_obj_hit_info": 0x803893ec,
		"palmNormal_obj_hit_info": 0x803893ec,
		"MoveBG::@2969": 0x803893fc,
		"MoveBG::palmOugi_hit_data_table": 0x80389418,
		"palmOugi_hit_data_table": 0x80389418,
		"MoveBG::palmOugi_obj_hit_info": 0x80389428,
		"palmOugi_obj_hit_info": 0x80389428,
		"MoveBG::palmSago_hit_data_table": 0x80389444,
		"palmSago_hit_data_table": 0x80389444,
		"MoveBG::palmSago_obj_hit_info": 0x80389454,
		"palmSago_obj_hit_info": 0x80389454,
		"MoveBG::palmNatume_hit_data_table": 0x80389470,
		"palmNatume_hit_data_table": 0x80389470,
		"MoveBG::palmNatume_obj_hit_info": 0x80389480,
		"palmNatume_obj_hit_info": 0x80389480,
		"MoveBG::PalmLeaf_anim_data": 0x803894ac,
		"PalmLeaf_anim_data": 0x803894ac,
		"MoveBG::palmLeaf_hit_data_table": 0x803894c0,
		"palmLeaf_hit_data_table": 0x803894c0,
		"MoveBG::palmLeaf_obj_hit_info": 0x803894d0,
		"palmLeaf_obj_hit_info": 0x803894d0,
		"MoveBG::BananaTree_anim_data": 0x803894fc,
		"BananaTree_anim_data": 0x803894fc,
		"MoveBG::BananaTree_hit_data_table": 0x80389510,
		"BananaTree_hit_data_table": 0x80389510,
		"MoveBG::BananaTree_obj_hit_info": 0x80389520,
		"BananaTree_obj_hit_info": 0x80389520,
		"MoveBG::FruitTree_hit_data_table": 0x8038953c,
		"FruitTree_hit_data_table": 0x8038953c,
		"MoveBG::FruitTree_obj_hit_info": 0x8038954c,
		"FruitTree_obj_hit_info": 0x8038954c,
		"MoveBG::flower_hit_data_table": 0x80389568,
		"flower_hit_data_table": 0x80389568,
		"MoveBG::flower_obj_hit_info": 0x80389578,
		"flower_obj_hit_info": 0x80389578,
		"MoveBG::flowerOrange_anim_data": 0x803895bc,
		"flowerOrange_anim_data": 0x803895bc,
		"MoveBG::flowerPink_anim_data": 0x80389614,
		"flowerPink_anim_data": 0x80389614,
		"MoveBG::flowerPurple_anim_data": 0x80389670,
		"flowerPurple_anim_data": 0x80389670,
		"MoveBG::@2991": 0x803896b8,
		"MoveBG::flowerRed_anim_data": 0x803896c8,
		"flowerRed_anim_data": 0x803896c8,
		"MoveBG::flowerYellow_anim_data": 0x80389724,
		"flowerYellow_anim_data": 0x80389724,
		"MoveBG::flowerSunflower_anim_data": 0x80389788,
		"flowerSunflower_anim_data": 0x80389788,
		"MoveBG::pole_sound_data": 0x803897c0,
		"pole_sound_data": 0x803897c0,
		"MoveBG::telegraph_pole_l_hit_data_table": 0x803897e8,
		"telegraph_pole_l_hit_data_table": 0x803897e8,
		"MoveBG::telegraph_pole_l_obj_hit_info": 0x803897f8,
		"telegraph_pole_l_obj_hit_info": 0x803897f8,
		"MoveBG::telegraph_pole_s_hit_data_table": 0x8038981c,
		"telegraph_pole_s_hit_data_table": 0x8038981c,
		"MoveBG::telegraph_pole_s_obj_hit_info": 0x8038982c,
		"telegraph_pole_s_obj_hit_info": 0x8038982c,
		"MoveBG::dptlight_anim_data": 0x8038988c,
		"dptlight_anim_data": 0x8038988c,
		"MoveBG::streetlamp_hit_data_table": 0x80389918,
		"streetlamp_hit_data_table": 0x80389918,
		"MoveBG::streetlamp_obj_hit_info": 0x80389948,
		"streetlamp_obj_hit_info": 0x80389948,
		"MoveBG::streetlamp_map_collision_data": 0x80389974,
		"streetlamp_map_collision_data": 0x80389974,
		"MoveBG::PoleNormal_hit_data_table": 0x80389984,
		"PoleNormal_hit_data_table": 0x80389984,
		"MoveBG::PoleNormal_obj_hit_info": 0x80389994,
		"PoleNormal_obj_hit_info": 0x80389994,
		"MoveBG::football_anim_data": 0x803899c0,
		"football_anim_data": 0x803899c0,
		"MoveBG::football_hit_data_table": 0x803899d4,
		"football_hit_data_table": 0x803899d4,
		"MoveBG::football_obj_hit_info": 0x803899e4,
		"football_obj_hit_info": 0x803899e4,
		"MoveBG::football_sound_data": 0x803899f4,
		"football_sound_data": 0x803899f4,
		"MoveBG::football_goal_anim_data": 0x80389a40,
		"football_goal_anim_data": 0x80389a40,
		"MoveBG::football_goal_hit_data_table": 0x80389a54,
		"football_goal_hit_data_table": 0x80389a54,
		"MoveBG::football_goal_obj_hit_info": 0x80389a64,
		"football_goal_obj_hit_info": 0x80389a64,
		"MoveBG::football_goal_map_collision_data": 0x80389a94,
		"football_goal_map_collision_data": 0x80389a94,
		"MoveBG::@3013": 0x80389ab4,
		"MoveBG::@3014": 0x80389ac0,
		"MoveBG::@3015": 0x80389ad0,
		"MoveBG::@3016": 0x80389ae0,
		"MoveBG::@3017": 0x80389af4,
		"MoveBG::Watermelon_anim_data": 0x80389b18,
		"Watermelon_anim_data": 0x80389b18,
		"MoveBG::watermelon_hit_data_table": 0x80389bb8,
		"watermelon_hit_data_table": 0x80389bb8,
		"MoveBG::watermelon_obj_hit_info": 0x80389bc8,
		"watermelon_obj_hit_info": 0x80389bc8,
		"MoveBG::watermelon_sound_data": 0x80389bd8,
		"watermelon_sound_data": 0x80389bd8,
		"MoveBG::@3018": 0x80389c00,
		"MoveBG::WatermelonStatic_anim_data": 0x80389c0c,
		"WatermelonStatic_anim_data": 0x80389c0c,
		"MoveBG::@3019": 0x80389c20,
		"MoveBG::@3020": 0x80389c34,
		"MoveBG::@3021": 0x80389c40,
		"MoveBG::cloud_anim_data": 0x80389c4c,
		"cloud_anim_data": 0x80389c4c,
		"MoveBG::cloud_hit_data_table": 0x80389c60,
		"cloud_hit_data_table": 0x80389c60,
		"MoveBG::cloud_obj_hit_info": 0x80389c70,
		"cloud_obj_hit_info": 0x80389c70,
		"MoveBG::normallift_anim_data": 0x80389c90,
		"normallift_anim_data": 0x80389c90,
		"MoveBG::normallift_hit_data_table": 0x80389ca4,
		"normallift_hit_data_table": 0x80389ca4,
		"MoveBG::normallift_obj_hit_info": 0x80389cb4,
		"normallift_obj_hit_info": 0x80389cb4,
		"MoveBG::exrollcube_anim_data": 0x80389ce0,
		"exrollcube_anim_data": 0x80389ce0,
		"MoveBG::exrollcube_hit_data_table": 0x80389cf4,
		"exrollcube_hit_data_table": 0x80389cf4,
		"MoveBG::exrollcube_obj_hit_info": 0x80389d04,
		"exrollcube_obj_hit_info": 0x80389d04,
		"MoveBG::exkickboard_anim_data": 0x80389d3c,
		"exkickboard_anim_data": 0x80389d3c,
		"MoveBG::exkickboard_hit_data_table": 0x80389d50,
		"exkickboard_hit_data_table": 0x80389d50,
		"MoveBG::exkickboard_obj_hit_info": 0x80389d60,
		"exkickboard_obj_hit_info": 0x80389d60,
		"MoveBG::railblockr_anim_data": 0x80389da0,
		"railblockr_anim_data": 0x80389da0,
		"MoveBG::railblocky_anim_data": 0x80389dcc,
		"railblocky_anim_data": 0x80389dcc,
		"MoveBG::railblockb_anim_data": 0x80389df8,
		"railblockb_anim_data": 0x80389df8,
		"MoveBG::railblock_hit_data_table": 0x80389e0c,
		"railblock_hit_data_table": 0x80389e0c,
		"MoveBG::railblock_obj_hit_info": 0x80389e1c,
		"railblock_obj_hit_info": 0x80389e1c,
		"MoveBG::umaibou_anim_data": 0x80389e90,
		"umaibou_anim_data": 0x80389e90,
		"MoveBG::umaibou_hit_data_table": 0x80389ea4,
		"umaibou_hit_data_table": 0x80389ea4,
		"MoveBG::umaibou_obj_hit_info": 0x80389eb4,
		"umaibou_obj_hit_info": 0x80389eb4,
		"MoveBG::kamaboko_anim_data": 0x80389ed4,
		"kamaboko_anim_data": 0x80389ed4,
		"MoveBG::kamaboko_hit_data_table": 0x80389ee8,
		"kamaboko_hit_data_table": 0x80389ee8,
		"MoveBG::kamaboko_obj_hit_info": 0x80389ef8,
		"kamaboko_obj_hit_info": 0x80389ef8,
		"MoveBG::getag_anim_data": 0x80389f24,
		"getag_anim_data": 0x80389f24,
		"MoveBG::getao_anim_data": 0x80389f48,
		"getao_anim_data": 0x80389f48,
		"MoveBG::geta_hit_data_table": 0x80389f5c,
		"geta_hit_data_table": 0x80389f5c,
		"MoveBG::geta_obj_hit_info": 0x80389f6c,
		"geta_obj_hit_info": 0x80389f6c,
		"MoveBG::uirou_anim_data": 0x80389f88,
		"uirou_anim_data": 0x80389f88,
		"MoveBG::uirou_hit_data_table": 0x80389f9c,
		"uirou_hit_data_table": 0x80389f9c,
		"MoveBG::uirou_obj_hit_info": 0x80389fac,
		"uirou_obj_hit_info": 0x80389fac,
		"MoveBG::hikidashi_anim_data": 0x80389fcc,
		"hikidashi_anim_data": 0x80389fcc,
		"MoveBG::hikidashi_hit_data_table": 0x80389fe0,
		"hikidashi_hit_data_table": 0x80389fe0,
		"MoveBG::hikidashi_obj_hit_info": 0x80389ff0,
		"hikidashi_obj_hit_info": 0x80389ff0,
		"MoveBG::castella_anim_data": 0x8038a01c,
		"castella_anim_data": 0x8038a01c,
		"MoveBG::castella_hit_data_table": 0x8038a030,
		"castella_hit_data_table": 0x8038a030,
		"MoveBG::castella_obj_hit_info": 0x8038a040,
		"castella_obj_hit_info": 0x8038a040,
		"MoveBG::yoshiblock_anim_data": 0x8038a06c,
		"yoshiblock_anim_data": 0x8038a06c,
		"MoveBG::yoshiblock_hit_data_table": 0x8038a080,
		"yoshiblock_hit_data_table": 0x8038a080,
		"MoveBG::yoshiblock_obj_hit_info": 0x8038a090,
		"yoshiblock_obj_hit_info": 0x8038a090,
		"MoveBG::@3057": 0x8038a0a0,
		"MoveBG::@3058": 0x8038a0ac,
		"MoveBG::@3062": 0x8038a0f4,
		"MoveBG::@3063": 0x8038a104,
		"MoveBG::@3065": 0x8038a120,
		"MoveBG::normalvariant0_hit_data_table": 0x8038a130,
		"normalvariant0_hit_data_table": 0x8038a130,
		"MoveBG::normalvariant0_obj_hit_info": 0x8038a140,
		"normalvariant0_obj_hit_info": 0x8038a140,
		"MoveBG::normalvariant1_hit_data_table": 0x8038a160,
		"normalvariant1_hit_data_table": 0x8038a160,
		"MoveBG::normalvariant1_obj_hit_info": 0x8038a170,
		"normalvariant1_obj_hit_info": 0x8038a170,
		"MoveBG::@3067": 0x8038a180,
		"MoveBG::normalvariant2_hit_data_table": 0x8038a190,
		"normalvariant2_hit_data_table": 0x8038a190,
		"MoveBG::normalvariant2_obj_hit_info": 0x8038a1a0,
		"normalvariant2_obj_hit_info": 0x8038a1a0,
		"MoveBG::normalvariant3_hit_data_table": 0x8038a1c0,
		"normalvariant3_hit_data_table": 0x8038a1c0,
		"MoveBG::normalvariant3_obj_hit_info": 0x8038a1d0,
		"normalvariant3_obj_hit_info": 0x8038a1d0,
		"MoveBG::@3069": 0x8038a1e0,
		"MoveBG::normalvariant4_hit_data_table": 0x8038a1f0,
		"normalvariant4_hit_data_table": 0x8038a1f0,
		"MoveBG::normalvariant4_obj_hit_info": 0x8038a200,
		"normalvariant4_obj_hit_info": 0x8038a200,
		"MoveBG::railvariant0_hit_data_table": 0x8038a220,
		"railvariant0_hit_data_table": 0x8038a220,
		"MoveBG::railvariant0_obj_hit_info": 0x8038a230,
		"railvariant0_obj_hit_info": 0x8038a230,
		"MoveBG::railvariant1_hit_data_table": 0x8038a250,
		"railvariant1_hit_data_table": 0x8038a250,
		"MoveBG::railvariant1_obj_hit_info": 0x8038a260,
		"railvariant1_obj_hit_info": 0x8038a260,
		"MoveBG::@3072": 0x8038a270,
		"MoveBG::railvariant2_hit_data_table": 0x8038a280,
		"railvariant2_hit_data_table": 0x8038a280,
		"MoveBG::railvariant2_obj_hit_info": 0x8038a290,
		"railvariant2_obj_hit_info": 0x8038a290,
		"MoveBG::@3073": 0x8038a2a0,
		"MoveBG::railvariant3_hit_data_table": 0x8038a2b0,
		"railvariant3_hit_data_table": 0x8038a2b0,
		"MoveBG::railvariant3_obj_hit_info": 0x8038a2c0,
		"railvariant3_obj_hit_info": 0x8038a2c0,
		"MoveBG::railvariant4_hit_data_table": 0x8038a2e0,
		"railvariant4_hit_data_table": 0x8038a2e0,
		"MoveBG::railvariant4_obj_hit_info": 0x8038a2f0,
		"railvariant4_obj_hit_info": 0x8038a2f0,
		"MoveBG::rollvariant0_hit_data_table": 0x8038a310,
		"rollvariant0_hit_data_table": 0x8038a310,
		"MoveBG::rollvariant0_obj_hit_info": 0x8038a320,
		"rollvariant0_obj_hit_info": 0x8038a320,
		"MoveBG::@3076": 0x8038a330,
		"MoveBG::rollvariant1_hit_data_table": 0x8038a340,
		"rollvariant1_hit_data_table": 0x8038a340,
		"MoveBG::rollvariant1_obj_hit_info": 0x8038a350,
		"rollvariant1_obj_hit_info": 0x8038a350,
		"MoveBG::@3077": 0x8038a360,
		"MoveBG::rollvariant2_hit_data_table": 0x8038a370,
		"rollvariant2_hit_data_table": 0x8038a370,
		"MoveBG::rollvariant2_obj_hit_info": 0x8038a380,
		"rollvariant2_obj_hit_info": 0x8038a380,
		"MoveBG::@3078": 0x8038a390,
		"MoveBG::rollvariant3_hit_data_table": 0x8038a3a0,
		"rollvariant3_hit_data_table": 0x8038a3a0,
		"MoveBG::rollvariant3_obj_hit_info": 0x8038a3b0,
		"rollvariant3_obj_hit_info": 0x8038a3b0,
		"MoveBG::@3079": 0x8038a3c0,
		"MoveBG::rollvariant4_hit_data_table": 0x8038a3d0,
		"rollvariant4_hit_data_table": 0x8038a3d0,
		"MoveBG::rollvariant4_obj_hit_info": 0x8038a3e0,
		"rollvariant4_obj_hit_info": 0x8038a3e0,
		"MoveBG::lamptrapspike_anim_data": 0x8038a414,
		"lamptrapspike_anim_data": 0x8038a414,
		"MoveBG::lamptrapiron_anim_data": 0x8038a43c,
		"lamptrapiron_anim_data": 0x8038a43c,
		"MoveBG::lamptrap_hit_data_table": 0x8038a450,
		"lamptrap_hit_data_table": 0x8038a450,
		"MoveBG::lamptrap_obj_hit_info": 0x8038a460,
		"lamptrap_obj_hit_info": 0x8038a460,
		"MoveBG::@3088": 0x8038a4b4,
		"MoveBG::WoodBox_anim_data": 0x8038a4d8,
		"WoodBox_anim_data": 0x8038a4d8,
		"MoveBG::WoodBox_sound_data": 0x8038a514,
		"WoodBox_sound_data": 0x8038a514,
		"MoveBG::AirportPole_hit_data_table": 0x8038a53c,
		"AirportPole_hit_data_table": 0x8038a53c,
		"MoveBG::AirportPole_obj_hit_info": 0x8038a54c,
		"AirportPole_obj_hit_info": 0x8038a54c,
		"MoveBG::@3093": 0x8038a568,
		"MoveBG::@3094": 0x8038a574,
		"MoveBG::ice_car_anim_data": 0x8038a580,
		"ice_car_anim_data": 0x8038a580,
		"MoveBG::ice_car_hit_data_table": 0x8038a60c,
		"ice_car_hit_data_table": 0x8038a60c,
		"MoveBG::ice_car_obj_hit_info": 0x8038a61c,
		"ice_car_obj_hit_info": 0x8038a61c,
		"MoveBG::AirportBuoy_hit_data_table": 0x8038a63c,
		"AirportBuoy_hit_data_table": 0x8038a63c,
		"MoveBG::AirportBuoy_obj_hit_info": 0x8038a64c,
		"AirportBuoy_obj_hit_info": 0x8038a64c,
		"MoveBG::dptKing_map_collision_data": 0x8038a668,
		"dptKing_map_collision_data": 0x8038a668,
		"MoveBG::monumentshine_anim_data": 0x8038a6a0,
		"monumentshine_anim_data": 0x8038a6a0,
		"MoveBG::monumentshine_hit_data_table": 0x8038a6b4,
		"monumentshine_hit_data_table": 0x8038a6b4,
		"MoveBG::monumentshine_obj_hit_info": 0x8038a6c4,
		"monumentshine_obj_hit_info": 0x8038a6c4,
		"MoveBG::belldolpic_anim_data": 0x8038a6f4,
		"belldolpic_anim_data": 0x8038a6f4,
		"MoveBG::belldolpic_hit_data_table": 0x8038a708,
		"belldolpic_hit_data_table": 0x8038a708,
		"MoveBG::belldolpic_obj_hit_info": 0x8038a718,
		"belldolpic_obj_hit_info": 0x8038a718,
		"MoveBG::DptWeathercock_anim_data": 0x8038a758,
		"DptWeathercock_anim_data": 0x8038a758,
		"MoveBG::DptWeathercock_hit_data_table": 0x8038a76c,
		"DptWeathercock_hit_data_table": 0x8038a76c,
		"MoveBG::DptWeathercock_obj_hit_info": 0x8038a77c,
		"DptWeathercock_obj_hit_info": 0x8038a77c,
		"MoveBG::DptMonteFence_hit_data_table": 0x8038a79c,
		"DptMonteFence_hit_data_table": 0x8038a79c,
		"MoveBG::DptMonteFence_obj_hit_info": 0x8038a7ac,
		"DptMonteFence_obj_hit_info": 0x8038a7ac,
		"MoveBG::MapSmoke_hit_data_table": 0x8038a7dc,
		"MapSmoke_hit_data_table": 0x8038a7dc,
		"MoveBG::MapSmoke_obj_hit_info": 0x8038a7ec,
		"MapSmoke_obj_hit_info": 0x8038a7ec,
		"MoveBG::@3112": 0x8038a808,
		"MoveBG::MareGate_anim_data": 0x8038a824,
		"MareGate_anim_data": 0x8038a824,
		"MoveBG::NozzleDoor_anim_data": 0x8038a860,
		"NozzleDoor_anim_data": 0x8038a860,
		"MoveBG::NozzleDoor_hit_data_table": 0x8038a888,
		"NozzleDoor_hit_data_table": 0x8038a888,
		"MoveBG::NozzleDoor_obj_hit_info": 0x8038a898,
		"NozzleDoor_obj_hit_info": 0x8038a898,
		"MoveBG::DokanGate_anim_data": 0x8038a8d0,
		"DokanGate_anim_data": 0x8038a8d0,
		"MoveBG::Crane_hit_data_table": 0x8038a8f0,
		"Crane_hit_data_table": 0x8038a8f0,
		"MoveBG::Crane_obj_hit_info": 0x8038a900,
		"Crane_obj_hit_info": 0x8038a900,
		"MoveBG::CraneUpDown_hit_data_table": 0x8038a930,
		"CraneUpDown_hit_data_table": 0x8038a930,
		"MoveBG::CraneUpDown_obj_hit_info": 0x8038a940,
		"CraneUpDown_obj_hit_info": 0x8038a940,
		"MoveBG::crane_cargo_hit_data_table": 0x8038a95c,
		"crane_cargo_hit_data_table": 0x8038a95c,
		"MoveBG::crane_cargo_obj_hit_info": 0x8038a96c,
		"crane_cargo_obj_hit_info": 0x8038a96c,
		"MoveBG::Submarine_hit_data_table": 0x8038a99c,
		"Submarine_hit_data_table": 0x8038a99c,
		"MoveBG::Submarine_obj_hit_info": 0x8038a9ac,
		"Submarine_obj_hit_info": 0x8038a9ac,
		"MoveBG::submarine_map_collision_data": 0x8038a9c8,
		"submarine_map_collision_data": 0x8038a9c8,
		"MoveBG::ricco_ship_hit_data_table": 0x8038a9d8,
		"ricco_ship_hit_data_table": 0x8038a9d8,
		"MoveBG::ricco_ship_obj_hit_info": 0x8038a9e8,
		"ricco_ship_obj_hit_info": 0x8038a9e8,
		"MoveBG::ricco_pole_hit_data_table": 0x8038aa04,
		"ricco_pole_hit_data_table": 0x8038aa04,
		"MoveBG::ricco_pole_obj_hit_info": 0x8038aa14,
		"ricco_pole_obj_hit_info": 0x8038aa14,
		"MoveBG::riccoLog_hit_data_table": 0x8038aa30,
		"riccoLog_hit_data_table": 0x8038aa30,
		"MoveBG::riccoLog_obj_hit_info": 0x8038aa40,
		"riccoLog_obj_hit_info": 0x8038aa40,
		"MoveBG::gesoSurfboard_anim_data": 0x8038aa6c,
		"gesoSurfboard_anim_data": 0x8038aa6c,
		"MoveBG::gesoSurfboard_hit_data_table": 0x8038aa80,
		"gesoSurfboard_hit_data_table": 0x8038aa80,
		"MoveBG::gesoSurfboard_obj_hit_info": 0x8038aa90,
		"gesoSurfboard_obj_hit_info": 0x8038aa90,
		"MoveBG::riccoWatermill_hit_data_table": 0x8038aac4,
		"riccoWatermill_hit_data_table": 0x8038aac4,
		"MoveBG::riccoWatermill_obj_hit_info": 0x8038aad4,
		"riccoWatermill_obj_hit_info": 0x8038aad4,
		"MoveBG::riccoShipLog_hit_data_table": 0x8038aaf4,
		"riccoShipLog_hit_data_table": 0x8038aaf4,
		"MoveBG::riccoShipLog_obj_hit_info": 0x8038ab04,
		"riccoShipLog_obj_hit_info": 0x8038ab04,
		"MoveBG::riccoShipDol_hit_data_table": 0x8038ab24,
		"riccoShipDol_hit_data_table": 0x8038ab24,
		"MoveBG::riccoShipDol_obj_hit_info": 0x8038ab34,
		"riccoShipDol_obj_hit_info": 0x8038ab34,
		"MoveBG::riccoYachtL_hit_data_table": 0x8038ab54,
		"riccoYachtL_hit_data_table": 0x8038ab54,
		"MoveBG::riccoYachtL_obj_hit_info": 0x8038ab64,
		"riccoYachtL_obj_hit_info": 0x8038ab64,
		"MoveBG::riccoYachtS_hit_data_table": 0x8038ab80,
		"riccoYachtS_hit_data_table": 0x8038ab80,
		"MoveBG::riccoYachtS_obj_hit_info": 0x8038ab90,
		"riccoYachtS_obj_hit_info": 0x8038ab90,
		"MoveBG::riccoBoatL_hit_data_table": 0x8038abac,
		"riccoBoatL_hit_data_table": 0x8038abac,
		"MoveBG::riccoBoatL_obj_hit_info": 0x8038abbc,
		"riccoBoatL_obj_hit_info": 0x8038abbc,
		"MoveBG::riccoBoatS_hit_data_table": 0x8038abd8,
		"riccoBoatS_hit_data_table": 0x8038abd8,
		"MoveBG::riccoBoatS_obj_hit_info": 0x8038abe8,
		"riccoBoatS_obj_hit_info": 0x8038abe8,
		"MoveBG::surfgeso_hit_data_table": 0x8038acb8,
		"surfgeso_hit_data_table": 0x8038acb8,
		"MoveBG::surfgeso_obj_hit_info": 0x8038acc8,
		"surfgeso_obj_hit_info": 0x8038acc8,
		"MoveBG::surfgeso_anim_data": 0x8038ace8,
		"surfgeso_anim_data": 0x8038ace8,
		"MoveBG::@3157": 0x8038ad18,
		"MoveBG::windmill_anim_data": 0x8038ad38,
		"windmill_anim_data": 0x8038ad38,
		"MoveBG::Windmill_hit_data_table": 0x8038ad4c,
		"Windmill_hit_data_table": 0x8038ad4c,
		"MoveBG::Windmill_obj_hit_info": 0x8038ad5c,
		"Windmill_obj_hit_info": 0x8038ad5c,
		"MoveBG::MiniWindmill_hit_data_table": 0x8038ad88,
		"MiniWindmill_hit_data_table": 0x8038ad88,
		"MoveBG::MiniWindmill_obj_hit_info": 0x8038ad98,
		"MiniWindmill_obj_hit_info": 0x8038ad98,
		"MoveBG::@3162": 0x8038adb8,
		"MoveBG::@3163": 0x8038adc8,
		"MoveBG::@3164": 0x8038add8,
		"MoveBG::lamp_bianco_anim_data": 0x8038ade8,
		"lamp_bianco_anim_data": 0x8038ade8,
		"MoveBG::lamp_bianco_hit_data_table": 0x8038ae74,
		"lamp_bianco_hit_data_table": 0x8038ae74,
		"MoveBG::lamp_bianco_obj_hit_info": 0x8038aea4,
		"lamp_bianco_obj_hit_info": 0x8038aea4,
		"MoveBG::@3165": 0x8038aeb4,
		"MoveBG::lamp_bianco_map_collision_data": 0x8038aec0,
		"lamp_bianco_map_collision_data": 0x8038aec0,
		"MoveBG::WindmillBlock_hit_data_table": 0x8038aedc,
		"WindmillBlock_hit_data_table": 0x8038aedc,
		"MoveBG::WindmillBlock_obj_hit_info": 0x8038aeec,
		"WindmillBlock_obj_hit_info": 0x8038aeec,
		"MoveBG::PolluterPakkun_hit_data_table": 0x8038af10,
		"PolluterPakkun_hit_data_table": 0x8038af10,
		"MoveBG::PolluterPakkun_obj_hit_info": 0x8038af20,
		"PolluterPakkun_obj_hit_info": 0x8038af20,
		"MoveBG::@3168": 0x8038af30,
		"MoveBG::@3169": 0x8038af40,
		"MoveBG::BiaBell_anim_data": 0x8038af7c,
		"BiaBell_anim_data": 0x8038af7c,
		"MoveBG::BiaBell_hit_data_table": 0x8038afe0,
		"BiaBell_hit_data_table": 0x8038afe0,
		"MoveBG::BiaBell_obj_hit_info": 0x8038aff0,
		"BiaBell_obj_hit_info": 0x8038aff0,
		"MoveBG::watermill00_anim_data": 0x8038b03c,
		"watermill00_anim_data": 0x8038b03c,
		"MoveBG::BiaWatermill00_hit_data_table": 0x8038b050,
		"BiaWatermill00_hit_data_table": 0x8038b050,
		"MoveBG::BiaWatermill00_obj_hit_info": 0x8038b060,
		"BiaWatermill00_obj_hit_info": 0x8038b060,
		"MoveBG::@3177": 0x8038b070,
		"MoveBG::BiaWatermill01_hit_data_table": 0x8038b080,
		"BiaWatermill01_hit_data_table": 0x8038b080,
		"MoveBG::BiaWatermill01_obj_hit_info": 0x8038b090,
		"BiaWatermill01_obj_hit_info": 0x8038b090,
		"MoveBG::@3178": 0x8038b0a0,
		"MoveBG::BiaWatermillVertical_hit_data_table": 0x8038b0b0,
		"BiaWatermillVertical_hit_data_table": 0x8038b0b0,
		"MoveBG::BiaWatermillVertical_obj_hit_info": 0x8038b0c0,
		"BiaWatermillVertical_obj_hit_info": 0x8038b0c0,
		"MoveBG::@3179": 0x8038b0d0,
		"MoveBG::BiaTurnBridge_hit_data_table": 0x8038b0e8,
		"BiaTurnBridge_hit_data_table": 0x8038b0e8,
		"MoveBG::BiaTurnBridge_obj_hit_info": 0x8038b0f8,
		"BiaTurnBridge_obj_hit_info": 0x8038b0f8,
		"MoveBG::@3180": 0x8038b108,
		"MoveBG::LeafBoat_hit_data_table": 0x8038b118,
		"LeafBoat_hit_data_table": 0x8038b118,
		"MoveBG::LeafBoat_obj_hit_info": 0x8038b128,
		"LeafBoat_obj_hit_info": 0x8038b128,
		"MoveBG::LampSeesaw_anim_data": 0x8038b154,
		"LampSeesaw_anim_data": 0x8038b154,
		"MoveBG::LampSeesaw_hit_data_table": 0x8038b168,
		"LampSeesaw_hit_data_table": 0x8038b168,
		"MoveBG::LampSeesaw_obj_hit_info": 0x8038b198,
		"LampSeesaw_obj_hit_info": 0x8038b198,
		"MoveBG::SandBird_anim_data": 0x8038b1dc,
		"SandBird_anim_data": 0x8038b1dc,
		"MoveBG::SandBirdBlock_hit_data_table": 0x8038b1fc,
		"SandBirdBlock_hit_data_table": 0x8038b1fc,
		"MoveBG::SandBirdBlock_obj_hit_info": 0x8038b20c,
		"SandBirdBlock_obj_hit_info": 0x8038b20c,
		"MoveBG::SandBirdBlock_map_collision_data": 0x8038b22c,
		"SandBirdBlock_map_collision_data": 0x8038b22c,
		"MoveBG::@3191": 0x8038b24c,
		"MoveBG::SkyIsland_anim_data": 0x8038b258,
		"SkyIsland_anim_data": 0x8038b258,
		"MoveBG::@3192": 0x8038b26c,
		"MoveBG::SandLeaf_anim_data": 0x8038b2c8,
		"SandLeaf_anim_data": 0x8038b2c8,
		"MoveBG::sand_leaf_hit_data_table": 0x8038b32c,
		"sand_leaf_hit_data_table": 0x8038b32c,
		"MoveBG::sand_leaf_obj_hit_info": 0x8038b33c,
		"sand_leaf_obj_hit_info": 0x8038b33c,
		"MoveBG::SandLeafBase00_anim_data": 0x8038b36c,
		"SandLeafBase00_anim_data": 0x8038b36c,
		"MoveBG::SandLeafBase00_map_collision_data": 0x8038b390,
		"SandLeafBase00_map_collision_data": 0x8038b390,
		"MoveBG::SandLeafBase01_anim_data": 0x8038b3b4,
		"SandLeafBase01_anim_data": 0x8038b3b4,
		"MoveBG::SandLeafBase01_map_collision_data": 0x8038b3d8,
		"SandLeafBase01_map_collision_data": 0x8038b3d8,
		"MoveBG::SandLeafBase02_anim_data": 0x8038b3fc,
		"SandLeafBase02_anim_data": 0x8038b3fc,
		"MoveBG::SandLeafBase02_map_collision_data": 0x8038b420,
		"SandLeafBase02_map_collision_data": 0x8038b420,
		"MoveBG::SandLeafBase03_anim_data": 0x8038b444,
		"SandLeafBase03_anim_data": 0x8038b444,
		"MoveBG::SandLeafBase03_map_collision_data": 0x8038b468,
		"SandLeafBase03_map_collision_data": 0x8038b468,
		"MoveBG::SandBomb_anim_data": 0x8038b4c8,
		"SandBomb_anim_data": 0x8038b4c8,
		"MoveBG::sand_bomb_hit_data_table": 0x8038b554,
		"sand_bomb_hit_data_table": 0x8038b554,
		"MoveBG::sand_bomb_obj_hit_info": 0x8038b564,
		"sand_bomb_obj_hit_info": 0x8038b564,
		"MoveBG::@3212": 0x8038b574,
		"MoveBG::mirror_L_hit_data_table": 0x8038b580,
		"mirror_L_hit_data_table": 0x8038b580,
		"MoveBG::mirror_L_obj_hit_info": 0x8038b590,
		"mirror_L_obj_hit_info": 0x8038b590,
		"MoveBG::mirror_L_map_collision_data": 0x8038b5a0,
		"mirror_L_map_collision_data": 0x8038b5a0,
		"MoveBG::mirror_M_hit_data_table": 0x8038b5b0,
		"mirror_M_hit_data_table": 0x8038b5b0,
		"MoveBG::mirror_M_obj_hit_info": 0x8038b5c0,
		"mirror_M_obj_hit_info": 0x8038b5c0,
		"MoveBG::mirror_M_map_collision_data": 0x8038b5d0,
		"mirror_M_map_collision_data": 0x8038b5d0,
		"MoveBG::mirrorS_hit_data_table": 0x8038b5e0,
		"mirrorS_hit_data_table": 0x8038b5e0,
		"MoveBG::mirrorS_obj_hit_info": 0x8038b5f0,
		"mirrorS_obj_hit_info": 0x8038b5f0,
		"MoveBG::mirrorS_map_collision_data": 0x8038b600,
		"mirrorS_map_collision_data": 0x8038b600,
		"MoveBG::@3218": 0x8038b630,
		"MoveBG::SandCastle_anim_data": 0x8038b640,
		"SandCastle_anim_data": 0x8038b640,
		"MoveBG::@3219": 0x8038b690,
		"MoveBG::SandCastle_map_collision_data": 0x8038b69c,
		"SandCastle_map_collision_data": 0x8038b69c,
		"MoveBG::MammaBlockRotate_map_collision_data": 0x8038b6c0,
		"MammaBlockRotate_map_collision_data": 0x8038b6c0,
		"MoveBG::MammaSurfboard_hit_data_table": 0x8038b700,
		"MammaSurfboard_hit_data_table": 0x8038b700,
		"MoveBG::MammaSurfboard_obj_hit_info": 0x8038b710,
		"MammaSurfboard_obj_hit_info": 0x8038b710,
		"MoveBG::@3225": 0x8038b734,
		"MoveBG::@3226": 0x8038b748,
		"MoveBG::@3227": 0x8038b75c,
		"MoveBG::@3228": 0x8038b770,
		"MoveBG::MammaYacht00_hit_data_table": 0x8038b784,
		"MammaYacht00_hit_data_table": 0x8038b784,
		"MoveBG::MammaYacht00_obj_hit_info": 0x8038b794,
		"MammaYacht00_obj_hit_info": 0x8038b794,
		"MoveBG::@3229": 0x8038b7a4,
		"MoveBG::SandBombBase00_anim_data": 0x8038b7f8,
		"SandBombBase00_anim_data": 0x8038b7f8,
		"MoveBG::SandBombBase00_map_collision_data": 0x8038b830,
		"SandBombBase00_map_collision_data": 0x8038b830,
		"MoveBG::SandBombBaseMushroom_anim_data": 0x8038b85c,
		"SandBombBaseMushroom_anim_data": 0x8038b85c,
		"MoveBG::SandBombBaseMushroom_map_collision_data": 0x8038b89c,
		"SandBombBaseMushroom_map_collision_data": 0x8038b89c,
		"MoveBG::SandBombBasePyramid_anim_data": 0x8038b8c4,
		"SandBombBasePyramid_anim_data": 0x8038b8c4,
		"MoveBG::SandBombBasePyramid_map_collision_data": 0x8038b900,
		"SandBombBasePyramid_map_collision_data": 0x8038b900,
		"MoveBG::SandBombBaseShit_anim_data": 0x8038b928,
		"SandBombBaseShit_anim_data": 0x8038b928,
		"MoveBG::SandBombBaseShit_map_collision_data": 0x8038b964,
		"SandBombBaseShit_map_collision_data": 0x8038b964,
		"MoveBG::SandBombBaseStar_anim_data": 0x8038b98c,
		"SandBombBaseStar_anim_data": 0x8038b98c,
		"MoveBG::SandBombBaseStar_map_collision_data": 0x8038b9c8,
		"SandBombBaseStar_map_collision_data": 0x8038b9c8,
		"MoveBG::SandBombBaseTurtle_anim_data": 0x8038b9f0,
		"SandBombBaseTurtle_anim_data": 0x8038b9f0,
		"MoveBG::SandBombBaseTurtle_map_collision_data": 0x8038ba2c,
		"SandBombBaseTurtle_map_collision_data": 0x8038ba2c,
		"MoveBG::SandBombBaseFoot_anim_data": 0x8038ba54,
		"SandBombBaseFoot_anim_data": 0x8038ba54,
		"MoveBG::SandBombBaseFoot_map_collision_data": 0x8038ba90,
		"SandBombBaseFoot_map_collision_data": 0x8038ba90,
		"MoveBG::SandBombBaseHand_anim_data": 0x8038bab8,
		"SandBombBaseHand_anim_data": 0x8038bab8,
		"MoveBG::SandBombBaseHand_map_collision_data": 0x8038baf4,
		"SandBombBaseHand_map_collision_data": 0x8038baf4,
		"MoveBG::SandBombBaseStairs_anim_data": 0x8038bb1c,
		"SandBombBaseStairs_anim_data": 0x8038bb1c,
		"MoveBG::SandBombBaseStairs_map_collision_data": 0x8038bb58,
		"SandBombBaseStairs_map_collision_data": 0x8038bb58,
		"MoveBG::GoalWatermelon_hit_data_table": 0x8038bb68,
		"GoalWatermelon_hit_data_table": 0x8038bb68,
		"MoveBG::GoalWatermelon_obj_hit_info": 0x8038bb78,
		"GoalWatermelon_obj_hit_info": 0x8038bb78,
		"MoveBG::TeethOfJuicer_anim_data": 0x8038bbbc,
		"TeethOfJuicer_anim_data": 0x8038bbbc,
		"MoveBG::TeethOfJuicer_hit_data_table": 0x8038bbd0,
		"TeethOfJuicer_hit_data_table": 0x8038bbd0,
		"MoveBG::TeethOfJuicer_obj_hit_info": 0x8038bbe0,
		"TeethOfJuicer_obj_hit_info": 0x8038bbe0,
		"MoveBG::merrygoround_anim_data": 0x8038bc1c,
		"merrygoround_anim_data": 0x8038bc1c,
		"MoveBG::merry_hit_data_table": 0x8038bc30,
		"merry_hit_data_table": 0x8038bc30,
		"MoveBG::merrygoround_obj_hit_info": 0x8038bc40,
		"merrygoround_obj_hit_info": 0x8038bc40,
		"MoveBG::merry_egg_hit_data_table": 0x8038bc50,
		"merry_egg_hit_data_table": 0x8038bc50,
		"MoveBG::merry_egg_obj_hit_info": 0x8038bc60,
		"merry_egg_obj_hit_info": 0x8038bc60,
		"MoveBG::merry_pole_hit_data_table": 0x8038bc7c,
		"merry_pole_hit_data_table": 0x8038bc7c,
		"MoveBG::merry_pole_obj_hit_info": 0x8038bc8c,
		"merry_pole_obj_hit_info": 0x8038bc8c,
		"MoveBG::FerrisWheel_anim_data": 0x8038bcc4,
		"FerrisWheel_anim_data": 0x8038bcc4,
		"MoveBG::FerrisWheel_hit_data_table": 0x8038bcd8,
		"FerrisWheel_hit_data_table": 0x8038bcd8,
		"MoveBG::FerrisWheel_obj_hit_info": 0x8038bce8,
		"FerrisWheel_obj_hit_info": 0x8038bce8,
		"MoveBG::FerrisWheelGondola_hit_data_table": 0x8038bd14,
		"FerrisWheelGondola_hit_data_table": 0x8038bd14,
		"MoveBG::FerrisWheelGondola_obj_hit_info": 0x8038bd24,
		"FerrisWheelGondola_obj_hit_info": 0x8038bd24,
		"MoveBG::FerrisLOD_anim_data": 0x8038bd50,
		"FerrisLOD_anim_data": 0x8038bd50,
		"MoveBG::Viking_hit_data_table": 0x8038bd70,
		"Viking_hit_data_table": 0x8038bd70,
		"MoveBG::Viking_obj_hit_info": 0x8038bd80,
		"Viking_obj_hit_info": 0x8038bd80,
		"MoveBG::balloon_koopajr_anim_data": 0x8038bde0,
		"balloon_koopajr_anim_data": 0x8038bde0,
		"MoveBG::balloon_koopajr_hit_data_table": 0x8038be1c,
		"balloon_koopajr_hit_data_table": 0x8038be1c,
		"MoveBG::balloon_koopajr_obj_hit_info": 0x8038be2c,
		"balloon_koopajr_obj_hit_info": 0x8038be2c,
		"MoveBG::@3276": 0x8038be4c,
		"MoveBG::@3277": 0x8038be5c,
		"MoveBG::ShellCup_anim_data": 0x8038be68,
		"ShellCup_anim_data": 0x8038be68,
		"MoveBG::@3278": 0x8038be7c,
		"MoveBG::ShellCup_hit_data_table": 0x8038be8c,
		"ShellCup_hit_data_table": 0x8038be8c,
		"MoveBG::ShellCup_obj_hit_info": 0x8038be9c,
		"ShellCup_obj_hit_info": 0x8038be9c,
		"MoveBG::Gateshell_anim_data": 0x8038bed4,
		"Gateshell_anim_data": 0x8038bed4,
		"MoveBG::PinnaHangingBridgeBoard_anim_data": 0x8038bf04,
		"PinnaHangingBridgeBoard_anim_data": 0x8038bf04,
		"MoveBG::PinnaHangingBridgeBoard_hit_data_table": 0x8038bf18,
		"PinnaHangingBridgeBoard_hit_data_table": 0x8038bf18,
		"MoveBG::PinnaHangingBridgeBoard_obj_hit_info": 0x8038bf28,
		"PinnaHangingBridgeBoard_obj_hit_info": 0x8038bf28,
		"MoveBG::GateManta_anim_data": 0x8038bf78,
		"GateManta_anim_data": 0x8038bf78,
		"MoveBG::@3289": 0x8038bf98,
		"MoveBG::@3290": 0x8038bfa8,
		"MoveBG::AmiKing_anim_data": 0x8038bfbc,
		"AmiKing_anim_data": 0x8038bfbc,
		"MoveBG::AmiKing_hit_data_table": 0x8038bfd0,
		"AmiKing_hit_data_table": 0x8038bfd0,
		"MoveBG::AmiKing_obj_hit_info": 0x8038bfe0,
		"AmiKing_obj_hit_info": 0x8038bfe0,
		"MoveBG::PinnaCoaster_hit_data_table": 0x8038bff0,
		"PinnaCoaster_hit_data_table": 0x8038bff0,
		"MoveBG::PinnaCoaster_obj_hit_info": 0x8038c000,
		"PinnaCoaster_obj_hit_info": 0x8038c000,
		"MoveBG::roulette_anim_data": 0x8038c028,
		"roulette_anim_data": 0x8038c028,
		"MoveBG::slotdrum_hit_data_table": 0x8038c03c,
		"slotdrum_hit_data_table": 0x8038c03c,
		"MoveBG::slotdrum_obj_hit_info": 0x8038c04c,
		"slotdrum_obj_hit_info": 0x8038c04c,
		"MoveBG::telesaslot_hit_data_table": 0x8038c074,
		"telesaslot_hit_data_table": 0x8038c074,
		"MoveBG::telesaslot_obj_hit_info": 0x8038c084,
		"telesaslot_obj_hit_info": 0x8038c084,
		"MoveBG::@3300": 0x8038c094,
		"MoveBG::donchou_anim_data": 0x8038c0a0,
		"donchou_anim_data": 0x8038c0a0,
		"MoveBG::donchou_hit_data_table": 0x8038c0b4,
		"donchou_hit_data_table": 0x8038c0b4,
		"MoveBG::donchou_obj_hit_info": 0x8038c0c4,
		"donchou_obj_hit_info": 0x8038c0c4,
		"MoveBG::casino_panel_gate_hit_data_table": 0x8038c0d4,
		"casino_panel_gate_hit_data_table": 0x8038c0d4,
		"MoveBG::casino_panel_gate_obj_hit_info": 0x8038c0e4,
		"casino_panel_gate_obj_hit_info": 0x8038c0e4,
		"MoveBG::bosswall_anim_data": 0x8038c110,
		"bosswall_anim_data": 0x8038c110,
		"MoveBG::casinoroof_anim_data": 0x8038c158,
		"casinoroof_anim_data": 0x8038c158,
		"MoveBG::GlassBreak_anim_data": 0x8038c19c,
		"GlassBreak_anim_data": 0x8038c19c,
		"MoveBG::GlassBreak_sound_data": 0x8038c228,
		"GlassBreak_sound_data": 0x8038c228,
		"MoveBG::closet_anim_data": 0x8038c268,
		"closet_anim_data": 0x8038c268,
		"MoveBG::closet_hit_data_table": 0x8038c27c,
		"closet_hit_data_table": 0x8038c27c,
		"MoveBG::closet_obj_hit_info": 0x8038c28c,
		"closet_obj_hit_info": 0x8038c28c,
		"MoveBG::ChestRevolve_anim_data": 0x8038c2e0,
		"ChestRevolve_anim_data": 0x8038c2e0,
		"MoveBG::ChestRevolve_map_collision_data": 0x8038c318,
		"ChestRevolve_map_collision_data": 0x8038c318,
		"MoveBG::PosterTeresa_anim_data": 0x8038c34c,
		"PosterTeresa_anim_data": 0x8038c34c,
		"MoveBG::PictureTeresa_anim_data": 0x8038c394,
		"PictureTeresa_anim_data": 0x8038c394,
		"MoveBG::PictureTeresa_hit_data_table": 0x8038c3a8,
		"PictureTeresa_hit_data_table": 0x8038c3a8,
		"MoveBG::PictureTeresa_obj_hit_info": 0x8038c3b8,
		"PictureTeresa_obj_hit_info": 0x8038c3b8,
		"MoveBG::PanelBreak_anim_data": 0x8038c3f4,
		"PanelBreak_anim_data": 0x8038c3f4,
		"MoveBG::PanelBreak_sound_data": 0x8038c480,
		"PanelBreak_sound_data": 0x8038c480,
		"MoveBG::PanelRevolve_anim_data": 0x8038c4cc,
		"PanelRevolve_anim_data": 0x8038c4cc,
		"MoveBG::cogwheel_anim_data": 0x8038c544,
		"cogwheel_anim_data": 0x8038c544,
		"MoveBG::Cogwheel_hit_data_table": 0x8038c558,
		"Cogwheel_hit_data_table": 0x8038c558,
		"MoveBG::Cogwheel_obj_hit_info": 0x8038c568,
		"Cogwheel_obj_hit_info": 0x8038c568,
		"MoveBG::CogwheelPlate_hit_data_table": 0x8038c594,
		"CogwheelPlate_hit_data_table": 0x8038c594,
		"MoveBG::CogwheelPlate_obj_hit_info": 0x8038c5a4,
		"CogwheelPlate_obj_hit_info": 0x8038c5a4,
		"MoveBG::@3336": 0x8038c5b4,
		"MoveBG::CogwheelPot_hit_data_table": 0x8038c5c4,
		"CogwheelPot_hit_data_table": 0x8038c5c4,
		"MoveBG::CogwheelPot_obj_hit_info": 0x8038c5d4,
		"CogwheelPot_obj_hit_info": 0x8038c5d4,
		"MoveBG::@3337": 0x8038c5e4,
		"MoveBG::mare_float_house_hit_data_table": 0x8038c5f4,
		"mare_float_house_hit_data_table": 0x8038c5f4,
		"MoveBG::mare_float_house_obj_hit_info": 0x8038c604,
		"mare_float_house_obj_hit_info": 0x8038c604,
		"MoveBG::StopRock_hit_data_table": 0x8038c614,
		"StopRock_hit_data_table": 0x8038c614,
		"MoveBG::StopRock_obj_hit_info": 0x8038c624,
		"StopRock_obj_hit_info": 0x8038c624,
		"MoveBG::@3339": 0x8038c634,
		"MoveBG::ElasticCode_hit_data_table": 0x8038c640,
		"ElasticCode_hit_data_table": 0x8038c640,
		"MoveBG::ElasticCode_obj_hit_info": 0x8038c650,
		"ElasticCode_obj_hit_info": 0x8038c650,
		"MoveBG::@3340": 0x8038c660,
		"MoveBG::@3343": 0x8038c684,
		"MoveBG::GrowthTree_anim_data": 0x8038c694,
		"GrowthTree_anim_data": 0x8038c694,
		"MoveBG::GrowthTree_hit_data_table": 0x8038c6bc,
		"GrowthTree_hit_data_table": 0x8038c6bc,
		"MoveBG::GrowthTree_obj_hit_info": 0x8038c6cc,
		"GrowthTree_obj_hit_info": 0x8038c6cc,
		"MoveBG::MuddyBoat_anim_data": 0x8038c724,
		"MuddyBoat_anim_data": 0x8038c724,
		"MoveBG::MuddyBoat_hit_data_table": 0x8038c760,
		"MuddyBoat_hit_data_table": 0x8038c760,
		"MoveBG::MuddyBoat_obj_hit_info": 0x8038c770,
		"MuddyBoat_obj_hit_info": 0x8038c770,
		"MoveBG::Puncher_anim_data": 0x8038c7d4,
		"Puncher_anim_data": 0x8038c7d4,
		"MoveBG::Puncher_hit_data_table": 0x8038c7fc,
		"Puncher_hit_data_table": 0x8038c7fc,
		"MoveBG::Puncher_obj_hit_info": 0x8038c80c,
		"Puncher_obj_hit_info": 0x8038c80c,
		"MoveBG::@3354": 0x8038c81c,
		"MoveBG::@3356": 0x8038c840,
		"MoveBG::HatoPop_anim_data": 0x8038c864,
		"HatoPop_anim_data": 0x8038c864,
		"MoveBG::HatoPop_hit_data_table": 0x8038c88c,
		"HatoPop_hit_data_table": 0x8038c88c,
		"MoveBG::HatoPop_obj_hit_info": 0x8038c89c,
		"HatoPop_obj_hit_info": 0x8038c89c,
		"MoveBG::MareWaterJump_hit_data_table": 0x8038c8ac,
		"MareWaterJump_hit_data_table": 0x8038c8ac,
		"MoveBG::MareWaterJump_obj_hit_info": 0x8038c8bc,
		"MareWaterJump_obj_hit_info": 0x8038c8bc,
		"MoveBG::@3358": 0x8038c8cc,
		"MoveBG::@3359": 0x8038c8e0,
		"MoveBG::BumpyWall_hit_data_table": 0x8038c8f0,
		"BumpyWall_hit_data_table": 0x8038c8f0,
		"MoveBG::BumpyWall_obj_hit_info": 0x8038c900,
		"BumpyWall_obj_hit_info": 0x8038c900,
		"MoveBG::@3360": 0x8038c910,
		"MoveBG::ExBottle_hit_data_table": 0x8038c924,
		"ExBottle_hit_data_table": 0x8038c924,
		"MoveBG::ExBottle_obj_hit_info": 0x8038c934,
		"ExBottle_obj_hit_info": 0x8038c934,
		"MoveBG::@3362": 0x8038c950,
		"MoveBG::@3363": 0x8038c960,
		"MoveBG::CoinFish_anim_data": 0x8038c96c,
		"CoinFish_anim_data": 0x8038c96c,
		"MoveBG::@3365": 0x8038c98c,
		"MoveBG::@3366": 0x8038c99c,
		"MoveBG::MareFall_anim_data": 0x8038c9a8,
		"MareFall_anim_data": 0x8038c9a8,
		"MoveBG::@3367": 0x8038c9bc,
		"MoveBG::MonteRoot_anim_data": 0x8038c9e0,
		"MonteRoot_anim_data": 0x8038c9e0,
		"MoveBG::MonteRoot_hit_data_table": 0x8038c9f4,
		"MonteRoot_hit_data_table": 0x8038c9f4,
		"MoveBG::MonteRoot_obj_hit_info": 0x8038ca04,
		"MonteRoot_obj_hit_info": 0x8038ca04,
		"MoveBG::@3370": 0x8038ca14,
		"MoveBG::@3371": 0x8038ca20,
		"MoveBG::@3372": 0x8038ca30,
		"MoveBG::JumpMushroom_anim_data": 0x8038ca44,
		"JumpMushroom_anim_data": 0x8038ca44,
		"MoveBG::@3373": 0x8038ca6c,
		"MoveBG::@3374": 0x8038ca78,
		"MoveBG::MonteGoalFlag_anim_data": 0x8038caa8,
		"MonteGoalFlag_anim_data": 0x8038caa8,
		"MoveBG::MonteGoalFlag_hit_data_table": 0x8038cabc,
		"MonteGoalFlag_hit_data_table": 0x8038cabc,
		"MoveBG::MonteGoalFlag_obj_hit_info": 0x8038cacc,
		"MonteGoalFlag_obj_hit_info": 0x8038cacc,
		"MoveBG::HangingBridgeBoard_anim_data": 0x8038caf8,
		"HangingBridgeBoard_anim_data": 0x8038caf8,
		"MoveBG::HangingBridgeBoard_hit_data_table": 0x8038cb0c,
		"HangingBridgeBoard_hit_data_table": 0x8038cb0c,
		"MoveBG::HangingBridgeBoard_obj_hit_info": 0x8038cb1c,
		"HangingBridgeBoard_obj_hit_info": 0x8038cb1c,
		"MoveBG::SwingBoard_hit_data_table": 0x8038cb50,
		"SwingBoard_hit_data_table": 0x8038cb50,
		"MoveBG::SwingBoard_obj_hit_info": 0x8038cb60,
		"SwingBoard_obj_hit_info": 0x8038cb60,
		"MoveBG::Fluff_anim_data": 0x8038cb88,
		"Fluff_anim_data": 0x8038cb88,
		"MoveBG::Fluff_hit_data_table": 0x8038cb9c,
		"Fluff_hit_data_table": 0x8038cb9c,
		"MoveBG::Fluff_obj_hit_info": 0x8038cbac,
		"Fluff_obj_hit_info": 0x8038cbac,
		"MoveBG::Bathtub_anim_data": 0x8038cbe8,
		"Bathtub_anim_data": 0x8038cbe8,
		"MoveBG::BathtubStandBreaking_anim_data": 0x8038cc90,
		"BathtubStandBreaking_anim_data": 0x8038cc90,
		"MoveBG::ex1_turn_lift_anim_data": 0x8038cd10,
		"ex1_turn_lift_anim_data": 0x8038cd10,
		"MoveBG::y_turn_lift_anim_data": 0x8038cd94,
		"y_turn_lift_anim_data": 0x8038cd94,
		"MoveBG::Nail_anim_data": 0x8038ce00,
		"Nail_anim_data": 0x8038ce00,
		"MoveBG::Nail_hit_data_table": 0x8038ce14,
		"Nail_hit_data_table": 0x8038ce14,
		"MoveBG::Nail_obj_hit_info": 0x8038ce24,
		"Nail_obj_hit_info": 0x8038ce24,
		"MoveBG::PachinkoNail_anim_data": 0x8038ce54,
		"PachinkoNail_anim_data": 0x8038ce54,
		"MoveBG::FileLoadBlockA_anim_data": 0x8038cee0,
		"FileLoadBlockA_anim_data": 0x8038cee0,
		"MoveBG::FileLoadBlock_hit_data_table": 0x8038cf1c,
		"FileLoadBlock_hit_data_table": 0x8038cf1c,
		"MoveBG::FileLoadBlock_obj_hit_info": 0x8038cf2c,
		"FileLoadBlock_obj_hit_info": 0x8038cf2c,
		"MoveBG::FileLoadBlockB_anim_data": 0x8038cf78,
		"FileLoadBlockB_anim_data": 0x8038cf78,
		"MoveBG::FileLoadBlockC_anim_data": 0x8038cff0,
		"FileLoadBlockC_anim_data": 0x8038cff0,
		"MoveBG::@3728": 0x8038d03c,
		"MoveBG::@2183": 0x8038d0b8,
		"MoveBG::@2184": 0x8038d0f0,
		"MoveBG::@2185": 0x8038d124,
		"MoveBG::entry$3280": 0x8038d1b0,
		"entry$3280": 0x8038d1b0,
		"MoveBG::@3779": 0x8038d27c,
		"MoveBG::@3786": 0x8038d2f8,
		"MoveBG::@3806": 0x8038d408,
		"MoveBG::@3807": 0x8038d41c,
		"MoveBG::@3808": 0x8038d428,
		"MoveBG::@3809": 0x8038d434,
		"MoveBG::@3810": 0x8038d444,
		"MoveBG::@4173": 0x8038d6a0,
		"MoveBG::@4174": 0x8038d6c0,
		"MoveBG::@4175": 0x8038d6dc,
		"MoveBG::@4176": 0x8038d6f8,
		"MoveBG::@4177": 0x8038d718,
		"MoveBG::@4178": 0x8038d734,
		"MoveBG::@4179": 0x8038d750,
		"MoveBG::@4182": 0x8038d7b0,
		"MoveBG::@4183": 0x8038d7cc,
		"MoveBG::@4185": 0x8038d804,
		"MoveBG::@4186": 0x8038d824,
		"MoveBG::@4187": 0x8038d840,
		"MoveBG::@4188": 0x8038d860,
		"MoveBG::@3548": 0x8038da20,
		"MoveBG::@3549": 0x8038da38,
		"MoveBG::@4022": 0x8038da9c,
		"MoveBG::@4062": 0x8038dae0,
		"MoveBG::@4063": 0x8038dafc,
		"MoveBG::@4267": 0x8038db14,
		"MoveBG::@4506": 0x8038db34,
		"MoveBG::@4686": 0x8038db64,
		"MoveBG::@4687": 0x8038db84,
		"MoveBG::@2667": 0x8038dbb4,
		"MoveBG::@3462": 0x8038ddc4,
		"MoveBG::@2409": 0x8038de08,
		"MoveBG::@2410": 0x8038de38,
		"MoveBG::@2411": 0x8038de70,
		"MoveBG::@2412": 0x8038dea4,
		"MoveBG::@4036": 0x8038e120,
		"MoveBG::@4241": 0x8038e174,
		"MoveBG::@4295": 0x8038e194,
		"MoveBG::@2235": 0x8038e1b4,
		"MoveBG::@2291": 0x8038e1c8,
		"MoveBG::@2292": 0x8038e1f8,
		"MoveBG::@2293": 0x8038e230,
		"MoveBG::@2294": 0x8038e264,
		"MoveBG::@4013": 0x8038e2dc,
		"MoveBG::@4053": 0x8038e2fc,
		"MoveBG::@4149": 0x8038e31c,
		"MoveBG::@4592": 0x8038e348,
		"MoveBG::@5165": 0x8038e35c,
		"MoveBG::@5166": 0x8038e370,
		"MoveBG::@3440": 0x8038e594,
		"MoveBG::@2724": 0x8038e680,
		"MoveBG::@3686": 0x8038e744,
		"MoveBG::@3717": 0x8038e778,
		"MoveBG::@3718": 0x8038e78c,
		"MoveBG::@3746": 0x8038e7a0,
		"MoveBG::@3747": 0x8038e7c4,
		"MoveBG::@3871": 0x8038e808,
		"MoveBG::@4103": 0x8038e84c,
		"MoveBG::@4104": 0x8038e858,
		"MoveBG::@4109": 0x8038e8e8,
		"MoveBG::@4217": 0x8038e954,
		"MoveBG::@4493": 0x8038e97c,
		"MoveBG::@4495": 0x8038e994,
		"MoveBG::@4496": 0x8038e9a8,
		"@4496": 0x8038e9a8,
		"MoveBG::@4579": 0x8038e9bc,
		"MoveBG::@4580": 0x8038e9d0,
		"MoveBG::@4581": 0x8038e9e4,
		"MoveBG::@4790": 0x8038e9f8,
		"MoveBG::@4800": 0x8038ea10,
		"@4800": 0x8038ea10,
		"MoveBG::@4815": 0x8038ea20,
		"@4815": 0x8038ea20,
		"MoveBG::@4971": 0x8038ea34,
		"MoveBG::@4976": 0x8038ea5c,
		"MoveBG::@4978": 0x8038ea70,
		"MoveBG::@4979": 0x8038ea84,
		"MoveBG::@4985": 0x8038eaa0,
		"MoveBG::@5233": 0x8038eaac,
		"MoveBG::@3499": 0x8038ec48,
		"MoveBG::@3500": 0x8038ec60,
		"MoveBG::@3501": 0x8038ec6c,
		"MoveBG::@3696": 0x8038ed78,
		"MoveBG::@4075": 0x8038ee30,
		"MoveBG::@2211": 0x8038ee70,
		"MoveBG::@2212": 0x8038eea0,
		"MoveBG::@2213": 0x8038eed8,
		"MoveBG::@2214": 0x8038ef0c,
		"MoveBG::@2692": 0x8038ef3c,
		"MoveBG::@2498": 0x8038f140,
		"MoveBG::@2499": 0x8038f150,
		"MoveBG::@2500": 0x8038f160,
		"MoveBG::@2501": 0x8038f170,
		"MoveBG::@2464": 0x8038f278,
		"MoveBG::@2467": 0x8038f284,
		"MoveBG::@2468": 0x8038f290,
		"@2468": 0x8038f290,
		"MoveBG::@2469": 0x8038f29c,
		"@2469": 0x8038f29c,
		"MoveBG::@2470": 0x8038f2a8,
		"MoveBG::@2471": 0x8038f2b4,
		"MoveBG::@2473": 0x8038f2d0,
		"MoveBG::param_table": 0x8038f2f0,
		"param_table": 0x8038f2f0,
		"MoveBG::@2539": 0x8038f500,
		"MoveBG::@2540": 0x8038f524,
		"MoveBG::@2634": 0x8038f548,
		"MoveBG::@2639": 0x8038f5a8,
		"MoveBG::@2371": 0x8038f5e8,
		"MoveBG::@2372": 0x8038f618,
		"MoveBG::@2373": 0x8038f650,
		"MoveBG::@2374": 0x8038f684,
		"MoveBG::@2600": 0x8038fbd0,
		"MoveBG::@2188": 0x8038fc40,
		"MoveBG::@2520": 0x8038fd00,
		"MoveBG::@2522": 0x8038fd0c,
		"MoveBG::@2397": 0x8038fda0,
		"MoveBG::@2398": 0x8038fdd0,
		"MoveBG::@2399": 0x8038fe08,
		"MoveBG::@2400": 0x8038fe3c,
		"MoveBG::@2575": 0x8038feac,
		"MoveBG::@2576": 0x8038feb8,
		"MoveBG::@2577": 0x8038fec4,
		"MoveBG::@2578": 0x8038fed0,
		"MoveBG::cDirtyFileName": 0x803902e8,
		"MoveBG::cDirtyTexName": 0x8039030c,
		"MoveBG::@3679": 0x803903a0,
		"MoveBG::@3680": 0x803903c0,
		"MoveBG::@3715": 0x80390460,
		"MoveBG::@3755": 0x80390488,
		"MoveBG::@3758": 0x803904c0,
		"MoveBG::@2753": 0x803905e0,
		"MoveBG::@3927": 0x80390908,
		"MoveBG::@3928": 0x8039091c,
		"MoveBG::@2605": 0x80390a68,
		"MoveBG::@2659": 0x80390aac,
		"MoveBG::@2660": 0x80390abc,
		"MoveBG::@2661": 0x80390adc,
		"MoveBG::@4471": 0x80390d7c,
		"MoveBG::@4473": 0x80390d8c,
		"MoveBG::@4474": 0x80390d9c,
		"MoveBG::@5004": 0x80390db8,
		"MoveBG::@5411": 0x80390dc8,
		"MoveBG::@5412": 0x80390de8,
		"MoveBG::@5413": 0x80390e08,
		"MoveBG::@5414": 0x80390e2c,
		"MoveBG::@5842": 0x80390e80,
		"MoveBG::@5844": 0x80390e8c,
		"MoveBG::@5845": 0x80390eb0,
		"MoveBG::@5847": 0x80390ed4,
		"MoveBG::@5966": 0x80390ef4,
		"@5966": 0x80390ef4,
		"MoveBG::@5967": 0x80390f08,
		"@5967": 0x80390f08,
		"MoveBG::@5968": 0x80390f14,
		"@5968": 0x80390f14,
		"MoveBG::@5969": 0x80390f24,
		"@5969": 0x80390f24,
		"MoveBG::@5970": 0x80390f34,
		"@5970": 0x80390f34,
		"MoveBG::@5971": 0x80390f44,
		"@5971": 0x80390f44,
		"MoveBG::@5972": 0x80390f54,
		"@5972": 0x80390f54,
		"MoveBG::@5973": 0x80390f64,
		"@5973": 0x80390f64,
		"MoveBG::@5976": 0x80390f8c,
		"@5976": 0x80390f8c,
		"MoveBG::@5977": 0x80390f98,
		"@5977": 0x80390f98,
		"MoveBG::@5978": 0x80390fa4,
		"@5978": 0x80390fa4,
		"MoveBG::@5991": 0x80391008,
		"MoveBG::@5995": 0x80391018,
		"MoveBG::@5996": 0x80391024,
		"MoveBG::@5997": 0x80391030,
		"MoveBG::@5998": 0x80391040,
		"MoveBG::@2546": 0x80391088,
		"MoveBG::@2547": 0x803910b8,
		"MoveBG::@2548": 0x803910f0,
		"MoveBG::@2549": 0x80391124,
		"MoveBG::@2327": 0x80391348,
		"MoveBG::@2328": 0x80391378,
		"MoveBG::@2329": 0x803913b0,
		"MoveBG::@2330": 0x803913e4,
		"Map::@2324": 0x80391478,
		"Map::@2514": 0x80391568,
		"Map::@2516": 0x80391574,
		"Map::@2972": 0x80391580,
		"Map::@3338": 0x80391590,
		"Map::@3339": 0x803915ac,
		"Map::@3340": 0x803915bc,
		"Map::@3506": 0x803915cc,
		"Map::@3507": 0x803915e4,
		"Map::@3509": 0x803915f0,
		"Map::@3510": 0x80391604,
		"Map::@3511": 0x80391610,
		"Map::@3512": 0x80391624,
		"Map::@3566": 0x80391640,
		"Map::@3567": 0x80391658,
		"Map::@3701": 0x80391664,
		"Map::@3702": 0x80391678,
		"Map::@3703": 0x80391684,
		"Map::@3704": 0x803916a8,
		"Map::@3705": 0x803916cc,
		"Map::@3799": 0x803916e8,
		"Map::@3800": 0x803916fc,
		"Map::@3801": 0x80391724,
		"Map::@3802": 0x8039174c,
		"Map::@1526": 0x8039177c,
		"Map::@1766": 0x80391790,
		"@1766": 0x80391790,
		"Map::@1768": 0x8039179c,
		"Map::@2018": 0x803917a8,
		"Map::@2019": 0x803917b8,
		"Map::@2020": 0x803917c8,
		"Map::@2272": 0x80391810,
		"Map::@2273": 0x80391840,
		"Map::@2274": 0x80391878,
		"Map::@2275": 0x803918ac,
		"Map::@2604": 0x803918d0,
		"Map::@3076": 0x803918e8,
		"Map::@3151": 0x80391930,
		"Map::@3154": 0x8039193c,
		"Map::@3224": 0x8039194c,
		"Map::@3233": 0x8039195c,
		"Map::@2513": 0x80391a98,
		"Map::@2515": 0x80391aa4,
		"Map::@2517": 0x80391ab0,
		"Map::@2667": 0x80391b00,
		"Map::@2502": 0x80391b10,
		"Map::@2503": 0x80391b20,
		"Map::point_name_table$2639": 0x80391b40,
		"point_name_table$2639": 0x80391b40,
		"Map::@2197": 0x80391bf8,
		"Map::@2198": 0x80391c28,
		"Map::@2199": 0x80391c60,
		"Map::@2200": 0x80391c94,
		"Map::@2882": 0x80391d94,
		"Map::@2883": 0x80391da0,
		"Map::@2884": 0x80391db8,
		"Map::@2885": 0x80391ddc,
		"Map::@2886": 0x80391df0,
		"Map::@2887": 0x80391dfc,
		"Map::@2888": 0x80391e10,
		"Map::@2889": 0x80391e24,
		"Map::@2890": 0x80391e38,
		"Map::@2891": 0x80391e4c,
		"Map::@2892": 0x80391e60,
		"Map::@2893": 0x80391e6c,
		"Map::@2894": 0x80391e80,
		"Map::@2895": 0x80391e94,
		"Map::@2896": 0x80391eac,
		"Map::@2897": 0x80391eb8,
		"Map::@2898": 0x80391ec4,
		"Map::@2899": 0x80391ed0,
		"Map::actor_data_table": 0x80391edc,
		"actor_data_table": 0x80391edc,
		"Map::@2999": 0x80392690,
		"Map::sound_info": 0x8039269c,
		"sound_info": 0x8039269c,
		"Map::@3309": 0x803926d8,
		"Map::@3334": 0x803926e8,
		"Map::@3335": 0x803926fc,
		"Map::@3336": 0x80392714,
		"Map::@1937": 0x8039276c,
		"Map::@2174": 0x80392780,
		"Map::@2176": 0x8039278c,
		"Map::@2579": 0x80392798,
		"Map::@2178": 0x80392818,
		"Map::@2179": 0x80392848,
		"Map::@2180": 0x80392880,
		"Map::@2181": 0x803928b4,
		"Map::@2829": 0x803929ec,
		"Map::@2986": 0x803929f8,
		"Map::@2987": 0x80392a0c,
		"Map::@2988": 0x80392a20,
		"Map::@2720": 0x80392a80,
		"Map::@2771": 0x80392ba8,
		"Map::@2772": 0x80392bcc,
		"Map::@2784": 0x80392bf0,
		"Map::@3031": 0x80392c84,
		"Map::@1974": 0x80392ca0,
		"Map::@2925": 0x80392dc8,
		"Map::@2990": 0x80392e98,
		"Map::@3396": 0x80392eb0,
		"Map::@3403": 0x80392ed0,
		"Map::@3688": 0x80392ef4,
		"Map::@3699": 0x80392f04,
		"Map::@3735": 0x80392f14,
		"Map::@1900": 0x80392f30,
		"Map::@1907": 0x80392f44,
		"Map::@1996": 0x80392f50,
		"Map::@1997": 0x80392f80,
		"Map::@1998": 0x80392fb8,
		"Map::@1999": 0x80392fec,
		"Map::@3425": 0x8039304c,
		"Map::@4208": 0x8039306c,
		"Map::@4358": 0x80393078,
		"Map::@4359": 0x80393090,
		"Map::@4360": 0x803930a8,
		"Map::@4361": 0x803930c0,
		"Map::@4362": 0x803930dc,
		"Map::@4363": 0x803930fc,
		"Map::@4364": 0x8039311c,
		"Map::@4440": 0x80393134,
		"Map::@4441": 0x80393144,
		"@4441": 0x80393144,
		"Map::@4442": 0x80393150,
		"@4442": 0x80393150,
		"Map::@4748": 0x80393178,
		"Map::@4749": 0x80393184,
		"Map::@4752": 0x803931a8,
		"Map::@4755": 0x803931cc,
		"Map::@4758": 0x803931d8,
		"Map::@4762": 0x803931f8,
		"Map::@4764": 0x80393214,
		"Map::@4766": 0x80393220,
		"Map::@4768": 0x8039322c,
		"Map::@4832": 0x80393238,
		"Map::@4834": 0x80393258,
		"Map::@4835": 0x80393264,
		"Map::@4837": 0x8039327c,
		"Map::@4838": 0x80393288,
		"Map::@4844": 0x803932b8,
		"Map::@4855": 0x803932dc,
		"Map::@4858": 0x803932e8,
		"GC2D::@1772": 0x803932f8,
		"GC2D::@1953": 0x80393314,
		"GC2D::@2082": 0x80393328,
		"GC2D::@2084": 0x80393348,
		"GC2D::@2086": 0x80393368,
		"GC2D::scNozzleSoundList": 0x803933a8,
		"scNozzleSoundList": 0x803933a8,
		"GC2D::@2426": 0x803933d8,
		"GC2D::@2427": 0x80393408,
		"GC2D::@2428": 0x80393440,
		"GC2D::@2429": 0x80393474,
		"GC2D::@7074": 0x80393498,
		"@7074": 0x80393498,
		"GC2D::@7075": 0x803934cc,
		"@7075": 0x803934cc,
		"GC2D::@10723": 0x803934e8,
		"@10723": 0x803934e8,
		"GC2D::@11361": 0x803934f8,
		"@11361": 0x803934f8,
		"GC2D::@11365": 0x80393508,
		"@11365": 0x80393508,
		"GC2D::@11366": 0x80393514,
		"@11366": 0x80393514,
		"GC2D::@11367": 0x80393524,
		"@11367": 0x80393524,
		"GC2D::@11582": 0x80393530,
		"@11582": 0x80393530,
		"GC2D::@11583": 0x80393540,
		"@11583": 0x80393540,
		"GC2D::@11584": 0x80393560,
		"@11584": 0x80393560,
		"GC2D::@11585": 0x80393578,
		"@11585": 0x80393578,
		"GC2D::@1937": 0x8039359c,
		"GC2D::scTalkSoundList": 0x80393670,
		"scTalkSoundList": 0x80393670,
		"GC2D::@2719": 0x8039388c,
		"GC2D::@2722": 0x8039389c,
		"GC2D::@2723": 0x803938c4,
		"GC2D::@3560": 0x803938ec,
		"GC2D::@3561": 0x803938fc,
		"GC2D::@3562": 0x8039390c,
		"GC2D::@3563": 0x8039391c,
		"GC2D::@4204": 0x8039397c,
		"GC2D::@4205": 0x803939bc,
		"GC2D::@4977": 0x803939fc,
		"GC2D::@4978": 0x80393a0c,
		"GC2D::@4979": 0x80393a2c,
		"GC2D::@4980": 0x80393a44,
		"GC2D::@4981": 0x80393a60,
		"GC2D::@3284": 0x80393a98,
		"GC2D::@3340": 0x80393ab4,
		"GC2D::@3341": 0x80393ad0,
		"GC2D::@1991": 0x80393af0,
		"GC2D::@4430": 0x80393b20,
		"GC2D::@6860": 0x80393b30,
		"@6860": 0x80393b30,
		"GC2D::@6862": 0x80393b40,
		"@6862": 0x80393b40,
		"GC2D::@6863": 0x80393b4c,
		"@6863": 0x80393b4c,
		"GC2D::@6864": 0x80393b70,
		"@6864": 0x80393b70,
		"GC2D::@6865": 0x80393b90,
		"@6865": 0x80393b90,
		"GC2D::@6866": 0x80393bac,
		"@6866": 0x80393bac,
		"GC2D::@2112": 0x80393bcc,
		"GC2D::@2368": 0x80393be0,
		"GC2D::@2369": 0x80393c10,
		"GC2D::@2370": 0x80393c48,
		"GC2D::@2371": 0x80393c7c,
		"GC2D::@2685": 0x80393ca0,
		"GC2D::@2750": 0x80393cbc,
		"GC2D::@5142": 0x80393cd8,
		"GC2D::@7692": 0x80393ce8,
		"@7692": 0x80393ce8,
		"GC2D::@7693": 0x80393cfc,
		"@7693": 0x80393cfc,
		"GC2D::@7694": 0x80393d10,
		"@7694": 0x80393d10,
		"GC2D::@7695": 0x80393d24,
		"@7695": 0x80393d24,
		"GC2D::@8252": 0x80393d34,
		"@8252": 0x80393d34,
		"GC2D::@8253": 0x80393d4c,
		"@8253": 0x80393d4c,
		"GC2D::@8254": 0x80393d58,
		"@8254": 0x80393d58,
		"GC2D::@8255": 0x80393d68,
		"@8255": 0x80393d68,
		"GC2D::@8256": 0x80393d74,
		"@8256": 0x80393d74,
		"GC2D::@8258": 0x80393d98,
		"@8258": 0x80393d98,
		"GC2D::@1705": 0x80393dc4,
		"GC2D::@1917": 0x80393dd8,
		"GC2D::@3484": 0x80393de4,
		"GC2D::@3485": 0x80393df4,
		"GC2D::@3486": 0x80393e08,
		"GC2D::@3487": 0x80393e24,
		"GC2D::@2421": 0x80393e8c,
		"GC2D::@2422": 0x80393eb8,
		"GC2D::@3928": 0x80393ee4,
		"GC2D::@3929": 0x80393efc,
		"GC2D::@3930": 0x80393f1c,
		"GC2D::@3933": 0x80393f3c,
		"GC2D::@3934": 0x80393f58,
		"GC2D::@3935": 0x80393f74,
		"GC2D::@3936": 0x80393f90,
		"GC2D::@3040": 0x80393ff4,
		"GC2D::@3041": 0x80394004,
		"GC2D::@3042": 0x80394010,
		"GC2D::@3043": 0x80394020,
		"GC2D::@3044": 0x80394034,
		"GC2D::@3045": 0x80394044,
		"GC2D::@3046": 0x80394050,
		"GC2D::@3047": 0x8039405c,
		"GC2D::@3048": 0x80394068,
		"GC2D::@3049": 0x8039407c,
		"GC2D::@3050": 0x803940a4,
		"GC2D::@3051": 0x803940cc,
		"GC2D::@3052": 0x803940f4,
		"GC2D::@3053": 0x80394120,
		"GC2D::@3054": 0x80394148,
		"GC2D::@3055": 0x80394170,
		"GC2D::@3056": 0x80394198,
		"GC2D::@3057": 0x803941c0,
		"GC2D::@3058": 0x803941e8,
		"GC2D::@3059": 0x803941fc,
		"GC2D::@3060": 0x8039420c,
		"GC2D::@3066": 0x8039421c,
		"GC2D::@3128": 0x80394250,
		"GC2D::@1752": 0x8039426c,
		"GC2D::@2482": 0x80394280,
		"GC2D::@2483": 0x80394298,
		"GC2D::@1942": 0x803942fc,
		"GC2D::@4089": 0x80394310,
		"GC2D::@4090": 0x8039431c,
		"GC2D::@4091": 0x8039433c,
		"GC2D::@4092": 0x8039435c,
		"GC2D::@4093": 0x80394378,
		"GC2D::@4094": 0x8039439c,
		"GC2D::@4095": 0x803943c0,
		"GC2D::@4096": 0x803943e8,
		"GC2D::@4097": 0x80394410,
		"GC2D::@4098": 0x80394434,
		"GC2D::@1685": 0x80394450,
		"GC2D::@1686": 0x803944c4,
		"GC2D::@941": 0x80394560,
		"@941": 0x80394560,
		"GC2D::@1128": 0x80394578,
		"@1128": 0x80394578,
		"GC2D::@1591": 0x803945b0,
		"GC2D::@1851": 0x803945d8,
		"GC2D::@1938": 0x803945f4,
		"@unnamed@::cRumbleAnm": 0x80394608,
		"cRumbleAnm": 0x80394608,
		"@unnamed@::cSurMonteAnm": 0x80394658,
		"cSurMonteAnm": 0x80394658,
		"@unnamed@::cSurLTSpeakerAnm": 0x80394698,
		"cSurLTSpeakerAnm": 0x80394698,
		"@unnamed@::cSurRTSpeakerAnm": 0x803946c0,
		"cSurRTSpeakerAnm": 0x803946c0,
		"@unnamed@::cSurLBSpeakerAnm": 0x803946e8,
		"cSurLBSpeakerAnm": 0x803946e8,
		"@unnamed@::cSurRBSpeakerAnm": 0x80394710,
		"cSurRBSpeakerAnm": 0x80394710,
		"@unnamed@::cSteMonteAnm": 0x80394738,
		"cSteMonteAnm": 0x80394738,
		"@unnamed@::cSteLSpeakerAnm": 0x80394778,
		"cSteLSpeakerAnm": 0x80394778,
		"@unnamed@::cSteRSpeakerAnm": 0x803947a0,
		"cSteRSpeakerAnm": 0x803947a0,
		"@unnamed@::cMonoMonteAnm": 0x803947c8,
		"cMonoMonteAnm": 0x803947c8,
		"@unnamed@::cMonoSpeakerAnm": 0x803947d8,
		"cMonoSpeakerAnm": 0x803947d8,
		"@unnamed@::cSoundToggleItems": 0x803947e8,
		"cSoundToggleItems": 0x803947e8,
		"GC2D::@1557": 0x80394820,
		"GC2D::@1578": 0x80394834,
		"GC2D::@1579": 0x80394840,
		"Enemy::@4571": 0x803949c0,
		"@4571": 0x803949c0,
		"Enemy::@2141": 0x80394a44,
		"Enemy::@2673": 0x80394b18,
		"Enemy::@2685": 0x80394b30,
		"Enemy::@1973": 0x80394e38,
		"Enemy::@1974": 0x80394e68,
		"Enemy::@1975": 0x80394ea0,
		"Enemy::@1976": 0x80394ed4,
		"Enemy::@2760": 0x80394f3c,
		"Enemy::@2620": 0x80394fb0,
		"Enemy::@2270": 0x80395010,
		"Enemy::@2272": 0x8039507c,
		"Enemy::@2281": 0x80395180,
		"Enemy::@2283": 0x803951ec,
		"Enemy::replayLinkMonteMan": 0x80395854,
		"replayLinkMonteMan": 0x80395854,
		"Enemy::@6434": 0x8039593c,
		"@6434": 0x8039593c,
		"Enemy::@6435": 0x80395964,
		"@6435": 0x80395964,
		"Enemy::@6437": 0x803959c8,
		"@6437": 0x803959c8,
		"Enemy::@6438": 0x803959f0,
		"@6438": 0x803959f0,
		"Enemy::@6439": 0x80395a18,
		"@6439": 0x80395a18,
		"Enemy::@6440": 0x80395a40,
		"@6440": 0x80395a40,
		"Enemy::@6441": 0x80395a58,
		"@6441": 0x80395a58,
		"Enemy::@6442": 0x80395a64,
		"@6442": 0x80395a64,
		"Enemy::@6444": 0x80395a74,
		"@6444": 0x80395a74,
		"Enemy::@6445": 0x80395a80,
		"@6445": 0x80395a80,
		"Enemy::@6446": 0x80395a8c,
		"@6446": 0x80395a8c,
		"Enemy::@6448": 0x80395aa4,
		"@6448": 0x80395aa4,
		"Enemy::@6449": 0x80395ab0,
		"@6449": 0x80395ab0,
		"Enemy::@6450": 0x80395ac0,
		"@6450": 0x80395ac0,
		"Enemy::@6451": 0x80395acc,
		"@6451": 0x80395acc,
		"Enemy::@6455": 0x80395af8,
		"@6455": 0x80395af8,
		"Enemy::@6456": 0x80395b14,
		"@6456": 0x80395b14,
		"Enemy::@6457": 0x80395b30,
		"@6457": 0x80395b30,
		"Enemy::@6458": 0x80395b50,
		"@6458": 0x80395b50,
		"Enemy::@6461": 0x80395b74,
		"@6461": 0x80395b74,
		"Enemy::@6462": 0x80395b84,
		"@6462": 0x80395b84,
		"Enemy::@6463": 0x80395ba8,
		"@6463": 0x80395ba8,
		"Enemy::@6464": 0x80395bcc,
		"@6464": 0x80395bcc,
		"Enemy::@6465": 0x80395bf0,
		"@6465": 0x80395bf0,
		"Enemy::@6466": 0x80395bfc,
		"@6466": 0x80395bfc,
		"Enemy::@6467": 0x80395c08,
		"@6467": 0x80395c08,
		"Enemy::@6717": 0x80395cb0,
		"@6717": 0x80395cb0,
		"Enemy::@6718": 0x80395ccc,
		"@6718": 0x80395ccc,
		"Enemy::@6719": 0x80395ce4,
		"@6719": 0x80395ce4,
		"Enemy::@4075": 0x80396074,
		"Enemy::@4993": 0x80396080,
		"Enemy::@4994": 0x80396090,
		"Enemy::@5217": 0x803960b4,
		"Enemy::@5242": 0x803960fc,
		"Enemy::@5324": 0x80396108,
		"Enemy::@5330": 0x80396174,
		"Enemy::@5331": 0x8039618c,
		"Enemy::@5332": 0x803961a0,
		"Enemy::@5333": 0x803961b8,
		"Enemy::@5334": 0x803961cc,
		"Enemy::@5336": 0x803961dc,
		"Enemy::@5338": 0x803961ec,
		"Enemy::@5340": 0x80396214,
		"Enemy::@1961": 0x80396258,
		"Enemy::@1962": 0x80396288,
		"Enemy::@1963": 0x803962c0,
		"Enemy::@1964": 0x803962f4,
		"Enemy::@2248": 0x80396334,
		"Enemy::tevColorData$3149": 0x803966c4,
		"tevColorData$3149": 0x803966c4,
		"Enemy::@7551": 0x80396788,
		"Enemy::@7735": 0x803967d8,
		"@7735": 0x803967d8,
		"Enemy::@7736": 0x803967ec,
		"@7736": 0x803967ec,
		"Enemy::@7737": 0x803967f8,
		"@7737": 0x803967f8,
		"Enemy::@7738": 0x80396804,
		"@7738": 0x80396804,
		"Enemy::@7744": 0x80396810,
		"@7744": 0x80396810,
		"Enemy::@7755": 0x8039681c,
		"@7755": 0x8039681c,
		"Enemy::@7756": 0x80396834,
		"@7756": 0x80396834,
		"Enemy::@7777": 0x80396844,
		"@7777": 0x80396844,
		"Enemy::@7788": 0x80396858,
		"@7788": 0x80396858,
		"Enemy::@7821": 0x80396884,
		"@7821": 0x80396884,
		"Enemy::@7825": 0x8039689c,
		"@7825": 0x8039689c,
		"Enemy::@7828": 0x803968ac,
		"@7828": 0x803968ac,
		"Enemy::@7838": 0x803968c8,
		"@7838": 0x803968c8,
		"Enemy::@7904": 0x803968d8,
		"@7904": 0x803968d8,
		"Enemy::@7905": 0x803968f0,
		"Enemy::@7906": 0x80396900,
		"@7906": 0x80396900,
		"Enemy::@7907": 0x80396910,
		"@7907": 0x80396910,
		"Enemy::@7908": 0x80396924,
		"@7908": 0x80396924,
		"Enemy::@7909": 0x80396938,
		"@7909": 0x80396938,
		"Enemy::@7926": 0x8039694c,
		"@7926": 0x8039694c,
		"Enemy::@8179": 0x80396994,
		"@8179": 0x80396994,
		"Enemy::@8294": 0x803969a8,
		"@8294": 0x803969a8,
		"Enemy::@8297": 0x803969cc,
		"Enemy::@8298": 0x803969e0,
		"@8298": 0x803969e0,
		"Enemy::@8299": 0x803969f0,
		"@8299": 0x803969f0,
		"Enemy::@8300": 0x803969fc,
		"@8300": 0x803969fc,
		"Enemy::@8301": 0x80396a10,
		"@8301": 0x80396a10,
		"Enemy::@8302": 0x80396a24,
		"@8302": 0x80396a24,
		"Enemy::@8303": 0x80396a38,
		"Enemy::@8304": 0x80396a50,
		"@8304": 0x80396a50,
		"Enemy::@8305": 0x80396a5c,
		"@8305": 0x80396a5c,
		"Enemy::@8306": 0x80396a70,
		"@8306": 0x80396a70,
		"Enemy::@8307": 0x80396a84,
		"@8307": 0x80396a84,
		"Enemy::@8308": 0x80396a98,
		"@8308": 0x80396a98,
		"Enemy::@2539": 0x80396b88,
		"Enemy::@2541": 0x80396b94,
		"Enemy::@5905": 0x80396fa4,
		"Enemy::@5906": 0x80396fc4,
		"Enemy::@6361": 0x80397014,
		"@6361": 0x80397014,
		"Enemy::@6363": 0x80397028,
		"@6363": 0x80397028,
		"Enemy::@6365": 0x8039703c,
		"Enemy::@6366": 0x80397050,
		"Enemy::@6368": 0x80397060,
		"@6368": 0x80397060,
		"Enemy::@6369": 0x80397070,
		"@6369": 0x80397070,
		"Enemy::@6370": 0x80397080,
		"@6370": 0x80397080,
		"Enemy::@6372": 0x80397090,
		"@6372": 0x80397090,
		"Enemy::@6374": 0x803970a0,
		"@6374": 0x803970a0,
		"Enemy::@6375": 0x803970b0,
		"@6375": 0x803970b0,
		"Enemy::@6377": 0x803970bc,
		"@6377": 0x803970bc,
		"Enemy::@6378": 0x803970cc,
		"@6378": 0x803970cc,
		"Enemy::@6379": 0x803970dc,
		"@6379": 0x803970dc,
		"Enemy::@6380": 0x803970f0,
		"@6380": 0x803970f0,
		"Enemy::@6381": 0x80397104,
		"@6381": 0x80397104,
		"Enemy::@6383": 0x80397118,
		"@6383": 0x80397118,
		"Enemy::@6384": 0x80397128,
		"@6384": 0x80397128,
		"Enemy::@6388": 0x80397140,
		"@6388": 0x80397140,
		"Enemy::@6390": 0x8039714c,
		"@6390": 0x8039714c,
		"Enemy::@6391": 0x80397158,
		"@6391": 0x80397158,
		"Enemy::@6392": 0x80397168,
		"@6392": 0x80397168,
		"Enemy::@6397": 0x80397194,
		"@6397": 0x80397194,
		"Enemy::@6399": 0x803971a4,
		"@6399": 0x803971a4,
		"Enemy::@6400": 0x803971b4,
		"@6400": 0x803971b4,
		"Enemy::@6401": 0x803971c4,
		"@6401": 0x803971c4,
		"Enemy::@6402": 0x803971d8,
		"@6402": 0x803971d8,
		"Enemy::@6404": 0x803971e8,
		"@6404": 0x803971e8,
		"Enemy::@6405": 0x803971fc,
		"@6405": 0x803971fc,
		"Enemy::@6406": 0x80397210,
		"@6406": 0x80397210,
		"Enemy::@6407": 0x80397224,
		"@6407": 0x80397224,
		"Enemy::@6408": 0x80397238,
		"@6408": 0x80397238,
		"Enemy::@6409": 0x8039724c,
		"@6409": 0x8039724c,
		"Enemy::@2430": 0x8039734c,
		"Enemy::@2458": 0x80397358,
		"Enemy::@2478": 0x80397458,
		"@2478": 0x80397458,
		"Enemy::@2479": 0x80397464,
		"Enemy::@2480": 0x80397470,
		"Enemy::@2481": 0x8039747c,
		"Enemy::@2482": 0x80397488,
		"Enemy::@2483": 0x80397494,
		"Enemy::@2484": 0x803974a0,
		"Enemy::xzTable$2559": 0x803974ac,
		"xzTable$2559": 0x803974ac,
		"Enemy::@2121": 0x80397614,
		"Enemy::nameKuriTevColorData": 0x80397714,
		"nameKuriTevColorData": 0x80397714,
		"Enemy::@3662": 0x80397818,
		"Enemy::@3664": 0x80397828,
		"Enemy::@4528": 0x803978b4,
		"Enemy::@4529": 0x803978c0,
		"Enemy::@4530": 0x803978e4,
		"Enemy::@4531": 0x803978f4,
		"Enemy::@4536": 0x80397904,
		"Enemy::@4602": 0x80397914,
		"@4602": 0x80397914,
		"Enemy::@2325": 0x8039794c,
		"Enemy::@2565": 0x80397990,
		"Enemy::@4440": 0x80397b20,
		"Enemy::@5123": 0x80397be4,
		"Enemy::@5125": 0x80397c04,
		"Enemy::@5127": 0x80397c14,
		"Enemy::@5134": 0x80397c68,
		"Enemy::@5135": 0x80397c7c,
		"Enemy::@2396": 0x80397ce8,
		"Enemy::@2398": 0x80397cf4,
		"Enemy::@4939": 0x80397e44,
		"Enemy::@4941": 0x80397e54,
		"Enemy::@4943": 0x80397e64,
		"@4943": 0x80397e64,
		"Enemy::@4947": 0x80397e94,
		"Enemy::@4961": 0x80397f3c,
		"Enemy::@4964": 0x80397f68,
		"Enemy::@4966": 0x80397f88,
		"Enemy::@4968": 0x80397fac,
		"Enemy::@1604": 0x80397fe0,
		"Enemy::@1605": 0x80398010,
		"Enemy::@1606": 0x80398048,
		"Enemy::@2252": 0x803980a0,
		"Enemy::@2253": 0x803980b4,
		"Enemy::@2370": 0x803980e8,
		"Enemy::@2373": 0x80398184,
		"Enemy::@2112": 0x803981fc,
		"Enemy::idxarray$3675": 0x80398480,
		"idxarray$3675": 0x80398480,
		"Enemy::@3712": 0x803984d8,
		"Enemy::entry$3707": 0x80398530,
		"entry$3707": 0x80398530,
		"Enemy::@4690": 0x803985d8,
		"Enemy::@4697": 0x80398618,
		"Enemy::@5562": 0x80398784,
		"@5562": 0x80398784,
		"Enemy::@5563": 0x803987ac,
		"@5563": 0x803987ac,
		"Enemy::@5564": 0x803987d4,
		"@5564": 0x803987d4,
		"Enemy::@5565": 0x803987fc,
		"@5565": 0x803987fc,
		"Enemy::@5566": 0x80398820,
		"@5566": 0x80398820,
		"Enemy::@5578": 0x803989e4,
		"@5578": 0x803989e4,
		"Enemy::@5955": 0x80398a08,
		"@5955": 0x80398a08,
		"Enemy::@9156": 0x80398a94,
		"@9156": 0x80398a94,
		"Enemy::@9157": 0x80398aa4,
		"Enemy::@9185": 0x80398c2c,
		"@9185": 0x80398c2c,
		"Enemy::@9187": 0x80398c3c,
		"@9187": 0x80398c3c,
		"Enemy::@9188": 0x80398c50,
		"@9188": 0x80398c50,
		"Enemy::@9189": 0x80398c64,
		"@9189": 0x80398c64,
		"Enemy::@9191": 0x80398c74,
		"@9191": 0x80398c74,
		"Enemy::@9192": 0x80398c84,
		"@9192": 0x80398c84,
		"Enemy::@9193": 0x80398c94,
		"@9193": 0x80398c94,
		"Enemy::@9194": 0x80398ca4,
		"@9194": 0x80398ca4,
		"Enemy::@9196": 0x80398cb4,
		"@9196": 0x80398cb4,
		"Enemy::@2346": 0x80398cd4,
		"Enemy::@5269": 0x80399020,
		"Enemy::@5271": 0x80399038,
		"Enemy::@2151": 0x8039907c,
		"Enemy::cTelesaColor": 0x803991bc,
		"cTelesaColor": 0x803991bc,
		"Enemy::@5210": 0x803993d4,
		"Enemy::@5299": 0x803993e4,
		"Enemy::@5411": 0x80399430,
		"Enemy::@5414": 0x80399460,
		"Enemy::@5415": 0x80399470,
		"@5415": 0x80399470,
		"Enemy::@5417": 0x80399498,
		"Enemy::@2255": 0x803995a8,
		"Enemy::@2256": 0x803995e0,
		"Enemy::@2257": 0x80399614,
		"Enemy::@7288": 0x8039970c,
		"Enemy::@7289": 0x80399734,
		"Enemy::@7290": 0x80399760,
		"@7290": 0x80399760,
		"Enemy::@7427": 0x80399788,
		"@7427": 0x80399788,
		"Enemy::@7429": 0x803997a8,
		"@7429": 0x803997a8,
		"Enemy::@8399": 0x803997c0,
		"@8399": 0x803997c0,
		"Enemy::@8400": 0x803997d0,
		"@8400": 0x803997d0,
		"Enemy::@8401": 0x803997dc,
		"@8401": 0x803997dc,
		"Enemy::@8764": 0x803997e8,
		"@8764": 0x803997e8,
		"Enemy::@8765": 0x803997fc,
		"@8765": 0x803997fc,
		"Enemy::@8950": 0x80399810,
		"@8950": 0x80399810,
		"Enemy::@9111": 0x80399828,
		"@9111": 0x80399828,
		"Enemy::@9112": 0x80399834,
		"@9112": 0x80399834,
		"Enemy::@9114": 0x80399848,
		"@9114": 0x80399848,
		"Enemy::@9116": 0x8039986c,
		"@9116": 0x8039986c,
		"Enemy::@9117": 0x80399880,
		"@9117": 0x80399880,
		"Enemy::@9118": 0x8039988c,
		"@9118": 0x8039988c,
		"Enemy::@9120": 0x8039989c,
		"@9120": 0x8039989c,
		"Enemy::@9122": 0x803998a8,
		"@9122": 0x803998a8,
		"Enemy::@9124": 0x803998c0,
		"@9124": 0x803998c0,
		"Enemy::@9125": 0x803998d4,
		"@9125": 0x803998d4,
		"Enemy::@9126": 0x803998e8,
		"@9126": 0x803998e8,
		"Enemy::@9127": 0x803998fc,
		"@9127": 0x803998fc,
		"Enemy::@9129": 0x8039990c,
		"@9129": 0x8039990c,
		"Enemy::@9131": 0x8039991c,
		"@9131": 0x8039991c,
		"Enemy::@9133": 0x80399948,
		"@9133": 0x80399948,
		"Enemy::@9134": 0x8039995c,
		"@9134": 0x8039995c,
		"Enemy::@9135": 0x8039996c,
		"@9135": 0x8039996c,
		"Enemy::@9136": 0x80399980,
		"@9136": 0x80399980,
		"Enemy::@9137": 0x80399994,
		"@9137": 0x80399994,
		"Enemy::@9139": 0x803999a4,
		"@9139": 0x803999a4,
		"Enemy::@9141": 0x803999c8,
		"@9141": 0x803999c8,
		"Enemy::@9142": 0x803999e0,
		"@9142": 0x803999e0,
		"Enemy::@9144": 0x803999f4,
		"@9144": 0x803999f4,
		"Enemy::@9146": 0x80399a1c,
		"@9146": 0x80399a1c,
		"Enemy::@9148": 0x80399a2c,
		"@9148": 0x80399a2c,
		"Enemy::@9150": 0x80399a40,
		"@9150": 0x80399a40,
		"Enemy::@2233": 0x80399a50,
		"Enemy::@2154": 0x80399a6c,
		"Enemy::@2210": 0x80399a80,
		"Enemy::@2211": 0x80399ab0,
		"Enemy::@2212": 0x80399ae8,
		"Enemy::@2213": 0x80399b1c,
		"Enemy::@3113": 0x80399cbc,
		"Enemy::@3124": 0x80399eac,
		"Enemy::entry$3621": 0x80399f44,
		"entry$3621": 0x80399f44,
		"Enemy::entry$3626": 0x80399fc4,
		"entry$3626": 0x80399fc4,
		"Enemy::@5869": 0x8039a0b8,
		"Enemy::@5870": 0x8039a0d0,
		"Enemy::@5871": 0x8039a0f8,
		"Enemy::@5872": 0x8039a120,
		"Enemy::@5873": 0x8039a14c,
		"Enemy::@5874": 0x8039a178,
		"Enemy::@5875": 0x8039a1a4,
		"Enemy::@5877": 0x8039a1f8,
		"Enemy::@5878": 0x8039a220,
		"Enemy::@6555": 0x8039a2e8,
		"Enemy::@7211": 0x8039a2f8,
		"@7211": 0x8039a2f8,
		"Enemy::@7213": 0x8039a304,
		"@7213": 0x8039a304,
		"Enemy::@7215": 0x8039a318,
		"@7215": 0x8039a318,
		"Enemy::@7218": 0x8039a340,
		"@7218": 0x8039a340,
		"Enemy::@7220": 0x8039a360,
		"@7220": 0x8039a360,
		"Enemy::@7222": 0x8039a384,
		"@7222": 0x8039a384,
		"Enemy::@7223": 0x8039a390,
		"@7223": 0x8039a390,
		"Enemy::@7224": 0x8039a3a0,
		"@7224": 0x8039a3a0,
		"Enemy::@8199": 0x8039a3c8,
		"@8199": 0x8039a3c8,
		"Enemy::@8310": 0x8039a3dc,
		"@8310": 0x8039a3dc,
		"Enemy::@8311": 0x8039a3f0,
		"@8311": 0x8039a3f0,
		"Enemy::@8312": 0x8039a404,
		"@8312": 0x8039a404,
		"Enemy::@8313": 0x8039a414,
		"@8313": 0x8039a414,
		"Enemy::@8314": 0x8039a42c,
		"@8314": 0x8039a42c,
		"Enemy::@8315": 0x8039a43c,
		"@8315": 0x8039a43c,
		"Enemy::@8316": 0x8039a450,
		"@8316": 0x8039a450,
		"Enemy::@8317": 0x8039a45c,
		"@8317": 0x8039a45c,
		"Enemy::@8318": 0x8039a46c,
		"@8318": 0x8039a46c,
		"Enemy::@8320": 0x8039a480,
		"@8320": 0x8039a480,
		"Enemy::@8322": 0x8039a490,
		"Enemy::@8325": 0x8039a4b4,
		"Enemy::@8327": 0x8039a4d4,
		"Enemy::@8329": 0x8039a4e8,
		"@8329": 0x8039a4e8,
		"Enemy::@8331": 0x8039a510,
		"Enemy::@8334": 0x8039a538,
		"Enemy::@8335": 0x8039a548,
		"Enemy::@8336": 0x8039a55c,
		"Enemy::@8338": 0x8039a570,
		"Enemy::@4821": 0x8039a84c,
		"@4821": 0x8039a84c,
		"Enemy::@4859": 0x8039a864,
		"Enemy::entry$3488": 0x8039aee8,
		"entry$3488": 0x8039aee8,
		"Enemy::@6087": 0x8039b394,
		"@6087": 0x8039b394,
		"Enemy::@6088": 0x8039b3a0,
		"@6088": 0x8039b3a0,
		"Enemy::@6089": 0x8039b3ac,
		"Enemy::@6091": 0x8039b3d8,
		"Enemy::@6093": 0x8039b3f0,
		"Enemy::@6099": 0x8039b458,
		"Enemy::@6101": 0x8039b480,
		"Enemy::entry$2906": 0x8039b5f0,
		"entry$2906": 0x8039b5f0,
		"Enemy::@2110": 0x8039b67c,
		"Enemy::@2495": 0x8039b690,
		"Enemy::@2497": 0x8039b69c,
		"Enemy::@2719": 0x8039b6a8,
		"Enemy::@2720": 0x8039b6d8,
		"Enemy::@2722": 0x8039b744,
		"Enemy::@3483": 0x8039b800,
		"Enemy::@3485": 0x8039b828,
		"Enemy::entry$3482": 0x8039b83c,
		"entry$3482": 0x8039b83c,
		"Enemy::@7585": 0x8039ba9c,
		"Enemy::@7586": 0x8039baac,
		"@7586": 0x8039baac,
		"Enemy::@7587": 0x8039babc,
		"@7587": 0x8039babc,
		"Enemy::@7589": 0x8039bacc,
		"@7589": 0x8039bacc,
		"Enemy::@7590": 0x8039badc,
		"@7590": 0x8039badc,
		"Enemy::@7593": 0x8039bb14,
		"@7593": 0x8039bb14,
		"Enemy::@7595": 0x8039bb3c,
		"@7595": 0x8039bb3c,
		"Enemy::@7597": 0x8039bb5c,
		"@7597": 0x8039bb5c,
		"Enemy::@7598": 0x8039bb6c,
		"@7598": 0x8039bb6c,
		"Enemy::@7599": 0x8039bb7c,
		"@7599": 0x8039bb7c,
		"Enemy::@7600": 0x8039bb90,
		"@7600": 0x8039bb90,
		"Enemy::@7602": 0x8039bb9c,
		"@7602": 0x8039bb9c,
		"Enemy::@7604": 0x8039bbb0,
		"@7604": 0x8039bbb0,
		"Enemy::@5741": 0x8039bdc0,
		"@5741": 0x8039bdc0,
		"Enemy::@5742": 0x8039bdd0,
		"@5742": 0x8039bdd0,
		"Enemy::@5743": 0x8039bde0,
		"Enemy::@5744": 0x8039bdf4,
		"Enemy::@5745": 0x8039be04,
		"@5745": 0x8039be04,
		"Enemy::@5747": 0x8039be18,
		"@5747": 0x8039be18,
		"Enemy::@5748": 0x8039be2c,
		"@5748": 0x8039be2c,
		"Enemy::@5750": 0x8039be44,
		"@5750": 0x8039be44,
		"Enemy::@5751": 0x8039be5c,
		"@5751": 0x8039be5c,
		"Enemy::@5752": 0x8039be70,
		"@5752": 0x8039be70,
		"Enemy::@5753": 0x8039be84,
		"@5753": 0x8039be84,
		"Enemy::@5754": 0x8039be9c,
		"@5754": 0x8039be9c,
		"Enemy::@5755": 0x8039beb4,
		"@5755": 0x8039beb4,
		"Enemy::@5756": 0x8039bec8,
		"@5756": 0x8039bec8,
		"Enemy::@5757": 0x8039bedc,
		"@5757": 0x8039bedc,
		"Enemy::@5758": 0x8039bef4,
		"@5758": 0x8039bef4,
		"Enemy::@5759": 0x8039bf0c,
		"@5759": 0x8039bf0c,
		"Enemy::@5761": 0x8039bf1c,
		"@5761": 0x8039bf1c,
		"Enemy::@5762": 0x8039bf30,
		"@5762": 0x8039bf30,
		"Enemy::@5763": 0x8039bf40,
		"@5763": 0x8039bf40,
		"Enemy::@5765": 0x8039bf4c,
		"@5765": 0x8039bf4c,
		"Enemy::@5767": 0x8039bf5c,
		"@5767": 0x8039bf5c,
		"Enemy::@5768": 0x8039bf6c,
		"@5768": 0x8039bf6c,
		"Enemy::@5770": 0x8039bf7c,
		"@5770": 0x8039bf7c,
		"Enemy::@5771": 0x8039bf88,
		"@5771": 0x8039bf88,
		"Enemy::@5772": 0x8039bf98,
		"@5772": 0x8039bf98,
		"Enemy::@2150": 0x8039bfbc,
		"Enemy::@3324": 0x8039c18c,
		"Enemy::@3338": 0x8039c1a4,
		"Enemy::@4612": 0x8039c20c,
		"Enemy::@4613": 0x8039c22c,
		"Enemy::@4484": 0x8039c6a4,
		"Enemy::@4485": 0x8039c6b8,
		"Enemy::@2429": 0x8039c6dc,
		"Enemy::@2641": 0x8039c720,
		"Enemy::@2642": 0x8039c758,
		"Enemy::@2643": 0x8039c78c,
		"Enemy::@3072": 0x8039c884,
		"Enemy::@3073": 0x8039c8b0,
		"Enemy::@3074": 0x8039c8dc,
		"Enemy::@3077": 0x8039c95c,
		"Enemy::@3078": 0x8039c988,
		"Enemy::@4997": 0x8039ca30,
		"Enemy::@5050": 0x8039ca78,
		"Enemy::@5053": 0x8039ca98,
		"Enemy::@5054": 0x8039caa8,
		"Enemy::@5056": 0x8039cabc,
		"Enemy::@5059": 0x8039cae0,
		"Enemy::@5060": 0x8039caec,
		"Enemy::@2315": 0x8039cb0c,
		"Enemy::@2554": 0x8039cb20,
		"Enemy::@2555": 0x8039cb50,
		"Enemy::xzTable$3488": 0x8039cd50,
		"xzTable$3488": 0x8039cd50,
		"Enemy::@3934": 0x8039cd70,
		"Enemy::@3936": 0x8039cd9c,
		"Enemy::@6151": 0x8039ce68,
		"Enemy::@7630": 0x8039cea0,
		"@7630": 0x8039cea0,
		"Enemy::@7633": 0x8039cec4,
		"@7633": 0x8039cec4,
		"Enemy::@7634": 0x8039ced0,
		"@7634": 0x8039ced0,
		"Enemy::@7635": 0x8039cedc,
		"@7635": 0x8039cedc,
		"Enemy::@7636": 0x8039cee8,
		"Enemy::@7637": 0x8039cef4,
		"Enemy::@7638": 0x8039cf00,
		"Enemy::@7639": 0x8039cf0c,
		"Enemy::@7640": 0x8039cf18,
		"Enemy::@7641": 0x8039cf24,
		"Enemy::@7642": 0x8039cf30,
		"Enemy::@7643": 0x8039cf3c,
		"Enemy::@7644": 0x8039cf48,
		"Enemy::@7645": 0x8039cf54,
		"Enemy::@7646": 0x8039cf60,
		"Enemy::@7647": 0x8039cf6c,
		"Enemy::@7648": 0x8039cf78,
		"Enemy::@7649": 0x8039cf84,
		"Enemy::@7650": 0x8039cf90,
		"Enemy::@7651": 0x8039cf9c,
		"Enemy::@7652": 0x8039cfa8,
		"@7652": 0x8039cfa8,
		"Enemy::@7677": 0x8039d348,
		"@7677": 0x8039d348,
		"Enemy::@7678": 0x8039d358,
		"@7678": 0x8039d358,
		"Enemy::@7679": 0x8039d364,
		"@7679": 0x8039d364,
		"Enemy::@7968": 0x8039d3d8,
		"@7968": 0x8039d3d8,
		"Enemy::@7969": 0x8039d3f0,
		"@7969": 0x8039d3f0,
		"Enemy::@8535": 0x8039d400,
		"@8535": 0x8039d400,
		"Enemy::@8538": 0x8039d40c,
		"@8538": 0x8039d40c,
		"Enemy::@8598": 0x8039d424,
		"@8598": 0x8039d424,
		"Enemy::@8599": 0x8039d434,
		"@8599": 0x8039d434,
		"Enemy::@8600": 0x8039d444,
		"@8600": 0x8039d444,
		"Enemy::@8601": 0x8039d454,
		"@8601": 0x8039d454,
		"Enemy::@8602": 0x8039d464,
		"@8602": 0x8039d464,
		"Enemy::@8603": 0x8039d478,
		"@8603": 0x8039d478,
		"Enemy::@8604": 0x8039d48c,
		"@8604": 0x8039d48c,
		"Enemy::@8605": 0x8039d498,
		"@8605": 0x8039d498,
		"Enemy::@8606": 0x8039d4a8,
		"@8606": 0x8039d4a8,
		"Enemy::@8607": 0x8039d4b8,
		"@8607": 0x8039d4b8,
		"Enemy::@8608": 0x8039d4cc,
		"@8608": 0x8039d4cc,
		"Enemy::@8609": 0x8039d4dc,
		"@8609": 0x8039d4dc,
		"Enemy::@8610": 0x8039d4ec,
		"@8610": 0x8039d4ec,
		"Enemy::@8611": 0x8039d508,
		"@8611": 0x8039d508,
		"Enemy::@8612": 0x8039d520,
		"@8612": 0x8039d520,
		"Enemy::@8613": 0x8039d530,
		"@8613": 0x8039d530,
		"Enemy::@8614": 0x8039d544,
		"@8614": 0x8039d544,
		"Enemy::@8615": 0x8039d558,
		"@8615": 0x8039d558,
		"Enemy::@8616": 0x8039d56c,
		"@8616": 0x8039d56c,
		"Enemy::@8800": 0x8039d57c,
		"@8800": 0x8039d57c,
		"Enemy::@9058": 0x8039d594,
		"@9058": 0x8039d594,
		"Enemy::@9060": 0x8039d5b4,
		"@9060": 0x8039d5b4,
		"Enemy::@9061": 0x8039d5c4,
		"@9061": 0x8039d5c4,
		"Enemy::@9062": 0x8039d5d0,
		"@9062": 0x8039d5d0,
		"Enemy::@9065": 0x8039d5f0,
		"@9065": 0x8039d5f0,
		"Enemy::entry$2170": 0x8039d6f0,
		"entry$2170": 0x8039d6f0,
		"Enemy::@2328": 0x8039d708,
		"Enemy::@2329": 0x8039d720,
		"Enemy::@2427": 0x8039d760,
		"Enemy::@3190": 0x8039d934,
		"Enemy::xzTable$3107": 0x8039dbc0,
		"xzTable$3107": 0x8039dbc0,
		"Enemy::@3833": 0x8039dc08,
		"Enemy::@5157": 0x8039dc54,
		"Enemy::@5158": 0x8039dc68,
		"Enemy::@5159": 0x8039dc7c,
		"Enemy::@5778": 0x8039dc94,
		"@5778": 0x8039dc94,
		"Enemy::@5779": 0x8039dcb4,
		"@5779": 0x8039dcb4,
		"Enemy::@5780": 0x8039dcc0,
		"@5780": 0x8039dcc0,
		"Enemy::@5782": 0x8039dccc,
		"@5782": 0x8039dccc,
		"Enemy::@5784": 0x8039dcf4,
		"@5784": 0x8039dcf4,
		"Enemy::@6073": 0x8039de0c,
		"@6073": 0x8039de0c,
		"Enemy::@6156": 0x8039de5c,
		"Enemy::@6158": 0x8039de6c,
		"@6158": 0x8039de6c,
		"Enemy::@6161": 0x8039dea4,
		"@6161": 0x8039dea4,
		"Enemy::@6169": 0x8039df34,
		"Enemy::entry$3312": 0x8039e108,
		"entry$3312": 0x8039e108,
		"Enemy::eyeTable$3627": 0x8039e194,
		"eyeTable$3627": 0x8039e194,
		"Enemy::@6796": 0x8039e330,
		"@6796": 0x8039e330,
		"Enemy::@6797": 0x8039e340,
		"@6797": 0x8039e340,
		"Enemy::@6798": 0x8039e350,
		"@6798": 0x8039e350,
		"Enemy::@7895": 0x8039e364,
		"@7895": 0x8039e364,
		"Enemy::@7896": 0x8039e374,
		"@7896": 0x8039e374,
		"Enemy::@7954": 0x8039e38c,
		"@7954": 0x8039e38c,
		"Enemy::@7955": 0x8039e3b4,
		"@7955": 0x8039e3b4,
		"Enemy::@8097": 0x8039e6c0,
		"@8097": 0x8039e6c0,
		"Enemy::@8102": 0x8039e704,
		"@8102": 0x8039e704,
		"Enemy::@8104": 0x8039e71c,
		"@8104": 0x8039e71c,
		"Enemy::@8105": 0x8039e734,
		"@8105": 0x8039e734,
		"Enemy::@8106": 0x8039e744,
		"@8106": 0x8039e744,
		"Enemy::@8107": 0x8039e754,
		"@8107": 0x8039e754,
		"Enemy::@8109": 0x8039e764,
		"@8109": 0x8039e764,
		"Enemy::@8110": 0x8039e778,
		"@8110": 0x8039e778,
		"Enemy::@8111": 0x8039e78c,
		"@8111": 0x8039e78c,
		"Enemy::@8112": 0x8039e79c,
		"@8112": 0x8039e79c,
		"Enemy::@8122": 0x8039e870,
		"@8122": 0x8039e870,
		"Enemy::@8910": 0x8039e884,
		"@8910": 0x8039e884,
		"Enemy::@8912": 0x8039e89c,
		"@8912": 0x8039e89c,
		"Enemy::@9004": 0x8039e8ac,
		"@9004": 0x8039e8ac,
		"Enemy::@9012": 0x8039e8d0,
		"@9012": 0x8039e8d0,
		"Enemy::@9054": 0x8039e8e0,
		"@9054": 0x8039e8e0,
		"Enemy::@9055": 0x8039e90c,
		"@9055": 0x8039e90c,
		"Enemy::@9056": 0x8039e938,
		"@9056": 0x8039e938,
		"Enemy::@2118": 0x8039ed9c,
		"Enemy::@2359": 0x8039ee18,
		"Enemy::@2695": 0x8039ef64,
		"Enemy::@2701": 0x8039f064,
		"Enemy::@4217": 0x8039f188,
		"Enemy::@4297": 0x8039f228,
		"@4297": 0x8039f228,
		"Enemy::@5204": 0x8039f290,
		"Enemy::@5650": 0x8039f348,
		"@5650": 0x8039f348,
		"Enemy::@5651": 0x8039f364,
		"Enemy::@5652": 0x8039f374,
		"Enemy::@5653": 0x8039f38c,
		"Enemy::@5665": 0x8039f3b4,
		"Enemy::@2449": 0x8039f568,
		"Enemy::@5346": 0x8039f694,
		"Enemy::@5348": 0x8039f6b0,
		"Enemy::@5349": 0x8039f6c0,
		"Enemy::@5350": 0x8039f6d0,
		"Enemy::@5351": 0x8039f6e4,
		"Enemy::@5353": 0x8039f704,
		"Enemy::@5354": 0x8039f714,
		"Enemy::@2261": 0x8039f8a4,
		"Enemy::entry$2260": 0x8039f8bc,
		"entry$2260": 0x8039f8bc,
		"Enemy::@1597": 0x8039f938,
		"Enemy::@2029": 0x8039f9f8,
		"Enemy::@2031": 0x8039fa08,
		"Enemy::entry$2758": 0x8039fb28,
		"entry$2758": 0x8039fb28,
		"Enemy::entry$2761": 0x8039fb50,
		"entry$2761": 0x8039fb50,
		"Enemy::entry$2764": 0x8039fb78,
		"entry$2764": 0x8039fb78,
		"Enemy::entry$2768": 0x8039fba0,
		"entry$2768": 0x8039fba0,
		"Enemy::@2004": 0x8039fcd0,
		"Enemy::@2005": 0x8039fd00,
		"Enemy::@2006": 0x8039fd38,
		"Enemy::@2007": 0x8039fd6c,
		"Enemy::@2353": 0x8039fd9c,
		"Enemy::@2715": 0x8039fe10,
		"Enemy::@4364": 0x8039fe54,
		"Enemy::@4365": 0x8039fe68,
		"Enemy::@4833": 0x8039fe7c,
		"Enemy::@4834": 0x8039fe90,
		"Enemy::@2220": 0x8039fef0,
		"Enemy::@2221": 0x8039ff20,
		"Enemy::@2222": 0x8039ff58,
		"Enemy::@2223": 0x8039ff8c,
		"Enemy::sBodyBckIndex$2891": 0x803a0018,
		"sBodyBckIndex$2891": 0x803a0018,
		"Enemy::sHeadBckIndex$2906": 0x803a0060,
		"sHeadBckIndex$2906": 0x803a0060,
		"Enemy::sHeadBtpIndex$2907": 0x803a00a8,
		"sHeadBtpIndex$2907": 0x803a00a8,
		"Enemy::sHeadBtkIndex$2908": 0x803a00f0,
		"sHeadBtkIndex$2908": 0x803a00f0,
		"Enemy::@1637": 0x803a0188,
		"Enemy::@1639": 0x803a01a0,
		"Enemy::@1641": 0x803a01b4,
		"Enemy::@1643": 0x803a01cc,
		"Enemy::@1645": 0x803a01e0,
		"@1645": 0x803a01e0,
		"Enemy::@1646": 0x803a01f4,
		"@1646": 0x803a01f4,
		"Enemy::@1648": 0x803a0204,
		"@1648": 0x803a0204,
		"Enemy::@1650": 0x803a0218,
		"Enemy::@1652": 0x803a022c,
		"Enemy::@1654": 0x803a0244,
		"@1654": 0x803a0244,
		"Enemy::@1656": 0x803a025c,
		"@1656": 0x803a025c,
		"Enemy::@1657": 0x803a0274,
		"Enemy::@1658": 0x803a0288,
		"Enemy::@1660": 0x803a02a0,
		"Enemy::@1661": 0x803a02b4,
		"Enemy::@1662": 0x803a02d0,
		"Enemy::@1666": 0x803a02f8,
		"Enemy::@1667": 0x803a030c,
		"Enemy::@1669": 0x803a031c,
		"Enemy::@1671": 0x803a032c,
		"Enemy::@1673": 0x803a034c,
		"Enemy::@1674": 0x803a0364,
		"Enemy::@1675": 0x803a037c,
		"Enemy::@1676": 0x803a0390,
		"Enemy::@1677": 0x803a03a4,
		"@1677": 0x803a03a4,
		"Enemy::@1678": 0x803a03b8,
		"@1678": 0x803a03b8,
		"Enemy::@1679": 0x803a03cc,
		"@1679": 0x803a03cc,
		"Enemy::@1681": 0x803a03e4,
		"Enemy::@1682": 0x803a03f8,
		"Enemy::@1684": 0x803a040c,
		"Enemy::@1686": 0x803a0420,
		"Enemy::@1687": 0x803a0438,
		"Enemy::@1778": 0x803a0448,
		"Enemy::@1780": 0x803a0458,
		"Enemy::@1786": 0x803a0494,
		"Enemy::@1788": 0x803a04a8,
		"@1788": 0x803a04a8,
		"Enemy::@1792": 0x803a04d0,
		"@1792": 0x803a04d0,
		"Enemy::@1793": 0x803a04e4,
		"@1793": 0x803a04e4,
		"Enemy::@1802": 0x803a055c,
		"Enemy::@1803": 0x803a0570,
		"Enemy::@1805": 0x803a0584,
		"@1805": 0x803a0584,
		"Enemy::@1806": 0x803a0598,
		"Enemy::@1808": 0x803a05a8,
		"Enemy::@1810": 0x803a05b8,
		"Enemy::@1812": 0x803a05cc,
		"@1812": 0x803a05cc,
		"Enemy::@1814": 0x803a05e0,
		"@1814": 0x803a05e0,
		"Enemy::@1816": 0x803a05f8,
		"Enemy::@1818": 0x803a0610,
		"Enemy::@1820": 0x803a0628,
		"Enemy::@1821": 0x803a0640,
		"@1821": 0x803a0640,
		"Enemy::@1822": 0x803a0658,
		"@1822": 0x803a0658,
		"Enemy::@1824": 0x803a066c,
		"@1824": 0x803a066c,
		"Enemy::@1825": 0x803a0680,
		"Enemy::@2560": 0x803a0754,
		"Enemy::@4244": 0x803a0890,
		"@4244": 0x803a0890,
		"Enemy::@4245": 0x803a08a4,
		"Enemy::entry$2988": 0x803a0b40,
		"entry$2988": 0x803a0b40,
		"Enemy::@4875": 0x803a0b9c,
		"@4875": 0x803a0b9c,
		"Enemy::@5537": 0x803a0c68,
		"@5537": 0x803a0c68,
		"Enemy::@2434": 0x803a0e20,
		"@2434": 0x803a0e20,
		"Enemy::@2435": 0x803a0e50,
		"@2435": 0x803a0e50,
		"Enemy::@2436": 0x803a0e88,
		"@2436": 0x803a0e88,
		"Enemy::@2437": 0x803a0ebc,
		"Enemy::sSnortStepFrames": 0x803a0ee0,
		"sSnortStepFrames": 0x803a0ee0,
		"Enemy::@2267": 0x803a1130,
		"Enemy::entry$2266": 0x803a1144,
		"entry$2266": 0x803a1144,
		"Enemy::@2277": 0x803a115c,
		"Enemy::entry$2836": 0x803a1280,
		"entry$2836": 0x803a1280,
		"Enemy::@3211": 0x803a12b0,
		"Enemy::@2444": 0x803a12e8,
		"Enemy::idx$3298": 0x803a1438,
		"idx$3298": 0x803a1438,
		"Enemy::zangle$3575": 0x803a1448,
		"zangle$3575": 0x803a1448,
		"Enemy::zangle$3580": 0x803a1458,
		"zangle$3580": 0x803a1458,
		"Enemy::zangle$3584": 0x803a1468,
		"zangle$3584": 0x803a1468,
		"Enemy::zangle$3586": 0x803a1478,
		"zangle$3586": 0x803a1478,
		"Enemy::@5287": 0x803a14bc,
		"Enemy::@5288": 0x803a14d0,
		"Enemy::@5289": 0x803a14dc,
		"Enemy::@6666": 0x803a15fc,
		"Enemy::@6667": 0x803a160c,
		"@6667": 0x803a160c,
		"Enemy::@2122": 0x803a1664,
		"Enemy::@2363": 0x803a16a8,
		"Enemy::@2365": 0x803a1714,
		"Enemy::tevColorData1$2781": 0x803a1738,
		"tevColorData1$2781": 0x803a1738,
		"Enemy::tevColorData2$2782": 0x803a1778,
		"tevColorData2$2782": 0x803a1778,
		"Enemy::entry$2669": 0x803a1900,
		"entry$2669": 0x803a1900,
		"Enemy::@1755": 0x803a19d0,
		"Enemy::@1756": 0x803a1a00,
		"Enemy::@1757": 0x803a1a38,
		"Enemy::@1758": 0x803a1a6c,
		"Enemy::@1941": 0x803a1abc,
		"Enemy::@1942": 0x803a1aec,
		"Enemy::@1943": 0x803a1b1c,
		"Enemy::@1948": 0x803a1c14,
		"Enemy::@1949": 0x803a1c44,
		"Enemy::@1950": 0x803a1c70,
		"Enemy::@1951": 0x803a1c9c,
		"Enemy::@1952": 0x803a1cc8,
		"Enemy::@1953": 0x803a1cf4,
		"Enemy::@1954": 0x803a1d2c,
		"Enemy::@1956": 0x803a1d88,
		"Enemy::@2603": 0x803a1dd8,
		"Enemy::@2605": 0x803a1e40,
		"Enemy::@2587": 0x803a2018,
		"Enemy::@2588": 0x803a2040,
		"Enemy::@2589": 0x803a2068,
		"Enemy::entry$2838": 0x803a2098,
		"entry$2838": 0x803a2098,
		"Enemy::@3742": 0x803a2160,
		"Enemy::entry$3295": 0x803a2710,
		"entry$3295": 0x803a2710,
		"Enemy::@3477": 0x803a2870,
		"Enemy::@2766": 0x803a2ab8,
		"Enemy::entry$2872": 0x803a2bfc,
		"entry$2872": 0x803a2bfc,
		"Enemy::@3285": 0x803a2c44,
		"Enemy::@3287": 0x803a2c50,
		"Enemy::entry$3350": 0x803a2f1c,
		"entry$3350": 0x803a2f1c,
		"Enemy::@6000": 0x803a307c,
		"@6000": 0x803a307c,
		"Enemy::@6001": 0x803a308c,
		"@6001": 0x803a308c,
		"Enemy::@6002": 0x803a30a4,
		"@6002": 0x803a30a4,
		"Enemy::@6063": 0x803a3224,
		"@6063": 0x803a3224,
		"Enemy::@6065": 0x803a323c,
		"@6065": 0x803a323c,
		"Enemy::@6066": 0x803a324c,
		"@6066": 0x803a324c,
		"Enemy::@6067": 0x803a3264,
		"@6067": 0x803a3264,
		"Enemy::@6068": 0x803a3274,
		"@6068": 0x803a3274,
		"Enemy::@6069": 0x803a328c,
		"@6069": 0x803a328c,
		"Enemy::@1529": 0x803a32b4,
		"@1529": 0x803a32b4,
		"Enemy::@1608": 0x803a32f8,
		"Enemy::@1609": 0x803a3330,
		"Enemy::@1610": 0x803a3364,
		"Enemy::@2183": 0x803a3424,
		"Enemy::@2184": 0x803a344c,
		"Enemy::@2185": 0x803a3474,
		"Enemy::@2186": 0x803a349c,
		"Enemy::@2187": 0x803a34c4,
		"Enemy::@2188": 0x803a34ec,
		"Enemy::@2189": 0x803a3514,
		"Enemy::@2190": 0x803a3538,
		"Enemy::@2191": 0x803a355c,
		"Enemy::@2192": 0x803a3588,
		"Enemy::@2193": 0x803a35b4,
		"Enemy::entry$2660": 0x803a3704,
		"entry$2660": 0x803a3704,
		"Enemy::@3773": 0x803a3834,
		"Enemy::@3401": 0x803a3b28,
		"Enemy::entry$3400": 0x803a3b38,
		"entry$3400": 0x803a3b38,
		"Enemy::@3555": 0x803a3ca4,
		"Enemy::@3573": 0x803a3d54,
		"@unnamed@::cDropCoinNumTable": 0x803a3fe4,
		"cDropCoinNumTable": 0x803a3fe4,
		"Enemy::entry$3098": 0x803a4000,
		"entry$3098": 0x803a4000,
		"Enemy::@3632": 0x803a40cc,
		"Enemy::@3727": 0x803a40f4,
		"Enemy::@4518": 0x803a4144,
		"Enemy::@4779": 0x803a419c,
		"Enemy::@1586": 0x803a4200,
		"Enemy::@1587": 0x803a4238,
		"Enemy::@1588": 0x803a426c,
		"Enemy::@2367": 0x803a4290,
		"Enemy::@2369": 0x803a429c,
		"Enemy::@2386": 0x803a42a8,
		"Enemy::@2387": 0x803a42d0,
		"Enemy::@2389": 0x803a42f4,
		"@unnamed@::cJointNames": 0x803a4324,
		"cJointNames": 0x803a4324,
		"Enemy::@2528": 0x803a4334,
		"Enemy::entry$2527": 0x803a4348,
		"entry$2527": 0x803a4348,
		"Enemy::entry$2976": 0x803a4610,
		"entry$2976": 0x803a4610,
		"Enemy::@3202": 0x803a4780,
		"Enemy::@5093": 0x803a4834,
		"Enemy::@5696": 0x803a4858,
		"@5696": 0x803a4858,
		"Enemy::@5697": 0x803a4874,
		"@5697": 0x803a4874,
		"Enemy::@5699": 0x803a488c,
		"@5699": 0x803a488c,
		"Enemy::@5703": 0x803a48b0,
		"@5703": 0x803a48b0,
		"Enemy::@5706": 0x803a48f4,
		"Enemy::@2015": 0x803a4d08,
		"Enemy::@2016": 0x803a4d38,
		"Enemy::@2017": 0x803a4d70,
		"Enemy::@2602": 0x803a4dc8,
		"Enemy::@2621": 0x803a4de0,
		"Enemy::entry$2835": 0x803a4e1c,
		"entry$2835": 0x803a4e1c,
		"Enemy::entry$2868": 0x803a4fe0,
		"entry$2868": 0x803a4fe0,
		"Enemy::@1525": 0x803a50d4,
		"Enemy::@1582": 0x803a50e8,
		"Enemy::@1583": 0x803a5118,
		"Enemy::@1584": 0x803a5150,
		"Enemy::@2160": 0x803a51a8,
		"Enemy::@2161": 0x803a51b4,
		"Enemy::entry$3213": 0x803a52d0,
		"entry$3213": 0x803a52d0,
		"Enemy::@3369": 0x803a5478,
		"Enemy::entry$3045": 0x803a573c,
		"entry$3045": 0x803a573c,
		"Enemy::@3784": 0x803a57b0,
		"Enemy::@3790": 0x803a57e4,
		"Camera::@1873": 0x803a5868,
		"@1873": 0x803a5868,
		"Camera::@1874": 0x803a5898,
		"@1874": 0x803a5898,
		"Camera::@1875": 0x803a58d0,
		"Camera::@1876": 0x803a5904,
		"@1876": 0x803a5904,
		"Camera::cDirtyFileName": 0x803a5928,
		"Camera::cDirtyTexName": 0x803a594c,
		"Camera::@1857": 0x803a5af8,
		"@1857": 0x803a5af8,
		"Camera::@1858": 0x803a5b28,
		"@1858": 0x803a5b28,
		"Camera::@1901": 0x803a5c40,
		"@1901": 0x803a5c40,
		"Camera::@1903": 0x803a5c4c,
		"@1903": 0x803a5c4c,
		"Camera::@1905": 0x803a5c5c,
		"@1905": 0x803a5c5c,
		"Camera::@1912": 0x803a5cc0,
		"Camera::@1915": 0x803a5cec,
		"@1915": 0x803a5cec,
		"Camera::@1917": 0x803a5d04,
		"Camera::@1919": 0x803a5d1c,
		"@1919": 0x803a5d1c,
		"Camera::@1921": 0x803a5d34,
		"@1921": 0x803a5d34,
		"Camera::@1941": 0x803a5eb8,
		"Camera::@1943": 0x803a5ed0,
		"Camera::@1944": 0x803a5ee8,
		"Camera::@1946": 0x803a5f00,
		"Camera::@1948": 0x803a5f18,
		"Camera::@1957": 0x803a5f8c,
		"Camera::@1959": 0x803a5fa0,
		"Camera::@1961": 0x803a5fb4,
		"Camera::@1962": 0x803a5fc8,
		"Camera::@1964": 0x803a5fdc,
		"Camera::@1966": 0x803a5fec,
		"Camera::@1967": 0x803a5ffc,
		"Camera::@1968": 0x803a6010,
		"Camera::@1969": 0x803a6024,
		"Camera::@1970": 0x803a6038,
		"Camera::@1971": 0x803a604c,
		"Camera::@1972": 0x803a6060,
		"Camera::@1973": 0x803a6070,
		"Camera::@1974": 0x803a6080,
		"Camera::@1975": 0x803a6098,
		"Camera::@1976": 0x803a60ac,
		"Camera::@1977": 0x803a60bc,
		"Camera::@1988": 0x803a6184,
		"@1988": 0x803a6184,
		"Camera::@1989": 0x803a6194,
		"Camera::@1994": 0x803a61e4,
		"Camera::@1995": 0x803a61f4,
		"Camera::@2003": 0x803a6290,
		"Camera::@2004": 0x803a62a4,
		"Camera::@2005": 0x803a62b4,
		"Camera::@2006": 0x803a62c4,
		"Camera::@2007": 0x803a62d4,
		"Camera::@2008": 0x803a62e4,
		"Camera::@2009": 0x803a62f4,
		"Camera::@2012": 0x803a6324,
		"Camera::@2013": 0x803a6338,
		"Camera::@2014": 0x803a634c,
		"Camera::@2015": 0x803a635c,
		"Camera::@2016": 0x803a6370,
		"Camera::@2017": 0x803a6384,
		"Camera::@2021": 0x803a63cc,
		"Camera::@2022": 0x803a63dc,
		"Camera::@2023": 0x803a63f4,
		"Camera::@2029": 0x803a6464,
		"Camera::@2030": 0x803a6474,
		"Camera::@2031": 0x803a6484,
		"Camera::@2032": 0x803a6494,
		"Camera::@2033": 0x803a64a8,
		"Camera::@2034": 0x803a64b8,
		"Camera::@2035": 0x803a64d0,
		"Camera::@2036": 0x803a64e0,
		"Camera::@2037": 0x803a64f0,
		"Camera::@2038": 0x803a6504,
		"Camera::@2119": 0x803a6518,
		"Camera::@2120": 0x803a6534,
		"Camera::@2122": 0x803a6540,
		"Camera::@2123": 0x803a6550,
		"Camera::@2127": 0x803a6584,
		"Camera::@2129": 0x803a6598,
		"Camera::@2130": 0x803a65b0,
		"Camera::@2131": 0x803a65c0,
		"Camera::@2135": 0x803a65f0,
		"Camera::@2136": 0x803a6600,
		"Camera::@2138": 0x803a6610,
		"Camera::@2139": 0x803a6624,
		"Camera::@2141": 0x803a664c,
		"Camera::@2142": 0x803a6660,
		"Camera::@2143": 0x803a667c,
		"Camera::@2144": 0x803a6690,
		"Camera::@2146": 0x803a66a4,
		"Camera::@2147": 0x803a66bc,
		"Camera::@2148": 0x803a66d4,
		"Camera::@2150": 0x803a66fc,
		"Camera::@2151": 0x803a6710,
		"Camera::@2152": 0x803a6724,
		"Camera::@2174": 0x803a675c,
		"Camera::@2175": 0x803a6774,
		"Camera::@2203": 0x803a67f4,
		"Camera::@2204": 0x803a6800,
		"Camera::@2206": 0x803a680c,
		"Camera::@2207": 0x803a6818,
		"Camera::@2208": 0x803a6824,
		"Camera::@1632": 0x803a6920,
		"Camera::@2078": 0x803a6980,
		"Camera::@2079": 0x803a698c,
		"Camera::@2223": 0x803a69b0,
		"Camera::@2224": 0x803a69bc,
		"CPolarSubCamera::sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x803a6a88,
		"sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x803a6a88,
		"Camera::@1681": 0x803a6b78,
		"Camera::@1682": 0x803a6ba4,
		"Camera::@1683": 0x803a6bd4,
		"Camera::@1684": 0x803a6bf8,
		"Camera::@1685": 0x803a6c08,
		"Camera::@1686": 0x803a6c18,
		"Camera::@1687": 0x803a6c2c,
		"Camera::@1688": 0x803a6c5c,
		"Camera::@1689": 0x803a6c90,
		"Camera::@1837": 0x803a6cb8,
		"@1837": 0x803a6cb8,
		"Camera::@1650": 0x803a6cf8,
		"Camera::@1535": 0x803a6d40,
		"Camera::@1578": 0x803a71a0,
		"Camera::@1579": 0x803a71b8,
		"Camera::@1580": 0x803a71d0,
		"Camera::@1581": 0x803a71e8,
		"Camera::@1582": 0x803a7204,
		"Camera::@1583": 0x803a7220,
		"Camera::@1584": 0x803a7238,
		"Camera::@1585": 0x803a7254,
		"Camera::@1586": 0x803a7270,
		"Camera::@1587": 0x803a728c,
		"Camera::@1588": 0x803a72a8,
		"Camera::@1589": 0x803a72c0,
		"Camera::@1590": 0x803a72d8,
		"Camera::@1591": 0x803a72f0,
		"Camera::@1592": 0x803a7310,
		"Camera::@1597": 0x803a7394,
		"Camera::@1598": 0x803a73b0,
		"Camera::@1599": 0x803a73c8,
		"Camera::@1600": 0x803a73e0,
		"Camera::@1601": 0x803a73f8,
		"Camera::@1602": 0x803a7414,
		"Camera::@1603": 0x803a742c,
		"Camera::@1604": 0x803a744c,
		"Camera::@1605": 0x803a7464,
		"Camera::@1606": 0x803a747c,
		"Camera::@1607": 0x803a7498,
		"Animal::@2230": 0x803a7a78,
		"Animal::@2231": 0x803a7a84,
		"Animal::@2232": 0x803a7a90,
		"Animal::@2233": 0x803a7a9c,
		"@unnamed@::cFishoidMdlNames": 0x803a7aa8,
		"cFishoidMdlNames": 0x803a7aa8,
		"Animal::entry$2319": 0x803a7ab8,
		"entry$2319": 0x803a7ab8,
		"Animal::@2688": 0x803a7b00,
		"Animal::@3202": 0x803a7b10,
		"Animal::@2337": 0x803a7b40,
		"Animal::@2338": 0x803a7b70,
		"Animal::@2340": 0x803a7bdc,
		"Animal::@2543": 0x803a7c00,
		"Animal::entry$2542": 0x803a7c10,
		"entry$2542": 0x803a7c10,
		"Animal::@2573": 0x803a7c28,
		"Animal::@1562": 0x803a7c58,
		"Animal::@1563": 0x803a7c68,
		"Animal::@1565": 0x803a7c78,
		"Animal::@1567": 0x803a7c88,
		"Animal::@1569": 0x803a7c9c,
		"Animal::@1571": 0x803a7cb0,
		"Animal::@1573": 0x803a7cc0,
		"Animal::@1575": 0x803a7cd4,
		"Animal::@1577": 0x803a7ce8,
		"Animal::@1940": 0x803a7d0c,
		"Animal::@2018": 0x803a7d20,
		"Animal::@2019": 0x803a7d50,
		"Animal::@2020": 0x803a7d88,
		"Animal::@2021": 0x803a7dbc,
		"Animal::@2904": 0x803a7de0,
		"Animal::@2905": 0x803a7e00,
		"Animal::@2906": 0x803a7e20,
		"Animal::@2907": 0x803a7e40,
		"@unnamed@::cRandomAnims": 0x803a7e60,
		"cRandomAnims": 0x803a7e60,
		"Animal::@2909": 0x803a7e74,
		"@unnamed@::cColorTable": 0x803a7e80,
		"Animal::entry$3023": 0x803a7eb0,
		"entry$3023": 0x803a7eb0,
		"Animal::@3452": 0x803a7ec8,
		"Animal::@3871": 0x803a7edc,
		"Animal::@3928": 0x803a7ef0,
		"Animal::@3929": 0x803a7efc,
		"Animal::@3931": 0x803a7f08,
		"Animal::@3932": 0x803a7f18,
		"Animal::@3934": 0x803a7f28,
		"Animal::@3936": 0x803a7f38,
		"Animal::@3938": 0x803a7f48,
		"Animal::@3940": 0x803a7f58,
		"Animal::@3941": 0x803a7f68,
		"Animal::@3942": 0x803a7f7c,
		"Animal::@3943": 0x803a7f90,
		"Animal::@3945": 0x803a7fa4,
		"Animal::@3947": 0x803a7fb4,
		"Animal::@3948": 0x803a7fc4,
		"Animal::@3949": 0x803a7fd4,
		"Animal::@3950": 0x803a7fe0,
		"Animal::@3952": 0x803a7ff0,
		"Animal::@3953": 0x803a8000,
		"Animal::@1996": 0x803a8030,
		"Animal::@1997": 0x803a8060,
		"Animal::@1998": 0x803a8098,
		"Animal::@1999": 0x803a80cc,
		"Animal::@2986": 0x803a80f0,
		"Animal::@2987": 0x803a8100,
		"Animal::@2988": 0x803a8110,
		"Animal::entry$2985": 0x803a8124,
		"Animal::@3447": 0x803a8154,
		"Animal::@3661": 0x803a8164,
		"Animal::@3662": 0x803a8178,
		"Animal::@3663": 0x803a8188,
		"Animal::@3665": 0x803a8198,
		"Animal::@3666": 0x803a81a8,
		"Animal::@3670": 0x803a81b4,
		"Animal::@3672": 0x803a81c4,
		"Animal::@3674": 0x803a81d0,
		"Animal::@3675": 0x803a81e0,
		"Animal::@5081": 0x803a81f0,
		"Animal::@2393": 0x803a82e0,
		"Animal::@2394": 0x803a82f0,
		"Animal::@2395": 0x803a8300,
		"@unnamed@::cButterflyMdlNames": 0x803a8310,
		"cButterflyMdlNames": 0x803a8310,
		"Animal::entry$2459": 0x803a831c,
		"entry$2459": 0x803a831c,
		"Animal::@2493": 0x803a834c,
		"Animal::@2594": 0x803a835c,
		"Animal::@2711": 0x803a836c,
		"JKRFile::__vt": 0x803a8380,
		"JKRAramArchive::__vt": 0x803a83a0,
		"JKRAramHeap::__vt": 0x803a83e8,
		"JKRAram::sMessageBuffer": 0x803a83f8,
		"JKRAram::sMessageQueue": 0x803a8408,
		"JKRAram::__vt": 0x803a8428,
		"JKRArchive::__vt": 0x803a8438,
		"JKRCompArchive::__vt": 0x803a8480,
		"JKRDisposer::__vt": 0x803a84c8,
		"JKRDvdArchive::__vt": 0x803a84d8,
		"JKRDvdFile::__vt": 0x803a8520,
		"JKRExpHeap::__vt": 0x803a8548,
		"JKRArcFinder::__vt": 0x803a85a8,
		"JKRFileLoader::__vt": 0x803a85b8,
		"JKRHeap::__vt": 0x803a85f8,
		"JKRMemArchive::__vt": 0x803a8648,
		"JKRSolidHeap::__vt": 0x803a8690,
		"JKRStdHeap::__vt": 0x803a86e0,
		"JKRThread::__vt": 0x803a8730,
		"JSURandomOutputStream::__vt": 0x803a8740,
		"JSUOutputStream::__vt": 0x803a8774,
		"JSURandomInputStream::__vt": 0x803a8788,
		"JSUInputStream::__vt": 0x803a87ac,
		"JSUMemoryOutputStream::__vt": 0x803a87c8,
		"JSUMemoryInputStream::__vt": 0x803a87f0,
		"JSUFileInputStream::__vt": 0x803a8818,
		"JUTException::sMessageQueue": 0x803a8840,
		"JUTException::sCpuExpName": 0x803a8860,
		"sCpuExpName": 0x803a8860,
		"JUTException::__vt": 0x803a88a0,
		"JUTDirectPrint::sAsciiTable": 0x803a88b0,
		"sAsciiTable": 0x803a88b0,
		"JUTDirectPrint::sFontData": 0x803a8930,
		"sFontData": 0x803a8930,
		"JUTDirectPrint::sFontData2": 0x803a8a30,
		"sFontData2": 0x803a8a30,
		"JUTFont::__vt": 0x803a8b68,
		"JSystem::channel_mask": 0x803a8ba0,
		"channel_mask": 0x803a8ba0,
		"JUTGamePad::__vt": 0x803a8bb0,
		"J2DPane::__vt": 0x803a8bc0,
		"J2DPicture::__vt": 0x803a8bf0,
		"J2DPrint::__vt": 0x803a8c80,
		"J2DSetScreen::__vt": 0x803a8ce0,
		"J2DScreen::__vt": 0x803a8d14,
		"J2DTextBox::__vt": 0x803a8d48,
		"J2DWindow::__vt": 0x803a8d78,
		"J2DWindow::Texture::__vt": 0x803a8da4,
		"JSystem::j3dDefaultTransformInfo": 0x803a8db0,
		"j3dDefaultTransformInfo": 0x803a8db0,
		"JSystem::j3dDefaultMtx": 0x803a8dd0,
		"j3dDefaultMtx": 0x803a8dd0,
		"JSystem::PSMulUnit01": 0x803a8e00,
		"PSMulUnit01": 0x803a8e00,
		"J3DSkinDeform::__vt": 0x803a8e08,
		"J3DJoint::__vt": 0x803a8e18,
		"J3DMtxCalcMayaAnm::__vt": 0x803a8e40,
		"J3DMtxCalcMaya::__vt": 0x803a8f3c,
		"J3DMtxCalcSoftimage::__vt": 0x803a8f80,
		"J3DMtxCalcBasic::__vt": 0x803a8fc4,
		"J3DMtxCalcAnm::__vt": 0x803a9028,
		"J3DPEBlockFull::__vt": 0x803a9058,
		"J3DIndBlockFull::__vt": 0x803a90bc,
		"J3DTevBlock16::__vt": 0x803a9104,
		"J3DTevBlock4::__vt": 0x803a91a0,
		"J3DTevBlock2::__vt": 0x803a923c,
		"J3DTevBlock1::__vt": 0x803a92d8,
		"J3DTexGenBlockBasic::__vt": 0x803a9374,
		"J3DColorBlockLightOn::__vt": 0x803a93c4,
		"J3DColorBlockLightOff::__vt": 0x803a9428,
		"J3DPEBlockXlu::__vt": 0x803a948c,
		"J3DPEBlockTexEdge::__vt": 0x803a94f0,
		"J3DPEBlockOpa::__vt": 0x803a9554,
		"J3DPEBlock::__vt": 0x803a95b8,
		"J3DIndBlockNull::__vt": 0x803a961c,
		"J3DIndBlock::__vt": 0x803a9664,
		"J3DTevBlock::__vt": 0x803a96ac,
		"J3DTexGenBlock::__vt": 0x803a9748,
		"J3DColorBlock::__vt": 0x803a9798,
		"J3DModel::__vt": 0x803a984c,
		"J3DModelData::__vt": 0x803a9868,
		"J3DNode::__vt": 0x803a9878,
		"JSystem::@952": 0x803a98a0,
		"@952": 0x803a98a0,
		"JSystem::@953": 0x803a98ac,
		"@953": 0x803a98ac,
		"JSystem::@954": 0x803a98b8,
		"@954": 0x803a98b8,
		"J3DShapeMtx::mtxLoadPipeline": 0x803a98d0,
		"mtxLoadPipeline": 0x803a98d0,
		"J3DShapeDraw::__vt": 0x803a9900,
		"J3DShapeMtxMulti::__vt": 0x803a990c,
		"J3DShapeMtxDL::__vt": 0x803a992c,
		"J3DShapeMtx::__vt": 0x803a994c,
		"J3DAnmColorKey::__vt": 0x803a9990,
		"J3DAnmColor::__vt": 0x803a99a0,
		"J3DAnmColorFull::__vt": 0x803a99b0,
		"J3DAnmVtxColorKey::__vt": 0x803a99c0,
		"J3DAnmVtxColor::__vt": 0x803a99d0,
		"J3DAnmVtxColorFull::__vt": 0x803a99e0,
		"J3DAnmClusterKey::__vt": 0x803a99f0,
		"J3DAnmCluster::__vt": 0x803a9a00,
		"J3DAnmClusterFull::__vt": 0x803a9a10,
		"J3DAnmTransformKey::__vt": 0x803a9a20,
		"J3DAnmTransform::__vt": 0x803a9a34,
		"J3DAnmTransformFull::__vt": 0x803a9a44,
		"J3DAnmBase::__vt": 0x803a9a54,
		"J3DModelLoader_v21::__vt": 0x803a9a60,
		"J3DModelLoader_v26::__vt": 0x803a9a88,
		"J3DTexture::__vt": 0x803a9ab0,
		"J3DModelLoader::__vt": 0x803a9abc,
		"J3DAnmKeyLoader_v15::__vt": 0x803a9ae8,
		"J3DAnmFullLoader_v15::__vt": 0x803a9af8,
		"J3DAnmLoader::__vt": 0x803a9b08,
		"J3DAnmVisibilityFull::__vt": 0x803a9b18,
		"J3DAnmTexPattern::__vt": 0x803a9b24,
		"J3DAnmTevRegKey::__vt": 0x803a9b30,
		"J3DAnmTextureSRTKey::__vt": 0x803a9b3c,
		"J2DGrafContext::__vt": 0x803a9b48,
		"JKRDecomp::sMessageBuffer": 0x803a9b70,
		"JKRDecomp::sMessageQueue": 0x803a9b80,
		"JKRDecomp::__vt": 0x803a9ba0,
		"J2DOrthoGraph::__vt": 0x803a9bb0,
		"J3DVertexBuffer::__vt": 0x803a9bd8,
		"J3DShapePacket::__vt": 0x803a9be8,
		"J3DMatPacket::__vt": 0x803a9c00,
		"J3DDrawPacket::__vt": 0x803a9c18,
		"J3DCallBackPacket::__vt": 0x803a9c30,
		"J3DPacket::__vt": 0x803a9c48,
		"JSystem::j3dDefaultLightInfo": 0x803a9ca4,
		"j3dDefaultLightInfo": 0x803a9ca4,
		"JSystem::j3dDefaultTexCoordInfo": 0x803a9cd8,
		"j3dDefaultTexCoordInfo": 0x803a9cd8,
		"JSystem::j3dDefaultTexMtxInfo": 0x803a9cf8,
		"j3dDefaultTexMtxInfo": 0x803a9cf8,
		"JSystem::j3dDefaultIndTexMtxInfo": 0x803a9d5c,
		"j3dDefaultIndTexMtxInfo": 0x803a9d5c,
		"JSystem::j3dDefaultTevStageInfo": 0x803a9d78,
		"j3dDefaultTevStageInfo": 0x803a9d78,
		"JSystem::j3dDefaultIndTevStageInfo": 0x803a9d8c,
		"j3dDefaultIndTevStageInfo": 0x803a9d8c,
		"JSystem::j3dDefaultFogInfo": 0x803a9d98,
		"j3dDefaultFogInfo": 0x803a9d98,
		"JSystem::j3dDefaultNBTScaleInfo": 0x803a9dc4,
		"j3dDefaultNBTScaleInfo": 0x803a9dc4,
		"JSystem::@815": 0x803a9de4,
		"@815": 0x803a9de4,
		"JSystem::@816": 0x803a9df0,
		"@816": 0x803a9df0,
		"JSystem::@817": 0x803a9dfc,
		"@817": 0x803a9dfc,
		"JSystem::@818": 0x803a9e08,
		"@818": 0x803a9e08,
		"JSystem::@819": 0x803a9e14,
		"@819": 0x803a9e14,
		"J3DDrawBuffer::sortFuncTable": 0x803a9e20,
		"sortFuncTable": 0x803a9e20,
		"JSystem::@820": 0x803a9e68,
		"@820": 0x803a9e68,
		"JSystem::@821": 0x803a9e74,
		"@821": 0x803a9e74,
		"J3DDrawBuffer::drawFuncTable": 0x803a9e80,
		"drawFuncTable": 0x803a9e80,
		"J3DMaterialAnm::__vt": 0x803a9e98,
		"J3DTexNoAnm::__vt": 0x803a9ea8,
		"JKRAramBlock::__vt": 0x803a9eb8,
		"JKRAramStream::sMessageBuffer": 0x803a9ec8,
		"JKRAramStream::sMessageQueue": 0x803a9ed8,
		"JKRAramStream::__vt": 0x803a9ef8,
		"JUTResFont::saoAboutEncoding_": 0x803a9f08,
		"JUTResFont::__vt": 0x803a9f14,
		"JUTRomFont::saoAboutEncoding_": 0x803a9f50,
		"JUTRomFont::__vt": 0x803a9f68,
		"JSystem::@320": 0x803a9fa8,
		"JSystem::c2r$795": 0x803a9ffc,
		"c2r$795": 0x803a9ffc,
		"JUTConsole::__vt": 0x803aa010,
		"JDrama::TActor::__vt": 0x803aa020,
		"JDrama::TOrthoProj::__vt": 0x803aa0e8,
		"JDrama::TLookAtCamera::__vt": 0x803aa1bc,
		"JDrama::TPolarCamera::__vt": 0x803aa2b0,
		"JDrama::TCamera::__vt": 0x803aa38c,
		"JDrama::TSmplChara::__vt": 0x803aa474,
		"JDrama::TDirector::__vt": 0x803aa498,
		"JDrama::TDisplay::__vt": 0x803aa508,
		"JDrama::TDrawBufObj::__vt": 0x803aa518,
		"JDrama::TDStageDisp::__vt": 0x803aa56c,
		"JDrama::TDStageGroup::__vt": 0x803aa590,
		"JDrama::TEfbCtrlTex::__vt": 0x803aa5c0,
		"JDrama::TEfbCtrlDisp::__vt": 0x803aa5e4,
		"JDrama::TEfbCtrl::__vt": 0x803aa608,
		"JDrama::TFrmGXSet::__vt": 0x803aa630,
		"JDrama::TLightMap::__vt": 0x803aa658,
		"JDrama::TAmbAry::__vt": 0x803aa67c,
		"JDrama::TAmbColor::__vt": 0x803aa6a0,
		"JDrama::TIdxLight::__vt": 0x803aa704,
		"JDrama::TLightAry::__vt": 0x803aa7a0,
		"JDrama::TLight::__vt": 0x803aa7c4,
		"JDrama::TNameRef::__vt": 0x803aa860,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::__vt": 0x803aa880,
		"JDrama::TNameRefGen::__vt": 0x803aa8a0,
		"JDrama::TPlacement::__vt": 0x803aa8b0,
		"JDrama::TScreen::__vt": 0x803aa8d8,
		"TCamConnecter::__vt": 0x803aa8fc,
		"JDrama::TSmJ3DAct::__vt": 0x803aa920,
		"JDrama::TSmJ3DScn::__vt": 0x803aa9d0,
		"JDrama::TViewConnecter::__vt": 0x803aaa00,
		"JDrama::TViewport::__vt": 0x803aaa28,
		"JALSeModData<JALSeModVolFunk>::__vt": 0x803aaa50,
		"JALSeModData<JALSeModPitFunk>::__vt": 0x803aaa60,
		"JALSeModData<JALSeModEffFunk>::__vt": 0x803aaa70,
		"JALSeModData<JALSeModVolDist>::__vt": 0x803aaa80,
		"JALSeModData<JALSeModEffDist>::__vt": 0x803aaa90,
		"JALSeModData<JALSeModPitDist>::__vt": 0x803aaaa0,
		"JALSeModData<JALSeModVolFGrp>::__vt": 0x803aaab0,
		"JALSeModData<JALSeModPitFGrp>::__vt": 0x803aaac0,
		"JALSeModData<JALSeModEffFGrp>::__vt": 0x803aaad0,
		"JALSeModData<JALSeModVolDGrp>::__vt": 0x803aaae0,
		"JALSeModData<JALSeModEffDGrp>::__vt": 0x803aaaf0,
		"JALSeModData<JALSeModPitDGrp>::__vt": 0x803aab00,
		"JALSeModPitDGrp::__vt": 0x803aab10,
		"JALSeModDataGrp<JALSeModPitDGrp>::__vt": 0x803aab20,
		"JALSeModEffDGrp::__vt": 0x803aab30,
		"JALSeModDataGrp<JALSeModEffDGrp>::__vt": 0x803aab40,
		"JALSeModVolDGrp::__vt": 0x803aab50,
		"JALSeModDataGrp<JALSeModVolDGrp>::__vt": 0x803aab60,
		"JALSeModEffFGrp::__vt": 0x803aab70,
		"JALSeModDataGrp<JALSeModEffFGrp>::__vt": 0x803aab80,
		"JALSeModPitFGrp::__vt": 0x803aab90,
		"JALSeModDataGrp<JALSeModPitFGrp>::__vt": 0x803aaba0,
		"JALSeModVolFGrp::__vt": 0x803aabb0,
		"JALSeModDataGrp<JALSeModVolFGrp>::__vt": 0x803aabc0,
		"JALSeModPitDist::__vt": 0x803aabd0,
		"JALSeModEffDist::__vt": 0x803aabe0,
		"JALSeModVolDist::__vt": 0x803aabf0,
		"JALSeModEffFunk::__vt": 0x803aac00,
		"JALSeModPitFunk::__vt": 0x803aac10,
		"JALSeModVolFunk::__vt": 0x803aac20,
		"JAIAnimeSound::__vt": 0x803aac30,
		"JSystem::@547": 0x803aac40,
		"@547": 0x803aac40,
		"JAIBasic::__vt": 0x803aac64,
		"JAIConst::dummyZeroVec": 0x803aaca0,
		"dummyZeroVec": 0x803aaca0,
		"JAIConst::nullInfoData2": 0x803aacac,
		"nullInfoData2": 0x803aacac,
		"JAIConst::sCInfos_0": 0x803aaccc,
		"sCInfos_0": 0x803aaccc,
		"JAInter::StreamLib::filter_table": 0x803aacf0,
		"filter_table": 0x803aacf0,
		"JAInter::StreamLib::table4": 0x803aad30,
		"table4": 0x803aad30,
		"JAISound::__vt": 0x803aad50,
		"JASystem::BankMgr::OSC_RELEASE_TABLE": 0x803aad88,
		"OSC_RELEASE_TABLE": 0x803aad88,
		"JASystem::BankMgr::OSC_ENV": 0x803aad94,
		"OSC_ENV": 0x803aad94,
		"JASystem::TBasicBank::__vt": 0x803aadb0,
		"JASystem::TBank::__vt": 0x803aadc4,
		"JASystem::TBasicInst::__vt": 0x803aadd8,
		"JASystem::TInst::__vt": 0x803aadf0,
		"JASystem::TWaveHandle::__vt": 0x803aae08,
		"JASystem::TBasicWaveBank::TWaveHandle::__vt": 0x803aae1c,
		"JASystem::TBasicWaveBank::TWaveGroup::__vt": 0x803aae30,
		"JASystem::WaveArcLoader::TObject::__vt": 0x803aae44,
		"JASystem::TBasicWaveBank::__vt": 0x803aae58,
		"JASystem::TWaveBank::__vt": 0x803aae6c,
		"JASystem::TInstEffect::__vt": 0x803aae80,
		"JASystem::TDrumSet::__vt": 0x803aae90,
		"JASystem::TInstRand::__vt": 0x803aaea8,
		"JASystem::TInstSense::__vt": 0x803aaeb8,
		"JASystem::TSimpleWaveBank::TWaveHandle::__vt": 0x803aaec8,
		"JASystem::TSimpleWaveBank::__vt": 0x803aaedc,
		"JASystem::WaveArcLoader::sCurrentDir": 0x803aaf10,
		"sCurrentDir": 0x803aaf10,
		"JASystem::Driver::calc_sw_table": 0x803aaf50,
		"calc_sw_table": 0x803aaf50,
		"JSystem::@325": 0x803aafc4,
		"@325": 0x803aafc4,
		"JASystem::Driver::C5BASE_PITCHTABLE": 0x803ab000,
		"C5BASE_PITCHTABLE": 0x803ab000,
		"JASystem::history": 0x803ab740,
		"history": 0x803ab740,
		"JASystem::DSPInterface::SEND_TABLE": 0x803ab768,
		"SEND_TABLE": 0x803ab768,
		"JSystem::connect_table$341": 0x803ab780,
		"connect_table$341": 0x803ab780,
		"JASystem::Driver::FORCE_STOP_TABLE": 0x803ab798,
		"FORCE_STOP_TABLE": 0x803ab798,
		"JASystem::Dvd::audioRootPath": 0x803ab7a8,
		"audioRootPath": 0x803ab7a8,
		"JASystem::HardStream::rootDir": 0x803ab7c8,
		"rootDir": 0x803ab7c8,
		"JSystem::@550": 0x803ab7e8,
		"@550": 0x803ab7e8,
		"JASystem::Player::CUTOFF_TO_IIR_TABLE": 0x803ab808,
		"CUTOFF_TO_IIR_TABLE": 0x803ab808,
		"JASystem::Player::s_key_table": 0x803abc08,
		"s_key_table": 0x803abc08,
		"JASystem::Player::sAdsrDef": 0x803abd08,
		"sAdsrDef": 0x803abd08,
		"JASystem::Player::sEnvelopeDef": 0x803abd20,
		"sEnvelopeDef": 0x803abd20,
		"JASystem::Player::sVibratoDef": 0x803abd38,
		"sVibratoDef": 0x803abd38,
		"JASystem::Player::sTremoroDef": 0x803abd50,
		"sTremoroDef": 0x803abd50,
		"JASystem::Player::sAdsTable": 0x803abd68,
		"sAdsTable": 0x803abd68,
		"JASystem::Player::sRelTable": 0x803abd80,
		"sRelTable": 0x803abd80,
		"JASystem::Player::sVibTable": 0x803abd8c,
		"sVibTable": 0x803abd8c,
		"JASystem::Player::sTreTable": 0x803abdb0,
		"sTreTable": 0x803abdb0,
		"JASystem::TTrack::sOscTable": 0x803abdd8,
		"sOscTable": 0x803abdd8,
		"JSystem::@982": 0x803abde0,
		"@982": 0x803abde0,
		"JSystem::@1324": 0x803abe58,
		"@1324": 0x803abe58,
		"JSystem::@139": 0x803abeb8,
		"@139": 0x803abeb8,
		"JSystem::@140": 0x803abec4,
		"@140": 0x803abec4,
		"JSystem::@141": 0x803abed0,
		"@141": 0x803abed0,
		"JSystem::@142": 0x803abedc,
		"@142": 0x803abedc,
		"JSystem::@143": 0x803abee8,
		"@143": 0x803abee8,
		"JSystem::@146": 0x803abf0c,
		"@146": 0x803abf0c,
		"JSystem::@147": 0x803abf18,
		"@147": 0x803abf18,
		"JSystem::@152": 0x803abf54,
		"JSystem::@153": 0x803abf60,
		"JSystem::@154": 0x803abf6c,
		"@154": 0x803abf6c,
		"JSystem::@155": 0x803abf78,
		"@155": 0x803abf78,
		"JSystem::@156": 0x803abf84,
		"JSystem::@157": 0x803abf90,
		"JSystem::@158": 0x803abf9c,
		"JSystem::@159": 0x803abfa8,
		"JSystem::@161": 0x803abfc0,
		"@161": 0x803abfc0,
		"JSystem::@162": 0x803abfcc,
		"@162": 0x803abfcc,
		"JSystem::@163": 0x803abfd8,
		"@163": 0x803abfd8,
		"JSystem::@168": 0x803ac014,
		"JSystem::@169": 0x803ac020,
		"JSystem::@170": 0x803ac02c,
		"JSystem::@171": 0x803ac038,
		"@171": 0x803ac038,
		"JSystem::@172": 0x803ac044,
		"@172": 0x803ac044,
		"JSystem::@173": 0x803ac050,
		"@173": 0x803ac050,
		"JSystem::@174": 0x803ac05c,
		"JSystem::@175": 0x803ac068,
		"JSystem::@176": 0x803ac074,
		"@176": 0x803ac074,
		"JSystem::@180": 0x803ac0a4,
		"@180": 0x803ac0a4,
		"JSystem::@181": 0x803ac0b0,
		"@181": 0x803ac0b0,
		"JSystem::@182": 0x803ac0bc,
		"JSystem::@183": 0x803ac0c8,
		"JSystem::@184": 0x803ac0d4,
		"@184": 0x803ac0d4,
		"JSystem::@185": 0x803ac0e0,
		"@185": 0x803ac0e0,
		"JASystem::TSeqParser::sCmdPList": 0x803ac11c,
		"sCmdPList": 0x803ac11c,
		"J3DMaterialTable::__vt": 0x803ac420,
		"JSystem::@2833": 0x803ac430,
		"JSystem::@3104": 0x803ac44c,
		"JSystem::@2535": 0x803ac478,
		"JPADragField::__vt": 0x803ac498,
		"JPARandomField::__vt": 0x803ac4b0,
		"JPAConvectionField::__vt": 0x803ac4c8,
		"JPAVortexField::__vt": 0x803ac4e0,
		"JPANewtonField::__vt": 0x803ac4f8,
		"JPAMagnetField::__vt": 0x803ac510,
		"JPAAirField::__vt": 0x803ac528,
		"JPAGravityField::__vt": 0x803ac540,
		"JPABaseField::__vt": 0x803ac558,
		"JPAParticle::__vt": 0x803ac570,
		"JPABaseParticle::__vt": 0x803ac5c8,
		"JSystem::@2383": 0x803ac620,
		"JSystem::@2382": 0x803ac64c,
		"JPADrawCalcEmitterVisitor::__vt": 0x803ac678,
		"JPADrawCalcParticleVisitor::__vt": 0x803ac688,
		"JPADrawExecParticleVisitor::__vt": 0x803ac698,
		"JPADrawExecEmitterVisitor::__vt": 0x803ac6a8,
		"JPADrawCalcChildScaleOut::__vt": 0x803ac6b8,
		"JPADrawCalcChildAlphaOut::__vt": 0x803ac6c8,
		"JPADrawCalcAlphaFlickMultSin::__vt": 0x803ac6d8,
		"JPADrawCalcAlphaFlickAddSin::__vt": 0x803ac6e8,
		"JPADrawCalcAlphaFlickNrmSin::__vt": 0x803ac6f8,
		"JPADrawCalcAlpha::__vt": 0x803ac708,
		"JPADrawCalcColorCopyFromEmitter::__vt": 0x803ac718,
		"JPADrawCalcScaleAnmTimingReverseY::__vt": 0x803ac728,
		"JPADrawCalcScaleAnmTimingReverseX::__vt": 0x803ac738,
		"JPADrawCalcScaleAnmTimingRepeatY::__vt": 0x803ac748,
		"JPADrawCalcScaleAnmTimingRepeatX::__vt": 0x803ac758,
		"JPADrawCalcScaleAnmTimingNormal::__vt": 0x803ac768,
		"JPADrawCalcScaleCopyX2Y::__vt": 0x803ac778,
		"JPADrawCalcScaleYBySpeed::__vt": 0x803ac788,
		"JPADrawCalcScaleXBySpeed::__vt": 0x803ac798,
		"JPADrawCalcScaleY::__vt": 0x803ac7a8,
		"JPADrawCalcScaleX::__vt": 0x803ac7b8,
		"JPADrawExecCallBack::__vt": 0x803ac7c8,
		"JPADrawCalcTextureAnmIndexRandom::__vt": 0x803ac7ec,
		"JPADrawCalcTextureAnmIndexMerge::__vt": 0x803ac810,
		"JPADrawCalcTextureAnmIndexReverse::__vt": 0x803ac834,
		"JPADrawCalcTextureAnmIndexRepeat::__vt": 0x803ac858,
		"JPADrawCalcTextureAnmIndexNormal::__vt": 0x803ac87c,
		"JPADrawCalcColorAnmFrameRandom::__vt": 0x803ac8a0,
		"JPADrawCalcColorAnmFrameMerge::__vt": 0x803ac8c4,
		"JPADrawCalcColorAnmFrameReverse::__vt": 0x803ac8e8,
		"JPADrawCalcColorAnmFrameRepeat::__vt": 0x803ac90c,
		"JPADrawCalcColorAnmFrameNormal::__vt": 0x803ac930,
		"JPADrawCalcColorEnv::__vt": 0x803ac954,
		"JPADrawCalcColorPrm::__vt": 0x803ac978,
		"JPADrawExecRegisterColorChildPE::__vt": 0x803ac99c,
		"JPADrawExecRegisterColorEmitterE::__vt": 0x803ac9ac,
		"JPADrawExecRegisterColorEmitterP::__vt": 0x803ac9bc,
		"JPADrawExecRegisterColorEmitterPE::__vt": 0x803ac9cc,
		"JPADrawExecStripeCross::__vt": 0x803ac9dc,
		"JPADrawExecStripe::__vt": 0x803ac9ec,
		"JPADrawExecLine::__vt": 0x803ac9fc,
		"JPADrawExecPoint::__vt": 0x803aca0c,
		"JPADrawExecRotationCross::__vt": 0x803aca1c,
		"JPADrawExecRotation::__vt": 0x803aca2c,
		"JPADrawExecDirBillBoard::__vt": 0x803aca3c,
		"JPADrawExecRotDirectionalCross::__vt": 0x803aca4c,
		"JPADrawExecDirectionalCross::__vt": 0x803aca5c,
		"JPADrawExecRotDirectional::__vt": 0x803aca6c,
		"JPADrawExecDirectional::__vt": 0x803aca7c,
		"JPADrawExecRotYBillBoard::__vt": 0x803aca8c,
		"JPADrawExecYBillBoard::__vt": 0x803aca9c,
		"JPADrawExecRotBillBoard::__vt": 0x803acaac,
		"JPADrawExecBillBoard::__vt": 0x803acabc,
		"JPADrawExecRegisterPrmAEnv::__vt": 0x803acacc,
		"JPADrawExecRegisterPrmCEnv::__vt": 0x803acadc,
		"JPADrawExecRegisterEnvColorAnm::__vt": 0x803acaec,
		"JPADrawExecRegisterPrmAlphaAnm::__vt": 0x803acafc,
		"JPADrawExecRegisterPrmColorAnm::__vt": 0x803acb0c,
		"JPADrawExecSetLineWidth::__vt": 0x803acb1c,
		"JPADrawExecSetPointSize::__vt": 0x803acb2c,
		"JPADrawExecLoadTexture::__vt": 0x803acb3c,
		"JPADrawExecLoadDefaultTexture::__vt": 0x803acb60,
		"JPADrawExecSetTexMtx::__vt": 0x803acb70,
		"JPADrawExecGenIdtMtx::__vt": 0x803acb94,
		"JPADrawExecGenTexMtx0::__vt": 0x803acba4,
		"JPADrawExecGenPrjTexMtx::__vt": 0x803acbb4,
		"JPADrawExecGenPrjMtx::__vt": 0x803acbc4,
		"JPADrawExecLoadExTex::__vt": 0x803acbd4,
		"JPAExTexShape::__vt": 0x803acbe8,
		"JPADataBlock::__vt": 0x803acbf4,
		"JPAKeyFrameAnime::__vt": 0x803acc00,
		"JPAEmitterLoader::__vt": 0x803acc0c,
		"JPAEmitterLoader_v10::__vt": 0x803acc18,
		"JPABaseShape::stBlendMode": 0x803acc28,
		"stBlendMode": 0x803acc28,
		"JPABaseShape::stBlendFactor": 0x803acc38,
		"stBlendFactor": 0x803acc38,
		"JPABaseShape::stLogicOp": 0x803acc60,
		"stLogicOp": 0x803acc60,
		"JPABaseShape::stCompare": 0x803acca0,
		"stCompare": 0x803acca0,
		"JPABaseShape::stAlphaOp": 0x803accc0,
		"stAlphaOp": 0x803accc0,
		"JPABaseShape::__vt": 0x803accd0,
		"JPAExtraShape::__vt": 0x803acce0,
		"JPASweepShape::__vt": 0x803accf0,
		"JPATexture::__vt": 0x803acd00,
		"JStage::TAmbientLight::__vt": 0x803acd10,
		"JStage::TCamera::__vt": 0x803acd48,
		"JStage::TActor::__vt": 0x803acdd0,
		"JStage::TLight::__vt": 0x803ace38,
		"JStage::TObject::__vt": 0x803ace98,
		"JStage::TSystem::__vt": 0x803acec8,
		"MSL_C.PPCEABI.bare.H::__files": 0x803aec00,
		"__files": 0x803aec00,
		"MSL_C.PPCEABI.bare.H::@1009": 0x803aecd8,
		"@1009": 0x803aecd8,
		"MSL_C.PPCEABI.bare.H::@1066": 0x803aed5c,
		"@1066": 0x803aed5c,
		"MSL_C.PPCEABI.bare.H::@1186": 0x803aede0,
		"@1186": 0x803aede0,
		"MSL_C.PPCEABI.bare.H::@1185": 0x803aeeb0,
		"@1185": 0x803aeeb0,
		"MSL_C.PPCEABI.bare.H::@410": 0x803aeef8,
		"@410": 0x803aeef8,
		"MSL_C.PPCEABI.bare.H::__float_nan": 0x803aef40,
		"__float_nan": 0x803aef40,
		"MSL_C.PPCEABI.bare.H::__float_huge": 0x803aef44,
		"__float_huge": 0x803aef44,
		"MSL_C.PPCEABI.bare.H::__four_over_pi_m1": 0x803aef48,
		"__four_over_pi_m1": 0x803aef48,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTable": 0x803aef58,
		"gTRKDispatchTable": 0x803aef58,
		"TRK_MINNOW_DOLPHIN::@175": 0x803aefe0,
		"TRK_MINNOW_DOLPHIN::@214": 0x803aeffc,
		"TRK_MINNOW_DOLPHIN::gTRKRestoreFlags": 0x803af018,
		"gTRKRestoreFlags": 0x803af018,
		"TRK_MINNOW_DOLPHIN::gTRKExceptionStatus": 0x803af024,
		"gTRKExceptionStatus": 0x803af024,
		"TRK_MINNOW_DOLPHIN::gTRKStepStatus": 0x803af034,
		"gTRKStepStatus": 0x803af034,
		"TRK_MINNOW_DOLPHIN::TRK_ISR_OFFSETS": 0x803af048,
		"TRK_ISR_OFFSETS": 0x803af048,
		"TRK_MINNOW_DOLPHIN::gDBCommTable": 0x803af088,
		"gDBCommTable": 0x803af088,
		"db::@7": 0x803af0a8,
		"@7": 0x803af0a8,
		"os::@84": 0x803af0c0,
		"os::@85": 0x803af0e0,
		"@85": 0x803af0e0,
		"os::@86": 0x803af0f8,
		"@86": 0x803af0f8,
		"os::@87": 0x803af104,
		"@87": 0x803af104,
		"os::@88": 0x803af110,
		"@88": 0x803af110,
		"os::@89": 0x803af120,
		"@89": 0x803af120,
		"os::__OSExceptionLocations": 0x803af1a8,
		"__OSExceptionLocations": 0x803af1a8,
		"os::@130": 0x803af1e4,
		"os::@131": 0x803af200,
		"@131": 0x803af200,
		"os::@132": 0x803af230,
		"@132": 0x803af230,
		"os::@133": 0x803af260,
		"os::@352": 0x803af280,
		"@352": 0x803af280,
		"os::@353": 0x803af2a4,
		"@353": 0x803af2a4,
		"os::@354": 0x803af2dc,
		"os::@355": 0x803af304,
		"os::@356": 0x803af354,
		"@356": 0x803af354,
		"os::@357": 0x803af394,
		"os::@358": 0x803af3cc,
		"os::@359": 0x803af418,
		"@359": 0x803af418,
		"os::@360": 0x803af44c,
		"os::@361": 0x803af48c,
		"@361": 0x803af48c,
		"os::@362": 0x803af4c8,
		"@362": 0x803af4c8,
		"os::@363": 0x803af510,
		"os::@364": 0x803af570,
		"os::@383": 0x803af59c,
		"@383": 0x803af59c,
		"os::@384": 0x803af5b0,
		"@384": 0x803af5b0,
		"os::@385": 0x803af5c4,
		"os::@386": 0x803af5e0,
		"os::@387": 0x803af5f4,
		"@387": 0x803af5f4,
		"os::@388": 0x803af604,
		"os::DSPInitCode": 0x803af618,
		"DSPInitCode": 0x803af618,
		"os::@97": 0x803af808,
		"os::@98": 0x803af828,
		"os::@110": 0x803af844,
		"os::@111": 0x803af860,
		"os::@112": 0x803af87c,
		"@112": 0x803af87c,
		"os::@113": 0x803af894,
		"@113": 0x803af894,
		"os::@59": 0x803af8c8,
		"@59": 0x803af8c8,
		"os::@60": 0x803af90c,
		"os::@61": 0x803af93c,
		"os::@62": 0x803af96c,
		"@62": 0x803af96c,
		"os::@63": 0x803af99c,
		"os::@64": 0x803af9b0,
		"os::@65": 0x803af9d4,
		"@65": 0x803af9d4,
		"os::@66": 0x803af9e8,
		"os::@67": 0x803afa04,
		"@67": 0x803afa04,
		"os::@68": 0x803afa18,
		"@68": 0x803afa18,
		"os::@70": 0x803afa60,
		"@70": 0x803afa60,
		"os::@74": 0x803afa7c,
		"@74": 0x803afa7c,
		"os::@10": 0x803afaa0,
		"@10": 0x803afaa0,
		"os::@11": 0x803afab8,
		"@11": 0x803afab8,
		"os::@12": 0x803afae0,
		"@12": 0x803afae0,
		"os::@30": 0x803afafc,
		"os::@31": 0x803afb1c,
		"os::@33": 0x803afb34,
		"os::@34": 0x803afb68,
		"os::@35": 0x803afb78,
		"os::@36": 0x803afbd8,
		"os::@37": 0x803afc24,
		"os::@38": 0x803afc88,
		"os::@39": 0x803afce8,
		"os::@40": 0x803afd08,
		"os::@41": 0x803afd28,
		"os::@42": 0x803afd44,
		"os::@43": 0x803afd7c,
		"@43": 0x803afd7c,
		"os::HankakuToCode": 0x803afdc0,
		"HankakuToCode": 0x803afdc0,
		"os::Zenkaku2Code": 0x803aff40,
		"Zenkaku2Code": 0x803aff40,
		"os::InterruptPrioTable": 0x803b08d0,
		"InterruptPrioTable": 0x803b08d0,
		"os::ResetFunctionInfo": 0x803b0900,
		"os::YearDays": 0x803b0910,
		"YearDays": 0x803b0910,
		"os::LeapYearDays": 0x803b0940,
		"LeapYearDays": 0x803b0940,
		"dvd::@117": 0x803b0970,
		"dvd::@138": 0x803b0a38,
		"dvd::@237": 0x803b0a70,
		"dvd::@263": 0x803b0aa4,
		"@263": 0x803b0aa4,
		"dvd::@269": 0x803b0ad4,
		"dvd::@309": 0x803b0afc,
		"dvd::@340": 0x803b0b38,
		"dvd::@341": 0x803b0ba0,
		"dvd::@342": 0x803b0bf8,
		"@342": 0x803b0bf8,
		"dvd::@373": 0x803b0c54,
		"@373": 0x803b0c54,
		"dvd::@374": 0x803b0cb8,
		"@374": 0x803b0cb8,
		"dvd::@375": 0x803b0d08,
		"@375": 0x803b0d08,
		"dvd::@13": 0x803b0d60,
		"@13": 0x803b0d60,
		"dvd::@14": 0x803b0d78,
		"dvd::@15": 0x803b0d84,
		"dvd::@16": 0x803b0da0,
		"dvd::@293": 0x803b0dac,
		"dvd::@331": 0x803b0dcc,
		"@331": 0x803b0dcc,
		"dvd::@835": 0x803b0e0c,
		"@835": 0x803b0e0c,
		"dvd::@936": 0x803b0e40,
		"@936": 0x803b0e40,
		"dvd::ErrorTable": 0x803b0e78,
		"ErrorTable": 0x803b0e78,
		"dvd::@36": 0x803b0ec0,
		"dvd::@37": 0x803b0edc,
		"dvd::@38": 0x803b0ef4,
		"dvd::@39": 0x803b0f08,
		"dvd::@42": 0x803b0f1c,
		"vi::timing": 0x803b0f30,
		"timing": 0x803b0f30,
		"vi::taps": 0x803b1060,
		"taps": 0x803b1060,
		"vi::@92": 0x803b1094,
		"vi::@336": 0x803b10ec,
		"@336": 0x803b10ec,
		"vi::@337": 0x803b1118,
		"@337": 0x803b1118,
		"vi::@338": 0x803b1144,
		"@338": 0x803b1144,
		"vi::@339": 0x803b1170,
		"vi::@340": 0x803b119c,
		"vi::@341": 0x803b11c8,
		"pad::ResetFunctionInfo": 0x803b11f8,
		"dsp::@16": 0x803b1208,
		"dsp::@17": 0x803b1228,
		"dsp::@18": 0x803b1234,
		"dsp::@264": 0x803b1240,
		"@264": 0x803b1240,
		"dsp::@265": 0x803b1260,
		"@265": 0x803b1260,
		"dsp::@266": 0x803b1290,
		"@266": 0x803b1290,
		"dsp::@267": 0x803b12c0,
		"@267": 0x803b12c0,
		"dsp::@268": 0x803b12f0,
		"@268": 0x803b12f0,
		"dsp::@269": 0x803b1320,
		"dsp::@292": 0x803b1350,
		"card::ResetFunctionInfo": 0x803b1380,
		"card::SectorSizeTable": 0x803b1500,
		"SectorSizeTable": 0x803b1500,
		"card::LatencyTable": 0x803b1520,
		"LatencyTable": 0x803b1520,
		"gx::@189": 0x803b15a8,
		"gx::@256": 0x803b1610,
		"gx::@302": 0x803b1678,
		"gx::@329": 0x803b16bc,
		"gx::@393": 0x803b1700,
		"@393": 0x803b1700,
		"gx::@499": 0x803b1744,
		"@499": 0x803b1744,
		"gx::@498": 0x803b1760,
		"@498": 0x803b1760,
		"gx::GXNtsc480IntDf": 0x803b17b8,
		"GXNtsc480IntDf": 0x803b17b8,
		"gx::GXNtsc480Int": 0x803b17f4,
		"GXNtsc480Int": 0x803b17f4,
		"gx::GXMpal480IntDf": 0x803b1830,
		"GXMpal480IntDf": 0x803b1830,
		"gx::GXPal528IntDf": 0x803b186c,
		"GXPal528IntDf": 0x803b186c,
		"gx::GXEurgb60Hz480IntDf": 0x803b18a8,
		"GXEurgb60Hz480IntDf": 0x803b18a8,
		"gx::@92": 0x803b18e8,
		"gx::@168": 0x803b1ad0,
		"gx::c2r$71": 0x803b1b10,
		"c2r$71": 0x803b1b10,
		"gx::p2f$194": 0x803b1b38,
		"p2f$194": 0x803b1b38,
		"gx::@242": 0x803b1b58,
		"@242": 0x803b1b58,
		"gx::@241": 0x803b1bb4,
		"gd::@121": 0x803b1c48,
		"gd::@207": 0x803b1cb0,
		"@207": 0x803b1cb0,
		"gd::c2r$382": 0x803b1cf8,
		"c2r$382": 0x803b1cf8,
		"si::Si": 0x803b1d08,
		"Si": 0x803b1d08,
		"si::Type": 0x803b1d1c,
		"si::@456": 0x803b1d2c,
		"@456": 0x803b1d2c,
		"si::@458": 0x803b1d38,
		"@458": 0x803b1d38,
		"si::@459": 0x803b1d48,
		"@459": 0x803b1d48,
		"si::@460": 0x803b1d58,
		"@460": 0x803b1d58,
		"si::@461": 0x803b1d68,
		"si::@462": 0x803b1d74,
		"@462": 0x803b1d74,
		"si::@463": 0x803b1d84,
		"si::@464": 0x803b1d98,
		"@464": 0x803b1d98,
		"si::@465": 0x803b1dac,
		"@465": 0x803b1dac,
		"si::@466": 0x803b1dc0,
		"@466": 0x803b1dc0,
		"si::@467": 0x803b1dcc,
		"@467": 0x803b1dcc,
		"si::XYNTSC": 0x803b1dd8,
		"XYNTSC": 0x803b1dd8,
		"si::XYPAL": 0x803b1e08,
		"XYPAL": 0x803b1e08,
		"si::@16": 0x803b1e38,
		"THPPlayer::VolumeTable": 0x803b1e70,
		"VolumeTable": 0x803b1e70,
		"TDLColorTexQuad::__vt": 0x803b1f70,
		"TDLTexQuad::__vt": 0x803b1f90,
		"TSilhouette::__vt": 0x803b1fb0,
		"TLightWithDBSetManager::__vt": 0x803b1fd8,
		"TIndirectLightWithDBSet::__vt": 0x803b1ffc,
		"TMapObjectLightWithDBSet::__vt": 0x803b2024,
		"TObjectLightWithDBSet::__vt": 0x803b204c,
		"TPlayerLightWithDBSet::__vt": 0x803b2074,
		"TLightWithDBSet::__vt": 0x803b209c,
		"TLightDrawBuffer::__vt": 0x803b20c4,
		"TLightMario::__vt": 0x803b20ec,
		"TLightShadow::__vt": 0x803b2120,
		"TLightCommon::__vt": 0x803b2154,
		"MarioUtil::@1431": 0x803b2188,
		"MarioUtil::@1210": 0x803b21a0,
		"MarioUtil::atntable": 0x803b21b0,
		"atntable": 0x803b21b0,
		"TParamT<JGeometry::TVec3<float><float>>::__vt": 0x803b29c4,
		"TMtxSwingRZReverseXZ::__vt": 0x803b29d0,
		"TParamVec::__vt": 0x803b29dc,
		"TMtxSwingRZ::__vt": 0x803b29e8,
		"TMtxTimeLag::__vt": 0x803b2a00,
		"TMtxEffectBase::__vt": 0x803b2a0c,
		"TScreenTexture::__vt": 0x803b2a18,
		"TAfterEffect::__vt": 0x803b2a3c,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::vl$localstatic0$makeDL": 0x803b2a60,
		"vl$localstatic0$makeDL": 0x803b2a60,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::fl$localstatic1$makeDL": 0x803b2a70,
		"fl$localstatic1$makeDL": 0x803b2a70,
		"TMBindShadowManager::__vt": 0x803b2a90,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::__vt": 0x803b2ab4,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::__vt": 0x803b2ac4,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::__vt": 0x803b2ad4,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::__vt": 0x803b2ae4,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::__vt": 0x803b2af4,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::__vt": 0x803b2b04,
		"MarioUtil::IdentityMtx": 0x803b2b30,
		"IdentityMtx": 0x803b2b30,
		"MarioUtil::rumbleFrame_00": 0x803b2b60,
		"rumbleFrame_00": 0x803b2b60,
		"MarioUtil::rumblePower_00": 0x803b2b8c,
		"rumblePower_00": 0x803b2b8c,
		"MarioUtil::rumbleFrame_01": 0x803b2bb8,
		"rumbleFrame_01": 0x803b2bb8,
		"MarioUtil::rumblePower_01": 0x803b2c18,
		"rumblePower_01": 0x803b2c18,
		"MarioUtil::rumbleFrame_04": 0x803b2c78,
		"rumbleFrame_04": 0x803b2c78,
		"MarioUtil::rumblePower_04": 0x803b2c94,
		"rumblePower_04": 0x803b2c94,
		"MarioUtil::rumbleFrame_05": 0x803b2cb0,
		"rumbleFrame_05": 0x803b2cb0,
		"MarioUtil::rumblePower_05": 0x803b2d04,
		"rumblePower_05": 0x803b2d04,
		"MarioUtil::rumbleFrame_06": 0x803b2d58,
		"rumbleFrame_06": 0x803b2d58,
		"MarioUtil::rumblePower_06": 0x803b2d80,
		"rumblePower_06": 0x803b2d80,
		"MarioUtil::rumbleFrame_07": 0x803b2da8,
		"rumbleFrame_07": 0x803b2da8,
		"MarioUtil::rumblePower_07": 0x803b2df8,
		"rumblePower_07": 0x803b2df8,
		"MarioUtil::rumbleFrame_08": 0x803b2e48,
		"rumbleFrame_08": 0x803b2e48,
		"MarioUtil::rumblePower_08": 0x803b2e5c,
		"rumblePower_08": 0x803b2e5c,
		"MarioUtil::rumbleFrame_09": 0x803b2e70,
		"rumbleFrame_09": 0x803b2e70,
		"MarioUtil::rumblePower_09": 0x803b2e80,
		"rumblePower_09": 0x803b2e80,
		"MarioUtil::rumbleFrame_19": 0x803b2e90,
		"rumbleFrame_19": 0x803b2e90,
		"MarioUtil::rumblePower_19": 0x803b2ea4,
		"rumblePower_19": 0x803b2ea4,
		"MarioUtil::rumbleFrame_23": 0x803b2eb8,
		"rumbleFrame_23": 0x803b2eb8,
		"MarioUtil::rumblePower_23": 0x803b2fec,
		"rumblePower_23": 0x803b2fec,
		"MarioUtil::rumbleFrame_24": 0x803b3120,
		"rumbleFrame_24": 0x803b3120,
		"MarioUtil::rumblePower_24": 0x803b31b4,
		"rumblePower_24": 0x803b31b4,
		"MarioUtil::channelDataTbl": 0x803b3248,
		"channelDataTbl": 0x803b3248,
		"MarioUtil::_info": 0x803b3378,
		"_info": 0x803b3378,
		"TGDLStatic::__vt": 0x803b3460,
		"TGDLStatic::TGDLSentinel::__vt": 0x803b3470,
		"Koga::ToolData::__vt": 0x803b3480,
		"M3DUtil::@1411": 0x803b3490,
		"M3UMtxCalcSIAnmBlendQuat::__vt": 0x803b349c,
		"M3UModel::__vt": 0x803b34e0,
		"M3UModelCommon::__vt": 0x803b3504,
		"MActorAnmEach<J3DAnmClusterKey>::__vt": 0x803b3510,
		"MActorAnmMatEach<J3DAnmTevRegKey>::__vt": 0x803b3538,
		"MActorAnmEach<J3DAnmTevRegKey>::__vt": 0x803b3560,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::__vt": 0x803b3588,
		"MActorAnmEach<J3DAnmTextureSRTKey>::__vt": 0x803b35b0,
		"MActorAnmMatEach<J3DAnmTexPattern>::__vt": 0x803b35d8,
		"MActorAnmEach<J3DAnmTexPattern>::__vt": 0x803b3600,
		"MActorAnmMatEach<J3DAnmColorKey>::__vt": 0x803b3628,
		"MActorAnmEach<J3DAnmColorKey>::__vt": 0x803b3650,
		"MActorAnmEach<J3DAnmTransformKey>::__vt": 0x803b3678,
		"MActorAnmBlk::__vt": 0x803b36a0,
		"MActorAnmBrk::__vt": 0x803b36c8,
		"MActorAnmBpk::__vt": 0x803b36f0,
		"MActorAnmBtk::__vt": 0x803b3718,
		"MActorAnmBtp::__vt": 0x803b3740,
		"MActorAnmBck::__vt": 0x803b3768,
		"MActorAnmBase::__vt": 0x803b3790,
		"SDLModel::__vt": 0x803b37b8,
		"SDLMatPacket::__vt": 0x803b37d8,
		"SampleCtrlJoint::__vt": 0x803b37f0,
		"SampleCtrlMaterial::__vt": 0x803b37fc,
		"SampleCtrlShape::__vt": 0x803b3808,
		"SampleCtrlModelData::__vt": 0x803b3818,
		"TBaseParam::__vt": 0x803b3828,
		"TMarioParticleManager::__vt": 0x803b3860,
		"TMarioEmitterCallBackBindToSRTMtxPtr::__vt": 0x803b38a8,
		"TMarioEmitterCallBackBindToMtxPtr::__vt": 0x803b38bc,
		"TMarioEmitterCallBackBindToPosPtr::__vt": 0x803b38d0,
		"TEmitterIndirectViewObj::__vt": 0x803b38e4,
		"TEmitterViewObj::__vt": 0x803b3908,
		"JPACallBackBase<JPABaseEmitter*>::__vt": 0x803b392c,
		"TEventWatcher::__vt": 0x803b3940,
		"TSpcTypedInterp<TEventWatcher>::__vt": 0x803b3968,
		"TSpcTypedBinary<TEventWatcher>::__vt": 0x803b397c,
		"System::@2031": 0x803b3990,
		"System::@2087": 0x803b39e8,
		"System::@2135": 0x803b3a10,
		"System::@2168": 0x803b3a3c,
		"TGCLogoDir::__vt": 0x803b3a68,
		"TNintendo2D::__vt": 0x803b3ad4,
		"TGXAlphaUpdate::__vt": 0x803b3af8,
		"TReInitGX::__vt": 0x803b3b1c,
		"TSMSDrawInit::__vt": 0x803b3b40,
		"TJ3DSysSetViewMtx::__vt": 0x803b3b64,
		"TJ3DSysFlag::__vt": 0x803b3b88,
		"System::@3623": 0x803b3bb0,
		"System::@4377": 0x803b3c04,
		"TMarDirector::__vt": 0x803b3ca0,
		"TMarNameRefGen::__vt": 0x803b3d10,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::__vt": 0x803b3d20,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::__vt": 0x803b3d40,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::__vt": 0x803b3d60,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::__vt": 0x803b3da0,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::__vt": 0x803b3dc0,
		"TCubeManagerFast::__vt": 0x803b3de0,
		"TCubeManagerArea::__vt": 0x803b3e04,
		"TCubeManagerMarioIn::__vt": 0x803b3e28,
		"TMenuDirector::__vt": 0x803b3ea8,
		"TPerformList::__vt": 0x803b3f18,
		"System::SMSAASamplePattern_non": 0x803b3f68,
		"SMSAASamplePattern_non": 0x803b3f68,
		"System::SMSAASamplePattern_aa": 0x803b3f80,
		"SMSAASamplePattern_aa": 0x803b3f80,
		"System::SMSVFilter_non": 0x803b3f98,
		"SMSVFilter_non": 0x803b3f98,
		"System::SMSVFilter_flicker": 0x803b3fa0,
		"SMSVFilter_flicker": 0x803b3fa0,
		"TSnapTimeObj::__vt": 0x803b3fa8,
		"TTalkCursor::__vt": 0x803b3fd0,
		"TAlphaCatch::__vt": 0x803b3ff8,
		"TZBufferCatch::__vt": 0x803b401c,
		"System::@2633": 0x803b4040,
		"System::@2929": 0x803b4074,
		"TMarioGamePad::__vt": 0x803b409c,
		"TScenarioArchiveName::__vt": 0x803b40a8,
		"TStageEventInfo::__vt": 0x803b40c8,
		"System::shineStageTable": 0x803b40e8,
		"shineStageTable": 0x803b40e8,
		"System::exShineTable": 0x803b4128,
		"exShineTable": 0x803b4128,
		"TStagePositionInfo::__vt": 0x803b4148,
		"TTimeRec::__vt": 0x803b4168,
		"TTHPRender::__vt": 0x803b4180,
		"TNameKuriLauncherManager::__vt": 0x803b41a8,
		"THamuKuriLauncherManager::__vt": 0x803b41fc,
		"TCasinoRoulette::__vt": 0x803b43c0,
		"TSirenaGate::__vt": 0x803b4528,
		"TMareWManager::__vt": 0x803b4740,
		"TMareMManager::__vt": 0x803b4798,
		"System::titles": 0x803b4818,
		"titles": 0x803b4818,
		"System::comments": 0x803b4834,
		"comments": 0x803b4834,
		"System::@1818": 0x803b4850,
		"System::movies$2032": 0x803b4888,
		"movies$2032": 0x803b4888,
		"TMovieDirector::__vt": 0x803b48d8,
		"System::@3810": 0x803b4948,
		"System::@3898": 0x803b4970,
		"System::@3897": 0x803b4998,
		"MSSTageSimpleEnvironment::__vt": 0x803b4af4,
		"MSStageCubeSwitch::__vt": 0x803b4b08,
		"MSStageCubeFadeMonte::__vt": 0x803b4b1c,
		"MSStageCubeFade::__vt": 0x803b4b30,
		"MSStageDistFadeMonte::__vt": 0x803b4b44,
		"MSStageDistFade::__vt": 0x803b4b58,
		"MSStage::__vt": 0x803b4b6c,
		"TTargetArrow::__vt": 0x803b4b80,
		"TLiveActor::__vt": 0x803b4ba8,
		"Strategic::@3444": 0x803b4ca8,
		"TLiveManager::__vt": 0x803b4e58,
		"TObjManager::__vt": 0x803b4ea8,
		"TObjChara::__vt": 0x803b4ed8,
		"Strategic::@285": 0x803b4f00,
		"@285": 0x803b4f00,
		"Strategic::@286": 0x803b4f0c,
		"@286": 0x803b4f0c,
		"Strategic::@287": 0x803b4f18,
		"@287": 0x803b4f18,
		"Strategic::@288": 0x803b4f24,
		"Strategic::@289": 0x803b4f30,
		"Strategic::@290": 0x803b4f3c,
		"@290": 0x803b4f3c,
		"Strategic::@291": 0x803b4f48,
		"@291": 0x803b4f48,
		"Strategic::@292": 0x803b4f54,
		"Strategic::@293": 0x803b4f60,
		"Strategic::@294": 0x803b4f6c,
		"Strategic::@295": 0x803b4f78,
		"Strategic::@296": 0x803b4f84,
		"@296": 0x803b4f84,
		"Strategic::@297": 0x803b4f90,
		"Strategic::@298": 0x803b4f9c,
		"@298": 0x803b4f9c,
		"Strategic::@299": 0x803b4fa8,
		"@299": 0x803b4fa8,
		"Strategic::@300": 0x803b4fb4,
		"@300": 0x803b4fb4,
		"Strategic::@301": 0x803b4fc0,
		"Strategic::@302": 0x803b4fcc,
		"Strategic::@303": 0x803b4fd8,
		"Strategic::@304": 0x803b4fe4,
		"Strategic::@305": 0x803b4ff0,
		"Strategic::@306": 0x803b4ffc,
		"@306": 0x803b4ffc,
		"Strategic::@307": 0x803b5008,
		"@307": 0x803b5008,
		"Strategic::@308": 0x803b5014,
		"@308": 0x803b5014,
		"Strategic::@309": 0x803b5020,
		"Strategic::@310": 0x803b502c,
		"@310": 0x803b502c,
		"Strategic::@311": 0x803b5038,
		"@311": 0x803b5038,
		"Strategic::@312": 0x803b5044,
		"@312": 0x803b5044,
		"Strategic::@313": 0x803b5050,
		"@313": 0x803b5050,
		"Strategic::@314": 0x803b505c,
		"@314": 0x803b505c,
		"Strategic::@315": 0x803b5068,
		"@315": 0x803b5068,
		"Strategic::@316": 0x803b5074,
		"@316": 0x803b5074,
		"Strategic::@317": 0x803b5080,
		"@317": 0x803b5080,
		"Strategic::@318": 0x803b508c,
		"@318": 0x803b508c,
		"Strategic::@319": 0x803b5098,
		"@319": 0x803b5098,
		"Strategic::@320": 0x803b50a4,
		"Strategic::@321": 0x803b50b0,
		"Strategic::@322": 0x803b50bc,
		"Strategic::@323": 0x803b50c8,
		"Strategic::@324": 0x803b50d4,
		"Strategic::table$284": 0x803b50e0,
		"table$284": 0x803b50e0,
		"TSpcInterp::__vt": 0x803b52c0,
		"TSpcStack<TSpcSlice>::__vt": 0x803b52d4,
		"TSpcStack<unsigned_long><unsigned_long>::__vt": 0x803b52e0,
		"TSpcBinary::__vt": 0x803b52ec,
		"TStrategy::__vt": 0x803b5300,
		"TIdxGroupObj::__vt": 0x803b5324,
		"TQuestionManager::__vt": 0x803b5350,
		"TSMSSmplChara::__vt": 0x803b5378,
		"THitActor::__vt": 0x803b53a0,
		"TBinder::__vt": 0x803b5448,
		"TSharedParts::__vt": 0x803b5458,
		"TMirrorActor::__vt": 0x803b5480,
		"M3UModelMario::__vt": 0x803b54a8,
		"TMarioCap::__vt": 0x803b54d0,
		"Player::marioAnimeFiles": 0x803b5518,
		"Player::gMarioAnimeData": 0x803b5b50,
		"gMarioAnimeData": 0x803b5b50,
		"Player::marioAnimeTexPatternFilenames": 0x803b65d0,
		"marioAnimeTexPatternFilenames": 0x803b65d0,
		"Player::@6663": 0x803b6720,
		"Player::@6662": 0x803b6744,
		"Player::param$3393": 0x803b67a8,
		"param$3393": 0x803b67a8,
		"Player::param$3396": 0x803b67bc,
		"param$3396": 0x803b67bc,
		"Player::param$3399": 0x803b67d0,
		"param$3399": 0x803b67d0,
		"Player::param$3402": 0x803b67e4,
		"param$3402": 0x803b67e4,
		"Player::param$3407": 0x803b67f8,
		"param$3407": 0x803b67f8,
		"Player::param$3410": 0x803b680c,
		"param$3410": 0x803b680c,
		"Player::cParticleFileNames": 0x803b6820,
		"cParticleFileNames": 0x803b6820,
		"TWarpInCallBack::__vt": 0x803b682c,
		"TBubbleCallBack::__vt": 0x803b6864,
		"TSplashManager::__vt": 0x803b6888,
		"TYoshiTongue::__vt": 0x803b68b0,
		"Player::nozzleBmdData": 0x803b6998,
		"nozzleBmdData": 0x803b6998,
		"TWaterGun::__vt": 0x803b6a40,
		"Player::@4827": 0x803b6a4c,
		"TNozzleDeform::__vt": 0x803b6ab8,
		"TNozzleTrigger::__vt": 0x803b6ae0,
		"TNozzleBase::__vt": 0x803b6b08,
		"Player::@3436": 0x803b6b30,
		"TMarioEffect::__vt": 0x803b6b78,
		"TMario::__vt": 0x803b6c48,
		"Player::gModelWaterManagerWaterColor": 0x803b6e98,
		"gModelWaterManagerWaterColor": 0x803b6e98,
		"Player::prmNames": 0x803b6ea8,
		"prmNames": 0x803b6ea8,
		"Player::gWaterManagerPlaneInfo": 0x803b6eec,
		"gWaterManagerPlaneInfo": 0x803b6eec,
		"TModelWaterManager::__vt": 0x803b7fec,
		"TMarioPositionObj::__vt": 0x803b8138,
		"Player::@4230": 0x803b8160,
		"NPC::@3884": 0x803b8250,
		"NPC::@3883": 0x803b82a4,
		"NPC::@3880": 0x803b82f4,
		"NPC::@4719": 0x803b8350,
		"TBaseNPC::__vt": 0x803b83a8,
		"NPC::@3445": 0x803b84bc,
		"NPC::@3991": 0x803b8514,
		"NPC::@3990": 0x803b853c,
		"NPC::@4128": 0x803b8598,
		"NPC::@4190": 0x803b85f4,
		"TSunflowerSManager::__vt": 0x803b8650,
		"NPC::@2899": 0x803b86a8,
		"TMareWBaseManager::__vt": 0x803b86e0,
		"TMareMBaseManager::__vt": 0x803b8738,
		"TMonteWBManager::__vt": 0x803b8790,
		"TMonteWAManager::__vt": 0x803b87e8,
		"TMonteWManager::__vt": 0x803b8840,
		"TMonteMEManager::__vt": 0x803b8898,
		"TMonteMDManager::__vt": 0x803b88f0,
		"TMonteMCManager::__vt": 0x803b8948,
		"TMonteMBManager::__vt": 0x803b89a0,
		"TMonteMAManager::__vt": 0x803b89f8,
		"TMonteMManager::__vt": 0x803b8a50,
		"TSunflowerLManager::__vt": 0x803b8aa8,
		"TRaccoonDogManager::__vt": 0x803b8b00,
		"TPeachManager::__vt": 0x803b8b58,
		"TKinojiiManager::__vt": 0x803b8bb0,
		"TKinopioManager::__vt": 0x803b8c08,
		"TMareWBManager::__vt": 0x803b8c60,
		"TMareWAManager::__vt": 0x803b8cb8,
		"TMareMDManager::__vt": 0x803b8d10,
		"TMareMCManager::__vt": 0x803b8d68,
		"TMareMBManager::__vt": 0x803b8dc0,
		"TMareMAManager::__vt": 0x803b8e18,
		"TMonteWCManager::__vt": 0x803b8e70,
		"TMonteMHManager::__vt": 0x803b8ec8,
		"TMonteMGManager::__vt": 0x803b8f20,
		"TMonteMFManager::__vt": 0x803b8f78,
		"TMonteWSpecialManager::__vt": 0x803b8fd0,
		"TMonteMSpecialManager::__vt": 0x803b9028,
		"TMonteWBaseManager::__vt": 0x803b9080,
		"TMonteMBaseManager::__vt": 0x803b90d8,
		"TMareBaseManager::__vt": 0x803b9130,
		"TNPCManager::__vt": 0x803b9188,
		"TMareJellyFishManager::__vt": 0x803b91e0,
		"TBoardNpcManager::__vt": 0x803b9210,
		"TNerveNPCMareStand::__vt": 0x803b9250,
		"TNerveNPCBlown::__vt": 0x803b9270,
		"TNerveNPCMad::__vt": 0x803b9280,
		"TNerveNPCThrow::__vt": 0x803b9290,
		"TNerveNPCTalk::__vt": 0x803b92a0,
		"TNerveNPCSetPosAfterSinkBottom::__vt": 0x803b92b0,
		"TNerveNPCRecoverAfter::__vt": 0x803b92c0,
		"TNerveNPCRecoverFromSink::__vt": 0x803b92d0,
		"TNerveNPCSink::__vt": 0x803b92e0,
		"TNerveNPCWet::__vt": 0x803b92f0,
		"TNerveNPCTurnToMario::__vt": 0x803b9300,
		"TNerveNPCWaitMarioApproach::__vt": 0x803b9310,
		"TNerveNPCWaitContinue::__vt": 0x803b9320,
		"TNerveNPCGraphWait::__vt": 0x803b9330,
		"TNerveNPCUTurn::__vt": 0x803b9340,
		"TNerveNPCGraphWander::__vt": 0x803b9350,
		"NPC::sSaveFileName$1960": 0x803b9360,
		"sSaveFileName$1960": 0x803b9360,
		"NPC::sCameraNames$2626": 0x803b93d8,
		"sCameraNames$2626": 0x803b93d8,
		"NPC::sMareMB_FishingRodData": 0x803b9418,
		"sMareMB_FishingRodData": 0x803b9418,
		"NPC::sMareWB_BabyData": 0x803b9444,
		"sMareWB_BabyData": 0x803b9444,
		"NPC::sAllNpcInitData$1622": 0x803b9470,
		"sAllNpcInitData$1622": 0x803b9470,
		"NPC::MtxCalcTypeName": 0x803b9510,
		"NPC::monteMCommon_bastable": 0x803b9520,
		"monteMCommon_bastable": 0x803b9520,
		"NPC::monteMCommon_bas_c_table": 0x803b957c,
		"monteMCommon_bas_c_table": 0x803b957c,
		"NPC::monteME_bastable": 0x803b95d8,
		"monteME_bastable": 0x803b95d8,
		"NPC::monteME_bas_c_table": 0x803b95f4,
		"monteME_bas_c_table": 0x803b95f4,
		"NPC::monteMF_bastable": 0x803b9610,
		"monteMF_bastable": 0x803b9610,
		"NPC::monteMF_bas_c_table": 0x803b961c,
		"monteMF_bas_c_table": 0x803b961c,
		"NPC::monteMH_bastable": 0x803b9628,
		"monteMH_bastable": 0x803b9628,
		"NPC::monteMH_bas_c_table": 0x803b9638,
		"monteMH_bas_c_table": 0x803b9638,
		"NPC::monteWCommon_bastable": 0x803b9648,
		"monteWCommon_bastable": 0x803b9648,
		"NPC::monteWCommon_bas_c_table": 0x803b96a8,
		"monteWCommon_bas_c_table": 0x803b96a8,
		"NPC::monteWC_bastable": 0x803b9708,
		"monteWC_bastable": 0x803b9708,
		"NPC::monteWC_bas_c_table": 0x803b971c,
		"monteWC_bas_c_table": 0x803b971c,
		"NPC::mareM_bastable": 0x803b9730,
		"mareM_bastable": 0x803b9730,
		"NPC::mareM_bas_c_table": 0x803b9784,
		"mareM_bas_c_table": 0x803b9784,
		"NPC::mareMA_bastable": 0x803b97d8,
		"mareMA_bastable": 0x803b97d8,
		"NPC::mareMA_bas_c_table": 0x803b97ec,
		"mareMA_bas_c_table": 0x803b97ec,
		"NPC::mareMB_bastable": 0x803b9800,
		"mareMB_bastable": 0x803b9800,
		"NPC::mareMB_bas_c_table": 0x803b9818,
		"mareMB_bas_c_table": 0x803b9818,
		"NPC::mareMC_bastable": 0x803b9830,
		"mareMC_bastable": 0x803b9830,
		"NPC::mareMC_bas_c_table": 0x803b9844,
		"mareMC_bas_c_table": 0x803b9844,
		"NPC::mareW_bastable": 0x803b9858,
		"mareW_bastable": 0x803b9858,
		"NPC::mareW_bas_c_table": 0x803b98a8,
		"mareW_bas_c_table": 0x803b98a8,
		"NPC::mareWA_bastable": 0x803b98f8,
		"mareWA_bastable": 0x803b98f8,
		"NPC::mareWA_bas_c_table": 0x803b9908,
		"mareWA_bas_c_table": 0x803b9908,
		"NPC::mareWB_bastable": 0x803b9918,
		"mareWB_bastable": 0x803b9918,
		"NPC::mareWB_bas_c_table": 0x803b9930,
		"mareWB_bas_c_table": 0x803b9930,
		"NPC::kinopio_bastable": 0x803b9948,
		"kinopio_bastable": 0x803b9948,
		"NPC::kinopio_bas_c_table": 0x803b99ac,
		"kinopio_bas_c_table": 0x803b99ac,
		"NPC::kinojii_bastable": 0x803b9a10,
		"kinojii_bastable": 0x803b9a10,
		"NPC::kinojii_bas_c_table": 0x803b9a58,
		"kinojii_bas_c_table": 0x803b9a58,
		"NPC::peach_bastable": 0x803b9aa0,
		"peach_bastable": 0x803b9aa0,
		"NPC::peach_bas_c_table": 0x803b9afc,
		"peach_bas_c_table": 0x803b9afc,
		"NPC::raccoonDog_bastable": 0x803b9b58,
		"raccoonDog_bastable": 0x803b9b58,
		"NPC::raccoonDog_bas_c_table": 0x803b9b68,
		"raccoonDog_bas_c_table": 0x803b9b68,
		"NPC::sunflowerL_bastable": 0x803b9b78,
		"sunflowerL_bastable": 0x803b9b78,
		"NPC::sunflowerL_bas_c_table": 0x803b9b8c,
		"sunflowerL_bas_c_table": 0x803b9b8c,
		"NPC::sunflowerS_bastable": 0x803b9ba0,
		"sunflowerS_bastable": 0x803b9ba0,
		"NPC::sunflowerS_bas_c_table": 0x803b9bb4,
		"sunflowerS_bas_c_table": 0x803b9bb4,
		"MAnmSoundNPC::__vt": 0x803b9c28,
		"MAnmSound::__vt": 0x803b9c38,
		"MSSeCallBack::smTrackCategory": 0x803b9c48,
		"smTrackCategory": 0x803b9c48,
		"MSSeCallBack::smPolifonic": 0x803b9c88,
		"smPolifonic": 0x803b9c88,
		"MSound::__vt": 0x803b9c98,
		"MSound::@2331": 0x803b9d28,
		"MSoundSESystem::MSRandPlay::__vt": 0x803b9de8,
		"MSound::@2334": 0x803b9df4,
		"MSSetSoundTL<MSSetSoundGrp>::__vt": 0x803b9e80,
		"MSSetSoundGrp::__vt": 0x803b9e98,
		"MSoundSESystem::MSRandVol::__vt": 0x803b9eb0,
		"JALListFrameLoop<MSSetSoundGrp>::__vt": 0x803b9ebc,
		"MSSetSoundTL<MSSetSound>::__vt": 0x803b9ec8,
		"MSSetSound::__vt": 0x803b9ee0,
		"JALListFrameLoop<MSSetSound>::__vt": 0x803b9ef8,
		"MSHandle::smACosPrm": 0x803b9f30,
		"smACosPrm": 0x803b9f30,
		"MSHandle::smSeCategory": 0x803ba0c4,
		"smSeCategory": 0x803ba0c4,
		"MSHandle::__vt": 0x803ba1c4,
		"MSBgmXFade::scTiming": 0x803ba240,
		"scTiming": 0x803ba240,
		"MSBgmXFade::scExp": 0x803ba288,
		"scExp": 0x803ba288,
		"TWoodBarrel::__vt": 0x803ba2d0,
		"TMapObjBase::__vt": 0x803ba4b0,
		"TMapObjGeneral::mDefaultSound": 0x803ba650,
		"mDefaultSound": 0x803ba650,
		"MoveBG::normal_sound_data": 0x803ba678,
		"normal_sound_data": 0x803ba678,
		"MoveBG::end_data": 0x803ba6a0,
		"end_data": 0x803ba6a0,
		"MoveBG::no_data": 0x803ba6dc,
		"no_data": 0x803ba6dc,
		"MoveBG::billboard_dolphin_data": 0x803ba718,
		"billboard_dolphin_data": 0x803ba718,
		"MoveBG::billboard_sun_data": 0x803ba754,
		"billboard_sun_data": 0x803ba754,
		"MoveBG::billboard_restaurant_data": 0x803ba790,
		"billboard_restaurant_data": 0x803ba790,
		"MoveBG::billboard_fish_data": 0x803ba7cc,
		"billboard_fish_data": 0x803ba7cc,
		"MoveBG::HideObj_data": 0x803ba808,
		"HideObj_data": 0x803ba808,
		"MoveBG::WaterHitHideObj_data": 0x803ba844,
		"WaterHitHideObj_data": 0x803ba844,
		"MoveBG::FruitHitHideObj_data": 0x803ba880,
		"FruitHitHideObj_data": 0x803ba880,
		"MoveBG::HipDropHideObj_data": 0x803ba8bc,
		"HipDropHideObj_data": 0x803ba8bc,
		"MoveBG::MonteChair_data": 0x803ba8f8,
		"MonteChair_data": 0x803ba8f8,
		"MoveBG::door_data": 0x803ba934,
		"door_data": 0x803ba934,
		"MoveBG::doorHotel_data": 0x803ba970,
		"doorHotel_data": 0x803ba970,
		"MoveBG::manhole_data": 0x803ba9ac,
		"manhole_data": 0x803ba9ac,
		"MoveBG::FruitBasket_data": 0x803ba9e8,
		"FruitBasket_data": 0x803ba9e8,
		"MoveBG::BasketReverse_data": 0x803baa24,
		"BasketReverse_data": 0x803baa24,
		"MoveBG::CoconutJuice_data": 0x803baa60,
		"CoconutJuice_data": 0x803baa60,
		"MoveBG::Pile_data": 0x803baa9c,
		"Pile_data": 0x803baa9c,
		"MoveBG::ChangeStage_data": 0x803baad8,
		"ChangeStage_data": 0x803baad8,
		"MoveBG::ChangeStageMerrygoround_data": 0x803bab14,
		"ChangeStageMerrygoround_data": 0x803bab14,
		"MoveBG::StartDemo_data": 0x803bab50,
		"StartDemo_data": 0x803bab50,
		"MoveBG::ChipShine_data": 0x803bab8c,
		"ChipShine_data": 0x803bab8c,
		"MoveBG::KoopaJrSignM_data": 0x803babc8,
		"KoopaJrSignM_data": 0x803babc8,
		"MoveBG::StarSign_data": 0x803bac04,
		"StarSign_data": 0x803bac04,
		"MoveBG::SignCircle_data": 0x803bac40,
		"SignCircle_data": 0x803bac40,
		"MoveBG::SignCross_data": 0x803bac7c,
		"SignCross_data": 0x803bac7c,
		"MoveBG::SignTriangle_data": 0x803bacb8,
		"SignTriangle_data": 0x803bacb8,
		"MoveBG::ArrowBoardLR_data": 0x803bacf4,
		"ArrowBoardLR_data": 0x803bacf4,
		"MoveBG::ArrowBoardUp_data": 0x803bad30,
		"ArrowBoardUp_data": 0x803bad30,
		"MoveBG::ArrowBoardDown_data": 0x803bad6c,
		"ArrowBoardDown_data": 0x803bad6c,
		"MoveBG::WaterSprayCylinder_data": 0x803bada8,
		"WaterSprayCylinder_data": 0x803bada8,
		"MoveBG::WaterSprayBox_data": 0x803bade4,
		"WaterSprayBox_data": 0x803bade4,
		"MoveBG::ObjSwitch_data": 0x803bae20,
		"ObjSwitch_data": 0x803bae20,
		"MoveBG::RedCoinSwitch_data": 0x803bae5c,
		"RedCoinSwitch_data": 0x803bae5c,
		"MoveBG::bucket_data": 0x803bae98,
		"bucket_data": 0x803bae98,
		"MoveBG::GeneralHitObj_data": 0x803baed4,
		"GeneralHitObj_data": 0x803baed4,
		"MoveBG::bottle_large_data": 0x803baf10,
		"bottle_large_data": 0x803baf10,
		"MoveBG::bottle_short_data": 0x803baf4c,
		"bottle_short_data": 0x803baf4c,
		"MoveBG::WaterRecoverObj_data": 0x803baf88,
		"WaterRecoverObj_data": 0x803baf88,
		"MoveBG::watergun_item_data": 0x803bafc4,
		"watergun_item_data": 0x803bafc4,
		"MoveBG::nozzle_normal_physical_data": 0x803bb000,
		"nozzle_normal_physical_data": 0x803bb000,
		"MoveBG::nozzle_normal_physical_info": 0x803bb034,
		"nozzle_normal_physical_info": 0x803bb034,
		"MoveBG::nozzle_normal_item_data": 0x803bb040,
		"nozzle_normal_item_data": 0x803bb040,
		"MoveBG::yoshi_whistle_item_data": 0x803bb07c,
		"yoshi_whistle_item_data": 0x803bb07c,
		"MoveBG::nozzle_rocket_item_data": 0x803bb0b8,
		"nozzle_rocket_item_data": 0x803bb0b8,
		"MoveBG::nozzle_back_item_data": 0x803bb0f4,
		"nozzle_back_item_data": 0x803bb0f4,
		"MoveBG::coin_physical_data": 0x803bb130,
		"coin_physical_data": 0x803bb130,
		"MoveBG::coin_physical_info": 0x803bb164,
		"coin_physical_info": 0x803bb164,
		"MoveBG::coin_data": 0x803bb170,
		"coin_data": 0x803bb170,
		"MoveBG::invisible_coin_data": 0x803bb1ac,
		"invisible_coin_data": 0x803bb1ac,
		"MoveBG::coin_red_data": 0x803bb1e8,
		"coin_red_data": 0x803bb1e8,
		"MoveBG::coin_blue_data": 0x803bb224,
		"coin_blue_data": 0x803bb224,
		"MoveBG::shine_data": 0x803bb260,
		"shine_data": 0x803bb260,
		"MoveBG::mario_cap_data": 0x803bb29c,
		"mario_cap_data": 0x803bb29c,
		"MoveBG::joint_coin_data": 0x803bb2d8,
		"joint_coin_data": 0x803bb2d8,
		"MoveBG::eggYoshi_data": 0x803bb314,
		"eggYoshi_data": 0x803bb314,
		"MoveBG::EggYoshi_physical_data": 0x803bb350,
		"EggYoshi_physical_data": 0x803bb350,
		"MoveBG::EggYoshi_physical_info": 0x803bb384,
		"EggYoshi_physical_info": 0x803bb384,
		"MoveBG::eggYoshiEvent_data": 0x803bb390,
		"eggYoshiEvent_data": 0x803bb390,
		"MoveBG::NozzleBox_data": 0x803bb3cc,
		"NozzleBox_data": 0x803bb3cc,
		"MoveBG::mushroom1up_data": 0x803bb408,
		"mushroom1up_data": 0x803bb408,
		"MoveBG::mushroom1upR_data": 0x803bb444,
		"mushroom1upR_data": 0x803bb444,
		"MoveBG::mushroom1upX_data": 0x803bb480,
		"mushroom1upX_data": 0x803bb480,
		"MoveBG::jumpbase_data": 0x803bb4bc,
		"jumpbase_data": 0x803bb4bc,
		"MoveBG::coconut_physical_data": 0x803bb4f8,
		"coconut_physical_data": 0x803bb4f8,
		"MoveBG::coconut_physical_info": 0x803bb52c,
		"coconut_physical_info": 0x803bb52c,
		"MoveBG::coconut_data": 0x803bb538,
		"coconut_data": 0x803bb538,
		"MoveBG::papaya_physical_data": 0x803bb574,
		"papaya_physical_data": 0x803bb574,
		"MoveBG::papaya_physical_info": 0x803bb5a8,
		"papaya_physical_info": 0x803bb5a8,
		"MoveBG::papaya_data": 0x803bb5b4,
		"papaya_data": 0x803bb5b4,
		"MoveBG::pine_physical_data": 0x803bb5f0,
		"pine_physical_data": 0x803bb5f0,
		"MoveBG::pine_physical_info": 0x803bb624,
		"pine_physical_info": 0x803bb624,
		"MoveBG::pine_data": 0x803bb630,
		"pine_data": 0x803bb630,
		"MoveBG::CoverPine_data": 0x803bb66c,
		"CoverPine_data": 0x803bb66c,
		"MoveBG::durian_physical_data": 0x803bb6a8,
		"durian_physical_data": 0x803bb6a8,
		"MoveBG::durian_physical_info": 0x803bb6dc,
		"durian_physical_info": 0x803bb6dc,
		"MoveBG::durian_data": 0x803bb6e8,
		"durian_data": 0x803bb6e8,
		"MoveBG::banana_physical_data": 0x803bb724,
		"banana_physical_data": 0x803bb724,
		"MoveBG::banana_physical_info": 0x803bb758,
		"banana_physical_info": 0x803bb758,
		"MoveBG::banana_data": 0x803bb764,
		"banana_data": 0x803bb764,
		"MoveBG::red_pepper_physical_data": 0x803bb7a0,
		"red_pepper_physical_data": 0x803bb7a0,
		"MoveBG::red_pepper_physical_info": 0x803bb7d4,
		"red_pepper_physical_info": 0x803bb7d4,
		"MoveBG::RedPepper_data": 0x803bb7e0,
		"RedPepper_data": 0x803bb7e0,
		"MoveBG::fence_normal_data": 0x803bb81c,
		"fence_normal_data": 0x803bb81c,
		"MoveBG::fence3x3_data": 0x803bb858,
		"fence3x3_data": 0x803bb858,
		"MoveBG::fence_revolve_data": 0x803bb894,
		"fence_revolve_data": 0x803bb894,
		"MoveBG::fence_revolve_inner_data": 0x803bb8d0,
		"fence_revolve_inner_data": 0x803bb8d0,
		"MoveBG::fenceInnerGreen_data": 0x803bb90c,
		"fenceInnerGreen_data": 0x803bb90c,
		"MoveBG::FenceWaterV_data": 0x803bb948,
		"FenceWaterV_data": 0x803bb948,
		"MoveBG::FenceWaterH_data": 0x803bb984,
		"FenceWaterH_data": 0x803bb984,
		"MoveBG::RailFence_data": 0x803bb9c0,
		"RailFence_data": 0x803bb9c0,
		"MoveBG::bambooFenceRevolveInner_data": 0x803bb9fc,
		"bambooFenceRevolveInner_data": 0x803bb9fc,
		"MoveBG::bambooFenceRevolveOuter_data": 0x803bba38,
		"bambooFenceRevolveOuter_data": 0x803bba38,
		"MoveBG::bambooRailFence_data": 0x803bba74,
		"bambooRailFence_data": 0x803bba74,
		"MoveBG::wood_barrel_physical_data": 0x803bbab0,
		"wood_barrel_physical_data": 0x803bbab0,
		"MoveBG::wood_barrel_physical_info": 0x803bbae4,
		"wood_barrel_physical_info": 0x803bbae4,
		"MoveBG::wood_barrel_hold_data": 0x803bbaf0,
		"wood_barrel_hold_data": 0x803bbaf0,
		"MoveBG::wood_barrel_data": 0x803bbb04,
		"wood_barrel_data": 0x803bbb04,
		"MoveBG::wood_barrel_once_data": 0x803bbb40,
		"wood_barrel_once_data": 0x803bbb40,
		"MoveBG::barrel_float_data": 0x803bbb7c,
		"barrel_float_data": 0x803bbb7c,
		"MoveBG::drum_can_data": 0x803bbbb8,
		"drum_can_data": 0x803bbbb8,
		"MoveBG::barrel_oil_data": 0x803bbbf4,
		"barrel_oil_data": 0x803bbbf4,
		"MoveBG::breakable_block_data": 0x803bbc30,
		"breakable_block_data": 0x803bbc30,
		"MoveBG::supermario_block_data": 0x803bbc6c,
		"supermario_block_data": 0x803bbc6c,
		"MoveBG::move_block_data": 0x803bbca8,
		"move_block_data": 0x803bbca8,
		"MoveBG::fall_slow_block_data": 0x803bbce4,
		"fall_slow_block_data": 0x803bbce4,
		"MoveBG::expand_block_data": 0x803bbd20,
		"expand_block_data": 0x803bbd20,
		"MoveBG::spread_block_data": 0x803bbd5c,
		"spread_block_data": 0x803bbd5c,
		"MoveBG::water_roll_block_data": 0x803bbd98,
		"water_roll_block_data": 0x803bbd98,
		"MoveBG::sand_block_data": 0x803bbdd4,
		"sand_block_data": 0x803bbdd4,
		"MoveBG::water_power_lift_data": 0x803bbe10,
		"water_power_lift_data": 0x803bbe10,
		"MoveBG::water_power_inertial_lift_data": 0x803bbe4c,
		"water_power_inertial_lift_data": 0x803bbe4c,
		"MoveBG::water_power_ship_data": 0x803bbe88,
		"water_power_ship_data": 0x803bbe88,
		"MoveBG::lean_direct_block_data": 0x803bbec4,
		"lean_direct_block_data": 0x803bbec4,
		"MoveBG::lean_indirect_block_data": 0x803bbf00,
		"lean_indirect_block_data": 0x803bbf00,
		"MoveBG::lean_block_data": 0x803bbf3c,
		"lean_block_data": 0x803bbf3c,
		"MoveBG::skate_block_data": 0x803bbf78,
		"skate_block_data": 0x803bbf78,
		"MoveBG::MoveCoin_data": 0x803bbfb4,
		"MoveCoin_data": 0x803bbfb4,
		"MoveBG::cluster_block_data": 0x803bbff0,
		"cluster_block_data": 0x803bbff0,
		"MoveBG::NormalBlock_data": 0x803bc02c,
		"NormalBlock_data": 0x803bc02c,
		"MoveBG::IceBlock_data": 0x803bc068,
		"IceBlock_data": 0x803bc068,
		"MoveBG::BrickBlock_data": 0x803bc0a4,
		"BrickBlock_data": 0x803bc0a4,
		"MoveBG::WaterMelonBlock_data": 0x803bc0e0,
		"WaterMelonBlock_data": 0x803bc0e0,
		"MoveBG::TelesaBlock_data": 0x803bc11c,
		"TelesaBlock_data": 0x803bc11c,
		"MoveBG::WoodBlockPole_data": 0x803bc158,
		"WoodBlockPole_data": 0x803bc158,
		"MoveBG::JuiceBlock_data": 0x803bc194,
		"JuiceBlock_data": 0x803bc194,
		"MoveBG::SuperHipDropBlock_data": 0x803bc1d0,
		"SuperHipDropBlock_data": 0x803bc1d0,
		"MoveBG::palmNormal_data": 0x803bc20c,
		"palmNormal_data": 0x803bc20c,
		"MoveBG::palmOugi_data": 0x803bc248,
		"palmOugi_data": 0x803bc248,
		"MoveBG::palmSago_data": 0x803bc284,
		"palmSago_data": 0x803bc284,
		"MoveBG::palmNatume_data": 0x803bc2c0,
		"palmNatume_data": 0x803bc2c0,
		"MoveBG::palmLeaf_data": 0x803bc2fc,
		"palmLeaf_data": 0x803bc2fc,
		"MoveBG::BananaTree_data": 0x803bc338,
		"BananaTree_data": 0x803bc338,
		"MoveBG::FruitTree_data": 0x803bc374,
		"FruitTree_data": 0x803bc374,
		"MoveBG::flower_data": 0x803bc3b0,
		"flower_data": 0x803bc3b0,
		"MoveBG::flowerOrange_data": 0x803bc3ec,
		"flowerOrange_data": 0x803bc3ec,
		"MoveBG::flowerPink_data": 0x803bc428,
		"flowerPink_data": 0x803bc428,
		"MoveBG::flowerPurple_data": 0x803bc464,
		"flowerPurple_data": 0x803bc464,
		"MoveBG::flowerRed_data": 0x803bc4a0,
		"flowerRed_data": 0x803bc4a0,
		"MoveBG::flowerYellow_data": 0x803bc4dc,
		"flowerYellow_data": 0x803bc4dc,
		"MoveBG::flowerSunflower_data": 0x803bc518,
		"flowerSunflower_data": 0x803bc518,
		"MoveBG::telegraph_pole_l_data": 0x803bc554,
		"telegraph_pole_l_data": 0x803bc554,
		"MoveBG::telegraph_pole_s_data": 0x803bc590,
		"telegraph_pole_s_data": 0x803bc590,
		"MoveBG::streetlamp_data": 0x803bc5cc,
		"streetlamp_data": 0x803bc5cc,
		"MoveBG::PoleNormal_data": 0x803bc608,
		"PoleNormal_data": 0x803bc608,
		"MoveBG::football_physical_data": 0x803bc644,
		"football_physical_data": 0x803bc644,
		"MoveBG::football_physical_info": 0x803bc678,
		"football_physical_info": 0x803bc678,
		"MoveBG::football_data": 0x803bc684,
		"football_data": 0x803bc684,
		"MoveBG::football_goal_data": 0x803bc6c0,
		"football_goal_data": 0x803bc6c0,
		"MoveBG::baloonball_physical_data": 0x803bc6fc,
		"baloonball_physical_data": 0x803bc6fc,
		"MoveBG::baloonball_physical_info": 0x803bc730,
		"baloonball_physical_info": 0x803bc730,
		"MoveBG::baloonball_data": 0x803bc73c,
		"baloonball_data": 0x803bc73c,
		"MoveBG::coconutball_data": 0x803bc778,
		"coconutball_data": 0x803bc778,
		"MoveBG::watermelon_physical_data": 0x803bc7b4,
		"watermelon_physical_data": 0x803bc7b4,
		"MoveBG::watermelon_physical_info": 0x803bc7e8,
		"watermelon_physical_info": 0x803bc7e8,
		"MoveBG::watermelon_data": 0x803bc7f4,
		"watermelon_data": 0x803bc7f4,
		"MoveBG::WatermelonStatic_data": 0x803bc830,
		"WatermelonStatic_data": 0x803bc830,
		"MoveBG::cloud_data": 0x803bc86c,
		"cloud_data": 0x803bc86c,
		"MoveBG::normallift_data": 0x803bc8a8,
		"normallift_data": 0x803bc8a8,
		"MoveBG::exrollcube_data": 0x803bc8e4,
		"exrollcube_data": 0x803bc8e4,
		"MoveBG::exkickboard_data": 0x803bc920,
		"exkickboard_data": 0x803bc920,
		"MoveBG::railblockr_data": 0x803bc95c,
		"railblockr_data": 0x803bc95c,
		"MoveBG::railblocky_data": 0x803bc998,
		"railblocky_data": 0x803bc998,
		"MoveBG::railblockb_data": 0x803bc9d4,
		"railblockb_data": 0x803bc9d4,
		"MoveBG::rollblockr_data": 0x803bca10,
		"rollblockr_data": 0x803bca10,
		"MoveBG::rollblocky_data": 0x803bca4c,
		"rollblocky_data": 0x803bca4c,
		"MoveBG::rollblockb_data": 0x803bca88,
		"rollblockb_data": 0x803bca88,
		"MoveBG::umaibou_data": 0x803bcac4,
		"umaibou_data": 0x803bcac4,
		"MoveBG::kamaboko_data": 0x803bcb00,
		"kamaboko_data": 0x803bcb00,
		"MoveBG::getag_data": 0x803bcb3c,
		"getag_data": 0x803bcb3c,
		"MoveBG::getao_data": 0x803bcb78,
		"getao_data": 0x803bcb78,
		"MoveBG::uirou_data": 0x803bcbb4,
		"uirou_data": 0x803bcbb4,
		"MoveBG::hikidashi_data": 0x803bcbf0,
		"hikidashi_data": 0x803bcbf0,
		"MoveBG::castella_data": 0x803bcc2c,
		"castella_data": 0x803bcc2c,
		"MoveBG::yoshiblock_data": 0x803bcc68,
		"yoshiblock_data": 0x803bcc68,
		"MoveBG::WoodBlockTriangle_data": 0x803bcca4,
		"WoodBlockTriangle_data": 0x803bcca4,
		"MoveBG::WoodBlockPyramid_data": 0x803bcce0,
		"WoodBlockPyramid_data": 0x803bcce0,
		"MoveBG::WoodBlockLong_data": 0x803bcd1c,
		"WoodBlockLong_data": 0x803bcd1c,
		"MoveBG::WoodBlockLarge_data": 0x803bcd58,
		"WoodBlockLarge_data": 0x803bcd58,
		"MoveBG::WoodBlockCone_data": 0x803bcd94,
		"WoodBlockCone_data": 0x803bcd94,
		"MoveBG::WoodBlockL_data": 0x803bcdd0,
		"WoodBlockL_data": 0x803bcdd0,
		"MoveBG::WoodBlockBridge_data": 0x803bce0c,
		"WoodBlockBridge_data": 0x803bce0c,
		"MoveBG::WoodBlockCube_data": 0x803bce48,
		"WoodBlockCube_data": 0x803bce48,
		"MoveBG::normalvariant0_data": 0x803bce84,
		"normalvariant0_data": 0x803bce84,
		"MoveBG::normalvariant1_data": 0x803bcec0,
		"normalvariant1_data": 0x803bcec0,
		"MoveBG::normalvariant2_data": 0x803bcefc,
		"normalvariant2_data": 0x803bcefc,
		"MoveBG::normalvariant3_data": 0x803bcf38,
		"normalvariant3_data": 0x803bcf38,
		"MoveBG::normalvariant4_data": 0x803bcf74,
		"normalvariant4_data": 0x803bcf74,
		"MoveBG::railvariant0_data": 0x803bcfb0,
		"railvariant0_data": 0x803bcfb0,
		"MoveBG::railvariant1_data": 0x803bcfec,
		"railvariant1_data": 0x803bcfec,
		"MoveBG::railvariant2_data": 0x803bd028,
		"railvariant2_data": 0x803bd028,
		"MoveBG::railvariant3_data": 0x803bd064,
		"railvariant3_data": 0x803bd064,
		"MoveBG::railvariant4_data": 0x803bd0a0,
		"railvariant4_data": 0x803bd0a0,
		"MoveBG::rollvariant0_data": 0x803bd0dc,
		"rollvariant0_data": 0x803bd0dc,
		"MoveBG::rollvariant1_data": 0x803bd118,
		"rollvariant1_data": 0x803bd118,
		"MoveBG::rollvariant2_data": 0x803bd154,
		"rollvariant2_data": 0x803bd154,
		"MoveBG::rollvariant3_data": 0x803bd190,
		"rollvariant3_data": 0x803bd190,
		"MoveBG::rollvariant4_data": 0x803bd1cc,
		"rollvariant4_data": 0x803bd1cc,
		"MoveBG::lamptrapspike_data": 0x803bd208,
		"lamptrapspike_data": 0x803bd208,
		"MoveBG::lamptrapiron_data": 0x803bd244,
		"lamptrapiron_data": 0x803bd244,
		"MoveBG::airplane_data": 0x803bd280,
		"airplane_data": 0x803bd280,
		"MoveBG::WoodBox_data": 0x803bd2bc,
		"WoodBox_data": 0x803bd2bc,
		"MoveBG::AirportPole_data": 0x803bd2f8,
		"AirportPole_data": 0x803bd2f8,
		"MoveBG::ice_car_data": 0x803bd334,
		"ice_car_data": 0x803bd334,
		"MoveBG::move_ice_car_data": 0x803bd370,
		"move_ice_car_data": 0x803bd370,
		"MoveBG::AirportBuoy_data": 0x803bd3ac,
		"AirportBuoy_data": 0x803bd3ac,
		"MoveBG::dptCannon_data": 0x803bd3e8,
		"dptCannon_data": 0x803bd3e8,
		"MoveBG::dptKing_data": 0x803bd424,
		"dptKing_data": 0x803bd424,
		"MoveBG::KoopaJrSubmarine_data": 0x803bd460,
		"KoopaJrSubmarine_data": 0x803bd460,
		"MoveBG::monumentshine_data": 0x803bd49c,
		"monumentshine_data": 0x803bd49c,
		"MoveBG::belldolpic_data": 0x803bd4d8,
		"belldolpic_data": 0x803bd4d8,
		"MoveBG::dptWeathercock_data": 0x803bd514,
		"dptWeathercock_data": 0x803bd514,
		"MoveBG::dptMonteFence_data": 0x803bd550,
		"dptMonteFence_data": 0x803bd550,
		"MoveBG::dptCoronaFence_data": 0x803bd58c,
		"dptCoronaFence_data": 0x803bd58c,
		"MoveBG::MapSmoke_data": 0x803bd5c8,
		"MapSmoke_data": 0x803bd5c8,
		"MoveBG::MareGate_data": 0x803bd604,
		"MareGate_data": 0x803bd604,
		"MoveBG::DemoCannon_data": 0x803bd640,
		"DemoCannon_data": 0x803bd640,
		"MoveBG::NozzleDoor_data": 0x803bd67c,
		"NozzleDoor_data": 0x803bd67c,
		"MoveBG::DokanGate_data": 0x803bd6b8,
		"DokanGate_data": 0x803bd6b8,
		"MoveBG::crane_data": 0x803bd6f4,
		"crane_data": 0x803bd6f4,
		"MoveBG::crane90Scene2_data": 0x803bd730,
		"crane90Scene2_data": 0x803bd730,
		"MoveBG::crane180Scene1_data": 0x803bd76c,
		"crane180Scene1_data": 0x803bd76c,
		"MoveBG::craneUpDown_data": 0x803bd7a8,
		"craneUpDown_data": 0x803bd7a8,
		"MoveBG::craneCargoUpDown_data": 0x803bd7e4,
		"craneCargoUpDown_data": 0x803bd7e4,
		"MoveBG::tank_data": 0x803bd820,
		"tank_data": 0x803bd820,
		"MoveBG::container_data": 0x803bd85c,
		"container_data": 0x803bd85c,
		"MoveBG::submarine_data": 0x803bd898,
		"submarine_data": 0x803bd898,
		"MoveBG::riccoShip_data": 0x803bd8d4,
		"riccoShip_data": 0x803bd8d4,
		"MoveBG::riccoPole_data": 0x803bd910,
		"riccoPole_data": 0x803bd910,
		"MoveBG::riccoLog_data": 0x803bd94c,
		"riccoLog_data": 0x803bd94c,
		"MoveBG::gesoSurfboard_data": 0x803bd988,
		"gesoSurfboard_data": 0x803bd988,
		"MoveBG::gesoSurfboardStatic_data": 0x803bd9c4,
		"gesoSurfboardStatic_data": 0x803bd9c4,
		"MoveBG::riccoWatermill_data": 0x803bda00,
		"riccoWatermill_data": 0x803bda00,
		"MoveBG::riccoShipLog_data": 0x803bda3c,
		"riccoShipLog_data": 0x803bda3c,
		"MoveBG::riccoShipDol_data": 0x803bda78,
		"riccoShipDol_data": 0x803bda78,
		"MoveBG::riccoYachtL_data": 0x803bdab4,
		"riccoYachtL_data": 0x803bdab4,
		"MoveBG::riccoYachtS_data": 0x803bdaf0,
		"riccoYachtS_data": 0x803bdaf0,
		"MoveBG::riccoBoatL_data": 0x803bdb2c,
		"riccoBoatL_data": 0x803bdb2c,
		"MoveBG::riccoBoatS_data": 0x803bdb68,
		"riccoBoatS_data": 0x803bdb68,
		"MoveBG::riccoBasket_data": 0x803bdba4,
		"riccoBasket_data": 0x803bdba4,
		"MoveBG::riccoGangway_data": 0x803bdbe0,
		"riccoGangway_data": 0x803bdbe0,
		"MoveBG::riccoShipFish_data": 0x803bdc1c,
		"riccoShipFish_data": 0x803bdc1c,
		"MoveBG::riccoShipGeso_data": 0x803bdc58,
		"riccoShipGeso_data": 0x803bdc58,
		"MoveBG::riccoSwitch_data": 0x803bdc94,
		"riccoSwitch_data": 0x803bdc94,
		"MoveBG::riccoSwitchShine_data": 0x803bdcd0,
		"riccoSwitchShine_data": 0x803bdcd0,
		"MoveBG::riccoFenceMaze_data": 0x803bdd0c,
		"riccoFenceMaze_data": 0x803bdd0c,
		"MoveBG::riccoStand_data": 0x803bdd48,
		"riccoStand_data": 0x803bdd48,
		"MoveBG::riccoGrille_data": 0x803bdd84,
		"riccoGrille_data": 0x803bdd84,
		"MoveBG::riccoArrow_data": 0x803bddc0,
		"riccoArrow_data": 0x803bddc0,
		"MoveBG::riccoStreetStall_data": 0x803bddfc,
		"riccoStreetStall_data": 0x803bddfc,
		"MoveBG::riccoHericopter_data": 0x803bde38,
		"riccoHericopter_data": 0x803bde38,
		"MoveBG::surfgeso_red_data": 0x803bde74,
		"surfgeso_red_data": 0x803bde74,
		"MoveBG::surfgeso_yellow_data": 0x803bdeb0,
		"surfgeso_yellow_data": 0x803bdeb0,
		"MoveBG::surfgeso_green_data": 0x803bdeec,
		"surfgeso_green_data": 0x803bdeec,
		"MoveBG::big_windmill_data": 0x803bdf28,
		"big_windmill_data": 0x803bdf28,
		"MoveBG::windmill_far_data": 0x803bdf64,
		"windmill_far_data": 0x803bdf64,
		"MoveBG::MiniWindmillL_data": 0x803bdfa0,
		"MiniWindmillL_data": 0x803bdfa0,
		"MoveBG::MiniWindmillS_data": 0x803bdfdc,
		"MiniWindmillS_data": 0x803bdfdc,
		"MoveBG::WindmillRoof_data": 0x803be018,
		"WindmillRoof_data": 0x803be018,
		"MoveBG::lamp_bianco_data": 0x803be054,
		"lamp_bianco_data": 0x803be054,
		"MoveBG::root_pakkun_data": 0x803be090,
		"root_pakkun_data": 0x803be090,
		"MoveBG::windmill_block_data": 0x803be0cc,
		"windmill_block_data": 0x803be0cc,
		"MoveBG::PolluterPakkun_data": 0x803be108,
		"PolluterPakkun_data": 0x803be108,
		"MoveBG::BiaBell_data": 0x803be144,
		"BiaBell_data": 0x803be144,
		"MoveBG::BiaWatermill00_data": 0x803be180,
		"BiaWatermill00_data": 0x803be180,
		"MoveBG::BiaWatermill01_data": 0x803be1bc,
		"BiaWatermill01_data": 0x803be1bc,
		"MoveBG::BiaWatermillVertical_data": 0x803be1f8,
		"BiaWatermillVertical_data": 0x803be1f8,
		"MoveBG::BiaTurnBridge_data": 0x803be234,
		"BiaTurnBridge_data": 0x803be234,
		"MoveBG::LeafBoat_data": 0x803be270,
		"LeafBoat_data": 0x803be270,
		"MoveBG::LeafBoatRotten_data": 0x803be2ac,
		"LeafBoatRotten_data": 0x803be2ac,
		"MoveBG::LampSeesaw_data": 0x803be2e8,
		"LampSeesaw_data": 0x803be2e8,
		"MoveBG::BiancoDoor_data": 0x803be324,
		"BiancoDoor_data": 0x803be324,
		"MoveBG::BiaBridge_data": 0x803be360,
		"BiaBridge_data": 0x803be360,
		"MoveBG::SandBird_data": 0x803be39c,
		"SandBird_data": 0x803be39c,
		"MoveBG::SandBirdBlock_data": 0x803be3d8,
		"SandBirdBlock_data": 0x803be3d8,
		"MoveBG::SkyIsland_data": 0x803be414,
		"SkyIsland_data": 0x803be414,
		"MoveBG::SandLeaf_data": 0x803be450,
		"SandLeaf_data": 0x803be450,
		"MoveBG::SandLeafBase00_data": 0x803be48c,
		"SandLeafBase00_data": 0x803be48c,
		"MoveBG::SandLeafBase01_data": 0x803be4c8,
		"SandLeafBase01_data": 0x803be4c8,
		"MoveBG::SandLeafBase02_data": 0x803be504,
		"SandLeafBase02_data": 0x803be504,
		"MoveBG::SandLeafBase03_data": 0x803be540,
		"SandLeafBase03_data": 0x803be540,
		"MoveBG::SandBomb_data": 0x803be57c,
		"SandBomb_data": 0x803be57c,
		"MoveBG::MirrorL_data": 0x803be5b8,
		"MirrorL_data": 0x803be5b8,
		"MoveBG::MirrorM_data": 0x803be5f4,
		"MirrorM_data": 0x803be5f4,
		"MoveBG::MirrorS_data": 0x803be630,
		"MirrorS_data": 0x803be630,
		"MoveBG::SandCastle_data": 0x803be66c,
		"SandCastle_data": 0x803be66c,
		"MoveBG::MammaBlockRotate_data": 0x803be6a8,
		"MammaBlockRotate_data": 0x803be6a8,
		"MoveBG::SandEgg_data": 0x803be6e4,
		"SandEgg_data": 0x803be6e4,
		"MoveBG::SandEggBroken_data": 0x803be720,
		"SandEggBroken_data": 0x803be720,
		"MoveBG::ShiningStone_data": 0x803be75c,
		"ShiningStone_data": 0x803be75c,
		"MoveBG::MammaSurfboard00_data": 0x803be798,
		"MammaSurfboard00_data": 0x803be798,
		"MoveBG::MammaSurfboard01_data": 0x803be7d4,
		"MammaSurfboard01_data": 0x803be7d4,
		"MoveBG::MammaSurfboard02_data": 0x803be810,
		"MammaSurfboard02_data": 0x803be810,
		"MoveBG::MammaSurfboard03_data": 0x803be84c,
		"MammaSurfboard03_data": 0x803be84c,
		"MoveBG::MammaSurfboardStand_data": 0x803be888,
		"MammaSurfboardStand_data": 0x803be888,
		"MoveBG::MammaYacht00_data": 0x803be8c4,
		"MammaYacht00_data": 0x803be8c4,
		"MoveBG::MammaYacht01_data": 0x803be900,
		"MammaYacht01_data": 0x803be900,
		"MoveBG::MammaYacht02_data": 0x803be93c,
		"MammaYacht02_data": 0x803be93c,
		"MoveBG::SandBombBase00_data": 0x803be978,
		"SandBombBase00_data": 0x803be978,
		"MoveBG::SandBombBaseMushroom_data": 0x803be9b4,
		"SandBombBaseMushroom_data": 0x803be9b4,
		"MoveBG::SandBombBasePyramid_data": 0x803be9f0,
		"SandBombBasePyramid_data": 0x803be9f0,
		"MoveBG::SandBombBaseShit_data": 0x803bea2c,
		"SandBombBaseShit_data": 0x803bea2c,
		"MoveBG::SandBombBaseStar_data": 0x803bea68,
		"SandBombBaseStar_data": 0x803bea68,
		"MoveBG::SandBombBaseTurtle_data": 0x803beaa4,
		"SandBombBaseTurtle_data": 0x803beaa4,
		"MoveBG::SandBombBaseFoot_data": 0x803beae0,
		"SandBombBaseFoot_data": 0x803beae0,
		"MoveBG::SandBombBaseHand_data": 0x803beb1c,
		"SandBombBaseHand_data": 0x803beb1c,
		"MoveBG::SandBombBaseStairs_data": 0x803beb58,
		"SandBombBaseStairs_data": 0x803beb58,
		"MoveBG::coral00_data": 0x803beb94,
		"coral00_data": 0x803beb94,
		"MoveBG::coral01_data": 0x803bebd0,
		"coral01_data": 0x803bebd0,
		"MoveBG::GoalWatermelon_data": 0x803bec0c,
		"GoalWatermelon_data": 0x803bec0c,
		"MoveBG::TeethOfJuicer_data": 0x803bec48,
		"TeethOfJuicer_data": 0x803bec48,
		"MoveBG::SandEggRepair_data": 0x803bec84,
		"SandEggRepair_data": 0x803bec84,
		"MoveBG::merrygoround_data": 0x803becc0,
		"merrygoround_data": 0x803becc0,
		"MoveBG::merry_egg_data": 0x803becfc,
		"merry_egg_data": 0x803becfc,
		"MoveBG::merry_pole_data": 0x803bed38,
		"merry_pole_data": 0x803bed38,
		"MoveBG::FerrisWheel_data": 0x803bed74,
		"FerrisWheel_data": 0x803bed74,
		"MoveBG::gondola_data": 0x803bedb0,
		"gondola_data": 0x803bedb0,
		"MoveBG::FerrisLOD_data": 0x803bedec,
		"FerrisLOD_data": 0x803bedec,
		"MoveBG::viking_data": 0x803bee28,
		"viking_data": 0x803bee28,
		"MoveBG::PinnaEntrance_data": 0x803bee64,
		"PinnaEntrance_data": 0x803bee64,
		"MoveBG::PinnaEntranceOpen_data": 0x803beea0,
		"PinnaEntranceOpen_data": 0x803beea0,
		"MoveBG::SirenaGate_data": 0x803beedc,
		"SirenaGate_data": 0x803beedc,
		"MoveBG::BalloonKoopaJr_data": 0x803bef18,
		"BalloonKoopaJr_data": 0x803bef18,
		"MoveBG::ShellCup_data": 0x803bef54,
		"ShellCup_data": 0x803bef54,
		"MoveBG::Gateshell_data": 0x803bef90,
		"Gateshell_data": 0x803bef90,
		"MoveBG::PinnaHangingBridgeBoard_data": 0x803befcc,
		"PinnaHangingBridgeBoard_data": 0x803befcc,
		"MoveBG::GateManta_data": 0x803bf008,
		"GateManta_data": 0x803bf008,
		"MoveBG::PinnaSunFlower_data": 0x803bf044,
		"PinnaSunFlower_data": 0x803bf044,
		"MoveBG::AmiKing_data": 0x803bf080,
		"AmiKing_data": 0x803bf080,
		"MoveBG::PinnaCoaster_data": 0x803bf0bc,
		"PinnaCoaster_data": 0x803bf0bc,
		"MoveBG::casinoroulette_data": 0x803bf0f8,
		"casinoroulette_data": 0x803bf0f8,
		"MoveBG::roulette00_data": 0x803bf134,
		"roulette00_data": 0x803bf134,
		"MoveBG::roulette01_data": 0x803bf170,
		"roulette01_data": 0x803bf170,
		"MoveBG::roulette02_data": 0x803bf1ac,
		"roulette02_data": 0x803bf1ac,
		"MoveBG::slotdrum_data": 0x803bf1e8,
		"slotdrum_data": 0x803bf1e8,
		"MoveBG::telesaslot_data": 0x803bf224,
		"telesaslot_data": 0x803bf224,
		"MoveBG::donchou_data": 0x803bf260,
		"donchou_data": 0x803bf260,
		"MoveBG::casino_panel_gate_data": 0x803bf29c,
		"casino_panel_gate_data": 0x803bf29c,
		"MoveBG::SakuCasino_data": 0x803bf2d8,
		"SakuCasino_data": 0x803bf2d8,
		"MoveBG::SirenabossWall_data": 0x803bf314,
		"SirenabossWall_data": 0x803bf314,
		"MoveBG::SirenaCasinoRoof_data": 0x803bf350,
		"SirenaCasinoRoof_data": 0x803bf350,
		"MoveBG::GlassBreak_data": 0x803bf38c,
		"GlassBreak_data": 0x803bf38c,
		"MoveBG::Closet_data": 0x803bf3c8,
		"Closet_data": 0x803bf3c8,
		"MoveBG::ChestRevolve_data": 0x803bf404,
		"ChestRevolve_data": 0x803bf404,
		"MoveBG::PosterTeresa_data": 0x803bf440,
		"PosterTeresa_data": 0x803bf440,
		"MoveBG::PictureTeresa_data": 0x803bf47c,
		"PictureTeresa_data": 0x803bf47c,
		"MoveBG::PanelBreak_data": 0x803bf4b8,
		"PanelBreak_data": 0x803bf4b8,
		"MoveBG::PanelRevolve_data": 0x803bf4f4,
		"PanelRevolve_data": 0x803bf4f4,
		"MoveBG::SirenaBlockBreak_data": 0x803bf530,
		"SirenaBlockBreak_data": 0x803bf530,
		"MoveBG::SirenaShop_data": 0x803bf56c,
		"SirenaShop_data": 0x803bf56c,
		"MoveBG::StainHotel_data": 0x803bf5a8,
		"StainHotel_data": 0x803bf5a8,
		"MoveBG::cogwheel_data": 0x803bf5e4,
		"cogwheel_data": 0x803bf5e4,
		"MoveBG::CogwheelPlate_data": 0x803bf620,
		"CogwheelPlate_data": 0x803bf620,
		"MoveBG::CogwheelPot_data": 0x803bf65c,
		"CogwheelPot_data": 0x803bf65c,
		"MoveBG::mare_float_house_data": 0x803bf698,
		"mare_float_house_data": 0x803bf698,
		"MoveBG::StopRock_physical_data": 0x803bf6d4,
		"StopRock_physical_data": 0x803bf6d4,
		"MoveBG::StopRock_physical_info": 0x803bf708,
		"StopRock_physical_info": 0x803bf708,
		"MoveBG::StopRock_data": 0x803bf714,
		"StopRock_data": 0x803bf714,
		"MoveBG::ElasticCode_data": 0x803bf750,
		"ElasticCode_data": 0x803bf750,
		"MoveBG::GrowthTree_data": 0x803bf78c,
		"GrowthTree_data": 0x803bf78c,
		"MoveBG::WireBellPurple_data": 0x803bf7c8,
		"WireBellPurple_data": 0x803bf7c8,
		"MoveBG::MuddyBoat_data": 0x803bf804,
		"MuddyBoat_data": 0x803bf804,
		"MoveBG::Puncher_data": 0x803bf840,
		"Puncher_data": 0x803bf840,
		"MoveBG::HatoPop_data": 0x803bf87c,
		"HatoPop_data": 0x803bf87c,
		"MoveBG::MareWaterJump_data": 0x803bf8b8,
		"MareWaterJump_data": 0x803bf8b8,
		"MoveBG::BumpyWall_data": 0x803bf8f4,
		"BumpyWall_data": 0x803bf8f4,
		"MoveBG::ExBottle_data": 0x803bf930,
		"ExBottle_data": 0x803bf930,
		"MoveBG::CoinFish_data": 0x803bf96c,
		"CoinFish_data": 0x803bf96c,
		"MoveBG::MareFall_data": 0x803bf9a8,
		"MareFall_data": 0x803bf9a8,
		"MoveBG::MareCork_data": 0x803bf9e4,
		"MareCork_data": 0x803bf9e4,
		"MoveBG::MonteRoot_data": 0x803bfa20,
		"MonteRoot_data": 0x803bfa20,
		"MoveBG::JumpMushroom_data": 0x803bfa5c,
		"JumpMushroom_data": 0x803bfa5c,
		"MoveBG::MonteGoalFlag_data": 0x803bfa98,
		"MonteGoalFlag_data": 0x803bfa98,
		"MoveBG::HangingBridgeBoard_data": 0x803bfad4,
		"HangingBridgeBoard_data": 0x803bfad4,
		"MoveBG::HangingBridge_data": 0x803bfb10,
		"HangingBridge_data": 0x803bfb10,
		"MoveBG::SwingBoard_data": 0x803bfb4c,
		"SwingBoard_data": 0x803bfb4c,
		"MoveBG::Fluff_data": 0x803bfb88,
		"Fluff_data": 0x803bfb88,
		"MoveBG::FluffManager_data": 0x803bfbc4,
		"FluffManager_data": 0x803bfbc4,
		"MoveBG::Bathtub_data": 0x803bfc00,
		"Bathtub_data": 0x803bfc00,
		"MoveBG::BathtubStand_data": 0x803bfc3c,
		"BathtubStand_data": 0x803bfc3c,
		"MoveBG::BathtubStandBreaking_animation": 0x803bfc78,
		"BathtubStandBreaking_animation": 0x803bfc78,
		"MoveBG::BathtubStandBreaking_data": 0x803bfc84,
		"BathtubStandBreaking_data": 0x803bfc84,
		"MoveBG::ex1_turn_lift_move_data": 0x803bfcc0,
		"ex1_turn_lift_move_data": 0x803bfcc0,
		"MoveBG::ex1_turn_lift_data": 0x803bfccc,
		"ex1_turn_lift_data": 0x803bfccc,
		"MoveBG::z_turn_disk_move_data": 0x803bfd08,
		"z_turn_disk_move_data": 0x803bfd08,
		"MoveBG::z_turn_disk_data": 0x803bfd14,
		"z_turn_disk_data": 0x803bfd14,
		"MoveBG::y_turn_lift_move_data": 0x803bfd50,
		"y_turn_lift_move_data": 0x803bfd50,
		"MoveBG::y_turn_lift_data": 0x803bfd5c,
		"y_turn_lift_data": 0x803bfd5c,
		"MoveBG::EXskyTumiki_data": 0x803bfd98,
		"EXskyTumiki_data": 0x803bfd98,
		"MoveBG::EXskyWindow_data": 0x803bfdd4,
		"EXskyWindow_data": 0x803bfdd4,
		"MoveBG::EXskySenro_data": 0x803bfe10,
		"EXskySenro_data": 0x803bfe10,
		"MoveBG::Nail_data": 0x803bfe4c,
		"Nail_data": 0x803bfe4c,
		"MoveBG::PachinkoNail_data": 0x803bfe88,
		"PachinkoNail_data": 0x803bfe88,
		"MoveBG::FileLoadBlockA_data": 0x803bfec4,
		"FileLoadBlockA_data": 0x803bfec4,
		"MoveBG::FileLoadBlockB_data": 0x803bff00,
		"FileLoadBlockB_data": 0x803bff00,
		"MoveBG::FileLoadBlockC_data": 0x803bff3c,
		"FileLoadBlockC_data": 0x803bff3c,
		"MoveBG::sObjDataTable": 0x803bff78,
		"sObjDataTable": 0x803bff78,
		"TMapObjGeneral::__vt": 0x803c0518,
		"MoveBG::item_names$3004": 0x803c0728,
		"item_names$3004": 0x803c0728,
		"TMapObjBaseManager::__vt": 0x803c0740,
		"TMerryPole::__vt": 0x803c0780,
		"TMapObjManager::__vt": 0x803c08e4,
		"TMapObjTurn::__vt": 0x803c0928,
		"TMapObjMessenger::__vt": 0x803c0a9c,
		"TShine::mPromiLife": 0x803c0b78,
		"mPromiLife": 0x803c0b78,
		"TShine::mSenkoRate": 0x803c0b88,
		"mSenkoRate": 0x803c0b88,
		"TShine::mKiraRate": 0x803c0b98,
		"mKiraRate": 0x803c0b98,
		"TShine::mBowRate": 0x803c0ba8,
		"mBowRate": 0x803c0ba8,
		"TNozzleBox::__vt": 0x803c0bb8,
		"TItemNozzle::__vt": 0x803c0e24,
		"TEggYoshi::__vt": 0x803c1008,
		"TShine::__vt": 0x803c11e4,
		"TCoinBlue::__vt": 0x803c13c8,
		"TCoinRed::__vt": 0x803c15ac,
		"TCoinEmpty::__vt": 0x803c1790,
		"TFlowerCoin::__vt": 0x803c1974,
		"TCoin::__vt": 0x803c1b58,
		"TItem::__vt": 0x803c1d3c,
		"TItemManager::__vt": 0x803c1f20,
		"TBasketReverse::__vt": 0x803c1f60,
		"TRedCoinSwitch::__vt": 0x803c20c4,
		"TMapObjSwitch::__vt": 0x803c2228,
		"THideObjInfo::__vt": 0x803c238c,
		"TMapObjWaterSpray::__vt": 0x803c2430,
		"TDamageObj::__vt": 0x803c2594,
		"TMapObjStartDemo::__vt": 0x803c2638,
		"TMapObjChangeStageHipDrop::__vt": 0x803c279c,
		"TMapObjChangeStage::__vt": 0x803c2900,
		"TMapObjBillboard::__vt": 0x803c2a64,
		"TManhole::__vt": 0x803c2bd4,
		"TDoor::__vt": 0x803c2db0,
		"TSuperHipDropBlock::__vt": 0x803c2f18,
		"TTelesaBlock::__vt": 0x803c3088,
		"TJuiceBlock::__vt": 0x803c31ec,
		"TBrickBlock::__vt": 0x803c3350,
		"TIceBlock::__vt": 0x803c34c0,
		"TLeanBlock::__vt": 0x803c3624,
		"TSandBlock::__vt": 0x803c378c,
		"TBreakableBlock::__vt": 0x803c38f0,
		"TWoodLog::__vt": 0x803c3ad0,
		"TBellWatermill::__vt": 0x803c3c38,
		"TBiancoBell::__vt": 0x803c3dac,
		"TLampSeesawMain::__vt": 0x803c3f10,
		"TLampSeesaw::__vt": 0x803c4078,
		"TLeafBoatRotten::__vt": 0x803c41e0,
		"TLeafBoat::__vt": 0x803c4344,
		"TBiancoMiniWindmill::__vt": 0x803c44a8,
		"TBiancoWatermillVertical::__vt": 0x803c4618,
		"TBiancoWatermill::__vt": 0x803c477c,
		"TMapObjRootPakkun::__vt": 0x803c48e0,
		"TBigWindmill::__vt": 0x803c4a44,
		"TPictureTelesa::__vt": 0x803c4ba8,
		"TPanelRevolve::__vt": 0x803c4d24,
		"TChestRevolve::__vt": 0x803c4e88,
		"TWarpAreaActor::__vt": 0x803c4fec,
		"TSirenaCasinoRoof::__vt": 0x803c5090,
		"TSirenabossWall::__vt": 0x803c51f4,
		"TSakuCasino::__vt": 0x803c5358,
		"TCloset::__vt": 0x803c54bc,
		"TDonchou::__vt": 0x803c562c,
		"TCasinoPanelGate::__vt": 0x803c5790,
		"TItemSlotDrum::__vt": 0x803c5900,
		"TSlotDrum::__vt": 0x803c5a74,
		"TRoulette::__vt": 0x803c5be8,
		"TRouletteSw::__vt": 0x803c5d50,
		"TFruitLauncher::__vt": 0x803c5df8,
		"TFruitSwitch::__vt": 0x803c5f5c,
		"TSurfGesoObj::__vt": 0x803c60c0,
		"TRiccoWatermill::__vt": 0x803c62a4,
		"TCraneCargo::__vt": 0x803c6408,
		"TCraneUpDown::__vt": 0x803c6570,
		"TCraneRotY::__vt": 0x803c66d4,
		"TSandEgg::__vt": 0x803c6838,
		"MoveBG::@5077": 0x803c699c,
		"TMammaMirrorMapOperator::__vt": 0x803c69c0,
		"TGoalWatermelon::__vt": 0x803c69e4,
		"TSandBird::__vt": 0x803c6b48,
		"TMammaYacht::__vt": 0x803c6cb8,
		"TMammaBlockRotate::__vt": 0x803c6e1c,
		"TShiningStone::__vt": 0x803c6f80,
		"TLeanMirror::__vt": 0x803c7024,
		"TSandCastle::__vt": 0x803c7188,
		"TSandBombBase::__vt": 0x803c730c,
		"TSandBomb::__vt": 0x803c7490,
		"TSandLeafBase::__vt": 0x803c75f4,
		"TSandBase::__vt": 0x803c7760,
		"TSandLeaf::__vt": 0x803c78cc,
		"TPinnaCoaster::__vt": 0x803c7a30,
		"TAmiKing::__vt": 0x803c7b94,
		"TWaterRecoverObj::__vt": 0x803c7cf8,
		"TPinnaEntrance::__vt": 0x803c7e5c,
		"TBalloonKoopaJr::__vt": 0x803c7fc0,
		"TChangeStageMerrygoround::__vt": 0x803c819c,
		"TMerrygoround::__vt": 0x803c8300,
		"TShellCup::__vt": 0x803c8464,
		"TPinnaShell::__vt": 0x803c85c8,
		"TViking::__vt": 0x803c866c,
		"THorizontalViking::__vt": 0x803c87d4,
		"TFerrisWheel::__vt": 0x803c893c,
		"TGateShadow::__vt": 0x803c8aa0,
		"TMareEventPoint::__vt": 0x803c8ac8,
		"TMareCork::__vt": 0x803c8b6c,
		"TMareFall::__vt": 0x803c8cd0,
		"TMuddyBoat::__vt": 0x803c8e34,
		"TMapObjPuncher::__vt": 0x803c8f98,
		"TWireBell::__vt": 0x803c90fc,
		"TMapObjGrowTree::__vt": 0x803c9260,
		"TMapObjElasticCode::__vt": 0x803c93c4,
		"TCogwheel::__vt": 0x803c9528,
		"TCogwheelScale::__vt": 0x803c968c,
		"TMapObjFlagManager::__vt": 0x803c97f0,
		"TMapObjFlag::__vt": 0x803c9814,
		"TMapObjWave::__vt": 0x803c98c0,
		"TMapObjFloatOnSea::__vt": 0x803c98e8,
		"TSandPlane::__vt": 0x803c9a50,
		"TRockPlane::__vt": 0x803c9b4c,
		"TMapObjPlane::__vt": 0x803c9c48,
		"TRideCloud::__vt": 0x803c9d48,
		"TBigWatermelon::__vt": 0x803c9eb8,
		"MoveBG::@4190": 0x803ca0a8,
		"TCoverFruit::__vt": 0x803ca0e0,
		"TRandomFruit::__vt": 0x803ca244,
		"TResetFruit::__vt": 0x803ca434,
		"TMapObjBall::__vt": 0x803ca624,
		"TAirportEventSink::__vt": 0x803ca818,
		"TAirportSwitch::__vt": 0x803ca86c,
		"TTurboNozzleDoor::__vt": 0x803caa48,
		"TDemoCannon::__vt": 0x803cabac,
		"TMareGate::__vt": 0x803cad10,
		"TMapObjSmoke::__vt": 0x803cae74,
		"TDptMonteFence::__vt": 0x803cafe4,
		"TBellDolpic::__vt": 0x803cb148,
		"TMonumentShine::__vt": 0x803cb2ac,
		"TMapObjRevivalPollution::__vt": 0x803cb410,
		"TPolluterBase::__vt": 0x803cb434,
		"TMapObjGrassManager::__vt": 0x803cb598,
		"TMapObjGrassGroup::__vt": 0x803cb5bc,
		"TMapObjPoleManager::__vt": 0x803cb660,
		"TMapObjWaterFilter::__vt": 0x803cb688,
		"TMapObjSeaIndirect::__vt": 0x803cb728,
		"MoveBG::gateMActorNames": 0x803cb800,
		"gateMActorNames": 0x803cb800,
		"MoveBG::gateNames$2573": 0x803cb814,
		"gateNames$2573": 0x803cb814,
		"TModelGate::__vt": 0x803cb82c,
		"TRailFence::__vt": 0x803cb9b8,
		"TFenceWaterH::__vt": 0x803cbb1c,
		"TFenceWater::__vt": 0x803cbc88,
		"TRevolvingFenceInner::__vt": 0x803cbdf4,
		"TRevolvingFenceOuter::__vt": 0x803cbf58,
		"TFence::__vt": 0x803cc0bc,
		"TFileLoadBlock::__vt": 0x803cc220,
		"TMapObjOptionWall::__vt": 0x803cc384,
		"TWoodBlock::__vt": 0x803cc428,
		"TRollBlock::__vt": 0x803cc598,
		"TRailBlock::__vt": 0x803cc6fc,
		"TNormalLift::__vt": 0x803cc86c,
		"TRailMapObj::__vt": 0x803cc9dc,
		"TFluffManager::__vt": 0x803ccb50,
		"TFluff::__vt": 0x803cccb4,
		"TGoalFlag::__vt": 0x803cce18,
		"TSwingBoard::__vt": 0x803ccf7c,
		"THangingBridge::__vt": 0x803cd0e0,
		"THangingBridgeBoard::__vt": 0x803cd104,
		"TJumpMushroom::__vt": 0x803cd26c,
		"TMapObjMonteRoot::__vt": 0x803cd3d0,
		"TMapObjTreeScale::__vt": 0x803cd538,
		"TMapObjTree::__vt": 0x803cd714,
		"TMapObjSteam::__vt": 0x803cd8f0,
		"TJointCoin::__vt": 0x803cda60,
		"TMapObjNail::__vt": 0x803cdbd0,
		"TPool::__vt": 0x803cdd40,
		"TPoolManager::__vt": 0x803cdea4,
		"TBathtub::__vt": 0x803cdee8,
		"TBathtubGrip::__vt": 0x803ce04c,
		"TBathtubGripPartsHard::__vt": 0x803ce1b0,
		"TBathtubGripPartsFragile::__vt": 0x803ce2ac,
		"TBathtubGripParts::__vt": 0x803ce3a8,
		"TJumpBase::__vt": 0x803ce4a8,
		"TMushroom1up::__vt": 0x803ce60c,
		"TWoodBox::__vt": 0x803ce770,
		"TBreakHideObj::__vt": 0x803ce8e0,
		"THideObjPictureTwin::__vt": 0x803cea50,
		"TWaterHitPictureHideObj::__vt": 0x803cebcc,
		"THipDropHideObj::__vt": 0x803ced48,
		"TFruitBasketEvent::__vt": 0x803ceeb8,
		"TFruitBasket::__vt": 0x803cf030,
		"TFruitHitHideObj::__vt": 0x803cf1a8,
		"TWaterHitHideObj::__vt": 0x803cf31c,
		"THideObj::__vt": 0x803cf48c,
		"THideObjBase::__vt": 0x803cf5fc,
		"TLampTrapIron::__vt": 0x803cf770,
		"TLampTrapIronHit::__vt": 0x803cf8d4,
		"TLampTrapSpike::__vt": 0x803cf978,
		"TLampTrapSpikeHit::__vt": 0x803cfadc,
		"TJointModel::__vt": 0x803cfb80,
		"TJointModelManager::__vt": 0x803cfbb8,
		"TJointObj::__vt": 0x803cfbe0,
		"TMap::__vt": 0x803cfc08,
		"Map::@3341": 0x803cfc2c,
		"TBGCheckListWarp::__vt": 0x803cfc70,
		"TBGCheckList::__vt": 0x803cfc7c,
		"TMapCollisionWarp::__vt": 0x803cfc88,
		"TMapCollisionMove::__vt": 0x803cfcac,
		"TMapCollisionStatic::__vt": 0x803cfcd0,
		"TMapCollisionBase::__vt": 0x803cfcf4,
		"TMapDrawWall::__vt": 0x803cfd18,
		"TMapEvent::__vt": 0x803cfd40,
		"TMapEventSinkShadowMario::__vt": 0x803cfd80,
		"TMapEventSinkBianco::__vt": 0x803cfdd4,
		"TMapEventSinkInPollutionReset::__vt": 0x803cfe28,
		"TMapEventSinkInPollution::__vt": 0x803cfe7c,
		"TMapEventSink::__vt": 0x803cfed0,
		"TMirrorMapDrawBuf::__vt": 0x803cff28,
		"TMirrorModelManager::__vt": 0x803cff4c,
		"TMirrorModelObj::__vt": 0x803cff70,
		"TMirrorModel::__vt": 0x803cff8c,
		"TMirrorCamera::__vt": 0x803cffa8,
		"Map::name_table$2428": 0x803d0070,
		"name_table$2428": 0x803d0070,
		"TMapModel::__vt": 0x803d0084,
		"TMapModelManager::__vt": 0x803d00b8,
		"TMapObjSoundGroup::__vt": 0x803d00e0,
		"TMapModelActor::__vt": 0x803d0104,
		"TMapStaticObj::__vt": 0x803d01a8,
		"TMapWireManager::__vt": 0x803d0250,
		"TMapWireActor::__vt": 0x803d0274,
		"TPollutionCounterBase::__vt": 0x803d0328,
		"TPollutionCounterObj::__vt": 0x803d033c,
		"TPollutionCounterLayer::__vt": 0x803d0350,
		"Map::mare_name_table$2805": 0x803d0368,
		"mare_name_table$2805": 0x803d0368,
		"Map::name_table$2816": 0x803d0390,
		"name_table$2816": 0x803d0390,
		"TPollutionManager::__vt": 0x803d03e4,
		"Map::@3043": 0x803d040c,
		"TPollutionLayerWallMinusX::__vt": 0x803d0428,
		"TPollutionLayerWallMinusZ::__vt": 0x803d0484,
		"TPollutionObj::__vt": 0x803d04e0,
		"TShimmer::__vt": 0x803d0508,
		"TSky::__vt": 0x803d05a8,
		"TMapEventSirenaSink::__vt": 0x803d0648,
		"Map::x_offset_table$2432": 0x803d06a8,
		"x_offset_table$2432": 0x803d06a8,
		"Map::z_offset_table$2433": 0x803d06d0,
		"z_offset_table$2433": 0x803d06d0,
		"TPollutionLayer::__vt": 0x803d06f8,
		"TPollutionLayerWallBase::__vt": 0x803d0754,
		"TPollutionLayerWallPlusX::__vt": 0x803d07b0,
		"TPollutionLayerWallPlusZ::__vt": 0x803d080c,
		"TPollutionLayerWave::__vt": 0x803d0868,
		"TPollutionTest::__vt": 0x803d08c8,
		"TMarineSnow::__vt": 0x803d08f0,
		"TDolpicEventRiccoMammaGate::__vt": 0x803d0990,
		"TDolpicEventBiancoGate::__vt": 0x803d09d0,
		"TMareEventBumpyWall::__vt": 0x803d0a10,
		"Map::@3790": 0x803d0b74,
		"TMareEventDepressWall::__vt": 0x803d0b94,
		"TMareEventWallRock::__vt": 0x803d0bb8,
		"TMareWallRock::__vt": 0x803d0bdc,
		"TBathWaterManager::fileNames": 0x803d0d20,
		"fileNames": 0x803d0d20,
		"TBathWaterManager::__vt": 0x803d0d28,
		"TBathWater::__vt": 0x803d0d4c,
		"TBathWaterMeshRenderer::__vt": 0x803d0df0,
		"TBathWaterFlatRenderer::__vt": 0x803d0e04,
		"TBathWaterRenderer::__vt": 0x803d0e18,
		"TBathWaterPreprocessor::__vt": 0x803d0e2c,
		"TStickyStainManager::__vt": 0x803d0e50,
		"TFlashPane::__vt": 0x803d0e78,
		"TMenuPlane::__vt": 0x803d0e9c,
		"TMenuBase::__vt": 0x803d0ec0,
		"TSMSFader::__vt": 0x803d0ee8,
		"GC2D::scDolpicNewsDolpic5_1": 0x803d0f40,
		"scDolpicNewsDolpic5_1": 0x803d0f40,
		"GC2D::scDolpicNewsDolpic5_4": 0x803d0f4c,
		"scDolpicNewsDolpic5_4": 0x803d0f4c,
		"GC2D::scDolpicNewsDolpic6": 0x803d0f58,
		"scDolpicNewsDolpic6": 0x803d0f58,
		"GC2D::scDolpicNewsDolpic7": 0x803d0f64,
		"scDolpicNewsDolpic7": 0x803d0f64,
		"GC2D::scDolpicNewsDolpic8_2": 0x803d0f70,
		"scDolpicNewsDolpic8_2": 0x803d0f70,
		"GC2D::scDolpicNewsDolpic8_3": 0x803d0f7c,
		"scDolpicNewsDolpic8_3": 0x803d0f7c,
		"GC2D::scDolpicNewsDolpic8_4": 0x803d0f88,
		"scDolpicNewsDolpic8_4": 0x803d0f88,
		"GC2D::scDolpicNewsDolpic8_5": 0x803d0f94,
		"scDolpicNewsDolpic8_5": 0x803d0f94,
		"GC2D::scDolpicNewsDolpic8_6": 0x803d0fa0,
		"scDolpicNewsDolpic8_6": 0x803d0fa0,
		"GC2D::scDolpicNewsDolpic8_7": 0x803d0fb0,
		"scDolpicNewsDolpic8_7": 0x803d0fb0,
		"GC2D::scDolpicNewsDolpic9": 0x803d0fbc,
		"scDolpicNewsDolpic9": 0x803d0fbc,
		"GC2D::scDolpicNewsDolpic10": 0x803d0fc8,
		"scDolpicNewsDolpic10": 0x803d0fc8,
		"TGCConsole2::__vt": 0x803d0fe4,
		"GC2D::@7091": 0x803d1008,
		"@7091": 0x803d1008,
		"GC2D::@7077": 0x803d107c,
		"@7077": 0x803d107c,
		"GC2D::@7657": 0x803d10a8,
		"TTalk2D2::cColorTable": 0x803d1100,
		"TTalk2D2::__vt": 0x803d1118,
		"GC2D::@3886": 0x803d113c,
		"TPauseMenu2::__vt": 0x803d12a0,
		"TSwitchHelpActor::__vt": 0x803d12c8,
		"THelpActor::__vt": 0x803d1370,
		"TCardSave::cMessageID": 0x803d1418,
		"TCardSave::__vt": 0x803d14ec,
		"GC2D::@4199": 0x803d1510,
		"TCardLoad::cMessageID": 0x803d1638,
		"TCardLoad::__vt": 0x803d170c,
		"GC2D::@7209": 0x803d17fc,
		"@7209": 0x803d17fc,
		"GC2D::@7651": 0x803d181c,
		"GC2D::@7648": 0x803d1844,
		"TConsoleStr::__vt": 0x803d19b0,
		"TSelectMenu::__vt": 0x803d1b90,
		"GC2D::@3617": 0x803d1bb4,
		"TSelectGrad::__vt": 0x803d1c00,
		"TSelectDir::__vt": 0x803d1c28,
		"TSelectShine::__vt": 0x803d1c98,
		"TSelectShineManager::__vt": 0x803d1ca8,
		"TBlendPane::__vt": 0x803d1cd0,
		"TGuide::__vt": 0x803d1d58,
		"GC2D::@2657": 0x803d1d7c,
		"TSunShine::__vt": 0x803d1db0,
		"TSunGlass::__vt": 0x803d1dd8,
		"TShineFader::__vt": 0x803d1e00,
		"TProgSelect::__vt": 0x803d1e30,
		"GC2D::camLoc$96": 0x803d1e58,
		"camLoc$96": 0x803d1e58,
		"GC2D::objPt$97": 0x803d1e64,
		"objPt$97": 0x803d1e64,
		"GC2D::up$98": 0x803d1e70,
		"up$98": 0x803d1e70,
		"GC2D::handle_table": 0x803d1e7c,
		"handle_table": 0x803d1e7c,
		"GC2D::handle_type": 0x803d1eb8,
		"handle_type": 0x803d1eb8,
		"GC2D::boundtable$262": 0x803d1ec8,
		"boundtable$262": 0x803d1ec8,
		"GC2D::@943": 0x803d2044,
		"TMovieSubTitle::__vt": 0x803d2068,
		"TOptionSoundUnit::cSoundSettings": 0x803d20b8,
		"cSoundSettings": 0x803d20b8,
		"TOptionSoundUnit::cFlagInfos": 0x803d20d0,
		"cFlagInfos": 0x803d20d0,
		"GC2D::@2214": 0x803d20f4,
		"GC2D::@2216": 0x803d2100,
		"GC2D::@2225": 0x803d2130,
		"GC2D::@2227": 0x803d213c,
		"GC2D::@2230": 0x803d2148,
		"GC2D::@2232": 0x803d2154,
		"GC2D::@2234": 0x803d2160,
		"GC2D::@2236": 0x803d216c,
		"TMovieRumble::__vt": 0x803d2188,
		"TConductor::__vt": 0x803d21b0,
		"Enemy::entry$2672": 0x803d21d8,
		"entry$2672": 0x803d21d8,
		"Enemy::entry$2684": 0x803d21f0,
		"entry$2684": 0x803d21f0,
		"Enemy::entry$2697": 0x803d2208,
		"entry$2697": 0x803d2208,
		"Enemy::entry$2706": 0x803d2220,
		"entry$2706": 0x803d2220,
		"TEffectExplosion::__vt": 0x803d2238,
		"TEffectModelManager::__vt": 0x803d234c,
		"TEffectExplosionManager::__vt": 0x803d23a0,
		"TEffectColumSand::__vt": 0x803d23f4,
		"TEffectColumSandManager::__vt": 0x803d2508,
		"TEffectBombColumWater::__vt": 0x803d255c,
		"TEffectBombColumWaterManager::__vt": 0x803d2670,
		"TEffectColumWater::__vt": 0x803d26c4,
		"TEffectColumWaterManager::__vt": 0x803d27d8,
		"TEffectModel::__vt": 0x803d282c,
		"TEffectObjManager::__vt": 0x803d2940,
		"TEffectObjBase::__vt": 0x803d2964,
		"TEffectBiancoFunsui::__vt": 0x803d2a18,
		"TEffectPinnaFunsui::__vt": 0x803d2abc,
		"TSimpleEffect::__vt": 0x803d2b60,
		"TEMarioManager::__vt": 0x803d2c08,
		"TEMario::__vt": 0x803d2c5c,
		"TSpineEnemy::__vt": 0x803d2d70,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::__vt": 0x803d2e84,
		"TSpineBase<TLiveActor>::__vt": 0x803d2e90,
		"TSolidStack<TPathNode>::__vt": 0x803d2ea0,
		"TEnemyPolluteModel::__vt": 0x803d2eb0,
		"TEnemyPolluteModelManager::__vt": 0x803d2ed8,
		"TEnemyAttachment::__vt": 0x803d2f00,
		"TEnemyManager::__vt": 0x803d3048,
		"Enemy::marioAnimeFiles": 0x803d30d8,
		"Enemy::recordFileNamesDolpic1": 0x803d3710,
		"recordFileNamesDolpic1": 0x803d3710,
		"Enemy::recordFileNamesMonteMan": 0x803d3730,
		"recordFileNamesMonteMan": 0x803d3730,
		"Enemy::names$3274": 0x803d373c,
		"names$3274": 0x803d373c,
		"Enemy::bmdFileNames$3287": 0x803d3750,
		"bmdFileNames$3287": 0x803d3750,
		"TEnemyMario::__vt": 0x803d376c,
		"TMtxCalcFootInv::__vt": 0x803d3a70,
		"Enemy::rikuGesso_bastable": 0x803d3b38,
		"rikuGesso_bastable": 0x803d3b38,
		"Enemy::entry$2957": 0x803d3b94,
		"entry$2957": 0x803d3b94,
		"TNerveGessoTurn::__vt": 0x803d3bac,
		"TNerveGessoLand::__vt": 0x803d3bbc,
		"TNerveGessoFindMario::__vt": 0x803d3bcc,
		"TNerveGessoRolling::__vt": 0x803d3bdc,
		"TNerveGessoFall::__vt": 0x803d3bec,
		"TNerveGessoPollute::__vt": 0x803d3bfc,
		"TNerveGessoPunch::__vt": 0x803d3c0c,
		"TNerveGessoFreeze::__vt": 0x803d3c1c,
		"TNerveGessoStay::__vt": 0x803d3c2c,
		"TGessoPolluteObj::__vt": 0x803d3c3c,
		"TLandGesso::__vt": 0x803d3d84,
		"TSurfGesso::__vt": 0x803d3f3c,
		"TGesso::__vt": 0x803d40f4,
		"TGessoManager::__vt": 0x803d42ac,
		"TGessoPolluteModel::__vt": 0x803d4304,
		"TGessoPolluteModelManager::__vt": 0x803d432c,
		"Enemy::grDummyRail": 0x803d4390,
		"grDummyRail": 0x803d4390,
		"TGraphWeb::__vt": 0x803d445c,
		"Enemy::hanekuri_bastable": 0x803d4468,
		"hanekuri_bastable": 0x803d4468,
		"Enemy::hamukurianm_bastable": 0x803d4478,
		"hamukurianm_bastable": 0x803d4478,
		"Enemy::entry$3048": 0x803d44b4,
		"entry$3048": 0x803d44b4,
		"Enemy::entry$3115": 0x803d44cc,
		"entry$3115": 0x803d44cc,
		"Enemy::entry$3125": 0x803d44e4,
		"entry$3125": 0x803d44e4,
		"Enemy::entry$3156": 0x803d44fc,
		"entry$3156": 0x803d44fc,
		"Enemy::entry$3168": 0x803d4514,
		"entry$3168": 0x803d4514,
		"TNerveDoroHanePrepareAttack::__vt": 0x803d452c,
		"TNerveDoroHaneHitWater::__vt": 0x803d453c,
		"TNerveDoroHaneRise::__vt": 0x803d454c,
		"TNerveFireHamuKuriRecover::__vt": 0x803d455c,
		"TNerveDoroHamuKuriRobCap::__vt": 0x803d456c,
		"TNerveHaneHamuKuriMoveOnGraph::__vt": 0x803d457c,
		"TNerveHaneHamuKuriUpWait::__vt": 0x803d458c,
		"TNerveDangoHamuKuriWait::__vt": 0x803d459c,
		"TNerveHamuKuriJitabata::__vt": 0x803d45ac,
		"TNerveHamuKuriLand::__vt": 0x803d45bc,
		"TNerveHamuKuriWallDie::__vt": 0x803d45cc,
		"TNerveHamuKuriBoundFreeze::__vt": 0x803d45dc,
		"TNerveHamuKuriGoForSearchActor::__vt": 0x803d45ec,
		"TDoroHamuKuri::__vt": 0x803d45fc,
		"TFireHamuKuri::__vt": 0x803d47c4,
		"TBossDangoHamuKuri::__vt": 0x803d498c,
		"TDangoHamuKuri::__vt": 0x803d4b54,
		"THaneHamuKuri2::__vt": 0x803d4d1c,
		"TDoroHaneKuri::__vt": 0x803d4ee4,
		"THaneHamuKuri::__vt": 0x803d50ac,
		"THamuKuri::__vt": 0x803d5274,
		"TDoroHamuKuriManager::__vt": 0x803d543c,
		"TDoroHige::__vt": 0x803d5494,
		"TFireHamuKuriManager::__vt": 0x803d54b8,
		"TBossDangoHamuKuriManager::__vt": 0x803d5510,
		"TDangoHamuKuriManager::__vt": 0x803d5568,
		"TDoroHaneKuriManager::__vt": 0x803d55c0,
		"THaneHamuKuriManager::__vt": 0x803d5618,
		"THamuKuriManager::__vt": 0x803d5670,
		"THamuKuriLauncher::__vt": 0x803d56c8,
		"Enemy::hinokuri2_bastable": 0x803d5830,
		"hinokuri2_bastable": 0x803d5830,
		"TNerveHino2WaitAnm::__vt": 0x803d58a0,
		"TNerveHino2Freeze::__vt": 0x803d597c,
		"TNerveHino2Stamp::__vt": 0x803d598c,
		"TNerveHino2Die::__vt": 0x803d599c,
		"TNerveHino2Burst::__vt": 0x803d59ac,
		"TNerveHino2Squat::__vt": 0x803d59bc,
		"TNerveHino2Damage::__vt": 0x803d59cc,
		"TNerveHino2Pollute::__vt": 0x803d59dc,
		"TNerveHino2PrePol::__vt": 0x803d59ec,
		"TNerveHino2Turn::__vt": 0x803d59fc,
		"TNerveHino2Landing::__vt": 0x803d5a0c,
		"TNerveHino2JumpIn::__vt": 0x803d5a1c,
		"TNerveHino2Fly::__vt": 0x803d5a2c,
		"TNerveHino2GraphWander::__vt": 0x803d5a3c,
		"TNerveHino2Appear::__vt": 0x803d5a4c,
		"THinokuri2::__vt": 0x803d5a5c,
		"THino2Hit::__vt": 0x803d5b70,
		"THino2MtxCalc::__vt": 0x803d5c14,
		"THinokuri2Manager::__vt": 0x803d5c68,
		"Enemy::mameGesso_bastable": 0x803d5cc0,
		"mameGesso_bastable": 0x803d5cc0,
		"TNerveMameGessoWait::__vt": 0x803d5d0c,
		"TNerveMameGessoObject::__vt": 0x803d5d1c,
		"TNerveMameGessoThrown::__vt": 0x803d5d2c,
		"TNerveMameGessoPickUp::__vt": 0x803d5d3c,
		"TNerveMameGessoTrample::__vt": 0x803d5d4c,
		"TNerveMameGessoJitabata::__vt": 0x803d5d5c,
		"TNerveMameGessoDamage::__vt": 0x803d5d6c,
		"TNerveMameGessoGraphJumpWander::__vt": 0x803d5d7c,
		"TMameGesso::__vt": 0x803d5d8c,
		"TMameGessoManager::__vt": 0x803d5f44,
		"Enemy::namekuri2_bastable": 0x803d5fa0,
		"namekuri2_bastable": 0x803d5fa0,
		"Enemy::entry$2947": 0x803d5fc0,
		"entry$2947": 0x803d5fc0,
		"TNerveNKFollowMario::__vt": 0x803d5fd8,
		"TDiffusionNameKuri::__vt": 0x803d5fe8,
		"TNerveNameKuriDrawPollute::__vt": 0x803d61a0,
		"TNerveNameKuriDiffuse::__vt": 0x803d61b0,
		"TNerveNameKuriExplosion::__vt": 0x803d61c0,
		"TNerveNameKuriJumpAttackPrepare::__vt": 0x803d61d0,
		"TNerveNameKuriJumpAttack::__vt": 0x803d61e0,
		"TNerveNameKuriLand::__vt": 0x803d61f0,
		"TDiffusionNameKuriManager::__vt": 0x803d6200,
		"TNameKuri::__vt": 0x803d6258,
		"TNameIndParCallback::__vt": 0x803d6410,
		"TNameKuriManager::__vt": 0x803d6420,
		"TNameKuriLauncher::__vt": 0x803d6478,
		"Enemy::pakkun_bastable": 0x803d65a8,
		"pakkun_bastable": 0x803d65a8,
		"Enemy::entry$3011": 0x803d65d0,
		"entry$3011": 0x803d65d0,
		"TNerveStayPakkunAppear::__vt": 0x803d65e8,
		"TNerveStayPakkunHide::__vt": 0x803d65f8,
		"TNervePakkunFreeze::__vt": 0x803d6608,
		"TNervePakkunShoot::__vt": 0x803d6618,
		"TNervePakkunHide::__vt": 0x803d6628,
		"TNervePakkunAppear::__vt": 0x803d6638,
		"TNervePakkunStay::__vt": 0x803d6648,
		"TNervePakkunGenerate::__vt": 0x803d6658,
		"TStayPakkun::__vt": 0x803d6668,
		"TPakkunSeed::__vt": 0x803d6818,
		"TPakkun::__vt": 0x803d6960,
		"TPakkunManager::__vt": 0x803d6b10,
		"TNerveSmallEnemyChange::__vt": 0x803d6b80,
		"TNerveSmallEnemyWait::__vt": 0x803d6b90,
		"TNerveSmallEnemyHitWaterJump::__vt": 0x803d6ba0,
		"TNerveSmallEnemyJump::__vt": 0x803d6bb0,
		"TNerveSmallEnemyFreeze::__vt": 0x803d6bc0,
		"TNerveSmallEnemyDie::__vt": 0x803d6bd0,
		"TSmallEnemy::__vt": 0x803d6be0,
		"TSmallEnemyManager::__vt": 0x803d6d88,
		"TSpider::__vt": 0x803d6de0,
		"TNerveTypicalGraphWander::__vt": 0x803d6df0,
		"TTypicalManager::__vt": 0x803d6e00,
		"TTypicalEnemy::__vt": 0x803d6e54,
		"TWalker::__vt": 0x803d6f68,
		"TSolidStack<TBGCheckData_const*>::__vt": 0x803d6f78,
		"TNerveWalkerTraceMario::__vt": 0x803d6f88,
		"TNerveWalkerEscape::__vt": 0x803d6f98,
		"TNerveWalkerPostAttack::__vt": 0x803d6fa8,
		"TNerveWalkerAttack::__vt": 0x803d6fb8,
		"TNerveWalkerGraphWander::__vt": 0x803d6fc8,
		"TNerveWalkerGenerate::__vt": 0x803d6fd8,
		"TWalkerEnemy::__vt": 0x803d6fe8,
		"Enemy::bgeso_bastable": 0x803d71a0,
		"bgeso_bastable": 0x803d71a0,
		"TNerveBGRoll::__vt": 0x803d7210,
		"Enemy::@7548": 0x803d7240,
		"@7548": 0x803d7240,
		"TNerveBGPolDrop::__vt": 0x803d7260,
		"TNerveBGPollute::__vt": 0x803d7270,
		"TNerveBGDie::__vt": 0x803d7280,
		"TNerveBGTug::__vt": 0x803d7290,
		"TNerveBGTentacleDamage::__vt": 0x803d72a0,
		"TNerveBGBeakDamage::__vt": 0x803d72b0,
		"TNerveBGEyeDamage::__vt": 0x803d72c0,
		"TNerveBGWait::__vt": 0x803d72d0,
		"TBossGessoManager::__vt": 0x803d72e0,
		"TBossGesso::__vt": 0x803d7334,
		"TBGBinder::__vt": 0x803d7448,
		"TBossGessoMtxCalc::__vt": 0x803d7458,
		"TBGBodyHit::__vt": 0x803d749c,
		"TBGEyeHit::__vt": 0x803d7540,
		"TBGBeakHit::__vt": 0x803d75e4,
		"Enemy::dennoko_bastable": 0x803d7698,
		"dennoko_bastable": 0x803d7698,
		"Enemy::entry$2916": 0x803d76e0,
		"entry$2916": 0x803d76e0,
		"TNerveElecCarapaceReturn::__vt": 0x803d76f8,
		"TNerveElecCarapaceWait::__vt": 0x803d7708,
		"TNerveElecCarapaceMove::__vt": 0x803d7718,
		"TNerveElecNokonokoAttack::__vt": 0x803d7728,
		"TNerveElecNokonokoRebirth::__vt": 0x803d7738,
		"TNerveElecNokonokoFreeze::__vt": 0x803d7748,
		"TNerveElecNokonokoTurn::__vt": 0x803d7758,
		"TNerveElecNokonokoCollect::__vt": 0x803d7768,
		"TNerveElecNokonokoShoot::__vt": 0x803d7778,
		"TElecCarapace::__vt": 0x803d7788,
		"TElecNokonoko::__vt": 0x803d78d0,
		"TElecNokonokoManager::__vt": 0x803d7a8c,
		"Enemy::telesa_bastable": 0x803d7ae8,
		"telesa_bastable": 0x803d7ae8,
		"Enemy::entry$2992": 0x803d7b04,
		"entry$2992": 0x803d7b04,
		"TNerveKageMarioModokiWait::__vt": 0x803d7b34,
		"TKageMarioModoki::__vt": 0x803d7b78,
		"TKageMarioModokiManager::__vt": 0x803d7d30,
		"TNerveTelesaTrample::__vt": 0x803d7d88,
		"TNerveTelesaAttackMario::__vt": 0x803d7d98,
		"TNerveTelesaFreeze::__vt": 0x803d7da8,
		"TNerveTelesaDie::__vt": 0x803d7db8,
		"TNerveTelesaImitate::__vt": 0x803d7dc8,
		"TMarioModokiTelesa::__vt": 0x803d7dd8,
		"TBoxTelesa::__vt": 0x803d7f90,
		"TLoopTelesa::__vt": 0x803d8148,
		"TSeeTelesa::__vt": 0x803d8300,
		"TTelesa::__vt": 0x803d84b8,
		"TTelesaManager::__vt": 0x803d8670,
		"Enemy::fireWanwan_bastable": 0x803d86c8,
		"fireWanwan_bastable": 0x803d86c8,
		"Enemy::entry$3027": 0x803d86e8,
		"entry$3027": 0x803d86e8,
		"TNerveFireWanwanEscape::__vt": 0x803d8700,
		"TNerveFireWanwanFreeze::__vt": 0x803d8710,
		"TNerveFireWanwanFly::__vt": 0x803d8720,
		"TNerveFireWanwanHungTail::__vt": 0x803d8730,
		"TNerveFireWanwanDie::__vt": 0x803d8740,
		"TNerveFireWanwanRecover::__vt": 0x803d8750,
		"TNerveFireWanwanRecoverGraph::__vt": 0x803d8760,
		"TNerveFireWanwanTired::__vt": 0x803d8770,
		"TNerveFireWanwanAttack::__vt": 0x803d8780,
		"TNerveFireWanwanFindMario::__vt": 0x803d8790,
		"TNerveFireWanwanTurn::__vt": 0x803d87a0,
		"TNerveFireWanwanGraphWander::__vt": 0x803d87b0,
		"TFireWanwan::__vt": 0x803d87c0,
		"TFireWanwanTailHit::__vt": 0x803d8968,
		"TFireWanwanManager::__vt": 0x803d8a1c,
		"TStageEnemyInfo::__vt": 0x803d8a78,
		"TStageEnemyInfoTable::__vt": 0x803d8a98,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::__vt": 0x803d8ab8,
		"TOneShotGenerator::__vt": 0x803d8ad8,
		"TGenerator::__vt": 0x803d8b7c,
		"Enemy::bosspakkun_bastable": 0x803d8ba0,
		"bosspakkun_bastable": 0x803d8ba0,
		"TNerveBPCannonL::__vt": 0x803d8c18,
		"TNerveBPWaitL::__vt": 0x803d8c28,
		"TNerveBPBreakSleep::__vt": 0x803d8c38,
		"TNerveBPSleep::__vt": 0x803d8c48,
		"TNerveBPFall::__vt": 0x803d8c58,
		"TNerveBPHover::__vt": 0x803d8c68,
		"TNerveBPFlyPivot::__vt": 0x803d8c78,
		"TNerveBPFlyCannon::__vt": 0x803d8c88,
		"TNerveBPTouchDown::__vt": 0x803d8c98,
		"TNerveBPFly::__vt": 0x803d8ca8,
		"TNerveBPTakeOff::__vt": 0x803d8cb8,
		"TNerveBPDie::__vt": 0x803d8cc8,
		"TNerveBPPreDie::__vt": 0x803d8cd8,
		"TNerveBPJumpReact::__vt": 0x803d8ce8,
		"TNerveBPStompReact::__vt": 0x803d8cf8,
		"TNerveBPSwing::__vt": 0x803d8d08,
		"TNerveBPGetUp::__vt": 0x803d8d18,
		"TNerveBPTumbleOut::__vt": 0x803d8d28,
		"TNerveBPTumble::__vt": 0x803d8d38,
		"TNerveBPTumbleIn::__vt": 0x803d8d48,
		"TNerveBPSwallow::__vt": 0x803d8d58,
		"TNerveBPPivot::__vt": 0x803d8d68,
		"TNerveBPTornado::__vt": 0x803d8d78,
		"TNerveBPVomit::__vt": 0x803d8d88,
		"TNerveBPCannon::__vt": 0x803d8d98,
		"TNerveBPWait::__vt": 0x803d8da8,
		"TBossPakkunManager::__vt": 0x803d8db8,
		"TBossPakkun::__vt": 0x803d8e0c,
		"TBossPakkunMtxCalc::__vt": 0x803d8f20,
		"TBPNavel::__vt": 0x803d8f64,
		"TBPHeadHit::__vt": 0x803d9008,
		"TBPTornado::__vt": 0x803d90ac,
		"TBPVomit::__vt": 0x803d9150,
		"TBPPolDrop::__vt": 0x803d9174,
		"Enemy::pukupuku_bastable": 0x803d9218,
		"pukupuku_bastable": 0x803d9218,
		"Enemy::moepuku_bastable": 0x803d9244,
		"moepuku_bastable": 0x803d9244,
		"TNerveTobiPukuSwimWander::__vt": 0x803d9270,
		"TNerveTobiPukuReturnLaunch::__vt": 0x803d9280,
		"TNerveTobiPukuPrepareFly::__vt": 0x803d9290,
		"TNerveTobiPukuBound::__vt": 0x803d92a0,
		"TNerveTobiPukuLand::__vt": 0x803d92b0,
		"TNerveTobiPukuDie::__vt": 0x803d92c0,
		"TNerveTobiPukuPitiPiti::__vt": 0x803d92d0,
		"TNerveTobiPukuFall::__vt": 0x803d92e0,
		"TNerveTobiPukuHitWater::__vt": 0x803d92f0,
		"TNerveTobiPukuAttack::__vt": 0x803d9300,
		"TNerveTobiPukuFly::__vt": 0x803d9310,
		"TNerveTobiPukuGenerate::__vt": 0x803d9320,
		"TMoePuku::__vt": 0x803d9330,
		"TPukuPuku::__vt": 0x803d9530,
		"TTobiPuku::__vt": 0x803d9730,
		"TMoePukuLaunchPad::__vt": 0x803d9930,
		"TTobiPukuLaunchPad::__vt": 0x803d9adc,
		"TMoePukuManager::__vt": 0x803d9c88,
		"TTobiPukuManager::__vt": 0x803d9ce0,
		"TMoePukuLaunchPadManager::__vt": 0x803d9d38,
		"TTobiPukuLaunchPadManager::__vt": 0x803d9d90,
		"Enemy::tinkoopa_bastable": 0x803d9e20,
		"tinkoopa_bastable": 0x803d9e20,
		"Enemy::TTinKoopa_jointNameTable": 0x803d9e64,
		"TTinKoopa_jointNameTable": 0x803d9e64,
		"Enemy::table$3029": 0x803d9ea0,
		"table$3029": 0x803d9ea0,
		"Enemy::table$3036": 0x803d9eb8,
		"table$3036": 0x803d9eb8,
		"Enemy::table$3041": 0x803d9ed0,
		"table$3041": 0x803d9ed0,
		"Enemy::table$3042": 0x803d9ee8,
		"table$3042": 0x803d9ee8,
		"Enemy::table$3043": 0x803d9f00,
		"table$3043": 0x803d9f00,
		"Enemy::table$3044": 0x803d9f14,
		"table$3044": 0x803d9f14,
		"Enemy::table$3045": 0x803d9f28,
		"table$3045": 0x803d9f28,
		"Enemy::table$3046": 0x803d9f3c,
		"table$3046": 0x803d9f3c,
		"Enemy::table$3047": 0x803d9f50,
		"table$3047": 0x803d9f50,
		"Enemy::breastTrackJointNameTable": 0x803d9f64,
		"breastTrackJointNameTable": 0x803d9f64,
		"Enemy::bellyTrackJointNameTable": 0x803d9f7c,
		"bellyTrackJointNameTable": 0x803d9f7c,
		"Enemy::rightArmTrackJointNameTable": 0x803d9f94,
		"rightArmTrackJointNameTable": 0x803d9f94,
		"Enemy::leftArmTrackJointNameTable": 0x803d9fa4,
		"leftArmTrackJointNameTable": 0x803d9fa4,
		"Enemy::onetimeFilenames$3493": 0x803d9fb4,
		"onetimeFilenames$3493": 0x803d9fb4,
		"Enemy::loopFilenames$3507": 0x803d9fd0,
		"loopFilenames$3507": 0x803d9fd0,
		"TNerveTinKoopaBreak::__vt": 0x803da014,
		"TNerveTinKoopaDamage::__vt": 0x803da084,
		"TNerveTinKoopaWait::__vt": 0x803da094,
		"TTinKoopaManager::__vt": 0x803da0a4,
		"TTinKoopaMtxCalc::__vt": 0x803da0f8,
		"TTinKoopaPartsBase::__vt": 0x803da13c,
		"TTinKoopaFlame::__vt": 0x803da23c,
		"TTinKoopa::__vt": 0x803da2e0,
		"Enemy::clauncher_bastable": 0x803da3f8,
		"clauncher_bastable": 0x803da3f8,
		"TCommonLauncherManager::__vt": 0x803da408,
		"TCommonLauncher::__vt": 0x803da46c,
		"TLauncherManager::__vt": 0x803da598,
		"TLauncher::__vt": 0x803da5ec,
		"Enemy::bwanwan_bastable": 0x803da750,
		"bwanwan_bastable": 0x803da750,
		"TNerveBWFall::__vt": 0x803da76c,
		"TNerveBWShake::__vt": 0x803da8cc,
		"TNerveBWJumpAway::__vt": 0x803da8dc,
		"TNerveBWDie::__vt": 0x803da8ec,
		"TNerveBWJumpToBath::__vt": 0x803da8fc,
		"TNerveBWWakeup::__vt": 0x803da90c,
		"TNerveBWStun::__vt": 0x803da91c,
		"TNerveBWJump::__vt": 0x803da92c,
		"TNerveBWBark::__vt": 0x803da93c,
		"TNerveBWRoll::__vt": 0x803da94c,
		"TNerveBWGraphWander::__vt": 0x803da95c,
		"TBossWanwanManager::__vt": 0x803da96c,
		"TBossWanwan::__vt": 0x803da9c0,
		"TBossWanwanMtxCalc::__vt": 0x803daad4,
		"TBWBinder::__vt": 0x803dab18,
		"TBWHit::__vt": 0x803dab28,
		"TBWPicket::__vt": 0x803dabcc,
		"TBWLeash::__vt": 0x803dac80,
		"TBWLeashNode::__vt": 0x803daca4,
		"Enemy::tyuhana_bastable": 0x803dad48,
		"tyuhana_bastable": 0x803dad48,
		"Enemy::graphlist$2835": 0x803dad7c,
		"graphlist$2835": 0x803dad7c,
		"TNerveChuuHanaWait::__vt": 0x803dad94,
		"TNerveChuuHanaJumpPrepare::__vt": 0x803dada4,
		"TNerveChuuHanaAttack::__vt": 0x803dadb4,
		"TNerveChuuHanaObject::__vt": 0x803dadc4,
		"TNerveChuuHanaFall2::__vt": 0x803dadd4,
		"TNerveChuuHanaFall::__vt": 0x803dade4,
		"TNerveChuuHanaRoll::__vt": 0x803dadf4,
		"TNerveChuuHanaStick::__vt": 0x803dae04,
		"TNerveChuuHanaKeepBalance::__vt": 0x803dae14,
		"TNerveChuuHanaForceJumped::__vt": 0x803dae24,
		"TNerveChuuHanaWalkOnPanel::__vt": 0x803dae34,
		"TChuuHana::__vt": 0x803dae44,
		"TChuuHanaAseParCallback::__vt": 0x803daffc,
		"TChuuHanaManager::__vt": 0x803db00c,
		"Enemy::igaiga_bastable": 0x803db068,
		"igaiga_bastable": 0x803db068,
		"Enemy::gorogoro_bastable": 0x803db088,
		"gorogoro_bastable": 0x803db088,
		"Enemy::entry$3110": 0x803db098,
		"entry$3110": 0x803db098,
		"Enemy::entry$3337": 0x803db0b0,
		"entry$3337": 0x803db0b0,
		"TNerveGorogoroDie::__vt": 0x803db0c8,
		"TNerveGorogoroRollOnGraph::__vt": 0x803db0d8,
		"TGorogoro::__vt": 0x803db0e8,
		"TGorogoroManager::__vt": 0x803db2b8,
		"TGorogoroPolluteModel::__vt": 0x803db310,
		"TGorogoroPolluteModelManager::__vt": 0x803db338,
		"TNerveIgaigaShootFromCannon::__vt": 0x803db360,
		"TNerveIgaigaWaterHit::__vt": 0x803db370,
		"TNerveIgaigaRollOnGraph::__vt": 0x803db380,
		"TIgaiga::__vt": 0x803db390,
		"TIgaigaManager::__vt": 0x803db560,
		"TIgaigaPolluteModel::__vt": 0x803db5b8,
		"TIgaigaPolluteModelManager::__vt": 0x803db5e0,
		"TRollEnemy::__vt": 0x803db608,
		"Enemy::poihana_bastable": 0x803db7d8,
		"poihana_bastable": 0x803db7d8,
		"TNervePoihanaTrapped::__vt": 0x803db810,
		"TNervePoihanaThrow::__vt": 0x803db820,
		"TNervePoihanaFreeze::__vt": 0x803db830,
		"TNervePoihanaSleep::__vt": 0x803db840,
		"TSleepPoiHana::__vt": 0x803db850,
		"TPoiHanaRed::__vt": 0x803dba08,
		"TPoiHana::__vt": 0x803dbbc0,
		"TPoiHanaCollision::__vt": 0x803dbd78,
		"TPoiHanaManager::__vt": 0x803dbe1c,
		"Enemy::tamaNoko_bastable": 0x803dbe78,
		"tamaNoko_bastable": 0x803dbe78,
		"TNerveTamaNokoWait::__vt": 0x803dbed4,
		"TNerveTamaNokoHitWater::__vt": 0x803dbee4,
		"TNerveTamaNokoSink::__vt": 0x803dbef4,
		"TNerveTamaNokoThrown::__vt": 0x803dbf04,
		"TNerveTamaNokoPickUp::__vt": 0x803dbf14,
		"TNerveTamaNokoDown::__vt": 0x803dbf24,
		"TNerveTamaNokoAttack::__vt": 0x803dbf34,
		"TNerveTamaNokoSleep::__vt": 0x803dbf44,
		"TTamaNoko::__vt": 0x803dbf54,
		"TTamaNokoManager::__vt": 0x803dc10c,
		"TTamaNokoFlower::__vt": 0x803dc164,
		"Enemy::btelesa_bastable": 0x803dc188,
		"btelesa_bastable": 0x803dc188,
		"Enemy::entry$3173": 0x803dc1cc,
		"entry$3173": 0x803dc1cc,
		"Enemy::entry$3276": 0x803dc1e4,
		"entry$3276": 0x803dc1e4,
		"Enemy::manNameTable$3933": 0x803dc1fc,
		"manNameTable$3933": 0x803dc1fc,
		"TNerveBossTelesaFallDemo::__vt": 0x803dc220,
		"TBossTelesaKillSmallEnemy::__vt": 0x803dc230,
		"TNerveBossTelesaFreeze::__vt": 0x803dc2d4,
		"TNerveBossTelesaPrepareSlot::__vt": 0x803dc2e4,
		"TNerveBossTelesaSpitSlotItem::__vt": 0x803dc2f4,
		"TNerveBossTelesaSlotStart::__vt": 0x803dc304,
		"TNerveBossTelesaAppear::__vt": 0x803dc314,
		"TNerveBossTelesaHideWait::__vt": 0x803dc324,
		"TNerveBossTelesaHide::__vt": 0x803dc334,
		"TNerveBossTelesaSpit::__vt": 0x803dc344,
		"TNerveBossTelesaDie::__vt": 0x803dc354,
		"TBossTelesa::__vt": 0x803dc364,
		"TTelesaSlot::__vt": 0x803dc478,
		"TBossTelesaTongue::__vt": 0x803dc5ec,
		"TBossTelesaBody::__vt": 0x803dc690,
		"TBossTelesaManager::__vt": 0x803dc734,
		"TNerveBubbleSplit::__vt": 0x803dc788,
		"TNerveBubbleLive::__vt": 0x803dc798,
		"TBubble::__vt": 0x803dc7a8,
		"TBubbleManager::__vt": 0x803dc960,
		"TNerveRHGraphWander::__vt": 0x803dc9b8,
		"TRiccoHookManager::__vt": 0x803dc9c8,
		"TRiccoHook::__vt": 0x803dca1c,
		"THookTake::__vt": 0x803dcb30,
		"Enemy::bombhei_bastable": 0x803dcc20,
		"bombhei_bastable": 0x803dcc20,
		"TNerveBombHeiExplosion::__vt": 0x803dcc60,
		"TNerveBombHeiThrown::__vt": 0x803dccb0,
		"TNerveBombHeiPickUp::__vt": 0x803dccc0,
		"TNerveBombHeiWaitExplosion::__vt": 0x803dccd0,
		"TNerveBombHeiWalkExplosion::__vt": 0x803dcce0,
		"TNerveBombHeiAttack::__vt": 0x803dccf0,
		"TNerveBombHeiGenerate::__vt": 0x803dcd00,
		"TBombHei::__vt": 0x803dcd10,
		"TBombHeiManager::__vt": 0x803dcec8,
		"Enemy::cannon_bastable": 0x803dcf20,
		"cannon_bastable": 0x803dcf20,
		"Enemy::sCannonDomPartsJointTable$3043": 0x803dcf70,
		"sCannonDomPartsJointTable$3043": 0x803dcf70,
		"TNerveCannonObject::__vt": 0x803dcf7c,
		"TNerveCannonDamageDemo::__vt": 0x803dcf8c,
		"TNerveCannonDamage::__vt": 0x803dcf9c,
		"TNerveCannonClose::__vt": 0x803dcfac,
		"TNerveCannonForceBombShoot::__vt": 0x803dcfbc,
		"TNerveCannonShoot::__vt": 0x803dcfcc,
		"TNerveCannonSearch::__vt": 0x803dcfdc,
		"TNerveCannonOpen::__vt": 0x803dcfec,
		"TCannon::__vt": 0x803dcffc,
		"TCannonDom::__vt": 0x803dd1a8,
		"TChorobei::__vt": 0x803dd1cc,
		"TCannonManager::__vt": 0x803dd270,
		"Enemy::bosseel_bastable": 0x803dd300,
		"bosseel_bastable": 0x803dd300,
		"Enemy::bossEelTears_bastable": 0x803dd35c,
		"bossEelTears_bastable": 0x803dd35c,
		"Enemy::entry$3126": 0x803dd36c,
		"entry$3126": 0x803dd36c,
		"Enemy::sEyePartsJointTable$3535": 0x803dd390,
		"sEyePartsJointTable$3535": 0x803dd390,
		"Enemy::sToothPartsJointTable$3546": 0x803dd3a0,
		"sToothPartsJointTable$3546": 0x803dd3a0,
		"Enemy::sCollisionJointTable$3578": 0x803dd3c0,
		"sCollisionJointTable$3578": 0x803dd3c0,
		"Enemy::sCollisionFileTable$3582": 0x803dd3d0,
		"sCollisionFileTable$3582": 0x803dd3d0,
		"TNerveBossEelSleepOnBottom::__vt": 0x803dd3e0,
		"TNerveBossEelMouthOpenWait::__vt": 0x803dd454,
		"TNerveBossEelDie::__vt": 0x803dd464,
		"TNerveBossEelEat::__vt": 0x803dd474,
		"TNerveBossEelQuickBack::__vt": 0x803dd484,
		"TNerveBossEelSlowBack::__vt": 0x803dd494,
		"TNerveBossEelOutWait::__vt": 0x803dd4a4,
		"TNerveBossEelAppear::__vt": 0x803dd4b4,
		"TNerveBossEelSecondSpin::__vt": 0x803dd4c4,
		"TNerveBossEelFirstSpin::__vt": 0x803dd4d4,
		"TNerveBossEelWaitAppear::__vt": 0x803dd4e4,
		"TBossEel::__vt": 0x803dd4f4,
		"TBossEelTearsRecoverCollision::__vt": 0x803dd608,
		"TBossEelBarrierCollision::__vt": 0x803dd6b4,
		"TBossEelAwaCollision::__vt": 0x803dd760,
		"TBossEelBodyCollision::__vt": 0x803dd80c,
		"TBossEelCollision::__vt": 0x803dd8b8,
		"TBossEelHeartCoin::__vt": 0x803dd964,
		"TBossEelEye::__vt": 0x803dd988,
		"TBossEelVortex::__vt": 0x803dd9ac,
		"TBossEelTooth::__vt": 0x803dda54,
		"TBossEelManager::__vt": 0x803ddaf8,
		"TNerveOilBallStay::__vt": 0x803ddb4c,
		"TOilBall::__vt": 0x803ddb5c,
		"TNerveBEelTearsSplit::__vt": 0x803ddc74,
		"TNerveBEelTearsMarioRecover::__vt": 0x803ddc84,
		"TNerveBEelTearsWaterHit::__vt": 0x803ddc94,
		"TNerveBEelTearsMoveUp::__vt": 0x803ddca4,
		"TNerveBEelTearsGenerate::__vt": 0x803ddcb4,
		"TBEelTears::__vt": 0x803ddcc4,
		"TBEelTearsManager::__vt": 0x803ddddc,
		"TBEelTearsDrop::__vt": 0x803dde30,
		"Enemy::entry$3036": 0x803ddf24,
		"entry$3036": 0x803ddf24,
		"TNerveKillerExplosion::__vt": 0x803ddf48,
		"TKiller::__vt": 0x803ddf98,
		"TKillerManager::__vt": 0x803de15c,
		"TNerveFlyEnemyChaseFly::__vt": 0x803de1b4,
		"TNerveFlyEnemyNormalFly::__vt": 0x803de1c4,
		"TFlyEnemy::__vt": 0x803de1d4,
		"TBeamManager::__vt": 0x803de398,
		"Enemy::sambo_bastable": 0x803de3c0,
		"sambo_bastable": 0x803de3c0,
		"Enemy::entry$2894": 0x803de438,
		"entry$2894": 0x803de438,
		"Enemy::jIndexTable$3043": 0x803de45c,
		"jIndexTable$3043": 0x803de45c,
		"Enemy::entry$3085": 0x803de46c,
		"entry$3085": 0x803de46c,
		"TNerveSamboHeadHitWall::__vt": 0x803de484,
		"TNerveSamboHeadRecoverWater::__vt": 0x803de494,
		"TNerveSamboHeadHitWater::__vt": 0x803de4a4,
		"TNerveSamboHeadHide::__vt": 0x803de4b4,
		"TNerveSamboHeadAttack::__vt": 0x803de4c4,
		"TNerveSamboHeadAppear::__vt": 0x803de4d4,
		"TSamboHead::__vt": 0x803de4e4,
		"TSamboHeadManager::__vt": 0x803de69c,
		"TNerveHanaSamboFreeze::__vt": 0x803de6f4,
		"TNerveHanaSamboDie::__vt": 0x803de704,
		"TNerveHanaSamboHide::__vt": 0x803de714,
		"TNerveHanaSamboAttack::__vt": 0x803de724,
		"TNerveHanaSamboWait::__vt": 0x803de734,
		"TNerveHanaSamboAppear::__vt": 0x803de744,
		"THanaSambo::__vt": 0x803de754,
		"THanaSamboHead::__vt": 0x803de8fc,
		"THanaSamboManager::__vt": 0x803de9a0,
		"TSamboFlower::__vt": 0x803de9f8,
		"TSamboFlowerManager::__vt": 0x803deb10,
		"TSamboLeaf::__vt": 0x803deb68,
		"Enemy::popo_bastable": 0x803deb90,
		"popo_bastable": 0x803deb90,
		"Enemy::entry$2927": 0x803debac,
		"entry$2927": 0x803debac,
		"TNervePopoThrown::__vt": 0x803debd0,
		"TNervePopoWait::__vt": 0x803debe0,
		"TNervePopoExplosion::__vt": 0x803debf0,
		"TNervePopoFly::__vt": 0x803dec00,
		"TNervePopoAttack::__vt": 0x803dec10,
		"TNervePopoPossessedNozzle::__vt": 0x803dec20,
		"TPopo::__vt": 0x803dec30,
		"TPopoCollision::__vt": 0x803dede8,
		"TPopoManager::__vt": 0x803dee8c,
		"TNerveSBH_Fall::__vt": 0x803deee8,
		"TNerveSBH_SleepContinue::__vt": 0x803deef8,
		"TSleepBossHanachan::__vt": 0x803def08,
		"TSleepBossHanachanManager::__vt": 0x803df01c,
		"TDemoBossHanachan::__vt": 0x803df070,
		"TDemoBossHanachanManager::__vt": 0x803df184,
		"TNerveFruitsBoatBckTrace::__vt": 0x803df1d8,
		"TNerveFruitsBoatGraphWander::__vt": 0x803df1e8,
		"TFruitsBoatManager::__vt": 0x803df1f8,
		"TFruitsBoat::__vt": 0x803df24c,
		"TWaterHitActor::__vt": 0x803df360,
		"Enemy::sChangeSaveFileName$2712": 0x803df408,
		"sChangeSaveFileName$2712": 0x803df408,
		"Enemy::entry$2725": 0x803df414,
		"entry$2725": 0x803df414,
		"TBossHanachan::__vt": 0x803df444,
		"TBossHanachanManager::__vt": 0x803df558,
		"TNerveBossHanachanDead::__vt": 0x803df5b0,
		"TNerveBossHanachanSnort::__vt": 0x803df5c0,
		"TNerveBossHanachanDamage::__vt": 0x803df5d0,
		"TNerveBossHanachanGetUp::__vt": 0x803df5e0,
		"TNerveBossHanachanDown::__vt": 0x803df5f0,
		"TNerveBossHanachanTumble::__vt": 0x803df600,
		"TNerveBossHanachanGraphWander::__vt": 0x803df610,
		"TBossHanachanPartsHead::__vt": 0x803df620,
		"TFootHitActor::__vt": 0x803df768,
		"TBossHanachanPartsBody::__vt": 0x803df80c,
		"Enemy::amiNoko_bastable": 0x803df910,
		"amiNoko_bastable": 0x803df910,
		"Enemy::entry$2820": 0x803df950,
		"entry$2820": 0x803df950,
		"TNerveAmiNokoFreeze::__vt": 0x803df968,
		"TNerveAmiNokoDie::__vt": 0x803df978,
		"TNerveAmiNokoTurn::__vt": 0x803df988,
		"TNerveAmiNokoWalkOnFence::__vt": 0x803df998,
		"TAmiNoko::__vt": 0x803df9a8,
		"TAmiHit::__vt": 0x803dfb60,
		"TAmiNokoManager::__vt": 0x803dfc04,
		"Enemy::gatekeeper_bastable": 0x803dfc60,
		"gatekeeper_bastable": 0x803dfc60,
		"TNerveBGKLaunchName::__vt": 0x803dfcb0,
		"TBGKObstacle::__vt": 0x803dfcc0,
		"TNerveBGKLaunchGoro::__vt": 0x803dfd64,
		"TNerveBGKDive::__vt": 0x803dfd74,
		"TNerveBGKDie::__vt": 0x803dfd84,
		"TNerveBGKAwakeDamage::__vt": 0x803dfd94,
		"TNerveBGKSleepDamage::__vt": 0x803dfda4,
		"TNerveBGKWait2::__vt": 0x803dfdb4,
		"TNerveBGKWait::__vt": 0x803dfdc4,
		"TNerveBGKAppear::__vt": 0x803dfdd4,
		"TNerveBGKSleep::__vt": 0x803dfde4,
		"TBiancoGateKeeper::__vt": 0x803dfdf4,
		"TBGKMtxCalc::__vt": 0x803dff08,
		"TBiancoGateKeeperManager::__vt": 0x803dff4c,
		"TGateKeeperBase::__vt": 0x803dffa4,
		"TGKHitObj::__vt": 0x803e00b8,
		"TEggGenManager::__vt": 0x803e0160,
		"TEggGenerator::__vt": 0x803e01b4,
		"TNerveSealDie::__vt": 0x803e02c8,
		"TNerveSealWait::__vt": 0x803e02d8,
		"TNerveSealSleep::__vt": 0x803e02e8,
		"TSealManager::__vt": 0x803e02f8,
		"TSeal::__vt": 0x803e034c,
		"TBGPolDrop::__vt": 0x803e0460,
		"Enemy::tstatestr": 0x803e0538,
		"tstatestr": 0x803e0538,
		"Enemy::jntidx$3428": 0x803e0564,
		"jntidx$3428": 0x803e0564,
		"TBGTentacle::__vt": 0x803e0574,
		"TBGAttackHit::__vt": 0x803e0798,
		"TBGTakeHit::__vt": 0x803e083c,
		"TBGTentacleMtxCalc::__vt": 0x803e08f0,
		"TEffectEnemy::__vt": 0x803e0948,
		"TEffectEnemyManager::__vt": 0x803e0b00,
		"Enemy::hauntleg_bastable": 0x803e0b58,
		"hauntleg_bastable": 0x803e0b58,
		"Enemy::entry$2798": 0x803e0b64,
		"entry$2798": 0x803e0b64,
		"TNerveHauntLegHaunt::__vt": 0x803e0b70,
		"THauntLeg::__vt": 0x803e0b80,
		"THauntedObject::__vt": 0x803e0d38,
		"THauntLegManager::__vt": 0x803e0ddc,
		"TAreaCylinderManager::__vt": 0x803e0e38,
		"TAreaCylinder::__vt": 0x803e0e5c,
		"TNerveWireTrapGoWait::__vt": 0x803e0e80,
		"TNerveWireTrapWait::__vt": 0x803e0ec0,
		"TNerveWireTrapSearch::__vt": 0x803e0ed0,
		"TNerveWireTrapOnewayMoveEnd::__vt": 0x803e0ee0,
		"TNerveWireTrapOnewayMove::__vt": 0x803e0ef0,
		"TNerveWireTrapOnewayMoveStart::__vt": 0x803e0f00,
		"TNerveWireTrapReturnMove::__vt": 0x803e0f10,
		"TWireTrapManager::__vt": 0x803e0f20,
		"TWireTrap::__vt": 0x803e0f74,
		"Enemy::bosshanachan_bastable": 0x803e1088,
		"bosshanachan_bastable": 0x803e1088,
		"TBossHanachanPartsBase::__vt": 0x803e1120,
		"Enemy::rocket_bastable": 0x803e1220,
		"rocket_bastable": 0x803e1220,
		"Enemy::entry$2821": 0x803e1230,
		"entry$2821": 0x803e1230,
		"TNerveRocketWait::__vt": 0x803e1248,
		"TNerveRocketFly::__vt": 0x803e1258,
		"TNerveRocketPossessedNozzle::__vt": 0x803e1268,
		"TRocket::__vt": 0x803e1278,
		"TRocketManager::__vt": 0x803e1420,
		"Enemy::Kazekun_bastable": 0x803e1478,
		"Kazekun_bastable": 0x803e1478,
		"TNerveKazekunHitWater::__vt": 0x803e148c,
		"TNerveKazekunWait::__vt": 0x803e149c,
		"TNerveKazekunDisappear::__vt": 0x803e14ac,
		"TNerveKazekunAttack::__vt": 0x803e14bc,
		"TNerveKazekunPreAttack::__vt": 0x803e14cc,
		"TNerveKazekunTurn::__vt": 0x803e14dc,
		"TNerveKazekunAppear::__vt": 0x803e14ec,
		"TNerveKazekunSearch::__vt": 0x803e14fc,
		"TKazekunManager::__vt": 0x803e150c,
		"TKazekun::__vt": 0x803e1564,
		"TBossManta::sFrameRate": 0x803e1710,
		"sFrameRate": 0x803e1710,
		"TBossManta::sScale": 0x803e1728,
		"sScale": 0x803e1728,
		"Enemy::onetimeFilenames$3261": 0x803e1740,
		"onetimeFilenames$3261": 0x803e1740,
		"Enemy::loopFilenames$3273": 0x803e1754,
		"loopFilenames$3273": 0x803e1754,
		"TBossMantaManager::__vt": 0x803e177c,
		"TBossMantaAdditionalCollision::__vt": 0x803e17d0,
		"TBossManta::__vt": 0x803e1874,
		"TNerveMantaAppearDemo::__vt": 0x803e1988,
		"TNerveMantaDeath::__vt": 0x803e1998,
		"TNerveMantaSpawn::__vt": 0x803e19a8,
		"TNerveMantaHitWater::__vt": 0x803e19b8,
		"TNerveMantaMove::__vt": 0x803e19c8,
		"TWireBinder::__vt": 0x803e19d8,
		"TNerveYumboFreeze::__vt": 0x803e1a1c,
		"TNerveYumboAttack::__vt": 0x803e1a2c,
		"TNerveYumboAppearing::__vt": 0x803e1a3c,
		"TNerveYumboHiding::__vt": 0x803e1a4c,
		"TNerveYumboDancing::__vt": 0x803e1a5c,
		"TYumbo::__vt": 0x803e1a6c,
		"TYumboManager::__vt": 0x803e1c14,
		"TYumboSeed::__vt": 0x803e1c6c,
		"Enemy::TKoopaJr_jointNameTable": 0x803e1d28,
		"TKoopaJr_jointNameTable": 0x803e1d28,
		"TKoopaJrSubmarineManager::__vt": 0x803e1d3c,
		"TNerveKoopaJrSubmarineLaunchKiller::__vt": 0x803e1d90,
		"TNerveKoopaJrSubmarineCannonOpenClose::__vt": 0x803e1da0,
		"TNerveKoopaJrSubmarineWait::__vt": 0x803e1db0,
		"TKoopaJrSubmarine::__vt": 0x803e1dc0,
		"TKoopaJrManager::__vt": 0x803e1ed4,
		"TNerveKoopaJrYahoo::__vt": 0x803e1f28,
		"TNerveKoopaJrLaunch::__vt": 0x803e1f38,
		"TNerveKoopaJrDemo::__vt": 0x803e1f48,
		"TNerveKoopaJrDamage::__vt": 0x803e1f58,
		"TNerveKoopaJrWait::__vt": 0x803e1f68,
		"TKoopaJr::__vt": 0x803e1f78,
		"TCallbackHitActor::__vt": 0x803e208c,
		"Enemy::kumokun_bastable": 0x803e2130,
		"kumokun_bastable": 0x803e2130,
		"Enemy::kumokun_bas_c_table": 0x803e2164,
		"kumokun_bas_c_table": 0x803e2164,
		"TNerveKumokunPreFly::__vt": 0x803e2198,
		"TSolidStack<char_const*>::__vt": 0x803e21a8,
		"TNerveKumokunFly::__vt": 0x803e21b4,
		"TNerveKumokunPostFreeze::__vt": 0x803e21c4,
		"TNerveKumokunFreeze::__vt": 0x803e21d4,
		"TNerveKumokunWait::__vt": 0x803e21e4,
		"TNerveKumokunSearch::__vt": 0x803e21f4,
		"TNerveKumokunPostWalk::__vt": 0x803e2204,
		"TNerveKumokunWalk::__vt": 0x803e2214,
		"TNerveKumokunPreWalk::__vt": 0x803e2224,
		"TKumokunManager::__vt": 0x803e2234,
		"TKumokun::__vt": 0x803e228c,
		"Enemy::koopa_bastable": 0x803e2438,
		"koopa_bastable": 0x803e2438,
		"TKoopaManager::__vt": 0x803e2474,
		"TNerveKoopaTurnR::__vt": 0x803e2504,
		"TNerveKoopaTurnL::__vt": 0x803e2514,
		"TNerveKoopaTurn::__vt": 0x803e2524,
		"TKoopa::__vt": 0x803e2534,
		"TKoopaBody::__vt": 0x803e2648,
		"TKoopaHead::__vt": 0x803e26f4,
		"TKoopaHand::__vt": 0x803e27a0,
		"TKoopaFlame::__vt": 0x803e284c,
		"TKoopaParts::__vt": 0x803e28f8,
		"TNerveKoopaGetDown::__vt": 0x803e29a4,
		"TNerveKoopaGetShowered::__vt": 0x803e29b4,
		"TNerveKoopaStagger::__vt": 0x803e29c4,
		"TNerveKoopaProvoke::__vt": 0x803e29d4,
		"TNerveKoopaFlame::__vt": 0x803e29e4,
		"TNerveKoopaFall::__vt": 0x803e29f4,
		"TNerveKoopaTumble::__vt": 0x803e2a04,
		"TNerveKoopaWait::__vt": 0x803e2a14,
		"Enemy::tori_bastable": 0x803e2a28,
		"tori_bastable": 0x803e2a28,
		"TNerveKukkuRecoverGraph::__vt": 0x803e2a40,
		"TNerveKukkuPostFall::__vt": 0x803e2a50,
		"TNerveKukkuFall::__vt": 0x803e2a60,
		"TNerveKukkuGraphWander::__vt": 0x803e2a70,
		"TKukku::__vt": 0x803e2a80,
		"TKukkuManager::__vt": 0x803e2c28,
		"TKukkuBall::__vt": 0x803e2c80,
		"Enemy::amenbo_bastable": 0x803e2d28,
		"amenbo_bastable": 0x803e2d28,
		"TNerveAmenboHitWater::__vt": 0x803e2d44,
		"TNerveAmenboWalk::__vt": 0x803e2d54,
		"TNerveAmenboPreAttack::__vt": 0x803e2d64,
		"TNerveAmenboTurn::__vt": 0x803e2d74,
		"TNerveAmenboSearch::__vt": 0x803e2d84,
		"TAmenbo::__vt": 0x803e2d94,
		"TAmenboManager::__vt": 0x803e2f3c,
		"Enemy::bathtubpeach_bastable": 0x803e2f98,
		"bathtubpeach_bastable": 0x803e2f98,
		"TBathtubPeachManager::__vt": 0x803e2ff4,
		"TNervePeachEscape::__vt": 0x803e3048,
		"TNervePeachStagger::__vt": 0x803e3058,
		"TBathtubPeach::__vt": 0x803e3068,
		"Enemy::bathtubkiller_bastable": 0x803e3180,
		"bathtubkiller_bastable": 0x803e3180,
		"Enemy::entry$3235": 0x803e318c,
		"entry$3235": 0x803e318c,
		"TBathtubKillerManager::__vt": 0x803e31b0,
		"TNerveBathtubKillerExplosion::__vt": 0x803e3208,
		"TNerveBathtubKillerBreak::__vt": 0x803e3218,
		"TNerveBathtubKillerStraight::__vt": 0x803e3228,
		"TNerveBathtubKillerChaseStraight::__vt": 0x803e3238,
		"TNerveBathtubKillerChase::__vt": 0x803e3248,
		"TNerveBathtubKillerWander::__vt": 0x803e3258,
		"TBathtubKiller::__vt": 0x803e3268,
		"Enemy::entry$2930": 0x803e3424,
		"entry$2930": 0x803e3424,
		"TCoasterKillerManager::__vt": 0x803e3448,
		"TNerveCoasterKillerExplosion::__vt": 0x803e34a0,
		"TCoasterKiller::__vt": 0x803e34b0,
		"TNerveCoasterEnemyWander::__vt": 0x803e3674,
		"TCoasterEnemy::__vt": 0x803e3684,
		"TNerveDebuTelesaWait::__vt": 0x803e3848,
		"TDebuTelesaManager::__vt": 0x803e3858,
		"TDebuTelesa::__vt": 0x803e38b0,
		"Enemy::tabepuku_bastable": 0x803e3a58,
		"tabepuku_bastable": 0x803e3a58,
		"TNerveTabePukuDrag::__vt": 0x803e3a64,
		"TNerveTabePukuDive::__vt": 0x803e3a74,
		"TNerveTabePukuBite::__vt": 0x803e3a84,
		"TNerveTabePukuAttack::__vt": 0x803e3a94,
		"TNerveTabePukuRecoverGraph::__vt": 0x803e3aa4,
		"TNerveTabePukuFound::__vt": 0x803e3ab4,
		"TNerveTabePukuGraphWander::__vt": 0x803e3ac4,
		"TTabePukuManager::__vt": 0x803e3ad4,
		"TTabePuku::__vt": 0x803e3b2c,
		"TTPHitActor::__vt": 0x803e3cd4,
		"TBathtubBinder::__vt": 0x803e3d80,
		"TLimitKoopaManager::__vt": 0x803e3d90,
		"TNerveLimitKoopaTurn::__vt": 0x803e3de4,
		"TLimitKoopa::__vt": 0x803e3df4,
		"TLimitKoopaBody::__vt": 0x803e3f08,
		"TLimitKoopaHead::__vt": 0x803e4008,
		"TLimitKoopaHand::__vt": 0x803e4108,
		"TLimitKoopaFlame::__vt": 0x803e4208,
		"TLimitKoopaParts::__vt": 0x803e4308,
		"TNerveLimitKoopaGetDown::__vt": 0x803e4408,
		"TNerveLimitKoopaGetShowered::__vt": 0x803e4418,
		"TNerveLimitKoopaStagger::__vt": 0x803e4428,
		"TNerveLimitKoopaTumble::__vt": 0x803e4438,
		"TNerveLimitKoopaWait::__vt": 0x803e4448,
		"TNerveLimitKoopaHipDropStart::__vt": 0x803e4458,
		"TNerveLimitKoopaHipDropJump::__vt": 0x803e4468,
		"TLimitKoopaJrManager::__vt": 0x803e4488,
		"TNerveLimitKoopaJrYahoo::__vt": 0x803e44dc,
		"TNerveLimitKoopaJrLaunch::__vt": 0x803e44ec,
		"TNerveLimitKoopaJrWait::__vt": 0x803e44fc,
		"TNerveLimitKoopaJrRun::__vt": 0x803e450c,
		"TLimitKoopaJr::__vt": 0x803e451c,
		"Camera::@3698": 0x803e4630,
		"Camera::@3874": 0x803e46fc,
		"CPolarSubCamera::__vt": 0x803e4820,
		"Camera::@1790": 0x803e4a00,
		"Camera::sNoticeActorManagerName": 0x803e4ae8,
		"sNoticeActorManagerName": 0x803e4ae8,
		"CPolarSubCamera::sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803e4af8,
		"sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803e4af8,
		"TLensFlare::__vt": 0x803e4b10,
		"TLensGlow::__vt": 0x803e4b38,
		"TSunMgr::__vt": 0x803e4b60,
		"TSunModel::__vt": 0x803e4b98,
		"TCubeManagerBase::__vt": 0x803e4c38,
		"TCameraMapTool::__vt": 0x803e4c60,
		"TCubeStreamInfo::__vt": 0x803e4c80,
		"TCubeCameraInfo::__vt": 0x803e4ca0,
		"TCubeGeneralInfo::__vt": 0x803e4cc0,
		"Camera::sAddBckFileNameTable": 0x803e4ce0,
		"sAddBckFileNameTable": 0x803e4ce0,
		"CPolarSubCamera::mCamKindNameSaveFile": 0x803e4cf0,
		"mCamKindNameSaveFile": 0x803e4cf0,
		"Camera::@1781": 0x803e4e14,
		"TCameraShake::mCamShakeNameSave": 0x803e5288,
		"mCamShakeNameSave": 0x803e5288,
		"TBoidLeader::__vt": 0x803e5330,
		"TFishoidManager::__vt": 0x803e5358,
		"TFishoid::__vt": 0x803e53ac,
		"TFish::__vt": 0x803e54c4,
		"TRealoid::__vt": 0x803e557c,
		"TRealoidActor::__vt": 0x803e5694,
		"TAnimalBase::__vt": 0x803e5750,
		"TMewManager::__vt": 0x803e5868,
		"TAnimalManagerBase::__vt": 0x803e58bc,
		"TNerveAnimalGraphWander::__vt": 0x803e5910,
		"Animal::bird_bastable": 0x803e5920,
		"bird_bastable": 0x803e5920,
		"TNerveAnimalBirdLanding::__vt": 0x803e5944,
		"TNerveAnimalBirdPreLanding::__vt": 0x803e5954,
		"TNerveAnimalBirdComeback::__vt": 0x803e5964,
		"TNerveAnimalBirdChangeToCoin::__vt": 0x803e5974,
		"TNerveAnimalBirdGraphWander::__vt": 0x803e5984,
		"TNerveAnimalBirdTakeoff::__vt": 0x803e5994,
		"TNerveAnimalBirdWalkOnGround::__vt": 0x803e59a4,
		"TNerveAnimalBirdActionOnGround::__vt": 0x803e59b4,
		"TNerveAnimalBirdWaitOnGround::__vt": 0x803e59c4,
		"TAnimalBirdManager::__vt": 0x803e59d4,
		"TAnimalBird::__vt": 0x803e5a28,
		"TNerveBeeHiveReset::__vt": 0x803e5b40,
		"TNerveBeeHiveMarioWaterIn::__vt": 0x803e5b50,
		"TNerveBeeHiveAttack::__vt": 0x803e5b60,
		"TNerveBeeHiveBreak::__vt": 0x803e5b70,
		"TNerveBeeHiveFall::__vt": 0x803e5b80,
		"TNerveBeeHiveWait::__vt": 0x803e5b90,
		"TBeeHiveManager::__vt": 0x803e5ba0,
		"TBeeHive::__vt": 0x803e5bf4,
		"TBee::__vt": 0x803e5d0c,
		"TButterfloidManager::__vt": 0x803e5dc8,
		"TButterfloid::__vt": 0x803e5e1c,
		"TButterfly::__vt": 0x803e5f34,
		"main::gpApplication": 0x803e6000,
		"gpApplication": 0x803e6000,
		"JSystem::@25": 0x803e6090,
		"JSystem::exCallbackObject": 0x803e60a0,
		"exCallbackObject": 0x803e60a0,
		"JSystem::@301": 0x803e60c0,
		"JUTAssertion::@unnamed@::sMessageFileLine": 0x803e6100,
		"sMessageFileLine": 0x803e6100,
		"JUTAssertion::@unnamed@::sMessageString": 0x803e6140,
		"sMessageString": 0x803e6140,
		"JSystem::@1661": 0x803e61a0,
		"JSystem::@1662": 0x803e61ac,
		"JSystem::@1663": 0x803e61b8,
		"JSystem::@1664": 0x803e61c4,
		"JSystem::@1665": 0x803e61d0,
		"JSystem::@1666": 0x803e61dc,
		"JSystem::@1667": 0x803e61e8,
		"JSystem::@1668": 0x803e61f4,
		"JAInter::StreamLib::finfo": 0x803e6230,
		"finfo": 0x803e6230,
		"JAInter::StreamLib::header": 0x803e626c,
		"header": 0x803e626c,
		"JAInter::StreamLib::Filename": 0x803e628c,
		"Filename": 0x803e628c,
		"JSystem::@557": 0x803e6300,
		"@557": 0x803e6300,
		"JSystem::osc$294": 0x803e6310,
		"osc$294": 0x803e6310,
		"JSystem::@257": 0x803e6328,
		"@257": 0x803e6328,
		"JASystem::WaveArcLoader::sAramHeap": 0x803e6334,
		"sAramHeap": 0x803e6334,
		"JASystem::AudioThread::audioproc_mq": 0x803e6360,
		"audioproc_mq": 0x803e6360,
		"JASystem::AudioThread::msgbuf": 0x803e6380,
		"msgbuf": 0x803e6380,
		"JASystem::DSPBuf::dsp_buf": 0x803e63c0,
		"dsp_buf": 0x803e63c0,
		"JASystem::Kernel::dac": 0x803e63d0,
		"dac": 0x803e63d0,
		"JASystem::Dvd::mq": 0x803e63e0,
		"mq": 0x803e63e0,
		"JSystem::finfo$314": 0x803e6400,
		"finfo$314": 0x803e6400,
		"JSystem::req$315": 0x803e643c,
		"req$315": 0x803e643c,
		"JSystem::finfo$361": 0x803e64bc,
		"finfo$361": 0x803e64bc,
		"JSystem::req$362": 0x803e64f8,
		"req$362": 0x803e64f8,
		"JSystem::finfo$369": 0x803e6518,
		"finfo$369": 0x803e6518,
		"JSystem::req$370": 0x803e6554,
		"req$370": 0x803e6554,
		"JSystem::finfo$393": 0x803e6574,
		"finfo$393": 0x803e6574,
		"JSystem::finfo$422": 0x803e65b0,
		"finfo$422": 0x803e65b0,
		"JSystem::finfo$426": 0x803e65ec,
		"finfo$426": 0x803e65ec,
		"JASystem::HardStream::strCtrl": 0x803e6634,
		"strCtrl": 0x803e6634,
		"JSystem::finfo$425": 0x803e6684,
		"finfo$425": 0x803e6684,
		"JSystem::get_addr_cmd$429": 0x803e6738,
		"get_addr_cmd$429": 0x803e6738,
		"JSystem::stop_cmd$430": 0x803e6a38,
		"stop_cmd$430": 0x803e6a38,
		"JSystem::finish_cmd$431": 0x803e6a68,
		"finish_cmd$431": 0x803e6a68,
		"JSystem::@241": 0x803e6a98,
		"JASystem::Kernel::audioAramHeap": 0x803e6aa4,
		"audioAramHeap": 0x803e6aa4,
		"JASystem::Player::oRandom": 0x803e6ab8,
		"oRandom": 0x803e6ab8,
		"JASystem::TrackMgr::sTrackList": 0x803e6b40,
		"sTrackList": 0x803e6b40,
		"JSystem::JPAEmitterInfoObj": 0x803e6c40,
		"JPAEmitterInfoObj": 0x803e6c40,
		"JSystem::@1657": 0x803e6dc0,
		"JSystem::@1658": 0x803e6dcc,
		"JSystem::taskwork": 0x803e8e40,
		"taskwork": 0x803e8e40,
		"JSystem::sync_stack": 0x803e8ec0,
		"sync_stack": 0x803e8ec0,
		"Runtime.PPCEABI.H::fragmentinfo": 0x803e8ed0,
		"fragmentinfo": 0x803e8ed0,
		"MSL_C.PPCEABI.bare.H::atexit_funcs": 0x803e8ee0,
		"atexit_funcs": 0x803e8ee0,
		"MSL_C.PPCEABI.bare.H::__atexit_funcs": 0x803e8fe0,
		"__atexit_funcs": 0x803e8fe0,
		"TRK_MINNOW_DOLPHIN::gTRKEventQueue": 0x803e90e0,
		"gTRKEventQueue": 0x803e90e0,
		"TRK_MINNOW_DOLPHIN::gTRKBigEndian": 0x803e9108,
		"gTRKBigEndian": 0x803e9108,
		"TRK_MINNOW_DOLPHIN::gTRKMsgBufs": 0x803e9110,
		"gTRKMsgBufs": 0x803e9110,
		"TRK_MINNOW_DOLPHIN::gTRKFramingState": 0x803eaac0,
		"gTRKFramingState": 0x803eaac0,
		"TRK_MINNOW_DOLPHIN::gTRKInputPendingPtr": 0x803eaad4,
		"gTRKInputPendingPtr": 0x803eaad4,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTableSize": 0x803eaad8,
		"gTRKDispatchTableSize": 0x803eaad8,
		"TRK_MINNOW_DOLPHIN::gTRKSaveState": 0x803eaae4,
		"gTRKSaveState": 0x803eaae4,
		"TRK_MINNOW_DOLPHIN::TRKvalue128_temp": 0x803eab78,
		"TRKvalue128_temp": 0x803eab78,
		"TRK_MINNOW_DOLPHIN::gTRKState": 0x803eab88,
		"gTRKState": 0x803eab88,
		"TRK_MINNOW_DOLPHIN::lc_base": 0x803eb060,
		"lc_base": 0x803eb060,
		"TRK_MINNOW_DOLPHIN::TRK_mainError": 0x803eb068,
		"TRK_mainError": 0x803eb068,
		"os::DriveBlock": 0x803eb0a0,
		"DriveBlock": 0x803eb0a0,
		"os::__OSErrorTable": 0x803eb0d0,
		"__OSErrorTable": 0x803eb0d0,
		"os::RunQueue": 0x803eb198,
		"RunQueue": 0x803eb198,
		"dvd::CommandList": 0x803ebb80,
		"CommandList": 0x803ebb80,
		"dvd::Prev": 0x803ebc38,
		"Prev": 0x803ebc38,
		"dvd::Curr": 0x803ebc44,
		"Curr": 0x803ebc44,
		"dvd::DummyCommandBlock": 0x803ebce0,
		"DummyCommandBlock": 0x803ebce0,
		"dvd::WaitingQueue": 0x803ebd38,
		"WaitingQueue": 0x803ebd38,
		"dvd::bb2Buf": 0x803ebd58,
		"bb2Buf": 0x803ebd58,
		"dvd::block$16": 0x803ebd98,
		"block$16": 0x803ebd98,
		"vi::regs": 0x803ebdc8,
		"regs": 0x803ebdc8,
		"vi::shdwRegs": 0x803ebe40,
		"shdwRegs": 0x803ebe40,
		"vi::HorVer": 0x803ebeb8,
		"HorVer": 0x803ebeb8,
		"pad::Type": 0x803ebf10,
		"pad::Origin": 0x803ebf20,
		"Origin": 0x803ebf20,
		"pad::CmdProbeDevice": 0x803ebf50,
		"CmdProbeDevice": 0x803ebf50,
		"card::__CARDDiskNone": 0x803ec180,
		"__CARDDiskNone": 0x803ec180,
		"gx::gxData": 0x803ec1a0,
		"gxData": 0x803ec1a0,
		"gx::FifoObj": 0x803ec698,
		"FifoObj": 0x803ec698,
		"gx::vcd": 0x803ec718,
		"vcd": 0x803ec718,
		"gx::vat": 0x803ec7f0,
		"vat": 0x803ec7f0,
		"si::TypeCallback": 0x803ecb00,
		"TypeCallback": 0x803ecb00,
		"si::RDSTHandler": 0x803ecb40,
		"RDSTHandler": 0x803ecb40,
		"si::InputBufferValid": 0x803ecb50,
		"InputBufferValid": 0x803ecb50,
		"si::InputBuffer": 0x803ecb60,
		"InputBuffer": 0x803ecb60,
		"si::InputBufferVcount": 0x803ecb80,
		"InputBufferVcount": 0x803ecb80,
		"si::cmdFixDevice$326": 0x803ecb90,
		"cmdFixDevice$326": 0x803ecb90,
		"exi::Ecb": 0x803ecba0,
		"Ecb": 0x803ecba0,
		"thp::__THPLCWork512": 0x803ecd60,
		"__THPLCWork512": 0x803ecd60,
		"thp::__THPLCWork640": 0x803ecd6c,
		"__THPLCWork640": 0x803ecd6c,
		"thp::__THPMCUBuffer": 0x803ecd78,
		"__THPMCUBuffer": 0x803ecd78,
		"THPPlayer::AudioDecodeThreadStack": 0x803ed0a0,
		"AudioDecodeThreadStack": 0x803ed0a0,
		"THPPlayer::FreeAudioBufferQueue": 0x803ee0a0,
		"FreeAudioBufferQueue": 0x803ee0a0,
		"THPPlayer::DecodedAudioBufferQueue": 0x803ee0c0,
		"DecodedAudioBufferQueue": 0x803ee0c0,
		"THPPlayer::FreeAudioBufferMessage": 0x803ee0e0,
		"FreeAudioBufferMessage": 0x803ee0e0,
		"THPPlayer::DecodedAudioBufferMessage": 0x803ee0ec,
		"DecodedAudioBufferMessage": 0x803ee0ec,
		"THPPlayer::PrepareReadyQueue": 0x803ee320,
		"PrepareReadyQueue": 0x803ee320,
		"THPPlayer::UsedTextureSetQueue": 0x803ee340,
		"UsedTextureSetQueue": 0x803ee340,
		"THPPlayer::UsedTextureSetMessage": 0x803ee360,
		"UsedTextureSetMessage": 0x803ee360,
		"THPPlayer::FreeReadBufferQueue": 0x803ef500,
		"FreeReadBufferQueue": 0x803ef500,
		"THPPlayer::ReadedBufferQueue": 0x803ef520,
		"ReadedBufferQueue": 0x803ef520,
		"THPPlayer::ReadedBufferQueue2": 0x803ef540,
		"ReadedBufferQueue2": 0x803ef540,
		"THPPlayer::FreeReadBufferMessage": 0x803ef560,
		"FreeReadBufferMessage": 0x803ef560,
		"THPPlayer::ReadedBufferMessage": 0x803ef588,
		"ReadedBufferMessage": 0x803ef588,
		"THPPlayer::ReadedBufferMessage2": 0x803ef5b0,
		"ReadedBufferMessage2": 0x803ef5b0,
		"THPPlayer::ReadThreadStack": 0x803ef8e8,
		"ReadThreadStack": 0x803ef8e8,
		"THPPlayer::VideoDecodeThreadStack": 0x803f0bf8,
		"VideoDecodeThreadStack": 0x803f0bf8,
		"THPPlayer::FreeTextureSetQueue": 0x803f1bf8,
		"FreeTextureSetQueue": 0x803f1bf8,
		"THPPlayer::DecodedTextureSetQueue": 0x803f1c18,
		"DecodedTextureSetQueue": 0x803f1c18,
		"THPPlayer::FreeTextureSetMessage": 0x803f1c38,
		"FreeTextureSetMessage": 0x803f1c38,
		"THPPlayer::DecodedTextureSetMessage": 0x803f1c44,
		"DecodedTextureSetMessage": 0x803f1c44,
		"MarioUtil::sViewPlane": 0x803f1c50,
		"sViewPlane": 0x803f1c50,
		"MarioUtil::@2174": 0x803f1cb0,
		"MarioUtil::setup1$2173": 0x803f1cbc,
		"setup1$2173": 0x803f1cbc,
		"MarioUtil::@2178": 0x803f1ce0,
		"MarioUtil::cylinder$2177": 0x803f1cec,
		"cylinder$2177": 0x803f1cec,
		"MarioUtil::@2192": 0x803f1d10,
		"MarioUtil::setup2$2191": 0x803f1d1c,
		"setup2$2191": 0x803f1d1c,
		"MarioUtil::@2197": 0x803f1d40,
		"MarioUtil::setup3$2196": 0x803f1d4c,
		"setup3$2196": 0x803f1d4c,
		"MarioUtil::@2209": 0x803f1d70,
		"MarioUtil::setup4$2208": 0x803f1d7c,
		"setup4$2208": 0x803f1d7c,
		"MarioUtil::@2218": 0x803f1da0,
		"MarioUtil::setup5$2217": 0x803f1dac,
		"setup5$2217": 0x803f1dac,
		"System::@7636": 0x803f1dd0,
		"System::@7637": 0x803f1ddc,
		"System::@7638": 0x803f1de8,
		"System::@7639": 0x803f1df4,
		"System::@7640": 0x803f1e00,
		"System::@7641": 0x803f1e0c,
		"System::@7642": 0x803f1e18,
		"System::@7643": 0x803f1e24,
		"System::@7644": 0x803f1e30,
		"System::@7645": 0x803f1e3c,
		"System::@7646": 0x803f1e48,
		"System::@7647": 0x803f1e54,
		"System::@7648": 0x803f1e60,
		"System::@7649": 0x803f1e6c,
		"System::@7650": 0x803f1e78,
		"System::@2705": 0x803f1e88,
		"System::@2706": 0x803f1e94,
		"System::@2707": 0x803f1ea0,
		"System::@2708": 0x803f1eac,
		"System::@2709": 0x803f1eb8,
		"System::@2710": 0x803f1ec4,
		"System::@2711": 0x803f1ed0,
		"System::@2712": 0x803f1edc,
		"System::@2713": 0x803f1ee8,
		"System::@2714": 0x803f1ef4,
		"System::@2715": 0x803f1f00,
		"System::@2716": 0x803f1f0c,
		"System::@2717": 0x803f1f18,
		"System::@2718": 0x803f1f24,
		"System::@2719": 0x803f1f30,
		"System::@2272": 0x803f1f64,
		"System::@2273": 0x803f1f70,
		"System::@2274": 0x803f1f7c,
		"System::@2275": 0x803f1f88,
		"System::@2276": 0x803f1f94,
		"System::@2277": 0x803f1fa0,
		"System::@2278": 0x803f1fac,
		"System::@2279": 0x803f1fb8,
		"System::@2280": 0x803f1fc4,
		"System::@2281": 0x803f1fd0,
		"System::@2282": 0x803f1fdc,
		"System::@2283": 0x803f1fe8,
		"System::@2764": 0x803f20b0,
		"System::@2765": 0x803f20bc,
		"System::@2766": 0x803f20c8,
		"System::@2767": 0x803f20d4,
		"System::@2768": 0x803f20e0,
		"System::@2769": 0x803f20ec,
		"System::@2770": 0x803f20f8,
		"System::@2771": 0x803f2104,
		"System::@2772": 0x803f2110,
		"System::@2773": 0x803f211c,
		"System::@2774": 0x803f2128,
		"System::@2775": 0x803f2134,
		"System::@2776": 0x803f2140,
		"System::@2777": 0x803f214c,
		"System::@2778": 0x803f2158,
		"System::@3428": 0x803f2168,
		"System::@3431": 0x803f218c,
		"System::@3434": 0x803f21b0,
		"System::@3435": 0x803f21bc,
		"System::@3436": 0x803f21c8,
		"System::@3437": 0x803f21d4,
		"System::@3438": 0x803f21e0,
		"System::@3439": 0x803f21ec,
		"System::@3440": 0x803f21f8,
		"System::@3442": 0x803f2210,
		"System::@6138": 0x803f2220,
		"System::@6139": 0x803f222c,
		"System::@6140": 0x803f2238,
		"System::@6141": 0x803f2244,
		"@6141": 0x803f2244,
		"System::@6142": 0x803f2250,
		"@6142": 0x803f2250,
		"System::@6143": 0x803f225c,
		"@6143": 0x803f225c,
		"System::@6144": 0x803f2268,
		"@6144": 0x803f2268,
		"System::@6145": 0x803f2274,
		"@6145": 0x803f2274,
		"System::@6146": 0x803f2280,
		"@6146": 0x803f2280,
		"System::@6147": 0x803f228c,
		"System::@6148": 0x803f2298,
		"System::@6149": 0x803f22a4,
		"System::@6150": 0x803f22b0,
		"System::@6151": 0x803f22bc,
		"System::@6152": 0x803f22c8,
		"System::gParticleFlagLoaded": 0x803f2810,
		"gParticleFlagLoaded": 0x803f2810,
		"System::@2634": 0x803f2a14,
		"System::@2635": 0x803f2a20,
		"System::@2636": 0x803f2a2c,
		"System::@2637": 0x803f2a38,
		"System::@2638": 0x803f2a44,
		"System::@2639": 0x803f2a50,
		"System::@2640": 0x803f2a5c,
		"System::@2643": 0x803f2a80,
		"System::@2644": 0x803f2a8c,
		"System::@2645": 0x803f2a98,
		"System::@2646": 0x803f2aa4,
		"System::@2647": 0x803f2ab0,
		"System::@2648": 0x803f2abc,
		"System::@2913": 0x803f2ac8,
		"System::@2914": 0x803f2ad4,
		"System::@2915": 0x803f2ae0,
		"System::@2916": 0x803f2aec,
		"System::@2917": 0x803f2af8,
		"System::@2918": 0x803f2b04,
		"System::@2919": 0x803f2b10,
		"System::@2920": 0x803f2b1c,
		"System::@2921": 0x803f2b28,
		"System::@2922": 0x803f2b34,
		"System::@2923": 0x803f2b40,
		"System::@2924": 0x803f2b4c,
		"System::@2925": 0x803f2b58,
		"System::@2926": 0x803f2b64,
		"System::@2927": 0x803f2b70,
		"Strategic::@3355": 0x803f2cf0,
		"Strategic::@3356": 0x803f2cfc,
		"Strategic::@3357": 0x803f2d08,
		"Strategic::@3358": 0x803f2d14,
		"Strategic::@3359": 0x803f2d20,
		"Strategic::@3364": 0x803f2d5c,
		"Strategic::@3365": 0x803f2d68,
		"Strategic::@3366": 0x803f2d74,
		"Strategic::@3367": 0x803f2d80,
		"Strategic::@3368": 0x803f2d8c,
		"Strategic::@3369": 0x803f2d98,
		"Strategic::@2737": 0x803f2e14,
		"Strategic::@2738": 0x803f2e20,
		"Strategic::@2739": 0x803f2e2c,
		"Strategic::@2740": 0x803f2e38,
		"Strategic::@2741": 0x803f2e44,
		"Strategic::@2742": 0x803f2e50,
		"Player::@2108": 0x803f2e70,
		"Player::@2109": 0x803f2e7c,
		"Player::@2112": 0x803f2ea0,
		"Player::@2113": 0x803f2eac,
		"Player::@2114": 0x803f2eb8,
		"Player::@2115": 0x803f2ec4,
		"Player::@2116": 0x803f2ed0,
		"Player::@2117": 0x803f2edc,
		"Player::@2118": 0x803f2ee8,
		"Player::@2119": 0x803f2ef4,
		"Player::@2120": 0x803f2f00,
		"Player::@2121": 0x803f2f0c,
		"Player::@2122": 0x803f2f18,
		"Player::@2524": 0x803f2fe0,
		"Player::@2525": 0x803f2fec,
		"Player::@2526": 0x803f2ff8,
		"Player::@2527": 0x803f3004,
		"Player::@2528": 0x803f3010,
		"Player::@2536": 0x803f3070,
		"Player::@2537": 0x803f307c,
		"Player::@2538": 0x803f3088,
		"Player::@3120": 0x803f3150,
		"Player::@3121": 0x803f315c,
		"Player::@3122": 0x803f3168,
		"Player::@3123": 0x803f3174,
		"Player::@3126": 0x803f3198,
		"Player::@3127": 0x803f31a4,
		"Player::@3128": 0x803f31b0,
		"Player::@3129": 0x803f31bc,
		"Player::@2772": 0x803f3214,
		"Player::@2773": 0x803f3220,
		"Player::@2774": 0x803f322c,
		"Player::@2775": 0x803f3238,
		"Player::@2776": 0x803f3244,
		"Player::@2777": 0x803f3250,
		"Player::@2778": 0x803f325c,
		"Player::@2779": 0x803f3268,
		"Player::@2780": 0x803f3274,
		"Player::@2790": 0x803f3380,
		"Player::@2791": 0x803f338c,
		"Player::@2792": 0x803f3398,
		"Player::@2793": 0x803f33a4,
		"Player::@3455": 0x803f3450,
		"Player::@3227": 0x803f358c,
		"Player::@3228": 0x803f3598,
		"Player::scale$2692": 0x803f3660,
		"scale$2692": 0x803f3660,
		"Player::scale$2743": 0x803f366c,
		"scale$2743": 0x803f366c,
		"Player::@3608": 0x803f3678,
		"Player::@2167": 0x803f3830,
		"Player::@2168": 0x803f383c,
		"Player::@2169": 0x803f3848,
		"Player::@2170": 0x803f3854,
		"Player::@2171": 0x803f3860,
		"Player::@2173": 0x803f3878,
		"Player::@2174": 0x803f3884,
		"Player::@2175": 0x803f3890,
		"Player::@5981": 0x803f3958,
		"Player::@5982": 0x803f3964,
		"Player::@5983": 0x803f3970,
		"Player::@5984": 0x803f397c,
		"Player::@5985": 0x803f3988,
		"Player::@5986": 0x803f3994,
		"Player::@5987": 0x803f39a0,
		"Player::@5988": 0x803f39ac,
		"Player::@5989": 0x803f39b8,
		"Player::@5990": 0x803f39c4,
		"Player::@5991": 0x803f39d0,
		"Player::@5992": 0x803f39dc,
		"Player::@5993": 0x803f39e8,
		"Player::@5994": 0x803f39f4,
		"Player::@5995": 0x803f3a00,
		"Player::@3165": 0x803f3a10,
		"Player::@3167": 0x803f3a28,
		"Player::@3169": 0x803f3a40,
		"Player::@3171": 0x803f3a58,
		"Player::@6586": 0x803f3c44,
		"@6586": 0x803f3c44,
		"Player::@6587": 0x803f3c50,
		"@6587": 0x803f3c50,
		"Player::@6588": 0x803f3c5c,
		"@6588": 0x803f3c5c,
		"Player::@6589": 0x803f3c68,
		"Player::@6590": 0x803f3c74,
		"@6590": 0x803f3c74,
		"Player::@6591": 0x803f3c80,
		"@6591": 0x803f3c80,
		"Player::@6592": 0x803f3c8c,
		"@6592": 0x803f3c8c,
		"Player::@6593": 0x803f3c98,
		"@6593": 0x803f3c98,
		"Player::@6594": 0x803f3ca4,
		"@6594": 0x803f3ca4,
		"Player::@6595": 0x803f3cb0,
		"@6595": 0x803f3cb0,
		"Player::@6596": 0x803f3cbc,
		"@6596": 0x803f3cbc,
		"Player::@6597": 0x803f3cc8,
		"@6597": 0x803f3cc8,
		"Player::@6598": 0x803f3cd4,
		"@6598": 0x803f3cd4,
		"Player::@6599": 0x803f3ce0,
		"@6599": 0x803f3ce0,
		"Player::@6600": 0x803f3cec,
		"@6600": 0x803f3cec,
		"Player::@2664": 0x803f3cf8,
		"TModelWaterManager::mStaticHitActor": 0x803f3d04,
		"mStaticHitActor": 0x803f3d04,
		"Player::wcheck$2854": 0x803f3d70,
		"wcheck$2854": 0x803f3d70,
		"Player::@4749": 0x803f3d9c,
		"Player::@4750": 0x803f3da8,
		"Player::@4751": 0x803f3db4,
		"Player::@4752": 0x803f3dc0,
		"Player::@4753": 0x803f3dcc,
		"Player::@4754": 0x803f3dd8,
		"Player::@4755": 0x803f3de4,
		"Player::@4756": 0x803f3df0,
		"Player::@4757": 0x803f3dfc,
		"Player::@4758": 0x803f3e08,
		"Player::@4759": 0x803f3e14,
		"Player::@4760": 0x803f3e20,
		"Player::@4761": 0x803f3e2c,
		"Player::@4762": 0x803f3e38,
		"Player::@4763": 0x803f3e44,
		"Player::@3263": 0x803f3f50,
		"Player::@3264": 0x803f3f5c,
		"Player::@3265": 0x803f3f68,
		"Player::@3266": 0x803f3f74,
		"NPC::@2936": 0x803f4078,
		"NPC::@2937": 0x803f4084,
		"NPC::@2938": 0x803f4090,
		"NPC::@2939": 0x803f409c,
		"NPC::@2940": 0x803f40a8,
		"NPC::@2941": 0x803f40b4,
		"NPC::@2942": 0x803f40c0,
		"NPC::@2943": 0x803f40cc,
		"NPC::@2944": 0x803f40d8,
		"NPC::@2945": 0x803f40e4,
		"NPC::@2946": 0x803f40f0,
		"NPC::@2947": 0x803f40fc,
		"NPC::@2948": 0x803f4108,
		"NPC::@2949": 0x803f4114,
		"NPC::@2950": 0x803f4120,
		"NPC::@4339": 0x803f4130,
		"NPC::@4340": 0x803f413c,
		"NPC::@4341": 0x803f4148,
		"NPC::@4342": 0x803f4154,
		"NPC::@4343": 0x803f4160,
		"NPC::@4344": 0x803f416c,
		"NPC::@4345": 0x803f4178,
		"NPC::@4346": 0x803f4184,
		"NPC::@4347": 0x803f4190,
		"NPC::@4348": 0x803f419c,
		"NPC::@4349": 0x803f41a8,
		"NPC::@4350": 0x803f41b4,
		"NPC::@4351": 0x803f41c0,
		"NPC::@4352": 0x803f41cc,
		"NPC::@4353": 0x803f41d8,
		"NPC::@2244": 0x803f41f4,
		"NPC::@2252": 0x803f4200,
		"NPC::@2265": 0x803f420c,
		"NPC::@2304": 0x803f4224,
		"NPC::@2405": 0x803f4278,
		"NPC::@2415": 0x803f4284,
		"NPC::@2437": 0x803f429c,
		"NPC::@2640": 0x803f42a8,
		"NPC::@2641": 0x803f42b4,
		"NPC::@2642": 0x803f42c0,
		"NPC::@2643": 0x803f42cc,
		"NPC::@2644": 0x803f42d8,
		"NPC::@2645": 0x803f42e4,
		"NPC::@2646": 0x803f42f0,
		"NPC::@2647": 0x803f42fc,
		"NPC::@2648": 0x803f4308,
		"NPC::@2649": 0x803f4314,
		"NPC::@2650": 0x803f4320,
		"NPC::@2651": 0x803f432c,
		"NPC::@2652": 0x803f4338,
		"NPC::@2653": 0x803f4344,
		"NPC::@2654": 0x803f4350,
		"NPC::@3044": 0x803f4360,
		"NPC::@3045": 0x803f436c,
		"NPC::@3046": 0x803f4378,
		"NPC::@3047": 0x803f4384,
		"NPC::@3048": 0x803f4390,
		"NPC::@3049": 0x803f439c,
		"NPC::@3050": 0x803f43a8,
		"NPC::@3051": 0x803f43b4,
		"NPC::@3052": 0x803f43c0,
		"NPC::@3053": 0x803f43cc,
		"NPC::@3054": 0x803f43d8,
		"NPC::@3055": 0x803f43e4,
		"NPC::@3056": 0x803f43f0,
		"NPC::@3057": 0x803f43fc,
		"NPC::@3058": 0x803f4408,
		"NPC::@2377": 0x803f4418,
		"NPC::@2378": 0x803f4424,
		"NPC::@2379": 0x803f4430,
		"NPC::@2380": 0x803f443c,
		"NPC::@2381": 0x803f4448,
		"NPC::@2382": 0x803f4454,
		"NPC::@2383": 0x803f4460,
		"NPC::@2384": 0x803f446c,
		"NPC::@2386": 0x803f4484,
		"NPC::@2387": 0x803f4490,
		"NPC::@2388": 0x803f449c,
		"NPC::@2389": 0x803f44a8,
		"NPC::@2390": 0x803f44b4,
		"MSound::@2044": 0x803f44d0,
		"MSound::@2045": 0x803f44dc,
		"MSound::@2046": 0x803f44e8,
		"MSound::@2047": 0x803f44f4,
		"MSound::@3758": 0x803f4588,
		"MSound::@3759": 0x803f4594,
		"MSound::@3760": 0x803f45a0,
		"MSound::@3761": 0x803f45ac,
		"MSound::@3762": 0x803f45b8,
		"MSound::@3763": 0x803f45c4,
		"MSound::@3764": 0x803f45d0,
		"MSound::@3765": 0x803f45dc,
		"MSound::@3766": 0x803f45e8,
		"MSound::@3767": 0x803f45f4,
		"MSound::@3768": 0x803f4600,
		"MSound::@3769": 0x803f460c,
		"MSound::@3770": 0x803f4618,
		"MSound::@3771": 0x803f4624,
		"MSound::@3772": 0x803f4630,
		"MSBgm::smBgmInTrack": 0x803f4640,
		"smBgmInTrack": 0x803f4640,
		"MSound::@1961": 0x803f4778,
		"MSound::@1962": 0x803f4784,
		"MSound::@1963": 0x803f4790,
		"MSound::@1964": 0x803f479c,
		"MSound::@1965": 0x803f47a8,
		"MSound::_posByCamera": 0x803f47b8,
		"_posByCamera": 0x803f47b8,
		"MSound::@1969": 0x803f5470,
		"MSoundSESystem::MSRandVol::smList": 0x803f547c,
		"MSoundSESystem::MSRandPlay::smList": 0x803f5494,
		"MSound::@3185": 0x803f54a0,
		"MSound::@3186": 0x803f54ac,
		"MSound::@3187": 0x803f54b8,
		"MSound::@3188": 0x803f54c4,
		"MSound::@3189": 0x803f54d0,
		"MSound::@3190": 0x803f54dc,
		"MSound::@3191": 0x803f54e8,
		"MSound::@3192": 0x803f54f4,
		"MSound::@3193": 0x803f5500,
		"MSound::@3194": 0x803f550c,
		"MSound::@3195": 0x803f5518,
		"MSound::@3196": 0x803f5524,
		"MSound::@3197": 0x803f5530,
		"MSound::@3198": 0x803f553c,
		"MSound::@3199": 0x803f5548,
		"MSSetSound::smSetSound": 0x803f5558,
		"smSetSound": 0x803f5558,
		"MSound::@1932": 0x803f557c,
		"MSound::@1933": 0x803f5588,
		"MSound::@1934": 0x803f5594,
		"MSound::@1935": 0x803f55a0,
		"MSound::@1936": 0x803f55ac,
		"MSound::@1937": 0x803f55b8,
		"MSound::@1938": 0x803f55c4,
		"MSound::@1939": 0x803f55d0,
		"MSound::@1940": 0x803f55dc,
		"MSound::@1941": 0x803f55e8,
		"MSound::@1942": 0x803f55f4,
		"MSound::@1943": 0x803f5600,
		"MSound::@1944": 0x803f560c,
		"MSound::@2082": 0x803f5630,
		"MSound::@2083": 0x803f563c,
		"MSound::@2084": 0x803f5648,
		"MSound::@2085": 0x803f5654,
		"MSound::@2086": 0x803f5660,
		"MSound::@2087": 0x803f566c,
		"MSound::@2088": 0x803f5678,
		"MSound::@2089": 0x803f5684,
		"MSound::@2090": 0x803f5690,
		"MSound::@2091": 0x803f569c,
		"MSound::@2092": 0x803f56a8,
		"MSound::@2093": 0x803f56b4,
		"MSound::@2094": 0x803f56c0,
		"MSound::@2095": 0x803f56cc,
		"MSound::@2096": 0x803f56d8,
		"MSound::@1947": 0x803f5700,
		"MSound::@1948": 0x803f570c,
		"MSound::@1949": 0x803f5718,
		"MSound::@1950": 0x803f5724,
		"MoveBG::@4343": 0x803f5a80,
		"MoveBG::@4344": 0x803f5a8c,
		"MoveBG::@4345": 0x803f5a98,
		"MoveBG::@4346": 0x803f5aa4,
		"MoveBG::@4347": 0x803f5ab0,
		"MoveBG::@4348": 0x803f5abc,
		"MoveBG::@4350": 0x803f5ad4,
		"MoveBG::@4352": 0x803f5aec,
		"MoveBG::@4353": 0x803f5af8,
		"MoveBG::@4354": 0x803f5b04,
		"MoveBG::@4355": 0x803f5b10,
		"MoveBG::@4356": 0x803f5b1c,
		"MoveBG::@4357": 0x803f5b28,
		"MoveBG::@4274": 0x803f5b38,
		"MoveBG::@4278": 0x803f5b68,
		"MoveBG::@4279": 0x803f5b74,
		"MoveBG::@4280": 0x803f5b80,
		"MoveBG::@4281": 0x803f5b8c,
		"MoveBG::@4282": 0x803f5b98,
		"MoveBG::@4286": 0x803f5bc8,
		"MoveBG::@4856": 0x803f5bf0,
		"MoveBG::@4857": 0x803f5bfc,
		"MoveBG::@4858": 0x803f5c08,
		"MoveBG::@4859": 0x803f5c14,
		"MoveBG::@4863": 0x803f5c44,
		"MoveBG::@4864": 0x803f5c50,
		"MoveBG::@4865": 0x803f5c5c,
		"MoveBG::@4866": 0x803f5c68,
		"@4866": 0x803f5c68,
		"MoveBG::@4867": 0x803f5c74,
		"@4867": 0x803f5c74,
		"MoveBG::@4868": 0x803f5c80,
		"@4868": 0x803f5c80,
		"MoveBG::@4869": 0x803f5c8c,
		"MoveBG::@4870": 0x803f5c98,
		"MoveBG::@3834": 0x803f5dfc,
		"MoveBG::@5259": 0x803f5f88,
		"MoveBG::@5260": 0x803f5f94,
		"MoveBG::@5261": 0x803f5fa0,
		"MoveBG::@5262": 0x803f5fac,
		"MoveBG::@5263": 0x803f5fb8,
		"MoveBG::@5264": 0x803f5fc4,
		"MoveBG::@5265": 0x803f5fd0,
		"MoveBG::@5266": 0x803f5fdc,
		"MoveBG::@5267": 0x803f5fe8,
		"MoveBG::@5268": 0x803f5ff4,
		"MoveBG::@5269": 0x803f6000,
		"MoveBG::@5270": 0x803f600c,
		"MoveBG::@5271": 0x803f6018,
		"MoveBG::@5272": 0x803f6024,
		"MoveBG::@5273": 0x803f6030,
		"MoveBG::submarineCranePos_forSound": 0x803f6040,
		"submarineCranePos_forSound": 0x803f6040,
		"MoveBG::submarineSetWtPos_forSound": 0x803f604c,
		"submarineSetWtPos_forSound": 0x803f604c,
		"MoveBG::@3531": 0x803f6070,
		"MoveBG::@3532": 0x803f607c,
		"MoveBG::@3533": 0x803f6088,
		"MoveBG::@3534": 0x803f6094,
		"MoveBG::@3535": 0x803f60a0,
		"MoveBG::@3540": 0x803f60dc,
		"MoveBG::@3541": 0x803f60e8,
		"MoveBG::@3542": 0x803f60f4,
		"MoveBG::@5417": 0x803f6110,
		"MoveBG::@5418": 0x803f611c,
		"MoveBG::@5419": 0x803f6128,
		"MoveBG::@5420": 0x803f6134,
		"MoveBG::@5421": 0x803f6140,
		"MoveBG::@5422": 0x803f614c,
		"MoveBG::@5423": 0x803f6158,
		"MoveBG::@5424": 0x803f6164,
		"MoveBG::@5425": 0x803f6170,
		"MoveBG::@5426": 0x803f617c,
		"MoveBG::@5427": 0x803f6188,
		"MoveBG::@5428": 0x803f6194,
		"MoveBG::@5429": 0x803f61a0,
		"MoveBG::@5430": 0x803f61ac,
		"MoveBG::@5431": 0x803f61b8,
		"MoveBG::@4378": 0x803f61c8,
		"MoveBG::@4379": 0x803f61d4,
		"MoveBG::@4380": 0x803f61e0,
		"MoveBG::@4381": 0x803f61ec,
		"@4381": 0x803f61ec,
		"MoveBG::@4382": 0x803f61f8,
		"@4382": 0x803f61f8,
		"MoveBG::@4383": 0x803f6204,
		"@4383": 0x803f6204,
		"MoveBG::@4384": 0x803f6210,
		"@4384": 0x803f6210,
		"MoveBG::@4390": 0x803f6258,
		"MoveBG::@2483": 0x803f6280,
		"MoveBG::@2484": 0x803f628c,
		"MoveBG::@2485": 0x803f6298,
		"MoveBG::fall_upper_pos": 0x803f6338,
		"fall_upper_pos": 0x803f6338,
		"MoveBG::@4408": 0x803f6398,
		"MoveBG::@2557": 0x803f6568,
		"MoveBG::@2558": 0x803f6574,
		"MoveBG::@2562": 0x803f65a4,
		"MoveBG::@2563": 0x803f65b0,
		"MoveBG::@2564": 0x803f65bc,
		"MoveBG::@2565": 0x803f65c8,
		"MoveBG::@2566": 0x803f65d4,
		"MoveBG::@2567": 0x803f65e0,
		"MoveBG::@5478": 0x803f6790,
		"MoveBG::@5479": 0x803f679c,
		"MoveBG::@5480": 0x803f67a8,
		"MoveBG::@5481": 0x803f67b4,
		"MoveBG::@5482": 0x803f67c0,
		"MoveBG::@5483": 0x803f67cc,
		"MoveBG::@5484": 0x803f67d8,
		"MoveBG::@5485": 0x803f67e4,
		"MoveBG::@5486": 0x803f67f0,
		"MoveBG::@5487": 0x803f67fc,
		"MoveBG::@5488": 0x803f6808,
		"MoveBG::@5489": 0x803f6814,
		"MoveBG::@5490": 0x803f6820,
		"MoveBG::@5491": 0x803f682c,
		"MoveBG::@5492": 0x803f6838,
		"MoveBG::up$2645": 0x803f6900,
		"up$2645": 0x803f6900,
		"MoveBG::up$2710": 0x803f690c,
		"up$2710": 0x803f690c,
		"MoveBG::@2741": 0x803f6a00,
		"MoveBG::@2743": 0x803f6a18,
		"MoveBG::@2745": 0x803f6a30,
		"MoveBG::@2746": 0x803f6a3c,
		"MoveBG::@2747": 0x803f6a48,
		"MoveBG::@2751": 0x803f6a78,
		"TMapObjGrassManager::mDrawVec": 0x803f6a88,
		"mDrawVec": 0x803f6a88,
		"MoveBG::@2728": 0x803f6aac,
		"MoveBG::@2729": 0x803f6ab8,
		"MoveBG::@2731": 0x803f6ad0,
		"MoveBG::@2732": 0x803f6adc,
		"MoveBG::@2736": 0x803f6b0c,
		"MoveBG::@2311": 0x803f6b48,
		"MoveBG::@2312": 0x803f6b54,
		"MoveBG::@2313": 0x803f6b60,
		"MoveBG::@2314": 0x803f6b6c,
		"MoveBG::@2315": 0x803f6b78,
		"MoveBG::@2316": 0x803f6b84,
		"MoveBG::@2317": 0x803f6b90,
		"MoveBG::@2318": 0x803f6b9c,
		"@2318": 0x803f6b9c,
		"MoveBG::@2319": 0x803f6ba8,
		"MoveBG::@2320": 0x803f6bb4,
		"MoveBG::@2321": 0x803f6bc0,
		"MoveBG::@2322": 0x803f6bcc,
		"MoveBG::@2323": 0x803f6bd8,
		"MoveBG::@2324": 0x803f6be4,
		"MoveBG::@2325": 0x803f6bf0,
		"MoveBG::@3437": 0x803f6d60,
		"MoveBG::@4475": 0x803f6ee0,
		"MoveBG::@4476": 0x803f6eec,
		"MoveBG::@4477": 0x803f6ef8,
		"MoveBG::@4480": 0x803f6f1c,
		"MoveBG::@4481": 0x803f6f28,
		"MoveBG::@4482": 0x803f6f34,
		"MoveBG::@4483": 0x803f6f40,
		"MoveBG::@4484": 0x803f6f4c,
		"MoveBG::@4485": 0x803f6f58,
		"MoveBG::@4486": 0x803f6f64,
		"MoveBG::@4487": 0x803f6f70,
		"MoveBG::@4488": 0x803f6f7c,
		"MoveBG::@4489": 0x803f6f88,
		"MoveBG::yDown$3091": 0x803f7278,
		"yDown$3091": 0x803f7278,
		"MoveBG::y$3288": 0x803f7284,
		"y$3288": 0x803f7284,
		"MoveBG::@6029": 0x803f7290,
		"MoveBG::@6030": 0x803f729c,
		"MoveBG::@6031": 0x803f72a8,
		"MoveBG::@6032": 0x803f72b4,
		"MoveBG::@6033": 0x803f72c0,
		"MoveBG::@6034": 0x803f72cc,
		"MoveBG::@6035": 0x803f72d8,
		"MoveBG::@6036": 0x803f72e4,
		"MoveBG::@6037": 0x803f72f0,
		"MoveBG::@6038": 0x803f72fc,
		"MoveBG::@6039": 0x803f7308,
		"MoveBG::@6040": 0x803f7314,
		"MoveBG::@6041": 0x803f7320,
		"MoveBG::@6042": 0x803f732c,
		"MoveBG::@6043": 0x803f7338,
		"MoveBG::@3960": 0x803f7478,
		"MoveBG::@3961": 0x803f7484,
		"MoveBG::@3962": 0x803f7490,
		"MoveBG::@3963": 0x803f749c,
		"Map::@2345": 0x803f7618,
		"Map::@2417": 0x803f76b8,
		"Map::@2418": 0x803f76c4,
		"Map::@2419": 0x803f76d0,
		"Map::@2519": 0x803f76e0,
		"Map::@2520": 0x803f76ec,
		"Map::@2522": 0x803f7704,
		"Map::@2524": 0x803f771c,
		"Map::@2525": 0x803f7728,
		"Map::@2526": 0x803f7734,
		"Map::@2527": 0x803f7740,
		"Map::pos$2895": 0x803f7798,
		"pos$2895": 0x803f7798,
		"Map::@2534": 0x803f7888,
		"Map::@2535": 0x803f7894,
		"Map::@2536": 0x803f78a0,
		"Map::@2540": 0x803f78d0,
		"Map::@2541": 0x803f78dc,
		"Map::@2542": 0x803f78e8,
		"Map::@2543": 0x803f78f4,
		"Map::@2544": 0x803f7900,
		"TMapCollisionData::mIllegalCheckData": 0x803f7910,
		"mIllegalCheckData": 0x803f7910,
		"Map::@2159": 0x803f7958,
		"Map::@2160": 0x803f7964,
		"Map::@2161": 0x803f7970,
		"Map::@2162": 0x803f797c,
		"Map::@2163": 0x803f7988,
		"Map::@2164": 0x803f7994,
		"Map::@2165": 0x803f79a0,
		"Map::@2166": 0x803f79ac,
		"Map::@2171": 0x803f79e8,
		"Map::@2172": 0x803f79f4,
		"Map::@2173": 0x803f7a00,
		"Map::@2402": 0x803f7a10,
		"Map::@2403": 0x803f7a1c,
		"Map::@2404": 0x803f7a28,
		"Map::@2701": 0x803f7ad4,
		"Map::@2702": 0x803f7ae0,
		"Map::@2708": 0x803f7b28,
		"Map::@2709": 0x803f7b34,
		"Map::@2710": 0x803f7b40,
		"Map::@2712": 0x803f7b58,
		"Map::@2713": 0x803f7b64,
		"Map::@3811": 0x803f7b80,
		"Map::@2749": 0x803f7c74,
		"Map::@2750": 0x803f7c80,
		"Map::@2751": 0x803f7c8c,
		"Map::@2752": 0x803f7c98,
		"Map::@2753": 0x803f7ca4,
		"Map::@2754": 0x803f7cb0,
		"Map::@2755": 0x803f7cbc,
		"Map::@2756": 0x803f7cc8,
		"Map::@2757": 0x803f7cd4,
		"Map::@2758": 0x803f7ce0,
		"Map::@3295": 0x803f7d08,
		"Map::@3296": 0x803f7d14,
		"Map::@3297": 0x803f7d20,
		"Map::@3298": 0x803f7d2c,
		"Map::@3299": 0x803f7d38,
		"Map::@3300": 0x803f7d44,
		"Map::@3301": 0x803f7d50,
		"Map::@3302": 0x803f7d5c,
		"Map::@3303": 0x803f7d68,
		"Map::@3304": 0x803f7d74,
		"Map::@3305": 0x803f7d80,
		"Map::@2668": 0x803f7da8,
		"Map::@2669": 0x803f7db4,
		"Map::@2671": 0x803f7dcc,
		"Map::@2672": 0x803f7dd8,
		"Map::@2673": 0x803f7de4,
		"Map::@2684": 0x803f7e60,
		"Map::@2688": 0x803f7e90,
		"Map::@2689": 0x803f7e9c,
		"Map::@2692": 0x803f7ec0,
		"Map::@2697": 0x803f7efc,
		"Map::@2698": 0x803f7f08,
		"Map::@3581": 0x803f7f18,
		"Map::@3582": 0x803f7f24,
		"Map::@3583": 0x803f7f30,
		"Map::@3584": 0x803f7f3c,
		"Map::@3585": 0x803f7f48,
		"Map::@3586": 0x803f7f54,
		"Map::@3588": 0x803f7f6c,
		"Map::@3589": 0x803f7f78,
		"Map::@3590": 0x803f7f84,
		"Map::@3591": 0x803f7f90,
		"Map::@3592": 0x803f7f9c,
		"Map::@3594": 0x803f7fb4,
		"Map::@3595": 0x803f7fc0,
		"Map::@2358": 0x803f7fd0,
		"Map::@2359": 0x803f7fdc,
		"Map::@2360": 0x803f7fe8,
		"Map::@2361": 0x803f7ff4,
		"Map::@2362": 0x803f8000,
		"Map::@2363": 0x803f800c,
		"Map::@2365": 0x803f8024,
		"Map::@2366": 0x803f8030,
		"Map::@2367": 0x803f803c,
		"Map::@2369": 0x803f8054,
		"Map::@2370": 0x803f8060,
		"Map::@2371": 0x803f806c,
		"Map::@2372": 0x803f8078,
		"Map::@2938": 0x803f8088,
		"Map::@2939": 0x803f8094,
		"Map::@2940": 0x803f80a0,
		"Map::@2941": 0x803f80ac,
		"Map::@2942": 0x803f80b8,
		"Map::@2943": 0x803f80c4,
		"Map::@2944": 0x803f80d0,
		"Map::@2945": 0x803f80dc,
		"Map::@2946": 0x803f80e8,
		"Map::@2947": 0x803f80f4,
		"Map::@2948": 0x803f8100,
		"Map::@2950": 0x803f8118,
		"Map::@2584": 0x803f8164,
		"Map::@2586": 0x803f817c,
		"Map::@2588": 0x803f8194,
		"Map::@2589": 0x803f81a0,
		"Map::@2590": 0x803f81ac,
		"Map::@2591": 0x803f81b8,
		"Map::@2592": 0x803f81c4,
		"Map::@2593": 0x803f81d0,
		"Map::@2594": 0x803f81dc,
		"Map::@2615": 0x803f81f8,
		"Map::@2616": 0x803f8204,
		"Map::@2617": 0x803f8210,
		"Map::@2621": 0x803f8240,
		"Map::@2622": 0x803f824c,
		"Map::@2623": 0x803f8258,
		"Map::@2624": 0x803f8264,
		"Map::@2625": 0x803f8270,
		"Map::@2626": 0x803f827c,
		"Map::@2627": 0x803f8288,
		"Map::@2628": 0x803f8294,
		"Map::@2629": 0x803f82a0,
		"Map::@3519": 0x803f82b0,
		"Map::@3520": 0x803f82bc,
		"Map::@3521": 0x803f82c8,
		"Map::@3522": 0x803f82d4,
		"Map::@3523": 0x803f82e0,
		"Map::@3524": 0x803f82ec,
		"Map::@3525": 0x803f82f8,
		"Map::@3526": 0x803f8304,
		"Map::@3527": 0x803f8310,
		"Map::@3528": 0x803f831c,
		"Map::@3529": 0x803f8328,
		"Map::@3530": 0x803f8334,
		"Map::@3531": 0x803f8340,
		"Map::@3532": 0x803f834c,
		"Map::@3533": 0x803f8358,
		"Map::@3240": 0x803f8374,
		"Map::@3241": 0x803f8380,
		"Map::@3242": 0x803f838c,
		"Map::@3243": 0x803f8398,
		"Map::@3244": 0x803f83a4,
		"Map::@3245": 0x803f83b0,
		"Map::@3246": 0x803f83bc,
		"Map::@3247": 0x803f83c8,
		"Map::@3248": 0x803f83d4,
		"Map::@3249": 0x803f83e0,
		"Map::@3250": 0x803f83ec,
		"Map::@3251": 0x803f83f8,
		"Map::@3252": 0x803f8404,
		"Map::@3253": 0x803f8410,
		"Map::@2743": 0x803f848c,
		"Map::@2374": 0x803f84d8,
		"Map::@2379": 0x803f8514,
		"Map::@2380": 0x803f8520,
		"Map::@2381": 0x803f852c,
		"Map::@2382": 0x803f8538,
		"Map::@2383": 0x803f8544,
		"Map::@2386": 0x803f8568,
		"Map::@2387": 0x803f8574,
		"Map::@2388": 0x803f8580,
		"Map::@2867": 0x803f8648,
		"Map::pos$2426": 0x803f87b8,
		"pos$2426": 0x803f87b8,
		"Map::@3092": 0x803f883c,
		"Map::@3093": 0x803f8848,
		"Map::@3094": 0x803f8854,
		"Map::@3095": 0x803f8860,
		"Map::@3096": 0x803f886c,
		"Map::@3098": 0x803f8884,
		"Map::@3099": 0x803f8890,
		"Map::@3100": 0x803f889c,
		"Map::@3101": 0x803f88a8,
		"Map::@2727": 0x803f88e8,
		"Map::@2728": 0x803f88f4,
		"Map::@2729": 0x803f8900,
		"Map::@2730": 0x803f890c,
		"Map::@2731": 0x803f8918,
		"Map::@2732": 0x803f8924,
		"Map::@2733": 0x803f8930,
		"Map::@2330": 0x803f89a0,
		"Map::@2658": 0x803f8ab8,
		"Map::@2659": 0x803f8ac4,
		"Map::@2660": 0x803f8ad0,
		"Map::@2661": 0x803f8adc,
		"Map::@2662": 0x803f8ae8,
		"Map::@2663": 0x803f8af4,
		"Map::@2664": 0x803f8b00,
		"Map::@3109": 0x803f8b64,
		"Map::@3110": 0x803f8b70,
		"Map::@3111": 0x803f8b7c,
		"Map::@3112": 0x803f8b88,
		"Map::@3113": 0x803f8b94,
		"Map::@3114": 0x803f8ba0,
		"Map::@3115": 0x803f8bac,
		"Map::@3116": 0x803f8bb8,
		"Map::@3971": 0x803f8bc8,
		"Map::@3972": 0x803f8bd4,
		"Map::@3973": 0x803f8be0,
		"Map::@3974": 0x803f8bec,
		"Map::@3975": 0x803f8bf8,
		"Map::@3976": 0x803f8c04,
		"Map::@3977": 0x803f8c10,
		"Map::@3978": 0x803f8c1c,
		"Map::@3979": 0x803f8c28,
		"Map::@3980": 0x803f8c34,
		"Map::@3981": 0x803f8c40,
		"Map::@3982": 0x803f8c4c,
		"Map::@3983": 0x803f8c58,
		"Map::@3984": 0x803f8c64,
		"Map::@3985": 0x803f8c70,
		"Map::@6023": 0x803f8c80,
		"Map::@6024": 0x803f8c8c,
		"Map::@6025": 0x803f8c98,
		"Map::@6026": 0x803f8ca4,
		"Map::@6027": 0x803f8cb0,
		"Map::@6028": 0x803f8cbc,
		"Map::@6029": 0x803f8cc8,
		"Map::@6030": 0x803f8cd4,
		"Map::@6031": 0x803f8ce0,
		"Map::@6032": 0x803f8cec,
		"Map::@6033": 0x803f8cf8,
		"Map::@6034": 0x803f8d04,
		"Map::@6035": 0x803f8d10,
		"Map::@6036": 0x803f8d1c,
		"Map::@6037": 0x803f8d28,
		"GC2D::@2410": 0x803f8d74,
		"GC2D::@2411": 0x803f8d80,
		"GC2D::@2412": 0x803f8d8c,
		"GC2D::@2413": 0x803f8d98,
		"GC2D::@2414": 0x803f8da4,
		"GC2D::@11646": 0x803f8df0,
		"@11646": 0x803f8df0,
		"GC2D::@11647": 0x803f8dfc,
		"@11647": 0x803f8dfc,
		"GC2D::@11648": 0x803f8e08,
		"@11648": 0x803f8e08,
		"GC2D::@11649": 0x803f8e14,
		"@11649": 0x803f8e14,
		"GC2D::@11650": 0x803f8e20,
		"@11650": 0x803f8e20,
		"GC2D::@11651": 0x803f8e2c,
		"@11651": 0x803f8e2c,
		"GC2D::@11652": 0x803f8e38,
		"@11652": 0x803f8e38,
		"GC2D::@11653": 0x803f8e44,
		"@11653": 0x803f8e44,
		"GC2D::@11654": 0x803f8e50,
		"@11654": 0x803f8e50,
		"GC2D::@11655": 0x803f8e5c,
		"@11655": 0x803f8e5c,
		"GC2D::@11656": 0x803f8e68,
		"@11656": 0x803f8e68,
		"GC2D::@11657": 0x803f8e74,
		"@11657": 0x803f8e74,
		"GC2D::@11658": 0x803f8e80,
		"@11658": 0x803f8e80,
		"GC2D::@11659": 0x803f8e8c,
		"@11659": 0x803f8e8c,
		"GC2D::@11660": 0x803f8e98,
		"@11660": 0x803f8e98,
		"GC2D::@5013": 0x803f8ea8,
		"GC2D::@5014": 0x803f8eb4,
		"GC2D::@5015": 0x803f8ec0,
		"GC2D::@5016": 0x803f8ecc,
		"GC2D::@5020": 0x803f8efc,
		"GC2D::@5021": 0x803f8f08,
		"GC2D::@5022": 0x803f8f14,
		"GC2D::@5023": 0x803f8f20,
		"GC2D::@5024": 0x803f8f2c,
		"GC2D::@5025": 0x803f8f38,
		"GC2D::@5026": 0x803f8f44,
		"GC2D::@5027": 0x803f8f50,
		"GC2D::@3375": 0x803f8f60,
		"GC2D::@3376": 0x803f8f6c,
		"GC2D::@3377": 0x803f8f78,
		"GC2D::@3382": 0x803f8fb4,
		"GC2D::@3383": 0x803f8fc0,
		"GC2D::@3384": 0x803f8fcc,
		"GC2D::@3385": 0x803f8fd8,
		"GC2D::@3386": 0x803f8fe4,
		"GC2D::@3387": 0x803f8ff0,
		"GC2D::@3388": 0x803f8ffc,
		"GC2D::@3389": 0x803f9008,
		"GC2D::@6914": 0x803f9018,
		"@6914": 0x803f9018,
		"GC2D::@6915": 0x803f9024,
		"@6915": 0x803f9024,
		"GC2D::@6916": 0x803f9030,
		"@6916": 0x803f9030,
		"GC2D::@6917": 0x803f903c,
		"@6917": 0x803f903c,
		"GC2D::@6918": 0x803f9048,
		"@6918": 0x803f9048,
		"GC2D::@6919": 0x803f9054,
		"@6919": 0x803f9054,
		"GC2D::@6920": 0x803f9060,
		"@6920": 0x803f9060,
		"GC2D::@6921": 0x803f906c,
		"@6921": 0x803f906c,
		"GC2D::@6923": 0x803f9084,
		"@6923": 0x803f9084,
		"GC2D::@6924": 0x803f9090,
		"GC2D::@6925": 0x803f909c,
		"GC2D::@6926": 0x803f90a8,
		"GC2D::@6927": 0x803f90b4,
		"GC2D::@6928": 0x803f90c0,
		"GC2D::@8348": 0x803f90d0,
		"@8348": 0x803f90d0,
		"GC2D::@8349": 0x803f90dc,
		"@8349": 0x803f90dc,
		"GC2D::@8350": 0x803f90e8,
		"@8350": 0x803f90e8,
		"GC2D::@8351": 0x803f90f4,
		"@8351": 0x803f90f4,
		"GC2D::@8352": 0x803f9100,
		"@8352": 0x803f9100,
		"GC2D::@8353": 0x803f910c,
		"@8353": 0x803f910c,
		"GC2D::@8354": 0x803f9118,
		"@8354": 0x803f9118,
		"GC2D::@8355": 0x803f9124,
		"@8355": 0x803f9124,
		"GC2D::@8356": 0x803f9130,
		"@8356": 0x803f9130,
		"GC2D::@8357": 0x803f913c,
		"@8357": 0x803f913c,
		"GC2D::@8358": 0x803f9148,
		"@8358": 0x803f9148,
		"GC2D::@8359": 0x803f9154,
		"@8359": 0x803f9154,
		"GC2D::@8360": 0x803f9160,
		"GC2D::@8361": 0x803f916c,
		"@8361": 0x803f916c,
		"GC2D::@8362": 0x803f9178,
		"@8362": 0x803f9178,
		"GC2D::@4101": 0x803f9188,
		"GC2D::@4102": 0x803f9194,
		"GC2D::@4103": 0x803f91a0,
		"GC2D::@4104": 0x803f91ac,
		"GC2D::@4105": 0x803f91b8,
		"GC2D::@4106": 0x803f91c4,
		"GC2D::@4107": 0x803f91d0,
		"GC2D::@4108": 0x803f91dc,
		"GC2D::@4109": 0x803f91e8,
		"GC2D::@4110": 0x803f91f4,
		"GC2D::@4111": 0x803f9200,
		"GC2D::@4112": 0x803f920c,
		"GC2D::@4113": 0x803f9218,
		"GC2D::@4114": 0x803f9224,
		"GC2D::@4115": 0x803f9230,
		"GC2D::@3131": 0x803f9240,
		"GC2D::@3132": 0x803f924c,
		"GC2D::@3133": 0x803f9258,
		"GC2D::@3135": 0x803f9270,
		"GC2D::@3136": 0x803f927c,
		"GC2D::@3137": 0x803f9288,
		"GC2D::@3138": 0x803f9294,
		"GC2D::@3139": 0x803f92a0,
		"GC2D::@3140": 0x803f92ac,
		"GC2D::@3141": 0x803f92b8,
		"GC2D::@3142": 0x803f92c4,
		"GC2D::@3143": 0x803f92d0,
		"GC2D::@3144": 0x803f92dc,
		"GC2D::@3145": 0x803f92e8,
		"TSelectShineManager::cCenter": 0x803f92f8,
		"cCenter": 0x803f92f8,
		"GC2D::@4146": 0x803f93a4,
		"GC2D::@4147": 0x803f93b0,
		"GC2D::hx": 0x803f93c0,
		"hx": 0x803f93c0,
		"GC2D::@2300": 0x803fc740,
		"GC2D::@2301": 0x803fc74c,
		"GC2D::@2302": 0x803fc758,
		"GC2D::@2303": 0x803fc764,
		"GC2D::@2304": 0x803fc770,
		"GC2D::@2305": 0x803fc77c,
		"GC2D::@2306": 0x803fc788,
		"GC2D::@2307": 0x803fc794,
		"GC2D::@2308": 0x803fc7a0,
		"GC2D::@2309": 0x803fc7ac,
		"GC2D::@2310": 0x803fc7b8,
		"GC2D::@2311": 0x803fc7c4,
		"GC2D::@2312": 0x803fc7d0,
		"GC2D::@2313": 0x803fc7dc,
		"GC2D::@2314": 0x803fc7e8,
		"Enemy::@3176": 0x803fc8bc,
		"Enemy::@3178": 0x803fc8d4,
		"Enemy::@3183": 0x803fc910,
		"Enemy::@3185": 0x803fc928,
		"Enemy::@3186": 0x803fc934,
		"Enemy::@4335": 0x803fc9ec,
		"Enemy::@4336": 0x803fc9f8,
		"Enemy::@3909": 0x803fca2c,
		"Enemy::@3918": 0x803fca98,
		"Enemy::@3221": 0x803fcb90,
		"Enemy::@3889": 0x803fcd28,
		"Enemy::@8477": 0x803fcd58,
		"@8477": 0x803fcd58,
		"Enemy::@8478": 0x803fcd64,
		"@8478": 0x803fcd64,
		"Enemy::@8479": 0x803fcd70,
		"@8479": 0x803fcd70,
		"Enemy::@8480": 0x803fcd7c,
		"@8480": 0x803fcd7c,
		"Enemy::@8481": 0x803fcd88,
		"@8481": 0x803fcd88,
		"Enemy::@8482": 0x803fcd94,
		"@8482": 0x803fcd94,
		"Enemy::@8483": 0x803fcda0,
		"@8483": 0x803fcda0,
		"Enemy::@8484": 0x803fcdac,
		"@8484": 0x803fcdac,
		"Enemy::@8485": 0x803fcdb8,
		"@8485": 0x803fcdb8,
		"Enemy::@8486": 0x803fcdc4,
		"@8486": 0x803fcdc4,
		"Enemy::@8487": 0x803fcdd0,
		"@8487": 0x803fcdd0,
		"Enemy::@8488": 0x803fcddc,
		"@8488": 0x803fcddc,
		"Enemy::@8489": 0x803fcde8,
		"@8489": 0x803fcde8,
		"Enemy::@8490": 0x803fcdf4,
		"@8490": 0x803fcdf4,
		"Enemy::@8491": 0x803fce00,
		"@8491": 0x803fce00,
		"Enemy::@6476": 0x803fcec4,
		"@6476": 0x803fcec4,
		"Enemy::@6477": 0x803fced0,
		"@6477": 0x803fced0,
		"Enemy::@6480": 0x803fcef4,
		"@6480": 0x803fcef4,
		"Enemy::@6481": 0x803fcf00,
		"@6481": 0x803fcf00,
		"Enemy::@6482": 0x803fcf0c,
		"@6482": 0x803fcf0c,
		"Enemy::@6485": 0x803fcf30,
		"@6485": 0x803fcf30,
		"Enemy::@6486": 0x803fcf3c,
		"@6486": 0x803fcf3c,
		"Enemy::@6487": 0x803fcf48,
		"@6487": 0x803fcf48,
		"Enemy::@6488": 0x803fcf54,
		"@6488": 0x803fcf54,
		"Enemy::@6489": 0x803fcf60,
		"@6489": 0x803fcf60,
		"Enemy::@6490": 0x803fcf6c,
		"@6490": 0x803fcf6c,
		"Enemy::@2753": 0x803fcfcc,
		"Enemy::@4766": 0x803fd104,
		"Enemy::@4767": 0x803fd110,
		"Enemy::@4769": 0x803fd128,
		"Enemy::@4771": 0x803fd140,
		"Enemy::@4772": 0x803fd14c,
		"Enemy::@2167": 0x803fd388,
		"Enemy::@2615": 0x803fd398,
		"Enemy::@2626": 0x803fd3a4,
		"Enemy::@2638": 0x803fd3b0,
		"Enemy::@2668": 0x803fd3c8,
		"Enemy::@2682": 0x803fd3d4,
		"Enemy::@9261": 0x803fd504,
		"@9261": 0x803fd504,
		"Enemy::@9262": 0x803fd510,
		"@9262": 0x803fd510,
		"Enemy::@9263": 0x803fd51c,
		"@9263": 0x803fd51c,
		"Enemy::@9264": 0x803fd528,
		"@9264": 0x803fd528,
		"Enemy::@9265": 0x803fd534,
		"@9265": 0x803fd534,
		"Enemy::@9266": 0x803fd540,
		"@9266": 0x803fd540,
		"Enemy::@9267": 0x803fd54c,
		"@9267": 0x803fd54c,
		"Enemy::@9268": 0x803fd558,
		"@9268": 0x803fd558,
		"Enemy::@9269": 0x803fd564,
		"@9269": 0x803fd564,
		"Enemy::@9270": 0x803fd570,
		"@9270": 0x803fd570,
		"Enemy::@9271": 0x803fd57c,
		"@9271": 0x803fd57c,
		"Enemy::@9272": 0x803fd588,
		"@9272": 0x803fd588,
		"Enemy::@9273": 0x803fd594,
		"@9273": 0x803fd594,
		"Enemy::@9274": 0x803fd5a0,
		"@9274": 0x803fd5a0,
		"Enemy::@9275": 0x803fd5ac,
		"@9275": 0x803fd5ac,
		"Enemy::@5543": 0x803fd720,
		"@5543": 0x803fd720,
		"Enemy::@5544": 0x803fd72c,
		"@5544": 0x803fd72c,
		"Enemy::@5545": 0x803fd738,
		"@5545": 0x803fd738,
		"Enemy::@5546": 0x803fd744,
		"@5546": 0x803fd744,
		"Enemy::@5552": 0x803fd78c,
		"@5552": 0x803fd78c,
		"Enemy::@5553": 0x803fd798,
		"@5553": 0x803fd798,
		"Enemy::@3533": 0x803fd808,
		"Enemy::@9726": 0x803fd868,
		"@9726": 0x803fd868,
		"Enemy::@9727": 0x803fd874,
		"@9727": 0x803fd874,
		"Enemy::@9728": 0x803fd880,
		"@9728": 0x803fd880,
		"Enemy::@9729": 0x803fd88c,
		"@9729": 0x803fd88c,
		"Enemy::@9730": 0x803fd898,
		"@9730": 0x803fd898,
		"Enemy::@9731": 0x803fd8a4,
		"@9731": 0x803fd8a4,
		"Enemy::@9732": 0x803fd8b0,
		"@9732": 0x803fd8b0,
		"Enemy::@9733": 0x803fd8bc,
		"@9733": 0x803fd8bc,
		"Enemy::@9734": 0x803fd8c8,
		"@9734": 0x803fd8c8,
		"Enemy::@9735": 0x803fd8d4,
		"@9735": 0x803fd8d4,
		"Enemy::@9736": 0x803fd8e0,
		"@9736": 0x803fd8e0,
		"Enemy::@9737": 0x803fd8ec,
		"@9737": 0x803fd8ec,
		"Enemy::@9738": 0x803fd8f8,
		"@9738": 0x803fd8f8,
		"Enemy::@9739": 0x803fd904,
		"@9739": 0x803fd904,
		"Enemy::@9740": 0x803fd910,
		"@9740": 0x803fd910,
		"Enemy::up$3230": 0x803fd920,
		"up$3230": 0x803fd920,
		"Enemy::up$3276": 0x803fd92c,
		"up$3276": 0x803fd92c,
		"Enemy::goal$3329": 0x803fd938,
		"goal$3329": 0x803fd938,
		"Enemy::start$3332": 0x803fd944,
		"start$3332": 0x803fd944,
		"Enemy::goal$3336": 0x803fd950,
		"goal$3336": 0x803fd950,
		"Enemy::start$3339": 0x803fd95c,
		"start$3339": 0x803fd95c,
		"Enemy::s$3585": 0x803fd968,
		"s$3585": 0x803fd968,
		"Enemy::@8431": 0x803fdaac,
		"Enemy::@8432": 0x803fdab8,
		"Enemy::@8433": 0x803fdac4,
		"Enemy::@8434": 0x803fdad0,
		"Enemy::@8435": 0x803fdadc,
		"Enemy::@8436": 0x803fdae8,
		"Enemy::@8437": 0x803fdaf4,
		"Enemy::@8438": 0x803fdb00,
		"Enemy::@8439": 0x803fdb0c,
		"Enemy::@8440": 0x803fdb18,
		"Enemy::@8441": 0x803fdb24,
		"Enemy::@8442": 0x803fdb30,
		"Enemy::@8443": 0x803fdb3c,
		"@8443": 0x803fdb3c,
		"Enemy::@8444": 0x803fdb48,
		"@8444": 0x803fdb48,
		"Enemy::@8445": 0x803fdb54,
		"@8445": 0x803fdb54,
		"Enemy::@5224": 0x803fdbfc,
		"Enemy::@5225": 0x803fdc08,
		"Enemy::@5226": 0x803fdc14,
		"Enemy::@5229": 0x803fdc38,
		"Enemy::@5235": 0x803fdc80,
		"Enemy::@5236": 0x803fdc8c,
		"Enemy::@5237": 0x803fdc98,
		"Enemy::TTinKoopa_jointIndexTable": 0x803fdca8,
		"TTinKoopa_jointIndexTable": 0x803fdca8,
		"Enemy::@6191": 0x803fdd8c,
		"@6191": 0x803fdd8c,
		"Enemy::@6192": 0x803fdd98,
		"@6192": 0x803fdd98,
		"Enemy::@6193": 0x803fdda4,
		"@6193": 0x803fdda4,
		"Enemy::@6194": 0x803fddb0,
		"@6194": 0x803fddb0,
		"Enemy::BW_BATH_POS": 0x803fde80,
		"BW_BATH_POS": 0x803fde80,
		"Enemy::BW_PICKET_START": 0x803fde8c,
		"BW_PICKET_START": 0x803fde8c,
		"Enemy::BW_HEAD_START": 0x803fde98,
		"BW_HEAD_START": 0x803fde98,
		"Enemy::@3639": 0x803fdf04,
		"Enemy::@3239": 0x803fe058,
		"Enemy::@5860": 0x803fe0b8,
		"@5860": 0x803fe0b8,
		"Enemy::@4621": 0x803fe238,
		"@4621": 0x803fe238,
		"Enemy::@4623": 0x803fe250,
		"Enemy::@4624": 0x803fe25c,
		"Enemy::@4625": 0x803fe268,
		"Enemy::@4626": 0x803fe274,
		"Enemy::@4627": 0x803fe280,
		"Enemy::@4628": 0x803fe28c,
		"Enemy::@4629": 0x803fe298,
		"Enemy::@4630": 0x803fe2a4,
		"Enemy::@4631": 0x803fe2b0,
		"Enemy::@4632": 0x803fe2bc,
		"Enemy::@4633": 0x803fe2c8,
		"Enemy::@4634": 0x803fe2d4,
		"Enemy::@5309": 0x803fe350,
		"Enemy::@5310": 0x803fe35c,
		"Enemy::@5311": 0x803fe368,
		"Enemy::@5312": 0x803fe374,
		"Enemy::@5313": 0x803fe380,
		"Enemy::@5314": 0x803fe38c,
		"Enemy::@5319": 0x803fe3c8,
		"Enemy::@5320": 0x803fe3d4,
		"Enemy::@5321": 0x803fe3e0,
		"Enemy::@5322": 0x803fe3ec,
		"Enemy::@5323": 0x803fe3f8,
		"Enemy::@4133": 0x803fe45c,
		"Enemy::@9236": 0x803fe498,
		"@9236": 0x803fe498,
		"Enemy::@9237": 0x803fe4a4,
		"@9237": 0x803fe4a4,
		"Enemy::@9238": 0x803fe4b0,
		"@9238": 0x803fe4b0,
		"Enemy::@9239": 0x803fe4bc,
		"@9239": 0x803fe4bc,
		"Enemy::@9240": 0x803fe4c8,
		"@9240": 0x803fe4c8,
		"Enemy::@9241": 0x803fe4d4,
		"@9241": 0x803fe4d4,
		"Enemy::@9242": 0x803fe4e0,
		"@9242": 0x803fe4e0,
		"Enemy::@9243": 0x803fe4ec,
		"@9243": 0x803fe4ec,
		"Enemy::@9244": 0x803fe4f8,
		"@9244": 0x803fe4f8,
		"Enemy::@9245": 0x803fe504,
		"@9245": 0x803fe504,
		"Enemy::@9246": 0x803fe510,
		"@9246": 0x803fe510,
		"Enemy::@9247": 0x803fe51c,
		"@9247": 0x803fe51c,
		"Enemy::@9248": 0x803fe528,
		"@9248": 0x803fe528,
		"Enemy::@9249": 0x803fe534,
		"@9249": 0x803fe534,
		"Enemy::@9250": 0x803fe540,
		"@9250": 0x803fe540,
		"Enemy::@4266": 0x803fe5b4,
		"Enemy::@4267": 0x803fe5c0,
		"Enemy::@4268": 0x803fe5cc,
		"Enemy::@4270": 0x803fe5e4,
		"Enemy::@4273": 0x803fe608,
		"@4273": 0x803fe608,
		"Enemy::@4274": 0x803fe614,
		"Enemy::@4275": 0x803fe620,
		"Enemy::@4280": 0x803fe65c,
		"Enemy::@3409": 0x803fe6a4,
		"Enemy::@6263": 0x803fe6c8,
		"@6263": 0x803fe6c8,
		"Enemy::@6264": 0x803fe6d4,
		"@6264": 0x803fe6d4,
		"Enemy::@6266": 0x803fe6ec,
		"@6266": 0x803fe6ec,
		"Enemy::@6269": 0x803fe710,
		"@6269": 0x803fe710,
		"Enemy::@6270": 0x803fe71c,
		"@6270": 0x803fe71c,
		"Enemy::@6271": 0x803fe728,
		"@6271": 0x803fe728,
		"Enemy::@6272": 0x803fe734,
		"@6272": 0x803fe734,
		"Enemy::@6273": 0x803fe740,
		"@6273": 0x803fe740,
		"Enemy::@6274": 0x803fe74c,
		"@6274": 0x803fe74c,
		"Enemy::@6275": 0x803fe758,
		"@6275": 0x803fe758,
		"Enemy::@6276": 0x803fe764,
		"@6276": 0x803fe764,
		"Enemy::@6277": 0x803fe770,
		"@6277": 0x803fe770,
		"Enemy::@9463": 0x803fe84c,
		"@9463": 0x803fe84c,
		"Enemy::@9464": 0x803fe858,
		"@9464": 0x803fe858,
		"Enemy::@9465": 0x803fe864,
		"@9465": 0x803fe864,
		"Enemy::@9466": 0x803fe870,
		"@9466": 0x803fe870,
		"Enemy::@9467": 0x803fe87c,
		"@9467": 0x803fe87c,
		"Enemy::@9468": 0x803fe888,
		"@9468": 0x803fe888,
		"Enemy::@9469": 0x803fe894,
		"@9469": 0x803fe894,
		"Enemy::@9470": 0x803fe8a0,
		"@9470": 0x803fe8a0,
		"Enemy::@9471": 0x803fe8ac,
		"@9471": 0x803fe8ac,
		"Enemy::@9472": 0x803fe8b8,
		"@9472": 0x803fe8b8,
		"Enemy::@9473": 0x803fe8c4,
		"@9473": 0x803fe8c4,
		"Enemy::@9474": 0x803fe8d0,
		"@9474": 0x803fe8d0,
		"Enemy::@9475": 0x803fe8dc,
		"@9475": 0x803fe8dc,
		"Enemy::@9476": 0x803fe8e8,
		"@9476": 0x803fe8e8,
		"Enemy::@9477": 0x803fe8f4,
		"@9477": 0x803fe8f4,
		"Enemy::@4652": 0x803fe99c,
		"Enemy::@4654": 0x803fe9b4,
		"Enemy::@5992": 0x803feabc,
		"Enemy::@5993": 0x803feac8,
		"Enemy::@5446": 0x803feb68,
		"Enemy::@5453": 0x803febbc,
		"Enemy::@5454": 0x803febc8,
		"Enemy::@5455": 0x803febd4,
		"Enemy::@2265": 0x803fec20,
		"Enemy::up$2718": 0x803fec38,
		"up$2718": 0x803fec38,
		"Enemy::up$2732": 0x803fec44,
		"up$2732": 0x803fec44,
		"Enemy::@4906": 0x803fed20,
		"Enemy::@2400": 0x803fee08,
		"Enemy::@2409": 0x803fee14,
		"Enemy::@2647": 0x803fee2c,
		"Enemy::@2648": 0x803fee38,
		"Enemy::@2649": 0x803fee44,
		"Enemy::@2650": 0x803fee50,
		"Enemy::@2651": 0x803fee5c,
		"Enemy::@2652": 0x803fee68,
		"Enemy::@2653": 0x803fee74,
		"Enemy::@3818": 0x803feef8,
		"Enemy::@3819": 0x803fef04,
		"Enemy::@3820": 0x803fef10,
		"Enemy::@4468": 0x803fefd4,
		"Enemy::@4469": 0x803fefe0,
		"Enemy::@5800": 0x803ff154,
		"@5800": 0x803ff154,
		"Enemy::@5802": 0x803ff16c,
		"@5802": 0x803ff16c,
		"Enemy::@5805": 0x803ff190,
		"@5805": 0x803ff190,
		"Enemy::@5806": 0x803ff19c,
		"@5806": 0x803ff19c,
		"Enemy::@5807": 0x803ff1a8,
		"@5807": 0x803ff1a8,
		"Enemy::@2732": 0x803ff1c4,
		"Enemy::@2733": 0x803ff1d0,
		"Enemy::@2734": 0x803ff1dc,
		"Enemy::@2735": 0x803ff1e8,
		"Enemy::@2736": 0x803ff1f4,
		"Enemy::@2737": 0x803ff200,
		"Enemy::@2738": 0x803ff20c,
		"Enemy::@2739": 0x803ff218,
		"Enemy::@2742": 0x803ff23c,
		"Enemy::@3272": 0x803ff2c4,
		"Enemy::@3273": 0x803ff2d0,
		"Enemy::@6698": 0x803ff400,
		"@6698": 0x803ff400,
		"Enemy::@6699": 0x803ff40c,
		"@6699": 0x803ff40c,
		"Enemy::@6700": 0x803ff418,
		"@6700": 0x803ff418,
		"Enemy::@6701": 0x803ff424,
		"@6701": 0x803ff424,
		"Enemy::@6702": 0x803ff430,
		"@6702": 0x803ff430,
		"Enemy::@6703": 0x803ff43c,
		"@6703": 0x803ff43c,
		"Enemy::@6704": 0x803ff448,
		"@6704": 0x803ff448,
		"Enemy::@6705": 0x803ff454,
		"Enemy::@6706": 0x803ff460,
		"Enemy::@6707": 0x803ff46c,
		"@6707": 0x803ff46c,
		"Enemy::@6708": 0x803ff478,
		"@6708": 0x803ff478,
		"Enemy::@6709": 0x803ff484,
		"Enemy::@6710": 0x803ff490,
		"@6710": 0x803ff490,
		"Enemy::@6711": 0x803ff49c,
		"@6711": 0x803ff49c,
		"Enemy::@6712": 0x803ff4a8,
		"@6712": 0x803ff4a8,
		"Enemy::@4138": 0x803ff690,
		"Enemy::@4139": 0x803ff69c,
		"Enemy::@4140": 0x803ff6a8,
		"Enemy::@5909": 0x803ff974,
		"Enemy::@5910": 0x803ff980,
		"Enemy::@5911": 0x803ff98c,
		"Enemy::@5912": 0x803ff998,
		"Enemy::@5913": 0x803ff9a4,
		"Enemy::@5914": 0x803ff9b0,
		"Enemy::@5916": 0x803ff9c8,
		"Enemy::@5917": 0x803ff9d4,
		"Enemy::TKoopaJr_jointIndexTable": 0x803ffb18,
		"TKoopaJr_jointIndexTable": 0x803ffb18,
		"Enemy::@6227": 0x803ffb8c,
		"@6227": 0x803ffb8c,
		"Enemy::@6228": 0x803ffb98,
		"@6228": 0x803ffb98,
		"Enemy::@6230": 0x803ffbb0,
		"@6230": 0x803ffbb0,
		"Enemy::@6231": 0x803ffbbc,
		"@6231": 0x803ffbbc,
		"Enemy::@6232": 0x803ffbc8,
		"@6232": 0x803ffbc8,
		"Enemy::@6234": 0x803ffbe0,
		"@6234": 0x803ffbe0,
		"Enemy::@6236": 0x803ffbf8,
		"@6236": 0x803ffbf8,
		"Enemy::@6238": 0x803ffc10,
		"@6238": 0x803ffc10,
		"Enemy::@6239": 0x803ffc1c,
		"@6239": 0x803ffc1c,
		"Enemy::@6240": 0x803ffc28,
		"@6240": 0x803ffc28,
		"Enemy::@2675": 0x803ffc4c,
		"Enemy::@4839": 0x803ffe34,
		"Enemy::@4842": 0x803ffe58,
		"Enemy::@4845": 0x803ffe7c,
		"Enemy::@4846": 0x803ffe88,
		"Enemy::@4847": 0x803ffe94,
		"Enemy::@4850": 0x803ffeb8,
		"Enemy::@4851": 0x803ffec4,
		"Enemy::@2542": 0x803ffedc,
		"Enemy::@2576": 0x803fff00,
		"Enemy::@3891": 0x80400104,
		"Enemy::@3892": 0x80400110,
		"Enemy::@4981": 0x8040033c,
		"Enemy::@5480": 0x80400408,
		"Enemy::@5481": 0x80400414,
		"Enemy::@5485": 0x80400444,
		"Enemy::@3846": 0x80400504,
		"Enemy::@3847": 0x80400510,
		"Enemy::@3850": 0x80400534,
		"Enemy::@3852": 0x8040054c,
		"Camera::@3186": 0x80400598,
		"Camera::@3187": 0x804005a4,
		"Camera::@3188": 0x804005b0,
		"Camera::@3189": 0x804005bc,
		"Camera::@3190": 0x804005c8,
		"Camera::@3191": 0x804005d4,
		"Camera::@3192": 0x804005e0,
		"Camera::@3193": 0x804005ec,
		"Camera::@3194": 0x804005f8,
		"Camera::@3195": 0x80400604,
		"Camera::@3196": 0x80400610,
		"Camera::@3197": 0x8040061c,
		"Camera::@3198": 0x80400628,
		"Camera::@3199": 0x80400634,
		"Camera::@3200": 0x80400640,
		"Camera::CLBConstUpVec": 0x80400650,
		"CLBConstUpVec": 0x80400650,
		"Camera::@2254": 0x80400708,
		"Camera::@2284": 0x80400718,
		"Camera::@2285": 0x80400724,
		"Camera::@2286": 0x80400730,
		"@2286": 0x80400730,
		"Camera::@2287": 0x8040073c,
		"Camera::@2288": 0x80400748,
		"@2288": 0x80400748,
		"Camera::@2289": 0x80400754,
		"Camera::@2290": 0x80400760,
		"Camera::@2291": 0x8040076c,
		"Camera::@2292": 0x80400778,
		"Camera::@2293": 0x80400784,
		"Camera::@2294": 0x80400790,
		"Camera::@2295": 0x8040079c,
		"Camera::@2296": 0x804007a8,
		"Camera::@2297": 0x804007b4,
		"Camera::@2298": 0x804007c0,
		"Animal::@2300": 0x804007d0,
		"Animal::@3346": 0x804007e0,
		"Animal::@3348": 0x804007f8,
		"Animal::@3349": 0x80400804,
		"Animal::@3350": 0x80400810,
		"Animal::@3351": 0x8040081c,
		"Animal::@3352": 0x80400828,
		"Animal::@3353": 0x80400834,
		"Animal::@3354": 0x80400840,
		"Animal::@3355": 0x8040084c,
		"Animal::@3356": 0x80400858,
		"Animal::@3357": 0x80400864,
		"Animal::@3358": 0x80400870,
		"Animal::@3359": 0x8040087c,
		"Animal::@3360": 0x80400888,
		"Animal::@2617": 0x804008a4,
		"Animal::@2618": 0x804008b0,
		"Animal::@2619": 0x804008bc,
		"Animal::@2620": 0x804008c8,
		"Animal::@2621": 0x804008d4,
		"Animal::@2622": 0x804008e0,
		"Animal::@2623": 0x804008ec,
		"Animal::@2624": 0x804008f8,
		"Animal::@2625": 0x80400904,
		"Animal::@2626": 0x80400910,
		"Animal::@2629": 0x80400934,
		"Animal::@2630": 0x80400940,
		"Animal::@2001": 0x80400950,
		"Animal::@3026": 0x80400960,
		"Animal::@3041": 0x8040096c,
		"Animal::@3056": 0x80400978,
		"Animal::@3068": 0x80400984,
		"Animal::@3078": 0x80400990,
		"Animal::@3097": 0x8040099c,
		"Animal::@3105": 0x804009a8,
		"Animal::@3117": 0x804009b4,
		"Animal::@3129": 0x804009c0,
		"Animal::@4981": 0x804009cc,
		"Animal::@4982": 0x804009d8,
		"Animal::@4983": 0x804009e4,
		"Animal::@4984": 0x804009f0,
		"Animal::@4985": 0x804009fc,
		"Animal::@4986": 0x80400a08,
		"Animal::@4987": 0x80400a14,
		"Animal::@4988": 0x80400a20,
		"Animal::@4989": 0x80400a2c,
		"Animal::@4990": 0x80400a38,
		"Animal::@4991": 0x80400a44,
		"Animal::@4992": 0x80400a50,
		"Animal::@4994": 0x80400a68,
		"Animal::@4995": 0x80400a74,
		"Animal::@2990": 0x80400a80,
		"Animal::@3004": 0x80400a8c,
		"Animal::@3014": 0x80400a98,
		"Animal::@3036": 0x80400ab0,
		"Animal::@3048": 0x80400abc,
		"Animal::@5213": 0x80400ac8,
		"Animal::@5214": 0x80400ad4,
		"Animal::@5215": 0x80400ae0,
		"Animal::@5216": 0x80400aec,
		"Animal::@5217": 0x80400af8,
		"Animal::@5218": 0x80400b04,
		"Animal::@5219": 0x80400b10,
		"Animal::@5220": 0x80400b1c,
		"Animal::@5221": 0x80400b28,
		"Animal::@5222": 0x80400b34,
		"Animal::@5223": 0x80400b40,
		"Animal::@5224": 0x80400b4c,
		"Animal::@5225": 0x80400b58,
		"Animal::@5226": 0x80400b64,
		"Animal::@5227": 0x80400b70,
		"Animal::@2422": 0x80400b80,
		"JKRAramHeap::sAramList": 0x80400b8c,
		"sAramList": 0x80400b8c,
		"JKRAram::sAramCommandList": 0x80400b98,
		"sAramCommandList": 0x80400b98,
		"JKRDvdFile::sDvdList": 0x80400ba4,
		"sDvdList": 0x80400ba4,
		"JKRFileLoader::sVolumeList": 0x80400bb0,
		"sVolumeList": 0x80400bb0,
		"JKRThread::sThreadList": 0x80400bbc,
		"sThreadList": 0x80400bbc,
		"JUTException::sMapFileList": 0x80400bc8,
		"sMapFileList": 0x80400bc8,
		"JUTGamePad::mPadList": 0x80400bd4,
		"mPadList": 0x80400bd4,
		"JUTGamePad::mPadStatus": 0x80400d50,
		"mPadStatus": 0x80400d50,
		"JUTGamePad::mPadButton": 0x80400d80,
		"mPadButton": 0x80400d80,
		"JUTGamePad::mPadMStick": 0x80400e40,
		"mPadMStick": 0x80400e40,
		"JUTGamePad::mPadSStick": 0x80400e80,
		"mPadSStick": 0x80400e80,
		"J2DPrint::mMutex": 0x80400ec0,
		"JSystem::j3dSys": 0x80400ed8,
		"j3dSys": 0x80400ed8,
		"J3DSys::mCurrentMtx": 0x80401084,
		"mCurrentMtx": 0x80401084,
		"J3DSys::mCurrentS": 0x804010b4,
		"mCurrentS": 0x804010b4,
		"J3DSys::mParentS": 0x804010c0,
		"mParentS": 0x804010c0,
		"J3DSys::sTexCoordScaleTable": 0x804010cc,
		"sTexCoordScaleTable": 0x804010cc,
		"JKRDvdRipper::sDvdAsyncList": 0x8040110c,
		"sDvdAsyncList": 0x8040110c,
		"JKRDvdAramRipper::sDvdAramAsyncList": 0x80401118,
		"sDvdAramAsyncList": 0x80401118,
		"JSystem::j3dTexCoordTable": 0x80401124,
		"j3dTexCoordTable": 0x80401124,
		"JSystem::j3dTevSwapTableTable": 0x8040364c,
		"j3dTevSwapTableTable": 0x8040364c,
		"JSystem::j3dAlphaCmpTable": 0x80403a4c,
		"j3dAlphaCmpTable": 0x80403a4c,
		"JSystem::j3dZModeTable": 0x80403d4c,
		"j3dZModeTable": 0x80403d4c,
		"JKRAramPiece::sAramPieceCommandList": 0x80403dac,
		"sAramPieceCommandList": 0x80403dac,
		"JKRAramPiece::mMutex": 0x80403dd0,
		"JSystem::JAInullCamera": 0x80403de8,
		"JAInullCamera": 0x80403de8,
		"JAIConst::nullActor": 0x80403df4,
		"nullActor": 0x80403df4,
		"JAIConst::camMtx": 0x80403e4c,
		"camMtx": 0x80403e4c,
		"JAIConst::camTrans": 0x80403e7c,
		"camTrans": 0x80403e7c,
		"JAIConst::camPreTrans": 0x80403e88,
		"camPreTrans": 0x80403e88,
		"JAInter::StreamLib::streamHeap": 0x80403e94,
		"streamHeap": 0x80403e94,
		"JAISystemInterface::systemPortCmd": 0x80403ea8,
		"systemPortCmd": 0x80403ea8,
		"JASystem::TTrack::sParser": 0x80408820,
		"sParser": 0x80408820,
		"JPADraw::vc": 0x80408824,
		"vc": 0x80408824,
		"JPADraw::cb": 0x80408a10,
		"JSystem::rootPath$1763": 0x80408ac0,
		"rootPath$1763": 0x80408ac0,
		"JUTException::sMessageBuffer": 0x80408ac8,
		"JUTGamePad::mStickMode": 0x80408ad0,
		"mStickMode": 0x80408ad0,
		"JUTGamePad::C3ButtonReset::sResetPattern": 0x80408ad4,
		"sResetPattern": 0x80408ad4,
		"JSystem::Unit01": 0x80408ad8,
		"JSystem::J3DUnit01": 0x80408ae0,
		"J3DUnit01": 0x80408ae0,
		"JKRDvdRipper::szpBufferSize": 0x80408aec,
		"JKRDvdAramRipper::szpBufferSize": 0x80408af4,
		"JSystem::GXTexMode0Ids": 0x80408af8,
		"GXTexMode0Ids": 0x80408af8,
		"JSystem::GXTexMode1Ids": 0x80408b00,
		"GXTexMode1Ids": 0x80408b00,
		"JSystem::GXTexImage0Ids": 0x80408b08,
		"GXTexImage0Ids": 0x80408b08,
		"JSystem::GXTexImage1Ids": 0x80408b10,
		"GXTexImage1Ids": 0x80408b10,
		"JSystem::GXTexImage2Ids": 0x80408b18,
		"GXTexImage2Ids": 0x80408b18,
		"JSystem::GXTexImage3Ids": 0x80408b20,
		"GXTexImage3Ids": 0x80408b20,
		"JSystem::GXTexTlutIds": 0x80408b28,
		"GXTexTlutIds": 0x80408b28,
		"JSystem::GX2HWFiltConv": 0x80408b30,
		"JSystem::j3dDefaultColInfo": 0x80408b38,
		"j3dDefaultColInfo": 0x80408b38,
		"JSystem::j3dDefaultAmbInfo": 0x80408b3c,
		"j3dDefaultAmbInfo": 0x80408b3c,
		"JSystem::j3dDefaultTevOrderInfoNull": 0x80408b44,
		"j3dDefaultTevOrderInfoNull": 0x80408b44,
		"JSystem::j3dDefaultIndTexOrderNull": 0x80408b48,
		"j3dDefaultIndTexOrderNull": 0x80408b48,
		"JSystem::j3dDefaultTevColor": 0x80408b4c,
		"j3dDefaultTevColor": 0x80408b4c,
		"JSystem::j3dDefaultIndTexCoordScaleInfo": 0x80408b54,
		"j3dDefaultIndTexCoordScaleInfo": 0x80408b54,
		"JSystem::j3dDefaultTevKColor": 0x80408b58,
		"j3dDefaultTevKColor": 0x80408b58,
		"JSystem::j3dDefaultTevSwapMode": 0x80408b5c,
		"j3dDefaultTevSwapMode": 0x80408b5c,
		"JSystem::j3dDefaultTevSwapModeTable": 0x80408b60,
		"j3dDefaultTevSwapModeTable": 0x80408b60,
		"JSystem::j3dDefaultBlendInfo": 0x80408b64,
		"j3dDefaultBlendInfo": 0x80408b64,
		"JSystem::j3dDefaultColorChanInfo": 0x80408b68,
		"j3dDefaultColorChanInfo": 0x80408b68,
		"JSystem::JRNTexImage1Ids": 0x80408b80,
		"JRNTexImage1Ids": 0x80408b80,
		"JSystem::JRNTexImage2Ids": 0x80408b88,
		"JRNTexImage2Ids": 0x80408b88,
		"JALCalc::cEqualCSlope": 0x80408b90,
		"cEqualCSlope": 0x80408b90,
		"JALCalc::cPlusPSlope": 0x80408b94,
		"cPlusPSlope": 0x80408b94,
		"JAInter::TAsnData::asnFileName": 0x80408b98,
		"asnFileName": 0x80408b98,
		"JAInter::StreamLib::LOOP_BLOCKS": 0x80408ba0,
		"LOOP_BLOCKS": 0x80408ba0,
		"JAInter::StreamLib::LOOP_SAMPLESIZE": 0x80408ba4,
		"LOOP_SAMPLESIZE": 0x80408ba4,
		"JAInter::StreamLib::outputmode": 0x80408ba8,
		"outputmode": 0x80408ba8,
		"JAIGlobalParameter::soundSceneMax": 0x80408bb8,
		"soundSceneMax": 0x80408bb8,
		"JAIGlobalParameter::seRegistMax": 0x80408bbc,
		"seRegistMax": 0x80408bbc,
		"JAIGlobalParameter::seTrackMax": 0x80408bc0,
		"seTrackMax": 0x80408bc0,
		"JAIGlobalParameter::seqTrackMax": 0x80408bc4,
		"seqTrackMax": 0x80408bc4,
		"JAIGlobalParameter::seqPlayTrackMax": 0x80408bc8,
		"seqPlayTrackMax": 0x80408bc8,
		"JAIGlobalParameter::seqControlBufferMax": 0x80408bcc,
		"seqControlBufferMax": 0x80408bcc,
		"JAIGlobalParameter::streamControlBufferMax": 0x80408bd0,
		"streamControlBufferMax": 0x80408bd0,
		"JAIGlobalParameter::streamParameterBufferMax": 0x80408bd4,
		"streamParameterBufferMax": 0x80408bd4,
		"JAIGlobalParameter::autoHeapMax": 0x80408bd8,
		"autoHeapMax": 0x80408bd8,
		"JAIGlobalParameter::stayHeapMax": 0x80408bdc,
		"stayHeapMax": 0x80408bdc,
		"JAIGlobalParameter::autoHeapRoomSize": 0x80408be0,
		"autoHeapRoomSize": 0x80408be0,
		"JAIGlobalParameter::stayHeapSize": 0x80408be4,
		"stayHeapSize": 0x80408be4,
		"JAIGlobalParameter::seInfoFileName": 0x80408be8,
		"seInfoFileName": 0x80408be8,
		"JAIGlobalParameter::seqInfoFileName": 0x80408bec,
		"seqInfoFileName": 0x80408bec,
		"JAIGlobalParameter::streamInfoFileName": 0x80408bf0,
		"streamInfoFileName": 0x80408bf0,
		"JAIGlobalParameter::initDataFileName": 0x80408bf4,
		"initDataFileName": 0x80408bf4,
		"JAIGlobalParameter::wavePath": 0x80408bf8,
		"wavePath": 0x80408bf8,
		"JAIGlobalParameter::sequenceArchivesPath": 0x80408bfc,
		"sequenceArchivesPath": 0x80408bfc,
		"JAIGlobalParameter::streamPath": 0x80408c00,
		"streamPath": 0x80408c00,
		"JAIGlobalParameter::sequenceArchivesFileName": 0x80408c04,
		"sequenceArchivesFileName": 0x80408c04,
		"JAIGlobalParameter::inputGainDown": 0x80408c08,
		"inputGainDown": 0x80408c08,
		"JAIGlobalParameter::outputGainUp": 0x80408c0c,
		"outputGainUp": 0x80408c0c,
		"JAIGlobalParameter::distanceMax": 0x80408c10,
		"distanceMax": 0x80408c10,
		"JAIGlobalParameter::maxVolumeDistance": 0x80408c14,
		"maxVolumeDistance": 0x80408c14,
		"JAIGlobalParameter::seDolbyCenterValue": 0x80408c18,
		"seDolbyCenterValue": 0x80408c18,
		"JAIGlobalParameter::seDolbyFrontDistanceMax": 0x80408c1c,
		"seDolbyFrontDistanceMax": 0x80408c1c,
		"JAIGlobalParameter::seDolbyBehindDistanceMax": 0x80408c20,
		"seDolbyBehindDistanceMax": 0x80408c20,
		"JAIGlobalParameter::dopplarMoveTime": 0x80408c24,
		"dopplarMoveTime": 0x80408c24,
		"JAIGlobalParameter::dummyPositionMax": 0x80408c28,
		"dummyPositionMax": 0x80408c28,
		"JAIGlobalParameter::seqMuteMoveSpeedSePlay": 0x80408c2c,
		"seqMuteMoveSpeedSePlay": 0x80408c2c,
		"JAIGlobalParameter::audioCameraMax": 0x80408c30,
		"audioCameraMax": 0x80408c30,
		"JAIGlobalParameter::systemTrackMax": 0x80408c34,
		"systemTrackMax": 0x80408c34,
		"JAIGlobalParameter::systemRootTrackMax": 0x80408c38,
		"systemRootTrackMax": 0x80408c38,
		"JAIGlobalParameter::panDistanceMax": 0x80408c3c,
		"panDistanceMax": 0x80408c3c,
		"JAIGlobalParameter::panDistance2Max": 0x80408c40,
		"panDistance2Max": 0x80408c40,
		"JAIGlobalParameter::panAngleParameter": 0x80408c44,
		"panAngleParameter": 0x80408c44,
		"JAIGlobalParameter::panAngleParameter2": 0x80408c48,
		"panAngleParameter2": 0x80408c48,
		"JAIGlobalParameter::dopplarParameter": 0x80408c4c,
		"dopplarParameter": 0x80408c4c,
		"JAIGlobalParameter::seDistancepitchMax": 0x80408c54,
		"seDistancepitchMax": 0x80408c54,
		"JASystem::Driver::DSPQueue::waitMax": 0x80408c58,
		"waitMax": 0x80408c58,
		"JASystem::Driver::JAS_SYSTEM_OUTPUT_MODE": 0x80408c64,
		"JAS_SYSTEM_OUTPUT_MODE": 0x80408c64,
		"JASystem::Driver::DSP_VOICE_WAITS_MAX": 0x80408c6c,
		"DSP_VOICE_WAITS_MAX": 0x80408c6c,
		"JASystem::TDSPChannel::smnFree": 0x80408c70,
		"smnFree": 0x80408c70,
		"JASystem::DSP_LIMIT_RATIO": 0x80408c74,
		"DSP_LIMIT_RATIO": 0x80408c74,
		"JSystem::COMP_BLOCKSAMPLES$234": 0x80408c7c,
		"COMP_BLOCKSAMPLES$234": 0x80408c7c,
		"JSystem::COMP_BLOCKBYTES$235": 0x80408c84,
		"COMP_BLOCKBYTES$235": 0x80408c84,
		"JASystem::Kernel::maxCallbacksUser": 0x80408c90,
		"maxCallbacksUser": 0x80408c90,
		"JASystem::Dvd::dvdMsgsSize": 0x80408c98,
		"dvdMsgsSize": 0x80408c98,
		"JASystem::Dvd::dvdBufSize": 0x80408c9c,
		"dvdBufSize": 0x80408c9c,
		"JASystem::Dvd::maxDics": 0x80408ca0,
		"maxDics": 0x80408ca0,
		"JASystem::HardStream::playListMax": 0x80408ca8,
		"playListMax": 0x80408ca8,
		"JASystem::Kernel::gDacRate": 0x80408cb0,
		"gDacRate": 0x80408cb0,
		"JASystem::Kernel::gSubFrames": 0x80408cb4,
		"gSubFrames": 0x80408cb4,
		"JASystem::Kernel::gFrameSamples": 0x80408cb8,
		"gFrameSamples": 0x80408cb8,
		"JASystem::Kernel::gDacSize": 0x80408cbc,
		"gDacSize": 0x80408cbc,
		"JASystem::Kernel::audioDramSize": 0x80408cc0,
		"audioDramSize": 0x80408cc0,
		"JASystem::Kernel::audioAramSize": 0x80408cc4,
		"audioAramSize": 0x80408cc4,
		"JASystem::Vload::vlMaxArcs": 0x80408cc8,
		"vlMaxArcs": 0x80408cc8,
		"JASystem::Player::sV0": 0x80408cd0,
		"sV0": 0x80408cd0,
		"JASystem::Player::sV1": 0x80408cd4,
		"sV1": 0x80408cd4,
		"Runtime.PPCEABI.H::fragmentID": 0x80408ce0,
		"fragmentID": 0x80408ce0,
		"MSL_C.PPCEABI.bare.H::@wstringBase0": 0x80408ce8,
		"@wstringBase0": 0x80408ce8,
		"MSL_C.PPCEABI.bare.H::next": 0x80408cf0,
		"MSL_C.PPCEABI.bare.H::K1": 0x80408cf8,
		"K1": 0x80408cf8,
		"MSL_C.PPCEABI.bare.H::K2": 0x80408cfc,
		"K2": 0x80408cfc,
		"os::__OSCurrHeap": 0x80408d00,
		"__OSCurrHeap": 0x80408d00,
		"os::__OSArenaLo": 0x80408d08,
		"__OSArenaLo": 0x80408d08,
		"os::@32": 0x80408d10,
		"mtx::Unit01": 0x80408d20,
		"dvd::FirstRead": 0x80408d28,
		"FirstRead": 0x80408d28,
		"dvd::@116": 0x80408d30,
		"dvd::autoInvalidation": 0x80408d38,
		"autoInvalidation": 0x80408d38,
		"dvd::@35": 0x80408d40,
		"dvd::@40": 0x80408d44,
		"dvd::@41": 0x80408d48,
		"pad::ClampRegion": 0x80408d50,
		"ClampRegion": 0x80408d50,
		"pad::ResettingChan": 0x80408d58,
		"ResettingChan": 0x80408d58,
		"pad::XPatchBits": 0x80408d5c,
		"XPatchBits": 0x80408d5c,
		"pad::AnalogMode": 0x80408d60,
		"AnalogMode": 0x80408d60,
		"pad::Spec": 0x80408d64,
		"Spec": 0x80408d64,
		"pad::MakeStatus": 0x80408d68,
		"MakeStatus": 0x80408d68,
		"pad::CmdReadOrigin": 0x80408d6c,
		"CmdReadOrigin": 0x80408d6c,
		"pad::CmdCalibrate": 0x80408d70,
		"CmdCalibrate": 0x80408d70,
		"card::next": 0x80408d78,
		"gx::gx": 0x80408d88,
		"gx::tbl1$215": 0x80408d90,
		"tbl1$215": 0x80408d90,
		"gx::tbl2$216": 0x80408d94,
		"tbl2$216": 0x80408d94,
		"gx::tbl3$217": 0x80408d98,
		"tbl3$217": 0x80408d98,
		"gx::GX2HWFiltConv": 0x80408da0,
		"gd::cm2hw$400": 0x80408db0,
		"cm2hw$400": 0x80408db0,
		"gd::cm2hw$515": 0x80408db4,
		"cm2hw$515": 0x80408db4,
		"MarioUtil::className$1930": 0x80408dc8,
		"className$1930": 0x80408dc8,
		"MarioUtil::className$1944": 0x80408dd0,
		"className$1944": 0x80408dd0,
		"TMBindShadowManager::mSquareShadowHeight": 0x80408dd8,
		"mSquareShadowHeight": 0x80408dd8,
		"TMBindShadowManager::mTreeScale": 0x80408ddc,
		"mTreeScale": 0x80408ddc,
		"TMBindShadowManager::mYScalePlus": 0x80408de0,
		"mYScalePlus": 0x80408de0,
		"MarioUtil::ColorBlack": 0x80408de8,
		"ColorBlack": 0x80408de8,
		"MarioUtil::ColorWhite": 0x80408dec,
		"ColorWhite": 0x80408dec,
		"RumbleMgr::mMotorCountLimit": 0x80408df0,
		"mMotorCountLimit": 0x80408df0,
		"RumbleMgr::mPowerThreshold": 0x80408df8,
		"mPowerThreshold": 0x80408df8,
		"MarioUtil::rumblePoint_00": 0x80408e00,
		"rumblePoint_00": 0x80408e00,
		"MarioUtil::rumblePoint_01": 0x80408e04,
		"rumblePoint_01": 0x80408e04,
		"MarioUtil::rumblePoint_02": 0x80408e08,
		"rumblePoint_02": 0x80408e08,
		"MarioUtil::rumbleFrame_02": 0x80408e0c,
		"rumbleFrame_02": 0x80408e0c,
		"MarioUtil::rumblePower_02": 0x80408e14,
		"rumblePower_02": 0x80408e14,
		"MarioUtil::rumblePoint_03": 0x80408e1c,
		"rumblePoint_03": 0x80408e1c,
		"MarioUtil::rumbleFrame_03": 0x80408e20,
		"rumbleFrame_03": 0x80408e20,
		"MarioUtil::rumblePower_03": 0x80408e28,
		"rumblePower_03": 0x80408e28,
		"MarioUtil::rumblePoint_04": 0x80408e30,
		"rumblePoint_04": 0x80408e30,
		"MarioUtil::rumblePoint_05": 0x80408e34,
		"rumblePoint_05": 0x80408e34,
		"MarioUtil::rumblePoint_06": 0x80408e38,
		"rumblePoint_06": 0x80408e38,
		"MarioUtil::rumblePoint_07": 0x80408e3c,
		"rumblePoint_07": 0x80408e3c,
		"MarioUtil::rumblePoint_08": 0x80408e40,
		"rumblePoint_08": 0x80408e40,
		"MarioUtil::rumblePoint_09": 0x80408e44,
		"rumblePoint_09": 0x80408e44,
		"MarioUtil::rumblePoint_10": 0x80408e48,
		"rumblePoint_10": 0x80408e48,
		"MarioUtil::rumbleFrame_10": 0x80408e4c,
		"rumbleFrame_10": 0x80408e4c,
		"MarioUtil::rumblePower_10": 0x80408e50,
		"rumblePower_10": 0x80408e50,
		"MarioUtil::rumblePoint_11": 0x80408e54,
		"rumblePoint_11": 0x80408e54,
		"MarioUtil::rumbleFrame_11": 0x80408e58,
		"rumbleFrame_11": 0x80408e58,
		"MarioUtil::rumblePower_11": 0x80408e5c,
		"rumblePower_11": 0x80408e5c,
		"MarioUtil::rumblePoint_12": 0x80408e60,
		"rumblePoint_12": 0x80408e60,
		"MarioUtil::rumbleFrame_12": 0x80408e64,
		"rumbleFrame_12": 0x80408e64,
		"MarioUtil::rumblePower_12": 0x80408e68,
		"rumblePower_12": 0x80408e68,
		"MarioUtil::rumblePoint_13": 0x80408e6c,
		"rumblePoint_13": 0x80408e6c,
		"MarioUtil::rumbleFrame_13": 0x80408e70,
		"rumbleFrame_13": 0x80408e70,
		"MarioUtil::rumblePower_13": 0x80408e74,
		"rumblePower_13": 0x80408e74,
		"MarioUtil::rumblePoint_14": 0x80408e78,
		"rumblePoint_14": 0x80408e78,
		"MarioUtil::rumbleFrame_14": 0x80408e7c,
		"rumbleFrame_14": 0x80408e7c,
		"MarioUtil::rumblePower_14": 0x80408e80,
		"rumblePower_14": 0x80408e80,
		"MarioUtil::rumblePoint_15": 0x80408e84,
		"rumblePoint_15": 0x80408e84,
		"MarioUtil::rumbleFrame_15": 0x80408e88,
		"rumbleFrame_15": 0x80408e88,
		"MarioUtil::rumblePower_15": 0x80408e8c,
		"rumblePower_15": 0x80408e8c,
		"MarioUtil::rumblePoint_16": 0x80408e90,
		"rumblePoint_16": 0x80408e90,
		"MarioUtil::rumbleFrame_16": 0x80408e94,
		"rumbleFrame_16": 0x80408e94,
		"MarioUtil::rumblePower_16": 0x80408e98,
		"rumblePower_16": 0x80408e98,
		"MarioUtil::rumblePoint_17": 0x80408e9c,
		"rumblePoint_17": 0x80408e9c,
		"MarioUtil::rumbleFrame_17": 0x80408ea0,
		"rumbleFrame_17": 0x80408ea0,
		"MarioUtil::rumblePower_17": 0x80408ea4,
		"rumblePower_17": 0x80408ea4,
		"MarioUtil::rumblePoint_18": 0x80408ea8,
		"rumblePoint_18": 0x80408ea8,
		"MarioUtil::rumbleFrame_18": 0x80408eac,
		"rumbleFrame_18": 0x80408eac,
		"MarioUtil::rumblePower_18": 0x80408eb0,
		"rumblePower_18": 0x80408eb0,
		"MarioUtil::rumblePoint_19": 0x80408eb4,
		"rumblePoint_19": 0x80408eb4,
		"MarioUtil::rumblePoint_20": 0x80408eb8,
		"rumblePoint_20": 0x80408eb8,
		"MarioUtil::rumbleFrame_20": 0x80408ebc,
		"rumbleFrame_20": 0x80408ebc,
		"MarioUtil::rumblePower_20": 0x80408ec4,
		"rumblePower_20": 0x80408ec4,
		"MarioUtil::rumblePoint_21": 0x80408ecc,
		"rumblePoint_21": 0x80408ecc,
		"MarioUtil::rumbleFrame_21": 0x80408ed0,
		"rumbleFrame_21": 0x80408ed0,
		"MarioUtil::rumblePower_21": 0x80408ed8,
		"rumblePower_21": 0x80408ed8,
		"MarioUtil::rumblePoint_22": 0x80408ee0,
		"rumblePoint_22": 0x80408ee0,
		"MarioUtil::rumbleFrame_22": 0x80408ee4,
		"rumbleFrame_22": 0x80408ee4,
		"MarioUtil::rumblePower_22": 0x80408eec,
		"rumblePower_22": 0x80408eec,
		"MarioUtil::rumblePoint_23": 0x80408ef4,
		"rumblePoint_23": 0x80408ef4,
		"MarioUtil::rumblePoint_24": 0x80408ef8,
		"rumblePoint_24": 0x80408ef8,
		"MarioUtil::channelNum": 0x80408efc,
		"channelNum": 0x80408efc,
		"M3DUtil::@1211": 0x80408f00,
		"@1211": 0x80408f00,
		"System::sShineViewObjName$3431": 0x80408f08,
		"sShineViewObjName$3431": 0x80408f08,
		"System::stages$3022": 0x80408f10,
		"stages$3022": 0x80408f10,
		"System::cCameraBckNameShineGetInside": 0x80408f18,
		"System::cCameraBckNameShineGetOutside": 0x80408f1c,
		"System::cCameraBckNameGate": 0x80408f20,
		"System::cSunVolumeName": 0x80408f28,
		"System::cSunsetVolumeName": 0x80408f2c,
		"System::cTargetArrowBmdFileName": 0x80408f30,
		"cTargetArrowBmdFileName": 0x80408f30,
		"TLiveActor::mVelocityMinY": 0x80408f38,
		"mVelocityMinY": 0x80408f38,
		"NPC::cNpcPartsNameRootJoint": 0x80408f40,
		"cNpcPartsNameRootJoint": 0x80408f40,
		"NPC::cDummyPollutionTexName": 0x80408f48,
		"cDummyPollutionTexName": 0x80408f48,
		"NPC::cRealPollutionTexName": 0x80408f4c,
		"cRealPollutionTexName": 0x80408f4c,
		"NPC::cMonteMDummyStrawTexName": 0x80408f50,
		"cMonteMDummyStrawTexName": 0x80408f50,
		"NPC::cMonteWDummyStrawTexName": 0x80408f54,
		"cMonteWDummyStrawTexName": 0x80408f54,
		"NPC::cMonteMRealStrawTexName": 0x80408f58,
		"cMonteMRealStrawTexName": 0x80408f58,
		"NPC::cMonteWRealStrawTexName": 0x80408f5c,
		"cMonteWRealStrawTexName": 0x80408f5c,
		"NPC::cScreenTexViewObjName": 0x80408f60,
		"cScreenTexViewObjName": 0x80408f60,
		"NPC::cJellyFishDummyScreenTexName": 0x80408f64,
		"cJellyFishDummyScreenTexName": 0x80408f64,
		"NPC::cJellyFishDummyTexName": 0x80408f68,
		"cJellyFishDummyTexName": 0x80408f68,
		"NPC::cJellyFishRealTexName": 0x80408f6c,
		"cJellyFishRealTexName": 0x80408f6c,
		"NPC::cMonteMCommonVolumeName": 0x80408f70,
		"cMonteMCommonVolumeName": 0x80408f70,
		"NPC::cMonteWCommonVolumeName": 0x80408f74,
		"cMonteWCommonVolumeName": 0x80408f74,
		"NPC::cMareMCommonVolumeName": 0x80408f78,
		"cMareMCommonVolumeName": 0x80408f78,
		"NPC::cMareWCommonVolumeName": 0x80408f7c,
		"cMareWCommonVolumeName": 0x80408f7c,
		"NPC::cMareCommonNormalBmtName": 0x80408f80,
		"cMareCommonNormalBmtName": 0x80408f80,
		"NPC::cMareCommonPollutionBmtName": 0x80408f84,
		"cMareCommonPollutionBmtName": 0x80408f84,
		"NPC::cManiyaParentViewObjName": 0x80408f88,
		"cManiyaParentViewObjName": 0x80408f88,
		"NPC::cManiyaChildViewObjName": 0x80408f8c,
		"cManiyaChildViewObjName": 0x80408f8c,
		"NPC::cNotUseFastCubeViewObjName0": 0x80408f90,
		"cNotUseFastCubeViewObjName0": 0x80408f90,
		"NPC::cNotUseFastCubeViewObjName1": 0x80408f94,
		"cNotUseFastCubeViewObjName1": 0x80408f94,
		"NPC::cEyeMaterialName": 0x80408f98,
		"cEyeMaterialName": 0x80408f98,
		"NPC::cNeckJointName": 0x80408f9c,
		"cNeckJointName": 0x80408f9c,
		"TBaseNPC::sWaistJointName$localstatic0$setMtxEffect_": 0x80408fa0,
		"sWaistJointName$localstatic0$setMtxEffect_": 0x80408fa0,
		"NPC::cPeachPartsTextureName": 0x80408fa8,
		"cPeachPartsTextureName": 0x80408fa8,
		"NPC::cPeachHostTextureName": 0x80408fac,
		"cPeachHostTextureName": 0x80408fac,
		"NPC::monteMG_bastable": 0x80408fb0,
		"monteMG_bastable": 0x80408fb0,
		"NPC::mareMD_bastable": 0x80408fb8,
		"mareMD_bastable": 0x80408fb8,
		"MSBgm::smMainVolume": 0x80408fc0,
		"smMainVolume": 0x80408fc0,
		"MSHandle::cPan_MaxAmp": 0x80408fc8,
		"cPan_MaxAmp": 0x80408fc8,
		"MSHandle::cPan_CAdjust": 0x80408fcc,
		"cPan_CAdjust": 0x80408fcc,
		"MSHandle::cPan_CShift": 0x80408fd0,
		"cPan_CShift": 0x80408fd0,
		"MSHandle::cPan_HiSence_Dist": 0x80408fd4,
		"cPan_HiSence_Dist": 0x80408fd4,
		"MSHandle::cMS_DistanceMax_Sence": 0x80408fd8,
		"cMS_DistanceMax_Sence": 0x80408fd8,
		"MSHandle::cDol_0Rad": 0x80408fdc,
		"cDol_0Rad": 0x80408fdc,
		"MSHandle::cDol_HalfRad": 0x80408fe0,
		"cDol_HalfRad": 0x80408fe0,
		"MSHandle::cDol_FullRad": 0x80408fe4,
		"cDol_FullRad": 0x80408fe4,
		"TWoodBarrel::mWaitAppearTime": 0x80408fe8,
		"mWaitAppearTime": 0x80408fe8,
		"TWoodBarrel::mBreakTime": 0x80408fec,
		"mBreakTime": 0x80408fec,
		"TWoodBarrel::mOilBarrelFlushTime": 0x80408ff0,
		"mOilBarrelFlushTime": 0x80408ff0,
		"MoveBG::streetlamp_sink_data": 0x80408ff8,
		"streetlamp_sink_data": 0x80408ff8,
		"MoveBG::lamp_bianco_sink_data": 0x80409000,
		"lamp_bianco_sink_data": 0x80409000,
		"TMapObjGeneral::mNormalLivingTime": 0x80409008,
		"mNormalLivingTime": 0x80409008,
		"TMapObjGeneral::mNormalFlushTime": 0x8040900c,
		"mNormalFlushTime": 0x8040900c,
		"TMapObjGeneral::mNormalFlushInterval": 0x80409010,
		"mNormalFlushInterval": 0x80409010,
		"TMapObjGeneral::mNormalWaitToAppearTime": 0x80409014,
		"mNormalWaitToAppearTime": 0x80409014,
		"TMapObjGeneral::mNormalAppearingScaleUp": 0x80409018,
		"mNormalAppearingScaleUp": 0x80409018,
		"TMapObjGeneral::mNormalThrowSpeedRate": 0x8040901c,
		"mNormalThrowSpeedRate": 0x8040901c,
		"TMapObjLibWave::mWaveSpeed": 0x80409020,
		"mWaveSpeed": 0x80409020,
		"TItem::mAppearedScaleSpeed": 0x80409028,
		"mAppearedScaleSpeed": 0x80409028,
		"TShine::mCircleRateY": 0x8040902c,
		"mCircleRateY": 0x8040902c,
		"TShine::mUpSpeed": 0x80409030,
		"mUpSpeed": 0x80409030,
		"TShine::mSpeedDownRate": 0x80409034,
		"TManhole::mDownHeight": 0x80409038,
		"TManhole::mDownSpeed": 0x8040903c,
		"mDownSpeed": 0x8040903c,
		"TManhole::mVibrationSpeed": 0x80409040,
		"mVibrationSpeed": 0x80409040,
		"TManhole::mVibrationEndHeight": 0x80409044,
		"mVibrationEndHeight": 0x80409044,
		"TManhole::mVibrationDecreaseRate": 0x80409048,
		"mVibrationDecreaseRate": 0x80409048,
		"TSandBlock::mSandScaleUp": 0x80409050,
		"mSandScaleUp": 0x80409050,
		"TSandBlock::mSandScaleDown": 0x80409054,
		"mSandScaleDown": 0x80409054,
		"TSandBlock::mSandScaleMin": 0x80409058,
		"mSandScaleMin": 0x80409058,
		"TSandBlock::mWaitTimeToFall": 0x8040905c,
		"mWaitTimeToFall": 0x8040905c,
		"TSandBlock::mSandWaitTime": 0x80409060,
		"mSandWaitTime": 0x80409060,
		"TIceBlock::mMeltSpeedWater": 0x80409064,
		"mMeltSpeedWater": 0x80409064,
		"TIceBlock::mMeltSpeedAuto": 0x80409068,
		"mMeltSpeedAuto": 0x80409068,
		"TIceBlock::mAutoMeltScale": 0x8040906c,
		"mAutoMeltScale": 0x8040906c,
		"MoveBG::sSubZ": 0x80409074,
		"sSubZ": 0x80409074,
		"MoveBG::sSpeed": 0x80409078,
		"sSpeed": 0x80409078,
		"TMapObjRootPakkun::mTremblePower": 0x8040907c,
		"mTremblePower": 0x8040907c,
		"TMapObjRootPakkun::mTrembleAccel": 0x80409080,
		"mTrembleAccel": 0x80409080,
		"TMapObjRootPakkun::mTrembleBrake": 0x80409084,
		"mTrembleBrake": 0x80409084,
		"TMapObjRootPakkun::mTrembleTime": 0x80409088,
		"mTrembleTime": 0x80409088,
		"TBiancoWatermillVertical::mRotAccel": 0x8040908c,
		"TBiancoWatermillVertical::mRotSpeedDownRate": 0x80409090,
		"mRotSpeedDownRate": 0x80409090,
		"TBiancoWatermillVertical::mRotSpeedMax": 0x80409094,
		"TBiancoWatermillVertical::mBridgeRotRate": 0x80409098,
		"mBridgeRotRate": 0x80409098,
		"TBiancoMiniWindmill::mRotWaterAccel": 0x8040909c,
		"mRotWaterAccel": 0x8040909c,
		"TBiancoMiniWindmill::mFriction": 0x804090a0,
		"mFriction": 0x804090a0,
		"TBiancoMiniWindmill::mRotSpeedMax": 0x804090a4,
		"MoveBG::sMessengerPosZ": 0x804090a8,
		"sMessengerPosZ": 0x804090a8,
		"MoveBG::sMessengerPosY": 0x804090ac,
		"sMessengerPosY": 0x804090ac,
		"TLeafBoatRotten::mAlphaDownSpeed": 0x804090b0,
		"mAlphaDownSpeed": 0x804090b0,
		"TLeafBoatRotten::mCollisionRemoveAlpha": 0x804090b4,
		"mCollisionRemoveAlpha": 0x804090b4,
		"TLeafBoatRotten::mRottenColor": 0x804090b8,
		"mRottenColor": 0x804090b8,
		"TCraneRotY::mWaitTime": 0x804090c0,
		"TCraneUpDown::mRotSpeed": 0x804090c4,
		"TCraneUpDown::mWaitTime": 0x804090c8,
		"TRiccoWatermill::mRotAccel": 0x804090cc,
		"TRiccoWatermill::mRotSpeedMaxUp": 0x804090d0,
		"mRotSpeedMaxUp": 0x804090d0,
		"TRiccoWatermill::mRotSpeedMaxDown": 0x804090d4,
		"mRotSpeedMaxDown": 0x804090d4,
		"TRiccoWatermill::mRotDown": 0x804090d8,
		"mRotDown": 0x804090d8,
		"TRiccoWatermill::mSubmarineMoveRate": 0x804090dc,
		"mSubmarineMoveRate": 0x804090dc,
		"TRiccoWatermill::mSubmarineMaxTransY": 0x804090e0,
		"mSubmarineMaxTransY": 0x804090e0,
		"TRiccoWatermill::mSubmarineBottomTransY": 0x804090e4,
		"mSubmarineBottomTransY": 0x804090e4,
		"TRiccoWatermill::mWaitTime": 0x804090e8,
		"TFruitLauncher::mObjSpeedXZ": 0x804090ec,
		"mObjSpeedXZ": 0x804090ec,
		"TFruitLauncher::mObjSpeedY": 0x804090f0,
		"mObjSpeedY": 0x804090f0,
		"TFruitLauncher::mFruitLiveTime": 0x804090f4,
		"mFruitLiveTime": 0x804090f4,
		"TSandBase::mWitherTime": 0x804090f8,
		"mWitherTime": 0x804090f8,
		"TSandBase::mScaleMin": 0x804090fc,
		"TSandBombBase::mFiringFrameSpeed": 0x80409100,
		"mFiringFrameSpeed": 0x80409100,
		"TSandBombBase::mFiringFrameDownSpeed": 0x80409104,
		"mFiringFrameDownSpeed": 0x80409104,
		"TSandBombBase::mExplodeFrameSpeed": 0x80409108,
		"mExplodeFrameSpeed": 0x80409108,
		"TSandBombBase::mMarioJumpRate": 0x8040910c,
		"mMarioJumpRate": 0x8040910c,
		"TSandBombBase::mExlodingRumbleTime": 0x80409110,
		"mExlodingRumbleTime": 0x80409110,
		"TSandCastle::mCollisionRate": 0x80409114,
		"mCollisionRate": 0x80409114,
		"TLeanMirror::mGoTargetTime": 0x80409118,
		"mGoTargetTime": 0x80409118,
		"TLeanMirror::mDemoWaitTime": 0x8040911c,
		"mDemoWaitTime": 0x8040911c,
		"TLeanMirror::mDemoLightTime": 0x80409120,
		"mDemoLightTime": 0x80409120,
		"TMammaBlockRotate::mRotSpeed": 0x80409124,
		"TMammaBlockRotate::mRotReturnSpeed": 0x80409128,
		"mRotReturnSpeed": 0x80409128,
		"TMammaBlockRotate::mRotEnd": 0x8040912c,
		"mRotEnd": 0x8040912c,
		"TMammaBlockRotate::mMapGoSpeed": 0x80409130,
		"mMapGoSpeed": 0x80409130,
		"TMammaBlockRotate::mMapBackSpeed": 0x80409134,
		"mMapBackSpeed": 0x80409134,
		"TMammaBlockRotate::mWaitTime": 0x80409138,
		"TShellCup::mOpenRotMax": 0x80409140,
		"mOpenRotMax": 0x80409140,
		"TShellCup::mShellDamageRot": 0x80409144,
		"mShellDamageRot": 0x80409144,
		"TShellCup::mWaterOpenAccel": 0x80409148,
		"mWaterOpenAccel": 0x80409148,
		"TShellCup::mCloseAccel": 0x8040914c,
		"mCloseAccel": 0x8040914c,
		"TMerrygoround::mRotSpeed": 0x80409150,
		"TCogwheelScale::mWaterLeakSpeed": 0x80409158,
		"mWaterLeakSpeed": 0x80409158,
		"TCogwheel::mRopeWidthX": 0x80409160,
		"TCogwheel::mRopeWidthZ": 0x80409164,
		"TCogwheel::mTexPosRate": 0x80409168,
		"TCogwheel::mMinSpeed": 0x8040916c,
		"mMinSpeed": 0x8040916c,
		"MoveBG::mGrowStartFrame": 0x80409170,
		"mGrowStartFrame": 0x80409170,
		"MoveBG::mGrowEndFrame": 0x80409174,
		"mGrowEndFrame": 0x80409174,
		"TMapObjFlag::mFlutterSpeed": 0x80409178,
		"mFlutterSpeed": 0x80409178,
		"TMapObjPlane::mHipDropDownRate": 0x80409188,
		"mHipDropDownRate": 0x80409188,
		"TMapObjPlane::mWaterDownRate": 0x8040918c,
		"mWaterDownRate": 0x8040918c,
		"TMapObjPlane::mTexScale": 0x80409190,
		"mTexScale": 0x80409190,
		"TRideCloud::mMoveSpeedDefault": 0x80409198,
		"mMoveSpeedDefault": 0x80409198,
		"TRideCloud::mCushionLen": 0x8040919c,
		"mCushionLen": 0x8040919c,
		"TRideCloud::mCushionSpeed": 0x804091a0,
		"mCushionSpeed": 0x804091a0,
		"TRideCloud::mScaleSpeed": 0x804091a4,
		"mScaleSpeed": 0x804091a4,
		"TResetFruit::mFruitLivingTime": 0x804091a8,
		"mFruitLivingTime": 0x804091a8,
		"TResetFruit::mScaleUpSpeed": 0x804091ac,
		"TResetFruit::mBreakingScaleSpeed": 0x804091b0,
		"mBreakingScaleSpeed": 0x804091b0,
		"TResetFruit::mFruitWaitTimeToAppear": 0x804091b4,
		"mFruitWaitTimeToAppear": 0x804091b4,
		"TMapObjGrassManager::mWidth": 0x804091c0,
		"mWidth": 0x804091c0,
		"TMapObjGrassManager::mSwingWidth": 0x804091c4,
		"mSwingWidth": 0x804091c4,
		"TMapObjGrassManager::mSwingSpeed": 0x804091c8,
		"mSwingSpeed": 0x804091c8,
		"TMapObjGrassManager::mDistNear": 0x804091cc,
		"mDistNear": 0x804091cc,
		"TMapObjGrassManager::mDistFar": 0x804091d0,
		"mDistFar": 0x804091d0,
		"MoveBG::sGrassAddTime": 0x804091d4,
		"sGrassAddTime": 0x804091d4,
		"TRevolvingFenceInner::mSpeed": 0x804091e8,
		"mSpeed": 0x804091e8,
		"TFenceWater::mWaterAccel": 0x804091ec,
		"mWaterAccel": 0x804091ec,
		"TFenceWater::mBackSpeed": 0x804091f0,
		"mBackSpeed": 0x804091f0,
		"TFenceWater::mTurnedWaitTime": 0x804091f4,
		"mTurnedWaitTime": 0x804091f4,
		"TRailFence::mFallHeight": 0x804091f8,
		"mFallHeight": 0x804091f8,
		"TRailFence::mWaitTime": 0x804091fc,
		"MoveBG::sRumbleTime": 0x80409200,
		"sRumbleTime": 0x80409200,
		"THangingBridgeBoard::mMarioAccelY": 0x80409208,
		"mMarioAccelY": 0x80409208,
		"THangingBridgeBoard::mMarioHipDropAccelY": 0x8040920c,
		"mMarioHipDropAccelY": 0x8040920c,
		"THangingBridgeBoard::mReturnAccelRate": 0x80409210,
		"THangingBridgeBoard::mSpeedDownRate": 0x80409214,
		"THangingBridgeBoard::mRopeWidthX": 0x80409218,
		"THangingBridgeBoard::mRopeWidthZ": 0x8040921c,
		"THangingBridgeBoard::mTexPosRate": 0x80409220,
		"THangingBridge::mRopeWidthBetweenBoards": 0x80409224,
		"mRopeWidthBetweenBoards": 0x80409224,
		"THangingBridge::mRopeWidthBetweenBoardsY": 0x80409228,
		"mRopeWidthBetweenBoardsY": 0x80409228,
		"THangingBridge::mPointNumBetweenBoards": 0x8040922c,
		"mPointNumBetweenBoards": 0x8040922c,
		"THangingBridge::mBetweenBoardsTexPosRate": 0x80409230,
		"mBetweenBoardsTexPosRate": 0x80409230,
		"TSwingBoard::mBoardWidth": 0x80409234,
		"mBoardWidth": 0x80409234,
		"TSwingBoard::mRopeWidthX": 0x80409238,
		"TSwingBoard::mRopeWidthZ": 0x8040923c,
		"TSwingBoard::mTexPosRate": 0x80409240,
		"TSwingBoard::mReturnAccelRate": 0x80409244,
		"TSwingBoard::mSpeedDownRate": 0x80409248,
		"TFluff::mScaleUpSpeed": 0x8040924c,
		"TFluff::mScaleDownSpeed": 0x80409250,
		"mScaleDownSpeed": 0x80409250,
		"TFluffManager::mWindMin": 0x80409254,
		"mWindMin": 0x80409254,
		"TMapObjTree::mBananaTreeJumpPower": 0x80409258,
		"mBananaTreeJumpPower": 0x80409258,
		"TMapObjTreeScale::mScaleSpeedY": 0x8040925c,
		"mScaleSpeedY": 0x8040925c,
		"TMapObjTreeScale::mStatusChangeScaleY": 0x80409260,
		"mStatusChangeScaleY": 0x80409260,
		"TMapObjTreeScale::mScaleSpeedXZ": 0x80409264,
		"mScaleSpeedXZ": 0x80409264,
		"TMapObjTreeScale::mScaleMin": 0x80409268,
		"MoveBG::sWaitTime": 0x8040926c,
		"sWaitTime": 0x8040926c,
		"TMapObjNail::mDownHeight": 0x80409270,
		"TLampTrapIron::mHitPointMax": 0x80409280,
		"mHitPointMax": 0x80409280,
		"TLampTrapIron::mFireTimerMax": 0x80409284,
		"mFireTimerMax": 0x80409284,
		"TMapEventSink::mCleanedDegree": 0x80409288,
		"Map::table$2575": 0x80409290,
		"table$2575": 0x80409290,
		"TMapWire::mMoveTimerSpeed": 0x80409298,
		"mMoveTimerSpeed": 0x80409298,
		"TMapWire::mDownRateMax": 0x8040929c,
		"mDownRateMax": 0x8040929c,
		"TMapWire::mEndRate": 0x804092a0,
		"mEndRate": 0x804092a0,
		"TMapWire::mStretchRate": 0x804092a4,
		"mStretchRate": 0x804092a4,
		"TMapWire::mHeightRate": 0x804092a8,
		"mHeightRate": 0x804092a8,
		"TMapWire::mReleaseHeight": 0x804092ac,
		"mReleaseHeight": 0x804092ac,
		"TMapWire::mFootLength": 0x804092b0,
		"mFootLength": 0x804092b0,
		"TMapWire::mDrawWidth": 0x804092b4,
		"mDrawWidth": 0x804092b4,
		"TMapWire::mDrawHeight": 0x804092b8,
		"mDrawHeight": 0x804092b8,
		"TMapWireActor::mCommonAttackRadius": 0x804092c0,
		"mCommonAttackRadius": 0x804092c0,
		"TMapWireActor::mCommonAttackHeight": 0x804092c4,
		"mCommonAttackHeight": 0x804092c4,
		"TPollutionLayer::mAreaMinRate": 0x804092c8,
		"mAreaMinRate": 0x804092c8,
		"TPollutionLayer::mSpreadArea": 0x804092cc,
		"mSpreadArea": 0x804092cc,
		"TPollutionLayer::mSpreadFrequency": 0x804092d0,
		"mSpreadFrequency": 0x804092d0,
		"TPollutionLayer::mFireArea": 0x804092d4,
		"mFireArea": 0x804092d4,
		"TPollutionLayer::mFireEffectWaitTime": 0x804092d8,
		"mFireEffectWaitTime": 0x804092d8,
		"TPollutionLayer::mThunderArea": 0x804092dc,
		"mThunderArea": 0x804092dc,
		"TPollutionLayer::mGlassWallArea": 0x804092e0,
		"mGlassWallArea": 0x804092e0,
		"TPollutionLayer::mGlassWallEffectTime": 0x804092e4,
		"mGlassWallEffectTime": 0x804092e4,
		"TPollutionManager::mFlushTime": 0x804092e8,
		"mFlushTime": 0x804092e8,
		"TPollutionLayerWave::mInterval": 0x804092f0,
		"mInterval": 0x804092f0,
		"TPollutionLayer::mEffectTime": 0x804092f8,
		"mEffectTime": 0x804092f8,
		"TMareWallRock::mAppearSpeed": 0x80409300,
		"mAppearSpeed": 0x80409300,
		"TMareWallRock::mDepressSpeed": 0x80409304,
		"TMareWallRock::mCleanedDegree": 0x80409308,
		"TMareWallRock::mWaitTimeToAppear": 0x8040930c,
		"mWaitTimeToAppear": 0x8040930c,
		"TMareWallRock::mWaitTimeToDepress": 0x80409310,
		"mWaitTimeToDepress": 0x80409310,
		"TMareEventDepressWall::mDepressSpeed": 0x80409314,
		"TMareEventDepressWall::mRiseSpeed": 0x80409318,
		"mRiseSpeed": 0x80409318,
		"TMareEventDepressWall::mWaitTimeToWatch": 0x8040931c,
		"mWaitTimeToWatch": 0x8040931c,
		"GC2D::scDolpicNewsDolpic0": 0x80409320,
		"scDolpicNewsDolpic0": 0x80409320,
		"GC2D::scDolpicNewsDolpic1": 0x80409328,
		"scDolpicNewsDolpic1": 0x80409328,
		"GC2D::scDolpicNewsDolpic5_2": 0x80409330,
		"scDolpicNewsDolpic5_2": 0x80409330,
		"GC2D::scDolpicNewsDolpic5_3": 0x80409338,
		"scDolpicNewsDolpic5_3": 0x80409338,
		"GC2D::scDolpicNewsDolpic8_1": 0x80409340,
		"scDolpicNewsDolpic8_1": 0x80409340,
		"GC2D::fbuf": 0x80409348,
		"fbuf": 0x80409348,
		"GC2D::vtable_org": 0x8040934c,
		"vtable_org": 0x8040934c,
		"GC2D::dec_step": 0x80409354,
		"dec_step": 0x80409354,
		"GC2D::inc_step": 0x80409358,
		"inc_step": 0x80409358,
		"GC2D::fbuf2": 0x8040935c,
		"fbuf2": 0x8040935c,
		"GC2D::gmover_tex_buffer": 0x80409360,
		"gmover_tex_buffer": 0x80409360,
		"GC2D::mag$259": 0x80409364,
		"mag$259": 0x80409364,
		"TGesso::mBodyRotSpeed": 0x80409374,
		"mBodyRotSpeed": 0x80409374,
		"TGesso::mPollRange": 0x80409378,
		"mPollRange": 0x80409378,
		"TGesso::mThroughHoseiDistY": 0x8040937c,
		"mThroughHoseiDistY": 0x8040937c,
		"THamuKuri::mCapGravityY": 0x80409380,
		"mCapGravityY": 0x80409380,
		"THamuKuri::mCapSpeed": 0x80409384,
		"mCapSpeed": 0x80409384,
		"THamuKuri::mVGenerateGravityY": 0x80409388,
		"mVGenerateGravityY": 0x80409388,
		"THamuKuri::mLandAnmFrameNum": 0x8040938c,
		"mLandAnmFrameNum": 0x8040938c,
		"Enemy::mFireHamNoseColorDiff": 0x80409394,
		"mFireHamNoseColorDiff": 0x80409394,
		"Enemy::mFireHamOtherColorDiff": 0x8040939c,
		"mFireHamOtherColorDiff": 0x8040939c,
		"Enemy::mannameTable$3222": 0x804093a8,
		"mannameTable$3222": 0x804093a8,
		"TMameGesso::mBaseHoseiTransY": 0x804093b8,
		"mBaseHoseiTransY": 0x804093b8,
		"TNameKuriManager::mExplosionSpeed": 0x804093c0,
		"mExplosionSpeed": 0x804093c0,
		"TNameKuriManager::mStopMinScaleFrame": 0x804093c4,
		"mStopMinScaleFrame": 0x804093c4,
		"TPakkunManager::mRootExplosionScaleRate": 0x804093c8,
		"mRootExplosionScaleRate": 0x804093c8,
		"TPakkunManager::mTestFlyAngX": 0x804093cc,
		"mTestFlyAngX": 0x804093cc,
		"TPakkunManager::mIgnoreHitWaterY": 0x804093d0,
		"mIgnoreHitWaterY": 0x804093d0,
		"TSmallEnemyManager::mBlockWaitTime": 0x804093d8,
		"mBlockWaitTime": 0x804093d8,
		"TSmallEnemyManager::mBlockMoveSpeed": 0x804093dc,
		"mBlockMoveSpeed": 0x804093dc,
		"TSmallEnemyManager::mBlockWaitMoveY": 0x804093e0,
		"mBlockWaitMoveY": 0x804093e0,
		"TSmallEnemyManager::mChangeBlockTime": 0x804093e4,
		"mChangeBlockTime": 0x804093e4,
		"TSmallEnemyManager::mBlockXZScale": 0x804093e8,
		"mBlockXZScale": 0x804093e8,
		"TSmallEnemyManager::mBlockYScale": 0x804093ec,
		"mBlockYScale": 0x804093ec,
		"Enemy::idx$3335": 0x804093f8,
		"idx$3335": 0x804093f8,
		"TTelesa::mFlyAngMax": 0x80409408,
		"mFlyAngMax": 0x80409408,
		"TTobiPuku::mLandAngle": 0x80409420,
		"mLandAngle": 0x80409420,
		"TTobiPuku::mBoundVelocityY": 0x80409428,
		"mBoundVelocityY": 0x80409428,
		"Enemy::loopIndirectFilenames$3531": 0x80409464,
		"loopIndirectFilenames$3531": 0x80409464,
		"TChuuHana::mCheckOnPanelTimeRoll": 0x80409468,
		"mCheckOnPanelTimeRoll": 0x80409468,
		"TChuuHana::mCheckOnPanelTime": 0x8040946c,
		"mCheckOnPanelTime": 0x8040946c,
		"TChuuHana::mSmallMirrorR": 0x80409478,
		"mSmallMirrorR": 0x80409478,
		"TChuuHana::mMediumMirrorR": 0x8040947c,
		"mMediumMirrorR": 0x8040947c,
		"TChuuHana::mLargeMirrorR": 0x80409480,
		"mLargeMirrorR": 0x80409480,
		"TRollEnemy::mBoundVal": 0x80409488,
		"mBoundVal": 0x80409488,
		"TIgaiga::mReachNodeDist": 0x8040948c,
		"mReachNodeDist": 0x8040948c,
		"Enemy::anmlist$3317": 0x80409490,
		"anmlist$3317": 0x80409490,
		"Enemy::graphlist$3323": 0x80409498,
		"graphlist$3323": 0x80409498,
		"TTamaNoko::mStopOnAirTimeMax": 0x804094a8,
		"mStopOnAirTimeMax": 0x804094a8,
		"TTamaNoko::mRollOnAirTimeMax": 0x804094ac,
		"mRollOnAirTimeMax": 0x804094ac,
		"TTamaNoko::mRollOnAirAngle": 0x804094b0,
		"mRollOnAirAngle": 0x804094b0,
		"TTamaNoko::mDropVelocityY": 0x804094b4,
		"mDropVelocityY": 0x804094b4,
		"TBossTelesa::mEnemyGenRate": 0x804094b8,
		"mEnemyGenRate": 0x804094b8,
		"TBossTelesa::mItemGenRate": 0x804094bc,
		"mItemGenRate": 0x804094bc,
		"TBossTelesa::mBaseHoseiPosY": 0x804094c4,
		"mBaseHoseiPosY": 0x804094c4,
		"TBossTelesa::mRouletteUpRate": 0x804094c8,
		"mRouletteUpRate": 0x804094c8,
		"TBossTelesa::mTelesaGenerateInterval": 0x804094cc,
		"mTelesaGenerateInterval": 0x804094cc,
		"TBossTelesa::mCameraMoveLimit": 0x804094d0,
		"mCameraMoveLimit": 0x804094d0,
		"TBossTelesa::mCameraMoveSp": 0x804094d4,
		"mCameraMoveSp": 0x804094d4,
		"TCannon::mVelocityRate": 0x804094e4,
		"mVelocityRate": 0x804094e4,
		"TCannon::mSearchRate": 0x804094e8,
		"mSearchRate": 0x804094e8,
		"TBossEel::mOpenRollSpeed": 0x804094f0,
		"mOpenRollSpeed": 0x804094f0,
		"TBossEel::mForcePow": 0x804094f8,
		"mForcePow": 0x804094f8,
		"TFlyEnemy::mTestSp": 0x80409504,
		"mTestSp": 0x80409504,
		"TFlyEnemy::mInvalidTime": 0x80409508,
		"mInvalidTime": 0x80409508,
		"TFlyEnemy::mTestMarioSpMax": 0x8040950c,
		"mTestMarioSpMax": 0x8040950c,
		"TPopo::mTestAng_x": 0x8040951c,
		"TPopo::mTestAng_y": 0x80409520,
		"TPopo::mNozzleOffsetZ": 0x80409524,
		"TPopo::mTestBodyScale": 0x80409530,
		"mTestBodyScale": 0x80409530,
		"TPopo::mColOffsetY": 0x80409538,
		"TPopo::mColMinVal": 0x8040953c,
		"mColMinVal": 0x8040953c,
		"Enemy::sleepBossHanachan_bastable": 0x80409548,
		"sleepBossHanachan_bastable": 0x80409548,
		"Enemy::cSandPillarModelName": 0x80409558,
		"cSandPillarModelName": 0x80409558,
		"Enemy::cHitPoint1_RailName": 0x8040955c,
		"cHitPoint1_RailName": 0x8040955c,
		"Enemy::cHitPoint2_RailName": 0x80409560,
		"cHitPoint2_RailName": 0x80409560,
		"Enemy::cSandTextureName": 0x80409564,
		"cSandTextureName": 0x80409564,
		"Enemy::cDummyTextureName": 0x80409568,
		"cDummyTextureName": 0x80409568,
		"Enemy::cMapCollisionJointName": 0x80409570,
		"cMapCollisionJointName": 0x80409570,
		"Enemy::cBodyMapCollisionFileName": 0x80409574,
		"cBodyMapCollisionFileName": 0x80409574,
		"Enemy::cHeadMapCollisionFileName": 0x80409578,
		"cHeadMapCollisionFileName": 0x80409578,
		"Enemy::cLegJointName_L3": 0x8040957c,
		"cLegJointName_L3": 0x8040957c,
		"Enemy::cLegJointName_R3": 0x80409580,
		"cLegJointName_R3": 0x80409580,
		"Enemy::cNoseHallJointName_L": 0x80409584,
		"cNoseHallJointName_L": 0x80409584,
		"Enemy::cNoseHallJointName_R": 0x80409588,
		"cNoseHallJointName_R": 0x80409588,
		"Enemy::sFootJointName$2739": 0x8040958c,
		"sFootJointName$2739": 0x8040958c,
		"TRocket::mTestAng_y": 0x804095a0,
		"TRocket::mNozzleOffsetZ": 0x804095a4,
		"TRocket::mColOffsetY": 0x804095a8,
		"Enemy::koopajrsubmarine_bastable": 0x804095d0,
		"koopajrsubmarine_bastable": 0x804095d0,
		"Enemy::onetimeFilenames$3171": 0x80409634,
		"onetimeFilenames$3171": 0x80409634,
		"Enemy::@2522": 0x80409664,
		"Enemy::@2523": 0x80409668,
		"Enemy::@2524": 0x8040966c,
		"Enemy::@2525": 0x80409670,
		"Enemy::loopFilenames$3201": 0x80409708,
		"loopFilenames$3201": 0x80409708,
		"Enemy::DebuTelesa_bastable": 0x80409718,
		"DebuTelesa_bastable": 0x80409718,
		"Camera::cStartCamName": 0x80409770,
		"cStartCamName": 0x80409770,
		"Camera::cStartAfterCamName": 0x80409774,
		"cStartAfterCamName": 0x80409774,
		"Camera::cJetCoasterCam0BckName": 0x80409778,
		"cJetCoasterCam0BckName": 0x80409778,
		"Camera::cJetCoasterCam1BckName": 0x8040977c,
		"cJetCoasterCam1BckName": 0x8040977c,
		"Camera::cJetCoasterDemoBckName": 0x80409780,
		"cJetCoasterDemoBckName": 0x80409780,
		"Camera::cStartCamBckFileName": 0x80409784,
		"cStartCamBckFileName": 0x80409784,
		"Camera::bossGesoViewObjName": 0x80409788,
		"bossGesoViewObjName": 0x80409788,
		"Camera::cSunWarpPointName": 0x80409790,
		"cSunWarpPointName": 0x80409790,
		"Camera::cPositionJointName": 0x80409798,
		"cPositionJointName": 0x80409798,
		"Camera::cLookatJointName": 0x8040979c,
		"cLookatJointName": 0x8040979c,
		"Camera::cCameraBckVolumeName": 0x804097a0,
		"cCameraBckVolumeName": 0x804097a0,
		"Camera::cLoadCamName": 0x804097a8,
		"cLoadCamName": 0x804097a8,
		"JKRArchive::sCurrentDirID": 0x804097c0,
		"sCurrentDirID": 0x804097c0,
		"JKRAram::sAramObject": 0x804097c8,
		"sAramObject": 0x804097c8,
		"JSystem::srcAddress": 0x804097ec,
		"srcAddress": 0x804097ec,
		"JSystem::whatdo": 0x80409800,
		"whatdo": 0x80409800,
		"JSystem::whatdo2": 0x80409804,
		"whatdo2": 0x80409804,
		"JSystem::DBfoundSize": 0x80409808,
		"DBfoundSize": 0x80409808,
		"JSystem::DBfoundOffset": 0x8040980c,
		"DBfoundOffset": 0x8040980c,
		"JSystem::DBfoundBlock": 0x80409810,
		"DBfoundBlock": 0x80409810,
		"JSystem::DBnewFreeBlock": 0x80409814,
		"DBnewFreeBlock": 0x80409814,
		"JSystem::DBnewUsedBlock": 0x80409818,
		"DBnewUsedBlock": 0x80409818,
		"JKRFileLoader::sCurrentVolume": 0x80409820,
		"sCurrentVolume": 0x80409820,
		"JKRHeap::sSystemHeap": 0x80409828,
		"sSystemHeap": 0x80409828,
		"JKRHeap::sCurrentHeap": 0x8040982c,
		"JKRHeap::sRootHeap": 0x80409830,
		"sRootHeap": 0x80409830,
		"JKRHeap::mErrorHandler": 0x80409834,
		"mErrorHandler": 0x80409834,
		"JKRHeap::mCodeStart": 0x80409838,
		"mCodeStart": 0x80409838,
		"JKRHeap::mCodeEnd": 0x8040983c,
		"mCodeEnd": 0x8040983c,
		"JKRHeap::mUserRamStart": 0x80409840,
		"mUserRamStart": 0x80409840,
		"JKRHeap::mUserRamEnd": 0x80409844,
		"mUserRamEnd": 0x80409844,
		"JKRHeap::mMemorySize": 0x80409848,
		"mMemorySize": 0x80409848,
		"JUTException::sErrorManager": 0x80409850,
		"sErrorManager": 0x80409850,
		"JUTException::sPreUserCallback": 0x80409854,
		"sPreUserCallback": 0x80409854,
		"JUTException::sPostUserCallback": 0x80409858,
		"sPostUserCallback": 0x80409858,
		"JUTException::sConsoleBuffer": 0x8040985c,
		"sConsoleBuffer": 0x8040985c,
		"JUTException::sConsoleBufferSize": 0x80409860,
		"sConsoleBufferSize": 0x80409860,
		"JUTException::sConsole": 0x80409864,
		"sConsole": 0x80409864,
		"JUTException::msr": 0x80409868,
		"msr": 0x80409868,
		"JUTException::fpscr": 0x8040986c,
		"fpscr": 0x8040986c,
		"JUTDirectPrint::sDirectPrint": 0x80409870,
		"sDirectPrint": 0x80409870,
		"JUTGamePad::mPadAssign": 0x8040987c,
		"mPadAssign": 0x8040987c,
		"JUTGamePad::mSuppressPadReset": 0x80409880,
		"mSuppressPadReset": 0x80409880,
		"JUTGamePad::sAnalogMode": 0x80409884,
		"sAnalogMode": 0x80409884,
		"JUTGamePad::CRumble::mStatus": 0x80409888,
		"mStatus": 0x80409888,
		"JUTGamePad::CRumble::mEnable": 0x8040988c,
		"mEnable": 0x8040988c,
		"JUTGamePad::C3ButtonReset::sCallback": 0x80409890,
		"sCallback": 0x80409890,
		"JUTGamePad::C3ButtonReset::sCallbackArg": 0x80409894,
		"sCallbackArg": 0x80409894,
		"JUTGamePad::C3ButtonReset::sResetOccurredPort": 0x804098a4,
		"sResetOccurredPort": 0x804098a4,
		"JSystem::jmaSinShift": 0x804098ac,
		"jmaSinShift": 0x804098ac,
		"JSystem::jmaSinTable": 0x804098b0,
		"jmaSinTable": 0x804098b0,
		"JSystem::jmaCosTable": 0x804098b4,
		"jmaCosTable": 0x804098b4,
		"J2DPrint::mStrBuff": 0x804098b8,
		"mStrBuff": 0x804098b8,
		"J2DPrint::mStrBuffSize": 0x804098c0,
		"mStrBuffSize": 0x804098c0,
		"J3DShapeMtx::currentPipeline": 0x804098c8,
		"currentPipeline": 0x804098c8,
		"JSystem::j3dDefaultViewNo": 0x804098d0,
		"j3dDefaultViewNo": 0x804098d0,
		"JSystem::dmaBuf": 0x8040991c,
		"dmaBuf": 0x8040991c,
		"JSystem::dmaEnd": 0x80409920,
		"dmaEnd": 0x80409920,
		"JSystem::dmaCurrent": 0x80409924,
		"dmaCurrent": 0x80409924,
		"JKRDecomp::sDecompObject": 0x80409948,
		"sDecompObject": 0x80409948,
		"J3DDrawPacket::sInterruptFlag": 0x80409950,
		"sInterruptFlag": 0x80409950,
		"J3DDrawBuffer::entryNum": 0x80409958,
		"entryNum": 0x80409958,
		"JKRAramStream::sAramStreamObject": 0x80409960,
		"sAramStreamObject": 0x80409960,
		"JKRAramStream::transBuffer": 0x80409964,
		"transBuffer": 0x80409964,
		"JKRAramStream::transSize": 0x80409968,
		"transSize": 0x80409968,
		"JKRAramStream::transHeap": 0x8040996c,
		"transHeap": 0x8040996c,
		"JUTAssertion::@unnamed@::sMessageLife": 0x80409970,
		"sMessageLife": 0x80409970,
		"JUTVideo::sManager": 0x80409978,
		"JUTRomFont::spAboutEncoding_": 0x80409980,
		"spAboutEncoding_": 0x80409980,
		"JUTRomFont::spFontHeader_": 0x80409984,
		"spFontHeader_": 0x80409984,
		"JUTRomFont::suFontHeaderRefered_": 0x80409988,
		"suFontHeaderRefered_": 0x80409988,
		"JUTConsoleManager::sManager": 0x80409990,
		"JSystem::sReportConsole": 0x80409994,
		"sReportConsole": 0x80409994,
		"JSystem::sWarningConsole": 0x80409998,
		"sWarningConsole": 0x80409998,
		"JDrama::TNameRefGen::instance": 0x804099a0,
		"instance": 0x804099a0,
		"JADHioNode::smCurrentHeap": 0x804099a8,
		"smCurrentHeap": 0x804099a8,
		"JSystem::oRandom$356": 0x804099b4,
		"oRandom$356": 0x804099b4,
		"JALSystem::spFManager": 0x804099b8,
		"spFManager": 0x804099b8,
		"JAInter::TAsnData::asnData": 0x80409a58,
		"asnData": 0x80409a58,
		"JAIBasic::basic": 0x80409a60,
		"basic": 0x80409a60,
		"JSystem::_dinfo$1264": 0x80409a64,
		"_dinfo$1264": 0x80409a64,
		"JSystem::_info$1317": 0x80409a68,
		"_info$1317": 0x80409a68,
		"JAIConst::random": 0x80409a70,
		"random": 0x80409a70,
		"JAInter::TDebugHeap::currentHeap": 0x80409a78,
		"currentHeap": 0x80409a78,
		"JAInter::StreamLib::adpcm_remain": 0x80409a80,
		"adpcm_remain": 0x80409a80,
		"JAInter::StreamLib::adpcm_loadpoint": 0x80409a84,
		"adpcm_loadpoint": 0x80409a84,
		"JAInter::StreamLib::loadsize": 0x80409a88,
		"loadsize": 0x80409a88,
		"JAInter::StreamLib::adpcm_buffer": 0x80409a8c,
		"adpcm_buffer": 0x80409a8c,
		"JAInter::StreamLib::loop_buffer": 0x80409a90,
		"loop_buffer": 0x80409a90,
		"JAInter::StreamLib::store_buffer": 0x80409a94,
		"store_buffer": 0x80409a94,
		"JAInter::StreamLib::assign_ch": 0x80409a98,
		"assign_ch": 0x80409a98,
		"JAInter::StreamLib::playside": 0x80409aa0,
		"playside": 0x80409aa0,
		"JAInter::StreamLib::playback_samples": 0x80409aa4,
		"playback_samples": 0x80409aa4,
		"JAInter::StreamLib::loadup_samples": 0x80409aa8,
		"loadup_samples": 0x80409aa8,
		"JAInter::StreamLib::adpcmbuf_state": 0x80409aac,
		"adpcmbuf_state": 0x80409aac,
		"JAInter::StreamLib::movieframe": 0x80409ab0,
		"movieframe": 0x80409ab0,
		"JAInter::StreamLib::outvolume": 0x80409abc,
		"outvolume": 0x80409abc,
		"JAInter::StreamLib::outpitch": 0x80409ac0,
		"outpitch": 0x80409ac0,
		"JAInter::StreamLib::outpan": 0x80409ac4,
		"outpan": 0x80409ac4,
		"JAInter::StreamLib::stackvolume": 0x80409ac8,
		"stackvolume": 0x80409ac8,
		"JAInter::StreamLib::stackpitch": 0x80409acc,
		"stackpitch": 0x80409acc,
		"JAInter::StreamLib::stackpan": 0x80409ad0,
		"stackpan": 0x80409ad0,
		"JAInter::StreamLib::loop_start_flag": 0x80409ad8,
		"loop_start_flag": 0x80409ad8,
		"JAInter::StreamLib::outpause": 0x80409adc,
		"outpause": 0x80409adc,
		"JAInter::StreamLib::playmode": 0x80409ae0,
		"playmode": 0x80409ae0,
		"JAInter::StreamLib::shift_sample": 0x80409ae4,
		"shift_sample": 0x80409ae4,
		"JAInter::StreamLib::extra_sample": 0x80409ae8,
		"extra_sample": 0x80409ae8,
		"JAInter::StreamLib::DvdLoadFlag": 0x80409aec,
		"DvdLoadFlag": 0x80409aec,
		"JAInter::StreamLib::startInitFlag": 0x80409af0,
		"startInitFlag": 0x80409af0,
		"JAInter::StreamLib::Mode": 0x80409af4,
		"Mode": 0x80409af4,
		"JAInter::StreamLib::Head": 0x80409af8,
		"Head": 0x80409af8,
		"JSystem::before$612": 0x80409b00,
		"before$612": 0x80409b00,
		"JSystem::oldstat$823": 0x80409b10,
		"oldstat$823": 0x80409b10,
		"JSystem::old_dspside$839": 0x80409b18,
		"old_dspside$839": 0x80409b18,
		"JAIGlobalParameter::interfaceHeapSize": 0x80409b24,
		"interfaceHeapSize": 0x80409b24,
		"JAIGlobalParameter::audioResPath": 0x80409b28,
		"audioResPath": 0x80409b28,
		"JAIGlobalParameter::minDistanceVolume": 0x80409b2c,
		"minDistanceVolume": 0x80409b2c,
		"JAISound::interPointer": 0x80409b30,
		"interPointer": 0x80409b30,
		"JASystem::TBank::sCurrentHeap": 0x80409b38,
		"JASystem::BankMgr::sTableSize": 0x80409b40,
		"JASystem::BankMgr::sBankArray": 0x80409b44,
		"sBankArray": 0x80409b44,
		"JASystem::BankMgr::sVir2PhyTable": 0x80409b48,
		"sVir2PhyTable": 0x80409b48,
		"JASystem::BNKParser::sUsedHeapSize": 0x80409b50,
		"JSystem::oscp$295": 0x80409b58,
		"oscp$295": 0x80409b58,
		"JSystem::oRandom$331": 0x80409b64,
		"oRandom$331": 0x80409b64,
		"JASystem::TWaveBank::sCurrentHeap": 0x80409b68,
		"JASystem::WaveBankMgr::sTableSize": 0x80409b70,
		"JASystem::WaveBankMgr::sWaveBank": 0x80409b74,
		"sWaveBank": 0x80409b74,
		"JASystem::WSParser::sUsedHeapSize": 0x80409b78,
		"JASystem::AudioThread::isDSPBoot": 0x80409b80,
		"isDSPBoot": 0x80409b80,
		"JASystem::AudioThread::audioproc_mq_init": 0x80409b84,
		"audioproc_mq_init": 0x80409b84,
		"JASystem::AudioThread::intcount": 0x80409b88,
		"intcount": 0x80409b88,
		"JASystem::AudioThread::priority_set": 0x80409b8c,
		"priority_set": 0x80409b8c,
		"JASystem::AudioThread::jac_pri": 0x80409b90,
		"jac_pri": 0x80409b90,
		"JASystem::AudioThread::dvd_pri": 0x80409b94,
		"dvd_pri": 0x80409b94,
		"JSystem::first$120": 0x80409b98,
		"first$120": 0x80409b98,
		"JASystem::Driver::DSPQueue::waitp": 0x80409ba0,
		"waitp": 0x80409ba0,
		"JASystem::Driver::DSPQueue::waittime": 0x80409ba4,
		"waittime": 0x80409ba4,
		"JASystem::Driver::DSPQueue::cur_waits": 0x80409ba8,
		"cur_waits": 0x80409ba8,
		"JASystem::Driver::DSPQueue::cur_top": 0x80409bac,
		"cur_top": 0x80409bac,
		"JASystem::Driver::DSPQueue::cur_tail": 0x80409bb0,
		"cur_tail": 0x80409bb0,
		"JASystem::ChGlobal::GLOBAL_CHANNEL": 0x80409bb8,
		"GLOBAL_CHANNEL": 0x80409bb8,
		"JASystem::ChGlobal::CHANNEL": 0x80409bbc,
		"CHANNEL": 0x80409bbc,
		"JASystem::ChGlobal::OSCILLATOR": 0x80409bc0,
		"OSCILLATOR": 0x80409bc0,
		"JASystem::DSPBuf::dac_sync_counter": 0x80409bcc,
		"dac_sync_counter": 0x80409bcc,
		"JASystem::TDSPChannel::DSPCH": 0x80409bd0,
		"DSPCH": 0x80409bd0,
		"JASystem::TDSPChannel::smnUse": 0x80409bd4,
		"smnUse": 0x80409bd4,
		"JSystem::first$144": 0x80409bd8,
		"first$144": 0x80409bd8,
		"JASystem::old_time": 0x80409be0,
		"old_time": 0x80409be0,
		"JASystem::DSPInterface::CH_BUF": 0x80409be8,
		"CH_BUF": 0x80409be8,
		"JASystem::DSPInterface::FX_BUF": 0x80409bec,
		"FX_BUF": 0x80409bec,
		"JASystem::Kernel::JASUniversalDacCounter": 0x80409bf0,
		"JASUniversalDacCounter": 0x80409bf0,
		"JASystem::Kernel::lastRspMadep": 0x80409bf4,
		"lastRspMadep": 0x80409bf4,
		"JASystem::Kernel::useRspMadep": 0x80409bf8,
		"useRspMadep": 0x80409bf8,
		"JASystem::Kernel::vframeWorkRunning": 0x80409bfc,
		"vframeWorkRunning": 0x80409bfc,
		"JASystem::Kernel::dacCallbackFunc": 0x80409c00,
		"dacCallbackFunc": 0x80409c00,
		"JASystem::Kernel::JASVframeCounter": 0x80409c04,
		"JASVframeCounter": 0x80409c04,
		"JASystem::Kernel::extMixCallback": 0x80409c08,
		"extMixCallback": 0x80409c08,
		"JSystem::dacp$140": 0x80409c10,
		"dacp$140": 0x80409c10,
		"JASystem::Calc::JASC_SINTABLE": 0x80409c18,
		"JASC_SINTABLE": 0x80409c18,
		"JASystem::Calc::JASC_DOL2TABLE": 0x80409c1c,
		"JASC_DOL2TABLE": 0x80409c1c,
		"JASystem::Kernel::callList": 0x80409c20,
		"callList": 0x80409c20,
		"JSystem::cmd_once": 0x80409c28,
		"cmd_once": 0x80409c28,
		"JSystem::cmd_stay": 0x80409c30,
		"cmd_stay": 0x80409c30,
		"JASystem::Dvd::mqInit": 0x80409c38,
		"mqInit": 0x80409c38,
		"JASystem::Dvd::buffersize": 0x80409c3c,
		"buffersize": 0x80409c3c,
		"JASystem::Dvd::buffers": 0x80409c40,
		"buffers": 0x80409c40,
		"JASystem::Dvd::nextBufferSize": 0x80409c44,
		"nextBufferSize": 0x80409c44,
		"JASystem::Dvd::nextBufferTop": 0x80409c48,
		"nextBufferTop": 0x80409c48,
		"JASystem::Dvd::nextBuffers": 0x80409c4c,
		"nextBuffers": 0x80409c4c,
		"JASystem::Dvd::audioDvdBuffer": 0x80409c50,
		"audioDvdBuffer": 0x80409c50,
		"JASystem::Dvd::bufferLoad": 0x80409c58,
		"bufferLoad": 0x80409c58,
		"JASystem::Dvd::bufferFull": 0x80409c5c,
		"bufferFull": 0x80409c5c,
		"JASystem::Dvd::callStackArray": 0x80409c60,
		"callStackArray": 0x80409c60,
		"JASystem::Dvd::msgBuf": 0x80409c64,
		"msgBuf": 0x80409c64,
		"JASystem::Dvd::curQ": 0x80409c68,
		"curQ": 0x80409c68,
		"JASystem::Dvd::dvdtSleep": 0x80409c6c,
		"dvdtSleep": 0x80409c6c,
		"JASystem::Dvd::dvdThreadPauseFlag": 0x80409c74,
		"dvdThreadPauseFlag": 0x80409c74,
		"JASystem::Dvd::errorCallback": 0x80409c78,
		"errorCallback": 0x80409c78,
		"JASystem::Dvd::dvdFileDics": 0x80409c7c,
		"dvdFileDics": 0x80409c7c,
		"JASystem::Dvd::dvdFile": 0x80409c80,
		"dvdFile": 0x80409c80,
		"JASystem::Dvd::dvdEntryNum": 0x80409c84,
		"dvdEntryNum": 0x80409c84,
		"JSystem::arq_index$316": 0x80409c88,
		"arq_index$316": 0x80409c88,
		"JASystem::HardStream::streamFiles": 0x80409c94,
		"streamFiles": 0x80409c94,
		"JASystem::HardStream::playList": 0x80409c98,
		"playList": 0x80409c98,
		"JSystem::cur_finfo$426": 0x80409c9c,
		"cur_finfo$426": 0x80409c9c,
		"JSystem::last_frame$577": 0x80409ca4,
		"last_frame$577": 0x80409ca4,
		"JASystem::Kernel::global_id": 0x80409cb0,
		"global_id": 0x80409cb0,
		"JASystem::Kernel::gOutputRate": 0x80409cb8,
		"gOutputRate": 0x80409cb8,
		"JASystem::Kernel::gAiSetting": 0x80409cbc,
		"gAiSetting": 0x80409cbc,
		"JSystem::JASDram": 0x80409cc0,
		"JASDram": 0x80409cc0,
		"JASystem::Kernel::JASAramDmaBufferTop": 0x80409cc4,
		"JASAramDmaBufferTop": 0x80409cc4,
		"JASystem::Kernel::audioAramTop": 0x80409cc8,
		"audioAramTop": 0x80409cc8,
		"JASystem::Kernel::CARD_SECURITY_BUFFER": 0x80409ccc,
		"CARD_SECURITY_BUFFER": 0x80409ccc,
		"JASystem::Vload::vlDirName": 0x80409cd0,
		"vlDirName": 0x80409cd0,
		"JASystem::Vload::vlArcName": 0x80409cd4,
		"vlArcName": 0x80409cd4,
		"JASystem::Vload::vlArc": 0x80409cd8,
		"vlArc": 0x80409cd8,
		"JASystem::Vload::vlCurrentArcs": 0x80409cdc,
		"vlCurrentArcs": 0x80409cdc,
		"JASystem::TTrack::sCallBackFunc": 0x80409ce4,
		"sCallBackFunc": 0x80409ce4,
		"JASystem::TrackMgr::sTrackPool": 0x80409ce8,
		"sTrackPool": 0x80409ce8,
		"JASystem::TrackMgr::sSeqOuter": 0x80409cec,
		"sSeqOuter": 0x80409cec,
		"JASystem::TrackMgr::sRootTrack": 0x80409cf0,
		"sRootTrack": 0x80409cf0,
		"JASystem::TrackMgr::sFreeSeqpQueue": 0x80409cf4,
		"sFreeSeqpQueue": 0x80409cf4,
		"JASystem::TrackMgr::sRootSeqCount": 0x80409cf8,
		"sRootSeqCount": 0x80409cf8,
		"JASystem::TrackMgr::sTrackCount": 0x80409cfc,
		"sTrackCount": 0x80409cfc,
		"JASystem::TrackMgr::sTLists": 0x80409d00,
		"sTLists": 0x80409d00,
		"JASystem::TrackMgr::seqRemain": 0x80409d04,
		"seqRemain": 0x80409d04,
		"JASystem::TrackMgr::getP": 0x80409d08,
		"getP": 0x80409d08,
		"JASystem::TrackMgr::backP": 0x80409d0c,
		"backP": 0x80409d0c,
		"JSystem::FieldRand": 0x80409d10,
		"FieldRand": 0x80409d10,
		"JPADrawContext::pcb": 0x80409d18,
		"pcb": 0x80409d18,
		"JSystem::flag": 0x80409d20,
		"flag": 0x80409d20,
		"JSystem::taskreadp": 0x80409d28,
		"taskreadp": 0x80409d28,
		"JSystem::taskwritep": 0x80409d2c,
		"taskwritep": 0x80409d2c,
		"JSystem::__DSP_tmp_task": 0x80409d30,
		"__DSP_tmp_task": 0x80409d30,
		"JSystem::AUDIO_UPDATE_REQUEST": 0x80409d3c,
		"AUDIO_UPDATE_REQUEST": 0x80409d3c,
		"JSystem::DSP_prior_task": 0x80409d40,
		"DSP_prior_task": 0x80409d40,
		"Runtime.PPCEABI.H::__global_destructor_chain": 0x80409d48,
		"__global_destructor_chain": 0x80409d48,
		"MSL_C.PPCEABI.bare.H::__aborting": 0x80409d50,
		"__aborting": 0x80409d50,
		"MSL_C.PPCEABI.bare.H::atexit_curr_func": 0x80409d54,
		"atexit_curr_func": 0x80409d54,
		"MSL_C.PPCEABI.bare.H::__atexit_curr_func": 0x80409d58,
		"__atexit_curr_func": 0x80409d58,
		"MSL_C.PPCEABI.bare.H::__stdio_exit": 0x80409d5c,
		"__stdio_exit": 0x80409d5c,
		"MSL_C.PPCEABI.bare.H::__console_exit": 0x80409d60,
		"__console_exit": 0x80409d60,
		"MSL_C.PPCEABI.bare.H::errno": 0x80409d68,
		"errno": 0x80409d68,
		"MSL_C.PPCEABI.bare.H::initialized$16": 0x80409d70,
		"initialized$16": 0x80409d70,
		"db::__DBInterface": 0x80409d78,
		"__DBInterface": 0x80409d78,
		"db::DBVerbose": 0x80409d7c,
		"DBVerbose": 0x80409d7c,
		"os::BootInfo": 0x80409d80,
		"os::BI2DebugFlag": 0x80409d84,
		"BI2DebugFlag": 0x80409d84,
		"os::BI2DebugFlagHolder": 0x80409d88,
		"BI2DebugFlagHolder": 0x80409d88,
		"os::__OSIsGcam": 0x80409d8c,
		"__OSIsGcam": 0x80409d8c,
		"os::AreWeInitialized": 0x80409d90,
		"AreWeInitialized": 0x80409d90,
		"os::OSExceptionTable": 0x80409d94,
		"OSExceptionTable": 0x80409d94,
		"os::__OSSavedRegionEnd": 0x80409d98,
		"__OSSavedRegionEnd": 0x80409d98,
		"os::__OSSavedRegionStart": 0x80409d9c,
		"__OSSavedRegionStart": 0x80409d9c,
		"os::__OSInIPL": 0x80409da0,
		"__OSInIPL": 0x80409da0,
		"os::AlarmQueue": 0x80409db0,
		"AlarmQueue": 0x80409db0,
		"os::HeapArray": 0x80409db8,
		"HeapArray": 0x80409db8,
		"os::NumHeaps": 0x80409dbc,
		"NumHeaps": 0x80409dbc,
		"os::ArenaStart": 0x80409dc0,
		"ArenaStart": 0x80409dc0,
		"os::ArenaEnd": 0x80409dc4,
		"ArenaEnd": 0x80409dc4,
		"os::__OSArenaHi": 0x80409dc8,
		"__OSArenaHi": 0x80409dc8,
		"os::FontData": 0x80409dd0,
		"FontData": 0x80409dd0,
		"os::SheetImage": 0x80409dd4,
		"SheetImage": 0x80409dd4,
		"os::WidthTable": 0x80409dd8,
		"WidthTable": 0x80409dd8,
		"os::CharsInSheet": 0x80409ddc,
		"CharsInSheet": 0x80409ddc,
		"os::InterruptHandlerTable": 0x80409de0,
		"InterruptHandlerTable": 0x80409de0,
		"os::__OSLastInterruptSrr0": 0x80409de4,
		"__OSLastInterruptSrr0": 0x80409de4,
		"os::SaveStart": 0x80409df8,
		"SaveStart": 0x80409df8,
		"os::SaveEnd": 0x80409dfc,
		"SaveEnd": 0x80409dfc,
		"os::Prepared": 0x80409e00,
		"Prepared": 0x80409e00,
		"os::ResetFunctionQueue": 0x80409e08,
		"ResetFunctionQueue": 0x80409e08,
		"os::ResetCallback": 0x80409e10,
		"ResetCallback": 0x80409e10,
		"os::Down": 0x80409e14,
		"Down": 0x80409e14,
		"os::LastState": 0x80409e18,
		"os::RunQueueBits": 0x80409e30,
		"RunQueueBits": 0x80409e30,
		"os::RunQueueHint": 0x80409e34,
		"RunQueueHint": 0x80409e34,
		"os::Reschedule": 0x80409e38,
		"Reschedule": 0x80409e38,
		"dvd::StopAtNextInt": 0x80409e40,
		"StopAtNextInt": 0x80409e40,
		"dvd::LastLength": 0x80409e44,
		"LastLength": 0x80409e44,
		"dvd::Callback": 0x80409e48,
		"dvd::ResetCoverCallback": 0x80409e4c,
		"ResetCoverCallback": 0x80409e4c,
		"dvd::ResetOccurred": 0x80409e58,
		"ResetOccurred": 0x80409e58,
		"dvd::WaitingCoverClose": 0x80409e5c,
		"WaitingCoverClose": 0x80409e5c,
		"dvd::Breaking": 0x80409e60,
		"Breaking": 0x80409e60,
		"dvd::WorkAroundType": 0x80409e64,
		"WorkAroundType": 0x80409e64,
		"dvd::WorkAroundSeekLocation": 0x80409e68,
		"WorkAroundSeekLocation": 0x80409e68,
		"dvd::LastCommandWasRead": 0x80409e80,
		"LastCommandWasRead": 0x80409e80,
		"dvd::NextCommandNumber": 0x80409e84,
		"NextCommandNumber": 0x80409e84,
		"dvd::BootInfo": 0x80409e88,
		"dvd::FstStart": 0x80409e8c,
		"FstStart": 0x80409e8c,
		"dvd::FstStringStart": 0x80409e90,
		"FstStringStart": 0x80409e90,
		"dvd::MaxEntryNum": 0x80409e94,
		"MaxEntryNum": 0x80409e94,
		"dvd::currentDirectory": 0x80409e98,
		"currentDirectory": 0x80409e98,
		"dvd::__DVDLongFileNameFlag": 0x80409e9c,
		"__DVDLongFileNameFlag": 0x80409e9c,
		"dvd::__DVDThreadQueue": 0x80409ea0,
		"__DVDThreadQueue": 0x80409ea0,
		"dvd::executing": 0x80409ea8,
		"executing": 0x80409ea8,
		"dvd::currID": 0x80409eac,
		"currID": 0x80409eac,
		"dvd::bootInfo": 0x80409eb0,
		"bootInfo": 0x80409eb0,
		"dvd::PauseFlag": 0x80409eb4,
		"PauseFlag": 0x80409eb4,
		"dvd::PausingFlag": 0x80409eb8,
		"PausingFlag": 0x80409eb8,
		"dvd::AutoFinishing": 0x80409ebc,
		"AutoFinishing": 0x80409ebc,
		"dvd::FatalErrorFlag": 0x80409ec0,
		"FatalErrorFlag": 0x80409ec0,
		"dvd::CurrCommand": 0x80409ec4,
		"CurrCommand": 0x80409ec4,
		"dvd::Canceling": 0x80409ec8,
		"Canceling": 0x80409ec8,
		"dvd::CancelCallback": 0x80409ecc,
		"CancelCallback": 0x80409ecc,
		"dvd::ResumeFromHere": 0x80409ed0,
		"ResumeFromHere": 0x80409ed0,
		"dvd::CancelLastError": 0x80409ed4,
		"CancelLastError": 0x80409ed4,
		"dvd::LastError": 0x80409ed8,
		"LastError": 0x80409ed8,
		"dvd::NumInternalRetry": 0x80409edc,
		"NumInternalRetry": 0x80409edc,
		"dvd::ResetRequired": 0x80409ee0,
		"ResetRequired": 0x80409ee0,
		"dvd::FirstTimeInBootrom": 0x80409ee4,
		"FirstTimeInBootrom": 0x80409ee4,
		"dvd::DVDInitialized": 0x80409ee8,
		"DVDInitialized": 0x80409ee8,
		"dvd::LastState": 0x80409eec,
		"dvd::status": 0x80409ef0,
		"status": 0x80409ef0,
		"dvd::bb2": 0x80409ef4,
		"bb2": 0x80409ef4,
		"dvd::idTmp": 0x80409ef8,
		"idTmp": 0x80409ef8,
		"vi::retraceCount": 0x80409f00,
		"retraceCount": 0x80409f00,
		"vi::flushFlag": 0x80409f04,
		"flushFlag": 0x80409f04,
		"vi::retraceQueue": 0x80409f08,
		"retraceQueue": 0x80409f08,
		"vi::PreCB": 0x80409f10,
		"PreCB": 0x80409f10,
		"vi::PostCB": 0x80409f14,
		"PostCB": 0x80409f14,
		"vi::encoderType": 0x80409f18,
		"encoderType": 0x80409f18,
		"vi::changeMode": 0x80409f20,
		"vi::shdwChangeMode": 0x80409f30,
		"shdwChangeMode": 0x80409f30,
		"vi::CurrTiming": 0x80409f40,
		"CurrTiming": 0x80409f40,
		"vi::CurrTvMode": 0x80409f44,
		"CurrTvMode": 0x80409f44,
		"vi::FBSet": 0x80409f48,
		"FBSet": 0x80409f48,
		"vi::message$332": 0x80409f4c,
		"message$332": 0x80409f4c,
		"pad::Initialized": 0x80409f50,
		"pad::EnabledBits": 0x80409f54,
		"EnabledBits": 0x80409f54,
		"pad::ResettingBits": 0x80409f58,
		"ResettingBits": 0x80409f58,
		"pad::RecalibrateBits": 0x80409f5c,
		"RecalibrateBits": 0x80409f5c,
		"pad::WaitingBits": 0x80409f60,
		"WaitingBits": 0x80409f60,
		"pad::CheckingBits": 0x80409f64,
		"CheckingBits": 0x80409f64,
		"pad::PendingBits": 0x80409f68,
		"PendingBits": 0x80409f68,
		"pad::SamplingCallback": 0x80409f6c,
		"SamplingCallback": 0x80409f6c,
		"pad::recalibrated$396": 0x80409f70,
		"recalibrated$396": 0x80409f70,
		"pad::__PADSpec": 0x80409f74,
		"__PADSpec": 0x80409f74,
		"ai::__AIS_Callback": 0x80409f78,
		"__AIS_Callback": 0x80409f78,
		"ai::__AID_Callback": 0x80409f7c,
		"__AID_Callback": 0x80409f7c,
		"ai::__CallbackStack": 0x80409f80,
		"__CallbackStack": 0x80409f80,
		"ai::__OldStack": 0x80409f84,
		"__OldStack": 0x80409f84,
		"ai::__AI_init_flag": 0x80409f88,
		"__AI_init_flag": 0x80409f88,
		"ar::__AR_Callback": 0x80409fb8,
		"__AR_Callback": 0x80409fb8,
		"ar::__AR_Size": 0x80409fbc,
		"__AR_Size": 0x80409fbc,
		"ar::__AR_InternalSize": 0x80409fc0,
		"__AR_InternalSize": 0x80409fc0,
		"ar::__AR_ExpansionSize": 0x80409fc4,
		"__AR_ExpansionSize": 0x80409fc4,
		"ar::__AR_StackPointer": 0x80409fc8,
		"__AR_StackPointer": 0x80409fc8,
		"ar::__AR_FreeBlocks": 0x80409fcc,
		"__AR_FreeBlocks": 0x80409fcc,
		"ar::__AR_BlockLength": 0x80409fd0,
		"__AR_BlockLength": 0x80409fd0,
		"ar::__AR_init_flag": 0x80409fd4,
		"__AR_init_flag": 0x80409fd4,
		"ar::__ARQRequestQueueHi": 0x80409fd8,
		"__ARQRequestQueueHi": 0x80409fd8,
		"ar::__ARQRequestTailHi": 0x80409fdc,
		"__ARQRequestTailHi": 0x80409fdc,
		"ar::__ARQRequestQueueLo": 0x80409fe0,
		"__ARQRequestQueueLo": 0x80409fe0,
		"ar::__ARQRequestTailLo": 0x80409fe4,
		"__ARQRequestTailLo": 0x80409fe4,
		"ar::__ARQRequestPendingHi": 0x80409fe8,
		"__ARQRequestPendingHi": 0x80409fe8,
		"ar::__ARQRequestPendingLo": 0x80409fec,
		"__ARQRequestPendingLo": 0x80409fec,
		"ar::__ARQCallbackHi": 0x80409ff0,
		"__ARQCallbackHi": 0x80409ff0,
		"ar::__ARQCallbackLo": 0x80409ff4,
		"__ARQCallbackLo": 0x80409ff4,
		"ar::__ARQChunkSize": 0x80409ff8,
		"__ARQChunkSize": 0x80409ff8,
		"ar::__ARQ_init_flag": 0x80409ffc,
		"__ARQ_init_flag": 0x80409ffc,
		"dsp::__DSP_init_flag": 0x8040a000,
		"__DSP_init_flag": 0x8040a000,
		"dsp::__DSP_last_task": 0x8040a008,
		"__DSP_last_task": 0x8040a008,
		"dsp::__DSP_first_task": 0x8040a00c,
		"__DSP_first_task": 0x8040a00c,
		"dsp::__DSP_curr_task": 0x8040a010,
		"__DSP_curr_task": 0x8040a010,
		"gx::__piReg": 0x8040a018,
		"__piReg": 0x8040a018,
		"gx::__cpReg": 0x8040a01c,
		"__cpReg": 0x8040a01c,
		"gx::__peReg": 0x8040a020,
		"__peReg": 0x8040a020,
		"gx::__memReg": 0x8040a024,
		"__memReg": 0x8040a024,
		"gx::CPUFifo": 0x8040a028,
		"CPUFifo": 0x8040a028,
		"gx::GPFifo": 0x8040a02c,
		"GPFifo": 0x8040a02c,
		"gx::__GXCurrentThread": 0x8040a030,
		"__GXCurrentThread": 0x8040a030,
		"gx::GXOverflowSuspendInProgress": 0x8040a038,
		"GXOverflowSuspendInProgress": 0x8040a038,
		"gx::BreakPointCB": 0x8040a03c,
		"BreakPointCB": 0x8040a03c,
		"gx::__GXOverflowCount": 0x8040a040,
		"__GXOverflowCount": 0x8040a040,
		"gx::__GXCurrentBP": 0x8040a044,
		"__GXCurrentBP": 0x8040a044,
		"gx::TokenCB": 0x8040a048,
		"TokenCB": 0x8040a048,
		"gx::DrawDoneCB": 0x8040a04c,
		"DrawDoneCB": 0x8040a04c,
		"gx::FinishQueue": 0x8040a054,
		"FinishQueue": 0x8040a054,
		"OdemuExi2::MTRCallback": 0x8040a060,
		"MTRCallback": 0x8040a060,
		"OdemuExi2::DBGCallback": 0x8040a064,
		"DBGCallback": 0x8040a064,
		"OdemuExi2::SendMailData": 0x8040a068,
		"SendMailData": 0x8040a068,
		"OdemuExi2::RecvDataLeng": 0x8040a06c,
		"RecvDataLeng": 0x8040a06c,
		"OdemuExi2::pEXIInputFlag": 0x8040a070,
		"pEXIInputFlag": 0x8040a070,
		"gd::__GDCurrentDL": 0x8040a078,
		"__GDCurrentDL": 0x8040a078,
		"gd::overflowcb": 0x8040a07c,
		"overflowcb": 0x8040a07c,
		"si::cmdTypeAndStatus$77": 0x8040a080,
		"cmdTypeAndStatus$77": 0x8040a080,
		"si::cmdTypeAndStatus$371": 0x8040a084,
		"cmdTypeAndStatus$371": 0x8040a084,
		"si::__PADFixBits": 0x8040a088,
		"__PADFixBits": 0x8040a088,
		"si::SamplingRate": 0x8040a090,
		"SamplingRate": 0x8040a090,
		"exi::Chan": 0x8040a098,
		"Chan": 0x8040a098,
		"exi::Dev": 0x8040a09c,
		"Dev": 0x8040a09c,
		"exi::Enabled": 0x8040a0a0,
		"Enabled": 0x8040a0a0,
		"exi::BarnacleEnabled": 0x8040a0a4,
		"BarnacleEnabled": 0x8040a0a4,
		"thp::__THPHuffmanBits": 0x8040a164,
		"__THPHuffmanBits": 0x8040a164,
		"thp::__THPHuffmanSizeTab": 0x8040a168,
		"__THPHuffmanSizeTab": 0x8040a168,
		"thp::__THPHuffmanCodeTab": 0x8040a16c,
		"__THPHuffmanCodeTab": 0x8040a16c,
		"thp::__THPOldGQR5": 0x8040a1c4,
		"__THPOldGQR5": 0x8040a1c4,
		"thp::__THPOldGQR6": 0x8040a1c8,
		"__THPOldGQR6": 0x8040a1c8,
		"thp::__THPWorkArea": 0x8040a1cc,
		"__THPWorkArea": 0x8040a1cc,
		"thp::__THPInfo": 0x8040a1d0,
		"__THPInfo": 0x8040a1d0,
		"thp::__THPInitFlag": 0x8040a1d4,
		"__THPInitFlag": 0x8040a1d4,
		"THPPlayer::AudioDecodeThreadCreated": 0x8040a1d8,
		"AudioDecodeThreadCreated": 0x8040a1d8,
		"THPPlayer::Initialized": 0x8040a1e0,
		"THPPlayer::PrepareReadyMessage": 0x8040a1e4,
		"PrepareReadyMessage": 0x8040a1e4,
		"THPPlayer::OldVIPostCallback": 0x8040a1e8,
		"OldVIPostCallback": 0x8040a1e8,
		"THPPlayer::SoundBufferIndex": 0x8040a1ec,
		"SoundBufferIndex": 0x8040a1ec,
		"THPPlayer::LastAudioBuffer": 0x8040a1f0,
		"LastAudioBuffer": 0x8040a1f0,
		"THPPlayer::CurAudioBuffer": 0x8040a1f4,
		"CurAudioBuffer": 0x8040a1f4,
		"THPPlayer::ReadThreadCreated": 0x8040a1f8,
		"ReadThreadCreated": 0x8040a1f8,
		"THPPlayer::VideoDecodeThreadCreated": 0x8040a200,
		"VideoDecodeThreadCreated": 0x8040a200,
		"THPPlayer::First": 0x8040a204,
		"First": 0x8040a204,
		"MarioUtil::gpSilhouetteManager": 0x8040a208,
		"gpSilhouetteManager": 0x8040a208,
		"MarioUtil::sKeepViewClipFovy": 0x8040a20c,
		"sKeepViewClipFovy": 0x8040a20c,
		"MarioUtil::sKeepViewClipAspect": 0x8040a210,
		"sKeepViewClipAspect": 0x8040a210,
		"MarioUtil::sKeepViewClipNear": 0x8040a214,
		"sKeepViewClipNear": 0x8040a214,
		"MarioUtil::sKeepViewClipFar": 0x8040a218,
		"sKeepViewClipFar": 0x8040a218,
		"TLightCommon::mAmbAry": 0x8040a220,
		"mAmbAry": 0x8040a220,
		"TLightCommon::mLightAry": 0x8040a224,
		"mLightAry": 0x8040a224,
		"TLightCommon::mLightPos": 0x8040a228,
		"mLightPos": 0x8040a228,
		"MarioUtil::gpLightManager": 0x8040a22c,
		"gpLightManager": 0x8040a22c,
		"MarioUtil::gpAfterEffect": 0x8040a230,
		"gpAfterEffect": 0x8040a230,
		"MarioUtil::gpScreenTexture": 0x8040a234,
		"gpScreenTexture": 0x8040a234,
		"MarioUtil::gpBindShadowManager": 0x8040a238,
		"gpBindShadowManager": 0x8040a238,
		"TMBindShadowManager::mJoinDist": 0x8040a23c,
		"mJoinDist": 0x8040a23c,
		"MarioUtil::SMSRumbleMgr": 0x8040a248,
		"SMSRumbleMgr": 0x8040a248,
		"MarioUtil::currentTGDLStatic": 0x8040a250,
		"currentTGDLStatic": 0x8040a250,
		"System::gpMarioParticleManager": 0x8040a258,
		"gpMarioParticleManager": 0x8040a258,
		"System::emitterCallBackBindToPosPtr": 0x8040a25c,
		"emitterCallBackBindToPosPtr": 0x8040a25c,
		"System::emitterCallBackBindToMtxPtr": 0x8040a260,
		"emitterCallBackBindToMtxPtr": 0x8040a260,
		"System::emitterCallBackBindToSRTMtxPtr": 0x8040a264,
		"emitterCallBackBindToSRTMtxPtr": 0x8040a264,
		"TFlagManager::smInstance": 0x8040a290,
		"System::gpSceneCmnDat": 0x8040a298,
		"gpSceneCmnDat": 0x8040a298,
		"System::gpSceneCmnDatSize": 0x8040a29c,
		"gpSceneCmnDatSize": 0x8040a29c,
		"TParams::mArc": 0x8040a2a0,
		"mArc": 0x8040a2a0,
		"TParams::mSceneArc": 0x8040a2a4,
		"mSceneArc": 0x8040a2a4,
		"System::gpMarDirector": 0x8040a2a8,
		"gpMarDirector": 0x8040a2a8,
		"System::gpMSound": 0x8040a2ac,
		"gpMSound": 0x8040a2ac,
		"System::gpSetupThreadStack": 0x8040a2b0,
		"gpSetupThreadStack": 0x8040a2b0,
		"System::gpCardManager": 0x8040a2b4,
		"gpCardManager": 0x8040a2b4,
		"System::gpSystemFont": 0x8040a2b8,
		"gpSystemFont": 0x8040a2b8,
		"System::gpRomFont": 0x8040a2bc,
		"gpRomFont": 0x8040a2bc,
		"System::sGameInit": 0x8040a2c0,
		"sGameInit": 0x8040a2c0,
		"System::arcBufNLogo": 0x8040a2c4,
		"arcBufNLogo": 0x8040a2c4,
		"System::arcBufMario": 0x8040a2c8,
		"arcBufMario": 0x8040a2c8,
		"System::arcBufCmn": 0x8040a2cc,
		"arcBufCmn": 0x8040a2cc,
		"System::bufStageArcBin": 0x8040a2d0,
		"bufStageArcBin": 0x8040a2d0,
		"System::spGameHeapBlock": 0x8040a2d4,
		"spGameHeapBlock": 0x8040a2d4,
		"System::gArBkConsole": 0x8040a2d8,
		"gArBkConsole": 0x8040a2d8,
		"System::gArBkGuide": 0x8040a2e0,
		"gArBkGuide": 0x8040a2e0,
		"TMarioGamePad::mResetFlag": 0x8040a2e8,
		"mResetFlag": 0x8040a2e8,
		"System::gpPositionHolder": 0x8040a2f0,
		"gpPositionHolder": 0x8040a2f0,
		"TTimeRec::_instance": 0x8040a2f8,
		"_instance": 0x8040a2f8,
		"TDrawSyncManager::smInstance": 0x8040a300,
		"System::sDetach": 0x8040a308,
		"sDetach": 0x8040a308,
		"System::gpResourceManager": 0x8040a310,
		"gpResourceManager": 0x8040a310,
		"System::gpEmitterManager4D2": 0x8040a314,
		"gpEmitterManager4D2": 0x8040a314,
		"MSMainProc::MSStageInfo::msStg": 0x8040a318,
		"msStg": 0x8040a318,
		"MSMainProc::MSStageInfo::demoBgm": 0x8040a31c,
		"demoBgm": 0x8040a31c,
		"MSMainProc::MSStageInfo::stageBgm": 0x8040a320,
		"stageBgm": 0x8040a320,
		"MSMainProc::MSStageInfo::stageBgmSilent": 0x8040a324,
		"stageBgmSilent": 0x8040a324,
		"MSMainProc::MSStageInfo::switchBgm": 0x8040a330,
		"switchBgm": 0x8040a330,
		"MSMainProc::MSStageInfo::switchBgm2": 0x8040a334,
		"switchBgm2": 0x8040a334,
		"MSMainProc::MSStageInfo::cubeFadeRatio": 0x8040a338,
		"cubeFadeRatio": 0x8040a338,
		"MSStage::smMSStage": 0x8040a344,
		"smMSStage": 0x8040a344,
		"System::gpTargetArrow": 0x8040a348,
		"gpTargetArrow": 0x8040a348,
		"Strategic::gpObjHitCheck": 0x8040a350,
		"gpObjHitCheck": 0x8040a350,
		"Strategic::gpStrategy": 0x8040a360,
		"gpStrategy": 0x8040a360,
		"Strategic::gpQuestionManager": 0x8040a368,
		"gpQuestionManager": 0x8040a368,
		"Player::gpMarioForCallBack": 0x8040a370,
		"gpMarioForCallBack": 0x8040a370,
		"Player::gpMarioOriginal": 0x8040a378,
		"gpMarioOriginal": 0x8040a378,
		"Player::bubbleCallBack": 0x8040a384,
		"bubbleCallBack": 0x8040a384,
		"Player::warpInCallBack": 0x8040a38c,
		"warpInCallBack": 0x8040a38c,
		"Player::gpSplashManager": 0x8040a390,
		"gpSplashManager": 0x8040a390,
		"Player::gpMarioAddress": 0x8040a398,
		"gpMarioAddress": 0x8040a398,
		"Player::gpMarioPos": 0x8040a39c,
		"gpMarioPos": 0x8040a39c,
		"Player::gpMarioAngleX": 0x8040a3a0,
		"gpMarioAngleX": 0x8040a3a0,
		"Player::gpMarioAngleY": 0x8040a3a4,
		"gpMarioAngleY": 0x8040a3a4,
		"Player::gpMarioAngleZ": 0x8040a3a8,
		"gpMarioAngleZ": 0x8040a3a8,
		"Player::gpMarioSpeedX": 0x8040a3ac,
		"gpMarioSpeedX": 0x8040a3ac,
		"Player::gpMarioSpeedY": 0x8040a3b0,
		"gpMarioSpeedY": 0x8040a3b0,
		"Player::gpMarioSpeedZ": 0x8040a3b4,
		"gpMarioSpeedZ": 0x8040a3b4,
		"Player::gpMarioLightID": 0x8040a3b8,
		"gpMarioLightID": 0x8040a3b8,
		"Player::gpMarioFlag": 0x8040a3bc,
		"gpMarioFlag": 0x8040a3bc,
		"Player::gpMarioThrowPower": 0x8040a3c0,
		"gpMarioThrowPower": 0x8040a3c0,
		"Player::gpMarioGroundPlane": 0x8040a3c4,
		"gpMarioGroundPlane": 0x8040a3c4,
		"Player::gpModelWaterManager": 0x8040a3c8,
		"gpModelWaterManager": 0x8040a3c8,
		"Player::sphere_glist_p": 0x8040a3d0,
		"sphere_glist_p": 0x8040a3d0,
		"Player::sphere_pos_t": 0x8040a3d4,
		"sphere_pos_t": 0x8040a3d4,
		"TBaseNPC::mPtrSaveNormal": 0x8040a3e0,
		"mPtrSaveNormal": 0x8040a3e0,
		"NPC::gpCurrentNpc": 0x8040a3e8,
		"gpCurrentNpc": 0x8040a3e8,
		"TMonteMBaseManager::mStaticCommonKeeper": 0x8040a3f0,
		"TMonteWBaseManager::mStaticCommonKeeper": 0x8040a3f4,
		"TMareMBaseManager::mStaticCommonKeeper": 0x8040a3f8,
		"TMareWBaseManager::mStaticCommonKeeper": 0x8040a3fc,
		"TMareBaseManager::mStaticBmtNormal": 0x8040a400,
		"mStaticBmtNormal": 0x8040a400,
		"TMareBaseManager::mStaticBmtPollution": 0x8040a404,
		"mStaticBmtPollution": 0x8040a404,
		"NPC::gpMareJellyFishManager": 0x8040a408,
		"gpMareJellyFishManager": 0x8040a408,
		"NPC::instance$2212": 0x8040a414,
		"instance$2212": 0x8040a414,
		"NPC::instance$2243": 0x8040a41c,
		"instance$2243": 0x8040a41c,
		"NPC::instance$2251": 0x8040a424,
		"instance$2251": 0x8040a424,
		"NPC::instance$2264": 0x8040a42c,
		"NPC::instance$2275": 0x8040a434,
		"instance$2275": 0x8040a434,
		"NPC::instance$2303": 0x8040a43c,
		"instance$2303": 0x8040a43c,
		"NPC::instance$2349": 0x8040a444,
		"instance$2349": 0x8040a444,
		"NPC::instance$2359": 0x8040a44c,
		"NPC::instance$2365": 0x8040a454,
		"instance$2365": 0x8040a454,
		"NPC::instance$2373": 0x8040a45c,
		"instance$2373": 0x8040a45c,
		"NPC::instance$2384": 0x8040a464,
		"instance$2384": 0x8040a464,
		"NPC::instance$2390": 0x8040a46c,
		"instance$2390": 0x8040a46c,
		"NPC::instance$2404": 0x8040a474,
		"instance$2404": 0x8040a474,
		"NPC::instance$2414": 0x8040a47c,
		"instance$2414": 0x8040a47c,
		"NPC::instance$2424": 0x8040a484,
		"instance$2424": 0x8040a484,
		"NPC::instance$2436": 0x8040a48c,
		"instance$2436": 0x8040a48c,
		"TNpcEvent::mDownSunflowerNum": 0x8040a490,
		"mDownSunflowerNum": 0x8040a490,
		"NPC::sViewObjName$2632": 0x8040a494,
		"sViewObjName$2632": 0x8040a494,
		"TBaseNPC::sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x8040a4a0,
		"sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x8040a4a0,
		"TNpcTrample::msAmpDecrease": 0x8040a4a8,
		"msAmpDecrease": 0x8040a4a8,
		"MSound::MSGMSound": 0x8040a4b4,
		"MSGMSound": 0x8040a4b4,
		"MSound::MSGBasic": 0x8040a4b8,
		"MSGBasic": 0x8040a4b8,
		"MSoundSESystem::MSoundSE::mObj": 0x8040a4c0,
		"mObj": 0x8040a4c0,
		"MSoundSESystem::SeInfo::smSeSetting": 0x8040a4c4,
		"smSeSetting": 0x8040a4c4,
		"MoveBG::gpMapObjManager": 0x8040a4d0,
		"gpMapObjManager": 0x8040a4d0,
		"MoveBG::gpItemManager": 0x8040a4d8,
		"gpItemManager": 0x8040a4d8,
		"MoveBG::gpMapObjSwitch": 0x8040a4e0,
		"gpMapObjSwitch": 0x8040a4e0,
		"MoveBG::sAngleAdd": 0x8040a4e8,
		"sAngleAdd": 0x8040a4e8,
		"MoveBG::gpCurObject": 0x8040a4f0,
		"gpCurObject": 0x8040a4f0,
		"TRiccoWatermill::mSubmarineSurfaceTransY": 0x8040a4f8,
		"mSubmarineSurfaceTransY": 0x8040a4f8,
		"MoveBG::switchSnd": 0x8040a500,
		"switchSnd": 0x8040a500,
		"MoveBG::gpMapObjFlagManager": 0x8040a508,
		"gpMapObjFlagManager": 0x8040a508,
		"MoveBG::total_use_size$2278": 0x8040a50c,
		"total_use_size$2278": 0x8040a50c,
		"MoveBG::sColor": 0x8040a518,
		"sColor": 0x8040a518,
		"MoveBG::gpMapObjWave": 0x8040a51c,
		"gpMapObjWave": 0x8040a51c,
		"MoveBG::timer$2477": 0x8040a520,
		"timer$2477": 0x8040a520,
		"TMapObjGrassManager::mColorUpper": 0x8040a530,
		"TMapObjGrassManager::mColorLower": 0x8040a534,
		"TMapObjGrassManager::mColorFar": 0x8040a538,
		"mColorFar": 0x8040a538,
		"TMapObjGrassManager::mDrawVecS16": 0x8040a53c,
		"mDrawVecS16": 0x8040a53c,
		"MoveBG::gpMapObjGrassManager": 0x8040a544,
		"gpMapObjGrassManager": 0x8040a544,
		"MoveBG::gpMapObjPoleManager": 0x8040a548,
		"gpMapObjPoleManager": 0x8040a548,
		"THangingBridge::mRopeHeight": 0x8040a550,
		"mRopeHeight": 0x8040a550,
		"TMapObjTumblePole::mColorUpper": 0x8040a558,
		"TMapObjTumblePole::mColorLower": 0x8040a55c,
		"MoveBG::gpPoolManager": 0x8040a560,
		"gpPoolManager": 0x8040a560,
		"Map::gpMap": 0x8040a570,
		"gpMap": 0x8040a570,
		"Map::gpMapCollisionData": 0x8040a578,
		"gpMapCollisionData": 0x8040a578,
		"Map::gpMirrorModelManager": 0x8040a580,
		"gpMirrorModelManager": 0x8040a580,
		"TMapStaticObj::mEffectCoronaScale": 0x8040a588,
		"mEffectCoronaScale": 0x8040a588,
		"Map::gpMapWireManager": 0x8040a590,
		"gpMapWireManager": 0x8040a590,
		"TMapWireManager::mUpperSurface": 0x8040a594,
		"mUpperSurface": 0x8040a594,
		"TMapWireManager::mLowerSurface": 0x8040a598,
		"mLowerSurface": 0x8040a598,
		"Map::counter$2576": 0x8040a5a0,
		"counter$2576": 0x8040a5a0,
		"Map::gpPollution": 0x8040a5a8,
		"gpPollution": 0x8040a5a8,
		"Map::effect_counter$2421": 0x8040a5b0,
		"effect_counter$2421": 0x8040a5b0,
		"Map::now_pos_no$2429": 0x8040a5b8,
		"now_pos_no$2429": 0x8040a5b8,
		"Map::counter_x$2434": 0x8040a5c0,
		"counter_x$2434": 0x8040a5c0,
		"Map::counter_z$2437": 0x8040a5c8,
		"counter_z$2437": 0x8040a5c8,
		"Map::effect_timer$2449": 0x8040a5d0,
		"effect_timer$2449": 0x8040a5d0,
		"Map::delta$2349": 0x8040a5d8,
		"delta$2349": 0x8040a5d8,
		"TGCConsole2::cDownTopPoint": 0x8040a5e0,
		"cDownTopPoint": 0x8040a5e0,
		"TGCConsole2::cDownMidPoint": 0x8040a5e8,
		"cDownMidPoint": 0x8040a5e8,
		"TGCConsole2::cDownBotPoint": 0x8040a5f0,
		"cDownBotPoint": 0x8040a5f0,
		"TGCConsole2::cUpTopPoint": 0x8040a5f8,
		"cUpTopPoint": 0x8040a5f8,
		"TGCConsole2::cUpMidPoint": 0x8040a600,
		"cUpMidPoint": 0x8040a600,
		"TGCConsole2::cUpBotPoint": 0x8040a608,
		"cUpBotPoint": 0x8040a608,
		"TGCConsole2::cCoinTopPoint": 0x8040a610,
		"cCoinTopPoint": 0x8040a610,
		"TGCConsole2::cCoinMidPoint": 0x8040a618,
		"cCoinMidPoint": 0x8040a618,
		"TGCConsole2::cCoinBotPoint": 0x8040a620,
		"cCoinBotPoint": 0x8040a620,
		"GC2D::gpTalk2D": 0x8040a628,
		"gpTalk2D": 0x8040a628,
		"GC2D::gpCardLoad": 0x8040a630,
		"gpCardLoad": 0x8040a630,
		"TConsoleStr::cShineGetRight1": 0x8040a638,
		"cShineGetRight1": 0x8040a638,
		"TConsoleStr::cShineGetLeft1": 0x8040a640,
		"cShineGetLeft1": 0x8040a640,
		"TConsoleStr::cShineGetRight2": 0x8040a648,
		"cShineGetRight2": 0x8040a648,
		"TConsoleStr::cShineGetLeft2": 0x8040a650,
		"cShineGetLeft2": 0x8040a650,
		"TConsoleStr::cShineGetRight3": 0x8040a658,
		"cShineGetRight3": 0x8040a658,
		"TConsoleStr::cShineGetLeft3": 0x8040a660,
		"cShineGetLeft3": 0x8040a660,
		"GC2D::vtable": 0x8040a674,
		"vtable": 0x8040a674,
		"GC2D::r$181": 0x8040a67c,
		"r$181": 0x8040a67c,
		"GC2D::p1$182": 0x8040a680,
		"p1$182": 0x8040a680,
		"GC2D::p2$183": 0x8040a684,
		"p2$183": 0x8040a684,
		"GC2D::p3$184": 0x8040a688,
		"p3$184": 0x8040a688,
		"GC2D::boke$188": 0x8040a694,
		"boke$188": 0x8040a694,
		"GC2D::rot$260": 0x8040a698,
		"rot$260": 0x8040a698,
		"GC2D::fade$261": 0x8040a69c,
		"fade$261": 0x8040a69c,
		"GC2D::boundstate$263": 0x8040a6a0,
		"boundstate$263": 0x8040a6a0,
		"GC2D::boundtimer$264": 0x8040a6a4,
		"boundtimer$264": 0x8040a6a4,
		"GC2D::bounddelta$265": 0x8040a6a8,
		"bounddelta$265": 0x8040a6a8,
		"GC2D::hxs_logo_resetflag": 0x8040a6b0,
		"hxs_logo_resetflag": 0x8040a6b0,
		"GC2D::hxs_logodraw_resetflag": 0x8040a6b4,
		"hxs_logodraw_resetflag": 0x8040a6b4,
		"GC2D::dp$320": 0x8040a6b8,
		"dp$320": 0x8040a6b8,
		"GC2D::bx$321": 0x8040a6bc,
		"bx$321": 0x8040a6bc,
		"GC2D::by$322": 0x8040a6c0,
		"by$322": 0x8040a6c0,
		"GC2D::count$323": 0x8040a6c4,
		"count$323": 0x8040a6c4,
		"GC2D::r$393": 0x8040a6c8,
		"r$393": 0x8040a6c8,
		"GC2D::r$416": 0x8040a6cc,
		"r$416": 0x8040a6cc,
		"GC2D::r$432": 0x8040a6d0,
		"r$432": 0x8040a6d0,
		"GC2D::thin$469": 0x8040a6d4,
		"thin$469": 0x8040a6d4,
		"GC2D::rstep$470": 0x8040a6d8,
		"rstep$470": 0x8040a6d8,
		"GC2D::thin_d$471": 0x8040a6dc,
		"thin_d$471": 0x8040a6dc,
		"GC2D::rstep_d$472": 0x8040a6e0,
		"rstep_d$472": 0x8040a6e0,
		"Enemy::gpConductor": 0x8040a6e8,
		"gpConductor": 0x8040a6e8,
		"Enemy::gpEffectObjManager": 0x8040a6f0,
		"gpEffectObjManager": 0x8040a6f0,
		"Enemy::gpCurGesso": 0x8040a6f8,
		"gpCurGesso": 0x8040a6f8,
		"Enemy::instance$3220": 0x8040a700,
		"instance$3220": 0x8040a700,
		"Enemy::instance$3273": 0x8040a718,
		"instance$3273": 0x8040a718,
		"Enemy::instance$3370": 0x8040a730,
		"instance$3370": 0x8040a730,
		"Enemy::instance$3380": 0x8040a738,
		"instance$3380": 0x8040a738,
		"Enemy::instance$3756": 0x8040a74c,
		"instance$3756": 0x8040a74c,
		"Enemy::instance$3770": 0x8040a754,
		"instance$3770": 0x8040a754,
		"Enemy::instance$3787": 0x8040a75c,
		"instance$3787": 0x8040a75c,
		"Enemy::instance$3799": 0x8040a764,
		"instance$3799": 0x8040a764,
		"Enemy::instance$3827": 0x8040a774,
		"instance$3827": 0x8040a774,
		"Enemy::instance$3843": 0x8040a77c,
		"instance$3843": 0x8040a77c,
		"Enemy::instance$3874": 0x8040a78c,
		"instance$3874": 0x8040a78c,
		"Enemy::instance$3888": 0x8040a794,
		"instance$3888": 0x8040a794,
		"Enemy::instance$3899": 0x8040a79c,
		"instance$3899": 0x8040a79c,
		"Enemy::instance$3909": 0x8040a7a4,
		"instance$3909": 0x8040a7a4,
		"Enemy::instance$3922": 0x8040a7ac,
		"instance$3922": 0x8040a7ac,
		"Enemy::gpCurHinokuri": 0x8040a7b0,
		"gpCurHinokuri": 0x8040a7b0,
		"Enemy::instance$3385": 0x8040a7b8,
		"instance$3385": 0x8040a7b8,
		"Enemy::instance$3434": 0x8040a7c8,
		"instance$3434": 0x8040a7c8,
		"Enemy::instance$3450": 0x8040a7d0,
		"instance$3450": 0x8040a7d0,
		"Enemy::instance$3461": 0x8040a7d8,
		"instance$3461": 0x8040a7d8,
		"Enemy::instance$3474": 0x8040a7e0,
		"instance$3474": 0x8040a7e0,
		"Enemy::instance$3493": 0x8040a7e8,
		"instance$3493": 0x8040a7e8,
		"Enemy::instance$3510": 0x8040a7f0,
		"instance$3510": 0x8040a7f0,
		"Enemy::instance$3540": 0x8040a7f8,
		"instance$3540": 0x8040a7f8,
		"Enemy::instance$3569": 0x8040a800,
		"instance$3569": 0x8040a800,
		"Enemy::instance$3583": 0x8040a808,
		"instance$3583": 0x8040a808,
		"Enemy::instance$3593": 0x8040a810,
		"instance$3593": 0x8040a810,
		"Enemy::instance$3605": 0x8040a818,
		"instance$3605": 0x8040a818,
		"Enemy::instance$3623": 0x8040a820,
		"instance$3623": 0x8040a820,
		"Enemy::instance$2572": 0x8040a82c,
		"instance$2572": 0x8040a82c,
		"Enemy::instance$2630": 0x8040a834,
		"instance$2630": 0x8040a834,
		"Enemy::instance$2653": 0x8040a83c,
		"instance$2653": 0x8040a83c,
		"Enemy::instance$2707": 0x8040a854,
		"instance$2707": 0x8040a854,
		"Enemy::instance$2725": 0x8040a85c,
		"instance$2725": 0x8040a85c,
		"Enemy::instance$2752": 0x8040a864,
		"instance$2752": 0x8040a864,
		"Enemy::gpCurNameKuri": 0x8040a868,
		"gpCurNameKuri": 0x8040a868,
		"Enemy::instance$3068": 0x8040a870,
		"instance$3068": 0x8040a870,
		"Enemy::instance$3145": 0x8040a888,
		"instance$3145": 0x8040a888,
		"Enemy::instance$3157": 0x8040a890,
		"instance$3157": 0x8040a890,
		"Enemy::instance$3165": 0x8040a898,
		"instance$3165": 0x8040a898,
		"Enemy::gpCurPakkun": 0x8040a8a8,
		"gpCurPakkun": 0x8040a8a8,
		"Enemy::gpCurPakkunSeed": 0x8040a8ac,
		"gpCurPakkunSeed": 0x8040a8ac,
		"Enemy::instance$3308": 0x8040a8cc,
		"instance$3308": 0x8040a8cc,
		"Enemy::instance$3305": 0x8040a91c,
		"instance$3305": 0x8040a91c,
		"Enemy::instance$2166": 0x8040a924,
		"instance$2166": 0x8040a924,
		"Enemy::instance$2614": 0x8040a92c,
		"instance$2614": 0x8040a92c,
		"Enemy::instance$2625": 0x8040a934,
		"instance$2625": 0x8040a934,
		"Enemy::instance$2637": 0x8040a93c,
		"instance$2637": 0x8040a93c,
		"Enemy::instance$2656": 0x8040a944,
		"instance$2656": 0x8040a944,
		"Enemy::instance$2667": 0x8040a94c,
		"instance$2667": 0x8040a94c,
		"Enemy::instance$2681": 0x8040a954,
		"instance$2681": 0x8040a954,
		"Enemy::instance$3718": 0x8040a95c,
		"instance$3718": 0x8040a95c,
		"Enemy::instance$3736": 0x8040a964,
		"instance$3736": 0x8040a964,
		"Enemy::instance$3751": 0x8040a96c,
		"instance$3751": 0x8040a96c,
		"Enemy::instance$3782": 0x8040a974,
		"instance$3782": 0x8040a974,
		"Enemy::instance$3821": 0x8040a984,
		"instance$3821": 0x8040a984,
		"Enemy::instance$3868": 0x8040a98c,
		"instance$3868": 0x8040a98c,
		"Enemy::instance$3884": 0x8040a994,
		"instance$3884": 0x8040a994,
		"Enemy::instance$3901": 0x8040a99c,
		"instance$3901": 0x8040a99c,
		"Enemy::instance$3274": 0x8040a9cc,
		"instance$3274": 0x8040a9cc,
		"Enemy::instance$3285": 0x8040a9d4,
		"instance$3285": 0x8040a9d4,
		"Enemy::instance$3304": 0x8040a9dc,
		"instance$3304": 0x8040a9dc,
		"Enemy::instance$3312": 0x8040a9e4,
		"instance$3312": 0x8040a9e4,
		"Enemy::instance$3332": 0x8040a9f4,
		"instance$3332": 0x8040a9f4,
		"Enemy::instance$3353": 0x8040a9fc,
		"instance$3353": 0x8040a9fc,
		"Enemy::instance$3374": 0x8040aa04,
		"instance$3374": 0x8040aa04,
		"Enemy::instance$3404": 0x8040aa14,
		"instance$3404": 0x8040aa14,
		"Enemy::instance$3483": 0x8040aa1c,
		"instance$3483": 0x8040aa1c,
		"Enemy::instance$3497": 0x8040aa24,
		"instance$3497": 0x8040aa24,
		"Enemy::instance$3509": 0x8040aa2c,
		"instance$3509": 0x8040aa2c,
		"Enemy::instance$3519": 0x8040aa34,
		"instance$3519": 0x8040aa34,
		"Enemy::instance$3532": 0x8040aa3c,
		"instance$3532": 0x8040aa3c,
		"Enemy::instance$3547": 0x8040aa44,
		"instance$3547": 0x8040aa44,
		"Enemy::instance$3582": 0x8040aa5c,
		"instance$3582": 0x8040aa5c,
		"Enemy::instance$3592": 0x8040aa64,
		"instance$3592": 0x8040aa64,
		"Enemy::instance$3607": 0x8040aa6c,
		"instance$3607": 0x8040aa6c,
		"Enemy::instance$3618": 0x8040aa74,
		"instance$3618": 0x8040aa74,
		"Enemy::instance$3633": 0x8040aa80,
		"instance$3633": 0x8040aa80,
		"Enemy::instance$3673": 0x8040aa88,
		"instance$3673": 0x8040aa88,
		"Enemy::instance$3686": 0x8040aa90,
		"instance$3686": 0x8040aa90,
		"Enemy::instance$3715": 0x8040aa98,
		"instance$3715": 0x8040aa98,
		"Enemy::instance$3727": 0x8040aaa0,
		"instance$3727": 0x8040aaa0,
		"Enemy::instance$3740": 0x8040aaa8,
		"instance$3740": 0x8040aaa8,
		"Enemy::instance$3753": 0x8040aab0,
		"instance$3753": 0x8040aab0,
		"Enemy::instance$3767": 0x8040aab8,
		"instance$3767": 0x8040aab8,
		"Enemy::instance$3779": 0x8040aac0,
		"instance$3779": 0x8040aac0,
		"Enemy::instance$3803": 0x8040aac8,
		"instance$3803": 0x8040aac8,
		"Enemy::instance$3816": 0x8040aad0,
		"instance$3816": 0x8040aad0,
		"Enemy::instance$3828": 0x8040aad8,
		"instance$3828": 0x8040aad8,
		"Enemy::instance$3842": 0x8040aae0,
		"instance$3842": 0x8040aae0,
		"Enemy::instance$3852": 0x8040aae8,
		"instance$3852": 0x8040aae8,
		"Enemy::instance$3862": 0x8040aaf0,
		"instance$3862": 0x8040aaf0,
		"Enemy::instance$3879": 0x8040aaf8,
		"instance$3879": 0x8040aaf8,
		"Enemy::instance$3897": 0x8040ab00,
		"instance$3897": 0x8040ab00,
		"Enemy::instance$3910": 0x8040ab08,
		"instance$3910": 0x8040ab08,
		"Enemy::instance$3926": 0x8040ab10,
		"instance$3926": 0x8040ab10,
		"Enemy::instance$3938": 0x8040ab18,
		"instance$3938": 0x8040ab18,
		"Enemy::instance$3948": 0x8040ab20,
		"instance$3948": 0x8040ab20,
		"Enemy::instance$3962": 0x8040ab28,
		"instance$3962": 0x8040ab28,
		"Enemy::instance$3999": 0x8040ab30,
		"instance$3999": 0x8040ab30,
		"Enemy::instance$4007": 0x8040ab38,
		"instance$4007": 0x8040ab38,
		"Enemy::instance$4017": 0x8040ab40,
		"instance$4017": 0x8040ab40,
		"Enemy::instance$4033": 0x8040ab48,
		"instance$4033": 0x8040ab48,
		"Enemy::gpCurTobiPuku": 0x8040ab50,
		"gpCurTobiPuku": 0x8040ab50,
		"Enemy::instance$3083": 0x8040ab58,
		"instance$3083": 0x8040ab58,
		"Enemy::instance$3095": 0x8040ab60,
		"instance$3095": 0x8040ab60,
		"Enemy::instance$3113": 0x8040ab68,
		"instance$3113": 0x8040ab68,
		"Enemy::instance$3128": 0x8040ab70,
		"Enemy::instance$3153": 0x8040ab78,
		"instance$3153": 0x8040ab78,
		"Enemy::instance$3195": 0x8040ab90,
		"instance$3195": 0x8040ab90,
		"Enemy::instance$3246": 0x8040aba0,
		"instance$3246": 0x8040aba0,
		"Enemy::instance$3538": 0x8040abbc,
		"instance$3538": 0x8040abbc,
		"Enemy::instance$3550": 0x8040abc4,
		"instance$3550": 0x8040abc4,
		"Enemy::TNerveWaitForever<TLiveActor>::instance$localstatic0$theNerve": 0x8040abd4,
		"Enemy::instance$3488": 0x8040abdc,
		"instance$3488": 0x8040abdc,
		"Enemy::instance$3535": 0x8040abe4,
		"instance$3535": 0x8040abe4,
		"Enemy::instance$3548": 0x8040abec,
		"instance$3548": 0x8040abec,
		"Enemy::instance$3562": 0x8040abf4,
		"instance$3562": 0x8040abf4,
		"Enemy::instance$3590": 0x8040ac04,
		"instance$3590": 0x8040ac04,
		"Enemy::instance$3600": 0x8040ac0c,
		"instance$3600": 0x8040ac0c,
		"Enemy::instance$3619": 0x8040ac14,
		"instance$3619": 0x8040ac14,
		"Enemy::instance$3638": 0x8040ac1c,
		"instance$3638": 0x8040ac1c,
		"Enemy::instance$3652": 0x8040ac24,
		"instance$3652": 0x8040ac24,
		"Enemy::instance$3662": 0x8040ac2c,
		"instance$3662": 0x8040ac2c,
		"Enemy::gpCurChuuHana": 0x8040ac30,
		"gpCurChuuHana": 0x8040ac30,
		"Enemy::instance$3192": 0x8040ac68,
		"instance$3192": 0x8040ac68,
		"Enemy::instance$3238": 0x8040ac88,
		"instance$3238": 0x8040ac88,
		"Enemy::gpCurRollEnemy": 0x8040ac90,
		"gpCurRollEnemy": 0x8040ac90,
		"TRollEnemy::mTransYOffset": 0x8040ac94,
		"mTransYOffset": 0x8040ac94,
		"Enemy::instance$3464": 0x8040acb4,
		"instance$3464": 0x8040acb4,
		"Enemy::instance$3477": 0x8040acbc,
		"instance$3477": 0x8040acbc,
		"Enemy::instance$3098": 0x8040acc4,
		"instance$3098": 0x8040acc4,
		"Enemy::instance$3135": 0x8040accc,
		"instance$3135": 0x8040accc,
		"Enemy::instance$3342": 0x8040ace4,
		"instance$3342": 0x8040ace4,
		"Enemy::instance$3351": 0x8040acec,
		"instance$3351": 0x8040acec,
		"Enemy::instance$3414": 0x8040acf4,
		"instance$3414": 0x8040acf4,
		"Enemy::instance$3432": 0x8040acfc,
		"instance$3432": 0x8040acfc,
		"Enemy::instance$3456": 0x8040ad0c,
		"instance$3456": 0x8040ad0c,
		"Enemy::instance$3507": 0x8040ad1c,
		"instance$3507": 0x8040ad1c,
		"Enemy::instance$3206": 0x8040ad24,
		"instance$3206": 0x8040ad24,
		"Enemy::instance$3258": 0x8040ad2c,
		"instance$3258": 0x8040ad2c,
		"Enemy::instance$4031": 0x8040ad34,
		"instance$4031": 0x8040ad34,
		"Enemy::instance$4073": 0x8040ad3c,
		"instance$4073": 0x8040ad3c,
		"Enemy::instance$4087": 0x8040ad44,
		"instance$4087": 0x8040ad44,
		"Enemy::instance$4097": 0x8040ad4c,
		"instance$4097": 0x8040ad4c,
		"Enemy::instance$4110": 0x8040ad54,
		"instance$4110": 0x8040ad54,
		"Enemy::instance$4132": 0x8040ad5c,
		"instance$4132": 0x8040ad5c,
		"Enemy::instance$4148": 0x8040ad64,
		"instance$4148": 0x8040ad64,
		"Enemy::instance$4164": 0x8040ad6c,
		"instance$4164": 0x8040ad6c,
		"Enemy::instance$4199": 0x8040ad74,
		"instance$4199": 0x8040ad74,
		"Enemy::instance$4210": 0x8040ad7c,
		"instance$4210": 0x8040ad7c,
		"Enemy::instance$2174": 0x8040ad84,
		"instance$2174": 0x8040ad84,
		"Enemy::instance$3008": 0x8040ad8c,
		"instance$3008": 0x8040ad8c,
		"Enemy::instance$3029": 0x8040ad94,
		"instance$3029": 0x8040ad94,
		"Enemy::instance$3038": 0x8040ad9c,
		"instance$3038": 0x8040ad9c,
		"Enemy::instance$3051": 0x8040ada4,
		"instance$3051": 0x8040ada4,
		"Enemy::instance$3075": 0x8040adac,
		"instance$3075": 0x8040adac,
		"Enemy::instance$3294": 0x8040adcc,
		"instance$3294": 0x8040adcc,
		"Enemy::instance$3364": 0x8040addc,
		"instance$3364": 0x8040addc,
		"Enemy::instance$3388": 0x8040ade4,
		"instance$3388": 0x8040ade4,
		"Enemy::instance$3408": 0x8040adec,
		"instance$3408": 0x8040adec,
		"Enemy::instance$3444": 0x8040adf4,
		"instance$3444": 0x8040adf4,
		"Enemy::instance$3460": 0x8040adfc,
		"instance$3460": 0x8040adfc,
		"Enemy::instance$3243": 0x8040ae14,
		"instance$3243": 0x8040ae14,
		"Enemy::instance$3260": 0x8040ae1c,
		"instance$3260": 0x8040ae1c,
		"Enemy::instance$3277": 0x8040ae24,
		"instance$3277": 0x8040ae24,
		"Enemy::instance$3302": 0x8040ae2c,
		"instance$3302": 0x8040ae2c,
		"Enemy::instance$3822": 0x8040ae44,
		"instance$3822": 0x8040ae44,
		"Enemy::instance$3835": 0x8040ae4c,
		"instance$3835": 0x8040ae4c,
		"Enemy::testHeight": 0x8040ae50,
		"testHeight": 0x8040ae50,
		"Enemy::instance$3853": 0x8040ae58,
		"instance$3853": 0x8040ae58,
		"Enemy::instance$3895": 0x8040ae68,
		"instance$3895": 0x8040ae68,
		"Enemy::instance$3903": 0x8040ae70,
		"instance$3903": 0x8040ae70,
		"Enemy::instance$3934": 0x8040ae78,
		"instance$3934": 0x8040ae78,
		"Enemy::instance$3953": 0x8040ae80,
		"instance$3953": 0x8040ae80,
		"Enemy::instance$3980": 0x8040ae88,
		"instance$3980": 0x8040ae88,
		"Enemy::gpCurKiller": 0x8040ae90,
		"gpCurKiller": 0x8040ae90,
		"Enemy::instance$2970": 0x8040ae98,
		"instance$2970": 0x8040ae98,
		"Enemy::instance$3152": 0x8040aea8,
		"instance$3152": 0x8040aea8,
		"Enemy::gpBeamManager": 0x8040aeb0,
		"gpBeamManager": 0x8040aeb0,
		"Enemy::gpCurSamboHead": 0x8040aebc,
		"gpCurSamboHead": 0x8040aebc,
		"Enemy::instance$2964": 0x8040aec4,
		"instance$2964": 0x8040aec4,
		"Enemy::instance$2978": 0x8040aecc,
		"instance$2978": 0x8040aecc,
		"Enemy::instance$2996": 0x8040aed4,
		"instance$2996": 0x8040aed4,
		"Enemy::instance$3017": 0x8040aedc,
		"instance$3017": 0x8040aedc,
		"Enemy::instance$3031": 0x8040aee4,
		"instance$3031": 0x8040aee4,
		"Enemy::instance$3151": 0x8040aef4,
		"instance$3151": 0x8040aef4,
		"Enemy::gpCurPopo": 0x8040af20,
		"gpCurPopo": 0x8040af20,
		"TPopo::mTestAng_z": 0x8040af24,
		"Enemy::instance$3247": 0x8040af44,
		"instance$3247": 0x8040af44,
		"Enemy::instance$2264": 0x8040af5c,
		"Enemy::instance$2270": 0x8040af64,
		"instance$2270": 0x8040af64,
		"Enemy::instance$2772": 0x8040af6c,
		"instance$2772": 0x8040af6c,
		"Enemy::instance$2794": 0x8040af74,
		"instance$2794": 0x8040af74,
		"Enemy::sCommonSaveFileName$2709": 0x8040af78,
		"sCommonSaveFileName$2709": 0x8040af78,
		"Enemy::instance$2359": 0x8040af84,
		"Enemy::instance$2371": 0x8040af8c,
		"instance$2371": 0x8040af8c,
		"Enemy::instance$2383": 0x8040af94,
		"instance$2383": 0x8040af94,
		"Enemy::instance$2391": 0x8040af9c,
		"instance$2391": 0x8040af9c,
		"Enemy::instance$2399": 0x8040afa4,
		"instance$2399": 0x8040afa4,
		"Enemy::instance$2408": 0x8040afac,
		"instance$2408": 0x8040afac,
		"Enemy::instance$2423": 0x8040afb4,
		"instance$2423": 0x8040afb4,
		"Enemy::instance$2977": 0x8040afbc,
		"instance$2977": 0x8040afbc,
		"Enemy::instance$3007": 0x8040afc4,
		"instance$3007": 0x8040afc4,
		"Enemy::instance$3056": 0x8040afcc,
		"instance$3056": 0x8040afcc,
		"Enemy::instance$3300": 0x8040afec,
		"instance$3300": 0x8040afec,
		"Enemy::instance$3361": 0x8040aff4,
		"instance$3361": 0x8040aff4,
		"Enemy::instance$3411": 0x8040b004,
		"instance$3411": 0x8040b004,
		"Enemy::instance$3424": 0x8040b00c,
		"instance$3424": 0x8040b00c,
		"Enemy::instance$3452": 0x8040b014,
		"instance$3452": 0x8040b014,
		"Enemy::instance$3466": 0x8040b01c,
		"instance$3466": 0x8040b01c,
		"Enemy::instance$2838": 0x8040b02c,
		"instance$2838": 0x8040b02c,
		"Enemy::instance$2856": 0x8040b034,
		"instance$2856": 0x8040b034,
		"Enemy::gpCurHauntLeg": 0x8040b040,
		"gpCurHauntLeg": 0x8040b040,
		"Enemy::instance$2857": 0x8040b048,
		"instance$2857": 0x8040b048,
		"Enemy::instance$2671": 0x8040b054,
		"instance$2671": 0x8040b054,
		"Enemy::instance$2691": 0x8040b064,
		"instance$2691": 0x8040b064,
		"Enemy::instance$2702": 0x8040b06c,
		"instance$2702": 0x8040b06c,
		"Enemy::instance$2710": 0x8040b074,
		"instance$2710": 0x8040b074,
		"Enemy::instance$2720": 0x8040b07c,
		"instance$2720": 0x8040b07c,
		"TRocket::mTestAng_x": 0x8040b088,
		"TRocket::mTestAng_z": 0x8040b08c,
		"Enemy::instance$2931": 0x8040b0a4,
		"instance$2931": 0x8040b0a4,
		"Enemy::instance$2840": 0x8040b0ac,
		"instance$2840": 0x8040b0ac,
		"Enemy::instance$2852": 0x8040b0b4,
		"instance$2852": 0x8040b0b4,
		"Enemy::instance$2862": 0x8040b0bc,
		"instance$2862": 0x8040b0bc,
		"Enemy::instance$2874": 0x8040b0c4,
		"instance$2874": 0x8040b0c4,
		"Enemy::instance$2898": 0x8040b0d4,
		"instance$2898": 0x8040b0d4,
		"Enemy::instance$2919": 0x8040b0e4,
		"instance$2919": 0x8040b0e4,
		"Enemy::instance$2918": 0x8040b0ec,
		"instance$2918": 0x8040b0ec,
		"Enemy::instance$2924": 0x8040b0f4,
		"instance$2924": 0x8040b0f4,
		"Enemy::instance$2930": 0x8040b0fc,
		"instance$2930": 0x8040b0fc,
		"Enemy::instance$2936": 0x8040b104,
		"instance$2936": 0x8040b104,
		"Enemy::instance$2942": 0x8040b10c,
		"instance$2942": 0x8040b10c,
		"TBossManta::sCenterJointIndex": 0x8040b110,
		"sCenterJointIndex": 0x8040b110,
		"TBossManta::sBodyJointIndex": 0x8040b114,
		"sBodyJointIndex": 0x8040b114,
		"TBossManta::sRwingJointIndex": 0x8040b118,
		"sRwingJointIndex": 0x8040b118,
		"TBossManta::sLwingJointIndex": 0x8040b11c,
		"sLwingJointIndex": 0x8040b11c,
		"Enemy::sDefeatSE$3156": 0x8040b124,
		"sDefeatSE$3156": 0x8040b124,
		"Enemy::instance$2875": 0x8040b12c,
		"instance$2875": 0x8040b12c,
		"Enemy::instance$2922": 0x8040b14c,
		"instance$2922": 0x8040b14c,
		"Enemy::instance$3146": 0x8040b16c,
		"instance$3146": 0x8040b16c,
		"Enemy::instance$3338": 0x8040b18c,
		"instance$3338": 0x8040b18c,
		"Enemy::instance$2662": 0x8040b194,
		"instance$2662": 0x8040b194,
		"Enemy::instance$2674": 0x8040b19c,
		"instance$2674": 0x8040b19c,
		"Enemy::instance$2686": 0x8040b1a4,
		"instance$2686": 0x8040b1a4,
		"Enemy::instance$2696": 0x8040b1ac,
		"instance$2696": 0x8040b1ac,
		"Enemy::instance$2713": 0x8040b1b4,
		"instance$2713": 0x8040b1b4,
		"Enemy::instance$2726": 0x8040b1bc,
		"instance$2726": 0x8040b1bc,
		"Enemy::instance$2743": 0x8040b1c4,
		"instance$2743": 0x8040b1c4,
		"Enemy::instance$2753": 0x8040b1cc,
		"instance$2753": 0x8040b1cc,
		"Enemy::instance$2764": 0x8040b1d4,
		"instance$2764": 0x8040b1d4,
		"TNerveKoopaTurnR::nerve$localstatic0$theNerve": 0x8040b1dc,
		"TNerveKoopaTurnL::nerve$localstatic0$theNerve": 0x8040b1e4,
		"TNerveKoopaTumble::nerve$localstatic0$theNerve": 0x8040b1ec,
		"TNerveKoopaProvoke::nerve$localstatic0$theNerve": 0x8040b1f4,
		"TNerveKoopaWait::nerve$localstatic0$theNerve": 0x8040b1fc,
		"TNerveKoopaFlame::nerve$localstatic0$theNerve": 0x8040b204,
		"TNerveKoopaGetDown::nerve$localstatic0$theNerve": 0x8040b20c,
		"TNerveKoopaStagger::nerve$localstatic0$theNerve": 0x8040b214,
		"TNerveKoopaFall::nerve$localstatic0$theNerve": 0x8040b21c,
		"TNerveKoopaGetShowered::nerve$localstatic0$theNerve": 0x8040b224,
		"Enemy::bathtub$3040": 0x8040b228,
		"bathtub$3040": 0x8040b228,
		"Enemy::bathtub$3100": 0x8040b230,
		"bathtub$3100": 0x8040b230,
		"Enemy::instance$3127": 0x8040b244,
		"instance$3127": 0x8040b244,
		"Enemy::instance$3142": 0x8040b24c,
		"instance$3142": 0x8040b24c,
		"Enemy::instance$2529": 0x8040b25c,
		"instance$2529": 0x8040b25c,
		"Enemy::instance$2541": 0x8040b264,
		"instance$2541": 0x8040b264,
		"Enemy::instance$2555": 0x8040b26c,
		"instance$2555": 0x8040b26c,
		"Enemy::instance$2565": 0x8040b274,
		"instance$2565": 0x8040b274,
		"Enemy::instance$2575": 0x8040b27c,
		"instance$2575": 0x8040b27c,
		"TNervePeachStagger::nerve$localstatic0$theNerve": 0x8040b284,
		"TNervePeachEscape::nerve$localstatic0$theNerve": 0x8040b28c,
		"Enemy::instance$3125": 0x8040b294,
		"instance$3125": 0x8040b294,
		"Enemy::instance$3188": 0x8040b2bc,
		"instance$3188": 0x8040b2bc,
		"Enemy::instance$2868": 0x8040b2c4,
		"instance$2868": 0x8040b2c4,
		"Enemy::instance$2912": 0x8040b2cc,
		"instance$2912": 0x8040b2cc,
		"Enemy::instance$2849": 0x8040b2d4,
		"instance$2849": 0x8040b2d4,
		"@unnamed@::cAngleMax": 0x8040b2d8,
		"cAngleMax": 0x8040b2d8,
		"Enemy::instance$2885": 0x8040b2e8,
		"instance$2885": 0x8040b2e8,
		"Enemy::instance$2908": 0x8040b2f8,
		"instance$2908": 0x8040b2f8,
		"Enemy::instance$2927": 0x8040b308,
		"instance$2927": 0x8040b308,
		"Enemy::instance$2937": 0x8040b310,
		"instance$2937": 0x8040b310,
		"TNerveLimitKoopaHipDropJump::nerve$localstatic0$theNerve": 0x8040b31c,
		"TNerveLimitKoopaHipDropStart::nerve$localstatic0$theNerve": 0x8040b324,
		"TNerveLimitKoopaTumble::nerve$localstatic0$theNerve": 0x8040b32c,
		"TNerveLimitKoopaWait::nerve$localstatic0$theNerve": 0x8040b334,
		"TNerveLimitKoopaGetDown::nerve$localstatic0$theNerve": 0x8040b33c,
		"TNerveLimitKoopaStagger::nerve$localstatic0$theNerve": 0x8040b344,
		"TNerveLimitKoopaGetShowered::nerve$localstatic0$theNerve": 0x8040b34c,
		"Enemy::instance$3011": 0x8040b35c,
		"instance$3011": 0x8040b35c,
		"Enemy::instance$3025": 0x8040b364,
		"Enemy::instance$3035": 0x8040b36c,
		"Camera::gpCamera": 0x8040b370,
		"gpCamera": 0x8040b370,
		"Camera::gpCameraMario": 0x8040b378,
		"gpCameraMario": 0x8040b378,
		"Camera::gpCameraShake": 0x8040b380,
		"gpCameraShake": 0x8040b380,
		"Camera::gpSunMgr": 0x8040b388,
		"gpSunMgr": 0x8040b388,
		"Camera::gpSunModel": 0x8040b390,
		"gpSunModel": 0x8040b390,
		"Camera::gpCubeCamera": 0x8040b398,
		"gpCubeCamera": 0x8040b398,
		"Camera::gpCubeMirror": 0x8040b39c,
		"gpCubeMirror": 0x8040b39c,
		"Camera::gpCubeWire": 0x8040b3a0,
		"gpCubeWire": 0x8040b3a0,
		"Camera::gpCubeStream": 0x8040b3a4,
		"gpCubeStream": 0x8040b3a4,
		"Camera::gpCubeShadow": 0x8040b3a8,
		"gpCubeShadow": 0x8040b3a8,
		"Camera::gpCubeArea": 0x8040b3ac,
		"gpCubeArea": 0x8040b3ac,
		"Camera::gpCubeFastA": 0x8040b3b0,
		"gpCubeFastA": 0x8040b3b0,
		"Camera::gpCubeFastB": 0x8040b3b4,
		"gpCubeFastB": 0x8040b3b4,
		"Camera::gpCubeFastC": 0x8040b3b8,
		"gpCubeFastC": 0x8040b3b8,
		"Camera::gpCubeSoundChange": 0x8040b3bc,
		"gpCubeSoundChange": 0x8040b3bc,
		"Camera::gpCubeSoundEffect": 0x8040b3c0,
		"gpCubeSoundEffect": 0x8040b3c0,
		"Camera::gpCamMapToolTable": 0x8040b3c8,
		"gpCamMapToolTable": 0x8040b3c8,
		"Camera::gpCameraOption": 0x8040b3d0,
		"gpCameraOption": 0x8040b3d0,
		"Animal::instance$2000": 0x8040b3dc,
		"instance$2000": 0x8040b3dc,
		"Animal::instance$3025": 0x8040b3e4,
		"Animal::instance$3040": 0x8040b3ec,
		"instance$3040": 0x8040b3ec,
		"Animal::instance$3055": 0x8040b3f4,
		"Animal::instance$3067": 0x8040b3fc,
		"instance$3067": 0x8040b3fc,
		"Animal::instance$3077": 0x8040b404,
		"instance$3077": 0x8040b404,
		"Animal::instance$3096": 0x8040b40c,
		"instance$3096": 0x8040b40c,
		"Animal::instance$3104": 0x8040b414,
		"instance$3104": 0x8040b414,
		"Animal::instance$3116": 0x8040b41c,
		"instance$3116": 0x8040b41c,
		"Animal::instance$3128": 0x8040b424,
		"@unnamed@::cAngleLimit": 0x8040b428,
		"cAngleLimit": 0x8040b428,
		"Animal::instance$2989": 0x8040b430,
		"instance$2989": 0x8040b430,
		"Animal::instance$3003": 0x8040b438,
		"instance$3003": 0x8040b438,
		"Animal::instance$3013": 0x8040b440,
		"Animal::instance$3023": 0x8040b448,
		"instance$3023": 0x8040b448,
		"Animal::instance$3035": 0x8040b450,
		"Animal::instance$3047": 0x8040b458,
		"instance$3047": 0x8040b458,
		"JSystem::@722": 0x8040b460,
		"@722": 0x8040b460,
		"JSystem::@724": 0x8040b468,
		"@724": 0x8040b468,
		"JSystem::@728": 0x8040b478,
		"@728": 0x8040b478,
		"JSystem::@730": 0x8040b480,
		"@730": 0x8040b480,
		"JSystem::@1783": 0x8040b490,
		"JSystem::@370": 0x8040b498,
		"@370": 0x8040b498,
		"JSystem::@1565": 0x8040b4c8,
		"JSystem::@1629": 0x8040b4cc,
		"JSystem::@1630": 0x8040b4d0,
		"JSystem::@1756": 0x8040b4d4,
		"JSystem::@2094": 0x8040b4d8,
		"JSystem::@2216": 0x8040b4e0,
		"JSystem::@192": 0x8040b4e8,
		"JSystem::@604": 0x8040b4f0,
		"JSystem::@609": 0x8040b500,
		"JSystem::@639": 0x8040b518,
		"JSystem::@640": 0x8040b51c,
		"JSystem::@669": 0x8040b528,
		"JSystem::@670": 0x8040b52c,
		"@670": 0x8040b52c,
		"JSystem::@671": 0x8040b530,
		"@671": 0x8040b530,
		"JSystem::@672": 0x8040b534,
		"@672": 0x8040b534,
		"JSystem::@135": 0x8040b538,
		"@135": 0x8040b538,
		"JSystem::@543": 0x8040b590,
		"@543": 0x8040b590,
		"JSystem::@297": 0x8040b5a0,
		"JSystem::@920": 0x8040b5b8,
		"JSystem::@1014": 0x8040b5bc,
		"@1014": 0x8040b5bc,
		"JSystem::@52": 0x8040b5c0,
		"JSystem::@276": 0x8040b5d0,
		"@276": 0x8040b5d0,
		"JSystem::@403": 0x8040b5d4,
		"@403": 0x8040b5d4,
		"JSystem::@1321": 0x8040b5f0,
		"@1321": 0x8040b5f0,
		"JSystem::@1322": 0x8040b5f4,
		"@1322": 0x8040b5f4,
		"JSystem::@1329": 0x8040b600,
		"@1329": 0x8040b600,
		"JSystem::@871": 0x8040b608,
		"@871": 0x8040b608,
		"JSystem::@872": 0x8040b60c,
		"@872": 0x8040b60c,
		"JSystem::@912": 0x8040b610,
		"@912": 0x8040b610,
		"JSystem::@1084": 0x8040b618,
		"@1084": 0x8040b618,
		"JSystem::@1099": 0x8040b61c,
		"JSystem::@1259": 0x8040b624,
		"@1259": 0x8040b624,
		"JSystem::@1260": 0x8040b628,
		"@1260": 0x8040b628,
		"JSystem::@1261": 0x8040b62c,
		"@1261": 0x8040b62c,
		"JSystem::@1262": 0x8040b630,
		"@1262": 0x8040b630,
		"JSystem::@1077": 0x8040b650,
		"@1077": 0x8040b650,
		"JSystem::@1258": 0x8040b654,
		"@1258": 0x8040b654,
		"JSystem::@330": 0x8040b658,
		"@330": 0x8040b658,
		"JSystem::@2218": 0x8040b664,
		"JSystem::@2219": 0x8040b668,
		"JSystem::@2221": 0x8040b66c,
		"JSystem::@2222": 0x8040b674,
		"JSystem::@2223": 0x8040b678,
		"JSystem::@2225": 0x8040b67c,
		"JSystem::@2226": 0x8040b684,
		"JSystem::@2227": 0x8040b688,
		"JSystem::@2456": 0x8040b68c,
		"JSystem::@1460": 0x8040b690,
		"@1460": 0x8040b690,
		"JSystem::@2249": 0x8040b694,
		"JSystem::@994": 0x8040b6a8,
		"@994": 0x8040b6a8,
		"JSystem::@956": 0x8040b6b4,
		"@956": 0x8040b6b4,
		"JSystem::@1073": 0x8040b6b8,
		"JSystem::@1500": 0x8040b6d0,
		"@1500": 0x8040b6d0,
		"JSystem::@1288": 0x8040b6e0,
		"@1288": 0x8040b6e0,
		"JSystem::@1345": 0x8040b6e4,
		"@1345": 0x8040b6e4,
		"JSystem::@1425": 0x8040b6e8,
		"@1425": 0x8040b6e8,
		"JSystem::@1443": 0x8040b6f0,
		"@1443": 0x8040b6f0,
		"JSystem::@1126": 0x8040b6f8,
		"@1126": 0x8040b6f8,
		"JSystem::@123": 0x8040b710,
		"JSystem::@124": 0x8040b714,
		"@124": 0x8040b714,
		"JSystem::@926": 0x8040b730,
		"@926": 0x8040b730,
		"JSystem::@927": 0x8040b734,
		"@927": 0x8040b734,
		"JSystem::@978": 0x8040b738,
		"@978": 0x8040b738,
		"JSystem::@979": 0x8040b73c,
		"@979": 0x8040b73c,
		"JSystem::@824": 0x8040b748,
		"@824": 0x8040b748,
		"JSystem::@825": 0x8040b74c,
		"@825": 0x8040b74c,
		"JSystem::@360": 0x8040b758,
		"JSystem::@100": 0x8040b768,
		"JSystem::@111": 0x8040b770,
		"JSystem::@335": 0x8040b778,
		"@335": 0x8040b778,
		"JSystem::@295": 0x8040b794,
		"JSystem::@385": 0x8040b7a0,
		"JSystem::@386": 0x8040b7a4,
		"JSystem::@388": 0x8040b7b0,
		"JSystem::@390": 0x8040b7c0,
		"@390": 0x8040b7c0,
		"JSystem::@697": 0x8040b7d0,
		"@697": 0x8040b7d0,
		"JSystem::@2338": 0x8040b7f0,
		"JSystem::@878": 0x8040b7fc,
		"@878": 0x8040b7fc,
		"JSystem::@879": 0x8040b800,
		"@879": 0x8040b800,
		"JSystem::@633": 0x8040b810,
		"@633": 0x8040b810,
		"JSystem::@634": 0x8040b814,
		"JSystem::@1466": 0x8040b818,
		"@1466": 0x8040b818,
		"JSystem::@1467": 0x8040b81c,
		"@1467": 0x8040b81c,
		"JSystem::@1469": 0x8040b820,
		"@1469": 0x8040b820,
		"JSystem::@1470": 0x8040b824,
		"@1470": 0x8040b824,
		"JSystem::@1471": 0x8040b828,
		"@1471": 0x8040b828,
		"JSystem::@1472": 0x8040b82c,
		"@1472": 0x8040b82c,
		"JSystem::@1477": 0x8040b830,
		"@1477": 0x8040b830,
		"JSystem::@1478": 0x8040b838,
		"@1478": 0x8040b838,
		"JSystem::@1479": 0x8040b840,
		"@1479": 0x8040b840,
		"JSystem::@48": 0x8040b850,
		"@48": 0x8040b850,
		"JSystem::@244": 0x8040b870,
		"@244": 0x8040b870,
		"JSystem::@354": 0x8040b878,
		"JSystem::@355": 0x8040b87c,
		"JSystem::@544": 0x8040b890,
		"@544": 0x8040b890,
		"JSystem::@461": 0x8040b898,
		"JSystem::@622": 0x8040b89c,
		"@622": 0x8040b89c,
		"JSystem::@623": 0x8040b8a0,
		"@623": 0x8040b8a0,
		"JSystem::@624": 0x8040b8a4,
		"@624": 0x8040b8a4,
		"JSystem::@413": 0x8040b8c0,
		"@413": 0x8040b8c0,
		"JSystem::@694": 0x8040b8c8,
		"JSystem::@695": 0x8040b8cc,
		"JSystem::@696": 0x8040b8d0,
		"@696": 0x8040b8d0,
		"JSystem::@1287": 0x8040b8d4,
		"@1287": 0x8040b8d4,
		"JSystem::@494": 0x8040b8e0,
		"@494": 0x8040b8e0,
		"JSystem::@495": 0x8040b8e4,
		"@495": 0x8040b8e4,
		"JSystem::@496": 0x8040b8e8,
		"@496": 0x8040b8e8,
		"JSystem::@551": 0x8040b8f4,
		"@551": 0x8040b8f4,
		"JSystem::@587": 0x8040b900,
		"@587": 0x8040b900,
		"JSystem::@588": 0x8040b904,
		"@588": 0x8040b904,
		"JSystem::@589": 0x8040b908,
		"@589": 0x8040b908,
		"JSystem::@590": 0x8040b90c,
		"@590": 0x8040b90c,
		"JSystem::@762": 0x8040b930,
		"JSystem::@763": 0x8040b934,
		"JSystem::@934": 0x8040b940,
		"@934": 0x8040b940,
		"JSystem::@935": 0x8040b944,
		"@935": 0x8040b944,
		"JSystem::@826": 0x8040b94c,
		"@826": 0x8040b94c,
		"JSystem::@829": 0x8040b960,
		"@829": 0x8040b960,
		"JSystem::@830": 0x8040b964,
		"@830": 0x8040b964,
		"JSystem::@932": 0x8040b970,
		"@932": 0x8040b970,
		"JSystem::@504": 0x8040b980,
		"@504": 0x8040b980,
		"JSystem::@989": 0x8040b988,
		"@989": 0x8040b988,
		"JSystem::@534": 0x8040b9a0,
		"@534": 0x8040b9a0,
		"JSystem::@535": 0x8040b9a8,
		"@535": 0x8040b9a8,
		"JSystem::@536": 0x8040b9b0,
		"@536": 0x8040b9b0,
		"JSystem::@434": 0x8040b9c0,
		"@434": 0x8040b9c0,
		"JSystem::@602": 0x8040b9c4,
		"JSystem::@680": 0x8040b9e8,
		"@680": 0x8040b9e8,
		"JSystem::@681": 0x8040b9ec,
		"@681": 0x8040b9ec,
		"JSystem::@943": 0x8040b9f0,
		"JSystem::@944": 0x8040b9f4,
		"@944": 0x8040b9f4,
		"JSystem::@1207": 0x8040b9fc,
		"@1207": 0x8040b9fc,
		"JSystem::@1242": 0x8040ba00,
		"@1242": 0x8040ba00,
		"JSystem::@1373": 0x8040ba04,
		"@1373": 0x8040ba04,
		"JSystem::@509": 0x8040ba08,
		"@509": 0x8040ba08,
		"JSystem::@339": 0x8040ba10,
		"JSystem::@340": 0x8040ba14,
		"JSystem::@418": 0x8040ba18,
		"@418": 0x8040ba18,
		"JSystem::@419": 0x8040ba1c,
		"@419": 0x8040ba1c,
		"JSystem::@435": 0x8040ba28,
		"JSystem::@568": 0x8040ba50,
		"@568": 0x8040ba50,
		"JSystem::@328": 0x8040ba60,
		"@328": 0x8040ba60,
		"JSystem::@345": 0x8040ba68,
		"@345": 0x8040ba68,
		"JSystem::@346": 0x8040ba6c,
		"@346": 0x8040ba6c,
		"JSystem::@252": 0x8040ba78,
		"@252": 0x8040ba78,
		"JSystem::@253": 0x8040ba7c,
		"@253": 0x8040ba7c,
		"JSystem::@274": 0x8040baa8,
		"@274": 0x8040baa8,
		"JSystem::@836": 0x8040bab4,
		"@836": 0x8040bab4,
		"JSystem::@120": 0x8040bac8,
		"@120": 0x8040bac8,
		"JSystem::@204": 0x8040bad8,
		"@204": 0x8040bad8,
		"JSystem::@231": 0x8040badc,
		"@231": 0x8040badc,
		"JSystem::@260": 0x8040bae0,
		"JSystem::@261": 0x8040bae4,
		"JSystem::@332": 0x8040baf8,
		"@332": 0x8040baf8,
		"JSystem::@334": 0x8040bb08,
		"@334": 0x8040bb08,
		"JSystem::@236": 0x8040bb10,
		"@236": 0x8040bb10,
		"JSystem::@525": 0x8040bb20,
		"@525": 0x8040bb20,
		"JSystem::@526": 0x8040bb24,
		"@526": 0x8040bb24,
		"JSystem::@527": 0x8040bb28,
		"@527": 0x8040bb28,
		"JSystem::@528": 0x8040bb2c,
		"@528": 0x8040bb2c,
		"JSystem::@621": 0x8040bb44,
		"@621": 0x8040bb44,
		"JSystem::@754": 0x8040bb50,
		"JSystem::@129": 0x8040bb70,
		"@129": 0x8040bb70,
		"JSystem::@642": 0x8040bb98,
		"JSystem::@797": 0x8040bba0,
		"JSystem::@948": 0x8040bba8,
		"@948": 0x8040bba8,
		"JSystem::@949": 0x8040bbac,
		"@949": 0x8040bbac,
		"JSystem::@950": 0x8040bbb0,
		"@950": 0x8040bbb0,
		"JSystem::@981": 0x8040bbc0,
		"@981": 0x8040bbc0,
		"JSystem::@1217": 0x8040bbc8,
		"@1217": 0x8040bbc8,
		"JSystem::@1326": 0x8040bbcc,
		"@1326": 0x8040bbcc,
		"JSystem::@1344": 0x8040bbd4,
		"@1344": 0x8040bbd4,
		"JSystem::@363": 0x8040bbd8,
		"JSystem::@377": 0x8040bbe0,
		"@377": 0x8040bbe0,
		"JSystem::@411": 0x8040bc00,
		"@411": 0x8040bc00,
		"JSystem::@1706": 0x8040bc18,
		"JSystem::@1707": 0x8040bc1c,
		"JSystem::@2032": 0x8040bc38,
		"JSystem::@2829": 0x8040bc3c,
		"JSystem::@2830": 0x8040bc40,
		"JSystem::@2840": 0x8040bc50,
		"JSystem::@1786": 0x8040bc58,
		"JSystem::@1787": 0x8040bc5c,
		"JSystem::@1673": 0x8040bc68,
		"JSystem::@1877": 0x8040bc6c,
		"@1877": 0x8040bc6c,
		"JSystem::@1955": 0x8040bc70,
		"JSystem::@1956": 0x8040bc74,
		"JSystem::@1957": 0x8040bc78,
		"JSystem::@2076": 0x8040bc7c,
		"JSystem::@1639": 0x8040bc84,
		"JSystem::@1681": 0x8040bc94,
		"JSystem::@1682": 0x8040bc98,
		"JSystem::@1683": 0x8040bc9c,
		"JSystem::@1675": 0x8040bcb8,
		"JSystem::@1689": 0x8040bcbc,
		"JSystem::@1820": 0x8040bcc0,
		"JSystem::@1659": 0x8040bcc8,
		"JSystem::@1860": 0x8040bccc,
		"JSystem::@2759": 0x8040bcf0,
		"JSystem::@2760": 0x8040bcf4,
		"JSystem::@2761": 0x8040bcf8,
		"JSystem::@2762": 0x8040bcfc,
		"JSystem::@3307": 0x8040bd00,
		"JSystem::@1743": 0x8040bd10,
		"@1743": 0x8040bd10,
		"JSystem::@1744": 0x8040bd14,
		"@1744": 0x8040bd14,
		"JSystem::@1745": 0x8040bd18,
		"@1745": 0x8040bd18,
		"JSystem::@2374": 0x8040bd30,
		"JSystem::@2375": 0x8040bd34,
		"JSystem::@2378": 0x8040bd38,
		"JSystem::@2379": 0x8040bd3c,
		"JSystem::@2380": 0x8040bd40,
		"JSystem::@2538": 0x8040bd44,
		"JSystem::@2542": 0x8040bd48,
		"JSystem::@4485": 0x8040bd4c,
		"JSystem::@4568": 0x8040bd50,
		"@4568": 0x8040bd50,
		"JSystem::@1505": 0x8040bd58,
		"JSystem::@1506": 0x8040bd5c,
		"@1506": 0x8040bd5c,
		"JSystem::@1570": 0x8040bd70,
		"JSystem::@1571": 0x8040bd74,
		"JSystem::@1509": 0x8040bd78,
		"@1509": 0x8040bd78,
		"JSystem::@1510": 0x8040bd7c,
		"@1510": 0x8040bd7c,
		"JSystem::@1511": 0x8040bd80,
		"@1511": 0x8040bd80,
		"JSystem::@126": 0x8040bda0,
		"JSystem::@118": 0x8040bda8,
		"@118": 0x8040bda8,
		"JSystem::@71": 0x8040bdb0,
		"MSL_C.PPCEABI.bare.H::@156": 0x8040be70,
		"MSL_C.PPCEABI.bare.H::@157": 0x8040be74,
		"MSL_C.PPCEABI.bare.H::@158": 0x8040be78,
		"MSL_C.PPCEABI.bare.H::@159": 0x8040be7c,
		"MSL_C.PPCEABI.bare.H::@168": 0x8040be80,
		"MSL_C.PPCEABI.bare.H::@169": 0x8040be84,
		"MSL_C.PPCEABI.bare.H::@170": 0x8040be88,
		"MSL_C.PPCEABI.bare.H::@188": 0x8040be8c,
		"MSL_C.PPCEABI.bare.H::@106": 0x8040be90,
		"@106": 0x8040be90,
		"MSL_C.PPCEABI.bare.H::@107": 0x8040be94,
		"@107": 0x8040be94,
		"MSL_C.PPCEABI.bare.H::@108": 0x8040be98,
		"@108": 0x8040be98,
		"MSL_C.PPCEABI.bare.H::__log2e_m1$localstatic0$__log2f__Ff": 0x8040bea8,
		"__log2e_m1$localstatic0$__log2f__Ff": 0x8040bea8,
		"MSL_C.PPCEABI.bare.H::@93": 0x8040beb0,
		"MSL_C.PPCEABI.bare.H::_inf": 0x8040beb8,
		"_inf": 0x8040beb8,
		"MSL_C.PPCEABI.bare.H::_nan": 0x8040bebc,
		"_nan": 0x8040bebc,
		"MSL_C.PPCEABI.bare.H::@246": 0x8040bec0,
		"@246": 0x8040bec0,
		"MSL_C.PPCEABI.bare.H::@247": 0x8040bec4,
		"@247": 0x8040bec4,
		"MSL_C.PPCEABI.bare.H::@248": 0x8040bec8,
		"@248": 0x8040bec8,
		"MSL_C.PPCEABI.bare.H::@249": 0x8040becc,
		"@249": 0x8040becc,
		"MSL_C.PPCEABI.bare.H::@250": 0x8040bed0,
		"@250": 0x8040bed0,
		"MSL_C.PPCEABI.bare.H::@251": 0x8040bed4,
		"@251": 0x8040bed4,
		"MSL_C.PPCEABI.bare.H::@259": 0x8040bee0,
		"MSL_C.PPCEABI.bare.H::@260": 0x8040bee4,
		"MSL_C.PPCEABI.bare.H::@261": 0x8040bee8,
		"MSL_C.PPCEABI.bare.H::@262": 0x8040beec,
		"os::@153": 0x8040bef0,
		"mtx::@94": 0x8040bef8,
		"mtx::@95": 0x8040befc,
		"mtx::@193": 0x8040bf00,
		"mtx::@214": 0x8040bf04,
		"mtx::@217": 0x8040bf08,
		"@217": 0x8040bf08,
		"mtx::@218": 0x8040bf0c,
		"@218": 0x8040bf0c,
		"mtx::@97": 0x8040bf10,
		"mtx::@98": 0x8040bf14,
		"mtx::@99": 0x8040bf18,
		"mtx::@100": 0x8040bf1c,
		"mtx::@103": 0x8040bf20,
		"@103": 0x8040bf20,
		"mtx::@104": 0x8040bf24,
		"@104": 0x8040bf24,
		"mtx::@116": 0x8040bf28,
		"mtx::@117": 0x8040bf2c,
		"gx::@122": 0x8040bf34,
		"@122": 0x8040bf34,
		"gx::@123": 0x8040bf38,
		"gx::@177": 0x8040bf3c,
		"gx::@178": 0x8040bf40,
		"gx::@179": 0x8040bf44,
		"gx::@83": 0x8040bf50,
		"gx::@127": 0x8040bf64,
		"gx::@148": 0x8040bf68,
		"gx::@167": 0x8040bf80,
		"gx::@164": 0x8040bf88,
		"gx::@192": 0x8040bf98,
		"gx::@193": 0x8040bf9c,
		"gx::@194": 0x8040bfa0,
		"@194": 0x8040bfa0,
		"gx::@195": 0x8040bfa4,
		"@195": 0x8040bfa4,
		"gx::@196": 0x8040bfa8,
		"@196": 0x8040bfa8,
		"gx::@197": 0x8040bfac,
		"gx::@45": 0x8040bfb0,
		"@45": 0x8040bfb0,
		"gx::@125": 0x8040bfb8,
		"@125": 0x8040bfb8,
		"gx::@126": 0x8040bfbc,
		"gx::@130": 0x8040bfd8,
		"gx::@357": 0x8040bfec,
		"gx::@358": 0x8040bff0,
		"gx::@360": 0x8040bff4,
		"gx::@405": 0x8040c008,
		"@405": 0x8040c008,
		"gx::@493": 0x8040c00c,
		"@493": 0x8040c00c,
		"gx::@14": 0x8040c010,
		"gx::@15": 0x8040c014,
		"gx::@16": 0x8040c018,
		"gx::@63": 0x8040c028,
		"gx::@64": 0x8040c02c,
		"thp::@665": 0x8040c038,
		"@665": 0x8040c038,
		"thp::@666": 0x8040c03c,
		"@666": 0x8040c03c,
		"thp::@667": 0x8040c040,
		"@667": 0x8040c040,
		"thp::@668": 0x8040c044,
		"@668": 0x8040c044,
		"thp::@669": 0x8040c048,
		"THPPlayer::@22": 0x8040c050,
		"THPPlayer::@25": 0x8040c058,
		"THPPlayer::@28": 0x8040c05c,
		"THPPlayer::@31": 0x8040c060,
		"THPPlayer::@55": 0x8040c064,
		"@55": 0x8040c064,
		"THPPlayer::@71": 0x8040c068,
		"THPPlayer::@72": 0x8040c06c,
		"@72": 0x8040c06c,
		"THPPlayer::@479": 0x8040c080,
		"@479": 0x8040c080,
		"THPPlayer::@791": 0x8040c084,
		"@791": 0x8040c084,
		"THPPlayer::@792": 0x8040c088,
		"@792": 0x8040c088,
		"MarioUtil::@1997": 0x8040c090,
		"MarioUtil::@1999": 0x8040c094,
		"MarioUtil::@2009": 0x8040c098,
		"MarioUtil::@2452": 0x8040c0a8,
		"MarioUtil::@2453": 0x8040c0ac,
		"MarioUtil::@2472": 0x8040c0b0,
		"MarioUtil::@2473": 0x8040c0b4,
		"MarioUtil::@2948": 0x8040c0b8,
		"MarioUtil::@3041": 0x8040c0bc,
		"MarioUtil::@3042": 0x8040c0c0,
		"MarioUtil::@3043": 0x8040c0c4,
		"MarioUtil::@3044": 0x8040c0c8,
		"MarioUtil::@3357": 0x8040c0cc,
		"MarioUtil::@3505": 0x8040c0d0,
		"MarioUtil::@3506": 0x8040c0d4,
		"MarioUtil::@3507": 0x8040c0d8,
		"MarioUtil::@3555": 0x8040c0dc,
		"MarioUtil::@3556": 0x8040c0e0,
		"MarioUtil::@3557": 0x8040c0e4,
		"MarioUtil::@3558": 0x8040c0e8,
		"MarioUtil::@3560": 0x8040c0ec,
		"MarioUtil::@3561": 0x8040c0f0,
		"MarioUtil::@3565": 0x8040c0f4,
		"MarioUtil::@3566": 0x8040c0f8,
		"MarioUtil::@2043": 0x8040c108,
		"MarioUtil::@2044": 0x8040c10c,
		"MarioUtil::@2045": 0x8040c110,
		"MarioUtil::@2046": 0x8040c114,
		"MarioUtil::@2228": 0x8040c11c,
		"MarioUtil::@2229": 0x8040c120,
		"MarioUtil::@2230": 0x8040c124,
		"MarioUtil::@2231": 0x8040c128,
		"MarioUtil::@2665": 0x8040c130,
		"MarioUtil::@2666": 0x8040c138,
		"MarioUtil::@2667": 0x8040c13c,
		"MarioUtil::@2844": 0x8040c140,
		"MarioUtil::@1608": 0x8040c148,
		"MarioUtil::@1627": 0x8040c158,
		"MarioUtil::@1638": 0x8040c15c,
		"MarioUtil::@1639": 0x8040c160,
		"MarioUtil::@1673": 0x8040c164,
		"MarioUtil::@1674": 0x8040c168,
		"MarioUtil::@1675": 0x8040c16c,
		"MarioUtil::@1676": 0x8040c170,
		"MarioUtil::@1797": 0x8040c174,
		"MarioUtil::@1798": 0x8040c178,
		"MarioUtil::@1884": 0x8040c190,
		"@1884": 0x8040c190,
		"MarioUtil::@2093": 0x8040c198,
		"MarioUtil::@2094": 0x8040c19c,
		"MarioUtil::@2123": 0x8040c1a0,
		"MarioUtil::@2124": 0x8040c1a4,
		"MarioUtil::@2156": 0x8040c1a8,
		"MarioUtil::@2194": 0x8040c1b0,
		"MarioUtil::@2550": 0x8040c1c8,
		"MarioUtil::@2551": 0x8040c1d0,
		"MarioUtil::@2552": 0x8040c1d4,
		"MarioUtil::@2553": 0x8040c1d8,
		"MarioUtil::@2554": 0x8040c1dc,
		"MarioUtil::@2555": 0x8040c1e4,
		"MarioUtil::@1629": 0x8040c200,
		"MarioUtil::@1630": 0x8040c204,
		"MarioUtil::@1631": 0x8040c208,
		"MarioUtil::@1802": 0x8040c214,
		"MarioUtil::@1803": 0x8040c218,
		"MarioUtil::@1833": 0x8040c228,
		"MarioUtil::@1834": 0x8040c22c,
		"@1834": 0x8040c22c,
		"MarioUtil::@2235": 0x8040c230,
		"MarioUtil::@2297": 0x8040c234,
		"MarioUtil::@2312": 0x8040c238,
		"MarioUtil::@2315": 0x8040c23c,
		"MarioUtil::@2743": 0x8040c244,
		"MarioUtil::@2744": 0x8040c248,
		"MarioUtil::@2745": 0x8040c24c,
		"MarioUtil::@2746": 0x8040c250,
		"MarioUtil::@2747": 0x8040c254,
		"MarioUtil::@2748": 0x8040c258,
		"MarioUtil::@2749": 0x8040c25c,
		"MarioUtil::@2750": 0x8040c260,
		"MarioUtil::@2751": 0x8040c264,
		"MarioUtil::@2752": 0x8040c268,
		"MarioUtil::@2753": 0x8040c26c,
		"MarioUtil::@2754": 0x8040c270,
		"MarioUtil::@2857": 0x8040c274,
		"MarioUtil::@2858": 0x8040c278,
		"MarioUtil::@2859": 0x8040c27c,
		"MarioUtil::@2976": 0x8040c280,
		"MarioUtil::@2977": 0x8040c284,
		"MarioUtil::@2978": 0x8040c288,
		"MarioUtil::@4014": 0x8040c28c,
		"MarioUtil::@4158": 0x8040c290,
		"MarioUtil::@4159": 0x8040c294,
		"MarioUtil::@4634": 0x8040c298,
		"MarioUtil::@4756": 0x8040c29c,
		"MarioUtil::@4757": 0x8040c2a0,
		"MarioUtil::@4758": 0x8040c2a4,
		"MarioUtil::@4759": 0x8040c2a8,
		"MarioUtil::@4869": 0x8040c2ac,
		"MarioUtil::@5163": 0x8040c2b8,
		"MarioUtil::@5164": 0x8040c2bc,
		"MarioUtil::@51": 0x8040c2c0,
		"@51": 0x8040c2c0,
		"MarioUtil::@52": 0x8040c2c4,
		"MarioUtil::@53": 0x8040c2c8,
		"@53": 0x8040c2c8,
		"MarioUtil::@1799": 0x8040c2d0,
		"MarioUtil::@2233": 0x8040c2e4,
		"MarioUtil::@1767": 0x8040c2f0,
		"MarioUtil::@1790": 0x8040c2f4,
		"MarioUtil::@1841": 0x8040c2f8,
		"MarioUtil::@2244": 0x8040c2fc,
		"MarioUtil::@2245": 0x8040c300,
		"MarioUtil::@2249": 0x8040c304,
		"MarioUtil::sFogOffColor$1583": 0x8040c308,
		"sFogOffColor$1583": 0x8040c308,
		"MarioUtil::@2280": 0x8040c320,
		"MarioUtil::@2282": 0x8040c330,
		"MarioUtil::@1941": 0x8040c340,
		"MarioUtil::@1942": 0x8040c344,
		"M3DUtil::@1572": 0x8040c348,
		"M3DUtil::@1573": 0x8040c34c,
		"M3DUtil::@1716": 0x8040c350,
		"@1716": 0x8040c350,
		"M3DUtil::@3554": 0x8040c358,
		"M3DUtil::@1875": 0x8040c368,
		"M3DUtil::@1908": 0x8040c370,
		"M3DUtil::@1909": 0x8040c374,
		"M3DUtil::@2660": 0x8040c380,
		"M3DUtil::@2663": 0x8040c388,
		"M3DUtil::@2666": 0x8040c390,
		"M3DUtil::@2669": 0x8040c398,
		"M3DUtil::@2672": 0x8040c3a0,
		"M3DUtil::@2019": 0x8040c3a8,
		"M3DUtil::@2020": 0x8040c3b0,
		"M3DUtil::@2021": 0x8040c3b4,
		"M3DUtil::@2022": 0x8040c3bc,
		"M3DUtil::@2023": 0x8040c3c4,
		"M3DUtil::@2024": 0x8040c3cc,
		"M3DUtil::@2025": 0x8040c3d4,
		"M3DUtil::@2161": 0x8040c3dc,
		"M3DUtil::@2162": 0x8040c3e4,
		"M3DUtil::@2163": 0x8040c3e8,
		"M3DUtil::@1661": 0x8040c3f0,
		"M3DUtil::@1694": 0x8040c3f4,
		"M3DUtil::@1710": 0x8040c400,
		"M3DUtil::@1711": 0x8040c404,
		"System::@2802": 0x8040c408,
		"System::@2803": 0x8040c40c,
		"System::@3830": 0x8040c428,
		"System::@3831": 0x8040c42c,
		"System::@3832": 0x8040c430,
		"System::@3833": 0x8040c434,
		"System::@4803": 0x8040c454,
		"@4803": 0x8040c454,
		"System::@2171": 0x8040c468,
		"System::@2172": 0x8040c46c,
		"System::@2316": 0x8040c480,
		"System::@2317": 0x8040c484,
		"System::@1731": 0x8040c498,
		"@1731": 0x8040c498,
		"System::@2398": 0x8040c4a0,
		"System::@3915": 0x8040c4b8,
		"System::@4376": 0x8040c4d8,
		"System::@3071": 0x8040c4f0,
		"System::@2389": 0x8040c4f8,
		"System::@2731": 0x8040c500,
		"System::@2738": 0x8040c508,
		"System::@2739": 0x8040c50c,
		"System::@2740": 0x8040c510,
		"System::@2741": 0x8040c514,
		"System::@2742": 0x8040c518,
		"System::@2753": 0x8040c520,
		"System::@2754": 0x8040c524,
		"System::@2975": 0x8040c540,
		"System::@1626": 0x8040c548,
		"System::@3113": 0x8040c570,
		"System::@4673": 0x8040c590,
		"System::@4835": 0x8040c5c8,
		"System::@2844": 0x8040c5dc,
		"System::@2850": 0x8040c5e4,
		"System::@2851": 0x8040c5ec,
		"System::@2852": 0x8040c5f4,
		"System::@2853": 0x8040c5fc,
		"System::@1607": 0x8040c630,
		"System::@2481": 0x8040c648,
		"System::@2485": 0x8040c64c,
		"System::@1806": 0x8040c6a8,
		"System::@1807": 0x8040c6ac,
		"System::@2115": 0x8040c6b0,
		"System::@2116": 0x8040c6b4,
		"System::@2121": 0x8040c6c0,
		"System::@2122": 0x8040c6c4,
		"System::@1902": 0x8040c6d0,
		"System::@1665": 0x8040c6d8,
		"System::@3558": 0x8040c718,
		"System::@3559": 0x8040c720,
		"System::@3960": 0x8040c74c,
		"System::@3962": 0x8040c754,
		"System::@3964": 0x8040c75c,
		"System::@4118": 0x8040c7a8,
		"System::@2093": 0x8040c830,
		"System::@2094": 0x8040c834,
		"System::@4984": 0x8040c848,
		"System::@4986": 0x8040c850,
		"System::@5046": 0x8040c8a8,
		"System::@5060": 0x8040c8b4,
		"System::@5102": 0x8040c8f0,
		"System::@5207": 0x8040c938,
		"@5207": 0x8040c938,
		"System::@5328": 0x8040c9c8,
		"System::@5333": 0x8040c9d0,
		"System::@2441": 0x8040c9e8,
		"System::@2442": 0x8040c9ec,
		"System::@2553": 0x8040c9f4,
		"System::@2829": 0x8040c9fc,
		"System::@2835": 0x8040ca04,
		"System::@3804": 0x8040ca38,
		"System::@2293": 0x8040ca48,
		"System::@2344": 0x8040ca50,
		"System::@2373": 0x8040ca54,
		"System::@2814": 0x8040ca78,
		"System::@2815": 0x8040ca7c,
		"System::@2999": 0x8040ca80,
		"System::@3000": 0x8040ca84,
		"System::@3001": 0x8040ca88,
		"System::@3002": 0x8040ca8c,
		"Strategic::@2838": 0x8040caa8,
		"Strategic::@2872": 0x8040caac,
		"Strategic::@2873": 0x8040cab0,
		"Strategic::@2935": 0x8040cab4,
		"Strategic::@3064": 0x8040cab8,
		"Strategic::@3163": 0x8040cabc,
		"Strategic::@3282": 0x8040cac0,
		"Strategic::@3344": 0x8040cac4,
		"Strategic::@3345": 0x8040cac8,
		"Strategic::@3346": 0x8040cacc,
		"Strategic::@3347": 0x8040cad0,
		"Strategic::@2726": 0x8040cad8,
		"Strategic::@2875": 0x8040cb18,
		"Strategic::@3178": 0x8040cb28,
		"Strategic::@2101": 0x8040cb30,
		"Strategic::@2103": 0x8040cb34,
		"Strategic::@2104": 0x8040cb38,
		"Strategic::@2277": 0x8040cb40,
		"Strategic::@1841": 0x8040cb48,
		"Strategic::@1947": 0x8040cb50,
		"Strategic::@1662": 0x8040cb58,
		"Strategic::@2285": 0x8040cb68,
		"Strategic::@2409": 0x8040cb6c,
		"Strategic::@2532": 0x8040cb70,
		"Strategic::@2533": 0x8040cb78,
		"Strategic::@2534": 0x8040cb80,
		"Strategic::@2535": 0x8040cb88,
		"Strategic::@2536": 0x8040cb90,
		"Strategic::@2537": 0x8040cb98,
		"Strategic::@2538": 0x8040cba0,
		"Strategic::@2539": 0x8040cba4,
		"Strategic::@2540": 0x8040cbac,
		"Strategic::@2829": 0x8040cbb4,
		"Strategic::@2830": 0x8040cbb8,
		"Strategic::@2831": 0x8040cbbc,
		"Strategic::@1772": 0x8040cbc0,
		"Strategic::@1825": 0x8040cbc4,
		"Strategic::@1540": 0x8040cbc8,
		"Strategic::@1618": 0x8040cbd0,
		"Strategic::@1619": 0x8040cbd4,
		"Strategic::@1660": 0x8040cbd8,
		"Player::@1908": 0x8040cbe0,
		"Player::@2188": 0x8040cbf0,
		"Player::@3153": 0x8040cbfc,
		"Player::@3154": 0x8040cc00,
		"Player::@2278": 0x8040cc70,
		"Player::@2279": 0x8040cc74,
		"Player::@2280": 0x8040cc78,
		"Player::@2485": 0x8040cc7c,
		"Player::@2856": 0x8040cd70,
		"Player::@2857": 0x8040cd78,
		"Player::@2859": 0x8040cd80,
		"Player::@2860": 0x8040cd84,
		"Player::@2861": 0x8040cd8c,
		"Player::@2865": 0x8040cdac,
		"Player::@2866": 0x8040cdb4,
		"Player::@2867": 0x8040cdbc,
		"Player::@2958": 0x8040cedc,
		"Player::@3344": 0x8040cf64,
		"Player::@3647": 0x8040cf70,
		"Player::@3656": 0x8040cf74,
		"Player::@3659": 0x8040cf78,
		"Player::@4330": 0x8040cf8c,
		"Player::@4331": 0x8040cf90,
		"Player::@4332": 0x8040cf94,
		"Player::@4333": 0x8040cf98,
		"Player::@4947": 0x8040cfb0,
		"Player::@4948": 0x8040cfb4,
		"Player::@4949": 0x8040cfb8,
		"Player::@5689": 0x8040cfd8,
		"Player::@5743": 0x8040cfe0,
		"Player::@5744": 0x8040cfe4,
		"Player::@6364": 0x8040cfe8,
		"Player::@6365": 0x8040cfec,
		"Player::@6366": 0x8040cff0,
		"Player::@6705": 0x8040cff4,
		"Player::@3598": 0x8040d030,
		"Player::@3930": 0x8040d040,
		"Player::@4084": 0x8040d068,
		"Player::@4085": 0x8040d06c,
		"Player::@4204": 0x8040d070,
		"Player::@4513": 0x8040d074,
		"Player::@4514": 0x8040d078,
		"@4514": 0x8040d078,
		"Player::@4515": 0x8040d07c,
		"@4515": 0x8040d07c,
		"Player::@2752": 0x8040d088,
		"Player::@4375": 0x8040d0b8,
		"Player::@4499": 0x8040d0e0,
		"Player::@4520": 0x8040d0e4,
		"Player::@5111": 0x8040d0fc,
		"Player::@5112": 0x8040d100,
		"Player::@5137": 0x8040d104,
		"Player::@5138": 0x8040d108,
		"Player::@5269": 0x8040d10c,
		"Player::@5270": 0x8040d110,
		"Player::@5271": 0x8040d114,
		"Player::@5690": 0x8040d118,
		"Player::@5691": 0x8040d11c,
		"Player::@5692": 0x8040d120,
		"Player::@5693": 0x8040d124,
		"Player::@5694": 0x8040d128,
		"Player::@5792": 0x8040d12c,
		"@5792": 0x8040d12c,
		"Player::@5793": 0x8040d130,
		"Player::@5794": 0x8040d134,
		"Player::@5795": 0x8040d138,
		"Player::@6153": 0x8040d13c,
		"Player::@6154": 0x8040d140,
		"Player::@6155": 0x8040d144,
		"Player::@6156": 0x8040d148,
		"Player::@6157": 0x8040d14c,
		"Player::@7111": 0x8040d150,
		"@7111": 0x8040d150,
		"Player::@7112": 0x8040d154,
		"@7112": 0x8040d154,
		"Player::@7272": 0x8040d158,
		"@7272": 0x8040d158,
		"Player::@7551": 0x8040d15c,
		"Player::@7552": 0x8040d160,
		"@7552": 0x8040d160,
		"Player::@7553": 0x8040d164,
		"@7553": 0x8040d164,
		"Player::@7554": 0x8040d168,
		"@7554": 0x8040d168,
		"Player::@7555": 0x8040d16c,
		"@7555": 0x8040d16c,
		"Player::@7556": 0x8040d170,
		"@7556": 0x8040d170,
		"Player::@7557": 0x8040d174,
		"@7557": 0x8040d174,
		"Player::@7558": 0x8040d178,
		"@7558": 0x8040d178,
		"Player::@7996": 0x8040d17c,
		"@7996": 0x8040d17c,
		"Player::@8029": 0x8040d180,
		"@8029": 0x8040d180,
		"Player::@3039": 0x8040d1b0,
		"Player::@3041": 0x8040d1b8,
		"Player::@3042": 0x8040d1bc,
		"Player::@3349": 0x8040d1e4,
		"Player::@3623": 0x8040d20c,
		"Player::@3624": 0x8040d210,
		"Player::@3625": 0x8040d214,
		"Player::@3626": 0x8040d218,
		"Player::@3649": 0x8040d21c,
		"Player::@3852": 0x8040d230,
		"Player::@3907": 0x8040d234,
		"Player::@3908": 0x8040d238,
		"Player::@4131": 0x8040d26c,
		"Player::@4132": 0x8040d270,
		"Player::@4171": 0x8040d274,
		"Player::@4256": 0x8040d278,
		"Player::@4380": 0x8040d27c,
		"Player::@4535": 0x8040d280,
		"@4535": 0x8040d280,
		"Player::@4536": 0x8040d284,
		"Player::@4537": 0x8040d288,
		"Player::@4558": 0x8040d28c,
		"Player::@4559": 0x8040d290,
		"Player::@4700": 0x8040d294,
		"Player::@4701": 0x8040d298,
		"Player::@4792": 0x8040d29c,
		"Player::@3400": 0x8040d2b0,
		"Player::@3401": 0x8040d2b4,
		"Player::@3402": 0x8040d2b8,
		"Player::@3403": 0x8040d2bc,
		"Player::@3404": 0x8040d2c0,
		"Player::@3405": 0x8040d2c4,
		"Player::@3406": 0x8040d2c8,
		"Player::@3407": 0x8040d2cc,
		"Player::@3640": 0x8040d2e4,
		"Player::@3641": 0x8040d2e8,
		"Player::@3643": 0x8040d2f0,
		"Player::@4072": 0x8040d300,
		"Player::@4073": 0x8040d304,
		"Player::@4074": 0x8040d308,
		"Player::@4238": 0x8040d30c,
		"Player::@4614": 0x8040d310,
		"@4614": 0x8040d310,
		"Player::@4615": 0x8040d314,
		"@4615": 0x8040d314,
		"Player::@5157": 0x8040d338,
		"Player::@5187": 0x8040d33c,
		"Player::@5261": 0x8040d340,
		"Player::@5262": 0x8040d344,
		"Player::@5263": 0x8040d348,
		"Player::@5264": 0x8040d34c,
		"Player::@5265": 0x8040d350,
		"Player::@5359": 0x8040d354,
		"Player::@5360": 0x8040d358,
		"Player::@5361": 0x8040d35c,
		"Player::@5362": 0x8040d360,
		"Player::@2245": 0x8040d368,
		"Player::@3064": 0x8040d394,
		"Player::@3065": 0x8040d398,
		"Player::@3066": 0x8040d39c,
		"Player::@3067": 0x8040d3a0,
		"Player::@3068": 0x8040d3a4,
		"Player::@3070": 0x8040d3ac,
		"Player::@1978": 0x8040d408,
		"Player::@2014": 0x8040d40c,
		"Player::@2096": 0x8040d410,
		"Player::@2631": 0x8040d438,
		"Player::@2632": 0x8040d43c,
		"Player::@2633": 0x8040d440,
		"Player::@3022": 0x8040d468,
		"Player::@3428": 0x8040d490,
		"Player::@3697": 0x8040d4a4,
		"Player::@3699": 0x8040d4ac,
		"Player::@3711": 0x8040d4b0,
		"Player::@3882": 0x8040d4b4,
		"Player::@4029": 0x8040d4b8,
		"Player::@4033": 0x8040d4c0,
		"Player::@4036": 0x8040d4c4,
		"Player::@4040": 0x8040d4c8,
		"Player::@4358": 0x8040d4cc,
		"Player::@4557": 0x8040d4d8,
		"@4557": 0x8040d4d8,
		"Player::@4582": 0x8040d4dc,
		"Player::@4583": 0x8040d4e0,
		"Player::@5868": 0x8040d4e8,
		"Player::@5869": 0x8040d4f0,
		"Player::@5871": 0x8040d4f8,
		"Player::@5873": 0x8040d4fc,
		"Player::@5876": 0x8040d500,
		"Player::@5878": 0x8040d508,
		"Player::@5887": 0x8040d50c,
		"@5887": 0x8040d50c,
		"Player::@5889": 0x8040d510,
		"@5889": 0x8040d510,
		"Player::@5897": 0x8040d514,
		"Player::@5903": 0x8040d51c,
		"@5903": 0x8040d51c,
		"Player::@5905": 0x8040d520,
		"Player::@5908": 0x8040d524,
		"Player::@5910": 0x8040d528,
		"Player::@5912": 0x8040d52c,
		"Player::@5917": 0x8040d534,
		"Player::@3798": 0x8040d548,
		"Player::@3801": 0x8040d554,
		"Player::@3810": 0x8040d560,
		"Player::@4160": 0x8040d568,
		"Player::@4887": 0x8040d56c,
		"@4887": 0x8040d56c,
		"Player::@4892": 0x8040d574,
		"Player::@4898": 0x8040d57c,
		"Player::@4899": 0x8040d580,
		"Player::@4900": 0x8040d584,
		"Player::@4901": 0x8040d588,
		"Player::@4902": 0x8040d58c,
		"Player::@4903": 0x8040d590,
		"@4903": 0x8040d590,
		"Player::@4904": 0x8040d594,
		"@4904": 0x8040d594,
		"Player::@3053": 0x8040d5d0,
		"Player::@3201": 0x8040d5dc,
		"Player::@3203": 0x8040d5e4,
		"Player::@2019": 0x8040d5f8,
		"Player::@2560": 0x8040d624,
		"Player::@2562": 0x8040d628,
		"Player::@2564": 0x8040d62c,
		"Player::@2589": 0x8040d630,
		"Player::@2592": 0x8040d638,
		"Player::@2594": 0x8040d640,
		"Player::@2595": 0x8040d644,
		"Player::@2596": 0x8040d64c,
		"Player::@2615": 0x8040d650,
		"Player::@2617": 0x8040d658,
		"Player::@2619": 0x8040d65c,
		"Player::@2621": 0x8040d660,
		"Player::@2623": 0x8040d664,
		"Player::@2636": 0x8040d668,
		"Player::@2637": 0x8040d66c,
		"Player::@2638": 0x8040d674,
		"Player::@2710": 0x8040d678,
		"Player::@2712": 0x8040d684,
		"Player::@2714": 0x8040d690,
		"Player::@2717": 0x8040d6a4,
		"Player::@2718": 0x8040d6a8,
		"Player::@2719": 0x8040d6b0,
		"Player::@3148": 0x8040d72c,
		"Player::@3150": 0x8040d730,
		"Player::@3246": 0x8040d748,
		"Player::@3332": 0x8040d758,
		"Player::@3334": 0x8040d75c,
		"Player::@3369": 0x8040d760,
		"Player::@3485": 0x8040d774,
		"Player::@3491": 0x8040d778,
		"Player::@3493": 0x8040d780,
		"Player::@3571": 0x8040d794,
		"Player::@3580": 0x8040d79c,
		"Player::@3749": 0x8040d7ac,
		"Player::@3786": 0x8040d7bc,
		"Player::@3787": 0x8040d7c4,
		"Player::@3998": 0x8040d7e0,
		"Player::@6572": 0x8040d7fc,
		"@6572": 0x8040d7fc,
		"Player::@6573": 0x8040d800,
		"@6573": 0x8040d800,
		"Player::@6574": 0x8040d804,
		"@6574": 0x8040d804,
		"Player::@6575": 0x8040d808,
		"@6575": 0x8040d808,
		"Player::@6576": 0x8040d80c,
		"@6576": 0x8040d80c,
		"Player::@6709": 0x8040d818,
		"Player::@2699": 0x8040d820,
		"Player::@3018": 0x8040d828,
		"Player::@3035": 0x8040d82c,
		"Player::@3049": 0x8040d834,
		"Player::@3680": 0x8040d874,
		"Player::@3825": 0x8040d884,
		"Player::@3865": 0x8040d898,
		"@3865": 0x8040d898,
		"Player::@4343": 0x8040d89c,
		"Player::@4344": 0x8040d8a0,
		"Player::@4345": 0x8040d8a4,
		"Player::@4346": 0x8040d8a8,
		"Player::@4347": 0x8040d8ac,
		"Player::@4502": 0x8040d8b0,
		"Player::@4503": 0x8040d8b4,
		"Player::@4561": 0x8040d8bc,
		"Player::@4562": 0x8040d8c0,
		"Player::@4563": 0x8040d8c4,
		"Player::@4623": 0x8040d8c8,
		"Player::@4624": 0x8040d8cc,
		"Player::@4625": 0x8040d8d0,
		"Player::@4637": 0x8040d8dc,
		"Player::@4638": 0x8040d8e0,
		"Player::@4639": 0x8040d8e4,
		"Player::@4640": 0x8040d8e8,
		"Player::@4641": 0x8040d8ec,
		"Player::@4642": 0x8040d8f0,
		"Player::@4643": 0x8040d8f4,
		"Player::@4644": 0x8040d8f8,
		"Player::@4648": 0x8040d8fc,
		"Player::@4650": 0x8040d900,
		"Player::@4651": 0x8040d904,
		"Player::@4652": 0x8040d90c,
		"Player::@4653": 0x8040d910,
		"Player::@4654": 0x8040d914,
		"Player::@4731": 0x8040d918,
		"Player::@4732": 0x8040d920,
		"Player::@4733": 0x8040d928,
		"Player::@4734": 0x8040d930,
		"Player::@4735": 0x8040d938,
		"Player::@4737": 0x8040d93c,
		"Player::@4739": 0x8040d944,
		"Player::@4740": 0x8040d94c,
		"Player::@4744": 0x8040d950,
		"Player::@4745": 0x8040d958,
		"Player::@3352": 0x8040d998,
		"Player::@4222": 0x8040d9a4,
		"Player::@4223": 0x8040d9a8,
		"Player::@4224": 0x8040d9ac,
		"Player::@4225": 0x8040d9b0,
		"Player::@4226": 0x8040d9b4,
		"Player::@4227": 0x8040d9b8,
		"Player::@4228": 0x8040d9bc,
		"Player::@4229": 0x8040d9c0,
		"Player::@4272": 0x8040d9d0,
		"NPC::@3245": 0x8040d9f0,
		"NPC::@3246": 0x8040d9f4,
		"NPC::@3247": 0x8040d9f8,
		"NPC::@3361": 0x8040da08,
		"NPC::@3362": 0x8040da0c,
		"NPC::@3363": 0x8040da10,
		"NPC::@3365": 0x8040da18,
		"NPC::@3366": 0x8040da1c,
		"NPC::@3472": 0x8040da20,
		"NPC::@3878": 0x8040da24,
		"NPC::@3879": 0x8040da28,
		"NPC::@4245": 0x8040da2c,
		"NPC::@4246": 0x8040da30,
		"NPC::@4247": 0x8040da34,
		"NPC::@4250": 0x8040da48,
		"NPC::@4778": 0x8040da4c,
		"NPC::@3390": 0x8040da58,
		"NPC::@3704": 0x8040da5c,
		"NPC::@3705": 0x8040da60,
		"NPC::@3706": 0x8040da64,
		"NPC::@3707": 0x8040da68,
		"NPC::@3935": 0x8040da80,
		"NPC::@3936": 0x8040da84,
		"NPC::@3989": 0x8040da88,
		"NPC::@4213": 0x8040da8c,
		"NPC::@4359": 0x8040da90,
		"NPC::@2536": 0x8040dac4,
		"NPC::@2804": 0x8040dac8,
		"NPC::@2805": 0x8040dacc,
		"NPC::@2860": 0x8040dad0,
		"NPC::@2898": 0x8040dad8,
		"NPC::@2934": 0x8040dadc,
		"NPC::@2857": 0x8040db08,
		"NPC::@3036": 0x8040db0c,
		"NPC::@3037": 0x8040db10,
		"NPC::@2161": 0x8040db18,
		"NPC::@2163": 0x8040db1c,
		"NPC::@2165": 0x8040db20,
		"NPC::@2167": 0x8040db24,
		"NPC::@2169": 0x8040db28,
		"NPC::@2171": 0x8040db2c,
		"NPC::@2173": 0x8040db30,
		"NPC::@2175": 0x8040db34,
		"NPC::@2177": 0x8040db38,
		"NPC::@2180": 0x8040db3c,
		"NPC::@2182": 0x8040db40,
		"NPC::@2184": 0x8040db44,
		"NPC::@2187": 0x8040db48,
		"NPC::@2189": 0x8040db4c,
		"NPC::@2194": 0x8040db50,
		"NPC::@2196": 0x8040db54,
		"NPC::@2204": 0x8040db64,
		"NPC::@2206": 0x8040db68,
		"NPC::@2208": 0x8040db6c,
		"NPC::@2341": 0x8040db98,
		"NPC::@2356": 0x8040dba0,
		"NPC::@2375": 0x8040dbb4,
		"NPC::@2419": 0x8040dbb8,
		"NPC::@2681": 0x8040dbc0,
		"NPC::@2682": 0x8040dbc8,
		"NPC::@2685": 0x8040dbcc,
		"NPC::@2821": 0x8040dbd0,
		"NPC::sPeach_TakenMiddle": 0x8040dbd8,
		"sPeach_TakenMiddle": 0x8040dbd8,
		"NPC::@1539": 0x8040dbe0,
		"NPC::sMonteM_TieBColorBuf0": 0x8040dbe8,
		"sMonteM_TieBColorBuf0": 0x8040dbe8,
		"NPC::sMonteM_TieBColorBuf1": 0x8040dbf0,
		"sMonteM_TieBColorBuf1": 0x8040dbf0,
		"NPC::@1573": 0x8040dbf8,
		"NPC::@1577": 0x8040dc00,
		"NPC::sMareMB_ElderMat1ColorBuf0": 0x8040dc08,
		"sMareMB_ElderMat1ColorBuf0": 0x8040dc08,
		"NPC::sMareMB_ElderMat1ColorBuf1": 0x8040dc10,
		"sMareMB_ElderMat1ColorBuf1": 0x8040dc10,
		"NPC::sMareMB_ElderMat2ColorBuf0": 0x8040dc18,
		"sMareMB_ElderMat2ColorBuf0": 0x8040dc18,
		"NPC::sMareMB_ElderMat2ColorBuf1": 0x8040dc20,
		"sMareMB_ElderMat2ColorBuf1": 0x8040dc20,
		"NPC::@1583": 0x8040dc28,
		"NPC::sMareMB_ElderMat3ColorBuf0": 0x8040dc30,
		"sMareMB_ElderMat3ColorBuf0": 0x8040dc30,
		"NPC::sMareMB_ElderMat3ColorBuf1": 0x8040dc38,
		"sMareMB_ElderMat3ColorBuf1": 0x8040dc38,
		"NPC::@1584": 0x8040dc40,
		"NPC::sMareMB_FishingRodMat1ColorBuf0": 0x8040dc48,
		"sMareMB_FishingRodMat1ColorBuf0": 0x8040dc48,
		"NPC::sMareMB_FishingRodMat1ColorBuf1": 0x8040dc50,
		"sMareMB_FishingRodMat1ColorBuf1": 0x8040dc50,
		"NPC::sMareMB_FishingRodMat2ColorBuf0": 0x8040dc58,
		"sMareMB_FishingRodMat2ColorBuf0": 0x8040dc58,
		"NPC::sMareMB_FishingRodMat2ColorBuf1": 0x8040dc60,
		"sMareMB_FishingRodMat2ColorBuf1": 0x8040dc60,
		"NPC::sMareMB_FishingRodMat3ColorBuf0": 0x8040dc68,
		"sMareMB_FishingRodMat3ColorBuf0": 0x8040dc68,
		"NPC::sMareMB_FishingRodMat3ColorBuf1": 0x8040dc70,
		"sMareMB_FishingRodMat3ColorBuf1": 0x8040dc70,
		"NPC::sMareMC_HatFColorBuf0": 0x8040dc78,
		"sMareMC_HatFColorBuf0": 0x8040dc78,
		"NPC::sMareMC_HatFColorBuf1": 0x8040dc80,
		"sMareMC_HatFColorBuf1": 0x8040dc80,
		"NPC::sMareMC_BeardColorBuf0": 0x8040dc88,
		"sMareMC_BeardColorBuf0": 0x8040dc88,
		"NPC::sMareMC_BeardColorBuf1": 0x8040dc90,
		"sMareMC_BeardColorBuf1": 0x8040dc90,
		"NPC::sMareMC_MustacheColorBuf0": 0x8040dc98,
		"sMareMC_MustacheColorBuf0": 0x8040dc98,
		"NPC::sMareMC_MustacheColorBuf1": 0x8040dca0,
		"sMareMC_MustacheColorBuf1": 0x8040dca0,
		"NPC::sMareMD_PipeColorBuf0": 0x8040dca8,
		"sMareMD_PipeColorBuf0": 0x8040dca8,
		"NPC::sMareMD_PipeColorBuf1": 0x8040dcb0,
		"sMareMD_PipeColorBuf1": 0x8040dcb0,
		"NPC::@1590": 0x8040dcb8,
		"NPC::sMareWB_BabyBodyColorBuf0": 0x8040dcc0,
		"sMareWB_BabyBodyColorBuf0": 0x8040dcc0,
		"NPC::@1598": 0x8040dcc8,
		"NPC::sMareWB_BabyHatColorBuf0": 0x8040dcd0,
		"sMareWB_BabyHatColorBuf0": 0x8040dcd0,
		"NPC::sMareWB_BabyHatColorBuf1": 0x8040dcd8,
		"sMareWB_BabyHatColorBuf1": 0x8040dcd8,
		"NPC::sMareWB_BabyBedColorBuf0": 0x8040dce0,
		"sMareWB_BabyBedColorBuf0": 0x8040dce0,
		"NPC::sMareWB_BabyBedColorBuf1": 0x8040dce8,
		"sMareWB_BabyBedColorBuf1": 0x8040dce8,
		"NPC::@1614": 0x8040dcf0,
		"@1614": 0x8040dcf0,
		"NPC::@1621": 0x8040dcf8,
		"TBaseNPC::sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x8040dd08,
		"sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x8040dd08,
		"NPC::@2532": 0x8040dd10,
		"NPC::@2533": 0x8040dd14,
		"NPC::@2534": 0x8040dd18,
		"NPC::@2754": 0x8040dd30,
		"NPC::@2755": 0x8040dd34,
		"NPC::@2756": 0x8040dd38,
		"NPC::@1832": 0x8040dd40,
		"NPC::@1833": 0x8040dd44,
		"NPC::@2491": 0x8040dd50,
		"NPC::@2492": 0x8040dd54,
		"NPC::@3189": 0x8040dd68,
		"NPC::@3190": 0x8040dd6c,
		"NPC::@3191": 0x8040dd70,
		"NPC::@3387": 0x8040dd78,
		"NPC::@3388": 0x8040dd7c,
		"NPC::@3467": 0x8040dd88,
		"NPC::@3468": 0x8040dd8c,
		"NPC::@3776": 0x8040dd90,
		"NPC::@1682": 0x8040dd98,
		"NPC::@1683": 0x8040dd9c,
		"NPC::@1684": 0x8040dda0,
		"NPC::@1685": 0x8040dda4,
		"NPC::@1686": 0x8040dda8,
		"NPC::@2611": 0x8040ddc0,
		"NPC::@2612": 0x8040ddc4,
		"NPC::@2613": 0x8040ddc8,
		"NPC::@2614": 0x8040ddcc,
		"NPC::@2615": 0x8040ddd0,
		"NPC::@2695": 0x8040ddd4,
		"NPC::@2499": 0x8040ddf0,
		"NPC::@2500": 0x8040ddf4,
		"NPC::@2501": 0x8040ddf8,
		"NPC::@2319": 0x8040de38,
		"NPC::@2320": 0x8040de3c,
		"NPC::@2321": 0x8040de40,
		"NPC::@2322": 0x8040de44,
		"MSound::@1982": 0x8040de5c,
		"MSound::@1983": 0x8040de60,
		"MSound::@1984": 0x8040de64,
		"MSound::@1985": 0x8040de68,
		"MSound::@2520": 0x8040de7c,
		"MSound::@2594": 0x8040de80,
		"MSound::@2595": 0x8040de84,
		"MSound::@2614": 0x8040de90,
		"MSound::@2615": 0x8040de94,
		"MSound::@2968": 0x8040deb8,
		"MSound::@2969": 0x8040debc,
		"MSound::@2970": 0x8040dec0,
		"MSound::@3093": 0x8040dec4,
		"MSound::@3431": 0x8040dec8,
		"MSound::@3432": 0x8040decc,
		"MSound::@2263": 0x8040ded8,
		"MSound::@2264": 0x8040dedc,
		"MSound::@2265": 0x8040dee0,
		"MSound::@2486": 0x8040def0,
		"MSound::@2543": 0x8040def4,
		"MSound::@2544": 0x8040def8,
		"MSound::@2545": 0x8040defc,
		"MSound::@2575": 0x8040df00,
		"MSound::@2576": 0x8040df04,
		"MSound::@2577": 0x8040df08,
		"MSound::@2818": 0x8040df18,
		"MSound::@2819": 0x8040df1c,
		"MSound::@2820": 0x8040df20,
		"MSound::@2821": 0x8040df24,
		"MSound::@2823": 0x8040df28,
		"MSound::@2824": 0x8040df2c,
		"MSound::@2825": 0x8040df30,
		"MSound::@2827": 0x8040df34,
		"MSound::@2828": 0x8040df38,
		"MSound::@2829": 0x8040df3c,
		"MSound::@2830": 0x8040df40,
		"MSound::@2831": 0x8040df44,
		"MSound::@2833": 0x8040df48,
		"MSound::@2837": 0x8040df4c,
		"MSound::@2838": 0x8040df50,
		"MSound::@2839": 0x8040df54,
		"MSound::@2840": 0x8040df58,
		"MSound::@2842": 0x8040df5c,
		"MSound::@2843": 0x8040df60,
		"MSound::@2845": 0x8040df64,
		"MSound::@2847": 0x8040df68,
		"MSound::@2848": 0x8040df6c,
		"MSound::@2849": 0x8040df70,
		"MSound::@2850": 0x8040df74,
		"MSound::@2859": 0x8040df94,
		"MSound::@2860": 0x8040df98,
		"MSound::@2874": 0x8040dfb0,
		"MSound::@2878": 0x8040dfbc,
		"MSound::@2884": 0x8040dfc4,
		"MSound::@2890": 0x8040dfd0,
		"MSound::@2895": 0x8040dfdc,
		"MSound::@2902": 0x8040dfec,
		"MSound::@2907": 0x8040dffc,
		"MSound::@2909": 0x8040e000,
		"MSound::@2910": 0x8040e004,
		"MSound::@2912": 0x8040e008,
		"MSound::@2915": 0x8040e010,
		"MSound::@2919": 0x8040e01c,
		"MSound::@2920": 0x8040e020,
		"MSound::@2923": 0x8040e028,
		"MSound::@2924": 0x8040e02c,
		"MSound::@2925": 0x8040e030,
		"MSound::@2927": 0x8040e038,
		"MSound::@2929": 0x8040e03c,
		"MSound::@2931": 0x8040e040,
		"MSound::@2933": 0x8040e044,
		"MSound::@2935": 0x8040e048,
		"MSound::@2937": 0x8040e054,
		"MSound::@2939": 0x8040e05c,
		"MSound::@3166": 0x8040e068,
		"MSound::@1995": 0x8040e070,
		"MSound::@1996": 0x8040e074,
		"MSound::@1997": 0x8040e078,
		"MSound::@1998": 0x8040e07c,
		"MSound::@1999": 0x8040e080,
		"MSound::@2000": 0x8040e084,
		"MSound::@2001": 0x8040e088,
		"MSound::@2020": 0x8040e0cc,
		"MSound::@2021": 0x8040e0d0,
		"MSound::@2022": 0x8040e0d4,
		"MSound::@2023": 0x8040e0dc,
		"MSound::@2025": 0x8040e0e4,
		"MSound::@2027": 0x8040e0e8,
		"MSound::@2029": 0x8040e0ec,
		"MSound::@2030": 0x8040e0f0,
		"MSound::@2031": 0x8040e0f4,
		"MSound::@2036": 0x8040e128,
		"MSound::@2080": 0x8040e148,
		"MSound::@2039": 0x8040e160,
		"MSound::@2040": 0x8040e164,
		"MSound::@2041": 0x8040e168,
		"MoveBG::no_data_anim_info": 0x8040e198,
		"no_data_anim_info": 0x8040e198,
		"MoveBG::normal_sound_info": 0x8040e1a0,
		"normal_sound_info": 0x8040e1a0,
		"MoveBG::billboard_dolphin_anim_info": 0x8040e1b0,
		"billboard_dolphin_anim_info": 0x8040e1b0,
		"MoveBG::billboard_sun_anim_info": 0x8040e1b8,
		"billboard_sun_anim_info": 0x8040e1b8,
		"MoveBG::billboard_restaurant_anim_info": 0x8040e1c0,
		"billboard_restaurant_anim_info": 0x8040e1c0,
		"MoveBG::billboard_fish_anim_info": 0x8040e1c8,
		"billboard_fish_anim_info": 0x8040e1c8,
		"MoveBG::MonteChair_anim_info": 0x8040e1d8,
		"MonteChair_anim_info": 0x8040e1d8,
		"MoveBG::@2798": 0x8040e1e0,
		"MoveBG::doorHotel_anim_info": 0x8040e1e8,
		"doorHotel_anim_info": 0x8040e1e8,
		"MoveBG::@2802": 0x8040e1f0,
		"MoveBG::manhole_anim_info": 0x8040e1f8,
		"manhole_anim_info": 0x8040e1f8,
		"MoveBG::manhole_map_collision_info": 0x8040e200,
		"manhole_map_collision_info": 0x8040e200,
		"MoveBG::@2804": 0x8040e208,
		"MoveBG::FruitBasket_anim_info": 0x8040e210,
		"FruitBasket_anim_info": 0x8040e210,
		"MoveBG::@2805": 0x8040e218,
		"MoveBG::FruitBasket_map_collision_data": 0x8040e220,
		"FruitBasket_map_collision_data": 0x8040e220,
		"MoveBG::FruitBasket_map_collision_info": 0x8040e228,
		"FruitBasket_map_collision_info": 0x8040e228,
		"MoveBG::BasketReverse_anim_info": 0x8040e230,
		"BasketReverse_anim_info": 0x8040e230,
		"MoveBG::BasketReverse_map_collision_data": 0x8040e238,
		"BasketReverse_map_collision_data": 0x8040e238,
		"MoveBG::BasketReverse_map_collision_info": 0x8040e240,
		"BasketReverse_map_collision_info": 0x8040e240,
		"MoveBG::Pile_map_collision_data": 0x8040e250,
		"Pile_map_collision_data": 0x8040e250,
		"MoveBG::Pile_map_collision_info": 0x8040e258,
		"Pile_map_collision_info": 0x8040e258,
		"MoveBG::ChipShine_anim_info": 0x8040e260,
		"ChipShine_anim_info": 0x8040e260,
		"MoveBG::KoopaJrSignM_anim_info": 0x8040e268,
		"KoopaJrSignM_anim_info": 0x8040e268,
		"MoveBG::SignCircle_anim_info": 0x8040e270,
		"SignCircle_anim_info": 0x8040e270,
		"MoveBG::SignCross_anim_info": 0x8040e278,
		"SignCross_anim_info": 0x8040e278,
		"MoveBG::SignTriangle_anim_info": 0x8040e280,
		"SignTriangle_anim_info": 0x8040e280,
		"MoveBG::ObjSwitch_map_collision_data": 0x8040e288,
		"ObjSwitch_map_collision_data": 0x8040e288,
		"MoveBG::ObjSwitch_map_collision_info": 0x8040e290,
		"ObjSwitch_map_collision_info": 0x8040e290,
		"MoveBG::RedCoinSwitch_map_collision_data": 0x8040e298,
		"RedCoinSwitch_map_collision_data": 0x8040e298,
		"MoveBG::RedCoinSwitch_map_collision_info": 0x8040e2a0,
		"RedCoinSwitch_map_collision_info": 0x8040e2a0,
		"MoveBG::coin_sound_info": 0x8040e2b0,
		"coin_sound_info": 0x8040e2b0,
		"MoveBG::mario_cap_anim_info": 0x8040e2c8,
		"mario_cap_anim_info": 0x8040e2c8,
		"MoveBG::coin_anim_info": 0x8040e2d0,
		"coin_anim_info": 0x8040e2d0,
		"MoveBG::eggYoshi_anim_info": 0x8040e2d8,
		"eggYoshi_anim_info": 0x8040e2d8,
		"MoveBG::NozzleBox_anim_info": 0x8040e2e0,
		"NozzleBox_anim_info": 0x8040e2e0,
		"MoveBG::mushroom1up_anim_info": 0x8040e2e8,
		"mushroom1up_anim_info": 0x8040e2e8,
		"MoveBG::jumpbase_anim_info": 0x8040e2f0,
		"jumpbase_anim_info": 0x8040e2f0,
		"MoveBG::jumpbase_map_collision_data": 0x8040e2f8,
		"jumpbase_map_collision_data": 0x8040e2f8,
		"MoveBG::jumpbase_map_collision_info": 0x8040e300,
		"jumpbase_map_collision_info": 0x8040e300,
		"MoveBG::fruit_sound_info": 0x8040e308,
		"fruit_sound_info": 0x8040e308,
		"MoveBG::CoverPine_anim_info": 0x8040e310,
		"CoverPine_anim_info": 0x8040e310,
		"MoveBG::durian_sound_info": 0x8040e318,
		"durian_sound_info": 0x8040e318,
		"MoveBG::fence3x3_anim_info": 0x8040e320,
		"fence3x3_anim_info": 0x8040e320,
		"MoveBG::fence_revolve_outer_anim_info": 0x8040e328,
		"fence_revolve_outer_anim_info": 0x8040e328,
		"MoveBG::FenceWaterV_map_collision_data": 0x8040e330,
		"FenceWaterV_map_collision_data": 0x8040e330,
		"MoveBG::FenceWaterV_map_collision_info": 0x8040e338,
		"FenceWaterV_map_collision_info": 0x8040e338,
		"MoveBG::FenceWaterH_map_collision_info": 0x8040e340,
		"FenceWaterH_map_collision_info": 0x8040e340,
		"MoveBG::RailFence_anim_info": 0x8040e348,
		"RailFence_anim_info": 0x8040e348,
		"MoveBG::RailFence_map_collision_info": 0x8040e350,
		"RailFence_map_collision_info": 0x8040e350,
		"MoveBG::BambooRailFence_anim_info": 0x8040e358,
		"BambooRailFence_anim_info": 0x8040e358,
		"MoveBG::wood_barrel_anim_info": 0x8040e360,
		"wood_barrel_anim_info": 0x8040e360,
		"MoveBG::wood_barrel_map_collision_info": 0x8040e370,
		"wood_barrel_map_collision_info": 0x8040e370,
		"MoveBG::wood_barrel_sound_info": 0x8040e378,
		"wood_barrel_sound_info": 0x8040e378,
		"MoveBG::wood_barrel_sink_data": 0x8040e380,
		"wood_barrel_sink_data": 0x8040e380,
		"MoveBG::barrel_float_map_collision_data": 0x8040e388,
		"barrel_float_map_collision_data": 0x8040e388,
		"MoveBG::barrel_float_map_collision_info": 0x8040e390,
		"barrel_float_map_collision_info": 0x8040e390,
		"MoveBG::drum_can_anim_info": 0x8040e398,
		"drum_can_anim_info": 0x8040e398,
		"MoveBG::drum_can_map_collision_info": 0x8040e3a0,
		"drum_can_map_collision_info": 0x8040e3a0,
		"MoveBG::barrel_oil_anim_info": 0x8040e3a8,
		"barrel_oil_anim_info": 0x8040e3a8,
		"MoveBG::warp_block_map_collision_data": 0x8040e3b0,
		"warp_block_map_collision_data": 0x8040e3b0,
		"MoveBG::warp_block_map_collision_info": 0x8040e3b8,
		"warp_block_map_collision_info": 0x8040e3b8,
		"MoveBG::move_block_map_collision_data": 0x8040e3c0,
		"move_block_map_collision_data": 0x8040e3c0,
		"MoveBG::move_block_map_collision_info": 0x8040e3c8,
		"move_block_map_collision_info": 0x8040e3c8,
		"MoveBG::move_block_center_map_collision_data": 0x8040e3d0,
		"move_block_center_map_collision_data": 0x8040e3d0,
		"MoveBG::move_block_center_map_collision_info": 0x8040e3d8,
		"move_block_center_map_collision_info": 0x8040e3d8,
		"MoveBG::breakable_block_anim_info": 0x8040e3e0,
		"breakable_block_anim_info": 0x8040e3e0,
		"MoveBG::breakable_block_map_collision_data": 0x8040e3e8,
		"breakable_block_map_collision_data": 0x8040e3e8,
		"MoveBG::breakable_block_map_collision_info": 0x8040e3f0,
		"breakable_block_map_collision_info": 0x8040e3f0,
		"MoveBG::water_roll_block_anim_info": 0x8040e3f8,
		"water_roll_block_anim_info": 0x8040e3f8,
		"MoveBG::water_roll_block_map_collision_data": 0x8040e400,
		"water_roll_block_map_collision_data": 0x8040e400,
		"MoveBG::water_roll_block_map_collision_info": 0x8040e408,
		"water_roll_block_map_collision_info": 0x8040e408,
		"MoveBG::sand_block_anim_info": 0x8040e410,
		"sand_block_anim_info": 0x8040e410,
		"MoveBG::sand_block_map_collision_info": 0x8040e418,
		"sand_block_map_collision_info": 0x8040e418,
		"MoveBG::MoveCoin_anim_info": 0x8040e420,
		"MoveCoin_anim_info": 0x8040e420,
		"MoveBG::cluster_block_anim_info": 0x8040e428,
		"cluster_block_anim_info": 0x8040e428,
		"MoveBG::NormalBlock_map_collision_data": 0x8040e430,
		"NormalBlock_map_collision_data": 0x8040e430,
		"MoveBG::NormalBlock_map_collision_info": 0x8040e438,
		"NormalBlock_map_collision_info": 0x8040e438,
		"MoveBG::IceBlock_map_collision_data": 0x8040e440,
		"IceBlock_map_collision_data": 0x8040e440,
		"MoveBG::IceBlock_map_collision_info": 0x8040e448,
		"IceBlock_map_collision_info": 0x8040e448,
		"MoveBG::BrickBlock_anim_info": 0x8040e450,
		"BrickBlock_anim_info": 0x8040e450,
		"MoveBG::BrickBlock_map_collision_data": 0x8040e458,
		"BrickBlock_map_collision_data": 0x8040e458,
		"MoveBG::BrickBlock_map_collision_info": 0x8040e460,
		"BrickBlock_map_collision_info": 0x8040e460,
		"MoveBG::WaterMelonBlock_anim_info": 0x8040e468,
		"WaterMelonBlock_anim_info": 0x8040e468,
		"MoveBG::WaterMelonBlock_map_collision_data": 0x8040e470,
		"WaterMelonBlock_map_collision_data": 0x8040e470,
		"MoveBG::WaterMelonBlock_map_collision_info": 0x8040e478,
		"WaterMelonBlock_map_collision_info": 0x8040e478,
		"MoveBG::TelesaBlock_map_collision_data": 0x8040e480,
		"TelesaBlock_map_collision_data": 0x8040e480,
		"MoveBG::TelesaBlock_map_collision_info": 0x8040e488,
		"TelesaBlock_map_collision_info": 0x8040e488,
		"MoveBG::JuiceBlock_map_collision_data": 0x8040e490,
		"JuiceBlock_map_collision_data": 0x8040e490,
		"MoveBG::JuiceBlock_map_collision_info": 0x8040e498,
		"JuiceBlock_map_collision_info": 0x8040e498,
		"MoveBG::SuperHipDropBlock_anim_info": 0x8040e4a0,
		"SuperHipDropBlock_anim_info": 0x8040e4a0,
		"MoveBG::SuperHipDropBlock_map_collision_data": 0x8040e4a8,
		"SuperHipDropBlock_map_collision_data": 0x8040e4a8,
		"MoveBG::SuperHipDropBlock_map_collision_info": 0x8040e4b0,
		"SuperHipDropBlock_map_collision_info": 0x8040e4b0,
		"MoveBG::PalmNormal_anim_info": 0x8040e4b8,
		"PalmNormal_anim_info": 0x8040e4b8,
		"MoveBG::PalmNormalTree_map_collision_data": 0x8040e4c0,
		"PalmNormalTree_map_collision_data": 0x8040e4c0,
		"MoveBG::PalmNormalTree_map_collision_info": 0x8040e4c8,
		"PalmNormalTree_map_collision_info": 0x8040e4c8,
		"MoveBG::PalmOugiTree_map_collision_data": 0x8040e4d0,
		"PalmOugiTree_map_collision_data": 0x8040e4d0,
		"MoveBG::PalmOugiTree_map_collision_info": 0x8040e4d8,
		"PalmOugiTree_map_collision_info": 0x8040e4d8,
		"MoveBG::PalmSagoTree_map_collision_data": 0x8040e4e0,
		"PalmSagoTree_map_collision_data": 0x8040e4e0,
		"MoveBG::PalmSagoTree_map_collision_info": 0x8040e4e8,
		"PalmSagoTree_map_collision_info": 0x8040e4e8,
		"MoveBG::PalmNatumeTree_map_collision_data": 0x8040e4f0,
		"PalmNatumeTree_map_collision_data": 0x8040e4f0,
		"MoveBG::PalmNatumeTree_map_collision_info": 0x8040e4f8,
		"PalmNatumeTree_map_collision_info": 0x8040e4f8,
		"MoveBG::PalmLeaf_anim_info": 0x8040e500,
		"PalmLeaf_anim_info": 0x8040e500,
		"MoveBG::PalmLeafTree_map_collision_data": 0x8040e508,
		"PalmLeafTree_map_collision_data": 0x8040e508,
		"MoveBG::PalmLeafTree_map_collision_info": 0x8040e510,
		"PalmLeafTree_map_collision_info": 0x8040e510,
		"MoveBG::BananaTree_anim_info": 0x8040e518,
		"BananaTree_anim_info": 0x8040e518,
		"MoveBG::BananaTree_map_collision_data": 0x8040e520,
		"BananaTree_map_collision_data": 0x8040e520,
		"MoveBG::BananaTree_map_collision_info": 0x8040e528,
		"BananaTree_map_collision_info": 0x8040e528,
		"MoveBG::FruitTree_map_collision_data": 0x8040e530,
		"FruitTree_map_collision_data": 0x8040e530,
		"MoveBG::FruitTree_map_collision_info": 0x8040e538,
		"FruitTree_map_collision_info": 0x8040e538,
		"MoveBG::flowerOrange_anim_info": 0x8040e548,
		"flowerOrange_anim_info": 0x8040e548,
		"MoveBG::flowerPink_anim_info": 0x8040e550,
		"flowerPink_anim_info": 0x8040e550,
		"MoveBG::flowerPurple_anim_info": 0x8040e558,
		"flowerPurple_anim_info": 0x8040e558,
		"MoveBG::flowerRed_anim_info": 0x8040e560,
		"flowerRed_anim_info": 0x8040e560,
		"MoveBG::flowerYellow_anim_info": 0x8040e568,
		"flowerYellow_anim_info": 0x8040e568,
		"MoveBG::flowerSunflower_anim_info": 0x8040e570,
		"flowerSunflower_anim_info": 0x8040e570,
		"MoveBG::pole_sound_info": 0x8040e578,
		"pole_sound_info": 0x8040e578,
		"MoveBG::dptlight_anim_info": 0x8040e580,
		"dptlight_anim_info": 0x8040e580,
		"MoveBG::streetlamp_map_collision_info": 0x8040e588,
		"streetlamp_map_collision_info": 0x8040e588,
		"MoveBG::football_anim_info": 0x8040e590,
		"football_anim_info": 0x8040e590,
		"MoveBG::football_sound_info": 0x8040e598,
		"football_sound_info": 0x8040e598,
		"MoveBG::football_goal_anim_info": 0x8040e5a0,
		"football_goal_anim_info": 0x8040e5a0,
		"MoveBG::football_goal_map_collision_info": 0x8040e5a8,
		"football_goal_map_collision_info": 0x8040e5a8,
		"MoveBG::Watermelon_anim_info": 0x8040e5b0,
		"Watermelon_anim_info": 0x8040e5b0,
		"MoveBG::watermelon_sound_info": 0x8040e5b8,
		"watermelon_sound_info": 0x8040e5b8,
		"MoveBG::WatermelonStatic_anim_info": 0x8040e5c0,
		"WatermelonStatic_anim_info": 0x8040e5c0,
		"MoveBG::cloud_anim_info": 0x8040e5c8,
		"cloud_anim_info": 0x8040e5c8,
		"MoveBG::cloud_map_collision_data": 0x8040e5d8,
		"cloud_map_collision_data": 0x8040e5d8,
		"MoveBG::cloud_map_collision_info": 0x8040e5e0,
		"cloud_map_collision_info": 0x8040e5e0,
		"MoveBG::normallift_anim_info": 0x8040e5e8,
		"normallift_anim_info": 0x8040e5e8,
		"MoveBG::normallift_map_collision_data": 0x8040e5f0,
		"normallift_map_collision_data": 0x8040e5f0,
		"MoveBG::normallift_map_collision_info": 0x8040e5f8,
		"normallift_map_collision_info": 0x8040e5f8,
		"MoveBG::exrollcube_anim_info": 0x8040e600,
		"exrollcube_anim_info": 0x8040e600,
		"MoveBG::exrollcube_map_collision_data": 0x8040e608,
		"exrollcube_map_collision_data": 0x8040e608,
		"MoveBG::exrollcube_map_collision_info": 0x8040e610,
		"exrollcube_map_collision_info": 0x8040e610,
		"MoveBG::exkickboard_anim_info": 0x8040e618,
		"exkickboard_anim_info": 0x8040e618,
		"MoveBG::exkickboard_map_collision_data": 0x8040e620,
		"exkickboard_map_collision_data": 0x8040e620,
		"MoveBG::exkickboard_map_collision_info": 0x8040e628,
		"exkickboard_map_collision_info": 0x8040e628,
		"MoveBG::railblockr_anim_info": 0x8040e630,
		"railblockr_anim_info": 0x8040e630,
		"MoveBG::railblocky_anim_info": 0x8040e638,
		"railblocky_anim_info": 0x8040e638,
		"MoveBG::railblockb_anim_info": 0x8040e640,
		"railblockb_anim_info": 0x8040e640,
		"MoveBG::railblock_map_collision_data": 0x8040e648,
		"railblock_map_collision_data": 0x8040e648,
		"MoveBG::railblock_map_collision_info": 0x8040e650,
		"railblock_map_collision_info": 0x8040e650,
		"MoveBG::umaibou_anim_info": 0x8040e658,
		"umaibou_anim_info": 0x8040e658,
		"MoveBG::umaibou_map_collision_data": 0x8040e668,
		"umaibou_map_collision_data": 0x8040e668,
		"MoveBG::umaibou_map_collision_info": 0x8040e670,
		"umaibou_map_collision_info": 0x8040e670,
		"MoveBG::kamaboko_anim_info": 0x8040e678,
		"kamaboko_anim_info": 0x8040e678,
		"MoveBG::kamaboko_map_collision_data": 0x8040e680,
		"kamaboko_map_collision_data": 0x8040e680,
		"MoveBG::kamaboko_map_collision_info": 0x8040e688,
		"kamaboko_map_collision_info": 0x8040e688,
		"MoveBG::getag_anim_info": 0x8040e690,
		"getag_anim_info": 0x8040e690,
		"MoveBG::getao_anim_info": 0x8040e698,
		"getao_anim_info": 0x8040e698,
		"MoveBG::geta_map_collision_data": 0x8040e6a8,
		"geta_map_collision_data": 0x8040e6a8,
		"MoveBG::geta_map_collision_info": 0x8040e6b0,
		"geta_map_collision_info": 0x8040e6b0,
		"MoveBG::uirou_anim_info": 0x8040e6c8,
		"uirou_anim_info": 0x8040e6c8,
		"MoveBG::uirou_map_collision_data": 0x8040e6d8,
		"uirou_map_collision_data": 0x8040e6d8,
		"MoveBG::uirou_map_collision_info": 0x8040e6e0,
		"uirou_map_collision_info": 0x8040e6e0,
		"MoveBG::hikidashi_anim_info": 0x8040e6e8,
		"hikidashi_anim_info": 0x8040e6e8,
		"MoveBG::hikidashi_map_collision_data": 0x8040e6f0,
		"hikidashi_map_collision_data": 0x8040e6f0,
		"MoveBG::hikidashi_map_collision_info": 0x8040e6f8,
		"hikidashi_map_collision_info": 0x8040e6f8,
		"MoveBG::castella_anim_info": 0x8040e700,
		"castella_anim_info": 0x8040e700,
		"MoveBG::castella_map_collision_data": 0x8040e708,
		"castella_map_collision_data": 0x8040e708,
		"MoveBG::castella_map_collision_info": 0x8040e710,
		"castella_map_collision_info": 0x8040e710,
		"MoveBG::yoshiblock_anim_info": 0x8040e718,
		"yoshiblock_anim_info": 0x8040e718,
		"MoveBG::yoshiblock_map_collision_data": 0x8040e720,
		"yoshiblock_map_collision_data": 0x8040e720,
		"MoveBG::yoshiblock_map_collision_info": 0x8040e728,
		"yoshiblock_map_collision_info": 0x8040e728,
		"MoveBG::WoodBlockTriangle_map_collision_data": 0x8040e730,
		"WoodBlockTriangle_map_collision_data": 0x8040e730,
		"MoveBG::WoodBlockTriangle_map_collision_info": 0x8040e738,
		"WoodBlockTriangle_map_collision_info": 0x8040e738,
		"MoveBG::WoodBlockPyramid_map_collision_data": 0x8040e740,
		"WoodBlockPyramid_map_collision_data": 0x8040e740,
		"MoveBG::WoodBlockPyramid_map_collision_info": 0x8040e748,
		"WoodBlockPyramid_map_collision_info": 0x8040e748,
		"MoveBG::WoodBlockLong_map_collision_data": 0x8040e750,
		"WoodBlockLong_map_collision_data": 0x8040e750,
		"MoveBG::WoodBlockLong_map_collision_info": 0x8040e758,
		"WoodBlockLong_map_collision_info": 0x8040e758,
		"MoveBG::WoodBlockLarge_map_collision_data": 0x8040e760,
		"WoodBlockLarge_map_collision_data": 0x8040e760,
		"MoveBG::WoodBlockLarge_map_collision_info": 0x8040e768,
		"WoodBlockLarge_map_collision_info": 0x8040e768,
		"MoveBG::WoodBlockCone_map_collision_data": 0x8040e770,
		"WoodBlockCone_map_collision_data": 0x8040e770,
		"MoveBG::WoodBlockCone_map_collision_info": 0x8040e778,
		"WoodBlockCone_map_collision_info": 0x8040e778,
		"MoveBG::WoodBlockL_map_collision_data": 0x8040e780,
		"WoodBlockL_map_collision_data": 0x8040e780,
		"MoveBG::WoodBlockL_map_collision_info": 0x8040e788,
		"WoodBlockL_map_collision_info": 0x8040e788,
		"MoveBG::WoodBlockBridge_map_collision_data": 0x8040e790,
		"WoodBlockBridge_map_collision_data": 0x8040e790,
		"MoveBG::WoodBlockBridge_map_collision_info": 0x8040e798,
		"WoodBlockBridge_map_collision_info": 0x8040e798,
		"MoveBG::WoodBlockCube_map_collision_data": 0x8040e7a0,
		"WoodBlockCube_map_collision_data": 0x8040e7a0,
		"MoveBG::WoodBlockCube_map_collision_info": 0x8040e7a8,
		"WoodBlockCube_map_collision_info": 0x8040e7a8,
		"MoveBG::normalvariant0_map_collision_data": 0x8040e7b0,
		"normalvariant0_map_collision_data": 0x8040e7b0,
		"MoveBG::normalvariant0_map_collision_info": 0x8040e7b8,
		"normalvariant0_map_collision_info": 0x8040e7b8,
		"MoveBG::normalvariant1_map_collision_data": 0x8040e7c0,
		"normalvariant1_map_collision_data": 0x8040e7c0,
		"MoveBG::normalvariant1_map_collision_info": 0x8040e7c8,
		"normalvariant1_map_collision_info": 0x8040e7c8,
		"MoveBG::normalvariant2_map_collision_data": 0x8040e7d0,
		"normalvariant2_map_collision_data": 0x8040e7d0,
		"MoveBG::normalvariant2_map_collision_info": 0x8040e7d8,
		"normalvariant2_map_collision_info": 0x8040e7d8,
		"MoveBG::normalvariant3_map_collision_data": 0x8040e7e0,
		"normalvariant3_map_collision_data": 0x8040e7e0,
		"MoveBG::normalvariant3_map_collision_info": 0x8040e7e8,
		"normalvariant3_map_collision_info": 0x8040e7e8,
		"MoveBG::normalvariant4_map_collision_data": 0x8040e7f0,
		"normalvariant4_map_collision_data": 0x8040e7f0,
		"MoveBG::normalvariant4_map_collision_info": 0x8040e7f8,
		"normalvariant4_map_collision_info": 0x8040e7f8,
		"MoveBG::railvariant0_map_collision_data": 0x8040e800,
		"railvariant0_map_collision_data": 0x8040e800,
		"MoveBG::railvariant0_map_collision_info": 0x8040e808,
		"railvariant0_map_collision_info": 0x8040e808,
		"MoveBG::railvariant1_map_collision_data": 0x8040e810,
		"railvariant1_map_collision_data": 0x8040e810,
		"MoveBG::railvariant1_map_collision_info": 0x8040e818,
		"railvariant1_map_collision_info": 0x8040e818,
		"MoveBG::railvariant2_map_collision_data": 0x8040e820,
		"railvariant2_map_collision_data": 0x8040e820,
		"MoveBG::railvariant2_map_collision_info": 0x8040e828,
		"railvariant2_map_collision_info": 0x8040e828,
		"MoveBG::railvariant3_map_collision_data": 0x8040e830,
		"railvariant3_map_collision_data": 0x8040e830,
		"MoveBG::railvariant3_map_collision_info": 0x8040e838,
		"railvariant3_map_collision_info": 0x8040e838,
		"MoveBG::railvariant4_map_collision_data": 0x8040e840,
		"railvariant4_map_collision_data": 0x8040e840,
		"MoveBG::railvariant4_map_collision_info": 0x8040e848,
		"railvariant4_map_collision_info": 0x8040e848,
		"MoveBG::rollvariant0_map_collision_data": 0x8040e850,
		"rollvariant0_map_collision_data": 0x8040e850,
		"MoveBG::rollvariant0_map_collision_info": 0x8040e858,
		"rollvariant0_map_collision_info": 0x8040e858,
		"MoveBG::rollvariant1_map_collision_data": 0x8040e860,
		"rollvariant1_map_collision_data": 0x8040e860,
		"MoveBG::rollvariant1_map_collision_info": 0x8040e868,
		"rollvariant1_map_collision_info": 0x8040e868,
		"MoveBG::rollvariant2_map_collision_data": 0x8040e870,
		"rollvariant2_map_collision_data": 0x8040e870,
		"MoveBG::rollvariant2_map_collision_info": 0x8040e878,
		"rollvariant2_map_collision_info": 0x8040e878,
		"MoveBG::rollvariant3_map_collision_data": 0x8040e880,
		"rollvariant3_map_collision_data": 0x8040e880,
		"MoveBG::rollvariant3_map_collision_info": 0x8040e888,
		"rollvariant3_map_collision_info": 0x8040e888,
		"MoveBG::rollvariant4_map_collision_data": 0x8040e890,
		"rollvariant4_map_collision_data": 0x8040e890,
		"MoveBG::rollvariant4_map_collision_info": 0x8040e898,
		"rollvariant4_map_collision_info": 0x8040e898,
		"MoveBG::lamptrapspike_anim_info": 0x8040e8a0,
		"lamptrapspike_anim_info": 0x8040e8a0,
		"MoveBG::lamptrapiron_anim_info": 0x8040e8a8,
		"lamptrapiron_anim_info": 0x8040e8a8,
		"MoveBG::lamptrap_map_collision_data": 0x8040e8b0,
		"lamptrap_map_collision_data": 0x8040e8b0,
		"MoveBG::lamptrap_map_collision_info": 0x8040e8b8,
		"lamptrap_map_collision_info": 0x8040e8b8,
		"MoveBG::airplane_map_collision_data": 0x8040e8c0,
		"airplane_map_collision_data": 0x8040e8c0,
		"MoveBG::airplane_map_collision_info": 0x8040e8c8,
		"airplane_map_collision_info": 0x8040e8c8,
		"MoveBG::WoodBox_anim_info": 0x8040e8d0,
		"WoodBox_anim_info": 0x8040e8d0,
		"MoveBG::WoodBoxNozzle_map_collision_data": 0x8040e8e0,
		"WoodBoxNozzle_map_collision_data": 0x8040e8e0,
		"MoveBG::WoodBoxNozzle_map_collision_info": 0x8040e8e8,
		"WoodBoxNozzle_map_collision_info": 0x8040e8e8,
		"MoveBG::ice_car_anim_info": 0x8040e8f8,
		"ice_car_anim_info": 0x8040e8f8,
		"MoveBG::ice_car_map_collision_data": 0x8040e908,
		"ice_car_map_collision_data": 0x8040e908,
		"MoveBG::ice_car_map_collision_info": 0x8040e910,
		"ice_car_map_collision_info": 0x8040e910,
		"MoveBG::move_ice_car_map_collision_data": 0x8040e920,
		"move_ice_car_map_collision_data": 0x8040e920,
		"MoveBG::move_ice_car_map_collision_info": 0x8040e928,
		"move_ice_car_map_collision_info": 0x8040e928,
		"MoveBG::@3098": 0x8040e930,
		"MoveBG::AirportBuoy_map_collision_data": 0x8040e938,
		"AirportBuoy_map_collision_data": 0x8040e938,
		"MoveBG::AirportBuoy_map_collision_info": 0x8040e940,
		"AirportBuoy_map_collision_info": 0x8040e940,
		"MoveBG::dptKing_map_collision_info": 0x8040e950,
		"dptKing_map_collision_info": 0x8040e950,
		"MoveBG::KoopaJrSubmarine_map_collision_data": 0x8040e958,
		"KoopaJrSubmarine_map_collision_data": 0x8040e958,
		"MoveBG::KoopaJrSubmarine_map_collision_info": 0x8040e960,
		"KoopaJrSubmarine_map_collision_info": 0x8040e960,
		"MoveBG::monumentshine_anim_info": 0x8040e968,
		"monumentshine_anim_info": 0x8040e968,
		"MoveBG::belldolpic_anim_info": 0x8040e970,
		"belldolpic_anim_info": 0x8040e970,
		"MoveBG::DptWeathercock_anim_info": 0x8040e978,
		"DptWeathercock_anim_info": 0x8040e978,
		"MoveBG::DptMonteFence_map_collision_data": 0x8040e980,
		"DptMonteFence_map_collision_data": 0x8040e980,
		"MoveBG::DptMonteFence_map_collision_info": 0x8040e988,
		"DptMonteFence_map_collision_info": 0x8040e988,
		"MoveBG::DptCoronaFence_map_collision_data": 0x8040e990,
		"DptCoronaFence_map_collision_data": 0x8040e990,
		"MoveBG::DptCoronaFence_map_collision_info": 0x8040e998,
		"DptCoronaFence_map_collision_info": 0x8040e998,
		"MoveBG::MareGate_anim_info": 0x8040e9a0,
		"MareGate_anim_info": 0x8040e9a0,
		"MoveBG::NozzleDoor_anim_info": 0x8040e9a8,
		"NozzleDoor_anim_info": 0x8040e9a8,
		"MoveBG::NozzleDoor_map_collision_data": 0x8040e9b0,
		"NozzleDoor_map_collision_data": 0x8040e9b0,
		"MoveBG::NozzleDoor_map_collision_info": 0x8040e9b8,
		"NozzleDoor_map_collision_info": 0x8040e9b8,
		"MoveBG::DokanGate_anim_info": 0x8040e9c0,
		"DokanGate_anim_info": 0x8040e9c0,
		"MoveBG::@3121": 0x8040e9c8,
		"MoveBG::crane_map_collision_data": 0x8040e9d0,
		"crane_map_collision_data": 0x8040e9d0,
		"MoveBG::crane_map_collision_info": 0x8040e9d8,
		"crane_map_collision_info": 0x8040e9d8,
		"MoveBG::crane90Scene2_map_collision_data": 0x8040e9e0,
		"crane90Scene2_map_collision_data": 0x8040e9e0,
		"MoveBG::crane90Scene2_map_collision_info": 0x8040e9e8,
		"crane90Scene2_map_collision_info": 0x8040e9e8,
		"MoveBG::crane180Scene1_map_collision_data": 0x8040e9f0,
		"crane180Scene1_map_collision_data": 0x8040e9f0,
		"MoveBG::crane180Scene1_map_collision_info": 0x8040e9f8,
		"crane180Scene1_map_collision_info": 0x8040e9f8,
		"MoveBG::crane_updown_map_collision_data": 0x8040ea00,
		"crane_updown_map_collision_data": 0x8040ea00,
		"MoveBG::crane_updown_map_collision_info": 0x8040ea08,
		"crane_updown_map_collision_info": 0x8040ea08,
		"MoveBG::crane_cargo_map_collision_data": 0x8040ea10,
		"crane_cargo_map_collision_data": 0x8040ea10,
		"MoveBG::crane_cargo_map_collision_info": 0x8040ea18,
		"crane_cargo_map_collision_info": 0x8040ea18,
		"MoveBG::tank_map_collision_data": 0x8040ea28,
		"tank_map_collision_data": 0x8040ea28,
		"MoveBG::tank_map_collision_info": 0x8040ea30,
		"tank_map_collision_info": 0x8040ea30,
		"MoveBG::container_map_collision_data": 0x8040ea38,
		"container_map_collision_data": 0x8040ea38,
		"MoveBG::container_map_collision_info": 0x8040ea40,
		"container_map_collision_info": 0x8040ea40,
		"MoveBG::submarine_map_collision_info": 0x8040ea48,
		"submarine_map_collision_info": 0x8040ea48,
		"MoveBG::riccoShip_map_collision_data": 0x8040ea50,
		"riccoShip_map_collision_data": 0x8040ea50,
		"MoveBG::riccoShip_map_collision_info": 0x8040ea58,
		"riccoShip_map_collision_info": 0x8040ea58,
		"MoveBG::riccoLog_map_collision_data": 0x8040ea60,
		"riccoLog_map_collision_data": 0x8040ea60,
		"MoveBG::riccoLog_map_collision_info": 0x8040ea68,
		"riccoLog_map_collision_info": 0x8040ea68,
		"MoveBG::gesoSurfboard_anim_info": 0x8040ea70,
		"gesoSurfboard_anim_info": 0x8040ea70,
		"MoveBG::riccoShipLog_map_collision_data": 0x8040ea78,
		"riccoShipLog_map_collision_data": 0x8040ea78,
		"MoveBG::riccoShipLog_map_collision_info": 0x8040ea80,
		"riccoShipLog_map_collision_info": 0x8040ea80,
		"MoveBG::riccoShipDol_map_collision_data": 0x8040ea88,
		"riccoShipDol_map_collision_data": 0x8040ea88,
		"MoveBG::riccoShipDol_map_collision_info": 0x8040ea90,
		"riccoShipDol_map_collision_info": 0x8040ea90,
		"MoveBG::riccoYachtL_map_collision_data": 0x8040ea98,
		"riccoYachtL_map_collision_data": 0x8040ea98,
		"MoveBG::riccoYachtL_map_collision_info": 0x8040eaa0,
		"riccoYachtL_map_collision_info": 0x8040eaa0,
		"MoveBG::riccoYachtS_map_collision_data": 0x8040eaa8,
		"riccoYachtS_map_collision_data": 0x8040eaa8,
		"MoveBG::riccoYachtS_map_collision_info": 0x8040eab0,
		"riccoYachtS_map_collision_info": 0x8040eab0,
		"MoveBG::riccoBoatL_map_collision_data": 0x8040eab8,
		"riccoBoatL_map_collision_data": 0x8040eab8,
		"MoveBG::riccoBoatL_map_collision_info": 0x8040eac0,
		"riccoBoatL_map_collision_info": 0x8040eac0,
		"MoveBG::riccoBoatS_map_collision_data": 0x8040eac8,
		"riccoBoatS_map_collision_data": 0x8040eac8,
		"MoveBG::riccoBoatS_map_collision_info": 0x8040ead0,
		"riccoBoatS_map_collision_info": 0x8040ead0,
		"MoveBG::riccoBasket_map_collision_data": 0x8040ead8,
		"riccoBasket_map_collision_data": 0x8040ead8,
		"MoveBG::riccoBasket_map_collision_info": 0x8040eae0,
		"riccoBasket_map_collision_info": 0x8040eae0,
		"MoveBG::riccoGangway_map_collision_data": 0x8040eae8,
		"riccoGangway_map_collision_data": 0x8040eae8,
		"MoveBG::riccoGangway_map_collision_info": 0x8040eaf0,
		"riccoGangway_map_collision_info": 0x8040eaf0,
		"MoveBG::riccoShipFish_map_collision_data": 0x8040eaf8,
		"riccoShipFish_map_collision_data": 0x8040eaf8,
		"MoveBG::riccoShipFish_map_collision_info": 0x8040eb00,
		"riccoShipFish_map_collision_info": 0x8040eb00,
		"MoveBG::riccoShipGeso_map_collision_data": 0x8040eb08,
		"riccoShipGeso_map_collision_data": 0x8040eb08,
		"MoveBG::riccoShipGeso_map_collision_info": 0x8040eb10,
		"riccoShipGeso_map_collision_info": 0x8040eb10,
		"MoveBG::riccoSwitch_map_collision_data": 0x8040eb18,
		"riccoSwitch_map_collision_data": 0x8040eb18,
		"MoveBG::riccoSwitch_map_collision_info": 0x8040eb20,
		"riccoSwitch_map_collision_info": 0x8040eb20,
		"MoveBG::riccoFenceMaze_map_collision_data": 0x8040eb28,
		"riccoFenceMaze_map_collision_data": 0x8040eb28,
		"MoveBG::riccoFenceMaze_map_collision_info": 0x8040eb30,
		"riccoFenceMaze_map_collision_info": 0x8040eb30,
		"MoveBG::riccoStand_map_collision_data": 0x8040eb38,
		"riccoStand_map_collision_data": 0x8040eb38,
		"MoveBG::riccoStand_map_collision_info": 0x8040eb40,
		"riccoStand_map_collision_info": 0x8040eb40,
		"MoveBG::riccoGrille_map_collision_data": 0x8040eb48,
		"riccoGrille_map_collision_data": 0x8040eb48,
		"MoveBG::riccoGrille_map_collision_info": 0x8040eb50,
		"riccoGrille_map_collision_info": 0x8040eb50,
		"MoveBG::riccoArrow_map_collision_data": 0x8040eb58,
		"riccoArrow_map_collision_data": 0x8040eb58,
		"MoveBG::riccoArrow_map_collision_info": 0x8040eb60,
		"riccoArrow_map_collision_info": 0x8040eb60,
		"MoveBG::riccoStreetStall_map_collision_data": 0x8040eb68,
		"riccoStreetStall_map_collision_data": 0x8040eb68,
		"MoveBG::riccoStreetStall_map_collision_info": 0x8040eb70,
		"riccoStreetStall_map_collision_info": 0x8040eb70,
		"MoveBG::riccoHericopter_map_collision_data": 0x8040eb78,
		"riccoHericopter_map_collision_data": 0x8040eb78,
		"MoveBG::riccoHericopter_map_collision_info": 0x8040eb80,
		"riccoHericopter_map_collision_info": 0x8040eb80,
		"MoveBG::windmill_anim_info": 0x8040eb88,
		"windmill_anim_info": 0x8040eb88,
		"MoveBG::windmill_map_collision_data": 0x8040eb90,
		"windmill_map_collision_data": 0x8040eb90,
		"MoveBG::windmill_map_collision_info": 0x8040eb98,
		"windmill_map_collision_info": 0x8040eb98,
		"MoveBG::MiniWindmillL_map_collision_data": 0x8040eba0,
		"MiniWindmillL_map_collision_data": 0x8040eba0,
		"MoveBG::MiniWindmillL_map_collision_info": 0x8040eba8,
		"MiniWindmillL_map_collision_info": 0x8040eba8,
		"MoveBG::MiniWindmillS_map_collision_data": 0x8040ebb0,
		"MiniWindmillS_map_collision_data": 0x8040ebb0,
		"MoveBG::MiniWindmillS_map_collision_info": 0x8040ebb8,
		"MiniWindmillS_map_collision_info": 0x8040ebb8,
		"MoveBG::windmill_roof_map_collision_data": 0x8040ebc0,
		"windmill_roof_map_collision_data": 0x8040ebc0,
		"MoveBG::windmill_roof_map_collision_info": 0x8040ebc8,
		"windmill_roof_map_collision_info": 0x8040ebc8,
		"MoveBG::lamp_bianco_anim_info": 0x8040ebd0,
		"lamp_bianco_anim_info": 0x8040ebd0,
		"MoveBG::lamp_bianco_map_collision_info": 0x8040ebd8,
		"lamp_bianco_map_collision_info": 0x8040ebd8,
		"MoveBG::RootPakkun_map_collision_data": 0x8040ebe0,
		"RootPakkun_map_collision_data": 0x8040ebe0,
		"MoveBG::RootPakkun_map_collision_info": 0x8040ebe8,
		"RootPakkun_map_collision_info": 0x8040ebe8,
		"MoveBG::windmill_block_map_collision_data": 0x8040ebf0,
		"windmill_block_map_collision_data": 0x8040ebf0,
		"MoveBG::windmill_block_map_collision_info": 0x8040ebf8,
		"windmill_block_map_collision_info": 0x8040ebf8,
		"MoveBG::BiaBell_anim_info": 0x8040ec00,
		"BiaBell_anim_info": 0x8040ec00,
		"MoveBG::watermill00_anim_info": 0x8040ec10,
		"watermill00_anim_info": 0x8040ec10,
		"MoveBG::BiaWatermill01_map_collision_data": 0x8040ec18,
		"BiaWatermill01_map_collision_data": 0x8040ec18,
		"MoveBG::BiaWatermill01_map_collision_info": 0x8040ec20,
		"BiaWatermill01_map_collision_info": 0x8040ec20,
		"MoveBG::BiaWatermillVertical_map_collision_data": 0x8040ec28,
		"BiaWatermillVertical_map_collision_data": 0x8040ec28,
		"MoveBG::BiaWatermillVertical_map_collision_info": 0x8040ec30,
		"BiaWatermillVertical_map_collision_info": 0x8040ec30,
		"MoveBG::BiaTurnBridge_map_collision_data": 0x8040ec38,
		"BiaTurnBridge_map_collision_data": 0x8040ec38,
		"MoveBG::BiaTurnBridge_map_collision_info": 0x8040ec40,
		"BiaTurnBridge_map_collision_info": 0x8040ec40,
		"MoveBG::LeafBoat_map_collision_data": 0x8040ec48,
		"LeafBoat_map_collision_data": 0x8040ec48,
		"MoveBG::LeafBoat_map_collision_info": 0x8040ec50,
		"LeafBoat_map_collision_info": 0x8040ec50,
		"MoveBG::LampSeesaw_anim_info": 0x8040ec58,
		"LampSeesaw_anim_info": 0x8040ec58,
		"MoveBG::LampSeesaw_map_collision_data": 0x8040ec60,
		"LampSeesaw_map_collision_data": 0x8040ec60,
		"MoveBG::LampSeesaw_map_collision_info": 0x8040ec68,
		"LampSeesaw_map_collision_info": 0x8040ec68,
		"MoveBG::BiancoDoor_map_collision_data": 0x8040ec78,
		"BiancoDoor_map_collision_data": 0x8040ec78,
		"MoveBG::BiancoDoor_map_collision_info": 0x8040ec80,
		"BiancoDoor_map_collision_info": 0x8040ec80,
		"MoveBG::BiaBridge_map_collision_data": 0x8040ec88,
		"BiaBridge_map_collision_data": 0x8040ec88,
		"MoveBG::BiaBridge_map_collision_info": 0x8040ec90,
		"BiaBridge_map_collision_info": 0x8040ec90,
		"MoveBG::SandBird_anim_info": 0x8040ec98,
		"SandBird_anim_info": 0x8040ec98,
		"MoveBG::SandBirdBlock_map_collision_info": 0x8040eca0,
		"SandBirdBlock_map_collision_info": 0x8040eca0,
		"MoveBG::SkyIsland_anim_info": 0x8040eca8,
		"SkyIsland_anim_info": 0x8040eca8,
		"MoveBG::SkyIsland_map_collision_data": 0x8040ecb0,
		"SkyIsland_map_collision_data": 0x8040ecb0,
		"MoveBG::SkyIsland_map_collision_info": 0x8040ecb8,
		"SkyIsland_map_collision_info": 0x8040ecb8,
		"MoveBG::SandLeaf_anim_info": 0x8040ecc0,
		"SandLeaf_anim_info": 0x8040ecc0,
		"MoveBG::SandLeafBase00_anim_info": 0x8040ecc8,
		"SandLeafBase00_anim_info": 0x8040ecc8,
		"MoveBG::SandLeafBase00_map_collision_info": 0x8040ecd0,
		"SandLeafBase00_map_collision_info": 0x8040ecd0,
		"MoveBG::SandLeafBase01_anim_info": 0x8040ecd8,
		"SandLeafBase01_anim_info": 0x8040ecd8,
		"MoveBG::SandLeafBase01_map_collision_info": 0x8040ece0,
		"SandLeafBase01_map_collision_info": 0x8040ece0,
		"MoveBG::SandLeafBase02_anim_info": 0x8040ece8,
		"SandLeafBase02_anim_info": 0x8040ece8,
		"MoveBG::SandLeafBase02_map_collision_info": 0x8040ecf0,
		"SandLeafBase02_map_collision_info": 0x8040ecf0,
		"MoveBG::SandLeafBase03_anim_info": 0x8040ecf8,
		"SandLeafBase03_anim_info": 0x8040ecf8,
		"MoveBG::SandLeafBase03_map_collision_info": 0x8040ed00,
		"SandLeafBase03_map_collision_info": 0x8040ed00,
		"MoveBG::SandBomb_anim_info": 0x8040ed08,
		"SandBomb_anim_info": 0x8040ed08,
		"MoveBG::mirror_L_map_collision_info": 0x8040ed18,
		"mirror_L_map_collision_info": 0x8040ed18,
		"MoveBG::mirror_M_map_collision_info": 0x8040ed28,
		"mirror_M_map_collision_info": 0x8040ed28,
		"MoveBG::mirrorS_map_collision_info": 0x8040ed38,
		"mirrorS_map_collision_info": 0x8040ed38,
		"MoveBG::SandCastle_anim_info": 0x8040ed40,
		"SandCastle_anim_info": 0x8040ed40,
		"MoveBG::SandCastle_map_collision_info": 0x8040ed48,
		"SandCastle_map_collision_info": 0x8040ed48,
		"MoveBG::MammaBlockRotate_map_collision_info": 0x8040ed50,
		"MammaBlockRotate_map_collision_info": 0x8040ed50,
		"MoveBG::SandEgg_map_collision_data": 0x8040ed58,
		"SandEgg_map_collision_data": 0x8040ed58,
		"MoveBG::SandEgg_map_collision_info": 0x8040ed60,
		"SandEgg_map_collision_info": 0x8040ed60,
		"MoveBG::SandEggBroken_map_collision_data": 0x8040ed68,
		"SandEggBroken_map_collision_data": 0x8040ed68,
		"MoveBG::SandEggBroken_map_collision_info": 0x8040ed70,
		"SandEggBroken_map_collision_info": 0x8040ed70,
		"MoveBG::MammaSurfboardStand_map_collision_data": 0x8040ed78,
		"MammaSurfboardStand_map_collision_data": 0x8040ed78,
		"MoveBG::MammaSurfboardStand_map_collision_info": 0x8040ed80,
		"MammaSurfboardStand_map_collision_info": 0x8040ed80,
		"MoveBG::MammaYacht00_map_collision_data": 0x8040ed88,
		"MammaYacht00_map_collision_data": 0x8040ed88,
		"MoveBG::MammaYacht00_map_collision_info": 0x8040ed90,
		"MammaYacht00_map_collision_info": 0x8040ed90,
		"MoveBG::MammaYacht01_map_collision_data": 0x8040ed98,
		"MammaYacht01_map_collision_data": 0x8040ed98,
		"MoveBG::MammaYacht01_map_collision_info": 0x8040eda0,
		"MammaYacht01_map_collision_info": 0x8040eda0,
		"MoveBG::MammaYacht02_map_collision_data": 0x8040eda8,
		"MammaYacht02_map_collision_data": 0x8040eda8,
		"MoveBG::MammaYacht02_map_collision_info": 0x8040edb0,
		"MammaYacht02_map_collision_info": 0x8040edb0,
		"MoveBG::SandBombBase00_anim_info": 0x8040edb8,
		"SandBombBase00_anim_info": 0x8040edb8,
		"MoveBG::SandBombBase00_map_collision_info": 0x8040edc0,
		"SandBombBase00_map_collision_info": 0x8040edc0,
		"MoveBG::SandBombBaseMushroom_anim_info": 0x8040edc8,
		"SandBombBaseMushroom_anim_info": 0x8040edc8,
		"MoveBG::SandBombBaseMushroom_map_collision_info": 0x8040edd0,
		"SandBombBaseMushroom_map_collision_info": 0x8040edd0,
		"MoveBG::SandBombBasePyramid_anim_info": 0x8040edd8,
		"SandBombBasePyramid_anim_info": 0x8040edd8,
		"MoveBG::SandBombBasePyramid_map_collision_info": 0x8040ede0,
		"SandBombBasePyramid_map_collision_info": 0x8040ede0,
		"MoveBG::SandBombBaseShit_anim_info": 0x8040ede8,
		"SandBombBaseShit_anim_info": 0x8040ede8,
		"MoveBG::SandBombBaseShit_map_collision_info": 0x8040edf0,
		"SandBombBaseShit_map_collision_info": 0x8040edf0,
		"MoveBG::SandBombBaseStar_anim_info": 0x8040edf8,
		"SandBombBaseStar_anim_info": 0x8040edf8,
		"MoveBG::SandBombBaseStar_map_collision_info": 0x8040ee00,
		"SandBombBaseStar_map_collision_info": 0x8040ee00,
		"MoveBG::SandBombBaseTurtle_anim_info": 0x8040ee08,
		"SandBombBaseTurtle_anim_info": 0x8040ee08,
		"MoveBG::SandBombBaseTurtle_map_collision_info": 0x8040ee10,
		"SandBombBaseTurtle_map_collision_info": 0x8040ee10,
		"MoveBG::SandBombBaseFoot_anim_info": 0x8040ee18,
		"SandBombBaseFoot_anim_info": 0x8040ee18,
		"MoveBG::SandBombBaseFoot_map_collision_info": 0x8040ee20,
		"SandBombBaseFoot_map_collision_info": 0x8040ee20,
		"MoveBG::SandBombBaseHand_anim_info": 0x8040ee28,
		"SandBombBaseHand_anim_info": 0x8040ee28,
		"MoveBG::SandBombBaseHand_map_collision_info": 0x8040ee30,
		"SandBombBaseHand_map_collision_info": 0x8040ee30,
		"MoveBG::SandBombBaseStairs_anim_info": 0x8040ee38,
		"SandBombBaseStairs_anim_info": 0x8040ee38,
		"MoveBG::SandBombBaseStairs_map_collision_info": 0x8040ee40,
		"SandBombBaseStairs_map_collision_info": 0x8040ee40,
		"MoveBG::TeethOfJuicer_anim_info": 0x8040ee58,
		"TeethOfJuicer_anim_info": 0x8040ee58,
		"MoveBG::SandEggRepair_map_collision_data": 0x8040ee60,
		"SandEggRepair_map_collision_data": 0x8040ee60,
		"MoveBG::SandEggRepair_map_collision_info": 0x8040ee68,
		"SandEggRepair_map_collision_info": 0x8040ee68,
		"MoveBG::merrygoround_anim_info": 0x8040ee78,
		"merrygoround_anim_info": 0x8040ee78,
		"MoveBG::merrygoround_map_collision_data": 0x8040ee80,
		"merrygoround_map_collision_data": 0x8040ee80,
		"MoveBG::merrygoround_map_collision_info": 0x8040ee88,
		"merrygoround_map_collision_info": 0x8040ee88,
		"MoveBG::merry_egg_map_collision_data": 0x8040ee90,
		"merry_egg_map_collision_data": 0x8040ee90,
		"MoveBG::merry_egg_map_collision_info": 0x8040ee98,
		"merry_egg_map_collision_info": 0x8040ee98,
		"MoveBG::FerrisWheel_anim_info": 0x8040eea0,
		"FerrisWheel_anim_info": 0x8040eea0,
		"MoveBG::gondola_map_collision_data": 0x8040eea8,
		"gondola_map_collision_data": 0x8040eea8,
		"MoveBG::gondola_map_collision_info": 0x8040eeb0,
		"gondola_map_collision_info": 0x8040eeb0,
		"MoveBG::FerrisLOD_anim_info": 0x8040eeb8,
		"FerrisLOD_anim_info": 0x8040eeb8,
		"MoveBG::viking_map_collision_data": 0x8040eec8,
		"viking_map_collision_data": 0x8040eec8,
		"MoveBG::viking_map_collision_info": 0x8040eed0,
		"viking_map_collision_info": 0x8040eed0,
		"MoveBG::PinnaEntrance_map_collision_data": 0x8040eed8,
		"PinnaEntrance_map_collision_data": 0x8040eed8,
		"MoveBG::PinnaEntrance_map_collision_info": 0x8040eee0,
		"PinnaEntrance_map_collision_info": 0x8040eee0,
		"MoveBG::PinnaEntranceOpen_map_collision_data": 0x8040eee8,
		"PinnaEntranceOpen_map_collision_data": 0x8040eee8,
		"MoveBG::PinnaEntranceOpen_map_collision_info": 0x8040eef0,
		"PinnaEntranceOpen_map_collision_info": 0x8040eef0,
		"MoveBG::SirenaGate_map_collision_data": 0x8040eef8,
		"SirenaGate_map_collision_data": 0x8040eef8,
		"MoveBG::SirenaGate_map_collision_info": 0x8040ef00,
		"SirenaGate_map_collision_info": 0x8040ef00,
		"MoveBG::balloon_koopajr_anim_info": 0x8040ef08,
		"balloon_koopajr_anim_info": 0x8040ef08,
		"MoveBG::ShellCup_anim_info": 0x8040ef10,
		"ShellCup_anim_info": 0x8040ef10,
		"MoveBG::ShellCup_map_collision_data": 0x8040ef18,
		"ShellCup_map_collision_data": 0x8040ef18,
		"MoveBG::ShellCup_map_collision_info": 0x8040ef20,
		"ShellCup_map_collision_info": 0x8040ef20,
		"MoveBG::Gateshell_anim_info": 0x8040ef28,
		"Gateshell_anim_info": 0x8040ef28,
		"MoveBG::Gateshell_map_collision_data": 0x8040ef30,
		"Gateshell_map_collision_data": 0x8040ef30,
		"MoveBG::Gateshell_map_collision_info": 0x8040ef38,
		"Gateshell_map_collision_info": 0x8040ef38,
		"MoveBG::PinnaHangingBridgeBoard_anim_info": 0x8040ef40,
		"PinnaHangingBridgeBoard_anim_info": 0x8040ef40,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_data": 0x8040ef48,
		"PinnaHangingBridgeBoard_map_collision_data": 0x8040ef48,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_info": 0x8040ef50,
		"PinnaHangingBridgeBoard_map_collision_info": 0x8040ef50,
		"MoveBG::GateManta_anim_info": 0x8040ef58,
		"GateManta_anim_info": 0x8040ef58,
		"MoveBG::AmiKing_anim_info": 0x8040ef60,
		"AmiKing_anim_info": 0x8040ef60,
		"MoveBG::@3291": 0x8040ef68,
		"MoveBG::casinoroulette_map_collision_data": 0x8040ef78,
		"casinoroulette_map_collision_data": 0x8040ef78,
		"MoveBG::casinoroulette_map_collision_info": 0x8040ef80,
		"casinoroulette_map_collision_info": 0x8040ef80,
		"MoveBG::@3295": 0x8040ef88,
		"MoveBG::roulette_anim_info": 0x8040ef90,
		"roulette_anim_info": 0x8040ef90,
		"MoveBG::roulette00_map_collision_data": 0x8040ef98,
		"roulette00_map_collision_data": 0x8040ef98,
		"MoveBG::roulette00_map_collision_info": 0x8040efa0,
		"roulette00_map_collision_info": 0x8040efa0,
		"MoveBG::roulette01_map_collision_data": 0x8040efb0,
		"roulette01_map_collision_data": 0x8040efb0,
		"MoveBG::roulette01_map_collision_info": 0x8040efb8,
		"roulette01_map_collision_info": 0x8040efb8,
		"MoveBG::roulette02_map_collision_data": 0x8040efc8,
		"roulette02_map_collision_data": 0x8040efc8,
		"MoveBG::roulette02_map_collision_info": 0x8040efd0,
		"roulette02_map_collision_info": 0x8040efd0,
		"MoveBG::pazul_map_collision_data": 0x8040eff0,
		"pazul_map_collision_data": 0x8040eff0,
		"MoveBG::pazul_map_collision_info": 0x8040eff8,
		"pazul_map_collision_info": 0x8040eff8,
		"MoveBG::bosswall_anim_info": 0x8040f000,
		"bosswall_anim_info": 0x8040f000,
		"MoveBG::casinoroof_anim_info": 0x8040f008,
		"casinoroof_anim_info": 0x8040f008,
		"MoveBG::GlassBreak_anim_info": 0x8040f010,
		"GlassBreak_anim_info": 0x8040f010,
		"MoveBG::GlassBreak_map_collision_data": 0x8040f018,
		"GlassBreak_map_collision_data": 0x8040f018,
		"MoveBG::GlassBreak_map_collision_info": 0x8040f020,
		"GlassBreak_map_collision_info": 0x8040f020,
		"MoveBG::GlassBreak_sound_info": 0x8040f028,
		"GlassBreak_sound_info": 0x8040f028,
		"MoveBG::closet_anim_info": 0x8040f030,
		"closet_anim_info": 0x8040f030,
		"MoveBG::ChestRevolve_anim_info": 0x8040f040,
		"ChestRevolve_anim_info": 0x8040f040,
		"MoveBG::ChestRevolve_map_collision_info": 0x8040f048,
		"ChestRevolve_map_collision_info": 0x8040f048,
		"MoveBG::PosterTeresa_map_collision_data": 0x8040f050,
		"PosterTeresa_map_collision_data": 0x8040f050,
		"MoveBG::PosterTeresa_map_collision_info": 0x8040f058,
		"PosterTeresa_map_collision_info": 0x8040f058,
		"MoveBG::PictureTeresa_map_collision_data": 0x8040f060,
		"PictureTeresa_map_collision_data": 0x8040f060,
		"MoveBG::PictureTeresa_map_collision_info": 0x8040f068,
		"PictureTeresa_map_collision_info": 0x8040f068,
		"MoveBG::PanelBreak_anim_info": 0x8040f070,
		"PanelBreak_anim_info": 0x8040f070,
		"MoveBG::PanelBreak_map_collision_data": 0x8040f078,
		"PanelBreak_map_collision_data": 0x8040f078,
		"MoveBG::PanelBreak_map_collision_info": 0x8040f080,
		"PanelBreak_map_collision_info": 0x8040f080,
		"MoveBG::PanelBreak_sound_info": 0x8040f088,
		"PanelBreak_sound_info": 0x8040f088,
		"MoveBG::PanelRevolve_anim_info": 0x8040f090,
		"PanelRevolve_anim_info": 0x8040f090,
		"MoveBG::PanelRevolve_map_collision_data": 0x8040f098,
		"PanelRevolve_map_collision_data": 0x8040f098,
		"MoveBG::PanelRevolve_map_collision_info": 0x8040f0a0,
		"PanelRevolve_map_collision_info": 0x8040f0a0,
		"MoveBG::SirenaShop_map_collision_data": 0x8040f0a8,
		"SirenaShop_map_collision_data": 0x8040f0a8,
		"MoveBG::SirenaShop_map_collision_info": 0x8040f0b0,
		"SirenaShop_map_collision_info": 0x8040f0b0,
		"MoveBG::cogwheel_anim_info": 0x8040f0b8,
		"cogwheel_anim_info": 0x8040f0b8,
		"MoveBG::cogwheel_map_collision_data": 0x8040f0c0,
		"cogwheel_map_collision_data": 0x8040f0c0,
		"MoveBG::cogwheel_map_collision_info": 0x8040f0c8,
		"cogwheel_map_collision_info": 0x8040f0c8,
		"MoveBG::CogwheelPlate_map_collision_data": 0x8040f0d0,
		"CogwheelPlate_map_collision_data": 0x8040f0d0,
		"MoveBG::CogwheelPlate_map_collision_info": 0x8040f0d8,
		"CogwheelPlate_map_collision_info": 0x8040f0d8,
		"MoveBG::CogwheelPot_map_collision_data": 0x8040f0e0,
		"CogwheelPot_map_collision_data": 0x8040f0e0,
		"MoveBG::CogwheelPot_map_collision_info": 0x8040f0e8,
		"CogwheelPot_map_collision_info": 0x8040f0e8,
		"MoveBG::@3338": 0x8040f0f0,
		"MoveBG::mare_float_house_map_collision_data": 0x8040f0f8,
		"mare_float_house_map_collision_data": 0x8040f0f8,
		"MoveBG::mare_float_house_map_collision_info": 0x8040f100,
		"mare_float_house_map_collision_info": 0x8040f100,
		"MoveBG::StopRock_map_collision_data": 0x8040f108,
		"StopRock_map_collision_data": 0x8040f108,
		"MoveBG::StopRock_map_collision_info": 0x8040f110,
		"StopRock_map_collision_info": 0x8040f110,
		"MoveBG::GrowthTree_anim_info": 0x8040f118,
		"GrowthTree_anim_info": 0x8040f118,
		"MoveBG::@3344": 0x8040f120,
		"MoveBG::GrowthTree_map_collision_data": 0x8040f128,
		"GrowthTree_map_collision_data": 0x8040f128,
		"MoveBG::GrowthTree_map_collision_info": 0x8040f130,
		"GrowthTree_map_collision_info": 0x8040f130,
		"MoveBG::MuddyBoat_anim_info": 0x8040f138,
		"MuddyBoat_anim_info": 0x8040f138,
		"MoveBG::MuddyBoat_map_collision_data": 0x8040f140,
		"MuddyBoat_map_collision_data": 0x8040f140,
		"MoveBG::MuddyBoat_map_collision_info": 0x8040f148,
		"MuddyBoat_map_collision_info": 0x8040f148,
		"MoveBG::Puncher_anim_info": 0x8040f150,
		"Puncher_anim_info": 0x8040f150,
		"MoveBG::HatoPop_anim_info": 0x8040f160,
		"HatoPop_anim_info": 0x8040f160,
		"MoveBG::@3357": 0x8040f168,
		"MoveBG::MareWaterJump_map_collision_data": 0x8040f170,
		"MareWaterJump_map_collision_data": 0x8040f170,
		"MoveBG::MareWaterJump_map_collision_info": 0x8040f178,
		"MareWaterJump_map_collision_info": 0x8040f178,
		"MoveBG::CoinFish_anim_info": 0x8040f180,
		"CoinFish_anim_info": 0x8040f180,
		"MoveBG::MareFall_anim_info": 0x8040f188,
		"MareFall_anim_info": 0x8040f188,
		"MoveBG::MareCork_map_collision_data": 0x8040f190,
		"MareCork_map_collision_data": 0x8040f190,
		"MoveBG::MareCork_map_collision_info": 0x8040f198,
		"MareCork_map_collision_info": 0x8040f198,
		"MoveBG::MonteRoot_anim_info": 0x8040f1a0,
		"MonteRoot_anim_info": 0x8040f1a0,
		"MoveBG::JumpMushroom_anim_info": 0x8040f1a8,
		"JumpMushroom_anim_info": 0x8040f1a8,
		"MoveBG::JumpMushroom_map_collision_data": 0x8040f1b0,
		"JumpMushroom_map_collision_data": 0x8040f1b0,
		"MoveBG::JumpMushroom_map_collision_info": 0x8040f1b8,
		"JumpMushroom_map_collision_info": 0x8040f1b8,
		"MoveBG::MonteGoalFlag_anim_info": 0x8040f1c0,
		"MonteGoalFlag_anim_info": 0x8040f1c0,
		"MoveBG::HangingBridgeBoard_anim_info": 0x8040f1c8,
		"HangingBridgeBoard_anim_info": 0x8040f1c8,
		"MoveBG::HangingBridgeBoard_map_collision_data": 0x8040f1d8,
		"HangingBridgeBoard_map_collision_data": 0x8040f1d8,
		"MoveBG::HangingBridgeBoard_map_collision_info": 0x8040f1e0,
		"HangingBridgeBoard_map_collision_info": 0x8040f1e0,
		"MoveBG::SwingBoard_map_collision_data": 0x8040f1e8,
		"SwingBoard_map_collision_data": 0x8040f1e8,
		"MoveBG::SwingBoard_map_collision_info": 0x8040f1f0,
		"SwingBoard_map_collision_info": 0x8040f1f0,
		"MoveBG::Fluff_anim_info": 0x8040f1f8,
		"Fluff_anim_info": 0x8040f1f8,
		"MoveBG::Bathtub_anim_info": 0x8040f208,
		"Bathtub_anim_info": 0x8040f208,
		"MoveBG::BathtubStandBreaking_anim_info": 0x8040f220,
		"BathtubStandBreaking_anim_info": 0x8040f220,
		"MoveBG::ex1_turn_lift_anim_info": 0x8040f228,
		"ex1_turn_lift_anim_info": 0x8040f228,
		"MoveBG::ex1_turn_lift_map_collision_data": 0x8040f230,
		"ex1_turn_lift_map_collision_data": 0x8040f230,
		"MoveBG::ex1_turn_lift_map_collision_info": 0x8040f238,
		"ex1_turn_lift_map_collision_info": 0x8040f238,
		"MoveBG::z_turn_disk_map_collision_data": 0x8040f240,
		"z_turn_disk_map_collision_data": 0x8040f240,
		"MoveBG::z_turn_disk_map_collision_info": 0x8040f248,
		"z_turn_disk_map_collision_info": 0x8040f248,
		"MoveBG::y_turn_lift_anim_info": 0x8040f250,
		"y_turn_lift_anim_info": 0x8040f250,
		"MoveBG::y_turn_lift_map_collision_data": 0x8040f258,
		"y_turn_lift_map_collision_data": 0x8040f258,
		"MoveBG::y_turn_lift_map_collision_info": 0x8040f260,
		"y_turn_lift_map_collision_info": 0x8040f260,
		"MoveBG::Nail_anim_info": 0x8040f268,
		"Nail_anim_info": 0x8040f268,
		"MoveBG::Nail_map_collision_data": 0x8040f278,
		"Nail_map_collision_data": 0x8040f278,
		"MoveBG::Nail_map_collision_info": 0x8040f280,
		"Nail_map_collision_info": 0x8040f280,
		"MoveBG::PachinkoNail_anim_info": 0x8040f288,
		"PachinkoNail_anim_info": 0x8040f288,
		"MoveBG::PachinkoNail_map_collision_data": 0x8040f290,
		"PachinkoNail_map_collision_data": 0x8040f290,
		"MoveBG::PachinkoNail_map_collision_info": 0x8040f298,
		"PachinkoNail_map_collision_info": 0x8040f298,
		"MoveBG::FileLoadBlock_map_collision_data": 0x8040f2a0,
		"FileLoadBlock_map_collision_data": 0x8040f2a0,
		"MoveBG::FileLoadBlock_map_collision_info": 0x8040f2a8,
		"FileLoadBlock_map_collision_info": 0x8040f2a8,
		"MoveBG::FileLoadBlockA_anim_info": 0x8040f2b0,
		"FileLoadBlockA_anim_info": 0x8040f2b0,
		"MoveBG::FileLoadBlockB_anim_info": 0x8040f2b8,
		"FileLoadBlockB_anim_info": 0x8040f2b8,
		"MoveBG::FileLoadBlockC_anim_info": 0x8040f2c0,
		"FileLoadBlockC_anim_info": 0x8040f2c0,
		"MoveBG::@3910": 0x8040f2cc,
		"MoveBG::@3969": 0x8040f2d4,
		"MoveBG::@4008": 0x8040f2d8,
		"MoveBG::@3676": 0x8040f310,
		"MoveBG::@3727": 0x8040f314,
		"MoveBG::@3738": 0x8040f318,
		"MoveBG::@3651": 0x8040f3a8,
		"MoveBG::@4224": 0x8040f3b8,
		"MoveBG::@3606": 0x8040f3f0,
		"MoveBG::@3885": 0x8040f414,
		"MoveBG::@3886": 0x8040f41c,
		"MoveBG::@4002": 0x8040f424,
		"MoveBG::@4064": 0x8040f43c,
		"MoveBG::@2665": 0x8040f464,
		"MoveBG::@2666": 0x8040f46c,
		"MoveBG::@3618": 0x8040f4d0,
		"MoveBG::@3668": 0x8040f584,
		"MoveBG::@3669": 0x8040f588,
		"MoveBG::@3842": 0x8040f594,
		"MoveBG::@3843": 0x8040f598,
		"MoveBG::@3844": 0x8040f59c,
		"MoveBG::@3629": 0x8040f5e8,
		"MoveBG::@3665": 0x8040f5ec,
		"MoveBG::@3666": 0x8040f5f0,
		"MoveBG::@3889": 0x8040f614,
		"MoveBG::@4014": 0x8040f628,
		"MoveBG::@4015": 0x8040f62c,
		"MoveBG::@4049": 0x8040f630,
		"MoveBG::@4050": 0x8040f634,
		"MoveBG::@4051": 0x8040f638,
		"MoveBG::@4052": 0x8040f63c,
		"MoveBG::@4257": 0x8040f650,
		"MoveBG::@4593": 0x8040f670,
		"MoveBG::@4594": 0x8040f674,
		"MoveBG::@4596": 0x8040f67c,
		"MoveBG::@4597": 0x8040f680,
		"MoveBG::@4598": 0x8040f684,
		"MoveBG::@4629": 0x8040f688,
		"MoveBG::@4786": 0x8040f68c,
		"MoveBG::@4788": 0x8040f694,
		"MoveBG::@4799": 0x8040f698,
		"MoveBG::@4844": 0x8040f6a0,
		"MoveBG::@4845": 0x8040f6a4,
		"MoveBG::@5163": 0x8040f6b0,
		"MoveBG::@5164": 0x8040f6b4,
		"MoveBG::@5167": 0x8040f6bc,
		"MoveBG::@5168": 0x8040f6c0,
		"MoveBG::@3439": 0x8040f71c,
		"MoveBG::@3654": 0x8040f720,
		"MoveBG::@3655": 0x8040f724,
		"MoveBG::@3656": 0x8040f728,
		"MoveBG::@3657": 0x8040f72c,
		"MoveBG::@3463": 0x8040f730,
		"MoveBG::@3648": 0x8040f758,
		"MoveBG::@3866": 0x8040f788,
		"@3866": 0x8040f788,
		"MoveBG::@4102": 0x8040f78c,
		"MoveBG::@4216": 0x8040f79c,
		"MoveBG::@4227": 0x8040f7a0,
		"MoveBG::@4228": 0x8040f7a4,
		"MoveBG::@4229": 0x8040f7a8,
		"MoveBG::@4230": 0x8040f7ac,
		"MoveBG::@4231": 0x8040f7b0,
		"MoveBG::@4233": 0x8040f7b8,
		"MoveBG::@4449": 0x8040f7c8,
		"@4449": 0x8040f7c8,
		"MoveBG::@4494": 0x8040f7e0,
		"MoveBG::@4755": 0x8040f7f0,
		"MoveBG::@4756": 0x8040f7f4,
		"MoveBG::@4757": 0x8040f7f8,
		"MoveBG::@4758": 0x8040f7fc,
		"MoveBG::@4777": 0x8040f800,
		"MoveBG::@4836": 0x8040f804,
		"MoveBG::@4837": 0x8040f808,
		"MoveBG::@4838": 0x8040f80c,
		"MoveBG::@4944": 0x8040f810,
		"MoveBG::@4969": 0x8040f814,
		"MoveBG::@4970": 0x8040f818,
		"MoveBG::@4972": 0x8040f81c,
		"MoveBG::@4977": 0x8040f828,
		"MoveBG::@5160": 0x8040f82c,
		"MoveBG::@5161": 0x8040f830,
		"MoveBG::@5225": 0x8040f834,
		"MoveBG::@5226": 0x8040f838,
		"MoveBG::@5232": 0x8040f83c,
		"MoveBG::@5341": 0x8040f840,
		"MoveBG::@3503": 0x8040f868,
		"MoveBG::@3504": 0x8040f86c,
		"MoveBG::@3544": 0x8040f870,
		"MoveBG::@3545": 0x8040f874,
		"MoveBG::@3694": 0x8040f890,
		"MoveBG::@3759": 0x8040f89c,
		"MoveBG::@4023": 0x8040f8d0,
		"MoveBG::@4024": 0x8040f8d4,
		"MoveBG::@4025": 0x8040f8d8,
		"MoveBG::@4077": 0x8040f8e0,
		"MoveBG::@4078": 0x8040f8e4,
		"MoveBG::@4079": 0x8040f8e8,
		"MoveBG::@4080": 0x8040f8ec,
		"MoveBG::@4081": 0x8040f8f0,
		"MoveBG::@4201": 0x8040f8fc,
		"@4201": 0x8040f8fc,
		"MoveBG::@4204": 0x8040f900,
		"MoveBG::@4205": 0x8040f904,
		"MoveBG::@4311": 0x8040f90c,
		"@4311": 0x8040f90c,
		"MoveBG::@3732": 0x8040f9a4,
		"MoveBG::@3733": 0x8040f9a8,
		"MoveBG::@3897": 0x8040f9b4,
		"MoveBG::@3898": 0x8040f9b8,
		"MoveBG::@4005": 0x8040f9bc,
		"MoveBG::@4054": 0x8040f9c4,
		"MoveBG::@4133": 0x8040f9c8,
		"MoveBG::@4136": 0x8040f9cc,
		"MoveBG::@4137": 0x8040f9d4,
		"MoveBG::@4138": 0x8040f9d8,
		"MoveBG::@4139": 0x8040f9dc,
		"MoveBG::@4140": 0x8040f9e0,
		"MoveBG::@4146": 0x8040f9f8,
		"MoveBG::@2392": 0x8040fa14,
		"MoveBG::@2393": 0x8040fa18,
		"MoveBG::@2394": 0x8040fa1c,
		"MoveBG::@2553": 0x8040fa28,
		"MoveBG::@2554": 0x8040fa2c,
		"MoveBG::@2587": 0x8040fa34,
		"MoveBG::@2588": 0x8040fa38,
		"MoveBG::@2589": 0x8040fa3c,
		"MoveBG::@2590": 0x8040fa40,
		"MoveBG::@2591": 0x8040fa44,
		"MoveBG::@2592": 0x8040fa48,
		"MoveBG::@2631": 0x8040fa58,
		"MoveBG::@2632": 0x8040fa5c,
		"MoveBG::@2646": 0x8040fa68,
		"MoveBG::@2647": 0x8040fa6c,
		"MoveBG::@2648": 0x8040fa70,
		"MoveBG::@2676": 0x8040fa90,
		"MoveBG::@2677": 0x8040fa94,
		"MoveBG::@2681": 0x8040faa0,
		"MoveBG::@2682": 0x8040faa4,
		"MoveBG::@2687": 0x8040fab8,
		"MoveBG::@2689": 0x8040fac0,
		"MoveBG::@2465": 0x8040faf0,
		"MoveBG::@2466": 0x8040faf8,
		"@2466": 0x8040faf8,
		"MoveBG::@2512": 0x8040fb00,
		"MoveBG::@2633": 0x8040fb14,
		"MoveBG::@2705": 0x8040fb2c,
		"MoveBG::@3592": 0x8040fbb0,
		"MoveBG::@3612": 0x8040fbb4,
		"MoveBG::@3689": 0x8040fbbc,
		"MoveBG::@4225": 0x8040fbd0,
		"MoveBG::@4359": 0x8040fbd4,
		"MoveBG::@4716": 0x8040fbd8,
		"MoveBG::@4717": 0x8040fbdc,
		"MoveBG::@4718": 0x8040fbe0,
		"MoveBG::@4719": 0x8040fbe4,
		"MoveBG::@4720": 0x8040fbe8,
		"MoveBG::@4721": 0x8040fbec,
		"MoveBG::@4722": 0x8040fbf0,
		"MoveBG::@4723": 0x8040fbf4,
		"MoveBG::@4724": 0x8040fbf8,
		"MoveBG::@4725": 0x8040fbfc,
		"MoveBG::@4726": 0x8040fc00,
		"MoveBG::@4727": 0x8040fc04,
		"MoveBG::@4728": 0x8040fc08,
		"MoveBG::@4729": 0x8040fc0c,
		"MoveBG::@4730": 0x8040fc10,
		"MoveBG::@4731": 0x8040fc14,
		"MoveBG::@4732": 0x8040fc18,
		"MoveBG::@4733": 0x8040fc1c,
		"MoveBG::@4734": 0x8040fc20,
		"MoveBG::@5113": 0x8040fc24,
		"MoveBG::@2453": 0x8040fca8,
		"MoveBG::@2620": 0x8040fcb4,
		"MoveBG::@2621": 0x8040fcb8,
		"MoveBG::@2622": 0x8040fcbc,
		"MoveBG::@2623": 0x8040fcc0,
		"MoveBG::@2186": 0x8040fcd0,
		"MoveBG::@2263": 0x8040fcd4,
		"MoveBG::@2279": 0x8040fcd8,
		"MoveBG::@2303": 0x8040fcdc,
		"MoveBG::@2574": 0x8040fce8,
		"MoveBG::@3681": 0x8040fdc4,
		"MoveBG::@3682": 0x8040fdc8,
		"@3682": 0x8040fdc8,
		"MoveBG::@2671": 0x8040fdf0,
		"MoveBG::@2693": 0x8040fdf4,
		"MoveBG::@2715": 0x8040fdf8,
		"MoveBG::@3441": 0x8040fe8c,
		"MoveBG::@3442": 0x8040fe90,
		"MoveBG::@3443": 0x8040fe94,
		"MoveBG::@3444": 0x8040fe98,
		"MoveBG::@3445": 0x8040fe9c,
		"MoveBG::@3446": 0x8040fea0,
		"MoveBG::@3916": 0x8040fed0,
		"MoveBG::@3919": 0x8040fedc,
		"MoveBG::@3920": 0x8040fee0,
		"MoveBG::@3922": 0x8040fee8,
		"MoveBG::@3923": 0x8040feec,
		"MoveBG::@3924": 0x8040fef0,
		"MoveBG::@3925": 0x8040fef4,
		"MoveBG::@3926": 0x8040fef8,
		"MoveBG::@3929": 0x8040fefc,
		"MoveBG::@3930": 0x8040ff00,
		"MoveBG::@3931": 0x8040ff04,
		"MoveBG::@2668": 0x8040ff78,
		"MoveBG::@2697": 0x8040ff84,
		"MoveBG::@2702": 0x8040ff94,
		"MoveBG::@2713": 0x8040ffac,
		"MoveBG::@3887": 0x80410060,
		"MoveBG::@4472": 0x80410074,
		"MoveBG::@4657": 0x80410078,
		"MoveBG::@4658": 0x8041007c,
		"MoveBG::@4659": 0x80410080,
		"MoveBG::@4660": 0x80410084,
		"MoveBG::@4662": 0x8041008c,
		"MoveBG::@5005": 0x80410090,
		"MoveBG::@5006": 0x80410094,
		"MoveBG::@5007": 0x80410098,
		"MoveBG::@5008": 0x8041009c,
		"MoveBG::@5245": 0x804100a0,
		"MoveBG::@5246": 0x804100a4,
		"MoveBG::@5348": 0x804100a8,
		"MoveBG::@5843": 0x804100ac,
		"MoveBG::@5846": 0x804100b0,
		"MoveBG::@5980": 0x804100b4,
		"@5980": 0x804100b4,
		"MoveBG::@5988": 0x804100c4,
		"MoveBG::@5994": 0x804100d8,
		"MoveBG::@5999": 0x804100dc,
		"MoveBG::@3520": 0x80410170,
		"MoveBG::@3521": 0x80410174,
		"MoveBG::@3525": 0x80410184,
		"MoveBG::@3526": 0x80410188,
		"MoveBG::@3527": 0x8041018c,
		"MoveBG::@3528": 0x80410190,
		"MoveBG::@3748": 0x80410198,
		"Map::@3002": 0x804101d0,
		"Map::@3209": 0x804101d4,
		"Map::@3210": 0x804101d8,
		"Map::@3211": 0x804101dc,
		"Map::@3508": 0x804101e0,
		"Map::@2050": 0x804101e8,
		"Map::@2904": 0x804101f0,
		"Map::@2905": 0x804101f4,
		"Map::@2906": 0x804101f8,
		"Map::@3158": 0x80410208,
		"Map::@3159": 0x8041020c,
		"Map::@3160": 0x80410210,
		"Map::@3161": 0x80410214,
		"Map::@3196": 0x80410218,
		"Map::@3255": 0x8041021c,
		"Map::@3256": 0x80410220,
		"Map::@3279": 0x80410224,
		"Map::@2183": 0x80410228,
		"Map::@2184": 0x8041022c,
		"Map::@2185": 0x80410230,
		"Map::@2221": 0x80410234,
		"Map::@1871": 0x80410240,
		"Map::@2017": 0x80410244,
		"Map::@1838": 0x80410250,
		"@1838": 0x80410250,
		"Map::@1839": 0x80410254,
		"Map::@1840": 0x80410258,
		"Map::@1841": 0x80410260,
		"Map::@3152": 0x80410270,
		"Map::@3153": 0x80410274,
		"Map::@3219": 0x80410278,
		"Map::@3220": 0x8041027c,
		"Map::@3221": 0x80410280,
		"Map::@3222": 0x80410284,
		"Map::@3223": 0x80410288,
		"Map::@3617": 0x80410290,
		"Map::@2976": 0x804102a0,
		"Map::@2088": 0x804102a8,
		"Map::@2089": 0x804102ac,
		"Map::@2207": 0x804102b8,
		"Map::@2841": 0x804102d8,
		"Map::@3181": 0x804102e8,
		"Map::@3182": 0x804102ec,
		"Map::@3183": 0x804102f0,
		"Map::@2429": 0x804102f8,
		"Map::@2430": 0x804102fc,
		"Map::@2431": 0x80410304,
		"Map::@2432": 0x8041030c,
		"Map::@2505": 0x80410314,
		"Map::@2506": 0x80410318,
		"Map::@2640": 0x80410328,
		"Map::@2643": 0x80410340,
		"Map::@2644": 0x80410348,
		"Map::@2645": 0x80410350,
		"Map::@2646": 0x80410358,
		"Map::@2648": 0x80410368,
		"Map::@2778": 0x804103bc,
		"Map::@2960": 0x804103c0,
		"Map::@2961": 0x804103c4,
		"Map::@2962": 0x804103c8,
		"Map::@2963": 0x804103cc,
		"Map::@2964": 0x804103d0,
		"Map::@2965": 0x804103d4,
		"Map::@2998": 0x804103ec,
		"Map::@3140": 0x804103f4,
		"Map::@3141": 0x804103f8,
		"Map::@2569": 0x80410414,
		"Map::@2570": 0x80410418,
		"Map::@2572": 0x80410420,
		"Map::@2573": 0x80410424,
		"Map::@2574": 0x80410428,
		"Map::@2575": 0x8041042c,
		"Map::@2577": 0x80410434,
		"Map::@2578": 0x80410438,
		"Map::@2393": 0x80410458,
		"Map::@2547": 0x8041048c,
		"Map::@2610": 0x8041049c,
		"Map::@2863": 0x804104b0,
		"Map::@2958": 0x804104b4,
		"Map::@3188": 0x804104c0,
		"Map::@2849": 0x804104c8,
		"Map::@2850": 0x804104cc,
		"Map::@2851": 0x804104d0,
		"Map::@2852": 0x804104d4,
		"Map::@2390": 0x804104e0,
		"Map::@2392": 0x804104e4,
		"Map::@2396": 0x804104e8,
		"Map::@2460": 0x804104ec,
		"Map::@2788": 0x80410510,
		"Map::@2790": 0x80410518,
		"Map::@2865": 0x80410524,
		"Map::@2866": 0x80410528,
		"Map::@2785": 0x80410534,
		"Map::@2548": 0x80410544,
		"Map::@3074": 0x80410558,
		"Map::@2352": 0x80410564,
		"Map::@2353": 0x80410568,
		"Map::@1992": 0x80410580,
		"Map::@1993": 0x80410584,
		"Map::@2926": 0x804105ac,
		"Map::@2927": 0x804105b0,
		"Map::@2928": 0x804105b4,
		"Map::@3053": 0x804105d8,
		"Map::@3063": 0x804105dc,
		"Map::@3064": 0x804105e4,
		"Map::@3085": 0x804105e8,
		"Map::@3135": 0x804105f4,
		"Map::@3136": 0x804105f8,
		"Map::@3169": 0x804105fc,
		"Map::@3258": 0x80410600,
		"Map::@3272": 0x80410608,
		"Map::@3290": 0x80410610,
		"Map::@3291": 0x80410618,
		"Map::@3292": 0x8041061c,
		"Map::@3397": 0x80410628,
		"Map::@3400": 0x80410640,
		"Map::@3401": 0x80410644,
		"Map::@3402": 0x80410648,
		"Map::@3700": 0x8041064c,
		"Map::@3760": 0x80410650,
		"Map::@3761": 0x80410654,
		"Map::@3762": 0x80410658,
		"Map::@3763": 0x8041065c,
		"Map::@3764": 0x80410660,
		"Map::@3765": 0x80410664,
		"Map::@3766": 0x80410668,
		"Map::@3767": 0x8041066c,
		"Map::@3768": 0x80410670,
		"Map::@3769": 0x80410674,
		"Map::@3770": 0x80410678,
		"Map::@3771": 0x8041067c,
		"Map::@3772": 0x80410680,
		"Map::@3773": 0x80410684,
		"Map::@3774": 0x80410688,
		"Map::@3775": 0x8041068c,
		"Map::@3776": 0x80410690,
		"Map::@3777": 0x80410694,
		"Map::@3778": 0x80410698,
		"Map::@3779": 0x8041069c,
		"Map::@3780": 0x804106a0,
		"Map::@3781": 0x804106a4,
		"Map::@3782": 0x804106a8,
		"Map::@3783": 0x804106ac,
		"Map::@3784": 0x804106b0,
		"Map::@3785": 0x804106b4,
		"Map::@3786": 0x804106b8,
		"Map::@3787": 0x804106bc,
		"Map::@3788": 0x804106c0,
		"Map::@3789": 0x804106c4,
		"Map::@2566": 0x804106d4,
		"Map::@2567": 0x804106d8,
		"Map::@2724": 0x804106e4,
		"Map::@3413": 0x804106e8,
		"Map::@3414": 0x804106ec,
		"Map::@3419": 0x80410700,
		"Map::@3420": 0x80410704,
		"Map::@3421": 0x80410708,
		"Map::@3422": 0x8041070c,
		"Map::@3424": 0x80410714,
		"Map::@3455": 0x80410720,
		"Map::@3843": 0x80410738,
		"Map::@3844": 0x8041073c,
		"Map::@3845": 0x80410740,
		"Map::@3846": 0x80410744,
		"Map::@4483": 0x80410748,
		"Map::@4630": 0x80410758,
		"Map::@4740": 0x8041075c,
		"Map::@4741": 0x80410764,
		"Map::@4759": 0x804107ac,
		"Map::@4765": 0x804107bc,
		"Map::@4767": 0x804107c0,
		"Map::@4769": 0x804107c4,
		"Map::@4842": 0x804107cc,
		"Map::@4846": 0x804107d0,
		"Map::@4847": 0x804107d8,
		"Map::@4848": 0x804107dc,
		"Map::@4851": 0x804107e8,
		"Map::@4853": 0x804107f4,
		"Map::@4854": 0x804107fc,
		"Map::@4856": 0x80410800,
		"Map::@4857": 0x80410808,
		"Map::@5833": 0x8041080c,
		"GC2D::@1680": 0x80410810,
		"GC2D::@1644": 0x80410820,
		"GC2D::@2120": 0x80410850,
		"GC2D::@2375": 0x80410858,
		"GC2D::@3494": 0x80410868,
		"GC2D::@3522": 0x8041086c,
		"GC2D::@3576": 0x80410870,
		"TGCConsole2::height$localstatic0$drawWater": 0x80410874,
		"height$localstatic0$drawWater": 0x80410874,
		"TGCConsole2::topDiff$localstatic1$drawWater": 0x8041087c,
		"topDiff$localstatic1$drawWater": 0x8041087c,
		"GC2D::@3578": 0x80410880,
		"GC2D::@7060": 0x80410884,
		"@7060": 0x80410884,
		"GC2D::@7061": 0x80410888,
		"@7061": 0x80410888,
		"GC2D::@7062": 0x8041088c,
		"@7062": 0x8041088c,
		"GC2D::@7063": 0x80410890,
		"@7063": 0x80410890,
		"GC2D::@7064": 0x80410894,
		"@7064": 0x80410894,
		"GC2D::@7065": 0x80410898,
		"@7065": 0x80410898,
		"GC2D::@7066": 0x8041089c,
		"@7066": 0x8041089c,
		"GC2D::@7067": 0x804108a0,
		"@7067": 0x804108a0,
		"GC2D::@7068": 0x804108a4,
		"@7068": 0x804108a4,
		"GC2D::@7069": 0x804108a8,
		"@7069": 0x804108a8,
		"GC2D::@7070": 0x804108ac,
		"@7070": 0x804108ac,
		"GC2D::@7071": 0x804108b0,
		"@7071": 0x804108b0,
		"GC2D::@7072": 0x804108b4,
		"@7072": 0x804108b4,
		"GC2D::@7073": 0x804108b8,
		"@7073": 0x804108b8,
		"GC2D::@7226": 0x804108d0,
		"GC2D::@7308": 0x804108d4,
		"@7308": 0x804108d4,
		"GC2D::@7309": 0x804108d8,
		"@7309": 0x804108d8,
		"GC2D::@8675": 0x804108e8,
		"@8675": 0x804108e8,
		"GC2D::@8676": 0x804108ec,
		"@8676": 0x804108ec,
		"GC2D::@9157": 0x804108f0,
		"GC2D::@9480": 0x804108f4,
		"GC2D::@11362": 0x804108f8,
		"@11362": 0x804108f8,
		"GC2D::@11363": 0x804108fc,
		"@11363": 0x804108fc,
		"GC2D::@11364": 0x80410900,
		"@11364": 0x80410900,
		"GC2D::@11581": 0x80410904,
		"@11581": 0x80410904,
		"GC2D::@11639": 0x8041090c,
		"@11639": 0x8041090c,
		"GC2D::@2720": 0x80410910,
		"GC2D::@2721": 0x80410918,
		"GC2D::@3304": 0x8041091c,
		"GC2D::@3370": 0x80410920,
		"GC2D::@3371": 0x80410924,
		"GC2D::@3555": 0x80410930,
		"GC2D::@3557": 0x80410940,
		"GC2D::@3558": 0x80410944,
		"GC2D::@3559": 0x80410948,
		"GC2D::@3564": 0x8041094c,
		"GC2D::@3720": 0x80410950,
		"GC2D::@3721": 0x80410954,
		"GC2D::@3885": 0x80410958,
		"GC2D::@4371": 0x8041095c,
		"GC2D::@4550": 0x80410968,
		"GC2D::@4551": 0x8041096c,
		"@4551": 0x8041096c,
		"GC2D::@4552": 0x80410970,
		"@4552": 0x80410970,
		"GC2D::@4553": 0x80410974,
		"GC2D::@4554": 0x80410978,
		"@4554": 0x80410978,
		"GC2D::@4555": 0x8041097c,
		"@4555": 0x8041097c,
		"GC2D::@4944": 0x80410988,
		"GC2D::@4945": 0x8041098c,
		"GC2D::@4976": 0x80410990,
		"GC2D::@5010": 0x80410998,
		"GC2D::@1549": 0x804109a0,
		"GC2D::@1550": 0x804109a4,
		"GC2D::@1551": 0x804109a8,
		"GC2D::@1552": 0x804109ac,
		"GC2D::@1553": 0x804109b0,
		"GC2D::@2665": 0x804109fc,
		"GC2D::@2666": 0x80410a00,
		"GC2D::@2667": 0x80410a04,
		"GC2D::@2668": 0x80410a08,
		"GC2D::@2669": 0x80410a0c,
		"GC2D::@2670": 0x80410a10,
		"GC2D::@2671": 0x80410a14,
		"GC2D::@2672": 0x80410a18,
		"GC2D::@2673": 0x80410a1c,
		"GC2D::@2674": 0x80410a20,
		"GC2D::@3154": 0x80410a54,
		"GC2D::@3155": 0x80410a58,
		"GC2D::@3156": 0x80410a5c,
		"GC2D::@3216": 0x80410a60,
		"GC2D::@3217": 0x80410a64,
		"GC2D::@3218": 0x80410a68,
		"GC2D::@3219": 0x80410a6c,
		"GC2D::@3220": 0x80410a70,
		"GC2D::@3221": 0x80410a74,
		"GC2D::@3222": 0x80410a78,
		"GC2D::@3223": 0x80410a7c,
		"GC2D::@3224": 0x80410a80,
		"GC2D::@3225": 0x80410a84,
		"GC2D::@3342": 0x80410a90,
		"GC2D::@3343": 0x80410a94,
		"GC2D::@1995": 0x80410a98,
		"GC2D::@1996": 0x80410a9c,
		"GC2D::@4196": 0x80410aa0,
		"GC2D::@4197": 0x80410aa4,
		"@4197": 0x80410aa4,
		"GC2D::@4198": 0x80410aa8,
		"@4198": 0x80410aa8,
		"GC2D::@4238": 0x80410ac0,
		"GC2D::@4431": 0x80410ac4,
		"GC2D::@5894": 0x80410ac8,
		"GC2D::@5895": 0x80410acc,
		"GC2D::@5896": 0x80410ad0,
		"GC2D::@5897": 0x80410ad4,
		"GC2D::@5898": 0x80410ad8,
		"GC2D::@5899": 0x80410adc,
		"GC2D::@6859": 0x80410ae0,
		"@6859": 0x80410ae0,
		"GC2D::@6861": 0x80410ae8,
		"@6861": 0x80410ae8,
		"GC2D::@4546": 0x80410b4c,
		"GC2D::@4547": 0x80410b50,
		"GC2D::@5143": 0x80410b60,
		"GC2D::@5144": 0x80410b64,
		"GC2D::@5145": 0x80410b68,
		"GC2D::@5146": 0x80410b6c,
		"GC2D::@5147": 0x80410b70,
		"GC2D::@5148": 0x80410b74,
		"GC2D::@5149": 0x80410b78,
		"GC2D::@5469": 0x80410b7c,
		"GC2D::@7203": 0x80410b88,
		"@7203": 0x80410b88,
		"GC2D::@7204": 0x80410b8c,
		"@7204": 0x80410b8c,
		"GC2D::@7205": 0x80410b90,
		"@7205": 0x80410b90,
		"GC2D::@7206": 0x80410b94,
		"@7206": 0x80410b94,
		"GC2D::@7207": 0x80410b98,
		"@7207": 0x80410b98,
		"GC2D::@7208": 0x80410b9c,
		"@7208": 0x80410b9c,
		"GC2D::@7642": 0x80410ba0,
		"GC2D::@7643": 0x80410ba4,
		"GC2D::@7644": 0x80410ba8,
		"GC2D::@7645": 0x80410bac,
		"GC2D::@7646": 0x80410bb0,
		"GC2D::@7647": 0x80410bb4,
		"GC2D::@8251": 0x80410bb8,
		"@8251": 0x80410bb8,
		"GC2D::@8257": 0x80410bc0,
		"@8257": 0x80410bc0,
		"GC2D::@8297": 0x80410bc4,
		"GC2D::@2222": 0x80410c04,
		"GC2D::@2224": 0x80410c0c,
		"GC2D::@2533": 0x80410c20,
		"GC2D::@2875": 0x80410c24,
		"GC2D::@2876": 0x80410c28,
		"GC2D::@2877": 0x80410c2c,
		"GC2D::@3483": 0x80410c48,
		"GC2D::@3488": 0x80410c50,
		"GC2D::@3489": 0x80410c54,
		"GC2D::@3491": 0x80410c58,
		"GC2D::@2809": 0x80410cbc,
		"GC2D::@2878": 0x80410cc0,
		"GC2D::@2879": 0x80410cc4,
		"GC2D::@3608": 0x80410cd4,
		"GC2D::@3609": 0x80410cd8,
		"GC2D::@3610": 0x80410cdc,
		"GC2D::@3616": 0x80410cf4,
		"GC2D::@3931": 0x80410d00,
		"GC2D::@3932": 0x80410d04,
		"GC2D::@4047": 0x80410d08,
		"GC2D::@4048": 0x80410d0c,
		"GC2D::@4049": 0x80410d10,
		"GC2D::@4050": 0x80410d14,
		"GC2D::@2392": 0x80410d18,
		"GC2D::@2393": 0x80410d1c,
		"GC2D::@2394": 0x80410d20,
		"GC2D::@3119": 0x80410d5c,
		"GC2D::@1912": 0x80410d68,
		"GC2D::@1913": 0x80410d6c,
		"GC2D::@2032": 0x80410d74,
		"GC2D::@2033": 0x80410d78,
		"GC2D::@2034": 0x80410d7c,
		"GC2D::@2035": 0x80410d80,
		"GC2D::@2036": 0x80410d84,
		"GC2D::@2037": 0x80410d88,
		"GC2D::@2220": 0x80410da4,
		"GC2D::@2488": 0x80410db4,
		"GC2D::@2489": 0x80410db8,
		"GC2D::@2490": 0x80410dbc,
		"GC2D::@2514": 0x80410dc0,
		"GC2D::@2515": 0x80410dc4,
		"GC2D::@1505": 0x80410dc8,
		"GC2D::@1507": 0x80410dcc,
		"@1507": 0x80410dcc,
		"GC2D::@2653": 0x80410e2c,
		"GC2D::@2654": 0x80410e34,
		"GC2D::@2655": 0x80410e38,
		"GC2D::@2656": 0x80410e3c,
		"GC2D::@2756": 0x80410e48,
		"GC2D::@2757": 0x80410e4c,
		"GC2D::@2758": 0x80410e50,
		"GC2D::@2858": 0x80410e54,
		"GC2D::@2859": 0x80410e58,
		"GC2D::@2954": 0x80410e5c,
		"GC2D::@2955": 0x80410e60,
		"GC2D::@2956": 0x80410e64,
		"GC2D::@3620": 0x80410e68,
		"GC2D::@3621": 0x80410e6c,
		"GC2D::@3622": 0x80410e70,
		"GC2D::@3623": 0x80410e74,
		"GC2D::@3624": 0x80410e78,
		"GC2D::@3814": 0x80410e7c,
		"GC2D::@1844": 0x80410e88,
		"@1844": 0x80410e88,
		"GC2D::@1684": 0x80410ea8,
		"GC2D::@1736": 0x80410ec0,
		"@1736": 0x80410ec0,
		"GC2D::@114": 0x80410ec8,
		"GC2D::@256": 0x80410ecc,
		"GC2D::@292": 0x80410ed0,
		"GC2D::@295": 0x80410ed4,
		"GC2D::@599": 0x80410ed8,
		"@599": 0x80410ed8,
		"GC2D::@600": 0x80410edc,
		"@600": 0x80410edc,
		"GC2D::@601": 0x80410ee0,
		"@601": 0x80410ee0,
		"GC2D::@602": 0x80410ee4,
		"GC2D::@603": 0x80410ee8,
		"@603": 0x80410ee8,
		"GC2D::@604": 0x80410eec,
		"GC2D::@605": 0x80410ef0,
		"@605": 0x80410ef0,
		"GC2D::@606": 0x80410ef4,
		"GC2D::@607": 0x80410ef8,
		"GC2D::@608": 0x80410efc,
		"@608": 0x80410efc,
		"GC2D::@609": 0x80410f00,
		"GC2D::@610": 0x80410f04,
		"GC2D::@650": 0x80410f10,
		"@650": 0x80410f10,
		"GC2D::@651": 0x80410f14,
		"@651": 0x80410f14,
		"GC2D::@652": 0x80410f18,
		"@652": 0x80410f18,
		"GC2D::@653": 0x80410f1c,
		"@653": 0x80410f1c,
		"GC2D::@654": 0x80410f20,
		"GC2D::@655": 0x80410f24,
		"GC2D::@656": 0x80410f28,
		"@656": 0x80410f28,
		"GC2D::@657": 0x80410f2c,
		"@657": 0x80410f2c,
		"GC2D::@753": 0x80410f48,
		"GC2D::@754": 0x80410f4c,
		"GC2D::@755": 0x80410f50,
		"@755": 0x80410f50,
		"GC2D::@756": 0x80410f54,
		"@756": 0x80410f54,
		"GC2D::@757": 0x80410f58,
		"@757": 0x80410f58,
		"GC2D::@758": 0x80410f5c,
		"@758": 0x80410f5c,
		"GC2D::@759": 0x80410f60,
		"@759": 0x80410f60,
		"GC2D::@760": 0x80410f64,
		"@760": 0x80410f64,
		"GC2D::@761": 0x80410f68,
		"@761": 0x80410f68,
		"GC2D::@762": 0x80410f6c,
		"GC2D::@763": 0x80410f70,
		"GC2D::@764": 0x80410f74,
		"@764": 0x80410f74,
		"GC2D::@765": 0x80410f78,
		"@765": 0x80410f78,
		"GC2D::@766": 0x80410f7c,
		"@766": 0x80410f7c,
		"GC2D::@853": 0x80410f80,
		"@853": 0x80410f80,
		"GC2D::@942": 0x80410f84,
		"@942": 0x80410f84,
		"GC2D::@964": 0x80410f88,
		"@964": 0x80410f88,
		"GC2D::@996": 0x80410f8c,
		"@996": 0x80410f8c,
		"GC2D::@997": 0x80410f90,
		"@997": 0x80410f90,
		"GC2D::@998": 0x80410f94,
		"@998": 0x80410f94,
		"GC2D::@1037": 0x80410f98,
		"@1037": 0x80410f98,
		"GC2D::@1072": 0x80410fa8,
		"GC2D::@1073": 0x80410fac,
		"GC2D::@1074": 0x80410fb0,
		"@1074": 0x80410fb0,
		"GC2D::@1075": 0x80410fb4,
		"@1075": 0x80410fb4,
		"GC2D::@1129": 0x80410fb8,
		"@1129": 0x80410fb8,
		"GC2D::@1130": 0x80410fbc,
		"@1130": 0x80410fbc,
		"GC2D::@1131": 0x80410fc0,
		"@1131": 0x80410fc0,
		"GC2D::@1132": 0x80410fc4,
		"@1132": 0x80410fc4,
		"GC2D::@1133": 0x80410fc8,
		"@1133": 0x80410fc8,
		"GC2D::@1134": 0x80410fcc,
		"@1134": 0x80410fcc,
		"GC2D::@1276": 0x80410fd0,
		"@1276": 0x80410fd0,
		"GC2D::@1620": 0x80410fd4,
		"GC2D::@1621": 0x80410fd8,
		"GC2D::@1622": 0x80410fdc,
		"GC2D::@1623": 0x80410fe0,
		"GC2D::@1626": 0x80410fec,
		"GC2D::@1627": 0x80410ff0,
		"GC2D::@1628": 0x80410ff4,
		"GC2D::@1764": 0x80410ff8,
		"@1764": 0x80410ff8,
		"GC2D::@1865": 0x80410ffc,
		"@unnamed@::cLongHeightMovieIdList": 0x80411000,
		"cLongHeightMovieIdList": 0x80411000,
		"GC2D::@1592": 0x80411008,
		"GC2D::@1605": 0x80411010,
		"@unnamed@::cStopRumbleAnm": 0x80411018,
		"cStopRumbleAnm": 0x80411018,
		"@unnamed@::cRumbleToggleItems": 0x80411020,
		"cRumbleToggleItems": 0x80411020,
		"GC2D::@2496": 0x80411028,
		"GC2D::@2497": 0x8041102c,
		"GC2D::@2498": 0x80411030,
		"GC2D::@2499": 0x80411034,
		"GC2D::@2732": 0x80411038,
		"GC2D::@2734": 0x80411040,
		"GC2D::@2912": 0x80411050,
		"GC2D::@2913": 0x80411054,
		"GC2D::@2914": 0x80411058,
		"GC2D::@3596": 0x80411064,
		"GC2D::@3597": 0x80411068,
		"GC2D::@1558": 0x80411070,
		"GC2D::@1580": 0x80411078,
		"Enemy::@4578": 0x804110a8,
		"Enemy::@2718": 0x804110b0,
		"Enemy::@2757": 0x8041115c,
		"Enemy::@2800": 0x804111e0,
		"Enemy::@2802": 0x804111f0,
		"Enemy::@2824": 0x80411270,
		"Enemy::@2849": 0x80411334,
		"Enemy::@2856": 0x8041135c,
		"Enemy::@3205": 0x80411458,
		"Enemy::@3212": 0x8041146c,
		"Enemy::@4108": 0x80411484,
		"Enemy::@4109": 0x80411488,
		"Enemy::@4110": 0x8041148c,
		"Enemy::@4113": 0x80411498,
		"Enemy::@4341": 0x804114e4,
		"Enemy::@5199": 0x80411510,
		"Enemy::@5510": 0x80411514,
		"@5510": 0x80411514,
		"Enemy::@5511": 0x80411518,
		"@5511": 0x80411518,
		"Enemy::@2168": 0x8041157c,
		"Enemy::@2169": 0x80411580,
		"Enemy::@2170": 0x80411584,
		"Enemy::@2172": 0x8041158c,
		"Enemy::@2173": 0x80411590,
		"Enemy::@2174": 0x80411594,
		"Enemy::@2176": 0x8041159c,
		"Enemy::@3678": 0x804115e0,
		"@3678": 0x804115e0,
		"Enemy::@4027": 0x8041160c,
		"Enemy::@4076": 0x80411618,
		"Enemy::@4080": 0x8041161c,
		"Enemy::@4547": 0x80411644,
		"Enemy::@5213": 0x80411654,
		"Enemy::@5337": 0x80411660,
		"Enemy::mFireHamNoseColorStart": 0x804116a8,
		"mFireHamNoseColorStart": 0x804116a8,
		"Enemy::mFireHamNoseColorEnd": 0x804116b0,
		"mFireHamNoseColorEnd": 0x804116b0,
		"Enemy::mFireHamOtherColorStart": 0x804116b8,
		"mFireHamOtherColorStart": 0x804116b8,
		"Enemy::mFireHamOtherColorEnd": 0x804116c0,
		"mFireHamOtherColorEnd": 0x804116c0,
		"Enemy::@3944": 0x804116c8,
		"Enemy::@3946": 0x804116d0,
		"Enemy::@4616": 0x80411720,
		"@4616": 0x80411720,
		"Enemy::@4799": 0x8041172c,
		"Enemy::@6521": 0x8041175c,
		"Enemy::@6522": 0x80411760,
		"Enemy::@6523": 0x80411764,
		"Enemy::@6524": 0x80411768,
		"Enemy::@7349": 0x8041176c,
		"@7349": 0x8041176c,
		"Enemy::@4408": 0x8041178c,
		"Enemy::@5072": 0x804117b8,
		"Enemy::@5073": 0x804117bc,
		"Enemy::@5188": 0x804117d0,
		"Enemy::@5189": 0x804117d4,
		"Enemy::@6362": 0x804117ec,
		"@6362": 0x804117ec,
		"Enemy::@6364": 0x804117f0,
		"Enemy::@6367": 0x804117f4,
		"@6367": 0x804117f4,
		"Enemy::@6371": 0x804117f8,
		"@6371": 0x804117f8,
		"Enemy::@6373": 0x804117fc,
		"@6373": 0x804117fc,
		"Enemy::@6376": 0x80411800,
		"@6376": 0x80411800,
		"Enemy::@6382": 0x80411804,
		"@6382": 0x80411804,
		"Enemy::@6389": 0x80411810,
		"@6389": 0x80411810,
		"Enemy::@6393": 0x80411814,
		"@6393": 0x80411814,
		"Enemy::@6398": 0x8041181c,
		"@6398": 0x8041181c,
		"Enemy::@6403": 0x80411820,
		"@6403": 0x80411820,
		"Enemy::@6410": 0x80411824,
		"@6410": 0x80411824,
		"Enemy::@4191": 0x804118d4,
		"Enemy::@3452": 0x804118f0,
		"Enemy::@4228": 0x80411934,
		"Enemy::@4451": 0x80411948,
		"@4451": 0x80411948,
		"Enemy::@4532": 0x8041195c,
		"Enemy::@4712": 0x80411968,
		"Enemy::@5131": 0x80411980,
		"Enemy::@4020": 0x804119dc,
		"Enemy::@4021": 0x804119e0,
		"Enemy::@4023": 0x804119e8,
		"Enemy::@4024": 0x804119ec,
		"Enemy::@4025": 0x804119f0,
		"Enemy::@4358": 0x804119fc,
		"Enemy::@4359": 0x80411a00,
		"Enemy::@4940": 0x80411a1c,
		"Enemy::@4942": 0x80411a20,
		"Enemy::@2402": 0x80411a38,
		"Enemy::@2403": 0x80411a3c,
		"Enemy::@2404": 0x80411a40,
		"Enemy::@1602": 0x80411a4c,
		"Enemy::@1603": 0x80411a50,
		"Enemy::@1630": 0x80411a54,
		"Enemy::@2245": 0x80411a6c,
		"Enemy::idxarray$3428": 0x80411ad8,
		"idxarray$3428": 0x80411ad8,
		"Enemy::idxarray$3450": 0x80411ae0,
		"idxarray$3450": 0x80411ae0,
		"Enemy::idxarray$3497": 0x80411ae8,
		"idxarray$3497": 0x80411ae8,
		"Enemy::idxarray$3517": 0x80411af0,
		"idxarray$3517": 0x80411af0,
		"Enemy::@4166": 0x80411afc,
		"Enemy::@4314": 0x80411b10,
		"@4314": 0x80411b10,
		"Enemy::@4694": 0x80411b1c,
		"Enemy::@4695": 0x80411b20,
		"Enemy::@4696": 0x80411b24,
		"Enemy::@5953": 0x80411b40,
		"@5953": 0x80411b40,
		"Enemy::@5954": 0x80411b44,
		"@5954": 0x80411b44,
		"Enemy::@5956": 0x80411b48,
		"@5956": 0x80411b48,
		"Enemy::@5957": 0x80411b4c,
		"@5957": 0x80411b4c,
		"Enemy::@5958": 0x80411b50,
		"Enemy::@5959": 0x80411b54,
		"Enemy::@6290": 0x80411b64,
		"@6290": 0x80411b64,
		"Enemy::@6291": 0x80411b68,
		"@6291": 0x80411b68,
		"Enemy::@6557": 0x80411b6c,
		"Enemy::@7099": 0x80411b70,
		"Enemy::@7100": 0x80411b74,
		"Enemy::@7101": 0x80411b78,
		"Enemy::@7160": 0x80411b7c,
		"Enemy::@7161": 0x80411b80,
		"Enemy::@7547": 0x80411b84,
		"@7547": 0x80411b84,
		"Enemy::@7833": 0x80411b8c,
		"@7833": 0x80411b8c,
		"Enemy::@7834": 0x80411b90,
		"@7834": 0x80411b90,
		"Enemy::@7835": 0x80411b94,
		"@7835": 0x80411b94,
		"Enemy::@8705": 0x80411bb0,
		"@8705": 0x80411bb0,
		"Enemy::@9006": 0x80411bb4,
		"@9006": 0x80411bb4,
		"Enemy::@9186": 0x80411bd4,
		"@9186": 0x80411bd4,
		"Enemy::@4037": 0x80411c14,
		"Enemy::@4119": 0x80411c18,
		"Enemy::@4120": 0x80411c1c,
		"Enemy::@4121": 0x80411c20,
		"Enemy::@4316": 0x80411c2c,
		"@4316": 0x80411c2c,
		"Enemy::@4317": 0x80411c30,
		"@4317": 0x80411c30,
		"Enemy::@4542": 0x80411c48,
		"@4542": 0x80411c48,
		"Enemy::@4739": 0x80411c4c,
		"Enemy::@5170": 0x80411c58,
		"Enemy::cTelesaColorStart": 0x80411c68,
		"cTelesaColorStart": 0x80411c68,
		"Enemy::@4397": 0x80411cb0,
		"Enemy::@4398": 0x80411cb4,
		"Enemy::@4454": 0x80411cb8,
		"Enemy::@4545": 0x80411cc4,
		"@unnamed@::cBodyColorOnFire": 0x80411d08,
		"cBodyColorOnFire": 0x80411d08,
		"@unnamed@::cBodyColorOnCool": 0x80411d10,
		"cBodyColorOnCool": 0x80411d10,
		"@unnamed@::cBodyColorOnSilver": 0x80411d18,
		"cBodyColorOnSilver": 0x80411d18,
		"Enemy::@4323": 0x80411d58,
		"Enemy::@5181": 0x80411d74,
		"Enemy::@5182": 0x80411d78,
		"Enemy::@5382": 0x80411d80,
		"@5382": 0x80411d80,
		"Enemy::@5383": 0x80411d84,
		"@5383": 0x80411d84,
		"Enemy::@5385": 0x80411d8c,
		"@5385": 0x80411d8c,
		"Enemy::@6626": 0x80411dac,
		"@6626": 0x80411dac,
		"Enemy::@6946": 0x80411db0,
		"@6946": 0x80411db0,
		"Enemy::@7428": 0x80411db4,
		"@7428": 0x80411db4,
		"Enemy::@7608": 0x80411dc8,
		"@7608": 0x80411dc8,
		"Enemy::@7609": 0x80411dcc,
		"@7609": 0x80411dcc,
		"Enemy::@7686": 0x80411dd0,
		"@7686": 0x80411dd0,
		"Enemy::@7687": 0x80411dd4,
		"@7687": 0x80411dd4,
		"Enemy::@7890": 0x80411dd8,
		"@7890": 0x80411dd8,
		"Enemy::@7891": 0x80411ddc,
		"@7891": 0x80411ddc,
		"Enemy::@7892": 0x80411de0,
		"@7892": 0x80411de0,
		"Enemy::@9121": 0x80411df4,
		"@9121": 0x80411df4,
		"Enemy::@9130": 0x80411dfc,
		"@9130": 0x80411dfc,
		"Enemy::@9149": 0x80411e0c,
		"@9149": 0x80411e0c,
		"Enemy::@9480": 0x80411e10,
		"Enemy::@9481": 0x80411e14,
		"@9481": 0x80411e14,
		"Enemy::@1696": 0x80411e18,
		"@1696": 0x80411e18,
		"Enemy::@2231": 0x80411e30,
		"Enemy::@2232": 0x80411e34,
		"Enemy::@2299": 0x80411e38,
		"Enemy::@4347": 0x80411e4c,
		"Enemy::@5398": 0x80411e74,
		"@5398": 0x80411e74,
		"Enemy::@5399": 0x80411e78,
		"@5399": 0x80411e78,
		"Enemy::@6207": 0x80411ea4,
		"Enemy::@6288": 0x80411ea8,
		"@6288": 0x80411ea8,
		"Enemy::@6924": 0x80411eb8,
		"Enemy::@6925": 0x80411ebc,
		"Enemy::@6926": 0x80411ec0,
		"Enemy::@6927": 0x80411ec4,
		"Enemy::@6928": 0x80411ec8,
		"Enemy::@7212": 0x80411ecc,
		"@7212": 0x80411ecc,
		"Enemy::@7214": 0x80411ed0,
		"@7214": 0x80411ed0,
		"Enemy::@7403": 0x80411ee4,
		"@7403": 0x80411ee4,
		"Enemy::@7463": 0x80411ee8,
		"Enemy::@7464": 0x80411eec,
		"@7464": 0x80411eec,
		"Enemy::@7465": 0x80411ef0,
		"@7465": 0x80411ef0,
		"Enemy::@7466": 0x80411ef4,
		"@7466": 0x80411ef4,
		"Enemy::@7467": 0x80411ef8,
		"@7467": 0x80411ef8,
		"Enemy::@7468": 0x80411efc,
		"@7468": 0x80411efc,
		"Enemy::@7469": 0x80411f00,
		"@7469": 0x80411f00,
		"Enemy::@7470": 0x80411f04,
		"@7470": 0x80411f04,
		"Enemy::@7992": 0x80411f10,
		"@7992": 0x80411f10,
		"Enemy::@7993": 0x80411f14,
		"@7993": 0x80411f14,
		"Enemy::@8328": 0x80411f24,
		"Enemy::@8337": 0x80411f2c,
		"Enemy::@3402": 0x80411f44,
		"Enemy::@3406": 0x80411f54,
		"Enemy::@3960": 0x80411f94,
		"Enemy::@4816": 0x80411fb0,
		"@4816": 0x80411fb0,
		"Enemy::@4259": 0x80412020,
		"Enemy::@4308": 0x80412030,
		"@4308": 0x80412030,
		"Enemy::@4309": 0x80412034,
		"@4309": 0x80412034,
		"Enemy::@5143": 0x80412054,
		"Enemy::@6097": 0x8041207c,
		"Enemy::@5477": 0x80412130,
		"Enemy::@6611": 0x80412174,
		"@6611": 0x80412174,
		"Enemy::@6612": 0x80412178,
		"@6612": 0x80412178,
		"Enemy::@6613": 0x8041217c,
		"@6613": 0x8041217c,
		"Enemy::@6614": 0x80412180,
		"@6614": 0x80412180,
		"Enemy::@6615": 0x80412184,
		"@6615": 0x80412184,
		"Enemy::@6852": 0x80412188,
		"@6852": 0x80412188,
		"Enemy::@6853": 0x8041218c,
		"@6853": 0x8041218c,
		"Enemy::@6854": 0x80412190,
		"@6854": 0x80412190,
		"Enemy::@7177": 0x80412194,
		"@7177": 0x80412194,
		"Enemy::@7178": 0x80412198,
		"@7178": 0x80412198,
		"Enemy::@7311": 0x8041219c,
		"@7311": 0x8041219c,
		"Enemy::@7312": 0x804121a0,
		"@7312": 0x804121a0,
		"Enemy::@7313": 0x804121a4,
		"@7313": 0x804121a4,
		"Enemy::@7314": 0x804121ac,
		"@7314": 0x804121ac,
		"Enemy::@7394": 0x804121b0,
		"@7394": 0x804121b0,
		"Enemy::@7514": 0x804121b4,
		"@7514": 0x804121b4,
		"Enemy::@7515": 0x804121b8,
		"@7515": 0x804121b8,
		"Enemy::@7516": 0x804121bc,
		"@7516": 0x804121bc,
		"Enemy::@7517": 0x804121c0,
		"@7517": 0x804121c0,
		"Enemy::@7518": 0x804121c4,
		"@7518": 0x804121c4,
		"Enemy::@7519": 0x804121c8,
		"@7519": 0x804121c8,
		"Enemy::@7601": 0x804121d0,
		"@7601": 0x804121d0,
		"Enemy::@7603": 0x804121d4,
		"@7603": 0x804121d4,
		"Enemy::@7605": 0x804121d8,
		"@7605": 0x804121d8,
		"Enemy::@7790": 0x804121e0,
		"@7790": 0x804121e0,
		"Enemy::@7791": 0x804121e4,
		"@7791": 0x804121e4,
		"Enemy::@7793": 0x804121ec,
		"@7793": 0x804121ec,
		"Enemy::@7794": 0x804121f0,
		"@7794": 0x804121f0,
		"Enemy::@7795": 0x804121f4,
		"@7795": 0x804121f4,
		"Enemy::@7796": 0x804121f8,
		"@7796": 0x804121f8,
		"Enemy::@3779": 0x8041223c,
		"Enemy::@5087": 0x80412284,
		"Enemy::@5295": 0x80412288,
		"Enemy::@5587": 0x80412294,
		"@5587": 0x80412294,
		"Enemy::@5746": 0x80412298,
		"@5746": 0x80412298,
		"Enemy::@5749": 0x8041229c,
		"@5749": 0x8041229c,
		"Enemy::@5760": 0x804122a0,
		"@5760": 0x804122a0,
		"Enemy::@5764": 0x804122a4,
		"@5764": 0x804122a4,
		"Enemy::@5766": 0x804122a8,
		"@5766": 0x804122a8,
		"Enemy::@5769": 0x804122ac,
		"@5769": 0x804122ac,
		"Enemy::@4212": 0x80412308,
		"Enemy::@5077": 0x80412328,
		"Enemy::@5078": 0x8041232c,
		"Enemy::@5185": 0x80412334,
		"Enemy::@5187": 0x8041233c,
		"Enemy::@5208": 0x80412340,
		"Enemy::@5209": 0x80412344,
		"Enemy::@5524": 0x80412360,
		"@5524": 0x80412360,
		"Enemy::@3961": 0x804123b0,
		"Enemy::@3886": 0x804123e4,
		"Enemy::@4510": 0x80412408,
		"@4510": 0x80412408,
		"Enemy::@4511": 0x8041240c,
		"@4511": 0x8041240c,
		"Enemy::@4512": 0x80412410,
		"Enemy::@4513": 0x80412414,
		"Enemy::@4550": 0x8041241c,
		"Enemy::@4783": 0x80412428,
		"Enemy::@5058": 0x80412440,
		"Enemy::@4788": 0x80412478,
		"Enemy::@5924": 0x80412490,
		"@5924": 0x80412490,
		"Enemy::@5926": 0x80412498,
		"@5926": 0x80412498,
		"Enemy::@5928": 0x804124a0,
		"@5928": 0x804124a0,
		"Enemy::@5929": 0x804124a4,
		"@5929": 0x804124a4,
		"Enemy::@5930": 0x804124a8,
		"@5930": 0x804124a8,
		"Enemy::@5931": 0x804124ac,
		"@5931": 0x804124ac,
		"Enemy::@5932": 0x804124b0,
		"@5932": 0x804124b0,
		"Enemy::@5933": 0x804124b4,
		"@5933": 0x804124b4,
		"Enemy::@5934": 0x804124b8,
		"@5934": 0x804124b8,
		"Enemy::@6152": 0x804124c8,
		"Enemy::@6257": 0x804124e4,
		"@6257": 0x804124e4,
		"Enemy::@6259": 0x804124ec,
		"@6259": 0x804124ec,
		"Enemy::@6260": 0x804124f0,
		"@6260": 0x804124f0,
		"Enemy::@6301": 0x804124f4,
		"@6301": 0x804124f4,
		"Enemy::@6816": 0x804124f8,
		"@6816": 0x804124f8,
		"Enemy::@6817": 0x804124fc,
		"@6817": 0x804124fc,
		"Enemy::@6818": 0x80412500,
		"@6818": 0x80412500,
		"Enemy::@7196": 0x80412504,
		"Enemy::@7197": 0x80412508,
		"@7197": 0x80412508,
		"Enemy::@8021": 0x80412518,
		"@8021": 0x80412518,
		"Enemy::@8022": 0x8041251c,
		"@8022": 0x8041251c,
		"Enemy::@8023": 0x80412520,
		"Enemy::@8024": 0x80412524,
		"@8024": 0x80412524,
		"Enemy::@8025": 0x80412528,
		"@8025": 0x80412528,
		"Enemy::@8026": 0x8041252c,
		"@8026": 0x8041252c,
		"Enemy::@8027": 0x80412530,
		"@8027": 0x80412530,
		"Enemy::@8028": 0x80412534,
		"@8028": 0x80412534,
		"Enemy::@8055": 0x80412538,
		"@8055": 0x80412538,
		"Enemy::@8182": 0x8041253c,
		"@8182": 0x8041253c,
		"Enemy::@8346": 0x80412540,
		"@8346": 0x80412540,
		"Enemy::@8750": 0x80412544,
		"@8750": 0x80412544,
		"Enemy::@8751": 0x80412548,
		"@8751": 0x80412548,
		"Enemy::@8850": 0x80412558,
		"@8850": 0x80412558,
		"Enemy::@9020": 0x8041255c,
		"@9020": 0x8041255c,
		"Enemy::@2294": 0x80412568,
		"Enemy::@2295": 0x8041256c,
		"Enemy::@2296": 0x80412570,
		"Enemy::@2297": 0x80412574,
		"Enemy::@2332": 0x8041257c,
		"Enemy::@2334": 0x80412580,
		"Enemy::@2336": 0x80412584,
		"Enemy::@3191": 0x8041258c,
		"Enemy::@3832": 0x8041261c,
		"Enemy::@4926": 0x80412670,
		"Enemy::@4927": 0x80412674,
		"Enemy::@4930": 0x80412680,
		"Enemy::@5101": 0x80412690,
		"Enemy::@6157": 0x804126e4,
		"Enemy::@6170": 0x804126f0,
		"Enemy::@4040": 0x80412744,
		"Enemy::@4419": 0x80412748,
		"Enemy::@4678": 0x80412754,
		"Enemy::@5139": 0x8041276c,
		"Enemy::@5505": 0x80412784,
		"@5505": 0x80412784,
		"Enemy::@6136": 0x804127b0,
		"Enemy::@6849": 0x804127c4,
		"@6849": 0x804127c4,
		"Enemy::@6896": 0x804127c8,
		"Enemy::@6897": 0x804127cc,
		"Enemy::@6908": 0x804127d0,
		"Enemy::@6910": 0x804127d4,
		"@6910": 0x804127d4,
		"Enemy::@6912": 0x804127d8,
		"@6912": 0x804127d8,
		"Enemy::@6913": 0x804127dc,
		"@6913": 0x804127dc,
		"Enemy::@7029": 0x804127e0,
		"@7029": 0x804127e0,
		"Enemy::@7030": 0x804127e4,
		"@7030": 0x804127e4,
		"Enemy::@7134": 0x804127e8,
		"@7134": 0x804127e8,
		"Enemy::@7330": 0x804127ec,
		"@7330": 0x804127ec,
		"Enemy::@7455": 0x804127f4,
		"Enemy::@7456": 0x804127f8,
		"@7456": 0x804127f8,
		"Enemy::@7457": 0x804127fc,
		"Enemy::@8806": 0x80412834,
		"@8806": 0x80412834,
		"Enemy::@8911": 0x80412838,
		"@8911": 0x80412838,
		"Enemy::@8985": 0x80412840,
		"@8985": 0x80412840,
		"Enemy::@8986": 0x80412844,
		"@8986": 0x80412844,
		"Enemy::@8987": 0x80412848,
		"@8987": 0x80412848,
		"Enemy::@8988": 0x8041284c,
		"@8988": 0x8041284c,
		"Enemy::@9005": 0x80412850,
		"@9005": 0x80412850,
		"Enemy::@4202": 0x804128e8,
		"Enemy::@4203": 0x804128ec,
		"@4203": 0x804128ec,
		"Enemy::@4204": 0x804128f0,
		"Enemy::@4206": 0x804128f8,
		"Enemy::@4208": 0x80412900,
		"Enemy::@4209": 0x80412904,
		"Enemy::@2022": 0x80412920,
		"Enemy::@2023": 0x80412924,
		"Enemy::@2024": 0x80412928,
		"Enemy::@2025": 0x8041292c,
		"Enemy::@3873": 0x80412968,
		"@3873": 0x80412968,
		"Enemy::@4014": 0x80412988,
		"Enemy::@5516": 0x804129c8,
		"@5516": 0x804129c8,
		"Enemy::@5774": 0x804129e0,
		"Enemy::@4238": 0x80412a2c,
		"Enemy::@4239": 0x80412a30,
		"Enemy::@4240": 0x80412a34,
		"Enemy::@4802": 0x80412a68,
		"@4802": 0x80412a68,
		"Enemy::@5089": 0x80412a70,
		"Enemy::@5090": 0x80412a74,
		"Enemy::@5152": 0x80412a78,
		"Enemy::@2030": 0x80412aac,
		"Enemy::@2032": 0x80412ab0,
		"Enemy::@3308": 0x80412af4,
		"Enemy::@2082": 0x80412b30,
		"Enemy::@2083": 0x80412b34,
		"Enemy::@2084": 0x80412b38,
		"Enemy::@2085": 0x80412b3c,
		"Enemy::@2086": 0x80412b40,
		"Enemy::@2087": 0x80412b44,
		"Enemy::@2088": 0x80412b48,
		"Enemy::@4374": 0x80412bd8,
		"@4374": 0x80412bd8,
		"Enemy::@4377": 0x80412be4,
		"Enemy::@4378": 0x80412be8,
		"Enemy::@4379": 0x80412bec,
		"Enemy::@4832": 0x80412c08,
		"Enemy::@4835": 0x80412c0c,
		"Enemy::@4836": 0x80412c10,
		"Enemy::@2474": 0x80412c30,
		"Enemy::@1638": 0x80412ca8,
		"Enemy::@1640": 0x80412cac,
		"Enemy::@1642": 0x80412cb0,
		"Enemy::@1644": 0x80412cb4,
		"Enemy::@1647": 0x80412cb8,
		"@1647": 0x80412cb8,
		"Enemy::@1649": 0x80412cbc,
		"@1649": 0x80412cbc,
		"Enemy::@1651": 0x80412cc0,
		"@1651": 0x80412cc0,
		"Enemy::@1653": 0x80412cc4,
		"Enemy::@1655": 0x80412cc8,
		"Enemy::@1659": 0x80412ccc,
		"Enemy::@1663": 0x80412cd0,
		"Enemy::@1665": 0x80412cd4,
		"Enemy::@1668": 0x80412cd8,
		"Enemy::@1670": 0x80412cdc,
		"Enemy::@1680": 0x80412ce0,
		"Enemy::@1683": 0x80412ce4,
		"Enemy::@1685": 0x80412ce8,
		"Enemy::@1688": 0x80412cec,
		"Enemy::@1779": 0x80412cf0,
		"Enemy::@1781": 0x80412cf4,
		"Enemy::@1787": 0x80412d00,
		"Enemy::@1789": 0x80412d04,
		"@1789": 0x80412d04,
		"Enemy::@1791": 0x80412d08,
		"@1791": 0x80412d08,
		"Enemy::@1794": 0x80412d0c,
		"@1794": 0x80412d0c,
		"Enemy::@1796": 0x80412d10,
		"@1796": 0x80412d10,
		"Enemy::@1804": 0x80412d18,
		"@1804": 0x80412d18,
		"Enemy::@1807": 0x80412d1c,
		"Enemy::@1809": 0x80412d20,
		"Enemy::@1811": 0x80412d24,
		"Enemy::@1813": 0x80412d28,
		"@1813": 0x80412d28,
		"Enemy::@1815": 0x80412d2c,
		"@1815": 0x80412d2c,
		"Enemy::@1817": 0x80412d30,
		"@1817": 0x80412d30,
		"Enemy::@1819": 0x80412d34,
		"Enemy::@1823": 0x80412d38,
		"@1823": 0x80412d38,
		"Enemy::@4553": 0x80412dc0,
		"Enemy::@4744": 0x80412dcc,
		"Enemy::@4745": 0x80412dd0,
		"Enemy::@4746": 0x80412dd4,
		"Enemy::@4877": 0x80412dd8,
		"Enemy::@4878": 0x80412ddc,
		"@4878": 0x80412ddc,
		"Enemy::@4879": 0x80412de0,
		"@4879": 0x80412de0,
		"Enemy::@4880": 0x80412de4,
		"@4880": 0x80412de4,
		"Enemy::@4881": 0x80412de8,
		"@4881": 0x80412de8,
		"Enemy::sEmitSandFrameFoot": 0x80412e28,
		"sEmitSandFrameFoot": 0x80412e28,
		"Enemy::@2291": 0x80412e68,
		"Enemy::@2309": 0x80412e6c,
		"Enemy::@2310": 0x80412e70,
		"Enemy::@4096": 0x80412efc,
		"Enemy::@4097": 0x80412f00,
		"Enemy::@4232": 0x80412f24,
		"Enemy::@4233": 0x80412f28,
		"Enemy::@4446": 0x80412f34,
		"@4446": 0x80412f34,
		"Enemy::@4729": 0x80412f40,
		"Enemy::@4730": 0x80412f44,
		"Enemy::@4731": 0x80412f48,
		"Enemy::@4732": 0x80412f4c,
		"Enemy::@4735": 0x80412f58,
		"Enemy::@4736": 0x80412f5c,
		"Enemy::@5290": 0x80412f7c,
		"Enemy::@6552": 0x80412f98,
		"Enemy::@2137": 0x80413020,
		"Enemy::@2138": 0x80413024,
		"Enemy::@2149": 0x80413030,
		"@unnamed@::cRedColor": 0x80413040,
		"cRedColor": 0x80413040,
		"@unnamed@::cBlueColor": 0x80413048,
		"cBlueColor": 0x80413048,
		"Enemy::@4684": 0x80413140,
		"Enemy::@3864": 0x804131ac,
		"@3864": 0x804131ac,
		"Enemy::@4199": 0x804131d0,
		"Enemy::@5252": 0x80413214,
		"Enemy::@5253": 0x80413218,
		"Enemy::@5506": 0x80413220,
		"@5506": 0x80413220,
		"Enemy::@5507": 0x80413224,
		"@5507": 0x80413224,
		"Enemy::@1966": 0x80413240,
		"Enemy::@2039": 0x80413244,
		"Enemy::@2040": 0x80413248,
		"Enemy::@2119": 0x8041324c,
		"Enemy::@2152": 0x80413250,
		"Enemy::@3860": 0x804132b0,
		"Enemy::@3861": 0x804132b4,
		"Enemy::@3862": 0x804132b8,
		"@3862": 0x804132b8,
		"Enemy::@6003": 0x8041333c,
		"@6003": 0x8041333c,
		"Enemy::@6064": 0x80413364,
		"@6064": 0x80413364,
		"Enemy::@3774": 0x804133a4,
		"Enemy::@4620": 0x804133b8,
		"@4620": 0x804133b8,
		"Enemy::@6055": 0x804133c8,
		"@6055": 0x804133c8,
		"Enemy::@6419": 0x804133d0,
		"@6419": 0x804133d0,
		"Enemy::@6420": 0x804133d4,
		"@6420": 0x804133d4,
		"Enemy::@6421": 0x804133d8,
		"@6421": 0x804133d8,
		"Enemy::@6422": 0x804133dc,
		"@6422": 0x804133dc,
		"Enemy::@6423": 0x804133e0,
		"@6423": 0x804133e0,
		"Enemy::@3672": 0x80413438,
		"Enemy::@4251": 0x80413468,
		"Enemy::@5366": 0x804134d8,
		"Enemy::@3636": 0x80413524,
		"Enemy::@4355": 0x804135d8,
		"Enemy::@5193": 0x80413690,
		"Enemy::@3600": 0x80413788,
		"Enemy::@4795": 0x804137a8,
		"Enemy::@5098": 0x804137b0,
		"Enemy::@2126": 0x804137c4,
		"Enemy::@2127": 0x804137c8,
		"Enemy::@2128": 0x804137cc,
		"Enemy::@2129": 0x804137d0,
		"Enemy::@2130": 0x804137d4,
		"Enemy::@2131": 0x804137d8,
		"Enemy::@4348": 0x8041385c,
		"Enemy::@4349": 0x80413860,
		"Enemy::@4598": 0x80413874,
		"Enemy::@3787": 0x804138a4,
		"Enemy::@3789": 0x804138a8,
		"Enemy::@3794": 0x804138b0,
		"Camera::@2112": 0x804138c4,
		"Camera::@2113": 0x804138c8,
		"Camera::@2304": 0x804138d0,
		"Camera::@2305": 0x804138d4,
		"Camera::@2306": 0x804138d8,
		"Camera::@2307": 0x804138dc,
		"Camera::@2308": 0x804138e0,
		"Camera::@2309": 0x804138e4,
		"Camera::@3696": 0x804138f0,
		"Camera::@3697": 0x804138f4,
		"Camera::@1717": 0x804138f8,
		"@1717": 0x804138f8,
		"Camera::@2650": 0x80413900,
		"Camera::@2651": 0x80413904,
		"Camera::@2670": 0x80413908,
		"Camera::@2671": 0x8041390c,
		"Camera::@2672": 0x80413910,
		"Camera::@2759": 0x80413928,
		"Camera::@2760": 0x8041392c,
		"Camera::@2761": 0x80413930,
		"Camera::@3274": 0x80413940,
		"Camera::@3275": 0x80413944,
		"Camera::@3276": 0x80413948,
		"Camera::@3277": 0x8041394c,
		"Camera::@3278": 0x80413950,
		"Camera::@3279": 0x80413954,
		"Camera::@3378": 0x80413960,
		"Camera::@3735": 0x80413964,
		"Camera::@3736": 0x8041396c,
		"Camera::@3834": 0x80413970,
		"Camera::@1655": 0x80413980,
		"Camera::@1663": 0x80413990,
		"Camera::@1659": 0x804139a0,
		"Camera::@1660": 0x804139a4,
		"Camera::@2403": 0x804139e4,
		"Camera::@2404": 0x804139e8,
		"Camera::@2190": 0x804139fc,
		"Camera::@2191": 0x80413a00,
		"Camera::@2080": 0x80413a18,
		"Camera::@2082": 0x80413a20,
		"Camera::@2326": 0x80413a38,
		"@2326": 0x80413a38,
		"Camera::@2327": 0x80413a3c,
		"Camera::@2328": 0x80413a40,
		"Camera::@2329": 0x80413a44,
		"Camera::@2330": 0x80413a48,
		"Camera::@2331": 0x80413a4c,
		"Camera::@1896": 0x80413a60,
		"@1896": 0x80413a60,
		"Camera::@1900": 0x80413a68,
		"Camera::@1902": 0x80413a6c,
		"Camera::@1904": 0x80413a70,
		"Camera::@1914": 0x80413a7c,
		"@1914": 0x80413a7c,
		"Camera::@1916": 0x80413a80,
		"@1916": 0x80413a80,
		"Camera::@1918": 0x80413a84,
		"@1918": 0x80413a84,
		"Camera::@1920": 0x80413a88,
		"@1920": 0x80413a88,
		"Camera::@1938": 0x80413a8c,
		"Camera::@1940": 0x80413a90,
		"Camera::@1942": 0x80413a94,
		"Camera::@1945": 0x80413a98,
		"Camera::@1947": 0x80413a9c,
		"Camera::@1958": 0x80413ab0,
		"Camera::@1960": 0x80413ab4,
		"Camera::@1963": 0x80413ab8,
		"Camera::@1965": 0x80413abc,
		"Camera::@2121": 0x80413ac0,
		"Camera::@2126": 0x80413ac4,
		"Camera::@2128": 0x80413ac8,
		"Camera::@2132": 0x80413acc,
		"Camera::@2134": 0x80413ad0,
		"Camera::@2137": 0x80413ad4,
		"Camera::@2145": 0x80413ad8,
		"Camera::@2205": 0x80413adc,
		"Camera::@1807": 0x80413af8,
		"Camera::@1808": 0x80413afc,
		"Camera::@1810": 0x80413b04,
		"Camera::@1811": 0x80413b08,
		"Camera::@2158": 0x80413bb8,
		"Camera::@2159": 0x80413bbc,
		"Camera::@2160": 0x80413bc0,
		"Camera::@1864": 0x80413bdc,
		"@1864": 0x80413bdc,
		"Camera::@1865": 0x80413be0,
		"Camera::@1887": 0x80413bf0,
		"@1887": 0x80413bf0,
		"Camera::@2042": 0x80413c18,
		"Camera::@2043": 0x80413c1c,
		"Camera::@2044": 0x80413c20,
		"Camera::@2045": 0x80413c24,
		"Camera::@1778": 0x80413c30,
		"Camera::@1652": 0x80413c58,
		"Camera::@1653": 0x80413c5c,
		"Camera::@1758": 0x80413c70,
		"Camera::@1759": 0x80413c74,
		"@1759": 0x80413c74,
		"Camera::@1762": 0x80413c88,
		"@1762": 0x80413c88,
		"Camera::@1763": 0x80413c8c,
		"Camera::@2361": 0x80413ca0,
		"Camera::@2362": 0x80413ca4,
		"Camera::@2363": 0x80413ca8,
		"Camera::@2364": 0x80413cac,
		"Camera::@2711": 0x80413cb0,
		"Camera::@2712": 0x80413cb4,
		"Camera::@2713": 0x80413cb8,
		"Camera::@2714": 0x80413cbc,
		"Camera::@2715": 0x80413cc0,
		"Camera::@2716": 0x80413cc4,
		"Camera::@2717": 0x80413cc8,
		"Camera::@1705": 0x80413cd4,
		"Camera::@1706": 0x80413cd8,
		"Camera::@1707": 0x80413cdc,
		"Camera::@1710": 0x80413ce8,
		"Camera::@1765": 0x80413cec,
		"@1765": 0x80413cec,
		"Camera::@1768": 0x80413d34,
		"Camera::@1839": 0x80413d38,
		"Camera::@1840": 0x80413d3c,
		"Camera::@1841": 0x80413d40,
		"Animal::@2190": 0x80413d50,
		"Animal::@2191": 0x80413d54,
		"Animal::@2192": 0x80413d58,
		"Animal::@2193": 0x80413d5c,
		"Animal::@2194": 0x80413d60,
		"Animal::@2195": 0x80413d64,
		"Animal::@2196": 0x80413d68,
		"Animal::@2202": 0x80413d78,
		"Animal::@2203": 0x80413d7c,
		"Animal::@2289": 0x80413d80,
		"Animal::@2290": 0x80413d84,
		"Animal::@2526": 0x80413d88,
		"Animal::@2527": 0x80413d8c,
		"Animal::@2528": 0x80413d90,
		"Animal::@2529": 0x80413d94,
		"Animal::@2530": 0x80413d98,
		"Animal::@2531": 0x80413d9c,
		"Animal::@2532": 0x80413da0,
		"Animal::@2533": 0x80413da4,
		"Animal::@2577": 0x80413da8,
		"Animal::@2578": 0x80413dac,
		"Animal::@2580": 0x80413db4,
		"Animal::@2362": 0x80413dc0,
		"Animal::@2450": 0x80413dc4,
		"Animal::@2451": 0x80413dc8,
		"Animal::@2452": 0x80413dcc,
		"Animal::@2453": 0x80413dd0,
		"Animal::@2454": 0x80413dd4,
		"Animal::@2455": 0x80413dd8,
		"Animal::@2456": 0x80413ddc,
		"Animal::@2457": 0x80413de0,
		"Animal::@2689": 0x80413dec,
		"Animal::@2601": 0x80413df4,
		"Animal::@2605": 0x80413df8,
		"Animal::@2606": 0x80413dfc,
		"Animal::@2760": 0x80413e00,
		"Animal::@2761": 0x80413e04,
		"Animal::@2762": 0x80413e08,
		"Animal::@2763": 0x80413e0c,
		"Animal::@2764": 0x80413e10,
		"Animal::@2765": 0x80413e14,
		"Animal::@2766": 0x80413e18,
		"Animal::@2767": 0x80413e1c,
		"Animal::@2768": 0x80413e20,
		"Animal::@2929": 0x80413e24,
		"Animal::@3022": 0x80413e28,
		"Animal::@3023": 0x80413e2c,
		"Animal::@3201": 0x80413e40,
		"Animal::@3267": 0x80413e44,
		"Animal::@3268": 0x80413e48,
		"Animal::@3269": 0x80413e4c,
		"Animal::@2600": 0x80413e50,
		"Animal::@2613": 0x80413e54,
		"Animal::@1564": 0x80413e58,
		"Animal::@1566": 0x80413e5c,
		"Animal::@1568": 0x80413e60,
		"Animal::@1570": 0x80413e64,
		"Animal::@1572": 0x80413e68,
		"Animal::@1574": 0x80413e6c,
		"Animal::@1576": 0x80413e70,
		"Animal::@1578": 0x80413e74,
		"Animal::@2158": 0x80413e78,
		"Animal::@2159": 0x80413e7c,
		"Animal::@2160": 0x80413e80,
		"Animal::@3220": 0x80413e94,
		"Animal::@3221": 0x80413e98,
		"Animal::@3303": 0x80413ea8,
		"Animal::@3407": 0x80413eac,
		"Animal::@3411": 0x80413eb0,
		"Animal::@3412": 0x80413eb4,
		"Animal::@3453": 0x80413eb8,
		"Animal::@3544": 0x80413ebc,
		"Animal::@3545": 0x80413ec0,
		"Animal::@3691": 0x80413ec4,
		"Animal::@3692": 0x80413ec8,
		"Animal::@3773": 0x80413ecc,
		"Animal::@3930": 0x80413ed0,
		"Animal::@3933": 0x80413ed4,
		"Animal::@3935": 0x80413ed8,
		"Animal::@3937": 0x80413edc,
		"Animal::@3939": 0x80413ee0,
		"Animal::@3944": 0x80413ee4,
		"Animal::@3946": 0x80413ee8,
		"Animal::@3951": 0x80413eec,
		"Animal::@3954": 0x80413ef0,
		"Animal::@4172": 0x80413ef4,
		"Animal::@4173": 0x80413ef8,
		"Animal::@4755": 0x80413efc,
		"Animal::@4897": 0x80413f00,
		"Animal::@4898": 0x80413f08,
		"Animal::@4921": 0x80413f0c,
		"Animal::@4922": 0x80413f10,
		"Animal::@4923": 0x80413f14,
		"Animal::@3087": 0x80413f18,
		"Animal::@3088": 0x80413f1c,
		"Animal::@3089": 0x80413f20,
		"Animal::@3203": 0x80413f24,
		"Animal::@3204": 0x80413f28,
		"Animal::@3205": 0x80413f2c,
		"Animal::@3206": 0x80413f30,
		"Animal::@3207": 0x80413f34,
		"Animal::@3208": 0x80413f38,
		"Animal::@3448": 0x80413f40,
		"Animal::@3664": 0x80413f44,
		"Animal::@3667": 0x80413f48,
		"Animal::@3668": 0x80413f4c,
		"Animal::@3669": 0x80413f54,
		"Animal::@3671": 0x80413f58,
		"Animal::@3673": 0x80413f5c,
		"Animal::@3676": 0x80413f60,
		"Animal::@3852": 0x80413f70,
		"Animal::@3853": 0x80413f74,
		"Animal::@3854": 0x80413f78,
		"Animal::@3855": 0x80413f7c,
		"Animal::@4245": 0x80413f80,
		"Animal::@4246": 0x80413f84,
		"Animal::@4332": 0x80413f88,
		"Animal::@4452": 0x80413f8c,
		"Animal::@4453": 0x80413f90,
		"@4453": 0x80413f90,
		"Animal::@4454": 0x80413f94,
		"Animal::@4455": 0x80413f98,
		"Animal::@4456": 0x80413f9c,
		"Animal::@4641": 0x80413fa0,
		"Animal::@4642": 0x80413fa4,
		"Animal::@4709": 0x80413fac,
		"Animal::@4869": 0x80413fb0,
		"Animal::@4870": 0x80413fb4,
		"Animal::@5080": 0x80413fbc,
		"Animal::@5340": 0x80413fc0,
		"Animal::@2489": 0x80413fc8,
		"Animal::@2490": 0x80413fcc,
		"Animal::@2491": 0x80413fd0,
		"Animal::@2492": 0x80413fd8,
		"Animal::@2586": 0x80413fdc,
		"Animal::@2587": 0x80413fe0,
		"Animal::@2588": 0x80413fe4,
		"Animal::@2589": 0x80413fe8,
		"Animal::@2590": 0x80413fec,
		"Animal::@2591": 0x80413ff0,
		"Animal::@2592": 0x80413ff4,
		"Animal::@2593": 0x80413ff8,
		"Animal::@2710": 0x80414000,
	},
	"GMSE01": {
		"Runtime.PPCEABI.H::memset": 0x80003100,
		"memset": 0x80003100,
		"Runtime.PPCEABI.H::__fill_mem": 0x80003130,
		"__fill_mem": 0x80003130,
		"Runtime.PPCEABI.H::memcpy": 0x800031f4,
		"memcpy": 0x800031f4,
		"TRK_MINNOW_DOLPHIN::TRK_memcpy": 0x80003244,
		"TRK_memcpy": 0x80003244,
		"TRK_MINNOW_DOLPHIN::TRK_memset": 0x80003268,
		"TRK_memset": 0x80003268,
		"TRK_MINNOW_DOLPHIN::__TRK_reset": 0x800051cc,
		"__TRK_reset": 0x800051cc,
		"os::__check_pad3": 0x800051ec,
		"__check_pad3": 0x800051ec,
		"os::__start": 0x8000522c,
		"os::__init_registers": 0x80005364,
		"__init_registers": 0x80005364,
		"os::__init_data": 0x80005380,
		"__init_data": 0x80005380,
		"os::__init_hardware": 0x80005440,
		"__init_hardware": 0x80005440,
		"os::__flush_cache": 0x80005460,
		"__flush_cache": 0x80005460,
		"Runtime.PPCEABI.H::@152": 0x80005540,
		"Runtime.PPCEABI.H::@157": 0x80005548,
		"Runtime.PPCEABI.H::@174": 0x80005550,
		"Runtime.PPCEABI.H::@182": 0x80005568,
		"Runtime.PPCEABI.H::@201": 0x80005570,
		"@201": 0x80005570,
		"Runtime.PPCEABI.H::@153": 0x800055a0,
		"Runtime.PPCEABI.H::@158": 0x800055ac,
		"Runtime.PPCEABI.H::@175": 0x800055b8,
		"Runtime.PPCEABI.H::@183": 0x800055c4,
		"Runtime.PPCEABI.H::@202": 0x800055d0,
		"@202": 0x800055d0,
		"main::main": 0x80005600,
		"main::__sinit_main_cpp": 0x80005644,
		"__sinit_main_cpp": 0x80005644,
		"Animal::CLBChaseGeneralConstantSpecifySpeed": 0x80009400,
		"Animal::CLBPalFrame": 0x8000ab38,
		"Animal::CLBRoundf": 0x8000ab90,
		"Animal::SMS_EasyEmitParticle": 0x8000e3a4,
		"MAnmSoundMario::startAnimSound": 0x80012c80,
		"MSound::getDistPowFromCamera": 0x800151c8,
		"getDistPowFromCamera": 0x800151c8,
		"Camera::CLBRoundf": 0x800210ec,
		"Camera::CLBChaseGeneralConstantSpecifySpeed": 0x8002631c,
		"Camera::CLBChaseConstantSpecifyFrame": 0x80026e84,
		"Camera::CLBSquared": 0x80029d54,
		"Camera::JMASCos": 0x8002d73c,
		"Camera::JMASSin": 0x8002d758,
		"Camera::__ct__Q26JDrama10TFlagT<Us>FUs": 0x8002f7dc,
		"Enemy::SpcTrace": 0x8003db3c,
		"Enemy::MsPerpendicFootToLineR": 0x800a98d4,
		"Enemy::__sinit_riccohook_cpp": 0x800c80d0,
		"__sinit_riccohook_cpp": 0x800c80d0,
		"TBombHeiManager::clipEnemies": 0x800cabfc,
		"TAmiNoko::emitEffects": 0x800f7158,
		"TAmiNoko::calcDirection": 0x800f7398,
		"calcDirection": 0x800f7398,
		"TGCConsole2::countBlueCoin": 0x8014757c,
		"countBlueCoin": 0x8014757c,
		"TGCConsole2::countShine": 0x80147a0c,
		"countShine": 0x80147a0c,
		"TGCConsole2::checkDolpic8": 0x801487d4,
		"checkDolpic8": 0x801487d4,
		"TGCConsole2::startDisappearTank": 0x8014c924,
		"startDisappearTank": 0x8014c924,
		"TCardSave::setMessageC": 0x80161c28,
		"setMessageC": 0x80161c28,
		"TOptionControl::checkInput": 0x801835ec,
		"checkInput": 0x801835ec,
		"GC2D::SMSGetMSound": 0x80183a8c,
		"SMSGetMSound": 0x80183a8c,
		"@unnamed@::ArrayWrapper<unsigned_long><unsigned_long>::begin": 0x80183a94,
		"TOptionSubtitleUnit::setInfluencedAlphaRecursive": 0x80185d4c,
		"TOptionSubtitleUnit::setState": 0x80185e38,
		"TOptionSubtitleUnit::update": 0x8018615c,
		"TOptionSubtitleUnit::TOptionSubtitleUnit": 0x801863e0,
		"TItemNozzle::calcRootMatrix": 0x801bbae4,
		"TJuiceBlock::touchActor": 0x801c32a0,
		"TWatermelonStatic::touchWater": 0x801cf9c8,
		"TAmiKing::calc": 0x801d4374,
		"System::evStartMontemanFanfare": 0x80289944,
		"evStartMontemanFanfare": 0x80289944,
		"System::evStartMontemanBGM": 0x802899e0,
		"evStartMontemanBGM": 0x802899e0,
		"TMarDirector::thpInit": 0x802b35cc,
		"thpInit": 0x802b35cc,
		"TEndingString::perform": 0x802b70dc,
		"TEndingString::TEndingString": 0x802b721c,
		"TEndingString::~TEndingString": 0x802b7304,
		"MSStageCubeFadeDouble::proc": 0x802ba3f4,
		"MSStageCubeFade::setBgmVolumeForce": 0x802ba78c,
		"setBgmVolumeForce": 0x802ba78c,
		"MSMainProc::getGateKeeperBGMStopFlag": 0x802bc4f8,
		"getGateKeeperBGMStopFlag": 0x802bc4f8,
		"MSMainProc::setGateKeeperBGMPlayFlag": 0x802bc540,
		"setGateKeeperBGMPlayFlag": 0x802bc540,
		"JKRArchive::~JKRArchive": 0x802bcab0,
		"JKRArchive::findDirectory": 0x802bcb14,
		"findDirectory": 0x802bcb14,
		"JKRArchive::findTypeResource": 0x802bccd4,
		"findTypeResource": 0x802bccd4,
		"JKRArchive::findFsResource": 0x802bcdcc,
		"findFsResource": 0x802bcdcc,
		"JKRArchive::findIdxResource": 0x802bced0,
		"findIdxResource": 0x802bced0,
		"JKRArchive::findNameResource": 0x802bcef8,
		"findNameResource": 0x802bcef8,
		"JKRArchive::findPtrResource": 0x802bcfb8,
		"findPtrResource": 0x802bcfb8,
		"JKRAramArchive::JKRAramArchive": 0x802bd15c,
		"JKRAramArchive::~JKRAramArchive": 0x802bd208,
		"JKRFile::~JKRFile": 0x802bd33c,
		"JKRAramArchive::open": 0x802bd3a0,
		"JKRAramHeap::JKRAramHeap": 0x802bd978,
		"JKRAramHeap::~JKRAramHeap": 0x802bda5c,
		"JKRAramHeap::alloc": 0x802bdb04,
		"JKRAramHeap::allocFromHead": 0x802bdb84,
		"JKRAramHeap::allocFromTail": 0x802bdc10,
		"JSystem::__sinit_JKRAramHeap_cpp": 0x802bdc88,
		"__sinit_JKRAramHeap_cpp": 0x802bdc88,
		"JSUList<JKRAramBlock>::~JSUList": 0x802bdcd4,
		"JKRAram::create": 0x802bdd2c,
		"JKRAram::JKRAram": 0x802bddbc,
		"JKRAram::~JKRAram": 0x802bdee8,
		"JKRAram::run": 0x802bdf78,
		"JKRAram::mainRamToAram": 0x802bdfe0,
		"mainRamToAram": 0x802bdfe0,
		"JSystem::JKRDecompressFromAramToMainRam": 0x802be654,
		"JKRDecompressFromAramToMainRam": 0x802be654,
		"JSystem::__sinit_JKRAram_cpp": 0x802beb74,
		"__sinit_JKRAram_cpp": 0x802beb74,
		"JSUList<JKRAMCommand>::~JSUList": 0x802bebc0,
		"JKRArchive::check_mount_already": 0x802bec18,
		"check_mount_already": 0x802bec18,
		"JKRArchive::mount": 0x802bec6c,
		"mount": 0x802bec6c,
		"JKRArchive::becomeCurrent": 0x802bee30,
		"becomeCurrent": 0x802bee30,
		"JKRArchive::getDirEntry": 0x802beec0,
		"getDirEntry": 0x802beec0,
		"JKRArchive::getGlbResource": 0x802bef38,
		"JKRArchive::removeResourceAll": 0x802bf254,
		"JKRArchive::removeResource": 0x802bf2ec,
		"JKRArchive::detachResource": 0x802bf34c,
		"detachResource": 0x802bf34c,
		"JKRArchive::getResSize": 0x802bf388,
		"JKRArchive::countFile": 0x802bf3bc,
		"countFile": 0x802bf3bc,
		"JKRArchive::getFirstFile": 0x802bf41c,
		"getFirstFile": 0x802bf41c,
		"JKRCompArchive::JKRCompArchive": 0x802bf4c4,
		"JKRCompArchive::~JKRCompArchive": 0x802bf56c,
		"JKRCompArchive::open": 0x802bf6a0,
		"JKRCompArchive::removeResourceAll": 0x802bfedc,
		"JKRCompArchive::removeResource": 0x802bff80,
		"JKRDisposer::JKRDisposer": 0x802bfff4,
		"JKRDisposer::~JKRDisposer": 0x802c006c,
		"JKRDvdArchive::JKRDvdArchive": 0x802c00f0,
		"JKRDvdArchive::~JKRDvdArchive": 0x802c0198,
		"JKRDvdArchive::open": 0x802c02a0,
		"JKRDvdFile::~JKRDvdFile": 0x802c0b14,
		"JKRDvdFile::initiate": 0x802c0bb4,
		"JKRDvdFile::close": 0x802c0d10,
		"close": 0x802c0d10,
		"JKRDvdFile::readData": 0x802c0d8c,
		"JKRDvdFile::writeData": 0x802c0e54,
		"JKRDvdFile::sync": 0x802c0e5c,
		"JKRDvdFile::doneProcess": 0x802c0eb0,
		"doneProcess": 0x802c0eb0,
		"JKRDvdFile::getFileSize": 0x802c0ee0,
		"getFileSize": 0x802c0ee0,
		"JSystem::__sinit_JKRDvdFile_cpp": 0x802c0ee8,
		"__sinit_JKRDvdFile_cpp": 0x802c0ee8,
		"JSUList<JKRDvdFile>::~JSUList": 0x802c0f34,
		"JKRExpHeap::createRoot": 0x802c0f8c,
		"createRoot": 0x802c0f8c,
		"JKRExpHeap::destroy": 0x802c1194,
		"destroy": 0x802c1194,
		"JKRExpHeap::JKRExpHeap": 0x802c1224,
		"JKRExpHeap::~JKRExpHeap": 0x802c12c8,
		"JKRExpHeap::changeGroupID": 0x802c1334,
		"JKRExpHeap::alloc": 0x802c138c,
		"JKRExpHeap::free": 0x802c1b14,
		"JKRExpHeap::freeAll": 0x802c1b88,
		"JKRExpHeap::freeTail": 0x802c1c04,
		"JKRExpHeap::resize": 0x802c1c94,
		"JKRExpHeap::getSize": 0x802c1e54,
		"JKRExpHeap::getFreeSize": 0x802c1edc,
		"JKRExpHeap::getTotalFreeSize": 0x802c1f48,
		"JKRExpHeap::getUsedSize": 0x802c1fac,
		"getUsedSize": 0x802c1fac,
		"JKRExpHeap::check": 0x802c2028,
		"JKRExpHeap::appendUsedList": 0x802c220c,
		"appendUsedList": 0x802c220c,
		"JKRExpHeap::setFreeBlock": 0x802c22a4,
		"setFreeBlock": 0x802c22a4,
		"JKRExpHeap::removeFreeBlock": 0x802c22f0,
		"removeFreeBlock": 0x802c22f0,
		"JKRExpHeap::recycleFreeBlock": 0x802c2324,
		"recycleFreeBlock": 0x802c2324,
		"JKRExpHeap::joinTwoBlocks": 0x802c250c,
		"joinTwoBlocks": 0x802c250c,
		"JKRExpHeap::dump": 0x802c2614,
		"JKRExpHeap::dump_sort": 0x802c27dc,
		"JKRExpHeap::CMemBlock::initiate": 0x802c29d4,
		"JKRExpHeap::CMemBlock::allocFore": 0x802c29f4,
		"allocFore": 0x802c29f4,
		"JKRExpHeap::CMemBlock::allocBack": 0x802c2a38,
		"allocBack": 0x802c2a38,
		"JKRExpHeap::CMemBlock::free": 0x802c2a90,
		"JKRExpHeap::CMemBlock::getHeapBlock": 0x802c2af0,
		"getHeapBlock": 0x802c2af0,
		"JKRExpHeap::state_register": 0x802c2b0c,
		"JKRExpHeap::state_compare": 0x802c2bd0,
		"JKRExpHeap::getCurrentGroupId": 0x802c2c00,
		"JKRExpHeap::getHeapType": 0x802c2c08,
		"JKRArcFinder::JKRArcFinder": 0x802c2c14,
		"JKRArcFinder::findNextFile": 0x802c2cb0,
		"findNextFile": 0x802c2cb0,
		"JKRArcFinder::~JKRArcFinder": 0x802c2d68,
		"JKRFileLoader::JKRFileLoader": 0x802c2dc4,
		"JKRFileLoader::~JKRFileLoader": 0x802c2e24,
		"JKRFileLoader::unmount": 0x802c2eb0,
		"JKRFileLoader::getVolume": 0x802c2f00,
		"getVolume": 0x802c2f00,
		"JKRFileLoader::changeDirectory": 0x802c2f6c,
		"changeDirectory": 0x802c2f6c,
		"JKRFileLoader::getResSize": 0x802c3094,
		"JKRFileLoader::findVolume": 0x802c3124,
		"findVolume": 0x802c3124,
		"JKRFileLoader::findFirstFile": 0x802c31b0,
		"findFirstFile": 0x802c31b0,
		"JKRFileLoader::fetchVolumeName": 0x802c3278,
		"fetchVolumeName": 0x802c3278,
		"JSystem::__sinit_JKRFileLoader_cpp": 0x802c3360,
		"__sinit_JKRFileLoader_cpp": 0x802c3360,
		"JSUList<JKRFileLoader>::~JSUList": 0x802c33ac,
		"JKRHeap::JKRHeap": 0x802c3404,
		"JKRHeap::~JKRHeap": 0x802c3524,
		"JKRHeap::initArena": 0x802c363c,
		"initArena": 0x802c363c,
		"JKRHeap::becomeSystemHeap": 0x802c3720,
		"becomeSystemHeap": 0x802c3720,
		"JKRHeap::becomeCurrentHeap": 0x802c3730,
		"becomeCurrentHeap": 0x802c3730,
		"JKRHeap::alloc": 0x802c3740,
		"JKRHeap::free": 0x802c37b8,
		"JKRHeap::freeAll": 0x802c3810,
		"JKRHeap::findFromRoot": 0x802c3860,
		"findFromRoot": 0x802c3860,
		"JKRHeap::find": 0x802c389c,
		"find": 0x802c389c,
		"JKRHeap::dispose_subroutine": 0x802c39a8,
		"dispose_subroutine": 0x802c39a8,
		"JKRHeap::copyMemory": 0x802c3ae4,
		"copyMemory": 0x802c3ae4,
		"JSystem::JKRDefaultMemoryErrorRoutine": 0x802c3b70,
		"JKRDefaultMemoryErrorRoutine": 0x802c3b70,
		"JSystem::operator_delete": 0x802c3da4,
		"operator_delete": 0x802c3da4,
		"JSystem::operator_delete[]": 0x802c3e08,
		"operator_delete[]": 0x802c3e08,
		"JKRHeap::state_register": 0x802c3e6c,
		"JKRHeap::state_compare": 0x802c3e70,
		"JKRHeap::state_dump": 0x802c3e88,
		"state_dump": 0x802c3e88,
		"JKRHeap::dump_sort": 0x802c3e8c,
		"JKRHeap::changeGroupID": 0x802c3e94,
		"JKRHeap::getCurrentGroupId": 0x802c3e9c,
		"JKRMemArchive::~JKRMemArchive": 0x802c4044,
		"JKRMemArchive::mountFixed": 0x802c40ec,
		"mountFixed": 0x802c40ec,
		"JKRMemArchive::unmountFixed": 0x802c41fc,
		"unmountFixed": 0x802c41fc,
		"JKRMemArchive::removeResourceAll": 0x802c4568,
		"JKRMemArchive::removeResource": 0x802c45b8,
		"JKRMemArchive::fetchResource_subroutine": 0x802c45f4,
		"JKRSolidHeap::create": 0x802c46cc,
		"JKRSolidHeap::JKRSolidHeap": 0x802c474c,
		"JKRSolidHeap::~JKRSolidHeap": 0x802c47a8,
		"JKRSolidHeap::alloc": 0x802c4814,
		"JKRSolidHeap::allocFromHead": 0x802c48c4,
		"JKRSolidHeap::allocFromTail": 0x802c49a8,
		"JKRSolidHeap::free": 0x802c4a7c,
		"JKRSolidHeap::freeAll": 0x802c4aa8,
		"JKRSolidHeap::freeTail": 0x802c4b08,
		"JKRSolidHeap::resize": 0x802c4b94,
		"JKRSolidHeap::getSize": 0x802c4bc4,
		"JKRSolidHeap::check": 0x802c4bf4,
		"JKRSolidHeap::dump": 0x802c4c84,
		"JKRSolidHeap::state_register": 0x802c4da4,
		"JKRSolidHeap::getTotalFreeSize": 0x802c4e0c,
		"JKRSolidHeap::getFreeSize": 0x802c4e38,
		"JKRSolidHeap::state_compare": 0x802c4e40,
		"JKRSolidHeap::getHeapType": 0x802c4e70,
		"JKRStdHeap::create": 0x802c4e7c,
		"JKRStdHeap::JKRStdHeap": 0x802c4efc,
		"JKRStdHeap::~JKRStdHeap": 0x802c4f50,
		"JKRStdHeap::alloc": 0x802c4fcc,
		"JKRStdHeap::free": 0x802c507c,
		"JKRStdHeap::freeAll": 0x802c50c4,
		"JKRStdHeap::freeTail": 0x802c5118,
		"JKRStdHeap::resize": 0x802c5140,
		"JKRStdHeap::getFreeSize": 0x802c5170,
		"JKRStdHeap::state_register": 0x802c519c,
		"JKRStdHeap::state_compare": 0x802c51b0,
		"JKRStdHeap::getSize": 0x802c51e0,
		"JKRStdHeap::getTotalFreeSize": 0x802c5204,
		"JKRStdHeap::getHeapType": 0x802c5230,
		"JKRStdHeap::check": 0x802c523c,
		"JKRStdHeap::dump": 0x802c526c,
		"JKRThread::JKRThread": 0x802c52b0,
		"JKRThread::~JKRThread": 0x802c53e0,
		"JKRThread::start": 0x802c54b8,
		"JKRThread::run": 0x802c54e4,
		"JSystem::__sinit_JKRThread_cpp": 0x802c54ec,
		"__sinit_JKRThread_cpp": 0x802c54ec,
		"JSUList<JKRThread>::~JSUList": 0x802c5538,
		"JSUOutputStream::~JSUOutputStream": 0x802c5590,
		"JSUOutputStream::write": 0x802c55ec,
		"JSUOutputStream::skip": 0x802c5644,
		"JSURandomOutputStream::seek": 0x802c56d0,
		"JSUInputStream::~JSUInputStream": 0x802c5714,
		"JSUInputStream::read": 0x802c5770,
		"JSUInputStream::skip": 0x802c59bc,
		"JSURandomInputStream::align": 0x802c5a44,
		"align": 0x802c5a44,
		"JSURandomInputStream::skip": 0x802c5ad4,
		"JSURandomInputStream::peek": 0x802c5b30,
		"peek": 0x802c5b30,
		"JSURandomInputStream::seek": 0x802c5bec,
		"JSUPtrLink::JSUPtrLink": 0x802c5c30,
		"JSUPtrLink::~JSUPtrLink": 0x802c5c48,
		"JSUPtrList::~JSUPtrList": 0x802c5ce4,
		"JSUPtrList::initiate": 0x802c5d4c,
		"JSUPtrList::append": 0x802c5d60,
		"JSUPtrList::prepend": 0x802c5e1c,
		"prepend": 0x802c5e1c,
		"JSUPtrList::insert": 0x802c5ed8,
		"JSUPtrList::remove": 0x802c60b4,
		"JSUMemoryInputStream::setBuffer": 0x802c6164,
		"JSUMemoryInputStream::readData": 0x802c6178,
		"JSUMemoryInputStream::seekPos": 0x802c61f0,
		"JSUMemoryOutputStream::setBuffer": 0x802c626c,
		"JSUMemoryOutputStream::writeData": 0x802c6280,
		"JSUMemoryOutputStream::seekPos": 0x802c62f4,
		"JSUMemoryOutputStream::getLength": 0x802c6370,
		"JSUMemoryOutputStream::getPosition": 0x802c6378,
		"JSUFileInputStream::JSUFileInputStream": 0x802c6380,
		"JSUFileInputStream::readData": 0x802c63c4,
		"JSUFileInputStream::seekPos": 0x802c6498,
		"JSUFileInputStream::~JSUFileInputStream": 0x802c6580,
		"JSUFileInputStream::getLength": 0x802c65f4,
		"JSUFileInputStream::getPosition": 0x802c6624,
		"JUTException::create": 0x802c662c,
		"JUTException::run": 0x802c6690,
		"JUTException::JUTException": 0x802c6750,
		"JUTException::errorHandler": 0x802c6830,
		"errorHandler": 0x802c6830,
		"JUTException::showFloat": 0x802c6920,
		"showFloat": 0x802c6920,
		"JSystem::__fpclassifyf": 0x802c6d68,
		"__fpclassifyf": 0x802c6d68,
		"JUTException::searchPartialModule": 0x802c6dd0,
		"searchPartialModule": 0x802c6dd0,
		"JSystem::search_name_part": 0x802c6e90,
		"search_name_part": 0x802c6e90,
		"JUTException::showStack": 0x802c6f08,
		"showStack": 0x802c6f08,
		"JUTException::showGPR": 0x802c7008,
		"showGPR": 0x802c7008,
		"JUTException::showMapInfo_subroutine": 0x802c70c8,
		"showMapInfo_subroutine": 0x802c70c8,
		"JUTException::showGPRMap": 0x802c7228,
		"showGPRMap": 0x802c7228,
		"JUTException::readPad": 0x802c7318,
		"readPad": 0x802c7318,
		"JUTException::printContext": 0x802c7504,
		"printContext": 0x802c7504,
		"JUTException::waitTime": 0x802c79a8,
		"waitTime": 0x802c79a8,
		"JUTException::createFB": 0x802c7a34,
		"createFB": 0x802c7a34,
		"JUTException::getFpscr": 0x802c7afc,
		"getFpscr": 0x802c7afc,
		"JUTException::setPreUserCallback": 0x802c7b24,
		"setPreUserCallback": 0x802c7b24,
		"JUTException::appendMapFile": 0x802c7b34,
		"appendMapFile": 0x802c7b34,
		"JUTException::queryMapAddress": 0x802c7bc8,
		"queryMapAddress": 0x802c7bc8,
		"JUTException::queryMapAddress_single": 0x802c7cc0,
		"queryMapAddress_single": 0x802c7cc0,
		"JUTException::createConsole": 0x802c800c,
		"createConsole": 0x802c800c,
		"JUTExternalFB::JUTExternalFB": 0x802c80ec,
		"JUTException::~JUTException": 0x802c810c,
		"JSystem::__sinit_JUTException_cpp": 0x802c8170,
		"__sinit_JUTException_cpp": 0x802c8170,
		"JSUList<JUTException::JUTExMapFile>::~JSUList": 0x802c81c0,
		"JUTDirectPrint::start": 0x802c8218,
		"JUTDirectPrint::JUTDirectPrint": 0x802c8268,
		"JUTDirectPrint::erase": 0x802c82a4,
		"JUTDirectPrint::drawChar": 0x802c8398,
		"drawChar": 0x802c8398,
		"JUTDirectPrint::changeFrameBuffer": 0x802c8598,
		"changeFrameBuffer": 0x802c8598,
		"JUTDirectPrint::drawString": 0x802c85cc,
		"drawString": 0x802c85cc,
		"JUTDirectPrint::drawString_f": 0x802c85f8,
		"drawString_f": 0x802c85f8,
		"JUTFont::JUTFont": 0x802c8780,
		"JUTFont::initiate": 0x802c87ec,
		"JUTFont::setCharColor": 0x802c87f0,
		"setCharColor": 0x802c87f0,
		"JUTFont::setGradColor": 0x802c8814,
		"setGradColor": 0x802c8814,
		"JUTFont::drawString_size_scale": 0x802c8838,
		"drawString_size_scale": 0x802c8838,
		"JUTFont::~JUTFont": 0x802c8928,
		"JUTFont::setGX": 0x802c8974,
		"JUTGamePad::JUTGamePad": 0x802c89a0,
		"JUTGamePad::~JUTGamePad": 0x802c8a7c,
		"JUTGamePad::initList": 0x802c8b28,
		"initList": 0x802c8b28,
		"JUTGamePad::init": 0x802c8b64,
		"JUTGamePad::read": 0x802c8b9c,
		"JUTGamePad::assign": 0x802c8ec0,
		"assign": 0x802c8ec0,
		"JUTGamePad::update": 0x802c8f70,
		"JUTGamePad::checkResetSwitch": 0x802c9158,
		"checkResetSwitch": 0x802c9158,
		"JUTGamePad::clearForReset": 0x802c91d8,
		"clearForReset": 0x802c91d8,
		"JUTGamePad::CButton::clear": 0x802c9204,
		"JUTGamePad::CButton::update": 0x802c9240,
		"JUTGamePad::CStick::clear": 0x802c93d0,
		"JUTGamePad::CStick::update": 0x802c93ec,
		"JUTGamePad::CStick::getButton": 0x802c9588,
		"getButton": 0x802c9588,
		"JUTGamePad::CRumble::clear": 0x802c9634,
		"JUTGamePad::CRumble::stopMotor": 0x802c96a0,
		"stopMotor": 0x802c96a0,
		"JUTGamePad::CRumble::stopMotorHard": 0x802c9700,
		"stopMotorHard": 0x802c9700,
		"JUTGamePad::CRumble::update": 0x802c9760,
		"JUTGamePad::CRumble::setEnable": 0x802c992c,
		"setEnable": 0x802c992c,
		"JUTGamePad::CButton::setRepeat": 0x802c9a30,
		"setRepeat": 0x802c9a30,
		"JUTGamePad::setButtonRepeat": 0x802c9a4c,
		"setButtonRepeat": 0x802c9a4c,
		"JUTGamePad::recalibrate": 0x802c9a98,
		"recalibrate": 0x802c9a98,
		"JUTGamePadRecord::read": 0x802c9b54,
		"JUTGamePadRecord::write": 0x802c9c00,
		"JUTGamePadRecord::streamDataToPadStatus": 0x802c9cbc,
		"streamDataToPadStatus": 0x802c9cbc,
		"JUTGamePadRecord::padStatusToStreamData": 0x802c9d54,
		"padStatusToStreamData": 0x802c9d54,
		"JSystem::__sinit_JUTGamePad_cpp": 0x802c9dec,
		"__sinit_JUTGamePad_cpp": 0x802c9dec,
		"JUTGamePad::CStick::CStick": 0x802c9ee0,
		"JUTGamePad::CButton::CButton": 0x802c9efc,
		"JSUList<JUTGamePad>::~JSUList": 0x802c9f38,
		"JUTNameTab::JUTNameTab": 0x802c9f90,
		"JUTNameTab::getIndex": 0x802c9fb4,
		"JUTNameTab::getName": 0x802ca050,
		"getName": 0x802ca050,
		"JUTNameTab::calcKeyCode": 0x802ca080,
		"JUTPalette::storeTLUT": 0x802ca0b0,
		"storeTLUT": 0x802ca0b0,
		"JUTPalette::JUTPalette": 0x802ca148,
		"JUTPalette::load": 0x802ca198,
		"JUTRect::set": 0x802ca1e0,
		"JUTRect::copy": 0x802ca1f4,
		"JUTRect::add": 0x802ca218,
		"JUTRect::intersect": 0x802ca24c,
		"intersect": 0x802ca24c,
		"JUTRect::move": 0x802ca2cc,
		"JUTRect::resize": 0x802ca308,
		"JUTRect::reform": 0x802ca324,
		"reform": 0x802ca324,
		"JUTRect::normalize": 0x802ca358,
		"JUTRect::isEmpty": 0x802ca38c,
		"isEmpty": 0x802ca38c,
		"JUTTexture::JUTTexture": 0x802ca4ec,
		"JUTTexture::~JUTTexture": 0x802ca5d0,
		"JUTTexture::storeTIMG": 0x802ca640,
		"storeTIMG": 0x802ca640,
		"JUTTexture::attachPalette": 0x802ca7c8,
		"attachPalette": 0x802ca7c8,
		"JUTTexture::load": 0x802caa3c,
		"JSystem::JMANewSinTable": 0x802caa8c,
		"JMANewSinTable": 0x802caa8c,
		"JSystem::JMAEulerToQuat": 0x802cac4c,
		"JMAEulerToQuat": 0x802cac4c,
		"JSystem::JMAQuatLerp": 0x802cad04,
		"JMAQuatLerp": 0x802cad04,
		"JSystem::JMAHermiteInterpolation": 0x802cada8,
		"JMAHermiteInterpolation": 0x802cada8,
		"J2DPane::~J2DPane": 0x802cb5f4,
		"J2DPane::draw": 0x802cb6d4,
		"J2DGrafContext::~J2DGrafContext": 0x802cbad0,
		"J2DPane::clip": 0x802cbb1c,
		"clip": 0x802cbb1c,
		"J2DPane::search": 0x802cbb68,
		"J2DPane::makeMatrix": 0x802cbbfc,
		"makeMatrix": 0x802cbbfc,
		"J2DPane::setCullBack": 0x802cbd68,
		"setCullBack": 0x802cbd68,
		"J2DPane::setBasePosition": 0x802cbe54,
		"setBasePosition": 0x802cbe54,
		"J2DPane::setConnectParent": 0x802cbf1c,
		"J2DPicture::J2DPicture": 0x802cbf30,
		"J2DPicture::~J2DPicture": 0x802cc3bc,
		"J2DPicture::insert": 0x802cc488,
		"J2DPicture::remove": 0x802cc5b4,
		"J2DPicture::changeTexture": 0x802cc6a0,
		"J2DPicture::drawFullSet": 0x802cc838,
		"drawFullSet": 0x802cc838,
		"J2DPicture::draw": 0x802ccef4,
		"J2DPicture::drawTexCoord": 0x802cd2ec,
		"drawTexCoord": 0x802cd2ec,
		"J2DPicture::setTevMode": 0x802cd4e4,
		"J2DPicture::swap": 0x802cd938,
		"swap": 0x802cd938,
		"J2DPicture::setBlendKonstColor": 0x802cd94c,
		"setBlendKonstColor": 0x802cd94c,
		"J2DPicture::setBlendKonstAlpha": 0x802cda84,
		"setBlendKonstAlpha": 0x802cda84,
		"JSystem::J2DPrint_print_alpha_va": 0x802cdbbc,
		"J2DPrint_print_alpha_va": 0x802cdbbc,
		"J2DPrint::~J2DPrint": 0x802cdd70,
		"J2DPrint::initiate": 0x802cddbc,
		"J2DPrint::private_initiate": 0x802cde44,
		"private_initiate": 0x802cde44,
		"J2DPrint::setBuffer": 0x802cdfcc,
		"J2DPrint::setFontSize": 0x802ce038,
		"setFontSize": 0x802ce038,
		"J2DPrint::locate": 0x802ce098,
		"locate": 0x802ce098,
		"J2DPrint::getWidth": 0x802ce294,
		"J2DPrint::printReturn": 0x802ce3a0,
		"printReturn": 0x802ce3a0,
		"J2DPrint::parse": 0x802ce5fc,
		"parse": 0x802ce5fc,
		"J2DPrint::doCtrlCode": 0x802cee3c,
		"doCtrlCode": 0x802cee3c,
		"J2DPrint::doEscapeCode": 0x802cefb0,
		"doEscapeCode": 0x802cefb0,
		"J2DPrint::initchar": 0x802cf598,
		"initchar": 0x802cf598,
		"J2DPrint::getNumber": 0x802cf5dc,
		"getNumber": 0x802cf5dc,
		"J2DScreen::~J2DScreen": 0x802cf6e4,
		"J2DScreen::makeHiearachyPanes": 0x802cf748,
		"makeHiearachyPanes": 0x802cf748,
		"J2DScreen::stop": 0x802cfd6c,
		"J2DScreen::draw": 0x802cfda8,
		"J2DScreen::search": 0x802d0050,
		"J2DSetScreen::J2DSetScreen": 0x802d0080,
		"J2DScreen::drawSelf": 0x802d01c8,
		"J2DSetScreen::~J2DSetScreen": 0x802d0280,
		"J2DTextBox::initiate": 0x802d08e4,
		"J2DTextBox::~J2DTextBox": 0x802d0a14,
		"J2DTextBox::setFont": 0x802d0ab8,
		"setFont": 0x802d0ab8,
		"J2DTextBox::draw": 0x802d0b28,
		"J2DTextBox::getStringPtr": 0x802d0c60,
		"getStringPtr": 0x802d0c60,
		"J2DTextBox::setString": 0x802d0c68,
		"setString": 0x802d0c68,
		"J2DTextBox::setConnectParent": 0x802d0d38,
		"J2DTextBox::resize": 0x802d0f14,
		"J2DWindow::J2DWindow": 0x802d0fc4,
		"J2DWindow::~J2DWindow": 0x802d1760,
		"J2DWindow::Texture::~Texture": 0x802d1888,
		"J2DWindow::draw_private": 0x802d18ec,
		"draw_private": 0x802d18ec,
		"J2DWindow::resize": 0x802d1da8,
		"J2DWindow::drawContents": 0x802d1f88,
		"drawContents": 0x802d1f88,
		"J2DWindow::Texture::drawContentsTexture": 0x802d243c,
		"drawContentsTexture": 0x802d243c,
		"J2DWindow::Texture::setTevMode": 0x802d2624,
		"JSystem::J3DCalcZValue": 0x802d29f4,
		"J3DCalcZValue": 0x802d29f4,
		"JSystem::J3DPSCalcInverseTranspose": 0x802d2a2c,
		"J3DPSCalcInverseTranspose": 0x802d2a2c,
		"JSystem::J3DGetTextureMtx": 0x802d2c60,
		"J3DGetTextureMtx": 0x802d2c60,
		"JSystem::J3DGetTextureMtxOld": 0x802d2d38,
		"J3DGetTextureMtxOld": 0x802d2d38,
		"JSystem::J3DGetTextureMtxMaya": 0x802d2e10,
		"J3DGetTextureMtxMaya": 0x802d2e10,
		"JSystem::J3DGetTextureMtxMayaOld": 0x802d2f60,
		"J3DGetTextureMtxMayaOld": 0x802d2f60,
		"JSystem::J3DScaleNrmMtx33": 0x802d30b0,
		"J3DScaleNrmMtx33": 0x802d30b0,
		"JSystem::J3DMtxProjConcat": 0x802d3104,
		"J3DMtxProjConcat": 0x802d3104,
		"JSystem::J3DPSMtx33Copy": 0x802d3228,
		"J3DPSMtx33Copy": 0x802d3228,
		"JSystem::J3DPSMtx33CopyFrom34": 0x802d3254,
		"J3DPSMtx33CopyFrom34": 0x802d3254,
		"JSystem::J3DPSMtxArrayCopy": 0x802d3288,
		"J3DPSMtxArrayCopy": 0x802d3288,
		"JSystem::J3DMTXConcatArrayIndexedSrc": 0x802d32cc,
		"J3DMTXConcatArrayIndexedSrc": 0x802d32cc,
		"JSystem::J3DPSMtxArrayConcat": 0x802d3404,
		"J3DPSMtxArrayConcat": 0x802d3404,
		"J3DDeformData::deform": 0x802d34e0,
		"J3DDeformData::setAnm": 0x802d35c8,
		"J3DAnmCluster::getWeight": 0x802d3770,
		"J3DDeformer::normalize": 0x802d3ec8,
		"J3DDeformer::normalizeWeight": 0x802d3f78,
		"normalizeWeight": 0x802d3f78,
		"J3DSkinDeform::J3DSkinDeform": 0x802d3fd4,
		"J3DSkinDeform::initMtxIndexArray": 0x802d3ffc,
		"initMtxIndexArray": 0x802d3ffc,
		"J3DSkinDeform::calcNrmMtx": 0x802d43d8,
		"J3DSkinDeform::deform": 0x802d4504,
		"J3DAnmVtxColor::getColor": 0x802d49a8,
		"J3DSkinDeform::~J3DSkinDeform": 0x802d49ac,
		"J3DMtxCalcBasic::J3DMtxCalcBasic": 0x802d4ae4,
		"J3DNode::updateOut": 0x802d4ce8,
		"J3DNode::updateIn": 0x802d4cec,
		"J3DNode::calcOut": 0x802d4eac,
		"J3DNode::calcIn": 0x802d4eb0,
		"J3DNode::entryIn": 0x802d4f30,
		"JSystem::J3DNewMtxCalcAnm": 0x802d5654,
		"J3DNewMtxCalcAnm": 0x802d5654,
		"J3DMtxCalcMaya::~J3DMtxCalcMaya": 0x802d58c4,
		"J3DJoint::initialize": 0x802d5954,
		"J3DJoint::addMesh": 0x802d5a48,
		"addMesh": 0x802d5a48,
		"J3DJoint::updateIn": 0x802d5a68,
		"J3DJoint::updateOut": 0x802d5ca0,
		"J3DJoint::calcIn": 0x802d5cc4,
		"J3DJoint::calcOut": 0x802d5d44,
		"J3DJoint::entryIn": 0x802d5d68,
		"J3DJoint::getType": 0x802d5f40,
		"J3DJoint::~J3DJoint": 0x802d5f4c,
		"J3DNode::init": 0x802d5fb0,
		"J3DColorBlockLightOff::initialize": 0x802d63f0,
		"J3DColorBlockLightOn::initialize": 0x802d645c,
		"J3DTevBlock2::initialize": 0x802d6530,
		"J3DTevBlock4::initialize": 0x802d6668,
		"J3DTevBlock16::initialize": 0x802d67f0,
		"J3DMaterial::createColorBlock": 0x802d6b14,
		"createColorBlock": 0x802d6b14,
		"J3DColorChan::J3DColorChan": 0x802d6c58,
		"JSystem::calcColorChanID": 0x802d6cbc,
		"calcColorChanID": 0x802d6cbc,
		"J3DGXColor::J3DGXColor": 0x802d6e38,
		"J3DColorBlock::~J3DColorBlock": 0x802d6e3c,
		"J3DMaterial::createTexGenBlock": 0x802d6e88,
		"createTexGenBlock": 0x802d6e88,
		"J3DTexCoord::J3DTexCoord": 0x802d6f58,
		"J3DTexGenBlock::~J3DTexGenBlock": 0x802d6f78,
		"J3DMaterial::createTevBlock": 0x802d6fc4,
		"createTevBlock": 0x802d6fc4,
		"J3DTevSwapModeTable::J3DTevSwapModeTable": 0x802d7374,
		"J3DGXColorS10::J3DGXColorS10": 0x802d7380,
		"J3DIndTevStage::J3DIndTevStage": 0x802d7384,
		"J3DTevStage::J3DTevStage": 0x802d73d4,
		"J3DTevOrder::J3DTevOrder": 0x802d7508,
		"J3DTevBlock::~J3DTevBlock": 0x802d7528,
		"J3DMaterial::createIndBlock": 0x802d7574,
		"createIndBlock": 0x802d7574,
		"J3DIndTexCoordScale::~J3DIndTexCoordScale": 0x802d766c,
		"J3DIndTexCoordScale::J3DIndTexCoordScale": 0x802d76ac,
		"J3DIndTexMtx::~J3DIndTexMtx": 0x802d76c4,
		"J3DIndTexMtx::J3DIndTexMtx": 0x802d7704,
		"J3DIndTexOrder::J3DIndTexOrder": 0x802d7744,
		"J3DIndBlock::~J3DIndBlock": 0x802d775c,
		"J3DMaterial::createPEBlock": 0x802d77a8,
		"createPEBlock": 0x802d77a8,
		"J3DPEBlock::~J3DPEBlock": 0x802d78f0,
		"J3DMaterial::initialize": 0x802d793c,
		"J3DMaterial::addShape": 0x802d798c,
		"addShape": 0x802d798c,
		"J3DColorBlockLightOff::countDLSize": 0x802d7994,
		"J3DColorBlockLightOn::countDLSize": 0x802d799c,
		"J3DTexGenBlockBasic::countDLSize": 0x802d79a4,
		"J3DTevBlock1::countDLSize": 0x802d79ac,
		"J3DTevBlock2::countDLSize": 0x802d79b4,
		"J3DTevBlock4::countDLSize": 0x802d79bc,
		"J3DTevBlock16::countDLSize": 0x802d79c4,
		"J3DIndBlockFull::countDLSize": 0x802d79cc,
		"J3DPEBlockOpa::countDLSize": 0x802d79d4,
		"J3DPEBlockTexEdge::countDLSize": 0x802d79dc,
		"J3DPEBlockXlu::countDLSize": 0x802d79e4,
		"J3DPEBlockFull::countDLSize": 0x802d79ec,
		"J3DMaterial::countDLSize": 0x802d79f4,
		"J3DColorBlockLightOff::load": 0x802d7aa8,
		"J3DColorBlockLightOn::load": 0x802d7ba0,
		"J3DTexGenBlockBasic::load": 0x802d7cfc,
		"J3DTexGenBlockBasic::patch": 0x802d7db4,
		"patch": 0x802d7db4,
		"J3DTevBlock1::load": 0x802d7e54,
		"J3DTevBlock2::load": 0x802d8040,
		"J3DTevBlock4::load": 0x802d8544,
		"J3DTevBlock16::load": 0x802d8a7c,
		"J3DIndBlockFull::load": 0x802d8fb4,
		"J3DPEBlockOpa::load": 0x802d91a4,
		"J3DPEBlockTexEdge::load": 0x802d931c,
		"J3DPEBlockXlu::load": 0x802d9490,
		"J3DPEBlockFull::load": 0x802d9608,
		"JSystem::J3DGDWrite_u32": 0x802d9740,
		"J3DGDWrite_u32": 0x802d9740,
		"JSystem::__GDWrite": 0x802d97a0,
		"__GDWrite": 0x802d97a0,
		"JSystem::GDOverflowCheck": 0x802d97b8,
		"J3DColorBlockLightOff::reset": 0x802d97f0,
		"J3DColorBlockLightOn::reset": 0x802d98c4,
		"J3DLightInfo::operator_=": 0x802d9a84,
		"J3DTexGenBlockBasic::reset": 0x802d9b08,
		"J3DTevBlock1::reset": 0x802d9c74,
		"J3DTevBlock2::reset": 0x802d9d9c,
		"J3DTevBlock4::reset": 0x802da104,
		"J3DTevBlock16::reset": 0x802da6c4,
		"J3DIndBlockFull::reset": 0x802da970,
		"J3DIndTexMtxInfo::operator_=": 0x802daa94,
		"J3DPEBlockFull::reset": 0x802daad0,
		"J3DPEBlock::getZCompLoc": 0x802dae48,
		"J3DPEBlock::getBlend": 0x802dae50,
		"J3DPEBlock::getAlphaComp": 0x802dae58,
		"J3DFogInfo::operator_=": 0x802dae60,
		"J3DMaterial::makeDisplayList": 0x802daf28,
		"makeDisplayList": 0x802daf28,
		"J3DMaterial::load": 0x802db08c,
		"J3DMaterial::safeMakeDisplayList": 0x802db110,
		"safeMakeDisplayList": 0x802db110,
		"J3DTexGenBlockBasic::calc": 0x802db274,
		"J3DMaterial::calc": 0x802db504,
		"J3DMaterial::setCurrentMtx": 0x802db534,
		"setCurrentMtx": 0x802db534,
		"J3DMaterial::copy": 0x802db660,
		"J3DPEBlock::reset": 0x802db720,
		"J3DIndBlock::reset": 0x802db724,
		"J3DTevBlock::reset": 0x802db728,
		"J3DTexGenBlock::reset": 0x802db72c,
		"J3DColorBlock::reset": 0x802db730,
		"J3DMaterial::change": 0x802db734,
		"change": 0x802db734,
		"J3DMaterial::newSharedDisplayList": 0x802db76c,
		"newSharedDisplayList": 0x802db76c,
		"J3DPEBlockFull::getType": 0x802db7e4,
		"J3DPEBlockFull::setFog": 0x802db7f0,
		"J3DPEBlockFull::replaceFog": 0x802db7f8,
		"J3DPEBlockFull::getFog": 0x802db808,
		"J3DPEBlockFull::getAlphaComp": 0x802db848,
		"J3DPEBlockFull::getBlend": 0x802db898,
		"J3DPEBlockFull::getZMode": 0x802db8b8,
		"J3DPEBlockFull::getZCompLoc": 0x802db8d4,
		"J3DPEBlockFull::getDither": 0x802db8f0,
		"J3DPEBlockFull::~J3DPEBlockFull": 0x802db8f8,
		"J3DIndBlockFull::getType": 0x802db954,
		"J3DIndBlockFull::setIndTexStageNum": 0x802db960,
		"J3DIndBlockFull::getIndTexStageNum": 0x802db968,
		"J3DIndBlockFull::getIndTexOrder": 0x802db9a8,
		"J3DIndBlockFull::getIndTexMtx": 0x802dba1c,
		"J3DIndBlockFull::getIndTexCoordScale": 0x802dba68,
		"J3DIndBlockFull::~J3DIndBlockFull": 0x802dba7c,
		"J3DTevBlock16::getType": 0x802dbb18,
		"J3DTevBlock16::getTexNo": 0x802dbb48,
		"J3DTevBlock16::getTevOrder": 0x802dbba0,
		"J3DTevBlock16::getTevColor": 0x802dbbec,
		"J3DTevBlock16::getTevKColor": 0x802dbc28,
		"J3DTevBlock16::getTevKColorSel": 0x802dbc58,
		"J3DTevBlock16::getTevKAlphaSel": 0x802dbc80,
		"J3DTevBlock16::getTevStageNum": 0x802dbca0,
		"J3DTevBlock16::getTevStage": 0x802dbd20,
		"J3DTevBlock16::getTevSwapModeTable": 0x802dbdc4,
		"J3DTevBlock16::getIndTevStage": 0x802dbe7c,
		"J3DTevBlock16::~J3DTevBlock16": 0x802dbe90,
		"J3DTevBlock4::getType": 0x802dbeec,
		"J3DTevBlock4::getTexNo": 0x802dbf1c,
		"J3DTevBlock4::getTevOrder": 0x802dbf74,
		"J3DTevBlock4::getTevColor": 0x802dbfc0,
		"J3DTevBlock4::getTevKColor": 0x802dbffc,
		"J3DTevBlock4::getTevKColorSel": 0x802dc02c,
		"J3DTevBlock4::getTevKAlphaSel": 0x802dc054,
		"J3DTevBlock4::getTevStageNum": 0x802dc074,
		"J3DTevBlock4::getTevStage": 0x802dc0f4,
		"J3DTevBlock4::getTevSwapModeTable": 0x802dc198,
		"J3DTevBlock4::getIndTevStage": 0x802dc250,
		"J3DTevBlock4::~J3DTevBlock4": 0x802dc264,
		"J3DTevBlock2::getType": 0x802dc2c0,
		"J3DTevBlock2::getTexNo": 0x802dc2f0,
		"J3DTevBlock2::getTevOrder": 0x802dc348,
		"J3DTevBlock2::getTevColor": 0x802dc394,
		"J3DTevBlock2::getTevKColor": 0x802dc3d0,
		"J3DTevBlock2::getTevKColorSel": 0x802dc400,
		"J3DTevBlock2::getTevKAlphaSel": 0x802dc428,
		"J3DTevBlock2::getTevStageNum": 0x802dc448,
		"J3DTevBlock2::getTevStage": 0x802dc4c8,
		"J3DTevBlock2::getTevSwapModeTable": 0x802dc56c,
		"J3DTevBlock2::getIndTevStage": 0x802dc624,
		"J3DTevBlock2::~J3DTevBlock2": 0x802dc638,
		"J3DTevBlock1::getType": 0x802dc694,
		"J3DTevBlock1::getTexNo": 0x802dc6c4,
		"J3DTevBlock1::getTevOrder": 0x802dc71c,
		"J3DTevBlock1::getTevColor": 0x802dc738,
		"J3DTevBlock1::getTevKColor": 0x802dc748,
		"J3DTevBlock1::getTevKColorSel": 0x802dc758,
		"J3DTevBlock1::getTevKAlphaSel": 0x802dc768,
		"J3DTevBlock1::getTevStageNum": 0x802dc778,
		"J3DTevBlock1::getTevStage": 0x802dc7f8,
		"J3DTevBlock1::getTevSwapModeTable": 0x802dc81c,
		"J3DTevBlock1::getIndTevStage": 0x802dc8cc,
		"J3DTevBlock1::~J3DTevBlock1": 0x802dc8e0,
		"J3DTexGenBlockBasic::getType": 0x802dc93c,
		"J3DTexGenBlockBasic::getTexGenNum": 0x802dc95c,
		"getTexGenNum": 0x802dc95c,
		"J3DTexGenBlockBasic::setTexCoord": 0x802dc964,
		"setTexCoord": 0x802dc964,
		"J3DTexGenBlockBasic::getTexCoord": 0x802dc988,
		"getTexCoord": 0x802dc988,
		"J3DTexGenBlockBasic::setTexMtx": 0x802dc99c,
		"setTexMtx": 0x802dc99c,
		"J3DTexGenBlockBasic::replaceTexMtx": 0x802dc9ac,
		"replaceTexMtx": 0x802dc9ac,
		"J3DTexGenBlockBasic::getTexMtx": 0x802dc9c0,
		"getTexMtx": 0x802dc9c0,
		"J3DTexGenBlockBasic::getNBTScale": 0x802dca18,
		"getNBTScale": 0x802dca18,
		"J3DTexGenBlockBasic::~J3DTexGenBlockBasic": 0x802dca20,
		"J3DColorBlockLightOn::getType": 0x802dca7c,
		"J3DColorBlockLightOn::getMatColor": 0x802dcab0,
		"J3DColorBlockLightOn::getAmbColor": 0x802dcaec,
		"J3DColorBlockLightOn::getColorChanNum": 0x802dcb14,
		"J3DColorBlockLightOn::getColorChan": 0x802dcb44,
		"J3DColorBlockLightOn::setLight": 0x802dcb58,
		"J3DColorBlockLightOn::replaceLight": 0x802dcb68,
		"J3DColorBlockLightOn::getLight": 0x802dcb7c,
		"J3DColorBlockLightOn::getCullMode": 0x802dcba0,
		"J3DColorBlockLightOn::~J3DColorBlockLightOn": 0x802dcba8,
		"J3DColorBlockLightOff::getType": 0x802dcc04,
		"J3DColorBlockLightOff::getMatColor": 0x802dcc38,
		"J3DColorBlockLightOff::getAmbColor": 0x802dcc54,
		"J3DColorBlockLightOff::getColorChanNum": 0x802dcc70,
		"J3DColorBlockLightOff::getColorChan": 0x802dcca0,
		"J3DColorBlockLightOff::setLight": 0x802dccb4,
		"J3DColorBlockLightOff::replaceLight": 0x802dccb8,
		"J3DColorBlockLightOff::getLight": 0x802dccc0,
		"J3DColorBlockLightOff::getCullMode": 0x802dccdc,
		"J3DColorBlockLightOff::~J3DColorBlockLightOff": 0x802dcce4,
		"J3DPEBlockXlu::getType": 0x802dcd40,
		"J3DPEBlockXlu::~J3DPEBlockXlu": 0x802dcd4c,
		"J3DPEBlock::setFog": 0x802dcda8,
		"J3DPEBlock::replaceFog": 0x802dcdac,
		"J3DPEBlock::getDither": 0x802dcddc,
		"J3DPEBlockTexEdge::getType": 0x802dcde4,
		"J3DPEBlockTexEdge::~J3DPEBlockTexEdge": 0x802dcdf0,
		"J3DPEBlockOpa::getType": 0x802dce4c,
		"J3DPEBlockOpa::~J3DPEBlockOpa": 0x802dce58,
		"J3DIndBlockNull::reset": 0x802dceb4,
		"J3DIndBlockNull::countDLSize": 0x802dceb8,
		"J3DIndBlockNull::getType": 0x802dcec0,
		"J3DIndBlockNull::setIndTexStageNum": 0x802dcecc,
		"J3DIndBlockNull::getIndTexStageNum": 0x802dced0,
		"J3DIndBlockNull::getIndTexOrder": 0x802dcee0,
		"J3DIndBlockNull::getIndTexMtx": 0x802dcef0,
		"J3DIndBlockNull::getIndTexCoordScale": 0x802dcf00,
		"J3DIndBlockNull::~J3DIndBlockNull": 0x802dcf08,
		"J3DIndBlockNull::load": 0x802dcf64,
		"J3DModelData::clear": 0x802dcf68,
		"J3DModelData::J3DModelData": 0x802dcfdc,
		"J3DModelData::~J3DModelData": 0x802dd030,
		"J3DModelData::makeHierarchy": 0x802dd0a0,
		"J3DNode::getType": 0x802dd24c,
		"J3DModelData::isDeformableVertexFormat": 0x802dd258,
		"isDeformableVertexFormat": 0x802dd258,
		"J3DModelData::setMaterialTable": 0x802dd2dc,
		"setMaterialTable": 0x802dd2dc,
		"J3DModelData::entryMatColorAnimator": 0x802dd394,
		"entryMatColorAnimator": 0x802dd394,
		"J3DModelData::entryTexMtxAnimator": 0x802dd448,
		"entryTexMtxAnimator": 0x802dd448,
		"J3DModelData::entryTevRegAnimator": 0x802dd61c,
		"entryTevRegAnimator": 0x802dd61c,
		"J3DModelData::removeMatColorAnimator": 0x802dd788,
		"removeMatColorAnimator": 0x802dd788,
		"J3DModelData::removeTexNoAnimator": 0x802dd800,
		"removeTexNoAnimator": 0x802dd800,
		"J3DModelData::removeTexMtxAnimator": 0x802dd894,
		"removeTexMtxAnimator": 0x802dd894,
		"J3DModelData::removeTevRegAnimator": 0x802dd938,
		"removeTevRegAnimator": 0x802dd938,
		"J3DModelData::setMatColorAnimator": 0x802dda54,
		"setMatColorAnimator": 0x802dda54,
		"J3DModelData::setTexNoAnimator": 0x802ddad4,
		"setTexNoAnimator": 0x802ddad4,
		"J3DModelData::setTexMtxAnimator": 0x802ddb7c,
		"setTexMtxAnimator": 0x802ddb7c,
		"J3DModelData::setTevRegAnimator": 0x802ddcb4,
		"setTevRegAnimator": 0x802ddcb4,
		"J3DModel::~J3DModel": 0x802ddea0,
		"J3DModel::initialize": 0x802ddeec,
		"J3DModel::entryModelData": 0x802ddf90,
		"entryModelData": 0x802ddf90,
		"J3DModel::lock": 0x802de470,
		"lock": 0x802de470,
		"J3DModel::unlock": 0x802de5a0,
		"unlock": 0x802de5a0,
		"J3DModel::makeDL": 0x802de6d0,
		"J3DModel::setSkinDeform": 0x802de768,
		"setSkinDeform": 0x802de768,
		"J3DModel::calcWeightEnvelopeMtx": 0x802de7e4,
		"calcWeightEnvelopeMtx": 0x802de7e4,
		"J3DModel::update": 0x802de9c0,
		"J3DModel::calc": 0x802debc4,
		"J3DModel::entry": 0x802dedc8,
		"J3DModel::viewCalc": 0x802deeb8,
		"J3DModel::calcNrmMtx": 0x802df0f0,
		"J3DModel::calcBumpMtx": 0x802df248,
		"calcBumpMtx": 0x802df248,
		"J3DModel::calcBBoard": 0x802df33c,
		"calcBBoard": 0x802df33c,
		"J3DModel::prepareShapePackets": 0x802df844,
		"prepareShapePackets": 0x802df844,
		"J3DNode::J3DNode": 0x802dfa08,
		"J3DNode::~J3DNode": 0x802dfa2c,
		"J3DNode::appendChild": 0x802dfa78,
		"appendChild": 0x802dfa78,
		"J3DShapeMtx::loadMtxIndx_PNGP": 0x802dfaac,
		"loadMtxIndx_PNGP": 0x802dfaac,
		"J3DShapeMtx::loadMtxIndx_PCPU": 0x802dfb08,
		"loadMtxIndx_PCPU": 0x802dfb08,
		"J3DShapeMtx::loadMtxIndx_NCPU": 0x802dfb68,
		"loadMtxIndx_NCPU": 0x802dfb68,
		"J3DShapeMtx::loadMtxIndx_PNCPU": 0x802dfbb4,
		"loadMtxIndx_PNCPU": 0x802dfbb4,
		"J3DShapeMtx::load": 0x802dfc04,
		"J3DShapeMtx::calcNBTScale": 0x802dfc60,
		"J3DShapeMtx::~J3DShapeMtx": 0x802dfcc8,
		"J3DShapeMtxDL::load": 0x802dfd14,
		"J3DShapeMtxMulti::load": 0x802dfd3c,
		"J3DShapeMtxMulti::calcNBTScale": 0x802dfde4,
		"J3DShapeDraw::J3DShapeDraw": 0x802dfe70,
		"J3DShapeDraw::draw": 0x802dfe88,
		"J3DShape::initialize": 0x802dfeb4,
		"J3DShape::calcNBTScale": 0x802dff20,
		"J3DShape::countBumpMtxNum": 0x802dff98,
		"countBumpMtxNum": 0x802dff98,
		"J3DShape::makeVtxArrayCmd": 0x802e0014,
		"makeVtxArrayCmd": 0x802e0014,
		"J3DShape::makeVcdVatCmd": 0x802e02ac,
		"makeVcdVatCmd": 0x802e02ac,
		"J3DShape::loadVtxArray": 0x802e0320,
		"loadVtxArray": 0x802e0320,
		"J3DShape::draw": 0x802e0390,
		"J3DShapeDraw::~J3DShapeDraw": 0x802e04f8,
		"J3DShapeMtxMulti::~J3DShapeMtxMulti": 0x802e0544,
		"J3DShapeMtxMulti::getType": 0x802e05a0,
		"J3DShapeMtxMulti::getUseMtxNum": 0x802e05ac,
		"J3DShapeMtxMulti::getUseMtxIndex": 0x802e05b4,
		"J3DShapeMtxDL::~J3DShapeMtxDL": 0x802e05c4,
		"J3DShapeMtxDL::calcNBTScale": 0x802e0620,
		"J3DShapeMtx::getType": 0x802e0624,
		"JSystem::__sinit_J3DShape_cpp": 0x802e0630,
		"__sinit_J3DShape_cpp": 0x802e0630,
		"J3DSys::J3DSys": 0x802e069c,
		"J3DSys::loadPosMtxIndx": 0x802e07b8,
		"loadPosMtxIndx": 0x802e07b8,
		"J3DSys::loadNrmMtxIndx": 0x802e07e0,
		"loadNrmMtxIndx": 0x802e07e0,
		"J3DSys::setTexCacheRegion": 0x802e0808,
		"setTexCacheRegion": 0x802e0808,
		"J3DSys::drawInit": 0x802e09c8,
		"drawInit": 0x802e09c8,
		"J3DSys::reinitTexture": 0x802e1094,
		"reinitTexture": 0x802e1094,
		"JSystem::__sinit_J3DSys_cpp": 0x802e1138,
		"__sinit_J3DSys_cpp": 0x802e1138,
		"J3DFrameCtrl::init": 0x802e1160,
		"J3DFrameCtrl::checkPass": 0x802e1190,
		"checkPass": 0x802e1190,
		"J3DFrameCtrl::update": 0x802e1730,
		"J3DAnmBase::~J3DAnmBase": 0x802e1ba8,
		"J3DAnmTransformFull::getTransform": 0x802e1bf4,
		"JSystem::J3DHermiteInterpolationS": 0x802e22e8,
		"J3DHermiteInterpolationS": 0x802e22e8,
		"JSystem::J3DGetKeyFrameInterpolationS": 0x802e233c,
		"J3DGetKeyFrameInterpolationS": 0x802e233c,
		"J3DAnmTransformKey::calcTransform": 0x802e256c,
		"J3DAnmTextureSRTKey::calcTransform": 0x802e2a58,
		"J3DAnmClusterFull::getWeight": 0x802e2d1c,
		"J3DAnmClusterKey::getWeight": 0x802e2df4,
		"J3DAnmVtxColorFull::getColor": 0x802e2e78,
		"J3DAnmVtxColorKey::getColor": 0x802e31d0,
		"J3DAnmColor::searchUpdateMaterialID": 0x802e352c,
		"J3DAnmColorFull::getColor": 0x802e35bc,
		"J3DAnmColorKey::getColor": 0x802e390c,
		"J3DAnmTexPattern::getTexNo": 0x802e3c58,
		"J3DAnmTexPattern::searchUpdateMaterialID": 0x802e3d44,
		"J3DAnmTextureSRTKey::searchUpdateMaterialID": 0x802e3dd4,
		"J3DAnmTevRegKey::getTevColorReg": 0x802e3ef8,
		"getTevColorReg": 0x802e3ef8,
		"J3DAnmTevRegKey::getTevKonstReg": 0x802e4244,
		"getTevKonstReg": 0x802e4244,
		"J3DAnmTevRegKey::searchUpdateMaterialID": 0x802e4590,
		"J3DAnmColorKey::~J3DAnmColorKey": 0x802e4684,
		"J3DAnmColor::getColor": 0x802e46f0,
		"J3DAnmColor::~J3DAnmColor": 0x802e46f4,
		"J3DAnmColorFull::~J3DAnmColorFull": 0x802e4750,
		"J3DAnmVtxColorKey::~J3DAnmVtxColorKey": 0x802e47bc,
		"J3DAnmVtxColor::~J3DAnmVtxColor": 0x802e4828,
		"J3DAnmVtxColorFull::~J3DAnmVtxColorFull": 0x802e4884,
		"J3DAnmClusterKey::~J3DAnmClusterKey": 0x802e48f0,
		"J3DAnmCluster::~J3DAnmCluster": 0x802e495c,
		"J3DAnmClusterFull::~J3DAnmClusterFull": 0x802e49b8,
		"J3DAnmTransformKey::~J3DAnmTransformKey": 0x802e4a24,
		"J3DAnmTransform::~J3DAnmTransform": 0x802e4a90,
		"J3DAnmTransformFull::~J3DAnmTransformFull": 0x802e4aec,
		"J3DJointFactory::J3DJointFactory": 0x802e5020,
		"J3DJointFactory::create": 0x802e5078,
		"J3DMaterialFactory::J3DMaterialFactory": 0x802e524c,
		"J3DMaterialFactory::countUniqueMaterials": 0x802e5480,
		"J3DMaterialFactory::countStages": 0x802e54bc,
		"J3DMaterialFactory::create": 0x802e55a0,
		"J3DMaterialFactory::newMatColor": 0x802e5ec4,
		"J3DMaterialFactory::newColorChanNum": 0x802e5f54,
		"J3DMaterialFactory::newColorChan": 0x802e5f8c,
		"J3DMaterialFactory::newAmbColor": 0x802e6054,
		"newAmbColor": 0x802e6054,
		"J3DMaterialFactory::newTexGenNum": 0x802e60e4,
		"J3DMaterialFactory::newTexCoord": 0x802e611c,
		"J3DMaterialFactory::newTexMtx": 0x802e6190,
		"J3DMaterialFactory::newCullMode": 0x802e6224,
		"J3DMaterialFactory::newTexNo": 0x802e6264,
		"J3DMaterialFactory::newTevOrder": 0x802e62ac,
		"J3DMaterialFactory::newTevColor": 0x802e6320,
		"J3DMaterialFactory::newTevKColor": 0x802e63b8,
		"J3DMaterialFactory::newTevStageNum": 0x802e6448,
		"J3DMaterialFactory::newTevStage": 0x802e6480,
		"J3DMaterialFactory::newTevSwapModeTable": 0x802e66ec,
		"J3DMaterialFactory::newIndTexStageNum": 0x802e6788,
		"newIndTexStageNum": 0x802e6788,
		"J3DMaterialFactory::newIndTexOrder": 0x802e67b0,
		"newIndTexOrder": 0x802e67b0,
		"J3DMaterialFactory::newIndTexMtx": 0x802e6810,
		"newIndTexMtx": 0x802e6810,
		"J3DMaterialFactory::newIndTevStage": 0x802e68d8,
		"newIndTevStage": 0x802e68d8,
		"J3DMaterialFactory::newIndTexCoordScale": 0x802e69bc,
		"newIndTexCoordScale": 0x802e69bc,
		"J3DMaterialFactory::newFog": 0x802e6a1c,
		"J3DMaterialFactory::newAlphaComp": 0x802e6aa8,
		"J3DMaterialFactory::newBlend": 0x802e6b28,
		"J3DMaterialFactory::newZMode": 0x802e6ba4,
		"J3DMaterialFactory::newZCompLoc": 0x802e6c08,
		"J3DMaterialFactory::newDither": 0x802e6c40,
		"J3DMaterialFactory::newNBTScale": 0x802e6c78,
		"J3DModelLoaderDataBase::load": 0x802e6f00,
		"J3DModelLoader_v26::~J3DModelLoader_v26": 0x802e7024,
		"J3DModelLoader_v21::~J3DModelLoader_v21": 0x802e7080,
		"J3DModelLoader::~J3DModelLoader": 0x802e70dc,
		"J3DModelLoaderDataBase::loadMaterialTable": 0x802e7128,
		"J3DModelLoader::load": 0x802e7248,
		"J3DModelLoader::readMaterial_v21": 0x802e746c,
		"J3DModelLoader::readMaterial": 0x802e7470,
		"J3DModelLoader::loadMaterialTable": 0x802e7474,
		"J3DModelLoader::readMaterialTable_v21": 0x802e75b8,
		"J3DModelLoader::readMaterialTable": 0x802e75bc,
		"J3DModelLoader::setupBBoardInfo": 0x802e75c0,
		"setupBBoardInfo": 0x802e75c0,
		"J3DModelLoader::readInformation": 0x802e770c,
		"readInformation": 0x802e770c,
		"J3DModelLoader::readVertex": 0x802e78d0,
		"readVertex": 0x802e78d0,
		"J3DModelLoader::readEnvelop": 0x802e7acc,
		"readEnvelop": 0x802e7acc,
		"J3DModelLoader::readDraw": 0x802e7b5c,
		"readDraw": 0x802e7b5c,
		"J3DModelLoader::readJoint": 0x802e7bf0,
		"readJoint": 0x802e7bf0,
		"J3DModelLoader_v26::readMaterial": 0x802e7ce0,
		"J3DMaterial::~J3DMaterial": 0x802e7f38,
		"J3DMaterial::J3DMaterial": 0x802e7f78,
		"J3DModelLoader_v21::readMaterial_v21": 0x802e7fa8,
		"J3DModelLoader::readShape": 0x802e8200,
		"readShape": 0x802e8200,
		"J3DModelLoader::readTexture": 0x802e8348,
		"readTexture": 0x802e8348,
		"J3DModelLoader_v26::readMaterialTable": 0x802e8400,
		"J3DModelLoader_v21::readMaterialTable_v21": 0x802e8544,
		"J3DModelLoader::readTextureTable": 0x802e8688,
		"readTextureTable": 0x802e8688,
		"J3DTexture::~J3DTexture": 0x802e8740,
		"J3DShapeFactory::J3DShapeFactory": 0x802e881c,
		"J3DShapeFactory::create": 0x802e88cc,
		"J3DShapeFactory::newShapeMtx": 0x802e8a84,
		"newShapeMtx": 0x802e8a84,
		"J3DShapeFactory::newShapeDraw": 0x802e8b78,
		"newShapeDraw": 0x802e8b78,
		"J3DShapeFactory::allocVcdVatCmdBuffer": 0x802e8c0c,
		"allocVcdVatCmdBuffer": 0x802e8c0c,
		"J3DAnmLoaderDataBase::load": 0x802e8ca4,
		"J3DAnmVtxColor::J3DAnmVtxColor": 0x802e93a4,
		"J3DAnmColor::J3DAnmColor": 0x802e93fc,
		"J3DAnmFullLoader_v15::J3DAnmFullLoader_v15": 0x802e9460,
		"J3DAnmLoader::~J3DAnmLoader": 0x802e947c,
		"J3DAnmFullLoader_v15::~J3DAnmFullLoader_v15": 0x802e94c8,
		"J3DAnmKeyLoader_v15::J3DAnmKeyLoader_v15": 0x802e9524,
		"J3DAnmKeyLoader_v15::~J3DAnmKeyLoader_v15": 0x802e9540,
		"J3DAnmFullLoader_v15::load": 0x802e959c,
		"J3DAnmFullLoader_v15::readAnmTransform": 0x802e96c8,
		"J3DAnmFullLoader_v15::readAnmColor": 0x802e975c,
		"J3DAnmFullLoader_v15::readAnmTexPattern": 0x802e9844,
		"readAnmTexPattern": 0x802e9844,
		"J3DAnmFullLoader_v15::readAnmVisibility": 0x802e9904,
		"readAnmVisibility": 0x802e9904,
		"J3DAnmFullLoader_v15::readAnmCluster": 0x802e9980,
		"J3DAnmFullLoader_v15::readAnmVtxColor": 0x802e99ec,
		"J3DAnmKeyLoader_v15::load": 0x802e9b64,
		"J3DAnmKeyLoader_v15::readAnmTransform": 0x802e9c90,
		"J3DAnmKeyLoader_v15::readAnmTextureSRT": 0x802e9d2c,
		"readAnmTextureSRT": 0x802e9d2c,
		"J3DAnmKeyLoader_v15::readAnmColor": 0x802e9f28,
		"J3DAnmKeyLoader_v15::readAnmCluster": 0x802ea030,
		"J3DAnmKeyLoader_v15::readAnmTevReg": 0x802ea09c,
		"readAnmTevReg": 0x802ea09c,
		"J3DAnmKeyLoader_v15::readAnmVtxColor": 0x802ea258,
		"J3DAnmVisibilityFull::~J3DAnmVisibilityFull": 0x802ea3d0,
		"J3DAnmTexPattern::~J3DAnmTexPattern": 0x802ea434,
		"J3DAnmTevRegKey::~J3DAnmTevRegKey": 0x802ea498,
		"J3DAnmTextureSRTKey::~J3DAnmTextureSRTKey": 0x802ea4fc,
		"JGadget::TList_pointer_void::TList_pointer_void": 0x802ea698,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::erase": 0x802ea6b8,
		"JGadget::TList_pointer_void::~TList_pointer_void": 0x802ea724,
		"JGadget::TList_pointer_void::insert": 0x802ea800,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::CreateNode_": 0x802ea888,
		"CreateNode_": 0x802ea888,
		"JSystem::JKRDecompressFromDVD": 0x802eae40,
		"JKRDecompressFromDVD": 0x802eae40,
		"JKRDvdRipper::isErrorRetry": 0x802eb3b4,
		"isErrorRetry": 0x802eb3b4,
		"JSystem::__sinit_JKRDvdRipper_cpp": 0x802eb3bc,
		"__sinit_JKRDvdRipper_cpp": 0x802eb3bc,
		"JSUList<JKRDMCommand>::~JSUList": 0x802eb408,
		"J2DGrafContext::setPort": 0x802eb5f0,
		"J2DGrafContext::setup2D": 0x802eb6bc,
		"setup2D": 0x802eb6bc,
		"J2DGrafContext::setScissor": 0x802eb868,
		"setScissor": 0x802eb868,
		"J2DGrafContext::scissor": 0x802eb920,
		"scissor": 0x802eb920,
		"J2DGrafContext::setColor": 0x802eb988,
		"J2DGrafContext::setLineWidth": 0x802eba44,
		"setLineWidth": 0x802eba44,
		"J2DGrafContext::fillBox": 0x802eba70,
		"fillBox": 0x802eba70,
		"J2DGrafContext::setLookat": 0x802ebb9c,
		"JKRDvdAramRipper::loadToAram_Async": 0x802ebd44,
		"loadToAram_Async": 0x802ebd44,
		"JKRDvdAramRipper::callCommand_Async": 0x802ebdf0,
		"callCommand_Async": 0x802ebdf0,
		"JKRDvdAramRipper::syncAram": 0x802ec11c,
		"syncAram": 0x802ec11c,
		"JKRADCommand::JKRADCommand": 0x802ec1ec,
		"JKRADCommand::~JKRADCommand": 0x802ec228,
		"JSystem::JKRDecompressFromDVDToAram": 0x802ec2b4,
		"JKRDecompressFromDVDToAram": 0x802ec2b4,
		"JSystem::dmaBufferFlush": 0x802ec814,
		"dmaBufferFlush": 0x802ec814,
		"JSystem::__sinit_JKRDvdAramRipper_cpp": 0x802ec87c,
		"__sinit_JKRDvdAramRipper_cpp": 0x802ec87c,
		"JSUList<JKRADCommand>::~JSUList": 0x802ec8c8,
		"JKRDecomp::create": 0x802ec920,
		"JKRDecomp::JKRDecomp": 0x802ec97c,
		"JKRDecomp::~JKRDecomp": 0x802ec9d4,
		"JKRDecomp::run": 0x802eca38,
		"JKRDecomp::sendCommand": 0x802ecaf8,
		"JKRDecomp::orderSync": 0x802ecb28,
		"JKRDecomp::decode": 0x802ecbd0,
		"decode": 0x802ecbd0,
		"JKRDecomp::decodeSZP": 0x802ecc5c,
		"decodeSZP": 0x802ecc5c,
		"JKRDecomp::decodeSZS": 0x802ece08,
		"decodeSZS": 0x802ece08,
		"JKRDecomp::checkCompressed": 0x802eceec,
		"checkCompressed": 0x802eceec,
		"JKRDecompCommand::JKRDecompCommand": 0x802ecf3c,
		"JKRDecompCommand::~JKRDecompCommand": 0x802ecf8c,
		"J2DOrthoGraph::setPort": 0x802ed180,
		"J2DOrthoGraph::setLookat": 0x802ed238,
		"J2DOrthoGraph::scissorBounds": 0x802ed274,
		"scissorBounds": 0x802ed274,
		"J3DVertexData::J3DVertexData": 0x802ed614,
		"J3DVertexData::~J3DVertexData": 0x802ed660,
		"J3DVertexBuffer::J3DVertexBuffer": 0x802ed6a0,
		"J3DVertexBuffer::~J3DVertexBuffer": 0x802ed70c,
		"J3DVertexBuffer::copyTransformedVtxArray": 0x802ed758,
		"copyTransformedVtxArray": 0x802ed758,
		"J3DDrawMtxData::J3DDrawMtxData": 0x802ed828,
		"J3DDrawMtxData::~J3DDrawMtxData": 0x802ed83c,
		"J3DDisplayListObj::newDisplayList": 0x802ed87c,
		"newDisplayList": 0x802ed87c,
		"J3DDisplayListObj::callDL": 0x802ed8d8,
		"callDL": 0x802ed8d8,
		"J3DPacket::isSame": 0x802ed904,
		"J3DPacket::entry": 0x802ed90c,
		"J3DPacket::addChildPacket": 0x802ed914,
		"addChildPacket": 0x802ed914,
		"J3DCallBackPacket::draw": 0x802ed934,
		"J3DPacket::draw": 0x802ed9c4,
		"J3DPacket::~J3DPacket": 0x802ed9c8,
		"J3DDrawPacket::~J3DDrawPacket": 0x802eda14,
		"J3DDrawPacket::draw": 0x802eda70,
		"J3DDrawPacket::beginDL": 0x802eda9c,
		"beginDL": 0x802eda9c,
		"J3DDrawPacket::endDL": 0x802edafc,
		"endDL": 0x802edafc,
		"J3DMatPacket::J3DMatPacket": 0x802edb58,
		"J3DMatPacket::~J3DMatPacket": 0x802edbac,
		"J3DMatPacket::addShapePacket": 0x802edc18,
		"addShapePacket": 0x802edc18,
		"J3DMatPacket::draw": 0x802edc38,
		"J3DShapePacket::J3DShapePacket": 0x802edcd8,
		"J3DCallBackPacket::~J3DCallBackPacket": 0x802edd3c,
		"J3DShapePacket::~J3DShapePacket": 0x802edd98,
		"J3DShapePacket::draw": 0x802ede04,
		"J3DMatPacket::isSame": 0x802edec8,
		"JSystem::J3DLoadArrayBasePtr": 0x802edeec,
		"J3DLoadArrayBasePtr": 0x802edeec,
		"JSystem::J3DSetVtxAttrFmtv": 0x802edf20,
		"J3DSetVtxAttrFmtv": 0x802edf20,
		"JSystem::loadCullMode": 0x802ee4ac,
		"loadCullMode": 0x802ee4ac,
		"J3DLightObj::load": 0x802ee4b0,
		"J3DTexMtx::calc": 0x802ee544,
		"J3DTexMtx::load": 0x802ee9d4,
		"JSystem::loadTexNo": 0x802eea04,
		"loadTexNo": 0x802eea04,
		"JSystem::loadDither": 0x802eed4c,
		"loadDither": 0x802eed4c,
		"JSystem::loadNBTScale": 0x802eed50,
		"loadNBTScale": 0x802eed50,
		"JSystem::makeTexCoordTable": 0x802eed84,
		"makeTexCoordTable": 0x802eed84,
		"JSystem::makeAlphaCmpTable": 0x802eef70,
		"makeAlphaCmpTable": 0x802eef70,
		"JSystem::makeZModeTable": 0x802ef318,
		"makeZModeTable": 0x802ef318,
		"JSystem::makeTevSwapTable": 0x802ef450,
		"makeTevSwapTable": 0x802ef450,
		"J3DDrawBuffer::J3DDrawBuffer": 0x802ef5c4,
		"J3DDrawBuffer::frameInit": 0x802ef66c,
		"frameInit": 0x802ef66c,
		"J3DDrawBuffer::entryMatSort": 0x802ef6a4,
		"entryMatSort": 0x802ef6a4,
		"J3DDrawBuffer::entryMatAnmSort": 0x802ef7fc,
		"entryMatAnmSort": 0x802ef7fc,
		"J3DDrawBuffer::entryZSort": 0x802ef8bc,
		"entryZSort": 0x802ef8bc,
		"J3DDrawBuffer::entryModelSort": 0x802ef9bc,
		"entryModelSort": 0x802ef9bc,
		"J3DDrawBuffer::entryInvalidSort": 0x802efa0c,
		"entryInvalidSort": 0x802efa0c,
		"J3DDrawBuffer::entryNonSort": 0x802efa60,
		"entryNonSort": 0x802efa60,
		"J3DDrawBuffer::entryImm": 0x802efa94,
		"entryImm": 0x802efa94,
		"J3DDrawBuffer::draw": 0x802efab4,
		"J3DDrawBuffer::drawHead": 0x802efb08,
		"drawHead": 0x802efb08,
		"J3DDrawBuffer::drawTail": 0x802efb94,
		"drawTail": 0x802efb94,
		"JSystem::__sinit_J3DDrawBuffer_cpp": 0x802efc20,
		"__sinit_J3DDrawBuffer_cpp": 0x802efc20,
		"J3DTexNoAnm::calc": 0x802efcec,
		"J3DMaterialAnm::initialize": 0x802efd1c,
		"J3DMaterialAnm::calc": 0x802efd8c,
		"J3DMaterialAnm::~J3DMaterialAnm": 0x802eff80,
		"JGadget::TVector_pointer_void::TVector_pointer_void": 0x802effcc,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::DestroyElement_": 0x802efff8,
		"std::__copy<void*,1,0>::copy": 0x802f000c,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::InsertRaw": 0x802f00c8,
		"JGadget::TVector_pointer_void::~TVector_pointer_void": 0x802f03bc,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::erase": 0x802f0424,
		"JGadget::TVector_pointer_void::insert": 0x802f048c,
		"JGadget::TVector_pointer_void::reserve": 0x802f0504,
		"reserve": 0x802f0504,
		"JKRAramBlock::JKRAramBlock": 0x802f05dc,
		"JKRAramBlock::~JKRAramBlock": 0x802f0648,
		"JKRAramBlock::allocHead": 0x802f0704,
		"allocHead": 0x802f0704,
		"JKRAramBlock::allocTail": 0x802f07a0,
		"allocTail": 0x802f07a0,
		"JKRAramPiece::sendCommand": 0x802f0844,
		"JKRAramPiece::orderAsync": 0x802f0864,
		"orderAsync": 0x802f0864,
		"JKRAramPiece::orderSync": 0x802f09b8,
		"JKRAramPiece::startDMA": 0x802f0a68,
		"startDMA": 0x802f0a68,
		"JKRAramPiece::doneDMA": 0x802f0ae0,
		"doneDMA": 0x802f0ae0,
		"JKRAMCommand::JKRAMCommand": 0x802f0b88,
		"JKRAMCommand::~JKRAMCommand": 0x802f0bfc,
		"JSystem::__sinit_JKRAramPiece_cpp": 0x802f0ca4,
		"__sinit_JKRAramPiece_cpp": 0x802f0ca4,
		"JKRAramStream::create": 0x802f0cf0,
		"JKRAramStream::JKRAramStream": 0x802f0d5c,
		"JKRAramStream::~JKRAramStream": 0x802f0db4,
		"JKRAramStream::run": 0x802f0e18,
		"JKRAramStream::readFromAram": 0x802f0e80,
		"readFromAram": 0x802f0e80,
		"JKRAramStream::writeToAram": 0x802f0e88,
		"writeToAram": 0x802f0e88,
		"JKRAramStream::write_StreamToAram_Async": 0x802f1058,
		"write_StreamToAram_Async": 0x802f1058,
		"JKRAramStream::sync": 0x802f1114,
		"JKRAramStream::setTransBuffer": 0x802f11a8,
		"setTransBuffer": 0x802f11a8,
		"JKRAramStreamCommand::JKRAramStreamCommand": 0x802f11fc,
		"JUTAssertion::flushMessage": 0x802f1208,
		"flushMessage": 0x802f1208,
		"JUTFont::isLeadByte_1Byte": 0x802f12a0,
		"isLeadByte_1Byte": 0x802f12a0,
		"JUTFont::isLeadByte_2Byte": 0x802f12a8,
		"isLeadByte_2Byte": 0x802f12a8,
		"JUTFont::isLeadByte_ShiftJIS": 0x802f12b0,
		"isLeadByte_ShiftJIS": 0x802f12b0,
		"JUTResFont::JUTResFont": 0x802f1300,
		"JUTResFont::~JUTResFont": 0x802f137c,
		"JUTResFont::initiate": 0x802f1418,
		"JUTResFont::protected_initiate": 0x802f14a4,
		"protected_initiate": 0x802f14a4,
		"JUTResFont::countBlock": 0x802f1554,
		"countBlock": 0x802f1554,
		"JUTResFont::setBlock": 0x802f164c,
		"setBlock": 0x802f164c,
		"JUTResFont::drawChar_scale": 0x802f1b00,
		"JUTResFont::getDescent": 0x802f1f10,
		"JUTResFont::getHeight": 0x802f1f1c,
		"JUTResFont::getAscent": 0x802f1f78,
		"JUTResFont::loadFont": 0x802f1f84,
		"loadFont": 0x802f1f84,
		"JUTResFont::getWidthEntry": 0x802f2084,
		"JUTResFont::isLeadByte": 0x802f2120,
		"JUTResFont::getFontCode": 0x802f2150,
		"getFontCode": 0x802f2150,
		"JUTResFont::getFontType": 0x802f22d0,
		"JUTResFont::loadImage": 0x802f22dc,
		"JUTResFont::convertSjis": 0x802f2450,
		"convertSjis": 0x802f2450,
		"JUTResFont::getLeading": 0x802f2480,
		"JUTRomFont::JUTRomFont": 0x802f248c,
		"JUTRomFont::initiate": 0x802f24e8,
		"JUTRomFont::~JUTRomFont": 0x802f252c,
		"JUTRomFont::loadImage": 0x802f25c8,
		"JUTRomFont::setGX": 0x802f269c,
		"JUTRomFont::drawChar_scale": 0x802f2774,
		"JUTRomFont::getDescent": 0x802f2bc8,
		"JUTRomFont::getAscent": 0x802f2bd4,
		"JUTRomFont::getHeight": 0x802f2be0,
		"JUTRomFont::getWidth": 0x802f2c3c,
		"JUTRomFont::getWidthEntry": 0x802f2c48,
		"JUTRomFont::isLeadByte": 0x802f2cb0,
		"JUTRomFont::getLeading": 0x802f2ce0,
		"JUTRomFont::getResFont": 0x802f2cec,
		"getResFont": 0x802f2cec,
		"JUTRomFont::getFontType": 0x802f2cf4,
		"JSystem::J3DGDLoadTexMtxImm": 0x802f2d00,
		"J3DGDLoadTexMtxImm": 0x802f2d00,
		"JSystem::J3DGDSetChanAmbColor": 0x802f33a8,
		"J3DGDSetChanAmbColor": 0x802f33a8,
		"JSystem::J3DGDSetChanMatColor": 0x802f34ec,
		"J3DGDSetChanMatColor": 0x802f34ec,
		"JSystem::J3DGDSetChanCtrl": 0x802f3630,
		"J3DGDSetChanCtrl": 0x802f3630,
		"JSystem::J3DGDSetTexCoordGen": 0x802f389c,
		"J3DGDSetTexCoordGen": 0x802f389c,
		"JSystem::J3DGDSetFog": 0x802f3c04,
		"J3DGDSetFog": 0x802f3c04,
		"JSystem::J3DGDSetTexCoordScale2": 0x802f3f80,
		"J3DGDSetTexCoordScale2": 0x802f3f80,
		"JSystem::J3DGDSetTexImgAttr": 0x802f417c,
		"J3DGDSetTexImgAttr": 0x802f417c,
		"JSystem::J3DGDSetTexImgPtr": 0x802f4260,
		"J3DGDSetTexImgPtr": 0x802f4260,
		"JSystem::J3DGDSetTexTlut": 0x802f432c,
		"J3DGDSetTexTlut": 0x802f432c,
		"JSystem::J3DGDLoadTlut": 0x802f4400,
		"J3DGDLoadTlut": 0x802f4400,
		"JSystem::J3DGDSetTevKColor": 0x802f47b8,
		"J3DGDSetTevKColor": 0x802f47b8,
		"JSystem::JRNLoadCurrentMtx": 0x802f4920,
		"JRNLoadCurrentMtx": 0x802f4920,
		"JSystem::JRNSetTevIndirect": 0x802f49b8,
		"JRNSetTevIndirect": 0x802f49b8,
		"JSystem::JRNSetIndTexMtx": 0x802f4ae0,
		"JRNSetIndTexMtx": 0x802f4ae0,
		"JSystem::JRNSetIndTexCoordScale": 0x802f4db8,
		"JRNSetIndTexCoordScale": 0x802f4db8,
		"JSystem::JRNSetIndTexOrder": 0x802f4ea8,
		"JRNSetIndTexOrder": 0x802f4ea8,
		"JSystem::JRNLoadTexCached": 0x802f50bc,
		"JRNLoadTexCached": 0x802f50bc,
		"JSystem::JRNISetTevOrder": 0x802f513c,
		"JRNISetTevOrder": 0x802f513c,
		"JSystem::JRNISetTevColorS10": 0x802f52ac,
		"JRNISetTevColorS10": 0x802f52ac,
		"JSystem::JRNISetFogRangeAdj": 0x802f54e0,
		"JRNISetFogRangeAdj": 0x802f54e0,
		"JUTConsole::create": 0x802f568c,
		"JUTConsole::JUTConsole": 0x802f5724,
		"JUTConsole::~JUTConsole": 0x802f5828,
		"JUTConsole::getLineFromObjectSize": 0x802f5898,
		"getLineFromObjectSize": 0x802f5898,
		"JUTConsole::clear": 0x802f58a8,
		"JUTConsole::doDraw": 0x802f5904,
		"doDraw": 0x802f5904,
		"JUTConsole::print_f": 0x802f5da8,
		"print_f": 0x802f5da8,
		"JUTConsole::print": 0x802f5e28,
		"JSystem::JUTConsole_print_f_va_": 0x802f6038,
		"JUTConsole_print_f_va_": 0x802f6038,
		"JUTConsole::scroll": 0x802f6080,
		"scroll": 0x802f6080,
		"JUTConsole::getUsedLine": 0x802f615c,
		"getUsedLine": 0x802f615c,
		"JUTConsole::getLineOffset": 0x802f6180,
		"getLineOffset": 0x802f6180,
		"JUTConsoleManager::JUTConsoleManager": 0x802f61a4,
		"JUTConsoleManager::createManager": 0x802f61cc,
		"createManager": 0x802f61cc,
		"JUTConsoleManager::appendConsole": 0x802f6214,
		"appendConsole": 0x802f6214,
		"JUTConsoleManager::removeConsole": 0x802f62b0,
		"removeConsole": 0x802f62b0,
		"JGadget::TNodeLinkList::end": 0x802f6388,
		"JGadget::TLinkList<10JUTConsole,-24>::iterator::iterator": 0x802f6394,
		"JUTConsoleManager::drawDirect": 0x802f63a0,
		"drawDirect": 0x802f63a0,
		"JUTConsoleManager::setDirectConsole": 0x802f6420,
		"setDirectConsole": 0x802f6420,
		"JGadget::TLinkListNode::getNext": 0x802f65d0,
		"getNext": 0x802f65d0,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getValue": 0x802f65d8,
		"Element_getValue": 0x802f65d8,
		"JGadget::TNodeLinkList::iterator::operator_->": 0x802f65e0,
		"operator_->": 0x802f65e0,
		"JGadget::TLinkListNode::getPrev": 0x802f65e8,
		"getPrev": 0x802f65e8,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getNode": 0x802f65f0,
		"JSystem::JUTSetReportConsole": 0x802f65f8,
		"JUTSetReportConsole": 0x802f65f8,
		"JSystem::JUTGetReportConsole": 0x802f6600,
		"JUTGetReportConsole": 0x802f6600,
		"JSystem::JUTSetWarningConsole": 0x802f6608,
		"JUTSetWarningConsole": 0x802f6608,
		"JSystem::JUTGetWarningConsole": 0x802f6610,
		"JUTGetWarningConsole": 0x802f6610,
		"JSystem::JUTReportConsole_f": 0x802f6618,
		"JUTReportConsole_f": 0x802f6618,
		"JSystem::JUTReportConsole": 0x802f66dc,
		"JUTReportConsole": 0x802f66dc,
		"JSystem::JUTWarningConsole_f": 0x802f6708,
		"JUTWarningConsole_f": 0x802f6708,
		"JSystem::JUTWarningConsole": 0x802f67cc,
		"JUTWarningConsole": 0x802f67cc,
		"JUTDirectFile::JUTDirectFile": 0x802f67f8,
		"JUTDirectFile::~JUTDirectFile": 0x802f681c,
		"JUTDirectFile::fopen": 0x802f6864,
		"fopen": 0x802f6864,
		"JUTDirectFile::fclose": 0x802f6908,
		"fclose": 0x802f6908,
		"JUTDirectFile::fgets": 0x802f6964,
		"fgets": 0x802f6964,
		"JGadget::TNodeLinkList::Insert": 0x802f6b9c,
		"JGadget::TNodeLinkList::Erase": 0x802f6bc8,
		"Erase": 0x802f6bc8,
		"JGadget::TNodeLinkList::Remove": 0x802f6bec,
		"Remove": 0x802f6bec,
		"JGadget::TNodeLinkList::Remove_if": 0x802f6c3c,
		"Remove_if": 0x802f6c3c,
		"JGadget::TSingleNodeLinkList::~TSingleNodeLinkList": 0x802f6d5c,
		"JGadget::TSingleNodeLinkList::Insert": 0x802f6d9c,
		"JDrama::TActor::load": 0x802f6dd0,
		"JDrama::TActor::perform": 0x802f6f24,
		"JDrama::TPolarCamera::load": 0x802f7180,
		"JDrama::TPolarCamera::perform": 0x802f71e8,
		"JDrama::TLookAtCamera::perform": 0x802f7654,
		"JDrama::TOrthoProj::load": 0x802f77cc,
		"JDrama::TOrthoProj::perform": 0x802f7844,
		"JDrama::TSmplChara::load": 0x802f7b1c,
		"JDrama::TSmplChara::~TSmplChara": 0x802f7b70,
		"JDrama::TSmplChara::getRes": 0x802f7c04,
		"JDrama::TSmplChara::mountArc": 0x802f7c34,
		"mountArc": 0x802f7c34,
		"JDrama::TDirector::searchF": 0x802f7c74,
		"JDrama::TDirector::direct": 0x802f7d28,
		"JDrama::TDisplay::TDisplay": 0x802f7eac,
		"JDrama::TDisplay::startRendering": 0x802f7fd8,
		"startRendering": 0x802f7fd8,
		"JDrama::TDisplay::endRendering": 0x802f80d0,
		"endRendering": 0x802f80d0,
		"JDrama::TDrawBufObj::load": 0x802f8294,
		"JDrama::TDrawBufObj::perform": 0x802f830c,
		"JDrama::TDStageDisp::TDStageDisp": 0x802f83b0,
		"JDrama::TViewConnecter::~TViewConnecter": 0x802f850c,
		"JDrama::TDStageDisp::getEfbCtrlDisp": 0x802f8580,
		"getEfbCtrlDisp": 0x802f8580,
		"JDrama::TDStageDisp::~TDStageDisp": 0x802f8588,
		"JDrama::TDStageGroup::perform": 0x802f860c,
		"JDrama::TDStageGroup::~TDStageGroup": 0x802f86a0,
		"JDrama::TEfbCtrl::perform": 0x802f8774,
		"JDrama::TEfbCtrl::setSrcRect": 0x802f884c,
		"setSrcRect": 0x802f884c,
		"JDrama::TEfbCtrlDisp::perform": 0x802f8904,
		"JDrama::TEfbCtrlTex::TEfbCtrlTex": 0x802f8a5c,
		"JDrama::TEfbCtrlTex::setTexAttb": 0x802f8b40,
		"setTexAttb": 0x802f8b40,
		"JDrama::TEfbCtrlTex::perform": 0x802f8bac,
		"JDrama::TEfbCtrlTex::~TEfbCtrlTex": 0x802f8da4,
		"JDrama::TEfbCtrlDisp::~TEfbCtrlDisp": 0x802f8e28,
		"JDrama::DecidePixelFmt": 0x802f8eac,
		"DecidePixelFmt": 0x802f8eac,
		"JDrama::IssueGXSetCopyFilter": 0x802f9054,
		"IssueGXSetCopyFilter": 0x802f9054,
		"JDrama::IssueGXSetCopyClear": 0x802f90a4,
		"IssueGXSetCopyClear": 0x802f90a4,
		"JDrama::IssueGXCopyDisp": 0x802f917c,
		"IssueGXCopyDisp": 0x802f917c,
		"JDrama::TFrmGXSet::perform": 0x802f9310,
		"JDrama::TGraphics::setViewport": 0x802f9534,
		"setViewport": 0x802f9534,
		"JDrama::TLight::load": 0x802f96b8,
		"JDrama::TLight::perform": 0x802f971c,
		"JDrama::TLight::correct": 0x802f9774,
		"correct": 0x802f9774,
		"JDrama::TLightAry::load": 0x802f9878,
		"JDrama::TLightAry::searchF": 0x802f9970,
		"JDrama::TLightAry::setLightNum": 0x802f9a00,
		"setLightNum": 0x802f9a00,
		"JDrama::TIdxLight::TIdxLight": 0x802f9b4c,
		"JDrama::TLightAry::perform": 0x802f9d14,
		"JDrama::TAmbColor::load": 0x802f9db4,
		"JDrama::TAmbColor::perform": 0x802f9e04,
		"JDrama::TAmbAry::load": 0x802f9e60,
		"JDrama::TAmbAry::searchF": 0x802f9f58,
		"JDrama::TAmbAry::setAmbNum": 0x802f9fe8,
		"setAmbNum": 0x802f9fe8,
		"JDrama::TAmbColor::TAmbColor": 0x802fa0e0,
		"JDrama::TLightMap::load": 0x802fa184,
		"JDrama::TLightMap::TLightInfo::TLightInfo": 0x802fa278,
		"JDrama::TLightMap::perform": 0x802fa288,
		"JDrama::TLightMap::~TLightMap": 0x802fa320,
		"JDrama::TAmbAry::~TAmbAry": 0x802fa394,
		"JDrama::TAmbAry::perform": 0x802fa408,
		"JDrama::TLightAry::~TLightAry": 0x802fa40c,
		"JDrama::TNameRef::calcKeyCode": 0x802fa4d8,
		"JDrama::TNameRef::genObject": 0x802fa598,
		"genObject": 0x802fa598,
		"JDrama::TNameRef::~TNameRef": 0x802fa648,
		"JDrama::TNameRef::load": 0x802fa69c,
		"JDrama::TNameRef::save": 0x802fa6f4,
		"JDrama::TNameRef::loadAfter": 0x802fa6f8,
		"JDrama::TNameRef::searchF": 0x802fa6fc,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadSuper": 0x802fa76c,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfterSuper": 0x802fa78c,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::searchF": 0x802fa7ac,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::loadAfter": 0x802fa894,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::load": 0x802fa940,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::perform": 0x802faa7c,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::searchF": 0x802fab38,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfter": 0x802fac20,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::load": 0x802facd8,
		"JDrama::TNameRefGen::load": 0x802fae20,
		"JDrama::TNameRefGen::getNameRef": 0x802faf0c,
		"JDrama::TLight::TLight": 0x802fb554,
		"JDrama::TCamera::TCamera": 0x802fb65c,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::~TNameRefPtrListT": 0x802fb728,
		"~TNameRefPtrListT": 0x802fb728,
		"JDrama::TPlacement::load": 0x802fb7a0,
		"JDrama::IsEqualRenderModeVIParams": 0x802fb808,
		"IsEqualRenderModeVIParams": 0x802fb808,
		"JDrama::IsRenderModeHalfAspectRatio": 0x802fb928,
		"IsRenderModeHalfAspectRatio": 0x802fb928,
		"JDrama::GetRenderModeYScale": 0x802fb944,
		"GetRenderModeYScale": 0x802fb944,
		"JDrama::CalcRenderModeXFBHeight": 0x802fb9e8,
		"CalcRenderModeXFBHeight": 0x802fb9e8,
		"JDrama::CalcRenderModeVIXOrigin": 0x802fbac8,
		"CalcRenderModeVIXOrigin": 0x802fbac8,
		"JDrama::CalcRenderModeVIYOrigin": 0x802fbb0c,
		"CalcRenderModeVIYOrigin": 0x802fbb0c,
		"JDrama::CopyRenderModeSamplePattern": 0x802fbb50,
		"CopyRenderModeSamplePattern": 0x802fbb50,
		"JDrama::CopyRenderModeVFilter": 0x802fbb78,
		"CopyRenderModeVFilter": 0x802fbb78,
		"TCamConnecter::perform": 0x802fbc68,
		"JDrama::TScreen::TScreen": 0x802fbd04,
		"JDrama::TScreen::assignCamera": 0x802fbddc,
		"assignCamera": 0x802fbddc,
		"JDrama::TScreen::assignViewObj": 0x802fbde8,
		"assignViewObj": 0x802fbde8,
		"JDrama::TScreen::~TScreen": 0x802fbdf4,
		"TCamConnecter::~TCamConnecter": 0x802fbe78,
		"JDrama::TSmJ3DAct::load": 0x802fbefc,
		"JDrama::TSmJ3DAct::perform": 0x802fc000,
		"JDrama::TSmJ3DScn::TSmJ3DScn": 0x802fc540,
		"JDrama::TSmJ3DScn::perform": 0x802fc644,
		"JDrama::TSmJ3DScn::loadSuper": 0x802fc758,
		"JDrama::TSmJ3DScn::~TSmJ3DScn": 0x802fc80c,
		"JDrama::TVideo::TVideo": 0x802fc8a8,
		"JDrama::TVideo::setNextXFB": 0x802fc99c,
		"setNextXFB": 0x802fc99c,
		"JDrama::TVideo::waitForRetrace": 0x802fc9a4,
		"waitForRetrace": 0x802fc9a4,
		"JDrama::TViewConnecter::TViewConnecter": 0x802fcb5c,
		"JDrama::TViewConnecter::perform": 0x802fcbf8,
		"JDrama::TViewObj::testPerform": 0x802fcc94,
		"testPerform": 0x802fcc94,
		"JDrama::TViewport::TViewport": 0x802fccfc,
		"JDrama::TViewport::perform": 0x802fcd8c,
		"JDrama::TViewport::load": 0x802fce3c,
		"JDrama::TViewport::~TViewport": 0x802fceb4,
		"JALCalc::linearTransform": 0x802fcf28,
		"linearTransform": 0x802fcf28,
		"JALCalc::getParamByExp": 0x802fcf9c,
		"getParamByExp": 0x802fcf9c,
		"JALCalc::getRandom": 0x802fd0f0,
		"getRandom": 0x802fd0f0,
		"JALCalc::getRandom_0_1": 0x802fd184,
		"getRandom_0_1": 0x802fd184,
		"JALCalc::getDist": 0x802fd1f8,
		"getDist": 0x802fd1f8,
		"JALCalc::getDistPow": 0x802fd270,
		"getDistPow": 0x802fd270,
		"JALSystem::init": 0x802fd344,
		"JALSystem::gateCheckFunc": 0x802fd384,
		"gateCheckFunc": 0x802fd384,
		"JALSystem::processModFunc": 0x802fd4f8,
		"processModFunc": 0x802fd4f8,
		"JALSystem::processModDistVolume": 0x802fd6f8,
		"processModDistVolume": 0x802fd6f8,
		"JALSystem::append": 0x802fd7a4,
		"JSUList<JALSeModDataGrpMemb>::JSUList": 0x802fdd70,
		"JALSystem::appendGrpMember": 0x802fdda0,
		"appendGrpMember": 0x802fdda0,
		"JALSystem::TFlagManager::TFlagManager": 0x802fe070,
		"JALSystem::TFlagManager::addUseFlag": 0x802fe1b8,
		"addUseFlag": 0x802fe1b8,
		"JALSystem::TFlagManager::isRegistered": 0x802fe1d4,
		"isRegistered": 0x802fe1d4,
		"JALSeModDataGrp<JALSeModVolDGrp>::calcGrp": 0x802fe200,
		"JALSeModDataGrp<JALSeModEffFGrp>::calcGrp": 0x802fe264,
		"JALSeModDataGrp<JALSeModEffFGrp>::gateCheckGrp": 0x802fe2c8,
		"JALSeModDataGrp<JALSeModPitFGrp>::gateCheckGrp": 0x802fe318,
		"JALSeModDataGrp<JALSeModVolFGrp>::calcGrp": 0x802fe368,
		"JALSeModDataGrp<JALSeModVolFGrp>::gateCheckGrp": 0x802fe3cc,
		"JALSeModData<JALSeModEffDGrp>::calcDyna": 0x802fe41c,
		"JALSeModData<JALSeModEffDGrp>::gateCheckDyna": 0x802fe454,
		"JALSeModData<JALSeModPitDGrp>::calcDyna": 0x802fe4e8,
		"JALSeModData<JALSeModPitDGrp>::gateCheckDyna": 0x802fe520,
		"JALSeModData<JALSeModVolDGrp>::calcDyna": 0x802fe5b4,
		"JALSeModData<JALSeModVolDGrp>::gateCheckDyna": 0x802fe5ec,
		"JALSeModData<JALSeModEffFGrp>::calcDyna": 0x802fe680,
		"JALSeModData<JALSeModEffFGrp>::gateCheckDyna": 0x802fe6b8,
		"JALSeModData<JALSeModPitFGrp>::gateCheckDyna": 0x802fe74c,
		"JALSeModData<JALSeModVolFGrp>::calcDyna": 0x802fe7e0,
		"JALSeModData<JALSeModVolFGrp>::gateCheckDyna": 0x802fe818,
		"JALSeModData<JALSeModEffDist>::calcDyna": 0x802fe8ac,
		"JALSeModData<JALSeModEffDist>::gateCheckDyna": 0x802fe8e4,
		"JALSeModData<JALSeModPitDist>::calcDyna": 0x802fe978,
		"JALSeModData<JALSeModPitDist>::gateCheckDyna": 0x802fe9b0,
		"JALSeModData<JALSeModVolDist>::calc": 0x802fea44,
		"JALSeModData<JALSeModVolDist>::calcDyna": 0x802feaa8,
		"JALSeModData<JALSeModVolDist>::gateCheckDyna": 0x802feae0,
		"JALSeModData<JALSeModEffFunk>::calc": 0x802feb74,
		"JALSeModData<JALSeModEffFunk>::calcDyna": 0x802febd8,
		"JALSeModData<JALSeModEffFunk>::gateCheck": 0x802fec10,
		"JALSeModData<JALSeModEffFunk>::gateCheckDyna": 0x802fec60,
		"JALSeModData<JALSeModPitFunk>::calc": 0x802fecf4,
		"JALSeModData<JALSeModPitFunk>::calcDyna": 0x802fed58,
		"JALSeModData<JALSeModPitFunk>::gateCheck": 0x802fed90,
		"JALSeModData<JALSeModPitFunk>::gateCheckDyna": 0x802fede0,
		"JALSeModData<JALSeModVolFunk>::gateCheck": 0x802fee74,
		"JALSeModData<JALSeModVolFunk>::gateCheckDyna": 0x802feec4,
		"JALListS<JALSeModPitFunk,unsigned_long><JALSeModPitFunk,unsigned_long>::search": 0x802fef58,
		"JALListS<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::search": 0x802fef8c,
		"JALListS<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::search": 0x802fefc0,
		"JALListS<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::search": 0x802feff4,
		"JALListS<JALSeModPitFGrp,unsigned_long><JALSeModPitFGrp,unsigned_long>::search": 0x802ff028,
		"JALListS<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::search": 0x802ff05c,
		"JALListS<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::search": 0x802ff090,
		"JALListS<JALSeModPitDGrp,unsigned_long><JALSeModPitDGrp,unsigned_long>::search": 0x802ff0c4,
		"JALListS<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::search": 0x802ff0f8,
		"JALLinkD<JALSeModDataGrpMemb,unsigned_long><JALSeModDataGrpMemb,unsigned_long>::JALLinkD": 0x802ff12c,
		"JALLinkD": 0x802ff12c,
		"JALSeModData<JALSeModVolFunk>::JALSeModData": 0x802ff19c,
		"JALSeModData<JALSeModPitFunk>::JALSeModData": 0x802ff228,
		"JALSeModData<JALSeModEffFunk>::JALSeModData": 0x802ff2b4,
		"JALSeModData<JALSeModVolDist>::JALSeModData": 0x802ff340,
		"JALSeModData<JALSeModPitDist>::JALSeModData": 0x802ff3cc,
		"JALSeModData<JALSeModEffDist>::JALSeModData": 0x802ff458,
		"JALSeModData<JALSeModVolFGrp>::JALSeModData": 0x802ff4e4,
		"JALSeModData<JALSeModPitFGrp>::JALSeModData": 0x802ff570,
		"JALSeModData<JALSeModEffFGrp>::JALSeModData": 0x802ff5fc,
		"JALSeModData<JALSeModVolDGrp>::JALSeModData": 0x802ff688,
		"JALSeModData<JALSeModPitDGrp>::JALSeModData": 0x802ff714,
		"JALSeModData<JALSeModEffDGrp>::JALSeModData": 0x802ff7a0,
		"JALListGrp<JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802ff82c,
		"JALListGrp<JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802ff888,
		"JALListGrp<JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802ff8e4,
		"JALListHioNode<JALSeModVolFunk,unsigned_long><JALSeModVolFunk,unsigned_long>::JALListHioNode": 0x802ff940,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x802ff994,
		"__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x802ff994,
		"JALListHioNode<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::JALListHioNode": 0x802ff9e8,
		"JALListHioNode<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::JALListHioNode": 0x802ffa3c,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x802ffa90,
		"__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x802ffa90,
		"JALListHioNode<JALSeModEffDist,unsigned_long><JALSeModEffDist,unsigned_long>::JALListHioNode": 0x802ffae4,
		"JALListHioNode<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::JALListHioNode": 0x802ffb38,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x802ffb8c,
		"__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x802ffb8c,
		"JALListHioNode<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::JALListHioNode": 0x802ffbe0,
		"JALListHioNode<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::JALListHioNode": 0x802ffc34,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x802ffc88,
		"__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x802ffc88,
		"JALListHioNode<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::JALListHioNode": 0x802ffcdc,
		"JSystem::__sinit_JALModSe_cpp": 0x802ffd30,
		"__sinit_JALModSe_cpp": 0x802ffd30,
		"JAIAnimeSound::JAIAnimeSound": 0x802fff9c,
		"JAIAnimeSound::initActorAnimSound": 0x80300010,
		"initActorAnimSound": 0x80300010,
		"JAIAnimeSound::setAnimSoundVec": 0x80300164,
		"setAnimSoundVec": 0x80300164,
		"JAIAnimeSound::setAnimSoundActor": 0x8030019c,
		"setAnimSoundActor": 0x8030019c,
		"JAIAnimeSound::playActorAnimSound": 0x803005f0,
		"playActorAnimSound": 0x803005f0,
		"JAIAnimeSound::startAnimSound": 0x80300804,
		"JAIAnimeSound::setSpeedModifySound": 0x80300838,
		"JAIAnimeSound::stop": 0x80300978,
		"JAIBasic::JAIBasic": 0x803009e0,
		"JAIBasic::initInterfaceMain": 0x80300ab8,
		"initInterfaceMain": 0x80300ab8,
		"JAIBasic::setCameraInfo": 0x80300ce4,
		"JAIBasic::initStream": 0x80300d18,
		"initStream": 0x80300d18,
		"JAIBasic::setRegisterTrackCallback": 0x80300d50,
		"JAIBasic::initReadFile": 0x80300d78,
		"initReadFile": 0x80300d78,
		"JAIBasic::checkInitListFile": 0x80300e44,
		"checkInitListFile": 0x80300e44,
		"JAIBasic::checkInitDataFile": 0x80300f30,
		"checkInitDataFile": 0x80300f30,
		"JAIBasic::checkInitDataOnMemory": 0x80300fa0,
		"checkInitDataOnMemory": 0x80300fa0,
		"JAIBasic::transInitDataFile": 0x803013d4,
		"transInitDataFile": 0x803013d4,
		"JAIBasic::initBankWave": 0x803014c0,
		"initBankWave": 0x803014c0,
		"JAIBasic::setWaveScene": 0x80301694,
		"setWaveScene": 0x80301694,
		"JAIBasic::setSceneSetFinishCallback": 0x80301744,
		"setSceneSetFinishCallback": 0x80301744,
		"JAIBasic::finishSceneSet": 0x80301790,
		"finishSceneSet": 0x80301790,
		"JAIBasic::loadSceneWave": 0x803017b0,
		"loadSceneWave": 0x803017b0,
		"JAIBasic::checkSceneWaveOnMemory": 0x80301850,
		"checkSceneWaveOnMemory": 0x80301850,
		"JAIBasic::loadGroupWave": 0x80301884,
		"JAIBasic::initNullData": 0x80301908,
		"initNullData": 0x80301908,
		"JAIBasic::initDriver": 0x80301a28,
		"initDriver": 0x80301a28,
		"JAIBasic::initInterface": 0x80301aa0,
		"initInterface": 0x80301aa0,
		"JAIBasic::initAllocParameter": 0x80301ac4,
		"initAllocParameter": 0x80301ac4,
		"JAIBasic::initSeqsLoadArea": 0x80301b88,
		"initSeqsLoadArea": 0x80301b88,
		"JAIBasic::setInitFileLoadSwitch": 0x80301c14,
		"setInitFileLoadSwitch": 0x80301c14,
		"JAIBasic::startFrameInterfaceWork": 0x80301c1c,
		"startFrameInterfaceWork": 0x80301c1c,
		"JAIBasic::processFrameWork": 0x80301c3c,
		"processFrameWork": 0x80301c3c,
		"JAIBasic::checkStream": 0x80301da4,
		"checkStream": 0x80301da4,
		"JAIBasic::checkDummyPositionBuffer": 0x80301de8,
		"checkDummyPositionBuffer": 0x80301de8,
		"JAIBasic::startSoundActor": 0x80301e80,
		"JAIBasic::startSoundActorReturnHandle": 0x80301f14,
		"startSoundActorReturnHandle": 0x80301f14,
		"JAIBasic::startSoundDirectID": 0x80301fc4,
		"startSoundDirectID": 0x80301fc4,
		"JAIBasic::startSoundIndirectID": 0x80302034,
		"startSoundIndirectID": 0x80302034,
		"JAIBasic::startSoundBasic": 0x803020ac,
		"startSoundBasic": 0x803020ac,
		"JAIBasic::stopSoundHandle": 0x80302224,
		"stopSoundHandle": 0x80302224,
		"JAIBasic::changeIDToCategory": 0x80302414,
		"changeIDToCategory": 0x80302414,
		"JAIBasic::stopAllSe": 0x8030241c,
		"stopAllSe": 0x8030241c,
		"JAIBasic::getControllerHandle": 0x80302484,
		"getControllerHandle": 0x80302484,
		"JAIBasic::releaseControllerHandle": 0x803024dc,
		"releaseControllerHandle": 0x803024dc,
		"JAIBasic::getStreamParameter": 0x80302554,
		"JAIBasic::releaseStreamParameterPointer": 0x803025b4,
		"releaseStreamParameterPointer": 0x803025b4,
		"JAIBasic::getSeqParametermeterPointer": 0x8030262c,
		"getSeqParametermeterPointer": 0x8030262c,
		"JAIBasic::releaseSeqParameterPointer": 0x8030268c,
		"releaseSeqParameterPointer": 0x8030268c,
		"JAIBasic::getSeParametermeterPointer": 0x80302704,
		"getSeParametermeterPointer": 0x80302704,
		"JAIBasic::releaseSeParameterPointer": 0x80302794,
		"releaseSeParameterPointer": 0x80302794,
		"JAIBasic::releaseDummyVecPointer": 0x80302814,
		"releaseDummyVecPointer": 0x80302814,
		"JAIBasic::getMapInfoFxline": 0x8030288c,
		"getMapInfoFxline": 0x8030288c,
		"JAIBasic::getMapInfoGround": 0x803028a4,
		"JAIBasic::getMapInfoFxParameter": 0x803028bc,
		"getMapInfoFxParameter": 0x803028bc,
		"JAIBasic::getInfoPointerFromID": 0x803028d4,
		"getInfoPointerFromID": 0x803028d4,
		"JAIBasic::getInfoFormat": 0x8030294c,
		"getInfoFormat": 0x8030294c,
		"JAIBasic::setSeCategoryVolume": 0x803029a4,
		"setSeCategoryVolume": 0x803029a4,
		"JAIBasic::setParameterSeqSync": 0x803029e0,
		"JAIBasic::getSoundInfoFromID": 0x80302bb0,
		"getSoundInfoFromID": 0x80302bb0,
		"JAIBasic::getSeqTrackNumber": 0x80302bdc,
		"getSeqTrackNumber": 0x80302bdc,
		"JAIBasic::getSoundPrioity": 0x80302be4,
		"getSoundPrioity": 0x80302be4,
		"JAIBasic::getSoundSwBit": 0x80302bec,
		"getSoundSwBit": 0x80302bec,
		"JAIBasic::setSeExtParameter": 0x80302bf4,
		"JAIBasic::routeToTrack": 0x80302da0,
		"routeToTrack": 0x80302da0,
		"JAIBasic::initHeap": 0x80302de0,
		"initHeap": 0x80302de0,
		"JAIBasic::allocHeap": 0x80302e28,
		"allocHeap": 0x80302e28,
		"JAIBasic::makeSound": 0x80302e70,
		"JAIBasic::loadDVDFile": 0x80302f04,
		"loadDVDFile": 0x80302f04,
		"JAIBasic::loadTmpDVDFile": 0x80302f88,
		"loadTmpDVDFile": 0x80302f88,
		"JAIBasic::deleteTmpDVDFile": 0x80303000,
		"deleteTmpDVDFile": 0x80303000,
		"JAIBasic::loadArcSeqData": 0x8030303c,
		"loadArcSeqData": 0x8030303c,
		"JSystem::__sinit_JAIBasic_cpp": 0x803031ac,
		"__sinit_JAIBasic_cpp": 0x803031ac,
		"JSystem::__sinit_JAIConst_cpp": 0x803031dc,
		"__sinit_JAIConst_cpp": 0x803031dc,
		"JAIData::init": 0x80303220,
		"JAIData::initLinkBuffer": 0x80303244,
		"initLinkBuffer": 0x80303244,
		"JAIData::initSeqParaLinkBuffer": 0x8030339c,
		"initSeqParaLinkBuffer": 0x8030339c,
		"JAIData::initSeqParameter": 0x803034a8,
		"initSeqParameter": 0x803034a8,
		"JAIData::initSePara": 0x803036f8,
		"initSePara": 0x803036f8,
		"JAIData::initStreamParaLinkBuffer": 0x80303858,
		"initStreamParaLinkBuffer": 0x80303858,
		"JAIData::initStreamParameter": 0x80303964,
		"initStreamParameter": 0x80303964,
		"JAIData::initSeqTrackInfoParameter": 0x803039c0,
		"initSeqTrackInfoParameter": 0x803039c0,
		"JAIData::initStreamUpdateParameter": 0x80303aa4,
		"initStreamUpdateParameter": 0x80303aa4,
		"JAIData::setSeMovePara": 0x80303af4,
		"setSeMovePara": 0x80303af4,
		"JAIData::moveParameter": 0x80303b58,
		"moveParameter": 0x80303b58,
		"JAIData::checkOnMemory": 0x80303ba0,
		"checkOnMemory": 0x80303ba0,
		"JAIData::checkUsefulAutoHeapPosition": 0x80303c68,
		"checkUsefulAutoHeapPosition": 0x80303c68,
		"JAIData::getFreeAutoHeapPointer": 0x80303d18,
		"getFreeAutoHeapPointer": 0x80303d18,
		"JAIData::releaseAutoHeapPointer": 0x80303d64,
		"releaseAutoHeapPointer": 0x80303d64,
		"JAIData::getFreeStayHeapPointer": 0x80303d88,
		"getFreeStayHeapPointer": 0x80303d88,
		"JAIData::setAutoHeapLoadedFlag": 0x80303e40,
		"setAutoHeapLoadedFlag": 0x80303e40,
		"JAIData::getInfoPointer": 0x80303e54,
		"getInfoPointer": 0x80303e54,
		"JAIData::initData": 0x80303fac,
		"JAIData::initInfoDataWork": 0x8030481c,
		"initInfoDataWork": 0x8030481c,
		"JAIEntry::checkSoundHandle": 0x8030493c,
		"checkSoundHandle": 0x8030493c,
		"JAIEntry::initSoundParameter": 0x803049f8,
		"initSoundParameter": 0x803049f8,
		"JAISeEntry::storeBuffer": 0x80304a9c,
		"JAISeqEntry::storeBuffer": 0x80304e18,
		"JAIStreamEntry::storeBuffer": 0x80305104,
		"JAIBasic::checkNextFrameSe": 0x80305204,
		"checkNextFrameSe": 0x80305204,
		"JAIBasic::sendPlayingSeCommand": 0x80305958,
		"sendPlayingSeCommand": 0x80305958,
		"JAIBasic::setSeqMuteFromSeStart": 0x80305edc,
		"setSeqMuteFromSeStart": 0x80305edc,
		"JAIBasic::checkSeMovePara": 0x80305fbc,
		"checkSeMovePara": 0x80305fbc,
		"JAIBasic::sendSeAllParameter": 0x803060e8,
		"sendSeAllParameter": 0x803060e8,
		"JAIBasic::releaseSeRegist": 0x803066f4,
		"releaseSeRegist": 0x803066f4,
		"JAIBasic::stopSeq": 0x803068d8,
		"JAIBasic::checkEntriedSeq": 0x80306a1c,
		"checkEntriedSeq": 0x80306a1c,
		"JAIBasic::checkPlayingSeqTrack": 0x80306da8,
		"checkPlayingSeqTrack": 0x80306da8,
		"JAIBasic::checkPlayingSeq": 0x80307c44,
		"checkPlayingSeq": 0x80307c44,
		"JAIBasic::checkStoppedSeq": 0x80307d4c,
		"checkStoppedSeq": 0x80307d4c,
		"JAIBasic::checkStartedSeq": 0x80307e18,
		"checkStartedSeq": 0x80307e18,
		"JAIBasic::checkFadeoutSeq": 0x80307ed0,
		"checkFadeoutSeq": 0x80307ed0,
		"JAIBasic::checkReadSeq": 0x80307fac,
		"checkReadSeq": 0x80307fac,
		"JAIBasic::checkSeqWave": 0x80308178,
		"checkSeqWave": 0x80308178,
		"JAIBasic::checkDvdLoadArc": 0x80308290,
		"checkDvdLoadArc": 0x80308290,
		"JAIBasic::checkEntriedStream": 0x8030836c,
		"checkEntriedStream": 0x8030836c,
		"JAIBasic::checkWaitStream": 0x80308438,
		"checkWaitStream": 0x80308438,
		"JAIBasic::checkRequestStream": 0x80308520,
		"checkRequestStream": 0x80308520,
		"JAIBasic::checkPlayingStream": 0x803085b8,
		"checkPlayingStream": 0x803085b8,
		"JAInter::StreamLib::Play_DirectPCM": 0x803089e8,
		"Play_DirectPCM": 0x803089e8,
		"JAInter::StreamLib::init": 0x80308b04,
		"JAInter::StreamLib::allocBuffer": 0x80308b64,
		"allocBuffer": 0x80308b64,
		"JAInter::StreamLib::getNeedBufferSize": 0x80308c8c,
		"getNeedBufferSize": 0x80308c8c,
		"JAInter::StreamLib::__DecodePCM": 0x80308d18,
		"__DecodePCM": 0x80308d18,
		"JAInter::StreamLib::__DecodeADPCM": 0x80308e78,
		"__DecodeADPCM": 0x80308e78,
		"JAInter::StreamLib::__LoadFin": 0x8030934c,
		"__LoadFin": 0x8030934c,
		"JAInter::StreamLib::LoadADPCM": 0x8030936c,
		"LoadADPCM": 0x8030936c,
		"JAInter::StreamLib::setVolume": 0x80309480,
		"JAInter::StreamLib::setPitch": 0x80309490,
		"JAInter::StreamLib::setPan": 0x803094a0,
		"JAInter::StreamLib::stop": 0x803094b0,
		"JAInter::StreamLib::setPauseFlag": 0x803094c0,
		"JAInter::StreamLib::clearPauseFlag": 0x803094d4,
		"clearPauseFlag": 0x803094d4,
		"JAInter::StreamLib::setPrepareFlag": 0x803094ec,
		"setPrepareFlag": 0x803094ec,
		"JAInter::StreamLib::setOutputMode": 0x803094f4,
		"JAInter::StreamLib::getPlayingFlag": 0x803094fc,
		"getPlayingFlag": 0x803094fc,
		"JAInter::StreamLib::start": 0x80309504,
		"JAInter::StreamLib::__start": 0x8030957c,
		"JAInter::StreamLib::callBack": 0x803098c8,
		"callBack": 0x803098c8,
		"JSystem::__sinit_JAIGFrameStream_cpp": 0x8030a19c,
		"__sinit_JAIGFrameStream_cpp": 0x8030a19c,
		"JASystem::Kernel::TSolidHeap::~TSolidHeap": 0x8030a1d8,
		"JAIGlobalParameter::setParamInitDataPointer": 0x8030a218,
		"setParamInitDataPointer": 0x8030a218,
		"JAIGlobalParameter::setParamSeqPlayTrackMax": 0x8030a230,
		"setParamSeqPlayTrackMax": 0x8030a230,
		"JAIGlobalParameter::setParamSeqControlBufferMax": 0x8030a240,
		"setParamSeqControlBufferMax": 0x8030a240,
		"JAIGlobalParameter::setParamAutoHeapMax": 0x8030a248,
		"setParamAutoHeapMax": 0x8030a248,
		"JAIGlobalParameter::setParamStayHeapMax": 0x8030a250,
		"setParamStayHeapMax": 0x8030a250,
		"JAIGlobalParameter::setParamInputGainDown": 0x8030a258,
		"setParamInputGainDown": 0x8030a258,
		"JAIGlobalParameter::setParamOutputGainUp": 0x8030a260,
		"setParamOutputGainUp": 0x8030a260,
		"JAIGlobalParameter::setParamDistanceMax": 0x8030a268,
		"setParamDistanceMax": 0x8030a268,
		"JAIGlobalParameter::setParamMaxVolumeDistance": 0x8030a270,
		"setParamMaxVolumeDistance": 0x8030a270,
		"JAIGlobalParameter::setParamMinDistanceVolume": 0x8030a278,
		"setParamMinDistanceVolume": 0x8030a278,
		"JAIGlobalParameter::setParamStreamInsideBufferCut": 0x8030a280,
		"setParamStreamInsideBufferCut": 0x8030a280,
		"JAIGlobalParameter::setParamAutoHeapRoomSize": 0x8030a294,
		"setParamAutoHeapRoomSize": 0x8030a294,
		"JAIGlobalParameter::setParamStayHeapSize": 0x8030a29c,
		"setParamStayHeapSize": 0x8030a29c,
		"JAIGlobalParameter::setParamInitDataFileName": 0x8030a2a4,
		"setParamInitDataFileName": 0x8030a2a4,
		"JAIGlobalParameter::setParamWavePath": 0x8030a2ac,
		"setParamWavePath": 0x8030a2ac,
		"JAIGlobalParameter::setParamSequenceArchivesPath": 0x8030a2b4,
		"setParamSequenceArchivesPath": 0x8030a2b4,
		"JAIGlobalParameter::setParamStreamPath": 0x8030a2bc,
		"setParamStreamPath": 0x8030a2bc,
		"JAIGlobalParameter::setParamSystemTrackMax": 0x8030a2c4,
		"setParamSystemTrackMax": 0x8030a2c4,
		"JAIGlobalParameter::setParamSystemRootTrackMax": 0x8030a2cc,
		"setParamSystemRootTrackMax": 0x8030a2cc,
		"JAIGlobalParameter::setParamSoundOutputMode": 0x8030a2d4,
		"setParamSoundOutputMode": 0x8030a2d4,
		"JAIGlobalParameter::getParamSeCategoryMax": 0x8030a360,
		"getParamSeCategoryMax": 0x8030a360,
		"JAIGlobalParameter::getParamSeqTrackMax": 0x8030a370,
		"getParamSeqTrackMax": 0x8030a370,
		"JAIGlobalParameter::getParamOutputGainUp": 0x8030a378,
		"getParamOutputGainUp": 0x8030a378,
		"JAIGlobalParameter::getParamMaxVolumeDistance": 0x8030a380,
		"getParamMaxVolumeDistance": 0x8030a380,
		"JAISound::JAISound": 0x8030a388,
		"JAISound::initMoveParameter": 0x8030a3b0,
		"initMoveParameter": 0x8030a3b0,
		"JAISound::getSeCategoryNumber": 0x8030a460,
		"getSeCategoryNumber": 0x8030a460,
		"JAISound::getSwBit": 0x8030a48c,
		"getSwBit": 0x8030a48c,
		"JAISound::checkSwBit": 0x8030a4b8,
		"checkSwBit": 0x8030a4b8,
		"JAISound::getInfoPriority": 0x8030a4f4,
		"getInfoPriority": 0x8030a4f4,
		"JAISound::clearMainSoundPPointer": 0x8030a520,
		"clearMainSoundPPointer": 0x8030a520,
		"JAISound::release": 0x8030a538,
		"JAISound::stop": 0x8030a54c,
		"JAISound::setVolume": 0x8030a57c,
		"JAISound::setPan": 0x8030a604,
		"JAISound::setPitch": 0x8030a68c,
		"JAISound::setFxmix": 0x8030a714,
		"setFxmix": 0x8030a714,
		"JAISound::setDolby": 0x8030a78c,
		"JAISound::setTempoProportion": 0x8030a804,
		"setTempoProportion": 0x8030a804,
		"JAISound::setPortData": 0x8030a85c,
		"setPortData": 0x8030a85c,
		"JAISound::setDistanceVolumeCommon": 0x8030a8c0,
		"JAISound::setDistancePanCommon": 0x8030aa14,
		"setDistancePanCommon": 0x8030aa14,
		"JAISound::setPositionDopplarCommon": 0x8030ab68,
		"setPositionDopplarCommon": 0x8030ab68,
		"JAISound::setSeqInterVolume": 0x8030ad44,
		"setSeqInterVolume": 0x8030ad44,
		"JAISound::setSeqInterPan": 0x8030ae44,
		"setSeqInterPan": 0x8030ae44,
		"JAISound::setSeqInterPitch": 0x8030af44,
		"setSeqInterPitch": 0x8030af44,
		"JAISound::setSeqInterFxmix": 0x8030b044,
		"setSeqInterFxmix": 0x8030b044,
		"JAISound::setSeqInterDolby": 0x8030b144,
		"setSeqInterDolby": 0x8030b144,
		"JAISound::setSeqTempoProportion": 0x8030b280,
		"setSeqTempoProportion": 0x8030b280,
		"JAISound::setSeqPortData": 0x8030b330,
		"setSeqPortData": 0x8030b330,
		"JAISound::setWaveReadMode": 0x8030b49c,
		"setWaveReadMode": 0x8030b49c,
		"JAISound::setTrackInterruptSwitch": 0x8030b53c,
		"setTrackInterruptSwitch": 0x8030b53c,
		"JAISound::setTrackPortData": 0x8030b5e0,
		"setTrackPortData": 0x8030b5e0,
		"JAISound::setSeInterVolume": 0x8030b700,
		"setSeInterVolume": 0x8030b700,
		"JAISound::setSeInterPan": 0x8030b8c8,
		"setSeInterPan": 0x8030b8c8,
		"JAISound::setSeInterFxmix": 0x8030ba90,
		"setSeInterFxmix": 0x8030ba90,
		"JAISound::setSeInterDolby": 0x8030bc58,
		"setSeInterDolby": 0x8030bc58,
		"JAISound::setSeInterPitch": 0x8030be20,
		"setSeInterPitch": 0x8030be20,
		"JAISound::setSePortData": 0x8030bfdc,
		"setSePortData": 0x8030bfdc,
		"JAISound::setSeDistanceParameters": 0x8030c15c,
		"JAISound::setSeDistanceVolume": 0x8030c2d0,
		"JAISound::setSeDistancePan": 0x8030c3d0,
		"JAISound::setSeDistancePitch": 0x8030c498,
		"JAISound::setSePositionDopplar": 0x8030c690,
		"setSePositionDopplar": 0x8030c690,
		"JAISound::setSeDistanceFxmix": 0x8030c78c,
		"setSeDistanceFxmix": 0x8030c78c,
		"JAISound::setSeDistanceFir": 0x8030c880,
		"setSeDistanceFir": 0x8030c880,
		"JAISound::setSeDistanceDolby": 0x8030c884,
		"JAISound::setStreamInterVolume": 0x8030c950,
		"setStreamInterVolume": 0x8030c950,
		"JAISound::setStreamInterPitch": 0x8030ca50,
		"setStreamInterPitch": 0x8030ca50,
		"JAISound::setStreamInterPan": 0x8030cb50,
		"setStreamInterPan": 0x8030cb50,
		"JAISound::setPauseMode": 0x8030cc50,
		"setPauseMode": 0x8030cc50,
		"JAISound::getSeqInterVolume": 0x8030d000,
		"getSeqInterVolume": 0x8030d000,
		"JAISound::getStreamInterVolume": 0x8030d054,
		"getStreamInterVolume": 0x8030d054,
		"JAISound::getSeqParameter": 0x8030d0e4,
		"getSeqParameter": 0x8030d0e4,
		"JAISound::getSeParameter": 0x8030d0ec,
		"getSeParameter": 0x8030d0ec,
		"JAISound::getStreamParameter": 0x8030d0f4,
		"JAISound::getTrackPortRoute": 0x8030d0fc,
		"getTrackPortRoute": 0x8030d0fc,
		"JAISystemInterface::checkFileExsistence": 0x8030d138,
		"checkFileExsistence": 0x8030d138,
		"JAISystemInterface::checkSeqActiveFlag": 0x8030d17c,
		"checkSeqActiveFlag": 0x8030d17c,
		"JAISystemInterface::trackToSeqp": 0x8030d284,
		"trackToSeqp": 0x8030d284,
		"JAISystemInterface::setSeqPortargsF32": 0x8030d314,
		"setSeqPortargsF32": 0x8030d314,
		"JAISystemInterface::setSeqPortargsU32": 0x8030d330,
		"setSeqPortargsU32": 0x8030d330,
		"JAISystemInterface::rootInit": 0x8030d34c,
		"rootInit": 0x8030d34c,
		"JAISystemInterface::trackInit": 0x8030d3c4,
		"trackInit": 0x8030d3c4,
		"JAISystemInterface::outerInit": 0x8030d4b4,
		"outerInit": 0x8030d4b4,
		"JAISystemInterface::setSePortParameter": 0x8030d6a4,
		"setSePortParameter": 0x8030d6a4,
		"JAISystemInterface::setSeqData": 0x8030d7f8,
		"JAISystemInterface::startSeq": 0x8030d878,
		"JAISystemInterface::stopSeq": 0x8030d8d0,
		"JAISystemInterface::writePortApp": 0x8030d918,
		"JAISystemInterface::readPortApp": 0x8030d970,
		"JSystem::__sinit_JAISystemInterface_cpp": 0x8030d9c8,
		"__sinit_JAISystemInterface_cpp": 0x8030d9c8,
		"JASystem::Kernel::TPortCmd::~TPortCmd": 0x8030da04,
		"JASystem::TBank::getCurrentHeap": 0x8030da44,
		"JASystem::BankMgr::init": 0x8030da58,
		"JASystem::BankMgr::registBankBNK": 0x8030db74,
		"registBankBNK": 0x8030db74,
		"JASystem::BankMgr::getPhysicalNumber": 0x8030dbdc,
		"getPhysicalNumber": 0x8030dbdc,
		"JASystem::BankMgr::setVir2PhyTable": 0x8030dbec,
		"setVir2PhyTable": 0x8030dbec,
		"JASystem::BankMgr::assignWaveBank": 0x8030dc08,
		"assignWaveBank": 0x8030dc08,
		"JASystem::BankMgr::noteOn": 0x8030dc7c,
		"JASystem::BankMgr::noteOnOsc": 0x8030e08c,
		"noteOnOsc": 0x8030e08c,
		"JASystem::BankMgr::gateOn": 0x8030e1e4,
		"JASystem::TBasicBank::TBasicBank": 0x8030e2ac,
		"JASystem::TBank::~TBank": 0x8030e2d8,
		"JASystem::TBasicBank::~TBasicBank": 0x8030e324,
		"JASystem::TBasicBank::setInstCount": 0x8030e398,
		"setInstCount": 0x8030e398,
		"JASystem::TBasicBank::setInst": 0x8030e3fc,
		"setInst": 0x8030e3fc,
		"JASystem::TBasicBank::getInst": 0x8030e40c,
		"getInst": 0x8030e40c,
		"JASystem::TBasicBank::getType": 0x8030e430,
		"JASystem::TBasicInst::TBasicInst": 0x8030e43c,
		"JASystem::TInst::~TInst": 0x8030e480,
		"JASystem::TBasicInst::~TBasicInst": 0x8030e4cc,
		"JASystem::TBasicInst::getParam": 0x8030e558,
		"JASystem::TBasicInst::getKeymapIndex": 0x8030e734,
		"getKeymapIndex": 0x8030e734,
		"JASystem::TBasicInst::setKeyRegionCount": 0x8030e73c,
		"setKeyRegionCount": 0x8030e73c,
		"JASystem::TBasicInst::TKeymap::TKeymap": 0x8030e7c4,
		"JASystem::TBasicInst::setEffectCount": 0x8030e7dc,
		"JASystem::TBasicInst::setEffect": 0x8030e854,
		"JASystem::TBasicInst::setOscCount": 0x8030e864,
		"setOscCount": 0x8030e864,
		"JASystem::TBasicInst::setOsc": 0x8030e8dc,
		"setOsc": 0x8030e8dc,
		"JASystem::TBasicInst::getKeyRegion": 0x8030e8ec,
		"getKeyRegion": 0x8030e8ec,
		"JASystem::TBasicInst::TKeymap::~TKeymap": 0x8030e910,
		"JASystem::TBasicInst::TKeymap::setVeloRegionCount": 0x8030e964,
		"JASystem::TBasicInst::getType": 0x8030ea04,
		"JASystem::TBasicWaveBank::TBasicWaveBank": 0x8030ea10,
		"JASystem::TWaveBank::~TWaveBank": 0x8030ea40,
		"JASystem::TBasicWaveBank::~TBasicWaveBank": 0x8030ea8c,
		"JASystem::TBasicWaveBank::getWaveGroup": 0x8030eb10,
		"getWaveGroup": 0x8030eb10,
		"JASystem::TBasicWaveBank::setGroupCount": 0x8030eb34,
		"setGroupCount": 0x8030eb34,
		"JASystem::TBasicWaveBank::setWaveTableSize": 0x8030ebbc,
		"JASystem::TBasicWaveBank::incWaveTable": 0x8030ec20,
		"incWaveTable": 0x8030ec20,
		"JASystem::TBasicWaveBank::decWaveTable": 0x8030ec80,
		"decWaveTable": 0x8030ec80,
		"JASystem::TBasicWaveBank::getWaveHandle": 0x8030ed10,
		"JASystem::TBasicWaveBank::TWaveGroup::TWaveGroup": 0x8030ed44,
		"JASystem::Kernel::THeap::~THeap": 0x8030eda4,
		"JASystem::TBasicWaveBank::TWaveGroup::~TWaveGroup": 0x8030ede4,
		"JASystem::TBasicWaveBank::TWaveInfo::~TWaveInfo": 0x8030ee54,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveArcFileName": 0x8030eeb4,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveCount": 0x8030ef28,
		"setWaveCount": 0x8030ef28,
		"JASystem::TBasicWaveBank::TWaveInfo::TWaveInfo": 0x8030f0c8,
		"JASystem::TBasicWaveBank::TWaveHandle::~TWaveHandle": 0x8030f0f8,
		"JASystem::TWaveHandle::~TWaveHandle": 0x8030f154,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveInfo": 0x8030f1a0,
		"JASystem::TBasicWaveBank::TWaveHandle::getWaveInfo": 0x8030f224,
		"JASystem::TBasicWaveBank::TWaveHandle::getWavePtr": 0x8030f22c,
		"JASystem::TBasicWaveBank::TWaveGroup::getWaveArcFileName": 0x8030f250,
		"JASystem::TBasicWaveBank::TWaveGroup::getHeap": 0x8030f258,
		"JASystem::TBasicWaveBank::getType": 0x8030f260,
		"JASystem::BNKParser::createBasicBank": 0x8030f26c,
		"createBasicBank": 0x8030f26c,
		"JASystem::TDrumSet::TDrumSet": 0x8030f99c,
		"JASystem::BNKParser::findOscPtr": 0x8030fa04,
		"findOscPtr": 0x8030fa04,
		"JASystem::BNKParser::getOscTableEndPtr": 0x8030fb60,
		"getOscTableEndPtr": 0x8030fb60,
		"JASystem::TDrumSet::getParam": 0x8030fc4c,
		"JASystem::TDrumSet::getPerc": 0x8030fe3c,
		"getPerc": 0x8030fe3c,
		"JASystem::TDrumSet::TPerc::TPerc": 0x8030fe50,
		"JASystem::TDrumSet::TPerc::~TPerc": 0x8030fe84,
		"JASystem::TDrumSet::TPerc::setEffectCount": 0x8030fee0,
		"JASystem::TDrumSet::TPerc::setVeloRegionCount": 0x8030ff58,
		"JASystem::TDrumSet::TPerc::getVeloRegion": 0x8030ffb0,
		"JASystem::TDrumSet::TPerc::setEffect": 0x8030ffc0,
		"JASystem::TDrumSet::TPerc::setRelease": 0x8030ffd0,
		"setRelease": 0x8030ffd0,
		"JASystem::TDrumSet::~TDrumSet": 0x8030ffd8,
		"JASystem::TDrumSet::getType": 0x8031005c,
		"JASystem::TInstEffect::setTarget": 0x80310068,
		"setTarget": 0x80310068,
		"JASystem::TInstRand::getY": 0x80310070,
		"JASystem::TInstSense::getY": 0x80310110,
		"JASystem::TInstSense::setParams": 0x80310234,
		"setParams": 0x80310234,
		"JASystem::TSimpleWaveBank::TSimpleWaveBank": 0x80310248,
		"JASystem::TSimpleWaveBank::~TSimpleWaveBank": 0x803102c8,
		"JASystem::TSimpleWaveBank::TWaveHandle::~TWaveHandle": 0x80310354,
		"JASystem::TSimpleWaveBank::setWaveTableSize": 0x803103b0,
		"JASystem::TSimpleWaveBank::TWaveHandle::TWaveHandle": 0x80310438,
		"JASystem::TSimpleWaveBank::getWaveHandle": 0x8031045c,
		"JASystem::TSimpleWaveBank::setWaveInfo": 0x80310480,
		"JASystem::TSimpleWaveBank::setWaveArcFileName": 0x80310508,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWaveInfo": 0x8031057c,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWavePtr": 0x80310584,
		"JASystem::TSimpleWaveBank::getType": 0x803105a8,
		"JASystem::WaveArcLoader::init": 0x803105dc,
		"JASystem::WaveArcLoader::setCurrentDir": 0x80310628,
		"setCurrentDir": 0x80310628,
		"JASystem::WaveArcLoader::getCurrentDir": 0x80310688,
		"getCurrentDir": 0x80310688,
		"JASystem::WaveArcLoader::loadWave": 0x80310694,
		"JASystem::WaveArcLoader::eraseWave": 0x803107c4,
		"JASystem::WaveArcLoader::getRootHeap": 0x80310850,
		"getRootHeap": 0x80310850,
		"JSystem::__sinit_JASWaveArcLoader_cpp": 0x8031085c,
		"__sinit_JASWaveArcLoader_cpp": 0x8031085c,
		"JASystem::TWaveBank::getCurrentHeap": 0x80310898,
		"JASystem::WaveBankMgr::init": 0x803108ac,
		"JASystem::WaveBankMgr::getWaveBank": 0x80310904,
		"getWaveBank": 0x80310904,
		"JASystem::WaveBankMgr::registWaveBankWS": 0x80310914,
		"registWaveBankWS": 0x80310914,
		"JASystem::WaveBankMgr::loadWave": 0x80310994,
		"JASystem::WaveBankMgr::eraseWave": 0x80310a84,
		"JASystem::WSParser::getGroupCount": 0x80310b74,
		"getGroupCount": 0x80310b74,
		"JASystem::WSParser::createBasicWaveBank": 0x80310b9c,
		"createBasicWaveBank": 0x80310b9c,
		"JASystem::WSParser::createSimpleWaveBank": 0x80310dc8,
		"createSimpleWaveBank": 0x80310dc8,
		"JSystem::Console_printf": 0x80311090,
		"Console_printf": 0x80311090,
		"JASystem::AudioThread::setDSPSyncCount": 0x803110e0,
		"setDSPSyncCount": 0x803110e0,
		"JASystem::AudioThread::getDSPSyncCount": 0x803110e8,
		"getDSPSyncCount": 0x803110e8,
		"JASystem::AudioThread::syncAudio": 0x803110f0,
		"syncAudio": 0x803110f0,
		"JASystem::AudioThread::audioproc": 0x80311170,
		"audioproc": 0x80311170,
		"JASystem::AudioThread::syncDSP": 0x803112d0,
		"syncDSP": 0x803112d0,
		"JASystem::AudioThread::stop": 0x80311358,
		"JASystem::AudioThread::setPriority": 0x803113a8,
		"setPriority": 0x803113a8,
		"JASystem::AudioThread::start": 0x803113c4,
		"JASystem::Driver::DSPQueue::init": 0x803114e0,
		"JASystem::Driver::DSPQueue::enQueue": 0x80311550,
		"enQueue": 0x80311550,
		"JASystem::Driver::DSPQueue::deQueue": 0x80311600,
		"deQueue": 0x80311600,
		"JASystem::Driver::DSPQueue::deleteQueue": 0x80311708,
		"deleteQueue": 0x80311708,
		"JASystem::Driver::DSPQueue::checkQueue": 0x80311768,
		"checkQueue": 0x80311768,
		"JASystem::Driver::calcEffect": 0x80311844,
		"calcEffect": 0x80311844,
		"JASystem::Driver::calcPan": 0x80311904,
		"JASystem::Driver::__UpdateJcToDSP": 0x80311a00,
		"__UpdateJcToDSP": 0x80311a00,
		"JASystem::Driver::__UpdateJcToDSPInit": 0x80311b48,
		"__UpdateJcToDSPInit": 0x80311b48,
		"JASystem::Driver::extraUpdate": 0x80311c50,
		"extraUpdate": 0x80311c50,
		"JASystem::Driver::updatecallLogicalChannel": 0x80311d34,
		"updatecallLogicalChannel": 0x80311d34,
		"JASystem::Driver::killBrokenLogicalChannels": 0x80311ed0,
		"killBrokenLogicalChannels": 0x80311ed0,
		"JASystem::Driver::updateMixer": 0x80311f78,
		"updateMixer": 0x80311f78,
		"JASystem::Driver::updatecallDSPChannel": 0x803121ac,
		"updatecallDSPChannel": 0x803121ac,
		"JASystem::TChannel::init": 0x80312550,
		"JASystem::TChannel::setOscillator": 0x803126f8,
		"setOscillator": 0x803126f8,
		"JASystem::TChannel::setOscInit": 0x80312708,
		"setOscInit": 0x80312708,
		"JASystem::TChannel::forceStopOsc": 0x8031273c,
		"forceStopOsc": 0x8031273c,
		"JASystem::TChannel::releaseOsc": 0x80312790,
		"releaseOsc": 0x80312790,
		"JASystem::TChannel::directReleaseOsc": 0x803127e4,
		"directReleaseOsc": 0x803127e4,
		"JASystem::TChannel::bankOscToOfs": 0x803127f8,
		"bankOscToOfs": 0x803127f8,
		"JASystem::TChannel::effectOsc": 0x8031284c,
		"effectOsc": 0x8031284c,
		"JASystem::TChannel::getOscState": 0x803128c4,
		"getOscState": 0x803128c4,
		"JASystem::TChannel::isOsc": 0x803128d8,
		"isOsc": 0x803128d8,
		"JASystem::TChannel::copyOsc": 0x80312900,
		"copyOsc": 0x80312900,
		"JASystem::TChannel::overwriteOsc": 0x80312960,
		"overwriteOsc": 0x80312960,
		"JASystem::TChannel::setKeySweepTarget": 0x80312a44,
		"setKeySweepTarget": 0x80312a44,
		"JASystem::TChannel::setPauseFlag": 0x80312adc,
		"JASystem::TChannel::setPauseFlagReq": 0x80312ae4,
		"setPauseFlagReq": 0x80312ae4,
		"JASystem::TChannel::setPanPower": 0x80312af4,
		"setPanPower": 0x80312af4,
		"JASystem::TChannel::resetInitialVolume": 0x80312b28,
		"resetInitialVolume": 0x80312b28,
		"JASystem::TChannel::play": 0x80312bb8,
		"JASystem::TChannel::stop": 0x80312cdc,
		"JASystem::TChannel::updateJcToDSP": 0x80312d34,
		"updateJcToDSP": 0x80312d34,
		"JASystem::TChannel::forceStopLogicalChannel": 0x80312d6c,
		"forceStopLogicalChannel": 0x80312d6c,
		"JASystem::TChannel::stopLogicalChannel": 0x80312da4,
		"stopLogicalChannel": 0x80312da4,
		"JASystem::TChannel::playLogicalChannel": 0x80312e14,
		"playLogicalChannel": 0x80312e14,
		"JASystem::TChannel::updateEffectorParam": 0x803130ac,
		"updateEffectorParam": 0x803130ac,
		"JASystem::TChannelMgr::init": 0x80313378,
		"JASystem::TChannelMgr::stopAll": 0x8031346c,
		"stopAll": 0x8031346c,
		"JASystem::TChannelMgr::stopAllRelease": 0x803134b0,
		"stopAllRelease": 0x803134b0,
		"JASystem::TChannelMgr::addListHead": 0x8031350c,
		"addListHead": 0x8031350c,
		"JASystem::TChannelMgr::addListTail": 0x8031356c,
		"addListTail": 0x8031356c,
		"JASystem::TChannelMgr::getListHead": 0x80313600,
		"getListHead": 0x80313600,
		"JASystem::TChannelMgr::cutList": 0x80313678,
		"cutList": 0x80313678,
		"JASystem::TChannelMgr::initAllocChannel": 0x803136f4,
		"initAllocChannel": 0x803136f4,
		"JASystem::TChannelMgr::getLogicalChannel": 0x80313768,
		"getLogicalChannel": 0x80313768,
		"JASystem::TChannelMgr::receiveAllChannels": 0x803138ac,
		"receiveAllChannels": 0x803138ac,
		"JASystem::TChannelMgr::checkLimitStart": 0x80313a04,
		"checkLimitStart": 0x80313a04,
		"JASystem::TChannelMgr::checkLimitStop": 0x80313b88,
		"checkLimitStop": 0x80313b88,
		"JASystem::ChGlobal::getChannelHandle": 0x80313c54,
		"getChannelHandle": 0x80313c54,
		"JASystem::ChGlobal::init": 0x80313c74,
		"JASystem::TOscillator::~TOscillator": 0x80313d9c,
		"JASystem::TOscillator::TOscillator": 0x80313ddc,
		"JASystem::TChannel::~TChannel": 0x80313e0c,
		"JASystem::TChannel::TChannel": 0x80313e4c,
		"JASystem::ChGlobal::alloc": 0x80313e74,
		"JASystem::ChGlobal::release": 0x80313f1c,
		"JASystem::ChGlobal::releaseAll": 0x80313f80,
		"releaseAll": 0x80313f80,
		"JASystem::Driver::init": 0x803140cc,
		"JASystem::Driver::setMixerLevel": 0x80314104,
		"setMixerLevel": 0x80314104,
		"JASystem::Driver::getMixerLevel": 0x80314140,
		"getMixerLevel": 0x80314140,
		"JASystem::Driver::setOutputMode": 0x80314148,
		"JASystem::Driver::getOutputMode": 0x80314150,
		"getOutputMode": 0x80314150,
		"JASystem::Driver::getUpdateInterval": 0x80314158,
		"getUpdateInterval": 0x80314158,
		"JASystem::DSPBuf::updateDSP": 0x80314160,
		"updateDSP": 0x80314160,
		"JASystem::DSPBuf::mixDSP": 0x803141b4,
		"mixDSP": 0x803141b4,
		"JASystem::DSPBuf::finishDSPFrame": 0x803141d8,
		"finishDSPFrame": 0x803141d8,
		"JASystem::DSPBuf::process": 0x803141fc,
		"process": 0x803141fc,
		"JASystem::TDSPChannel::forceStop": 0x80314660,
		"JASystem::TDSPChannel::forceDelete": 0x803146f0,
		"forceDelete": 0x803146f0,
		"JASystem::TDSPChannel::play": 0x80314704,
		"JASystem::TDSPChannel::stop": 0x8031473c,
		"JASystem::TDSPChannel::initAll": 0x8031476c,
		"initAll": 0x8031476c,
		"JASystem::TDSPChannel::~TDSPChannel": 0x8031485c,
		"JASystem::TDSPChannel::TDSPChannel": 0x8031489c,
		"JASystem::TDSPChannel::alloc": 0x803148ac,
		"JASystem::TDSPChannel::free": 0x803149ac,
		"JASystem::TDSPChannel::getLower": 0x80314a34,
		"getLower": 0x80314a34,
		"JASystem::TDSPChannel::getLowerActive": 0x80314ae8,
		"getLowerActive": 0x80314ae8,
		"JASystem::TDSPChannel::breakLower": 0x80314b74,
		"breakLower": 0x80314b74,
		"JASystem::TDSPChannel::updateAll": 0x80314c60,
		"updateAll": 0x80314c60,
		"JSystem::DSP_CreateMap": 0x80314e88,
		"DSP_CreateMap": 0x80314e88,
		"JASystem::DSPInterface::getDSPHandle": 0x80314f14,
		"getDSPHandle": 0x80314f14,
		"JASystem::DSPInterface::invalChannelAll": 0x80314f28,
		"invalChannelAll": 0x80314f28,
		"JASystem::DSPInterface::initBuffer": 0x80314f50,
		"initBuffer": 0x80314f50,
		"JASystem::DSPInterface::getFXHandle": 0x8031505c,
		"getFXHandle": 0x8031505c,
		"JASystem::DSPInterface::FXBuffer::setFXLine": 0x8031506c,
		"setFXLine": 0x8031506c,
		"JASystem::DSPInterface::DSPBuffer::allocInit": 0x803151c0,
		"allocInit": 0x803151c0,
		"JASystem::DSPInterface::DSPBuffer::playStart": 0x8031520c,
		"playStart": 0x8031520c,
		"JASystem::DSPInterface::DSPBuffer::setWaveInfo": 0x803152c8,
		"JASystem::DSPInterface::DSPBuffer::setOscInfo": 0x80315394,
		"setOscInfo": 0x80315394,
		"JASystem::DSPInterface::DSPBuffer::initAutoMixer": 0x803153ac,
		"initAutoMixer": 0x803153ac,
		"JASystem::DSPInterface::DSPBuffer::setAutoMixer": 0x803153d8,
		"setAutoMixer": 0x803153d8,
		"JASystem::DSPInterface::DSPBuffer::setPitch": 0x803153fc,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitDelayMax": 0x80315414,
		"setMixerInitDelayMax": 0x80315414,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitVolume": 0x80315420,
		"setMixerInitVolume": 0x80315420,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolume": 0x80315444,
		"setMixerVolume": 0x80315444,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolumeOnly": 0x80315474,
		"setMixerVolumeOnly": 0x80315474,
		"JASystem::DSPInterface::DSPBuffer::setPauseFlag": 0x80315490,
		"JASystem::DSPInterface::DSPBuffer::flushChannel": 0x8031549c,
		"flushChannel": 0x8031549c,
		"JASystem::DSPInterface::DSPBuffer::setIIRFilterParam": 0x803154c0,
		"setIIRFilterParam": 0x803154c0,
		"JASystem::DSPInterface::DSPBuffer::setFIR8FilterParam": 0x803154e4,
		"setFIR8FilterParam": 0x803154e4,
		"JASystem::DSPInterface::DSPBuffer::setFilterMode": 0x80315528,
		"setFilterMode": 0x80315528,
		"JASystem::DSPInterface::DSPBuffer::initFilter": 0x80315568,
		"initFilter": 0x80315568,
		"JASystem::DSPInterface::DSPBuffer::setDistFilter": 0x803155b0,
		"setDistFilter": 0x803155b0,
		"JASystem::DSPInterface::DSPBuffer::setBusConnect": 0x803155b8,
		"setBusConnect": 0x803155b8,
		"JASystem::TOscillator::init": 0x803155dc,
		"JASystem::TOscillator::initStart": 0x80315614,
		"initStart": 0x80315614,
		"JASystem::TOscillator::getOffset": 0x80315674,
		"getOffset": 0x80315674,
		"JASystem::TOscillator::getOffsetNoCount": 0x80315780,
		"getOffsetNoCount": 0x80315780,
		"JASystem::TOscillator::forceStop": 0x803157dc,
		"JASystem::TOscillator::release": 0x80315818,
		"JASystem::TOscillator::calc": 0x803159a0,
		"JASystem::Kernel::init": 0x80315d40,
		"JASystem::Kernel::initSystem": 0x80315d70,
		"initSystem": 0x80315d70,
		"JASystem::Kernel::registerMixCallback": 0x80315e24,
		"registerMixCallback": 0x80315e24,
		"JASystem::Kernel::vframeWork": 0x80315e30,
		"vframeWork": 0x80315e30,
		"JASystem::Kernel::updateDac": 0x80315fc0,
		"updateDac": 0x80315fc0,
		"JASystem::Kernel::mixMonoTrack": 0x80316068,
		"mixMonoTrack": 0x80316068,
		"JASystem::Kernel::mixMonoTrackWide": 0x80316164,
		"mixMonoTrackWide": 0x80316164,
		"JASystem::Kernel::mixExtraTrack": 0x80316260,
		"mixExtraTrack": 0x80316260,
		"JASystem::Kernel::mixInterleaveTrack": 0x80316378,
		"mixInterleaveTrack": 0x80316378,
		"JASystem::Calc::initSinfT": 0x80316414,
		"initSinfT": 0x80316414,
		"JASystem::Calc::sinfT": 0x8031653c,
		"sinfT": 0x8031653c,
		"JASystem::Calc::sinfDolby2": 0x80316568,
		"sinfDolby2": 0x80316568,
		"JASystem::Calc::imixcopy": 0x80316594,
		"imixcopy": 0x80316594,
		"JASystem::Calc::bcopy": 0x80316668,
		"bcopy": 0x80316668,
		"JASystem::Calc::bzero": 0x80316948,
		"bzero": 0x80316948,
		"JASystem::Kernel::resetCallback": 0x80316bac,
		"resetCallback": 0x80316bac,
		"JASystem::Kernel::registerSubframeCallback": 0x80316c20,
		"registerSubframeCallback": 0x80316c20,
		"JASystem::Kernel::registerAiCallback": 0x80316c78,
		"registerAiCallback": 0x80316c78,
		"JASystem::Kernel::aiCallback": 0x80316d60,
		"aiCallback": 0x80316d60,
		"JASystem::Kernel::subframeCallback": 0x80316e00,
		"subframeCallback": 0x80316e00,
		"JASystem::Kernel::TPortCmd::TPortCmd": 0x80316ea0,
		"JASystem::Kernel::TPortCmd::addPortCmdOnce": 0x80316eb8,
		"addPortCmdOnce": 0x80316eb8,
		"JASystem::Kernel::TPortCmd::setPortCmd": 0x80316edc,
		"setPortCmd": 0x80316edc,
		"JASystem::Kernel::TPortCmd::addPortCmd": 0x80316ef4,
		"addPortCmd": 0x80316ef4,
		"JASystem::Kernel::portCmdInit": 0x80316f74,
		"portCmdInit": 0x80316f74,
		"JASystem::Kernel::getPortCmd": 0x80316fbc,
		"getPortCmd": 0x80316fbc,
		"JASystem::Kernel::portCmdMain": 0x80316ffc,
		"portCmdMain": 0x80316ffc,
		"JASystem::Dvd::init": 0x8031706c,
		"JASystem::Dvd::extendPath": 0x803170b8,
		"extendPath": 0x803170b8,
		"JASystem::Dvd::dvdProcInit": 0x80317140,
		"dvdProcInit": 0x80317140,
		"JASystem::Dvd::dvdProc": 0x803171ec,
		"dvdProc": 0x803171ec,
		"JASystem::Dvd::loadToDramDvdTMain": 0x80317278,
		"loadToDramDvdTMain": 0x80317278,
		"JASystem::Dvd::loadToDramDvdT": 0x803173a0,
		"loadToDramDvdT": 0x803173a0,
		"JASystem::Dvd::loadToAramDvdTMain": 0x80317454,
		"loadToAramDvdTMain": 0x80317454,
		"JASystem::Dvd::loadToAramDvdT": 0x803176bc,
		"loadToAramDvdT": 0x803176bc,
		"JASystem::Dvd::checkFileExtend": 0x80317770,
		"checkFileExtend": 0x80317770,
		"JASystem::Dvd::loadFileDvdT": 0x80317824,
		"loadFileDvdT": 0x80317824,
		"JASystem::Dvd::checkPassDvdT": 0x8031790c,
		"checkPassDvdT": 0x8031790c,
		"JASystem::Dvd::checkFile": 0x80317990,
		"checkFile": 0x80317990,
		"JASystem::Dvd::loadFile": 0x803179ec,
		"JASystem::Dvd::pauseDvdT": 0x80317aa0,
		"pauseDvdT": 0x80317aa0,
		"JASystem::Dvd::unpauseDvdT": 0x80317aac,
		"unpauseDvdT": 0x80317aac,
		"JASystem::Dvd::registerFastOpen": 0x80317ae4,
		"registerFastOpen": 0x80317ae4,
		"JASystem::Dvd::openDvd": 0x80317bd4,
		"openDvd": 0x80317bd4,
		"JASystem::Dvd::getCallStack": 0x80317c2c,
		"getCallStack": 0x80317c2c,
		"JASystem::Dvd::dvdReadMutex": 0x80317c88,
		"dvdReadMutex": 0x80317c88,
		"JASystem::Dvd::doError": 0x80317d14,
		"doError": 0x80317d14,
		"JASystem::Dvd::doFinish": 0x80317d5c,
		"doFinish": 0x80317d5c,
		"JASystem::Dvd::dvdThreadCheckBack": 0x80317da0,
		"dvdThreadCheckBack": 0x80317da0,
		"JASystem::Dvd::allocDvdBuffer": 0x80317dec,
		"allocDvdBuffer": 0x80317dec,
		"JASystem::Dvd::writeBufferSize": 0x80317ec4,
		"writeBufferSize": 0x80317ec4,
		"JASystem::Dvd::updateBuffer": 0x80317f7c,
		"updateBuffer": 0x80317f7c,
		"JASystem::Dvd::aramDmaFinish": 0x80318050,
		"aramDmaFinish": 0x80318050,
		"JASystem::HardStream::main": 0x80318060,
		"JASystem::HardStream::firstBgmCallback": 0x803184e4,
		"firstBgmCallback": 0x803184e4,
		"JASystem::HardStream::secondBgmCallback": 0x80318570,
		"secondBgmCallback": 0x80318570,
		"JASystem::HardStream::getAddrCallback": 0x80318584,
		"getAddrCallback": 0x80318584,
		"JASystem::HardStream::TControl::TControl": 0x80318704,
		"JASystem::HardStream::TControl::getIntroNum": 0x80318764,
		"getIntroNum": 0x80318764,
		"JASystem::HardStream::TControl::getLoopNum": 0x8031879c,
		"getLoopNum": 0x8031879c,
		"JASystem::HardStream::TControl::clearListOne": 0x803187d4,
		"clearListOne": 0x803187d4,
		"JASystem::HardStream::TControl::getLastAddr": 0x80318808,
		"getLastAddr": 0x80318808,
		"JASystem::HardStream::TControl::startFirst": 0x8031881c,
		"startFirst": 0x8031881c,
		"JASystem::HardStream::TControl::startSecond": 0x8031893c,
		"startSecond": 0x8031893c,
		"JASystem::HardStream::TControl::resetFader": 0x80318a5c,
		"resetFader": 0x80318a5c,
		"JASystem::HardStream::TControl::getCurVol": 0x80318a98,
		"getCurVol": 0x80318a98,
		"JASystem::HardStream::TControl::calcCurVolume": 0x80318ad0,
		"calcCurVolume": 0x80318ad0,
		"JASystem::HardStream::TControl::volFloatToU8": 0x80318d54,
		"volFloatToU8": 0x80318d54,
		"JSystem::__sinit_JASHardStream_cpp": 0x80318d94,
		"__sinit_JASHardStream_cpp": 0x80318d94,
		"JASystem::HardStream::TControl::~TControl": 0x80318dd0,
		"JASystem::Kernel::THeap::THeap": 0x80318e10,
		"JASystem::Kernel::THeap::selfAlloc": 0x80318e5c,
		"selfAlloc": 0x80318e5c,
		"JASystem::Kernel::THeap::initMotherHeap": 0x80318f5c,
		"initMotherHeap": 0x80318f5c,
		"JASystem::Kernel::THeap::allocHeapCheck": 0x80318fb8,
		"allocHeapCheck": 0x80318fb8,
		"JASystem::Kernel::THeap::alloc": 0x8031916c,
		"JASystem::Kernel::THeap::free": 0x803191ac,
		"JASystem::Kernel::TSolidHeap::TSolidHeap": 0x8031934c,
		"JASystem::Kernel::TSolidHeap::alloc": 0x80319368,
		"JASystem::Kernel::TSolidHeap::init": 0x803193c4,
		"JASystem::Kernel::TSolidHeap::getRemain": 0x8031940c,
		"getRemain": 0x8031940c,
		"JASystem::Kernel::stackInit": 0x80319424,
		"stackInit": 0x80319424,
		"JASystem::Kernel::probeStart": 0x803194f4,
		"probeStart": 0x803194f4,
		"JASystem::Kernel::probeFinish": 0x803194f8,
		"probeFinish": 0x803194f8,
		"JASystem::Kernel::sysDramSetup": 0x803194fc,
		"sysDramSetup": 0x803194fc,
		"JASystem::Kernel::allocFromSysDram": 0x80319554,
		"allocFromSysDram": 0x80319554,
		"JASystem::Kernel::sysAramSetup": 0x803195ac,
		"sysAramSetup": 0x803195ac,
		"JASystem::Kernel::allocFromSysAramFull": 0x80319614,
		"allocFromSysAramFull": 0x80319614,
		"JSystem::__sinit_JASSystemHeap_cpp": 0x80319674,
		"__sinit_JASSystemHeap_cpp": 0x80319674,
		"JASystem::Vload::initHeader": 0x803196b0,
		"initHeader": 0x803196b0,
		"JASystem::Vload::initHeaderM": 0x803196d8,
		"initHeaderM": 0x803196d8,
		"JASystem::Vload::getArchiveHandle": 0x80319844,
		"getArchiveHandle": 0x80319844,
		"JASystem::Vload::getRealHandle": 0x803198cc,
		"getRealHandle": 0x803198cc,
		"JASystem::Vload::checkSize": 0x80319944,
		"checkSize": 0x80319944,
		"JASystem::Vload::loadFile": 0x80319978,
		"JASystem::Vload::loadFileAsync": 0x80319a24,
		"loadFileAsync": 0x80319a24,
		"JASystem::Vload::initVloadBuffers": 0x80319ac4,
		"initVloadBuffers": 0x80319ac4,
		"JASystem::TTrack::TNoteMgr::init": 0x80319b88,
		"JASystem::TTrack::TNoteMgr::endProcess": 0x80319be0,
		"endProcess": 0x80319be0,
		"JASystem::TTrack::TNoteMgr::getChannel": 0x80319c08,
		"getChannel": 0x80319c08,
		"JASystem::TTrack::TOuterParam::TOuterParam": 0x80319c58,
		"JASystem::TTrack::TOuterParam::initExtBuffer": 0x80319ca4,
		"initExtBuffer": 0x80319ca4,
		"JASystem::TTrack::TOuterParam::setOuterSwitch": 0x80319cb4,
		"setOuterSwitch": 0x80319cb4,
		"JASystem::TTrack::TOuterParam::checkOuterSwitch": 0x80319cbc,
		"checkOuterSwitch": 0x80319cbc,
		"JASystem::TTrack::TOuterParam::setOuterUpdate": 0x80319cdc,
		"setOuterUpdate": 0x80319cdc,
		"JASystem::TTrack::TOuterParam::getOuterUpdate": 0x80319ce4,
		"getOuterUpdate": 0x80319ce4,
		"JASystem::TTrack::TOuterParam::getIntFirFilter": 0x80319cec,
		"getIntFirFilter": 0x80319cec,
		"JASystem::TTrack::TOuterParam::setParam": 0x80319cfc,
		"setParam": 0x80319cfc,
		"JASystem::TTrack::TOuterParam::onSwitch": 0x80319d98,
		"onSwitch": 0x80319d98,
		"JASystem::TTrack::TOuterParam::setFirFilter": 0x80319db4,
		"setFirFilter": 0x80319db4,
		"JASystem::Player::extend8to16": 0x80319e10,
		"extend8to16": 0x80319e10,
		"JASystem::Player::pitchToCent": 0x80319e30,
		"pitchToCent": 0x80319e30,
		"JASystem::Player::getRandomS32": 0x80319efc,
		"getRandomS32": 0x80319efc,
		"JASystem::TRegisterParam::TRegisterParam": 0x80319f34,
		"JASystem::TRegisterParam::init": 0x80319f84,
		"JASystem::TRegisterParam::inherit": 0x80319fec,
		"inherit": 0x80319fec,
		"JASystem::TRegisterParam::getBankNumber": 0x8031a05c,
		"getBankNumber": 0x8031a05c,
		"JASystem::TRegisterParam::getProgramNumber": 0x8031a06c,
		"getProgramNumber": 0x8031a06c,
		"JASystem::TSeqCtrl::init": 0x8031a078,
		"JASystem::TSeqCtrl::loopE": 0x8031a0e0,
		"loopE": 0x8031a0e0,
		"JASystem::TSeqCtrl::waitCountDown": 0x8031a14c,
		"waitCountDown": 0x8031a14c,
		"JASystem::TSeqCtrl::callIntr": 0x8031a17c,
		"callIntr": 0x8031a17c,
		"JASystem::TSeqCtrl::retIntr": 0x8031a1b4,
		"retIntr": 0x8031a1b4,
		"JASystem::TSeqCtrl::get16": 0x8031a1e8,
		"get16": 0x8031a1e8,
		"JASystem::TSeqCtrl::get24": 0x8031a210,
		"get24": 0x8031a210,
		"JASystem::TSeqCtrl::get32": 0x8031a238,
		"get32": 0x8031a238,
		"JASystem::TSeqCtrl::read16": 0x8031a270,
		"read16": 0x8031a270,
		"JASystem::TSeqCtrl::read24": 0x8031a2a8,
		"read24": 0x8031a2a8,
		"JASystem::TTrack::TTrack": 0x8031a2ec,
		"JASystem::TTrack::MoveParam_::MoveParam_": 0x8031a50c,
		"JASystem::TTrack::AInnerParam_::AInnerParam_": 0x8031a524,
		"JASystem::TTrack::setInterrupt": 0x8031a654,
		"setInterrupt": 0x8031a654,
		"JASystem::TTrack::assignExtBuffer": 0x8031a67c,
		"assignExtBuffer": 0x8031a67c,
		"JASystem::TTrack::setInnerMemory": 0x8031a698,
		"setInnerMemory": 0x8031a698,
		"JASystem::TTrack::setPanSwitchExt": 0x8031a6a0,
		"setPanSwitchExt": 0x8031a6a0,
		"JASystem::TTrack::setPanSwitchParent": 0x8031a6b0,
		"setPanSwitchParent": 0x8031a6b0,
		"JASystem::TTrack::flushAll": 0x8031a6c0,
		"flushAll": 0x8031a6c0,
		"JASystem::TTrack::initTimed": 0x8031a6f8,
		"initTimed": 0x8031a6f8,
		"JASystem::TTrack::noteOn": 0x8031a818,
		"JASystem::TTrack::noteOff": 0x8031ab50,
		"noteOff": 0x8031ab50,
		"JASystem::TTrack::gateOn": 0x8031abdc,
		"JASystem::TTrack::oscSetupFull": 0x8031ac4c,
		"oscSetupFull": 0x8031ac4c,
		"JASystem::TTrack::oscSetupSimpleEnv": 0x8031ad78,
		"oscSetupSimpleEnv": 0x8031ad78,
		"JASystem::TTrack::oscUpdateParam": 0x8031ade8,
		"oscUpdateParam": 0x8031ade8,
		"JASystem::TTrack::oscSetupSimple": 0x8031ae50,
		"oscSetupSimple": 0x8031ae50,
		"JASystem::TTrack::updateTrackAll": 0x8031af2c,
		"updateTrackAll": 0x8031af2c,
		"JASystem::TTrack::updateTrack": 0x8031b2e4,
		"updateTrack": 0x8031b2e4,
		"JASystem::TTrack::updateTempo": 0x8031b814,
		"updateTempo": 0x8031b814,
		"JASystem::TTrack::updateSeq": 0x8031b940,
		"updateSeq": 0x8031b940,
		"JASystem::TTrack::incSelfOsc": 0x8031ba14,
		"incSelfOsc": 0x8031ba14,
		"JASystem::TTrack::mainProc": 0x8031bb08,
		"JASystem::TTrack::seqTimeToDspTime": 0x8031bfac,
		"seqTimeToDspTime": 0x8031bfac,
		"JASystem::TTrack::writeTimeParam": 0x8031c068,
		"writeTimeParam": 0x8031c068,
		"JASystem::TTrack::writeRegParam": 0x8031c26c,
		"writeRegParam": 0x8031c26c,
		"JASystem::TTrack::setSeqData": 0x8031c774,
		"JASystem::TTrack::startSeq": 0x8031c818,
		"JASystem::TTrack::stopSeq": 0x8031c894,
		"JASystem::TTrack::closeTrack": 0x8031c914,
		"closeTrack": 0x8031c914,
		"JASystem::TTrack::muteTrack": 0x8031ca74,
		"muteTrack": 0x8031ca74,
		"JASystem::TTrack::initTrack": 0x8031cb44,
		"initTrack": 0x8031cb44,
		"JASystem::TTrack::startTrack": 0x8031cdd4,
		"startTrack": 0x8031cdd4,
		"JASystem::TTrack::openTrack": 0x8031ce68,
		"openTrack": 0x8031ce68,
		"JASystem::TTrack::loadTbl": 0x8031cec0,
		"loadTbl": 0x8031cec0,
		"JASystem::TTrack::readReg32": 0x8031cf68,
		"readReg32": 0x8031cf68,
		"JASystem::TTrack::exchangeRegisterValue": 0x8031d004,
		"exchangeRegisterValue": 0x8031d004,
		"JASystem::TTrack::readRegDirect": 0x8031d0bc,
		"readRegDirect": 0x8031d0bc,
		"JASystem::TTrack::writeRegDirect": 0x8031d2f8,
		"writeRegDirect": 0x8031d2f8,
		"JASystem::TTrack::writePortAppDirect": 0x8031d3c4,
		"writePortAppDirect": 0x8031d3c4,
		"JASystem::TTrack::readPortAppDirect": 0x8031d420,
		"readPortAppDirect": 0x8031d420,
		"JASystem::TTrack::setExtFirFilterD": 0x8031d444,
		"setExtFirFilterD": 0x8031d444,
		"JASystem::TTrack::writePortApp": 0x8031d470,
		"JASystem::TTrack::readPortApp": 0x8031d518,
		"JASystem::TTrack::pauseTrack": 0x8031d588,
		"pauseTrack": 0x8031d588,
		"JASystem::TTrack::unPauseTrack": 0x8031d6bc,
		"unPauseTrack": 0x8031d6bc,
		"JASystem::TTrack::pauseTrackAll": 0x8031d798,
		"pauseTrackAll": 0x8031d798,
		"JASystem::TTrack::unPauseTrackAll": 0x8031d7bc,
		"unPauseTrackAll": 0x8031d7bc,
		"JASystem::TTrack::reset": 0x8031d7e0,
		"JASystem::TTrack::panCalc": 0x8031d7f0,
		"panCalc": 0x8031d7f0,
		"JASystem::TTrack::rootCallback": 0x8031d83c,
		"rootCallback": 0x8031d83c,
		"JASystem::TTrack::registerTrackCallback": 0x8031d9cc,
		"JSystem::__sinit_JASTrack_cpp": 0x8031d9d8,
		"__sinit_JASTrack_cpp": 0x8031d9d8,
		"JASystem::TIntrMgr::init": 0x8031da04,
		"JASystem::TIntrMgr::request": 0x8031da48,
		"JASystem::TIntrMgr::setIntr": 0x8031da6c,
		"setIntr": 0x8031da6c,
		"JASystem::TIntrMgr::resetInter": 0x8031da90,
		"resetInter": 0x8031da90,
		"JASystem::TIntrMgr::checkIntr": 0x8031daa8,
		"checkIntr": 0x8031daa8,
		"JASystem::TIntrMgr::timerProcess": 0x8031db14,
		"timerProcess": 0x8031db14,
		"JASystem::TrackMgr::init": 0x8031db84,
		"JASystem::TTrack::~TTrack": 0x8031dc78,
		"JASystem::TrackMgr::handleToSeq": 0x8031dcdc,
		"handleToSeq": 0x8031dcdc,
		"JASystem::TrackMgr::reset": 0x8031dd00,
		"JASystem::TrackMgr::initRegistTrack": 0x8031dd9c,
		"initRegistTrack": 0x8031dd9c,
		"JASystem::TrackMgr::getNewTrack": 0x8031de2c,
		"getNewTrack": 0x8031de2c,
		"JASystem::TrackMgr::allocNewRoot": 0x8031deb4,
		"allocNewRoot": 0x8031deb4,
		"JASystem::TrackMgr::deAllocRoot": 0x8031defc,
		"deAllocRoot": 0x8031defc,
		"JASystem::TrackMgr::registTrack": 0x8031df48,
		"registTrack": 0x8031df48,
		"JASystem::TrackMgr::unRegistTrack": 0x8031e064,
		"unRegistTrack": 0x8031e064,
		"JASystem::TrackMgr::backTrack": 0x8031e0dc,
		"backTrack": 0x8031e0dc,
		"JASystem::TrackMgr::registerTrackCallback": 0x8031e13c,
		"JASystem::TTrackPort::init": 0x8031e15c,
		"JMath::TRandom_fast_::TRandom_fast_": 0x8031e244,
		"JMath::TRandom_enough_::setSeed": 0x8031e24c,
		"setSeed": 0x8031e24c,
		"J3DMaterialFactory_v21::J3DMaterialFactory_v21": 0x8031e340,
		"J3DMaterialFactory_v21::countUniqueMaterials": 0x8031e520,
		"J3DMaterialFactory_v21::countStages": 0x8031e578,
		"J3DMaterialFactory_v21::create": 0x8031e65c,
		"J3DMaterialFactory_v21::newMatColor": 0x8031eda8,
		"J3DMaterialFactory_v21::newColorChanNum": 0x8031ee38,
		"J3DMaterialFactory_v21::newColorChan": 0x8031ee70,
		"J3DMaterialFactory_v21::newTexGenNum": 0x8031ef38,
		"J3DMaterialFactory_v21::newTexCoord": 0x8031ef70,
		"J3DMaterialFactory_v21::newTexMtx": 0x8031efe4,
		"J3DMaterialFactory_v21::newCullMode": 0x8031f078,
		"J3DMaterialFactory_v21::newTexNo": 0x8031f0b8,
		"J3DMaterialFactory_v21::newTevOrder": 0x8031f100,
		"J3DMaterialFactory_v21::newTevColor": 0x8031f174,
		"J3DMaterialFactory_v21::newTevKColor": 0x8031f20c,
		"J3DMaterialFactory_v21::newTevStageNum": 0x8031f29c,
		"J3DMaterialFactory_v21::newTevStage": 0x8031f2d4,
		"J3DMaterialFactory_v21::newTevSwapModeTable": 0x8031f540,
		"J3DMaterialFactory_v21::newFog": 0x8031f5dc,
		"J3DMaterialFactory_v21::newAlphaComp": 0x8031f668,
		"J3DMaterialFactory_v21::newBlend": 0x8031f6e8,
		"J3DMaterialFactory_v21::newZMode": 0x8031f764,
		"J3DMaterialFactory_v21::newZCompLoc": 0x8031f7c8,
		"J3DMaterialFactory_v21::newDither": 0x8031f800,
		"J3DMaterialFactory_v21::newNBTScale": 0x8031f838,
		"JASystem::TSeqParser::cmdOpenTrack": 0x8031f8f8,
		"cmdOpenTrack": 0x8031f8f8,
		"JASystem::TSeqParser::cmdOpenTrackBros": 0x8031f978,
		"cmdOpenTrackBros": 0x8031f978,
		"JASystem::TSeqParser::cmdCall": 0x8031fa0c,
		"cmdCall": 0x8031fa0c,
		"JASystem::TSeqParser::cmdRet": 0x8031fb28,
		"cmdRet": 0x8031fb28,
		"JASystem::TSeqParser::cmdJmp": 0x8031fba8,
		"cmdJmp": 0x8031fba8,
		"JASystem::TSeqParser::cmdLoopS": 0x8031fce4,
		"cmdLoopS": 0x8031fce4,
		"JASystem::TSeqParser::cmdLoopE": 0x8031fd1c,
		"cmdLoopE": 0x8031fd1c,
		"JASystem::TSeqParser::cmdReadPort": 0x8031fd54,
		"cmdReadPort": 0x8031fd54,
		"JASystem::TSeqParser::cmdWritePort": 0x8031fda0,
		"cmdWritePort": 0x8031fda0,
		"JASystem::TSeqParser::cmdCheckPortImport": 0x8031fdc8,
		"cmdCheckPortImport": 0x8031fdc8,
		"JASystem::TSeqParser::cmdCheckPortExport": 0x8031fe00,
		"cmdCheckPortExport": 0x8031fe00,
		"JASystem::TSeqParser::cmdWait": 0x8031fe38,
		"cmdWait": 0x8031fe38,
		"JASystem::TSeqParser::cmdConnectName": 0x8031fe58,
		"cmdConnectName": 0x8031fe58,
		"JASystem::TSeqParser::cmdParentWritePort": 0x8031fe74,
		"cmdParentWritePort": 0x8031fe74,
		"JASystem::TSeqParser::cmdChildWritePort": 0x8031feac,
		"cmdChildWritePort": 0x8031feac,
		"JASystem::TSeqParser::cmdSetLastNote": 0x8031feec,
		"cmdSetLastNote": 0x8031feec,
		"JASystem::TSeqParser::cmdTimeRelate": 0x8031ff08,
		"cmdTimeRelate": 0x8031ff08,
		"JASystem::TSeqParser::cmdSimpleOsc": 0x8031ff2c,
		"cmdSimpleOsc": 0x8031ff2c,
		"JASystem::TSeqParser::cmdSimpleEnv": 0x8031ff5c,
		"cmdSimpleEnv": 0x8031ff5c,
		"JASystem::TSeqParser::cmdSimpleADSR": 0x8031ff90,
		"cmdSimpleADSR": 0x8031ff90,
		"JASystem::TSeqParser::cmdTranspose": 0x8032004c,
		"cmdTranspose": 0x8032004c,
		"JASystem::TSeqParser::cmdCloseTrack": 0x80320084,
		"cmdCloseTrack": 0x80320084,
		"JASystem::TSeqParser::cmdOutSwitch": 0x803200dc,
		"cmdOutSwitch": 0x803200dc,
		"JASystem::TSeqParser::cmdUpdateSync": 0x80320134,
		"cmdUpdateSync": 0x80320134,
		"JASystem::TSeqParser::cmdBusConnect": 0x80320160,
		"cmdBusConnect": 0x80320160,
		"JASystem::TSeqParser::cmdPauseStatus": 0x80320184,
		"cmdPauseStatus": 0x80320184,
		"JASystem::TSeqParser::cmdVolumeMode": 0x80320194,
		"cmdVolumeMode": 0x80320194,
		"JASystem::TSeqParser::cmdSetInterrupt": 0x803201a4,
		"cmdSetInterrupt": 0x803201a4,
		"JASystem::TSeqParser::cmdDisInterrupt": 0x803201dc,
		"cmdDisInterrupt": 0x803201dc,
		"JASystem::TSeqParser::cmdClrI": 0x80320208,
		"cmdClrI": 0x80320208,
		"JASystem::TSeqParser::cmdSetI": 0x80320220,
		"cmdSetI": 0x80320220,
		"JASystem::TSeqParser::cmdRetI": 0x80320230,
		"cmdRetI": 0x80320230,
		"JASystem::TSeqParser::cmdIntTimer": 0x80320260,
		"cmdIntTimer": 0x80320260,
		"JASystem::TSeqParser::cmdConnectOpen": 0x8032027c,
		"cmdConnectOpen": 0x8032027c,
		"JASystem::TSeqParser::cmdConnectClose": 0x803202b8,
		"cmdConnectClose": 0x803202b8,
		"JASystem::TSeqParser::cmdSyncCPU": 0x80320300,
		"cmdSyncCPU": 0x80320300,
		"JASystem::TSeqParser::cmdFlushAll": 0x80320368,
		"cmdFlushAll": 0x80320368,
		"JASystem::TSeqParser::cmdFlushRelease": 0x80320390,
		"cmdFlushRelease": 0x80320390,
		"JASystem::TSeqParser::cmdTimeBase": 0x803203b8,
		"cmdTimeBase": 0x803203b8,
		"JASystem::TSeqParser::cmdTempo": 0x803203f4,
		"cmdTempo": 0x803203f4,
		"JASystem::TSeqParser::cmdFinish": 0x8032043c,
		"cmdFinish": 0x8032043c,
		"JASystem::TSeqParser::cmdNop": 0x80320528,
		"cmdNop": 0x80320528,
		"JASystem::TSeqParser::cmdPanPowSet": 0x80320530,
		"cmdPanPowSet": 0x80320530,
		"JASystem::TSeqParser::cmdIIRSet": 0x803205b4,
		"cmdIIRSet": 0x803205b4,
		"JASystem::TSeqParser::cmdFIRSet": 0x803206b8,
		"cmdFIRSet": 0x803206b8,
		"JASystem::TSeqParser::cmdEXTSet": 0x803206ec,
		"cmdEXTSet": 0x803206ec,
		"JASystem::TSeqParser::cmdPanSwSet": 0x80320740,
		"cmdPanSwSet": 0x80320740,
		"JASystem::TSeqParser::cmdOscRoute": 0x80320830,
		"cmdOscRoute": 0x80320830,
		"JASystem::TSeqParser::cmdIIRCutOff": 0x80320880,
		"cmdIIRCutOff": 0x80320880,
		"JASystem::TSeqParser::cmdOscFull": 0x80320988,
		"cmdOscFull": 0x80320988,
		"JASystem::TSeqParser::cmdCheckWave": 0x803209c4,
		"cmdCheckWave": 0x803209c4,
		"JASystem::TSeqParser::cmdPrintf": 0x803209f4,
		"cmdPrintf": 0x803209f4,
		"JASystem::TSeqParser::Cmd_Process": 0x80320c14,
		"Cmd_Process": 0x80320c14,
		"JASystem::TSeqParser::RegCmd_Process": 0x80320d6c,
		"RegCmd_Process": 0x80320d6c,
		"JASystem::TSeqParser::cmdNoteOff": 0x80320e50,
		"cmdNoteOff": 0x80320e50,
		"JASystem::TSeqParser::cmdNoteOn": 0x80320f30,
		"cmdNoteOn": 0x80320f30,
		"JASystem::TSeqParser::conditionCheck": 0x80321210,
		"conditionCheck": 0x80321210,
		"JASystem::TSeqParser::mainProc": 0x80321300,
		"JSystem::__sinit_JASSeqParser_cpp": 0x803215d4,
		"__sinit_JASSeqParser_cpp": 0x803215d4,
		"J3DMaterialTable::clear": 0x80321c08,
		"J3DMaterialTable::J3DMaterialTable": 0x80321c24,
		"J3DMaterialTable::~J3DMaterialTable": 0x80321c4c,
		"JSystem::JPAGetEmitterInfoPtr": 0x80321c98,
		"JPAGetEmitterInfoPtr": 0x80321c98,
		"JPABaseEmitter::JPABaseEmitter": 0x80321ca4,
		"JPABaseEmitter::getFovy": 0x80321dbc,
		"getFovy": 0x80321dbc,
		"JPABaseEmitter::getAspect": 0x80321dcc,
		"getAspect": 0x80321dcc,
		"JPABaseEmitter::deleteAllParticle": 0x80321ddc,
		"deleteAllParticle": 0x80321ddc,
		"JPABaseEmitter::createChildParticle": 0x80321eb0,
		"createChildParticle": 0x80321eb0,
		"JPAParticle::addBaseVelVec": 0x80322464,
		"addBaseVelVec": 0x80322464,
		"JPAParticle::setBaseVelVec": 0x80322498,
		"setBaseVelVec": 0x80322498,
		"JPABaseEmitter::getEmitterGlobalTranslation": 0x803224b4,
		"getEmitterGlobalTranslation": 0x803224b4,
		"JPABaseEmitter::calcEmitterGlobalParams": 0x8032259c,
		"calcEmitterGlobalParams": 0x8032259c,
		"JPABaseEmitter::loadBaseEmitterBlock": 0x80322910,
		"loadBaseEmitterBlock": 0x80322910,
		"JPABaseEmitter::drawEmitterCallBack": 0x80322cd8,
		"drawEmitterCallBack": 0x80322cd8,
		"JPABaseEmitter::createParticle": 0x80322d14,
		"createParticle": 0x80322d14,
		"JPABaseEmitter::calcCurrentRateTimerStep": 0x80323fbc,
		"calcCurrentRateTimerStep": 0x80323fbc,
		"JPABaseEmitter::calcCreateParticle": 0x80324010,
		"calcCreateParticle": 0x80324010,
		"JPABaseEmitter::checkStartFrame": 0x80324320,
		"checkStartFrame": 0x80324320,
		"JPABaseEmitter::checkMaxFrame": 0x8032437c,
		"checkMaxFrame": 0x8032437c,
		"JPABaseEmitter::doParticle": 0x80324428,
		"doParticle": 0x80324428,
		"JPABaseEmitter::doChildParticle": 0x80324594,
		"doChildParticle": 0x80324594,
		"JPABaseEmitter::calcKeyFrameAnime": 0x803246f0,
		"calcKeyFrameAnime": 0x803246f0,
		"JPABaseEmitter::calc": 0x803248c0,
		"JPABaseEmitter::setGlobalRTMatrix": 0x80324a0c,
		"setGlobalRTMatrix": 0x80324a0c,
		"JPABaseEmitter::setGlobalSRTMatrix": 0x80324a3c,
		"setGlobalSRTMatrix": 0x80324a3c,
		"JSystem::__sinit_JPAEmitter_cpp": 0x80324a70,
		"__sinit_JPAEmitter_cpp": 0x80324a70,
		"JPAEmitterManager::JPAEmitterManager": 0x80324ad0,
		"JSUList<JPABaseEmitter>::JSUList": 0x80324da8,
		"JSUList<JPABaseEmitter>::~JSUList": 0x80324dd8,
		"JPAEmitterManager::calcBase": 0x80324e30,
		"calcBase": 0x80324e30,
		"JPAEmitterManager::calc": 0x80324f0c,
		"JPAEmitterManager::createEmitterBase": 0x803250ec,
		"createEmitterBase": 0x803250ec,
		"JPAEmitterManager::createSimpleEmitterID": 0x80325298,
		"createSimpleEmitterID": 0x80325298,
		"JPAEmitterManager::createEmitter": 0x80325300,
		"createEmitter": 0x80325300,
		"JPAEmitterManager::deleteEmitter": 0x80325398,
		"deleteEmitter": 0x80325398,
		"JPAEmitterManager::forceDeleteEmitter": 0x803253fc,
		"forceDeleteEmitter": 0x803253fc,
		"JPABaseField::JPABaseField": 0x80325464,
		"JPABaseField::~JPABaseField": 0x803254fc,
		"JPABaseField::set": 0x80325564,
		"JPABaseField::checkMaxDistance": 0x80325568,
		"JPABaseField::calcFieldFadeScale": 0x803255c0,
		"calcFieldFadeScale": 0x803255c0,
		"JPABaseField::calcFieldVelocity": 0x803256e4,
		"calcFieldVelocity": 0x803256e4,
		"JPABaseField::affect": 0x80325854,
		"JPABaseField::loadFieldBlock": 0x80325874,
		"loadFieldBlock": 0x80325874,
		"JPAGravityField::JPAGravityField": 0x80325ad0,
		"JPAGravityField::~JPAGravityField": 0x80325b14,
		"JPAGravityField::set": 0x80325b8c,
		"JPAAirField::JPAAirField": 0x80325c28,
		"JPAAirField::set": 0x80325c6c,
		"JPAAirField::affect": 0x80325db4,
		"JPAParticle::getBaseVelVec": 0x80325fec,
		"getBaseVelVec": 0x80325fec,
		"JPAMagnetField::JPAMagnetField": 0x80326008,
		"JPAMagnetField::~JPAMagnetField": 0x8032604c,
		"JPAMagnetField::set": 0x803260c4,
		"JPAMagnetField::affect": 0x8032613c,
		"JPANewtonField::JPANewtonField": 0x8032627c,
		"JPANewtonField::~JPANewtonField": 0x803262c0,
		"JPANewtonField::set": 0x80326338,
		"JPANewtonField::affect": 0x803263bc,
		"JPAVortexField::JPAVortexField": 0x803265b8,
		"JPAVortexField::~JPAVortexField": 0x80326610,
		"JPAVortexField::set": 0x80326688,
		"JPAVortexField::affect": 0x803266e0,
		"JPAVortexField::checkMaxDistance": 0x80326848,
		"JPAConvectionField::JPAConvectionField": 0x80326850,
		"JPAConvectionField::~JPAConvectionField": 0x803268b4,
		"JPAConvectionField::set": 0x8032692c,
		"JPAConvectionField::affect": 0x80326be0,
		"JPAConvectionField::checkMaxDistance": 0x80326ed8,
		"JPARandomField::JPARandomField": 0x80326ee0,
		"JPARandomField::~JPARandomField": 0x80326f24,
		"JPARandomField::affect": 0x80326f9c,
		"JPADragField::JPADragField": 0x803270dc,
		"JPADragField::~JPADragField": 0x80327120,
		"JPADragField::affect": 0x80327198,
		"JPAParticle::getDragForce": 0x803272b8,
		"getDragForce": 0x803272b8,
		"JPAFieldManager::JPAFieldManager": 0x803272c0,
		"JPAFieldManager::deleteAllField": 0x803272f0,
		"deleteAllField": 0x803272f0,
		"JPAFieldManager::calcFieldParams": 0x80327368,
		"calcFieldParams": 0x80327368,
		"JPAFieldManager::affectField": 0x803273f0,
		"affectField": 0x803273f0,
		"JPAFieldManager::setField": 0x803274c8,
		"setField": 0x803274c8,
		"JPAFieldManager::setGravityField": 0x8032756c,
		"setGravityField": 0x8032756c,
		"JPAFieldManager::setAirField": 0x803275e0,
		"setAirField": 0x803275e0,
		"JPAFieldManager::setMagnetField": 0x80327654,
		"setMagnetField": 0x80327654,
		"JPAFieldManager::setNewtonField": 0x803276c8,
		"setNewtonField": 0x803276c8,
		"JPAFieldManager::setVortexField": 0x8032773c,
		"setVortexField": 0x8032773c,
		"JPAFieldManager::setConvectionField": 0x803277b0,
		"setConvectionField": 0x803277b0,
		"JPAFieldManager::setRandomField": 0x80327824,
		"setRandomField": 0x80327824,
		"JPAFieldManager::setDragField": 0x80327898,
		"setDragField": 0x80327898,
		"JPAAirField::~JPAAirField": 0x8032790c,
		"JSystem::__sinit_JPAField_cpp": 0x80327984,
		"__sinit_JPAField_cpp": 0x80327984,
		"JSystem::JPASqrtf": 0x803279ac,
		"JPASqrtf": 0x803279ac,
		"JSystem::JPAGetXYZRotateMtx": 0x803279d0,
		"JPAGetXYZRotateMtx": 0x803279d0,
		"JSystem::JPAGetXYRotateMtx": 0x80327be8,
		"JPAGetXYRotateMtx": 0x80327be8,
		"JSystem::JPAGetYZRotateMtx": 0x80327d1c,
		"JPAGetYZRotateMtx": 0x80327d1c,
		"JSystem::JPAGetYRotateMtx": 0x80327e50,
		"JPAGetYRotateMtx": 0x80327e50,
		"JSystem::JPAVecToRotaMtx": 0x80327ee8,
		"JPAVecToRotaMtx": 0x80327ee8,
		"JSystem::JPAConvertFixToFloat": 0x8032809c,
		"JPAConvertFixToFloat": 0x8032809c,
		"JSystem::JPAConvertFixVecToFloatVec": 0x80328158,
		"JPAConvertFixVecToFloatVec": 0x80328158,
		"JSystem::JPAGetRMtxSTVecElement": 0x80328380,
		"JPAGetRMtxSTVecElement": 0x80328380,
		"JSystem::JPAGetRMtxTVecElement": 0x80328614,
		"JPAGetRMtxTVecElement": 0x80328614,
		"JSystem::JPAGetKeyFrameValue": 0x80328884,
		"JPAGetKeyFrameValue": 0x80328884,
		"JSystem::JPAGetKeyFrameInterpolation": 0x803288a4,
		"JPAGetKeyFrameInterpolation": 0x803288a4,
		"JPABaseParticle::incTimer": 0x80328954,
		"incTimer": 0x80328954,
		"JPABaseParticle::executeParticleCallBack": 0x803289b4,
		"executeParticleCallBack": 0x803289b4,
		"JPABaseParticle::drawParticleCallBack": 0x803289f0,
		"drawParticleCallBack": 0x803289f0,
		"JPAParticle::JPAParticle": 0x80328a2c,
		"JPAParticle::init": 0x80328a78,
		"JPAParticle::setVelocity": 0x80328ab8,
		"setVelocity": 0x80328ab8,
		"JPAParticle::calcVelocity": 0x80328b74,
		"JPABaseParticle::initGlobalPosition": 0x80328c9c,
		"initGlobalPosition": 0x80328c9c,
		"JPABaseParticle::calcGlobalPosition": 0x80328d04,
		"calcGlobalPosition": 0x80328d04,
		"JPABaseParticle::getCurrentPosition": 0x80328d9c,
		"getCurrentPosition": 0x80328d9c,
		"JPAParticle::checkCreateChildParticle": 0x80328e28,
		"checkCreateChildParticle": 0x80328e28,
		"JPAParticle::getDynamicsWeight": 0x80328eec,
		"getDynamicsWeight": 0x80328eec,
		"JPAParticle::getAirResistance": 0x80328ef4,
		"getAirResistance": 0x80328ef4,
		"JPAParticle::getCurrentDragForce": 0x80328efc,
		"getCurrentDragForce": 0x80328efc,
		"JPAParticle::accessBaseVelVec": 0x80328f04,
		"accessBaseVelVec": 0x80328f04,
		"JPAParticle::accessFAccVec": 0x80328f0c,
		"accessFAccVec": 0x80328f0c,
		"JPAParticle::accessFVelVec": 0x80328f14,
		"accessFVelVec": 0x80328f14,
		"JPAParticle::getDrawParamPPtr": 0x80328f1c,
		"getDrawParamPPtr": 0x80328f1c,
		"JPAParticle::getDrawParamCPtr": 0x80328f24,
		"getDrawParamCPtr": 0x80328f24,
		"JPAParticle::getWidth": 0x80328f2c,
		"JPAParticle::getHeight": 0x80328f4c,
		"JPADrawSetupTev::setupTev": 0x80328f6c,
		"setupTev": 0x80328f6c,
		"JPADraw::initialize": 0x803292ac,
		"JPADraw::draw": 0x80329610,
		"JPADraw::calc": 0x80329894,
		"JPADraw::calcParticle": 0x80329908,
		"calcParticle": 0x80329908,
		"JPADraw::calcChild": 0x803299b0,
		"calcChild": 0x803299b0,
		"JPADraw::initParticle": 0x80329a58,
		"JPADraw::initChild": 0x80329da8,
		"initChild": 0x80329da8,
		"JPADraw::swapImage": 0x8032a06c,
		"swapImage": 0x8032a06c,
		"JPADraw::setDrawExecVisitorsBeforeCB": 0x8032a0cc,
		"setDrawExecVisitorsBeforeCB": 0x8032a0cc,
		"JPADraw::setDrawExecVisitorsAfterCB": 0x8032a774,
		"setDrawExecVisitorsAfterCB": 0x8032a774,
		"JPADraw::setDrawCalcVisitors": 0x8032ad74,
		"setDrawCalcVisitors": 0x8032ad74,
		"JPADraw::setParticleClipBoard": 0x8032b650,
		"setParticleClipBoard": 0x8032b650,
		"JPADraw::setChildClipBoard": 0x8032b9f0,
		"setChildClipBoard": 0x8032b9f0,
		"JPADraw::drawParticle": 0x8032bd10,
		"drawParticle": 0x8032bd10,
		"JPADraw::drawChild": 0x8032bf70,
		"drawChild": 0x8032bf70,
		"JPADraw::zDraw": 0x8032c214,
		"zDraw": 0x8032c214,
		"JPADraw::zDrawParticle": 0x8032c29c,
		"zDrawParticle": 0x8032c29c,
		"JPADraw::zDrawChild": 0x8032c4ac,
		"zDrawChild": 0x8032c4ac,
		"JPADraw::getMainTextureID": 0x8032c700,
		"getMainTextureID": 0x8032c700,
		"JPADraw::loadYBBMtx": 0x8032c740,
		"loadYBBMtx": 0x8032c740,
		"JSystem::__sinit_JPADraw_cpp": 0x8032c810,
		"__sinit_JPADraw_cpp": 0x8032c810,
		"JPADrawClipBoard::~JPADrawClipBoard": 0x8032cd8c,
		"JPADrawVisitorContainer::~JPADrawVisitorContainer": 0x8032cdcc,
		"JPADrawCalcChildScaleOut::~JPADrawCalcChildScaleOut": 0x8032d9ac,
		"JPADrawCalcChildAlphaOut::~JPADrawCalcChildAlphaOut": 0x8032da08,
		"JPADrawCalcAlphaFlickMultSin::~JPADrawCalcAlphaFlickMultSin": 0x8032dcd0,
		"JPADrawCalcAlphaFlickAddSin::~JPADrawCalcAlphaFlickAddSin": 0x8032dd2c,
		"JPADrawCalcAlphaFlickNrmSin::~JPADrawCalcAlphaFlickNrmSin": 0x8032dd88,
		"JPADrawCalcAlpha::~JPADrawCalcAlpha": 0x8032dde4,
		"JPADrawCalcColorCopyFromEmitter::~JPADrawCalcColorCopyFromEmitter": 0x8032e0ac,
		"JPADrawCalcEmitterVisitor::~JPADrawCalcEmitterVisitor": 0x8032e200,
		"JPADrawCalcScaleAnmTimingReverseY::~JPADrawCalcScaleAnmTimingReverseY": 0x8032e24c,
		"JPADrawCalcScaleAnmTimingReverseX::~JPADrawCalcScaleAnmTimingReverseX": 0x8032e2a8,
		"JPADrawCalcScaleAnmTimingRepeatY::~JPADrawCalcScaleAnmTimingRepeatY": 0x8032e304,
		"JPADrawCalcScaleAnmTimingRepeatX::~JPADrawCalcScaleAnmTimingRepeatX": 0x8032e360,
		"JPADrawCalcScaleAnmTimingNormal::~JPADrawCalcScaleAnmTimingNormal": 0x8032e3bc,
		"JPADrawCalcScaleCopyX2Y::~JPADrawCalcScaleCopyX2Y": 0x8032e418,
		"JPADrawCalcScaleYBySpeed::~JPADrawCalcScaleYBySpeed": 0x8032e474,
		"JPADrawCalcScaleY::~JPADrawCalcScaleY": 0x8032e4d0,
		"JPADrawCalcScaleXBySpeed::~JPADrawCalcScaleXBySpeed": 0x8032e52c,
		"JPADrawCalcScaleX::~JPADrawCalcScaleX": 0x8032e588,
		"JPADrawCalcParticleVisitor::~JPADrawCalcParticleVisitor": 0x8032e5e4,
		"JPADrawExecStripeCross::~JPADrawExecStripeCross": 0x8032e6ac,
		"JPADrawExecStripe::~JPADrawExecStripe": 0x8032e708,
		"JPADrawExecLine::~JPADrawExecLine": 0x8032e764,
		"JPADrawExecPoint::~JPADrawExecPoint": 0x8032e7c0,
		"JPADrawExecRotationCross::~JPADrawExecRotationCross": 0x8032e81c,
		"JPADrawExecRotation::~JPADrawExecRotation": 0x8032e878,
		"JPADrawExecDirBillBoard::~JPADrawExecDirBillBoard": 0x8032e8d4,
		"JPADrawExecRotDirectionalCross::~JPADrawExecRotDirectionalCross": 0x8032e930,
		"JPADrawExecDirectionalCross::~JPADrawExecDirectionalCross": 0x8032e98c,
		"JPADrawExecRotDirectional::~JPADrawExecRotDirectional": 0x8032e9e8,
		"JPADrawExecDirectional::~JPADrawExecDirectional": 0x8032ea44,
		"JPADrawExecRotYBillBoard::~JPADrawExecRotYBillBoard": 0x8032eaa0,
		"JPADrawExecYBillBoard::~JPADrawExecYBillBoard": 0x8032eafc,
		"JPADrawExecRotBillBoard::~JPADrawExecRotBillBoard": 0x8032eb58,
		"JPADrawExecBillBoard::~JPADrawExecBillBoard": 0x8032ebb4,
		"JPADrawExecLoadExTex::~JPADrawExecLoadExTex": 0x8032ec10,
		"JPADrawExecLoadDefaultTexture::~JPADrawExecLoadDefaultTexture": 0x8032ece8,
		"JPADrawExecRegisterPrmAEnv::~JPADrawExecRegisterPrmAEnv": 0x8032ed44,
		"JPADrawExecRegisterPrmCEnv::~JPADrawExecRegisterPrmCEnv": 0x8032eda0,
		"JPADrawExecRegisterEnvColorAnm::~JPADrawExecRegisterEnvColorAnm": 0x8032edfc,
		"JPADrawExecRegisterPrmAlphaAnm::~JPADrawExecRegisterPrmAlphaAnm": 0x8032ee58,
		"JPADrawExecRegisterPrmColorAnm::~JPADrawExecRegisterPrmColorAnm": 0x8032eeb4,
		"JPADrawExecRegisterColorChildPE::~JPADrawExecRegisterColorChildPE": 0x8032ef10,
		"JPADrawExecRegisterColorEmitterE::~JPADrawExecRegisterColorEmitterE": 0x8032ef6c,
		"JPADrawExecRegisterColorEmitterP::~JPADrawExecRegisterColorEmitterP": 0x8032efc8,
		"JPADrawExecRegisterColorEmitterPE::~JPADrawExecRegisterColorEmitterPE": 0x8032f024,
		"JPADrawExecSetLineWidth::~JPADrawExecSetLineWidth": 0x8032f080,
		"JPADrawExecSetPointSize::~JPADrawExecSetPointSize": 0x8032f0dc,
		"JPADrawExecParticleVisitor::~JPADrawExecParticleVisitor": 0x8032f1b4,
		"JPADrawExecGenIdtMtx::~JPADrawExecGenIdtMtx": 0x8032f200,
		"JPADrawExecGenTexMtx0::~JPADrawExecGenTexMtx0": 0x8032f25c,
		"JPADrawExecGenPrjTexMtx::~JPADrawExecGenPrjTexMtx": 0x8032f2b8,
		"JPADrawExecGenPrjMtx::~JPADrawExecGenPrjMtx": 0x8032f314,
		"JPADrawExecEmitterVisitor::~JPADrawExecEmitterVisitor": 0x8032f370,
		"JPADrawExecLoadExTex::exec": 0x8032f3bc,
		"JPADrawExecGenPrjMtx::exec": 0x8032f5b0,
		"JPADrawExecGenPrjTexMtx::exec": 0x8032f660,
		"JPADrawExecGenTexMtx0::exec": 0x8032f80c,
		"JPADrawExecGenIdtMtx::exec": 0x8032f854,
		"JPADrawExecLoadDefaultTexture::exec": 0x8032fa68,
		"JPADrawExecSetPointSize::exec": 0x8032fad4,
		"JPADrawExecSetLineWidth::exec": 0x8032fb28,
		"JPADrawExecRegisterPrmColorAnm::exec": 0x8032fb7c,
		"JPADrawExecRegisterPrmAlphaAnm::exec": 0x8032fc58,
		"JPADrawExecRegisterEnvColorAnm::exec": 0x8032fd44,
		"JPADrawExecRegisterPrmCEnv::exec": 0x8032fddc,
		"JPADrawExecRegisterPrmAEnv::exec": 0x8032ff1c,
		"JPADrawExecBillBoard::exec": 0x8033025c,
		"JPADrawExecRotBillBoard::exec": 0x80330434,
		"JPADrawExecYBillBoard::exec": 0x80330650,
		"JPADrawExecRotYBillBoard::exec": 0x80330874,
		"JSystem::dirTypeVel": 0x80330adc,
		"dirTypeVel": 0x80330adc,
		"JSystem::dirTypePos": 0x80330af8,
		"dirTypePos": 0x80330af8,
		"JSystem::dirTypePosInv": 0x80330b14,
		"dirTypePosInv": 0x80330b14,
		"JSystem::dirTypeEmtrDir": 0x80330b54,
		"dirTypeEmtrDir": 0x80330b54,
		"JSystem::dirTypePrevPtcl": 0x80330b70,
		"dirTypePrevPtcl": 0x80330b70,
		"JSystem::rotTypeY": 0x80330c18,
		"rotTypeY": 0x80330c18,
		"JSystem::rotTypeX": 0x80330c58,
		"rotTypeX": 0x80330c58,
		"JSystem::rotTypeZ": 0x80330c98,
		"rotTypeZ": 0x80330c98,
		"JSystem::rotTypeXYZ": 0x80330cd8,
		"rotTypeXYZ": 0x80330cd8,
		"JSystem::rotTypeYJiggle": 0x80330d34,
		"rotTypeYJiggle": 0x80330d34,
		"JPADrawExecDirectional::exec": 0x80330d8c,
		"JPADrawExecRotDirectional::exec": 0x803311a0,
		"JPADrawExecDirectionalCross::exec": 0x803315fc,
		"JPADrawExecRotDirectionalCross::exec": 0x80331b54,
		"JPADrawExecDirBillBoard::exec": 0x803320f4,
		"JPADrawExecRotation::exec": 0x80332444,
		"JPADrawExecRotationCross::exec": 0x8033266c,
		"JPADrawExecPoint::exec": 0x803329d8,
		"JPADrawExecLine::exec": 0x80332a64,
		"JSystem::stripeGetNext": 0x80332c24,
		"stripeGetNext": 0x80332c24,
		"JSystem::stripeGetPrev": 0x80332c2c,
		"stripeGetPrev": 0x80332c2c,
		"JPADrawExecStripe::exec": 0x80332c34,
		"JPADrawExecStripeCross::exec": 0x803330a4,
		"JPADrawExecRegisterColorEmitterPE::exec": 0x8033388c,
		"JPADrawExecRegisterColorEmitterP::exec": 0x80333990,
		"JPADrawExecRegisterColorEmitterE::exec": 0x80333a30,
		"JPADrawExecRegisterColorChildPE::exec": 0x80333ab8,
		"JPADrawCalcScaleX::calc": 0x80333ec8,
		"JPADrawCalcScaleY::calc": 0x80333f6c,
		"JPADrawCalcScaleXBySpeed::calc": 0x80334010,
		"JPADrawCalcScaleYBySpeed::calc": 0x80334140,
		"JPADrawCalcScaleCopyX2Y::calc": 0x80334270,
		"JPADrawCalcScaleAnmTimingNormal::calc": 0x803342a8,
		"JPADrawCalcScaleAnmTimingRepeatX::calc": 0x803342b8,
		"JPADrawCalcScaleAnmTimingRepeatY::calc": 0x80334324,
		"JPADrawCalcScaleAnmTimingReverseX::calc": 0x80334390,
		"JPADrawCalcScaleAnmTimingReverseY::calc": 0x80334430,
		"JPADrawCalcColorCopyFromEmitter::calc": 0x80334588,
		"JPADrawCalcAlpha::calc": 0x80334898,
		"JPADrawCalcAlphaFlickNrmSin::calc": 0x8033491c,
		"JPADrawCalcAlphaFlickAddSin::calc": 0x80334a0c,
		"JPADrawCalcAlphaFlickMultSin::calc": 0x80334b30,
		"JPADrawCalcChildAlphaOut::calc": 0x80334fd0,
		"JPADrawCalcChildScaleOut::calc": 0x80335018,
		"JPAExTexShape::JPAExTexShape": 0x80335170,
		"JPADataBlock::~JPADataBlock": 0x80335290,
		"JPAExTexShape::~JPAExTexShape": 0x803352dc,
		"JPADataBlock::JPADataBlock": 0x80335338,
		"JPAEmitterLoaderDataBase::load": 0x803353b8,
		"JPAEmitterLoader_v10::~JPAEmitterLoader_v10": 0x8033543c,
		"JPAEmitterLoader_v10::JPAEmitterLoader_v10": 0x80335498,
		"JPAEmitterLoader::~JPAEmitterLoader": 0x803354c8,
		"JPAEmitterLoader_v10::load": 0x80335514,
		"JPAKeyFrameAnime::JPAKeyFrameAnime": 0x803358fc,
		"JPAKeyFrameAnime::~JPAKeyFrameAnime": 0x80335938,
		"JSystem::makeColorTable": 0x80335994,
		"makeColorTable": 0x80335994,
		"JPABaseShape::JPABaseShape": 0x80335c04,
		"JPABaseShape::~JPABaseShape": 0x80336164,
		"JPAExtraShape::JPAExtraShape": 0x803361c0,
		"JPAExtraShape::~JPAExtraShape": 0x80336474,
		"JPATextureResource::JPATextureResource": 0x803364d0,
		"JPATextureResource::registration": 0x80336540,
		"registration": 0x80336540,
		"JPAEmitterResource::getByUserIndex": 0x803365fc,
		"getByUserIndex": 0x803365fc,
		"JPAResourceManager::JPAResourceManager": 0x80336640,
		"JPASweepShape::JPASweepShape": 0x803367cc,
		"JPASweepShape::~JPASweepShape": 0x80336918,
		"JPATexture::JPATexture": 0x80336974,
		"JPADefaultTexture::initialize": 0x803369d4,
		"JPATexture::~JPATexture": 0x80336e7c,
		"JStage::TAmbientLight::~TAmbientLight": 0x80336ef4,
		"JStage::TAmbientLight::JSGFGetType": 0x80336f58,
		"JStage::TAmbientLight::JSGGetColor": 0x80336f60,
		"JStage::TAmbientLight::JSGSetColor": 0x80336f78,
		"JStage::TCamera::~TCamera": 0x80336f7c,
		"JStage::TCamera::JSGFGetType": 0x80336fe0,
		"JStage::TCamera::JSGGetProjectionType": 0x80336fe8,
		"JStage::TCamera::JSGSetProjectionType": 0x80336ff0,
		"JStage::TCamera::JSGGetProjectionNear": 0x80336ff4,
		"JStage::TCamera::JSGSetProjectionNear": 0x80336ffc,
		"JStage::TCamera::JSGGetProjectionFar": 0x80337000,
		"JStage::TCamera::JSGSetProjectionFar": 0x80337008,
		"JStage::TCamera::JSGGetProjectionFovy": 0x8033700c,
		"JStage::TCamera::JSGSetProjectionFovy": 0x80337014,
		"JStage::TCamera::JSGGetProjectionAspect": 0x80337018,
		"JStage::TCamera::JSGSetProjectionAspect": 0x80337020,
		"JStage::TCamera::JSGGetProjectionField": 0x80337024,
		"JStage::TCamera::JSGSetProjectionField": 0x80337028,
		"JStage::TCamera::JSGGetViewType": 0x8033702c,
		"JSGGetViewType": 0x8033702c,
		"JStage::TCamera::JSGSetViewType": 0x80337034,
		"JSGSetViewType": 0x80337034,
		"JStage::TCamera::JSGGetViewPosition": 0x80337038,
		"JStage::TCamera::JSGSetViewPosition": 0x8033703c,
		"JStage::TCamera::JSGGetViewUpVector": 0x80337040,
		"JStage::TCamera::JSGSetViewUpVector": 0x80337044,
		"JStage::TCamera::JSGGetViewTargetPosition": 0x80337048,
		"JStage::TCamera::JSGSetViewTargetPosition": 0x8033704c,
		"JStage::TCamera::JSGGetViewRoll": 0x80337050,
		"JSGGetViewRoll": 0x80337050,
		"JStage::TCamera::JSGSetViewRoll": 0x80337058,
		"JSGSetViewRoll": 0x80337058,
		"JStage::TActor::~TActor": 0x8033705c,
		"JStage::TActor::JSGFGetType": 0x803370c0,
		"JStage::TActor::JSGGetTranslation": 0x803370c8,
		"JStage::TActor::JSGSetTranslation": 0x803370cc,
		"JStage::TActor::JSGGetScaling": 0x803370d0,
		"JStage::TActor::JSGSetScaling": 0x803370d4,
		"JStage::TActor::JSGGetRotation": 0x803370d8,
		"JStage::TActor::JSGSetRotation": 0x803370dc,
		"JStage::TActor::JSGGetShape": 0x803370e0,
		"JSGGetShape": 0x803370e0,
		"JStage::TActor::JSGSetShape": 0x803370e8,
		"JSGSetShape": 0x803370e8,
		"JStage::TActor::JSGGetAnimation": 0x803370ec,
		"JSGGetAnimation": 0x803370ec,
		"JStage::TActor::JSGSetAnimation": 0x803370f4,
		"JSGSetAnimation": 0x803370f4,
		"JStage::TActor::JSGGetAnimationFrame": 0x803370f8,
		"JSGGetAnimationFrame": 0x803370f8,
		"JStage::TActor::JSGSetAnimationFrame": 0x80337100,
		"JSGSetAnimationFrame": 0x80337100,
		"JStage::TActor::JSGGetAnimationFrameMax": 0x80337104,
		"JSGGetAnimationFrameMax": 0x80337104,
		"JStage::TLight::~TLight": 0x8033710c,
		"JStage::TLight::JSGFGetType": 0x80337170,
		"JStage::TLight::JSGGetLightType": 0x80337178,
		"JStage::TLight::JSGSetLightType": 0x80337180,
		"JStage::TLight::JSGGetColor": 0x80337184,
		"JStage::TLight::JSGSetColor": 0x8033719c,
		"JStage::TLight::JSGGetDistanceAttenuation": 0x803371a0,
		"JSGGetDistanceAttenuation": 0x803371a0,
		"JStage::TLight::JSGSetDistanceAttenuation": 0x803371a4,
		"JSGSetDistanceAttenuation": 0x803371a4,
		"JStage::TLight::JSGGetAngleAttenuation": 0x803371a8,
		"JSGGetAngleAttenuation": 0x803371a8,
		"JStage::TLight::JSGSetAngleAttenuation": 0x803371ac,
		"JSGSetAngleAttenuation": 0x803371ac,
		"JStage::TLight::JSGGetPosition": 0x803371b0,
		"JStage::TLight::JSGSetPosition": 0x803371b4,
		"JStage::TLight::JSGGetDirection": 0x803371b8,
		"JSGGetDirection": 0x803371b8,
		"JStage::TLight::JSGSetDirection": 0x803371bc,
		"JSGSetDirection": 0x803371bc,
		"JStage::TObject::~TObject": 0x803371c0,
		"JStage::TObject::JSGGetName": 0x8033720c,
		"JSGGetName": 0x8033720c,
		"JStage::TObject::JSGGetFlag": 0x80337214,
		"JStage::TObject::JSGSetFlag": 0x8033721c,
		"JStage::TObject::JSGGetData": 0x80337220,
		"JSGGetData": 0x80337220,
		"JStage::TObject::JSGSetData": 0x80337228,
		"JSGSetData": 0x80337228,
		"JStage::TObject::JSGGetParent": 0x8033722c,
		"JSGGetParent": 0x8033722c,
		"JStage::TObject::JSGSetParent": 0x80337230,
		"JSGSetParent": 0x80337230,
		"JStage::TObject::JSGSetRelation": 0x80337234,
		"JSGSetRelation": 0x80337234,
		"JStage::TSystem::~TSystem": 0x80337238,
		"JStage::TSystem::JSGFGetType": 0x8033729c,
		"JStage::TSystem::JSGFindObject": 0x803372a4,
		"JStage::TSystem::JSGCreateObject": 0x803372ac,
		"JSGCreateObject": 0x803372ac,
		"JStage::TSystem::JSGDestroyObject": 0x803372b4,
		"JSGDestroyObject": 0x803372b4,
		"JStage::TSystem::JSGGetSystemData": 0x803372b8,
		"JSGGetSystemData": 0x803372b8,
		"JStage::TSystem::JSGSetSystemData": 0x803372c0,
		"JSGSetSystemData": 0x803372c0,
		"Runtime.PPCEABI.H::__va_arg": 0x80337ccc,
		"__va_arg": 0x80337ccc,
		"Runtime.PPCEABI.H::__destroy_global_chain": 0x80337dc0,
		"__destroy_global_chain": 0x80337dc0,
		"Runtime.PPCEABI.H::__register_global_object": 0x80337e08,
		"__register_global_object": 0x80337e08,
		"Runtime.PPCEABI.H::__destroy_new_array": 0x80337e20,
		"__destroy_new_array": 0x80337e20,
		"Runtime.PPCEABI.H::__destroy_arr": 0x80337e9c,
		"__destroy_arr": 0x80337e9c,
		"Runtime.PPCEABI.H::__construct_array": 0x80337f14,
		"__construct_array": 0x80337f14,
		"__partial_array_destructor::~__partial_array_destructor": 0x80338014,
		"Runtime.PPCEABI.H::__construct_new_array": 0x803380cc,
		"__construct_new_array": 0x803380cc,
		"Runtime.PPCEABI.H::__ptmf_test": 0x803381d4,
		"__ptmf_test": 0x803381d4,
		"Runtime.PPCEABI.H::__ptmf_scall": 0x80338204,
		"__ptmf_scall": 0x80338204,
		"Runtime.PPCEABI.H::__unregister_fragment": 0x8033822c,
		"__unregister_fragment": 0x8033822c,
		"Runtime.PPCEABI.H::__register_fragment": 0x80338260,
		"__register_fragment": 0x80338260,
		"Runtime.PPCEABI.H::__cvt_fp2unsigned": 0x8033829c,
		"__cvt_fp2unsigned": 0x8033829c,
		"Runtime.PPCEABI.H::__div2u": 0x803382f8,
		"__div2u": 0x803382f8,
		"Runtime.PPCEABI.H::__div2i": 0x803383e4,
		"__div2i": 0x803383e4,
		"Runtime.PPCEABI.H::__mod2u": 0x8033851c,
		"__mod2u": 0x8033851c,
		"Runtime.PPCEABI.H::__mod2i": 0x80338600,
		"__mod2i": 0x80338600,
		"Runtime.PPCEABI.H::__shl2i": 0x8033870c,
		"__shl2i": 0x8033870c,
		"Runtime.PPCEABI.H::__shr2u": 0x80338730,
		"__shr2u": 0x80338730,
		"Runtime.PPCEABI.H::__shr2i": 0x80338754,
		"__shr2i": 0x80338754,
		"Runtime.PPCEABI.H::__cvt_sll_flt": 0x8033877c,
		"__cvt_sll_flt": 0x8033877c,
		"Runtime.PPCEABI.H::__cvt_dbl_usll": 0x80338830,
		"__cvt_dbl_usll": 0x80338830,
		"Runtime.PPCEABI.H::GetR2": 0x803388fc,
		"GetR2": 0x803388fc,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions": 0x80338904,
		"__fini_cpp_exceptions": 0x80338904,
		"Runtime.PPCEABI.H::__init_cpp_exceptions": 0x80338938,
		"__init_cpp_exceptions": 0x80338938,
		"MSL_C.PPCEABI.bare.H::exit": 0x80338978,
		"exit": 0x80338978,
		"MSL_C.PPCEABI.bare.H::__num2dec": 0x80338a84,
		"__num2dec": 0x80338a84,
		"MSL_C.PPCEABI.bare.H::__flush_buffer": 0x80338e38,
		"__flush_buffer": 0x80338e38,
		"MSL_C.PPCEABI.bare.H::__prep_buffer": 0x80338f04,
		"__prep_buffer": 0x80338f04,
		"MSL_C.PPCEABI.bare.H::__kill_critical_regions": 0x80338f38,
		"__kill_critical_regions": 0x80338f38,
		"MSL_C.PPCEABI.bare.H::toupper": 0x80338f3c,
		"toupper": 0x80338f3c,
		"MSL_C.PPCEABI.bare.H::tolower": 0x80338f64,
		"tolower": 0x80338f64,
		"MSL_C.PPCEABI.bare.H::fwrite": 0x80338f8c,
		"fwrite": 0x80338f8c,
		"MSL_C.PPCEABI.bare.H::wcstombs": 0x80339268,
		"wcstombs": 0x80339268,
		"MSL_C.PPCEABI.bare.H::memcmp": 0x803392a4,
		"memcmp": 0x803392a4,
		"MSL_C.PPCEABI.bare.H::memchr": 0x803392e8,
		"memchr": 0x803392e8,
		"MSL_C.PPCEABI.bare.H::memmove": 0x80339314,
		"memmove": 0x80339314,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_unaligned": 0x803393f0,
		"__copy_longs_rev_unaligned": 0x803393f0,
		"MSL_C.PPCEABI.bare.H::__copy_longs_unaligned": 0x803394a0,
		"__copy_longs_unaligned": 0x803394a0,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_aligned": 0x80339564,
		"__copy_longs_rev_aligned": 0x80339564,
		"MSL_C.PPCEABI.bare.H::__copy_longs_aligned": 0x80339610,
		"__copy_longs_aligned": 0x80339610,
		"MSL_C.PPCEABI.bare.H::__stdio_atexit": 0x803396cc,
		"__stdio_atexit": 0x803396cc,
		"MSL_C.PPCEABI.bare.H::sprintf": 0x803396d0,
		"sprintf": 0x803396d0,
		"MSL_C.PPCEABI.bare.H::snprintf": 0x803397a4,
		"snprintf": 0x803397a4,
		"MSL_C.PPCEABI.bare.H::vsnprintf": 0x80339874,
		"vsnprintf": 0x80339874,
		"MSL_C.PPCEABI.bare.H::vprintf": 0x803398e4,
		"vprintf": 0x803398e4,
		"MSL_C.PPCEABI.bare.H::__StringWrite": 0x80339960,
		"__StringWrite": 0x80339960,
		"MSL_C.PPCEABI.bare.H::__FileWrite": 0x803399cc,
		"__FileWrite": 0x803399cc,
		"MSL_C.PPCEABI.bare.H::__pformatter": 0x80339a24,
		"__pformatter": 0x80339a24,
		"MSL_C.PPCEABI.bare.H::float2str": 0x8033a054,
		"float2str": 0x8033a054,
		"MSL_C.PPCEABI.bare.H::round_decimal": 0x8033a68c,
		"round_decimal": 0x8033a68c,
		"MSL_C.PPCEABI.bare.H::longlong2str": 0x8033a7c0,
		"longlong2str": 0x8033a7c0,
		"MSL_C.PPCEABI.bare.H::long2str": 0x8033aaa0,
		"long2str": 0x8033aaa0,
		"MSL_C.PPCEABI.bare.H::parse_format": 0x8033acc4,
		"parse_format": 0x8033acc4,
		"MSL_C.PPCEABI.bare.H::srand": 0x8033b19c,
		"srand": 0x8033b19c,
		"MSL_C.PPCEABI.bare.H::rand": 0x8033b1a4,
		"rand": 0x8033b1a4,
		"MSL_C.PPCEABI.bare.H::__StringRead": 0x8033b1c8,
		"__StringRead": 0x8033b1c8,
		"MSL_C.PPCEABI.bare.H::strstr": 0x8033b258,
		"strstr": 0x8033b258,
		"MSL_C.PPCEABI.bare.H::strrchr": 0x8033b2c4,
		"strrchr": 0x8033b2c4,
		"MSL_C.PPCEABI.bare.H::strchr": 0x8033b30c,
		"strchr": 0x8033b30c,
		"MSL_C.PPCEABI.bare.H::strcmp": 0x8033b33c,
		"strcmp": 0x8033b33c,
		"MSL_C.PPCEABI.bare.H::strcat": 0x8033b460,
		"strcat": 0x8033b460,
		"MSL_C.PPCEABI.bare.H::strncpy": 0x8033b48c,
		"strncpy": 0x8033b48c,
		"MSL_C.PPCEABI.bare.H::strcpy": 0x8033b4d0,
		"strcpy": 0x8033b4d0,
		"MSL_C.PPCEABI.bare.H::strlen": 0x8033b584,
		"strlen": 0x8033b584,
		"MSL_C.PPCEABI.bare.H::strtol": 0x8033b5a4,
		"strtol": 0x8033b5a4,
		"MSL_C.PPCEABI.bare.H::strtoul": 0x8033b694,
		"strtoul": 0x8033b694,
		"MSL_C.PPCEABI.bare.H::__strtoul": 0x8033b740,
		"__strtoul": 0x8033b740,
		"MSL_C.PPCEABI.bare.H::__close_console": 0x8033ba88,
		"__close_console": 0x8033ba88,
		"MSL_C.PPCEABI.bare.H::__write_console": 0x8033ba90,
		"__write_console": 0x8033ba90,
		"MSL_C.PPCEABI.bare.H::__read_console": 0x8033bb28,
		"__read_console": 0x8033bb28,
		"MSL_C.PPCEABI.bare.H::fwide": 0x8033bc08,
		"fwide": 0x8033bc08,
		"MSL_C.PPCEABI.bare.H::fabs": 0x8033bc88,
		"fabs": 0x8033bc88,
		"MSL_C.PPCEABI.bare.H::__ieee754_atan2": 0x8033bc90,
		"__ieee754_atan2": 0x8033bc90,
		"MSL_C.PPCEABI.bare.H::frexp": 0x8033c168,
		"frexp": 0x8033c168,
		"MSL_C.PPCEABI.bare.H::atan2": 0x8033c204,
		"atan2": 0x8033c204,
		"MSL_C.PPCEABI.bare.H::fabsf": 0x8033c224,
		"fabsf": 0x8033c224,
		"MSL_C.PPCEABI.bare.H::atanf": 0x8033c22c,
		"atanf": 0x8033c22c,
		"MSL_C.PPCEABI.bare.H::_inv_sqrtf": 0x8033c440,
		"_inv_sqrtf": 0x8033c440,
		"MSL_C.PPCEABI.bare.H::acosf": 0x8033c4b0,
		"acosf": 0x8033c4b0,
		"MSL_C.PPCEABI.bare.H::atan2f": 0x8033c4f4,
		"atan2f": 0x8033c4f4,
		"MSL_C.PPCEABI.bare.H::tanf": 0x8033c5cc,
		"tanf": 0x8033c5cc,
		"MSL_C.PPCEABI.bare.H::cos": 0x8033c610,
		"cos": 0x8033c610,
		"MSL_C.PPCEABI.bare.H::sin": 0x8033c630,
		"sin": 0x8033c630,
		"MSL_C.PPCEABI.bare.H::cosf": 0x8033c650,
		"cosf": 0x8033c650,
		"MSL_C.PPCEABI.bare.H::sinf": 0x8033c7e4,
		"sinf": 0x8033c7e4,
		"MSL_C.PPCEABI.bare.H::__sinit_trigf_c": 0x8033c988,
		"__sinit_trigf_c": 0x8033c988,
		"MSL_C.PPCEABI.bare.H::powf": 0x8033c9b8,
		"powf": 0x8033c9b8,
		"MSL_C.PPCEABI.bare.H::expf": 0x8033d0f8,
		"expf": 0x8033d0f8,
		"TRK_MINNOW_DOLPHIN::TRKHandleRequestEvent": 0x8033d1e0,
		"TRKHandleRequestEvent": 0x8033d1e0,
		"TRK_MINNOW_DOLPHIN::TRKHandleSupportEvent": 0x8033d208,
		"TRKHandleSupportEvent": 0x8033d208,
		"TRK_MINNOW_DOLPHIN::TRKIdle": 0x8033d228,
		"TRKIdle": 0x8033d228,
		"TRK_MINNOW_DOLPHIN::TRKNubMainLoop": 0x8033d254,
		"TRKNubMainLoop": 0x8033d254,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEventQueue": 0x8033d348,
		"TRKInitializeEventQueue": 0x8033d348,
		"TRK_MINNOW_DOLPHIN::TRKCopyEvent": 0x8033d3a4,
		"TRKCopyEvent": 0x8033d3a4,
		"TRK_MINNOW_DOLPHIN::TRKGetNextEvent": 0x8033d3c8,
		"TRKGetNextEvent": 0x8033d3c8,
		"TRK_MINNOW_DOLPHIN::TRKPostEvent": 0x8033d488,
		"TRKPostEvent": 0x8033d488,
		"TRK_MINNOW_DOLPHIN::TRKConstructEvent": 0x8033d568,
		"TRKConstructEvent": 0x8033d568,
		"TRK_MINNOW_DOLPHIN::TRKDestructEvent": 0x8033d580,
		"TRKDestructEvent": 0x8033d580,
		"TRK_MINNOW_DOLPHIN::TRKInitializeNub": 0x8033d5a4,
		"TRKInitializeNub": 0x8033d5a4,
		"TRK_MINNOW_DOLPHIN::TRKTerminateNub": 0x8033d678,
		"TRKTerminateNub": 0x8033d678,
		"TRK_MINNOW_DOLPHIN::TRKNubWelcome": 0x8033d69c,
		"TRKNubWelcome": 0x8033d69c,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEndian": 0x8033d6c4,
		"TRKInitializeEndian": 0x8033d6c4,
		"TRK_MINNOW_DOLPHIN::TRKMessageSend": 0x8033d738,
		"TRKMessageSend": 0x8033d738,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferUsed": 0x8033d760,
		"TRKSetBufferUsed": 0x8033d760,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMessageBuffers": 0x8033d768,
		"TRKInitializeMessageBuffers": 0x8033d768,
		"TRK_MINNOW_DOLPHIN::TRKGetFreeBuffer": 0x8033d7e0,
		"TRKGetFreeBuffer": 0x8033d7e0,
		"TRK_MINNOW_DOLPHIN::TRKGetBuffer": 0x8033d87c,
		"TRKGetBuffer": 0x8033d87c,
		"TRK_MINNOW_DOLPHIN::TRKReleaseBuffer": 0x8033d8a8,
		"TRKReleaseBuffer": 0x8033d8a8,
		"TRK_MINNOW_DOLPHIN::TRKResetBuffer": 0x8033d910,
		"TRKResetBuffer": 0x8033d910,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferPosition": 0x8033d950,
		"TRKSetBufferPosition": 0x8033d950,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer": 0x8033d980,
		"TRKAppendBuffer": 0x8033d980,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer": 0x8033da24,
		"TRKReadBuffer": 0x8033da24,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui16": 0x8033dab0,
		"TRKAppendBuffer1_ui16": 0x8033dab0,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui32": 0x8033db04,
		"TRKAppendBuffer1_ui32": 0x8033db04,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui64": 0x8033db68,
		"TRKAppendBuffer1_ui64": 0x8033db68,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui8": 0x8033dbf0,
		"TRKAppendBuffer_ui8": 0x8033dbf0,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui32": 0x8033dc58,
		"TRKAppendBuffer_ui32": 0x8033dc58,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui8": 0x8033dcd4,
		"TRKReadBuffer1_ui8": 0x8033dcd4,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui16": 0x8033dcf8,
		"TRKReadBuffer1_ui16": 0x8033dcf8,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui32": 0x8033dd78,
		"TRKReadBuffer1_ui32": 0x8033dd78,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui64": 0x8033de08,
		"TRKReadBuffer1_ui64": 0x8033de08,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui8": 0x8033deb8,
		"TRKReadBuffer_ui8": 0x8033deb8,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui32": 0x8033df2c,
		"TRKReadBuffer_ui32": 0x8033df2c,
		"TRK_MINNOW_DOLPHIN::TRKTestForPacket": 0x8033dfa8,
		"TRKTestForPacket": 0x8033dfa8,
		"TRK_MINNOW_DOLPHIN::TRKGetInput": 0x8033e078,
		"TRKGetInput": 0x8033e078,
		"TRK_MINNOW_DOLPHIN::TRKProcessInput": 0x8033e0f4,
		"TRKProcessInput": 0x8033e0f4,
		"TRK_MINNOW_DOLPHIN::TRKInitializeSerialHandler": 0x8033e144,
		"TRKInitializeSerialHandler": 0x8033e144,
		"TRK_MINNOW_DOLPHIN::TRKTerminateSerialHandler": 0x8033e168,
		"TRKTerminateSerialHandler": 0x8033e168,
		"TRK_MINNOW_DOLPHIN::usr_put_initialize": 0x8033e170,
		"usr_put_initialize": 0x8033e170,
		"TRK_MINNOW_DOLPHIN::TRKInitializeDispatcher": 0x8033e174,
		"TRKInitializeDispatcher": 0x8033e174,
		"TRK_MINNOW_DOLPHIN::TRKDispatchMessage": 0x8033e188,
		"TRKDispatchMessage": 0x8033e188,
		"TRK_MINNOW_DOLPHIN::TRKMessageIntoReply": 0x8033e20c,
		"TRKMessageIntoReply": 0x8033e20c,
		"TRK_MINNOW_DOLPHIN::TRKSendACK": 0x8033e2a4,
		"TRKSendACK": 0x8033e2a4,
		"TRK_MINNOW_DOLPHIN::TRKStandardACK": 0x8033e2f4,
		"TRKStandardACK": 0x8033e2f4,
		"TRK_MINNOW_DOLPHIN::TRKDoUnsupported": 0x8033e328,
		"TRKDoUnsupported": 0x8033e328,
		"TRK_MINNOW_DOLPHIN::TRKDoConnect": 0x8033e350,
		"TRKDoConnect": 0x8033e350,
		"TRK_MINNOW_DOLPHIN::TRKDoDisconnect": 0x8033e378,
		"TRKDoDisconnect": 0x8033e378,
		"TRK_MINNOW_DOLPHIN::TRKDoReset": 0x8033e3c8,
		"TRKDoReset": 0x8033e3c8,
		"TRK_MINNOW_DOLPHIN::TRKDoVersions": 0x8033e3f8,
		"TRKDoVersions": 0x8033e3f8,
		"TRK_MINNOW_DOLPHIN::TRKDoSupportMask": 0x8033e57c,
		"TRKDoSupportMask": 0x8033e57c,
		"TRK_MINNOW_DOLPHIN::TRKDoCPUType": 0x8033e658,
		"TRKDoCPUType": 0x8033e658,
		"TRK_MINNOW_DOLPHIN::TRKDoReadMemory": 0x8033e89c,
		"TRKDoReadMemory": 0x8033e89c,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteMemory": 0x8033ea84,
		"TRKDoWriteMemory": 0x8033ea84,
		"TRK_MINNOW_DOLPHIN::TRKDoReadRegisters": 0x8033ec80,
		"TRKDoReadRegisters": 0x8033ec80,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteRegisters": 0x8033ee84,
		"TRKDoWriteRegisters": 0x8033ee84,
		"TRK_MINNOW_DOLPHIN::TRKDoFlushCache": 0x8033f08c,
		"TRKDoFlushCache": 0x8033f08c,
		"TRK_MINNOW_DOLPHIN::TRKDoContinue": 0x8033f1c4,
		"TRKDoContinue": 0x8033f1c4,
		"TRK_MINNOW_DOLPHIN::TRKDoStep": 0x8033f228,
		"TRKDoStep": 0x8033f228,
		"TRK_MINNOW_DOLPHIN::TRKDoStop": 0x8033f42c,
		"TRKDoStop": 0x8033f42c,
		"TRK_MINNOW_DOLPHIN::TRKSuppAccessFile": 0x8033f4b0,
		"TRKSuppAccessFile": 0x8033f4b0,
		"TRK_MINNOW_DOLPHIN::TRKRequestSend": 0x8033f788,
		"TRKRequestSend": 0x8033f788,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMutex": 0x8033f92c,
		"TRKInitializeMutex": 0x8033f92c,
		"TRK_MINNOW_DOLPHIN::TRKAcquireMutex": 0x8033f934,
		"TRKAcquireMutex": 0x8033f934,
		"TRK_MINNOW_DOLPHIN::TRKReleaseMutex": 0x8033f93c,
		"TRKReleaseMutex": 0x8033f93c,
		"TRK_MINNOW_DOLPHIN::TRKDoNotifyStopped": 0x8033f944,
		"TRKDoNotifyStopped": 0x8033f944,
		"TRK_MINNOW_DOLPHIN::TRK_flush_cache": 0x8033fa1c,
		"TRK_flush_cache": 0x8033fa1c,
		"TRK_MINNOW_DOLPHIN::TRK_fill_mem": 0x8033fa54,
		"TRK_fill_mem": 0x8033fa54,
		"TRK_MINNOW_DOLPHIN::__TRK_get_MSR": 0x8033fb18,
		"__TRK_get_MSR": 0x8033fb18,
		"TRK_MINNOW_DOLPHIN::__TRK_set_MSR": 0x8033fb20,
		"__TRK_set_MSR": 0x8033fb20,
		"TRK_MINNOW_DOLPHIN::TRKValidMemory32": 0x8033fb28,
		"TRKValidMemory32": 0x8033fb28,
		"TRK_MINNOW_DOLPHIN::TRK_ppc_memcpy": 0x8033fc60,
		"TRK_ppc_memcpy": 0x8033fc60,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessMemory": 0x8033fc9c,
		"TRKTargetAccessMemory": 0x8033fc9c,
		"TRK_MINNOW_DOLPHIN::TRKTargetReadInstruction": 0x8033fe00,
		"TRKTargetReadInstruction": 0x8033fe00,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessDefault": 0x8033fe4c,
		"TRKTargetAccessDefault": 0x8033fe4c,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessFP": 0x8033ff48,
		"TRKTargetAccessFP": 0x8033ff48,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended1": 0x80340090,
		"TRKTargetAccessExtended1": 0x80340090,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended2": 0x80340208,
		"TRKTargetAccessExtended2": 0x80340208,
		"TRK_MINNOW_DOLPHIN::TRKTargetVersions": 0x80340384,
		"TRKTargetVersions": 0x80340384,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportMask": 0x803403ac,
		"TRKTargetSupportMask": 0x803403ac,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUType": 0x80340450,
		"TRKTargetCPUType": 0x80340450,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandler": 0x803404b8,
		"TRKInterruptHandler": 0x803404b8,
		"TRK_MINNOW_DOLPHIN::TRKExceptionHandler": 0x8034064c,
		"TRKExceptionHandler": 0x8034064c,
		"TRK_MINNOW_DOLPHIN::TRKPostInterruptEvent": 0x803406e8,
		"TRKPostInterruptEvent": 0x803406e8,
		"TRK_MINNOW_DOLPHIN::TRKSwapAndGo": 0x80340798,
		"TRKSwapAndGo": 0x80340798,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandlerEnableInterrupts": 0x8034085c,
		"TRKInterruptHandlerEnableInterrupts": 0x8034085c,
		"TRK_MINNOW_DOLPHIN::TRKTargetInterrupt": 0x803408b0,
		"TRKTargetInterrupt": 0x803408b0,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddStopInfo": 0x80340914,
		"TRKTargetAddStopInfo": 0x80340914,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddExceptionInfo": 0x803409a4,
		"TRKTargetAddExceptionInfo": 0x803409a4,
		"TRK_MINNOW_DOLPHIN::TRKTargetEnableTrace": 0x80340a2c,
		"TRKTargetEnableTrace": 0x80340a2c,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepDone": 0x80340a68,
		"TRKTargetStepDone": 0x80340a68,
		"TRK_MINNOW_DOLPHIN::TRKTargetDoStep": 0x80340aec,
		"TRKTargetDoStep": 0x80340aec,
		"TRK_MINNOW_DOLPHIN::TRKTargetCheckStep": 0x80340b5c,
		"TRKTargetCheckStep": 0x80340b5c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSingleStep": 0x80340bc4,
		"TRKTargetSingleStep": 0x80340bc4,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepOutOfRange": 0x80340c08,
		"TRKTargetStepOutOfRange": 0x80340c08,
		"TRK_MINNOW_DOLPHIN::TRKTargetGetPC": 0x80340c50,
		"TRKTargetGetPC": 0x80340c50,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportRequest": 0x80340c60,
		"TRKTargetSupportRequest": 0x80340c60,
		"TRK_MINNOW_DOLPHIN::TRKTargetFlushCache": 0x80340d50,
		"TRKTargetFlushCache": 0x80340d50,
		"TRK_MINNOW_DOLPHIN::TRKTargetStopped": 0x80340d8c,
		"TRKTargetStopped": 0x80340d8c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetStopped": 0x80340d9c,
		"TRKTargetSetStopped": 0x80340d9c,
		"TRK_MINNOW_DOLPHIN::TRKTargetStop": 0x80340dac,
		"TRKTargetStop": 0x80340dac,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSPR": 0x80340dd4,
		"TRKPPCAccessSPR": 0x80340dd4,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessPairedSingleRegister": 0x80340e84,
		"TRKPPCAccessPairedSingleRegister": 0x80340e84,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessFPRegister": 0x80340efc,
		"TRKPPCAccessFPRegister": 0x80340efc,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSpecialReg": 0x8034107c,
		"TRKPPCAccessSpecialReg": 0x8034107c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetInputPendingPtr": 0x803410e4,
		"TRKTargetSetInputPendingPtr": 0x803410e4,
		"TRK_MINNOW_DOLPHIN::InitMetroTRK": 0x803410f4,
		"InitMetroTRK": 0x803410f4,
		"TRK_MINNOW_DOLPHIN::EnableMetroTRKInterrupts": 0x80341188,
		"EnableMetroTRKInterrupts": 0x80341188,
		"TRK_MINNOW_DOLPHIN::TRKTargetTranslate": 0x803411a8,
		"TRKTargetTranslate": 0x803411a8,
		"TRK_MINNOW_DOLPHIN::TRK_copy_vector": 0x803411f0,
		"TRK_copy_vector": 0x803411f0,
		"TRK_MINNOW_DOLPHIN::__TRK_copy_vectors": 0x80341250,
		"__TRK_copy_vectors": 0x80341250,
		"TRK_MINNOW_DOLPHIN::TRKInitializeTarget": 0x803412e4,
		"TRKInitializeTarget": 0x803412e4,
		"TRK_MINNOW_DOLPHIN::TRKSaveExtended1Block": 0x80341334,
		"TRKSaveExtended1Block": 0x80341334,
		"TRK_MINNOW_DOLPHIN::TRKRestoreExtended1Block": 0x803414ec,
		"TRKRestoreExtended1Block": 0x803414ec,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUMinorType": 0x803416a4,
		"TRKTargetCPUMinorType": 0x803416a4,
		"TRK_MINNOW_DOLPHIN::TRK_main": 0x803416ac,
		"TRK_main": 0x803416ac,
		"TRK_MINNOW_DOLPHIN::TRKLoadContext": 0x803416f4,
		"TRKLoadContext": 0x803416f4,
		"TRK_MINNOW_DOLPHIN::TRKEXICallBack": 0x8034177c,
		"TRKEXICallBack": 0x8034177c,
		"TRK_MINNOW_DOLPHIN::InitMetroTRKCommTable": 0x803417b4,
		"InitMetroTRKCommTable": 0x803417b4,
		"TRK_MINNOW_DOLPHIN::TRKUARTInterruptHandler": 0x8034189c,
		"TRKUARTInterruptHandler": 0x8034189c,
		"TRK_MINNOW_DOLPHIN::TRKInitializeIntDrivenUART": 0x803418a0,
		"TRKInitializeIntDrivenUART": 0x803418a0,
		"TRK_MINNOW_DOLPHIN::EnableEXI2Interrupts": 0x803418e0,
		"EnableEXI2Interrupts": 0x803418e0,
		"TRK_MINNOW_DOLPHIN::TRKPollUART": 0x80341910,
		"TRKPollUART": 0x80341910,
		"TRK_MINNOW_DOLPHIN::TRKReadUARTN": 0x80341940,
		"TRKReadUARTN": 0x80341940,
		"TRK_MINNOW_DOLPHIN::TRKWriteUARTN": 0x80341984,
		"TRKWriteUARTN": 0x80341984,
		"TRK_MINNOW_DOLPHIN::ReserveEXI2Port": 0x803419c8,
		"ReserveEXI2Port": 0x803419c8,
		"TRK_MINNOW_DOLPHIN::UnreserveEXI2Port": 0x803419f8,
		"UnreserveEXI2Port": 0x803419f8,
		"TRK_MINNOW_DOLPHIN::TRK_board_display": 0x80341a28,
		"TRK_board_display": 0x80341a28,
		"TRK_MINNOW_DOLPHIN::TRKTargetContinue": 0x80341a4c,
		"TRKTargetContinue": 0x80341a4c,
		"base::PPCMfmsr": 0x80341a80,
		"PPCMfmsr": 0x80341a80,
		"base::PPCMtmsr": 0x80341a88,
		"PPCMtmsr": 0x80341a88,
		"base::PPCMfhid0": 0x80341a90,
		"PPCMfhid0": 0x80341a90,
		"base::PPCMthid0": 0x80341a98,
		"PPCMthid0": 0x80341a98,
		"base::PPCMfl2cr": 0x80341aa0,
		"PPCMfl2cr": 0x80341aa0,
		"base::PPCMtl2cr": 0x80341aa8,
		"PPCMtl2cr": 0x80341aa8,
		"base::PPCMtdec": 0x80341ab0,
		"PPCMtdec": 0x80341ab0,
		"base::PPCSync": 0x80341ab8,
		"PPCSync": 0x80341ab8,
		"base::PPCHalt": 0x80341ac0,
		"PPCHalt": 0x80341ac0,
		"base::PPCMfhid2": 0x80341ad4,
		"PPCMfhid2": 0x80341ad4,
		"base::PPCMthid2": 0x80341adc,
		"PPCMthid2": 0x80341adc,
		"base::PPCMtwpar": 0x80341ae4,
		"PPCMtwpar": 0x80341ae4,
		"base::PPCDisableSpeculation": 0x80341aec,
		"PPCDisableSpeculation": 0x80341aec,
		"base::PPCSetFpNonIEEEMode": 0x80341b14,
		"PPCSetFpNonIEEEMode": 0x80341b14,
		"db::DBInit": 0x80341b1c,
		"DBInit": 0x80341b1c,
		"db::__DBExceptionDestinationAux": 0x80341b44,
		"__DBExceptionDestinationAux": 0x80341b44,
		"db::__DBExceptionDestination": 0x80341b8c,
		"__DBExceptionDestination": 0x80341b8c,
		"db::__DBIsExceptionMarked": 0x80341b9c,
		"__DBIsExceptionMarked": 0x80341b9c,
		"db::DBPrintf": 0x80341bb8,
		"DBPrintf": 0x80341bb8,
		"os::OSGetConsoleType": 0x80341c08,
		"OSGetConsoleType": 0x80341c08,
		"os::ClearArena": 0x80341c30,
		"ClearArena": 0x80341c30,
		"os::InquiryCallback": 0x80341d58,
		"InquiryCallback": 0x80341d58,
		"os::OSInit": 0x80341d94,
		"OSInit": 0x80341d94,
		"os::OSExceptionInit": 0x8034214c,
		"OSExceptionInit": 0x8034214c,
		"os::__OSDBIntegrator": 0x803423cc,
		"__OSDBIntegrator": 0x803423cc,
		"os::__OSDBJump": 0x803423f0,
		"__OSDBJump": 0x803423f0,
		"os::__OSSetExceptionHandler": 0x803423f4,
		"__OSSetExceptionHandler": 0x803423f4,
		"os::__OSGetExceptionHandler": 0x80342410,
		"__OSGetExceptionHandler": 0x80342410,
		"os::OSExceptionVector": 0x80342424,
		"OSExceptionVector": 0x80342424,
		"os::OSDefaultExceptionHandler": 0x803424c0,
		"OSDefaultExceptionHandler": 0x803424c0,
		"os::__OSPSInit": 0x80342518,
		"__OSPSInit": 0x80342518,
		"os::__OSGetDIConfig": 0x80342550,
		"__OSGetDIConfig": 0x80342550,
		"os::OSInitAlarm": 0x80342564,
		"OSInitAlarm": 0x80342564,
		"os::OSCreateAlarm": 0x803425b0,
		"OSCreateAlarm": 0x803425b0,
		"os::InsertAlarm": 0x803425bc,
		"InsertAlarm": 0x803425bc,
		"os::OSSetAlarm": 0x8034280c,
		"OSSetAlarm": 0x8034280c,
		"os::OSCancelAlarm": 0x80342874,
		"OSCancelAlarm": 0x80342874,
		"os::DecrementerExceptionCallback": 0x80342990,
		"DecrementerExceptionCallback": 0x80342990,
		"os::DecrementerExceptionHandler": 0x80342bc0,
		"DecrementerExceptionHandler": 0x80342bc0,
		"os::DLInsert": 0x80342c10,
		"DLInsert": 0x80342c10,
		"os::OSAllocFromHeap": 0x80342cbc,
		"OSAllocFromHeap": 0x80342cbc,
		"os::OSFreeToHeap": 0x80342db8,
		"OSFreeToHeap": 0x80342db8,
		"os::OSInitAlloc": 0x80342e34,
		"OSInitAlloc": 0x80342e34,
		"os::OSCreateHeap": 0x80342ea4,
		"OSCreateHeap": 0x80342ea4,
		"os::OSDestroyHeap": 0x80342f10,
		"OSDestroyHeap": 0x80342f10,
		"os::OSCheckHeap": 0x80342f24,
		"OSCheckHeap": 0x80342f24,
		"os::OSReferentSize": 0x80343284,
		"OSReferentSize": 0x80343284,
		"os::OSDumpHeap": 0x80343290,
		"OSDumpHeap": 0x80343290,
		"os::OSGetArenaHi": 0x80343394,
		"OSGetArenaHi": 0x80343394,
		"os::OSGetArenaLo": 0x8034339c,
		"OSGetArenaLo": 0x8034339c,
		"os::OSSetArenaHi": 0x803433a4,
		"OSSetArenaHi": 0x803433a4,
		"os::OSSetArenaLo": 0x803433ac,
		"OSSetArenaLo": 0x803433ac,
		"os::__OSInitAudioSystem": 0x803433b4,
		"__OSInitAudioSystem": 0x803433b4,
		"os::__OSStopAudioSystem": 0x80343570,
		"__OSStopAudioSystem": 0x80343570,
		"os::DCEnable": 0x80343648,
		"DCEnable": 0x80343648,
		"os::DCInvalidateRange": 0x8034365c,
		"DCInvalidateRange": 0x8034365c,
		"os::DCFlushRange": 0x8034368c,
		"DCFlushRange": 0x8034368c,
		"os::DCStoreRange": 0x803436c0,
		"DCStoreRange": 0x803436c0,
		"os::DCFlushRangeNoSync": 0x803436f4,
		"DCFlushRangeNoSync": 0x803436f4,
		"os::DCZeroRange": 0x80343724,
		"DCZeroRange": 0x80343724,
		"os::ICInvalidateRange": 0x80343754,
		"ICInvalidateRange": 0x80343754,
		"os::ICFlashInvalidate": 0x8034378c,
		"ICFlashInvalidate": 0x8034378c,
		"os::ICEnable": 0x8034379c,
		"ICEnable": 0x8034379c,
		"os::__LCEnable": 0x803437b0,
		"__LCEnable": 0x803437b0,
		"os::LCEnable": 0x8034387c,
		"LCEnable": 0x8034387c,
		"os::LCDisable": 0x803438b4,
		"LCDisable": 0x803438b4,
		"os::LCStoreBlocks": 0x803438dc,
		"LCStoreBlocks": 0x803438dc,
		"os::LCStoreData": 0x80343900,
		"LCStoreData": 0x80343900,
		"os::LCQueueWait": 0x803439ac,
		"LCQueueWait": 0x803439ac,
		"os::L2GlobalInvalidate": 0x803439c4,
		"L2GlobalInvalidate": 0x803439c4,
		"os::DMAErrorHandler": 0x80343a5c,
		"DMAErrorHandler": 0x80343a5c,
		"os::__OSCacheInit": 0x80343bbc,
		"__OSCacheInit": 0x80343bbc,
		"os::__OSLoadFPUContext": 0x80343cb0,
		"__OSLoadFPUContext": 0x80343cb0,
		"os::__OSSaveFPUContext": 0x80343dd4,
		"__OSSaveFPUContext": 0x80343dd4,
		"os::OSSetCurrentContext": 0x80343efc,
		"OSSetCurrentContext": 0x80343efc,
		"os::OSGetCurrentContext": 0x80343f58,
		"OSGetCurrentContext": 0x80343f58,
		"os::OSSaveContext": 0x80343f64,
		"OSSaveContext": 0x80343f64,
		"os::OSLoadContext": 0x80343fe4,
		"OSLoadContext": 0x80343fe4,
		"os::OSGetStackPointer": 0x803440bc,
		"OSGetStackPointer": 0x803440bc,
		"os::OSClearContext": 0x803440c4,
		"OSClearContext": 0x803440c4,
		"os::OSInitContext": 0x803440e8,
		"OSInitContext": 0x803440e8,
		"os::OSDumpContext": 0x803441a4,
		"OSDumpContext": 0x803441a4,
		"os::OSSwitchFPUContext": 0x8034444c,
		"OSSwitchFPUContext": 0x8034444c,
		"os::__OSContextInit": 0x803444d0,
		"__OSContextInit": 0x803444d0,
		"os::OSFillFPUContext": 0x80344518,
		"OSFillFPUContext": 0x80344518,
		"os::OSReport": 0x80344644,
		"OSReport": 0x80344644,
		"os::OSPanic": 0x803446c4,
		"OSPanic": 0x803446c4,
		"os::OSSetErrorHandler": 0x803447f0,
		"OSSetErrorHandler": 0x803447f0,
		"os::__OSUnhandledException": 0x8034480c,
		"__OSUnhandledException": 0x8034480c,
		"os::GetFontCode": 0x80344a0c,
		"GetFontCode": 0x80344a0c,
		"os::Decode": 0x80344ba8,
		"Decode": 0x80344ba8,
		"os::OSGetFontEncode": 0x80344d1c,
		"OSGetFontEncode": 0x80344d1c,
		"os::ReadROM": 0x80344d74,
		"ReadROM": 0x80344d74,
		"os::OSLoadFont": 0x80344e00,
		"OSLoadFont": 0x80344e00,
		"os::ExpandFontSheet": 0x80345134,
		"ExpandFontSheet": 0x80345134,
		"os::OSInitFont": 0x803454e4,
		"OSInitFont": 0x803454e4,
		"os::OSGetFontTexture": 0x803455c4,
		"OSGetFontTexture": 0x803455c4,
		"os::OSGetFontWidth": 0x8034576c,
		"OSGetFontWidth": 0x8034576c,
		"os::OSDisableInterrupts": 0x803458ac,
		"OSDisableInterrupts": 0x803458ac,
		"os::OSEnableInterrupts": 0x803458c0,
		"OSEnableInterrupts": 0x803458c0,
		"os::OSRestoreInterrupts": 0x803458d4,
		"OSRestoreInterrupts": 0x803458d4,
		"os::__OSSetInterruptHandler": 0x803458f8,
		"__OSSetInterruptHandler": 0x803458f8,
		"os::__OSGetInterruptHandler": 0x80345914,
		"__OSGetInterruptHandler": 0x80345914,
		"os::__OSInterruptInit": 0x80345928,
		"__OSInterruptInit": 0x80345928,
		"os::SetInterruptMask": 0x8034599c,
		"SetInterruptMask": 0x8034599c,
		"os::__OSMaskInterrupts": 0x80345c74,
		"__OSMaskInterrupts": 0x80345c74,
		"os::__OSUnmaskInterrupts": 0x80345cfc,
		"__OSUnmaskInterrupts": 0x80345cfc,
		"os::__OSDispatchInterrupt": 0x80345d84,
		"__OSDispatchInterrupt": 0x80345d84,
		"os::ExternalInterruptHandler": 0x803460c8,
		"ExternalInterruptHandler": 0x803460c8,
		"os::__OSModuleInit": 0x80346118,
		"__OSModuleInit": 0x80346118,
		"os::OSInitMessageQueue": 0x80346130,
		"OSInitMessageQueue": 0x80346130,
		"os::OSSendMessage": 0x80346190,
		"OSSendMessage": 0x80346190,
		"os::OSReceiveMessage": 0x80346258,
		"OSReceiveMessage": 0x80346258,
		"os::OnReset": 0x80346334,
		"os::MEMIntrruptHandler": 0x80346370,
		"MEMIntrruptHandler": 0x80346370,
		"os::OSProtectRange": 0x803463dc,
		"OSProtectRange": 0x803463dc,
		"os::Config24MB": 0x803464a0,
		"Config24MB": 0x803464a0,
		"os::Config48MB": 0x80346520,
		"Config48MB": 0x80346520,
		"os::RealMode": 0x803465a0,
		"RealMode": 0x803465a0,
		"os::__OSInitMemoryProtection": 0x803465b8,
		"__OSInitMemoryProtection": 0x803465b8,
		"os::OSInitMutex": 0x803466d8,
		"OSInitMutex": 0x803466d8,
		"os::OSLockMutex": 0x80346710,
		"OSLockMutex": 0x80346710,
		"os::OSUnlockMutex": 0x803467ec,
		"OSUnlockMutex": 0x803467ec,
		"os::__OSUnlockAllMutex": 0x803468b4,
		"__OSUnlockAllMutex": 0x803468b4,
		"os::OSTryLockMutex": 0x80346924,
		"OSTryLockMutex": 0x80346924,
		"os::OSInitCond": 0x803469e0,
		"OSInitCond": 0x803469e0,
		"os::OSWaitCond": 0x80346a00,
		"OSWaitCond": 0x80346a00,
		"os::OSSignalCond": 0x80346ad4,
		"OSSignalCond": 0x80346ad4,
		"os::Run": 0x80346af4,
		"Run": 0x80346af4,
		"os::Callback": 0x80346b34,
		"os::__OSReboot": 0x80346b40,
		"__OSReboot": 0x80346b40,
		"os::OSRegisterResetFunction": 0x80346d00,
		"OSRegisterResetFunction": 0x80346d00,
		"os::Reset": 0x80346d84,
		"Reset": 0x80346d84,
		"os::__OSDoHotReset": 0x80346df4,
		"__OSDoHotReset": 0x80346df4,
		"os::OSResetSystem": 0x80346e3c,
		"OSResetSystem": 0x80346e3c,
		"os::OSGetResetCode": 0x803470b4,
		"OSGetResetCode": 0x803470b4,
		"os::__OSResetSWInterruptHandler": 0x803470e4,
		"__OSResetSWInterruptHandler": 0x803470e4,
		"os::OSGetResetButtonState": 0x803471d8,
		"OSGetResetButtonState": 0x803471d8,
		"os::OSGetResetSwitchState": 0x80347470,
		"OSGetResetSwitchState": 0x80347470,
		"os::WriteSramCallback": 0x80347490,
		"WriteSramCallback": 0x80347490,
		"os::WriteSram": 0x803474f0,
		"WriteSram": 0x803474f0,
		"os::__OSInitSram": 0x80347608,
		"__OSInitSram": 0x80347608,
		"os::__OSLockSram": 0x8034773c,
		"__OSLockSram": 0x8034773c,
		"os::__OSLockSramEx": 0x80347798,
		"__OSLockSramEx": 0x80347798,
		"os::UnlockSram": 0x803477f4,
		"UnlockSram": 0x803477f4,
		"os::__OSUnlockSram": 0x80347afc,
		"__OSUnlockSram": 0x80347afc,
		"os::__OSUnlockSramEx": 0x80347b20,
		"__OSUnlockSramEx": 0x80347b20,
		"os::__OSSyncSram": 0x80347b44,
		"__OSSyncSram": 0x80347b44,
		"os::__OSReadROM": 0x80347b54,
		"__OSReadROM": 0x80347b54,
		"os::OSGetSoundMode": 0x80347c78,
		"OSGetSoundMode": 0x80347c78,
		"os::OSSetSoundMode": 0x80347cf8,
		"OSSetSoundMode": 0x80347cf8,
		"os::OSGetProgressiveMode": 0x80347d9c,
		"OSGetProgressiveMode": 0x80347d9c,
		"os::OSSetProgressiveMode": 0x80347e0c,
		"OSSetProgressiveMode": 0x80347e0c,
		"os::OSGetWirelessID": 0x80347eb0,
		"OSGetWirelessID": 0x80347eb0,
		"os::OSSetWirelessID": 0x80347f34,
		"OSSetWirelessID": 0x80347f34,
		"os::OSInitStopwatch": 0x80347fe0,
		"OSInitStopwatch": 0x80347fe0,
		"os::OSStartStopwatch": 0x8034800c,
		"OSStartStopwatch": 0x8034800c,
		"os::OSStopStopwatch": 0x80348048,
		"OSStopStopwatch": 0x80348048,
		"os::OSCheckStopwatch": 0x80348114,
		"OSCheckStopwatch": 0x80348114,
		"os::OSResetStopwatch": 0x80348184,
		"OSResetStopwatch": 0x80348184,
		"os::SystemCallVector": 0x803481ac,
		"SystemCallVector": 0x803481ac,
		"os::__OSInitSystemCall": 0x803481cc,
		"__OSInitSystemCall": 0x803481cc,
		"os::__OSThreadInit": 0x80348230,
		"__OSThreadInit": 0x80348230,
		"os::OSInitThreadQueue": 0x80348358,
		"OSInitThreadQueue": 0x80348358,
		"os::OSGetCurrentThread": 0x80348368,
		"OSGetCurrentThread": 0x80348368,
		"os::OSIsThreadTerminated": 0x80348374,
		"OSIsThreadTerminated": 0x80348374,
		"os::OSDisableScheduler": 0x803483a8,
		"OSDisableScheduler": 0x803483a8,
		"os::OSEnableScheduler": 0x803483e8,
		"OSEnableScheduler": 0x803483e8,
		"os::UnsetRun": 0x80348428,
		"UnsetRun": 0x80348428,
		"os::__OSGetEffectivePriority": 0x80348490,
		"__OSGetEffectivePriority": 0x80348490,
		"os::SetEffectivePriority": 0x803484cc,
		"SetEffectivePriority": 0x803484cc,
		"os::__OSPromoteThread": 0x8034868c,
		"__OSPromoteThread": 0x8034868c,
		"os::SelectThread": 0x803486dc,
		"SelectThread": 0x803486dc,
		"os::__OSReschedule": 0x803488dc,
		"__OSReschedule": 0x803488dc,
		"os::OSYieldThread": 0x8034890c,
		"OSYieldThread": 0x8034890c,
		"os::OSCreateThread": 0x80348948,
		"OSCreateThread": 0x80348948,
		"os::OSExitThread": 0x80348a68,
		"OSExitThread": 0x80348a68,
		"os::OSCancelThread": 0x80348b4c,
		"OSCancelThread": 0x80348b4c,
		"os::OSJoinThread": 0x80348d08,
		"OSJoinThread": 0x80348d08,
		"os::OSDetachThread": 0x80348e48,
		"OSDetachThread": 0x80348e48,
		"os::OSResumeThread": 0x80348ee8,
		"OSResumeThread": 0x80348ee8,
		"os::OSSuspendThread": 0x80349170,
		"OSSuspendThread": 0x80349170,
		"os::OSSleepThread": 0x803492e0,
		"OSSleepThread": 0x803492e0,
		"os::OSWakeupThread": 0x803493cc,
		"OSWakeupThread": 0x803493cc,
		"os::OSGetThreadPriority": 0x803494d0,
		"OSGetThreadPriority": 0x803494d0,
		"os::OSGetTime": 0x803494d8,
		"OSGetTime": 0x803494d8,
		"os::OSGetTick": 0x803494f0,
		"OSGetTick": 0x803494f0,
		"os::__OSGetSystemTime": 0x803494f8,
		"__OSGetSystemTime": 0x803494f8,
		"os::GetDates": 0x8034955c,
		"GetDates": 0x8034955c,
		"os::OSTicksToCalendarTime": 0x803496f8,
		"OSTicksToCalendarTime": 0x803496f8,
		"os::__init_user": 0x803498fc,
		"__init_user": 0x803498fc,
		"os::__init_cpp": 0x8034991c,
		"__init_cpp": 0x8034991c,
		"os::_ExitProcess": 0x80349970,
		"_ExitProcess": 0x80349970,
		"mtx::PSMTXIdentity": 0x80349990,
		"PSMTXIdentity": 0x80349990,
		"mtx::PSMTXCopy": 0x803499bc,
		"PSMTXCopy": 0x803499bc,
		"mtx::PSMTXConcat": 0x803499f0,
		"PSMTXConcat": 0x803499f0,
		"mtx::PSMTXInverse": 0x80349abc,
		"PSMTXInverse": 0x80349abc,
		"mtx::PSMTXRotRad": 0x80349bb4,
		"PSMTXRotRad": 0x80349bb4,
		"mtx::PSMTXRotTrig": 0x80349c24,
		"PSMTXRotTrig": 0x80349c24,
		"mtx::PSMTXRotAxisRad": 0x80349ccc,
		"PSMTXRotAxisRad": 0x80349ccc,
		"mtx::PSMTXTrans": 0x80349dd0,
		"PSMTXTrans": 0x80349dd0,
		"mtx::PSMTXTransApply": 0x80349e04,
		"PSMTXTransApply": 0x80349e04,
		"mtx::PSMTXScale": 0x80349e44,
		"PSMTXScale": 0x80349e44,
		"mtx::PSMTXScaleApply": 0x80349e6c,
		"PSMTXScaleApply": 0x80349e6c,
		"mtx::PSMTXQuat": 0x80349eb8,
		"PSMTXQuat": 0x80349eb8,
		"mtx::C_MTXLookAt": 0x80349f5c,
		"C_MTXLookAt": 0x80349f5c,
		"mtx::C_MTXLightFrustum": 0x8034a0e8,
		"C_MTXLightFrustum": 0x8034a0e8,
		"mtx::C_MTXLightPerspective": 0x8034a17c,
		"C_MTXLightPerspective": 0x8034a17c,
		"mtx::C_MTXLightOrtho": 0x8034a248,
		"C_MTXLightOrtho": 0x8034a248,
		"mtx::PSMTXMultVec": 0x8034a2d0,
		"PSMTXMultVec": 0x8034a2d0,
		"mtx::PSMTXMultVecArray": 0x8034a324,
		"PSMTXMultVecArray": 0x8034a324,
		"mtx::PSMTXMultVecSR": 0x8034a3b0,
		"PSMTXMultVecSR": 0x8034a3b0,
		"mtx::C_MTXPerspective": 0x8034a404,
		"C_MTXPerspective": 0x8034a404,
		"mtx::C_MTXOrtho": 0x8034a4d4,
		"C_MTXOrtho": 0x8034a4d4,
		"mtx::PSVECAdd": 0x8034a56c,
		"PSVECAdd": 0x8034a56c,
		"mtx::PSVECSubtract": 0x8034a590,
		"PSVECSubtract": 0x8034a590,
		"mtx::PSVECScale": 0x8034a5b4,
		"PSVECScale": 0x8034a5b4,
		"mtx::PSVECNormalize": 0x8034a5d0,
		"PSVECNormalize": 0x8034a5d0,
		"mtx::PSVECMag": 0x8034a614,
		"PSVECMag": 0x8034a614,
		"mtx::PSVECDotProduct": 0x8034a650,
		"PSVECDotProduct": 0x8034a650,
		"mtx::PSVECCrossProduct": 0x8034a670,
		"PSVECCrossProduct": 0x8034a670,
		"mtx::PSVECSquareDistance": 0x8034a6ac,
		"PSVECSquareDistance": 0x8034a6ac,
		"mtx::PSVECDistance": 0x8034a6d4,
		"PSVECDistance": 0x8034a6d4,
		"dvd::__DVDInitWA": 0x8034a720,
		"__DVDInitWA": 0x8034a720,
		"dvd::__DVDInterruptHandler": 0x8034a760,
		"__DVDInterruptHandler": 0x8034a760,
		"dvd::AlarmHandlerForTimeout": 0x8034aad8,
		"AlarmHandlerForTimeout": 0x8034aad8,
		"dvd::Read": 0x8034ab48,
		"Read": 0x8034ab48,
		"dvd::SeekTwiceBeforeRead": 0x8034ac58,
		"SeekTwiceBeforeRead": 0x8034ac58,
		"dvd::DVDLowRead": 0x8034acd8,
		"DVDLowRead": 0x8034acd8,
		"dvd::DVDLowSeek": 0x8034af70,
		"DVDLowSeek": 0x8034af70,
		"dvd::DVDLowWaitCoverClose": 0x8034b004,
		"DVDLowWaitCoverClose": 0x8034b004,
		"dvd::DVDLowReadDiskID": 0x8034b030,
		"DVDLowReadDiskID": 0x8034b030,
		"dvd::DVDLowStopMotor": 0x8034b0d4,
		"DVDLowStopMotor": 0x8034b0d4,
		"dvd::DVDLowRequestError": 0x8034b160,
		"DVDLowRequestError": 0x8034b160,
		"dvd::DVDLowInquiry": 0x8034b1ec,
		"DVDLowInquiry": 0x8034b1ec,
		"dvd::DVDLowAudioStream": 0x8034b288,
		"DVDLowAudioStream": 0x8034b288,
		"dvd::DVDLowRequestAudioStatus": 0x8034b320,
		"DVDLowRequestAudioStatus": 0x8034b320,
		"dvd::DVDLowAudioBufferConfig": 0x8034b3ac,
		"DVDLowAudioBufferConfig": 0x8034b3ac,
		"dvd::DVDLowReset": 0x8034b448,
		"DVDLowReset": 0x8034b448,
		"dvd::DVDLowBreak": 0x8034b504,
		"DVDLowBreak": 0x8034b504,
		"dvd::DVDLowClearCallback": 0x8034b518,
		"DVDLowClearCallback": 0x8034b518,
		"dvd::__DVDLowSetWAType": 0x8034b530,
		"__DVDLowSetWAType": 0x8034b530,
		"dvd::__DVDFSInit": 0x8034b574,
		"__DVDFSInit": 0x8034b574,
		"dvd::DVDConvertPathToEntrynum": 0x8034b5ac,
		"DVDConvertPathToEntrynum": 0x8034b5ac,
		"dvd::DVDFastOpen": 0x8034b8a0,
		"DVDFastOpen": 0x8034b8a0,
		"dvd::DVDOpen": 0x8034b914,
		"DVDOpen": 0x8034b914,
		"dvd::DVDClose": 0x8034b9dc,
		"DVDClose": 0x8034b9dc,
		"dvd::entryToPath": 0x8034ba00,
		"entryToPath": 0x8034ba00,
		"dvd::DVDGetCurrentDir": 0x8034bb60,
		"DVDGetCurrentDir": 0x8034bb60,
		"dvd::DVDChangeDir": 0x8034bc24,
		"DVDChangeDir": 0x8034bc24,
		"dvd::DVDReadAsyncPrio": 0x8034bc84,
		"DVDReadAsyncPrio": 0x8034bc84,
		"dvd::cbForReadAsync": 0x8034bd44,
		"cbForReadAsync": 0x8034bd44,
		"dvd::DVDReadPrio": 0x8034bd74,
		"DVDReadPrio": 0x8034bd74,
		"dvd::cbForReadSync": 0x8034be8c,
		"cbForReadSync": 0x8034be8c,
		"dvd::DVDPrepareStreamAsync": 0x8034beb0,
		"DVDPrepareStreamAsync": 0x8034beb0,
		"dvd::cbForPrepareStreamAsync": 0x8034bf9c,
		"cbForPrepareStreamAsync": 0x8034bf9c,
		"dvd::DVDInit": 0x8034bfcc,
		"DVDInit": 0x8034bfcc,
		"dvd::stateReadingFST": 0x8034c0c8,
		"stateReadingFST": 0x8034c0c8,
		"dvd::cbForStateReadingFST": 0x8034c11c,
		"cbForStateReadingFST": 0x8034c11c,
		"dvd::cbForStateError": 0x8034c19c,
		"cbForStateError": 0x8034c19c,
		"dvd::stateTimeout": 0x8034c244,
		"stateTimeout": 0x8034c244,
		"dvd::stateGettingError": 0x8034c2e0,
		"stateGettingError": 0x8034c2e0,
		"dvd::CategorizeError": 0x8034c308,
		"CategorizeError": 0x8034c308,
		"dvd::cbForStateGettingError": 0x8034c3bc,
		"cbForStateGettingError": 0x8034c3bc,
		"dvd::cbForUnrecoveredError": 0x8034c650,
		"cbForUnrecoveredError": 0x8034c650,
		"dvd::cbForUnrecoveredErrorRetry": 0x8034c6b8,
		"cbForUnrecoveredErrorRetry": 0x8034c6b8,
		"dvd::stateGoToRetry": 0x8034c750,
		"stateGoToRetry": 0x8034c750,
		"dvd::cbForStateGoToRetry": 0x8034c778,
		"cbForStateGoToRetry": 0x8034c778,
		"dvd::stateCheckID": 0x8034c8d0,
		"stateCheckID": 0x8034c8d0,
		"dvd::stateCheckID3": 0x8034c9b4,
		"stateCheckID3": 0x8034c9b4,
		"dvd::stateCheckID2": 0x8034c9e8,
		"stateCheckID2": 0x8034c9e8,
		"dvd::cbForStateCheckID1": 0x8034ca20,
		"cbForStateCheckID1": 0x8034ca20,
		"dvd::cbForStateCheckID2": 0x8034cb34,
		"cbForStateCheckID2": 0x8034cb34,
		"dvd::cbForStateCheckID3": 0x8034cbd8,
		"cbForStateCheckID3": 0x8034cbd8,
		"dvd::stateCoverClosed": 0x8034cd18,
		"stateCoverClosed": 0x8034cd18,
		"dvd::stateCoverClosed_CMD": 0x8034cde4,
		"stateCoverClosed_CMD": 0x8034cde4,
		"dvd::cbForStateCoverClosed": 0x8034ce14,
		"cbForStateCoverClosed": 0x8034ce14,
		"dvd::stateMotorStopped": 0x8034ce84,
		"stateMotorStopped": 0x8034ce84,
		"dvd::cbForStateMotorStopped": 0x8034ceac,
		"cbForStateMotorStopped": 0x8034ceac,
		"dvd::stateReady": 0x8034cf90,
		"stateReady": 0x8034cf90,
		"dvd::stateBusy": 0x8034d1d8,
		"stateBusy": 0x8034d1d8,
		"dvd::cbForStateBusy": 0x8034d498,
		"cbForStateBusy": 0x8034d498,
		"dvd::DVDReadAbsAsyncPrio": 0x8034da6c,
		"DVDReadAbsAsyncPrio": 0x8034da6c,
		"dvd::DVDReadAbsAsyncForBS": 0x8034db48,
		"DVDReadAbsAsyncForBS": 0x8034db48,
		"dvd::DVDReadDiskID": 0x8034dc18,
		"DVDReadDiskID": 0x8034dc18,
		"dvd::DVDPrepareStreamAbsAsync": 0x8034dcec,
		"DVDPrepareStreamAbsAsync": 0x8034dcec,
		"dvd::DVDCancelStreamAsync": 0x8034ddb0,
		"DVDCancelStreamAsync": 0x8034ddb0,
		"dvd::DVDStopStreamAtEndAsync": 0x8034de6c,
		"DVDStopStreamAtEndAsync": 0x8034de6c,
		"dvd::DVDGetStreamPlayAddrAsync": 0x8034df28,
		"DVDGetStreamPlayAddrAsync": 0x8034df28,
		"dvd::DVDInquiryAsync": 0x8034dfe4,
		"DVDInquiryAsync": 0x8034dfe4,
		"dvd::DVDReset": 0x8034e0b4,
		"DVDReset": 0x8034e0b4,
		"dvd::DVDGetCommandBlockStatus": 0x8034e0f8,
		"DVDGetCommandBlockStatus": 0x8034e0f8,
		"dvd::DVDGetDriveStatus": 0x8034e144,
		"DVDGetDriveStatus": 0x8034e144,
		"dvd::DVDSetAutoInvalidation": 0x8034e1f0,
		"DVDSetAutoInvalidation": 0x8034e1f0,
		"dvd::DVDCancelAsync": 0x8034e200,
		"DVDCancelAsync": 0x8034e200,
		"dvd::DVDCancel": 0x8034e470,
		"DVDCancel": 0x8034e470,
		"dvd::cbForCancelSync": 0x8034e51c,
		"cbForCancelSync": 0x8034e51c,
		"dvd::DVDGetCurrentDiskID": 0x8034e540,
		"DVDGetCurrentDiskID": 0x8034e540,
		"dvd::DVDCheckDisk": 0x8034e548,
		"DVDCheckDisk": 0x8034e548,
		"dvd::__DVDPrepareResetAsync": 0x8034e62c,
		"__DVDPrepareResetAsync": 0x8034e62c,
		"dvd::__DVDClearWaitingQueue": 0x8034e748,
		"__DVDClearWaitingQueue": 0x8034e748,
		"dvd::__DVDPushWaitingQueue": 0x8034e780,
		"__DVDPushWaitingQueue": 0x8034e780,
		"dvd::__DVDPopWaitingQueue": 0x8034e7e8,
		"__DVDPopWaitingQueue": 0x8034e7e8,
		"dvd::__DVDCheckWaitingQueue": 0x8034e888,
		"__DVDCheckWaitingQueue": 0x8034e888,
		"dvd::__DVDDequeueWaitingQueue": 0x8034e8e0,
		"__DVDDequeueWaitingQueue": 0x8034e8e0,
		"dvd::ErrorCode2Num": 0x8034e940,
		"ErrorCode2Num": 0x8034e940,
		"dvd::__DVDStoreErrorCode": 0x8034ea5c,
		"__DVDStoreErrorCode": 0x8034ea5c,
		"dvd::cb": 0x8034ead8,
		"dvd::__fstLoad": 0x8034ebb0,
		"__fstLoad": 0x8034ebb0,
		"vi::__VIRetraceHandler": 0x8034ed18,
		"__VIRetraceHandler": 0x8034ed18,
		"vi::VISetPostRetraceCallback": 0x8034ef40,
		"VISetPostRetraceCallback": 0x8034ef40,
		"vi::getTiming": 0x8034ef84,
		"getTiming": 0x8034ef84,
		"vi::__VIInit": 0x8034f014,
		"__VIInit": 0x8034f014,
		"vi::VIInit": 0x8034f20c,
		"VIInit": 0x8034f20c,
		"vi::VIWaitForRetrace": 0x8034f684,
		"VIWaitForRetrace": 0x8034f684,
		"vi::setFbbRegs": 0x8034f6d8,
		"setFbbRegs": 0x8034f6d8,
		"vi::setVerticalRegs": 0x8034f9ac,
		"setVerticalRegs": 0x8034f9ac,
		"vi::VIConfigure": 0x8034fb4c,
		"VIConfigure": 0x8034fb4c,
		"vi::VIFlush": 0x803502e8,
		"VIFlush": 0x803502e8,
		"vi::VISetNextFrameBuffer": 0x80350404,
		"VISetNextFrameBuffer": 0x80350404,
		"vi::VISetBlack": 0x80350470,
		"VISetBlack": 0x80350470,
		"vi::VIGetRetraceCount": 0x803504ec,
		"VIGetRetraceCount": 0x803504ec,
		"vi::getCurrentFieldEvenOdd": 0x803504f4,
		"getCurrentFieldEvenOdd": 0x803504f4,
		"vi::VIGetNextField": 0x8035055c,
		"VIGetNextField": 0x8035055c,
		"vi::VIGetCurrentLine": 0x80350604,
		"VIGetCurrentLine": 0x80350604,
		"vi::VIGetTvFormat": 0x8035069c,
		"VIGetTvFormat": 0x8035069c,
		"vi::VIGetDTVStatus": 0x80350718,
		"VIGetDTVStatus": 0x80350718,
		"pad::ClampStick": 0x80350754,
		"ClampStick": 0x80350754,
		"pad::PADClamp": 0x80350884,
		"PADClamp": 0x80350884,
		"pad::UpdateOrigin": 0x8035098c,
		"UpdateOrigin": 0x8035098c,
		"pad::PADOriginCallback": 0x80350b30,
		"PADOriginCallback": 0x80350b30,
		"pad::PADOriginUpdateCallback": 0x80350bf4,
		"PADOriginUpdateCallback": 0x80350bf4,
		"pad::PADProbeCallback": 0x80350cb4,
		"PADProbeCallback": 0x80350cb4,
		"pad::PADTypeAndStatusCallback": 0x80350d8c,
		"PADTypeAndStatusCallback": 0x80350d8c,
		"pad::PADReceiveCheckCallback": 0x803510b8,
		"PADReceiveCheckCallback": 0x803510b8,
		"pad::PADReset": 0x803511ec,
		"PADReset": 0x803511ec,
		"pad::PADRecalibrate": 0x803512ec,
		"PADRecalibrate": 0x803512ec,
		"pad::PADInit": 0x803513f0,
		"PADInit": 0x803513f0,
		"pad::PADRead": 0x80351600,
		"PADRead": 0x80351600,
		"pad::PADControlMotor": 0x803519ac,
		"PADControlMotor": 0x803519ac,
		"pad::PADSetSpec": 0x80351a50,
		"PADSetSpec": 0x80351a50,
		"pad::SPEC0_MakeStatus": 0x80351ab0,
		"SPEC0_MakeStatus": 0x80351ab0,
		"pad::SPEC1_MakeStatus": 0x80351c24,
		"SPEC1_MakeStatus": 0x80351c24,
		"pad::SPEC2_MakeStatus": 0x80351d98,
		"SPEC2_MakeStatus": 0x80351d98,
		"pad::PADSetAnalogMode": 0x80352190,
		"PADSetAnalogMode": 0x80352190,
		"pad::OnReset": 0x80352204,
		"pad::SamplingHandler": 0x80352398,
		"SamplingHandler": 0x80352398,
		"pad::PADSetSamplingCallback": 0x803523f8,
		"PADSetSamplingCallback": 0x803523f8,
		"pad::__PADDisableRecalibration": 0x8035244c,
		"__PADDisableRecalibration": 0x8035244c,
		"ai::AIRegisterDMACallback": 0x803524c8,
		"AIRegisterDMACallback": 0x803524c8,
		"ai::AIInitDMA": 0x8035250c,
		"AIInitDMA": 0x8035250c,
		"ai::AIStartDMA": 0x80352594,
		"AIStartDMA": 0x80352594,
		"ai::AIResetStreamSampleCount": 0x803525ac,
		"AIResetStreamSampleCount": 0x803525ac,
		"ai::AISetStreamPlayState": 0x803525c4,
		"AISetStreamPlayState": 0x803525c4,
		"ai::AIGetStreamPlayState": 0x8035269c,
		"AIGetStreamPlayState": 0x8035269c,
		"ai::AISetDSPSampleRate": 0x803526ac,
		"AISetDSPSampleRate": 0x803526ac,
		"ai::AIGetDSPSampleRate": 0x8035278c,
		"AIGetDSPSampleRate": 0x8035278c,
		"ai::AISetStreamSampleRate": 0x803527a0,
		"AISetStreamSampleRate": 0x803527a0,
		"ai::__AI_set_stream_sample_rate": 0x803527c8,
		"__AI_set_stream_sample_rate": 0x803527c8,
		"ai::AIGetStreamSampleRate": 0x8035289c,
		"AIGetStreamSampleRate": 0x8035289c,
		"ai::AISetStreamVolLeft": 0x803528ac,
		"AISetStreamVolLeft": 0x803528ac,
		"ai::AIGetStreamVolLeft": 0x803528c8,
		"AIGetStreamVolLeft": 0x803528c8,
		"ai::AISetStreamVolRight": 0x803528d8,
		"AISetStreamVolRight": 0x803528d8,
		"ai::AIGetStreamVolRight": 0x803528f4,
		"AIGetStreamVolRight": 0x803528f4,
		"ai::AIInit": 0x80352904,
		"AIInit": 0x80352904,
		"ai::__AISHandler": 0x80352a68,
		"__AISHandler": 0x80352a68,
		"ai::__AIDHandler": 0x80352ae4,
		"__AIDHandler": 0x80352ae4,
		"ai::__AICallbackStackSwitch": 0x80352b74,
		"__AICallbackStackSwitch": 0x80352b74,
		"ai::__AI_SRC_INIT": 0x80352bcc,
		"__AI_SRC_INIT": 0x80352bcc,
		"ar::ARRegisterDMACallback": 0x80352db0,
		"ARRegisterDMACallback": 0x80352db0,
		"ar::ARStartDMA": 0x80352df4,
		"ARStartDMA": 0x80352df4,
		"ar::ARAlloc": 0x80352ee4,
		"ARAlloc": 0x80352ee4,
		"ar::ARInit": 0x80352f4c,
		"ARInit": 0x80352f4c,
		"ar::ARGetBaseAddress": 0x80353008,
		"ARGetBaseAddress": 0x80353008,
		"ar::ARGetSize": 0x80353010,
		"ARGetSize": 0x80353010,
		"ar::__ARHandler": 0x80353018,
		"__ARHandler": 0x80353018,
		"ar::__ARChecksize": 0x80353090,
		"__ARChecksize": 0x80353090,
		"ar::__ARQServiceQueueLo": 0x803539a4,
		"__ARQServiceQueueLo": 0x803539a4,
		"ar::__ARQCallbackHack": 0x80353aa4,
		"__ARQCallbackHack": 0x80353aa4,
		"ar::__ARQInterruptServiceRoutine": 0x80353aa8,
		"__ARQInterruptServiceRoutine": 0x80353aa8,
		"ar::ARQInit": 0x80353b74,
		"ARQInit": 0x80353b74,
		"ar::ARQPostRequest": 0x80353bdc,
		"ARQPostRequest": 0x80353bdc,
		"dsp::DSPCheckMailToDSP": 0x80353d38,
		"DSPCheckMailToDSP": 0x80353d38,
		"dsp::DSPCheckMailFromDSP": 0x80353d48,
		"DSPCheckMailFromDSP": 0x80353d48,
		"dsp::DSPReadMailFromDSP": 0x80353d58,
		"DSPReadMailFromDSP": 0x80353d58,
		"dsp::DSPSendMailToDSP": 0x80353d70,
		"DSPSendMailToDSP": 0x80353d70,
		"dsp::DSPAssertInt": 0x80353d84,
		"DSPAssertInt": 0x80353d84,
		"dsp::DSPInit": 0x80353dc4,
		"DSPInit": 0x80353dc4,
		"dsp::__DSP_debug_printf": 0x80353e7c,
		"__DSP_debug_printf": 0x80353e7c,
		"dsp::__DSP_exec_task": 0x80353ecc,
		"__DSP_exec_task": 0x80353ecc,
		"dsp::__DSP_boot_task": 0x8035406c,
		"__DSP_boot_task": 0x8035406c,
		"dsp::__DSP_insert_task": 0x803541f8,
		"__DSP_insert_task": 0x803541f8,
		"dsp::__DSP_remove_task": 0x80354298,
		"__DSP_remove_task": 0x80354298,
		"card::__CARDDefaultApiCallback": 0x8035432c,
		"__CARDDefaultApiCallback": 0x8035432c,
		"card::__CARDSyncCallback": 0x80354330,
		"__CARDSyncCallback": 0x80354330,
		"card::__CARDExtHandler": 0x80354364,
		"__CARDExtHandler": 0x80354364,
		"card::__CARDExiHandler": 0x8035443c,
		"__CARDExiHandler": 0x8035443c,
		"card::__CARDTxHandler": 0x80354554,
		"__CARDTxHandler": 0x80354554,
		"card::__CARDUnlockedHandler": 0x803545fc,
		"__CARDUnlockedHandler": 0x803545fc,
		"card::__CARDEnableInterrupt": 0x80354680,
		"__CARDEnableInterrupt": 0x80354680,
		"card::__CARDReadStatus": 0x80354740,
		"__CARDReadStatus": 0x80354740,
		"card::__CARDClearStatus": 0x80354830,
		"__CARDClearStatus": 0x80354830,
		"card::TimeoutHandler": 0x803548dc,
		"TimeoutHandler": 0x803548dc,
		"card::Retry": 0x80354980,
		"Retry": 0x80354980,
		"card::UnlockedCallback": 0x80354bac,
		"UnlockedCallback": 0x80354bac,
		"card::__CARDStart": 0x80354cbc,
		"__CARDStart": 0x80354cbc,
		"card::__CARDReadSegment": 0x80354e70,
		"__CARDReadSegment": 0x80354e70,
		"card::__CARDWritePage": 0x80354fa4,
		"__CARDWritePage": 0x80354fa4,
		"card::__CARDEraseSector": 0x803550c0,
		"__CARDEraseSector": 0x803550c0,
		"card::CARDInit": 0x803551a0,
		"CARDInit": 0x803551a0,
		"card::__CARDSetDiskID": 0x8035523c,
		"__CARDSetDiskID": 0x8035523c,
		"card::__CARDGetControlBlock": 0x80355274,
		"__CARDGetControlBlock": 0x80355274,
		"card::__CARDPutControlBlock": 0x8035532c,
		"__CARDPutControlBlock": 0x8035532c,
		"card::CARDFreeBlocks": 0x80355390,
		"CARDFreeBlocks": 0x80355390,
		"card::__CARDSync": 0x803554e0,
		"__CARDSync": 0x803554e0,
		"card::OnReset": 0x80355578,
		"card::bitrev": 0x803555c8,
		"bitrev": 0x803555c8,
		"card::ReadArrayUnlock": 0x80355734,
		"ReadArrayUnlock": 0x80355734,
		"card::DummyLen": 0x80355878,
		"DummyLen": 0x80355878,
		"card::__CARDUnlock": 0x8035593c,
		"__CARDUnlock": 0x8035593c,
		"card::InitCallback": 0x80356494,
		"InitCallback": 0x80356494,
		"card::DoneCallback": 0x80356504,
		"DoneCallback": 0x80356504,
		"card::BlockReadCallback": 0x80356828,
		"BlockReadCallback": 0x80356828,
		"card::__CARDRead": 0x80356904,
		"__CARDRead": 0x80356904,
		"card::BlockWriteCallback": 0x80356968,
		"BlockWriteCallback": 0x80356968,
		"card::__CARDWrite": 0x80356a44,
		"__CARDWrite": 0x80356a44,
		"card::__CARDGetFatBlock": 0x80356aa8,
		"__CARDGetFatBlock": 0x80356aa8,
		"card::__CARDAllocBlock": 0x80356c4c,
		"__CARDAllocBlock": 0x80356c4c,
		"card::__CARDUpdateFatBlock": 0x80356d64,
		"__CARDUpdateFatBlock": 0x80356d64,
		"card::__CARDGetDirBlock": 0x80356e10,
		"__CARDGetDirBlock": 0x80356e10,
		"card::__CARDUpdateDir": 0x80356fb0,
		"__CARDUpdateDir": 0x80356fb0,
		"card::__CARDCheckSum": 0x80357074,
		"__CARDCheckSum": 0x80357074,
		"card::VerifyID": 0x80357224,
		"VerifyID": 0x80357224,
		"card::VerifyDir": 0x803574a8,
		"VerifyDir": 0x803574a8,
		"card::VerifyFAT": 0x803576e8,
		"VerifyFAT": 0x803576e8,
		"card::__CARDVerify": 0x8035796c,
		"__CARDVerify": 0x8035796c,
		"card::CARDCheckExAsync": 0x803579f8,
		"CARDCheckExAsync": 0x803579f8,
		"card::CARDCheck": 0x80357f88,
		"CARDCheck": 0x80357f88,
		"card::IsCard": 0x80357fdc,
		"IsCard": 0x80357fdc,
		"card::CARDProbeEx": 0x803580a8,
		"CARDProbeEx": 0x803580a8,
		"card::DoMount": 0x80358224,
		"DoMount": 0x80358224,
		"card::__CARDMountCallback": 0x80358634,
		"__CARDMountCallback": 0x80358634,
		"card::CARDMountAsync": 0x8035873c,
		"CARDMountAsync": 0x8035873c,
		"card::CARDMount": 0x803588dc,
		"CARDMount": 0x803588dc,
		"card::DoUnmount": 0x80358924,
		"DoUnmount": 0x80358924,
		"card::CARDUnmount": 0x803589c0,
		"CARDUnmount": 0x803589c0,
		"card::FormatCallback": 0x80358a6c,
		"FormatCallback": 0x80358a6c,
		"card::__CARDFormatRegionAsync": 0x80358bb0,
		"__CARDFormatRegionAsync": 0x80358bb0,
		"card::CARDFormat": 0x80359208,
		"CARDFormat": 0x80359208,
		"card::__CARDCompareFileName": 0x8035925c,
		"__CARDCompareFileName": 0x8035925c,
		"card::__CARDAccess": 0x803592c4,
		"__CARDAccess": 0x803592c4,
		"card::__CARDIsPublic": 0x8035935c,
		"__CARDIsPublic": 0x8035935c,
		"card::CARDOpen": 0x8035938c,
		"CARDOpen": 0x8035938c,
		"card::CARDClose": 0x80359504,
		"CARDClose": 0x80359504,
		"card::CreateCallbackFat": 0x80359558,
		"CreateCallbackFat": 0x80359558,
		"card::CARDCreateAsync": 0x80359688,
		"CARDCreateAsync": 0x80359688,
		"card::CARDCreate": 0x803598a8,
		"CARDCreate": 0x803598a8,
		"card::__CARDSeek": 0x803598f0,
		"__CARDSeek": 0x803598f0,
		"card::ReadCallback": 0x80359aa8,
		"ReadCallback": 0x80359aa8,
		"card::CARDReadAsync": 0x80359bd8,
		"CARDReadAsync": 0x80359bd8,
		"card::CARDRead": 0x80359d20,
		"CARDRead": 0x80359d20,
		"card::CARDWriteAsync": 0x80359f88,
		"CARDWriteAsync": 0x80359f88,
		"card::CARDWrite": 0x8035a09c,
		"CARDWrite": 0x8035a09c,
		"card::UpdateIconOffsets": 0x8035a0e4,
		"UpdateIconOffsets": 0x8035a0e4,
		"card::CARDGetStatus": 0x8035a2dc,
		"CARDGetStatus": 0x8035a2dc,
		"card::CARDSetStatusAsync": 0x8035a408,
		"CARDSetStatusAsync": 0x8035a408,
		"card::CARDSetStatus": 0x8035a57c,
		"CARDSetStatus": 0x8035a57c,
		"gx::__GXDefaultTexRegionCallback": 0x8035a5c4,
		"__GXDefaultTexRegionCallback": 0x8035a5c4,
		"gx::__GXDefaultTlutRegionCallback": 0x8035a640,
		"__GXDefaultTlutRegionCallback": 0x8035a640,
		"gx::GXInit": 0x8035a664,
		"GXInit": 0x8035a664,
		"gx::__GXInitGX": 0x8035ae30,
		"__GXInitGX": 0x8035ae30,
		"gx::GXCPInterruptHandler": 0x8035b6b4,
		"GXCPInterruptHandler": 0x8035b6b4,
		"gx::GXInitFifoBase": 0x8035b7f0,
		"GXInitFifoBase": 0x8035b7f0,
		"gx::GXInitFifoPtrs": 0x8035b85c,
		"GXInitFifoPtrs": 0x8035b85c,
		"gx::GXInitFifoLimits": 0x8035b8cc,
		"GXInitFifoLimits": 0x8035b8cc,
		"gx::GXSetCPUFifo": 0x8035b8d8,
		"GXSetCPUFifo": 0x8035b8d8,
		"gx::GXSetGPFifo": 0x8035b9e8,
		"GXSetGPFifo": 0x8035b9e8,
		"gx::GXGetFifoPtrs": 0x8035bb60,
		"GXGetFifoPtrs": 0x8035bb60,
		"gx::GXEnableBreakPt": 0x8035bbf8,
		"GXEnableBreakPt": 0x8035bbf8,
		"gx::GXDisableBreakPt": 0x8035bc90,
		"GXDisableBreakPt": 0x8035bc90,
		"gx::__GXFifoInit": 0x8035bcf4,
		"__GXFifoInit": 0x8035bcf4,
		"gx::__GXFifoReadEnable": 0x8035bd40,
		"__GXFifoReadEnable": 0x8035bd40,
		"gx::__GXFifoReadDisable": 0x8035bd68,
		"__GXFifoReadDisable": 0x8035bd68,
		"gx::__GXFifoLink": 0x8035bd8c,
		"__GXFifoLink": 0x8035bd8c,
		"gx::__GXWriteFifoIntEnable": 0x8035bdd0,
		"__GXWriteFifoIntEnable": 0x8035bdd0,
		"gx::__GXWriteFifoIntReset": 0x8035be1c,
		"__GXWriteFifoIntReset": 0x8035be1c,
		"gx::GXGetCPUFifo": 0x8035be68,
		"GXGetCPUFifo": 0x8035be68,
		"gx::__GXXfVtxSpecs": 0x8035be70,
		"__GXXfVtxSpecs": 0x8035be70,
		"gx::GXSetVtxDesc": 0x8035bfc8,
		"GXSetVtxDesc": 0x8035bfc8,
		"gx::GXSetVtxDescv": 0x8035c328,
		"GXSetVtxDescv": 0x8035c328,
		"gx::__GXSetVCD": 0x8035c6ac,
		"__GXSetVCD": 0x8035c6ac,
		"gx::__GXCalculateVLim": 0x8035c700,
		"__GXCalculateVLim": 0x8035c700,
		"gx::GXGetVtxDesc": 0x8035c824,
		"GXGetVtxDesc": 0x8035c824,
		"gx::GXGetVtxDescv": 0x8035c9d8,
		"GXGetVtxDescv": 0x8035c9d8,
		"gx::GXClearVtxDesc": 0x8035ca48,
		"GXClearVtxDesc": 0x8035ca48,
		"gx::GXSetVtxAttrFmt": 0x8035ca94,
		"GXSetVtxAttrFmt": 0x8035ca94,
		"gx::GXSetVtxAttrFmtv": 0x8035cdf0,
		"GXSetVtxAttrFmtv": 0x8035cdf0,
		"gx::__GXSetVAT": 0x8035d16c,
		"__GXSetVAT": 0x8035d16c,
		"gx::GXGetVtxAttrFmt": 0x8035d208,
		"GXGetVtxAttrFmt": 0x8035d208,
		"gx::GXGetVtxAttrFmtv": 0x8035d450,
		"GXGetVtxAttrFmtv": 0x8035d450,
		"gx::GXSetArray": 0x8035d4c4,
		"GXSetArray": 0x8035d4c4,
		"gx::GXInvalidateVtxCache": 0x8035d550,
		"GXInvalidateVtxCache": 0x8035d550,
		"gx::GXSetTexCoordGen2": 0x8035d560,
		"GXSetTexCoordGen2": 0x8035d560,
		"gx::GXSetNumTexGens": 0x8035d830,
		"GXSetNumTexGens": 0x8035d830,
		"gx::GXSetMisc": 0x8035d878,
		"GXSetMisc": 0x8035d878,
		"gx::GXFlush": 0x8035d8f0,
		"GXFlush": 0x8035d8f0,
		"gx::GXSetDrawSync": 0x8035d94c,
		"GXSetDrawSync": 0x8035d94c,
		"gx::GXSetDrawDone": 0x8035da04,
		"GXSetDrawDone": 0x8035da04,
		"gx::GXWaitDrawDone": 0x8035da9c,
		"GXWaitDrawDone": 0x8035da9c,
		"gx::GXDrawDone": 0x8035dae8,
		"GXDrawDone": 0x8035dae8,
		"gx::GXPixModeSync": 0x8035db68,
		"GXPixModeSync": 0x8035db68,
		"gx::GXPokeAlphaMode": 0x8035db8c,
		"GXPokeAlphaMode": 0x8035db8c,
		"gx::GXPokeAlphaRead": 0x8035dba0,
		"GXPokeAlphaRead": 0x8035dba0,
		"gx::GXPokeAlphaUpdate": 0x8035dbb4,
		"GXPokeAlphaUpdate": 0x8035dbb4,
		"gx::GXPokeBlendMode": 0x8035dbd0,
		"GXPokeBlendMode": 0x8035dbd0,
		"gx::GXPokeColorUpdate": 0x8035dc58,
		"GXPokeColorUpdate": 0x8035dc58,
		"gx::GXPokeDstAlpha": 0x8035dc74,
		"GXPokeDstAlpha": 0x8035dc74,
		"gx::GXPokeDither": 0x8035dc88,
		"GXPokeDither": 0x8035dc88,
		"gx::GXPokeZMode": 0x8035dca4,
		"GXPokeZMode": 0x8035dca4,
		"gx::GXPeekARGB": 0x8035dccc,
		"GXPeekARGB": 0x8035dccc,
		"gx::GXPeekZ": 0x8035dcf0,
		"GXPeekZ": 0x8035dcf0,
		"gx::GXSetDrawSyncCallback": 0x8035dd18,
		"GXSetDrawSyncCallback": 0x8035dd18,
		"gx::GXTokenInterruptHandler": 0x8035dd5c,
		"GXTokenInterruptHandler": 0x8035dd5c,
		"gx::GXFinishInterruptHandler": 0x8035dde4,
		"GXFinishInterruptHandler": 0x8035dde4,
		"gx::__GXPEInit": 0x8035de68,
		"__GXPEInit": 0x8035de68,
		"gx::__GXSetDirtyState": 0x8035dee8,
		"__GXSetDirtyState": 0x8035dee8,
		"gx::GXBegin": 0x8035df88,
		"GXBegin": 0x8035df88,
		"gx::__GXSendFlushPrim": 0x8035e078,
		"__GXSendFlushPrim": 0x8035e078,
		"gx::GXSetLineWidth": 0x8035e100,
		"GXSetLineWidth": 0x8035e100,
		"gx::GXSetPointSize": 0x8035e158,
		"GXSetPointSize": 0x8035e158,
		"gx::GXEnableTexOffsets": 0x8035e1ac,
		"GXEnableTexOffsets": 0x8035e1ac,
		"gx::GXSetCullMode": 0x8035e210,
		"GXSetCullMode": 0x8035e210,
		"gx::GXSetCoPlanar": 0x8035e260,
		"GXSetCoPlanar": 0x8035e260,
		"gx::__GXSetGenMode": 0x8035e2a4,
		"__GXSetGenMode": 0x8035e2a4,
		"gx::GXSetDispCopySrc": 0x8035e2c8,
		"GXSetDispCopySrc": 0x8035e2c8,
		"gx::GXSetTexCopySrc": 0x8035e388,
		"GXSetTexCopySrc": 0x8035e388,
		"gx::GXSetDispCopyDst": 0x8035e448,
		"GXSetDispCopyDst": 0x8035e448,
		"gx::GXSetTexCopyDst": 0x8035e48c,
		"GXSetTexCopyDst": 0x8035e48c,
		"gx::GXSetDispCopyFrame2Field": 0x8035e5fc,
		"GXSetDispCopyFrame2Field": 0x8035e5fc,
		"gx::GXSetCopyClamp": 0x8035e628,
		"GXSetCopyClamp": 0x8035e628,
		"gx::GXGetNumXfbLines": 0x8035e6a4,
		"GXGetNumXfbLines": 0x8035e6a4,
		"gx::GXGetYScaleFactor": 0x8035e734,
		"GXGetYScaleFactor": 0x8035e734,
		"gx::GXSetDispCopyYScale": 0x8035e96c,
		"GXSetDispCopyYScale": 0x8035e96c,
		"gx::GXSetCopyClear": 0x8035ea40,
		"GXSetCopyClear": 0x8035ea40,
		"gx::GXSetCopyFilter": 0x8035eaa8,
		"GXSetCopyFilter": 0x8035eaa8,
		"gx::GXSetDispCopyGamma": 0x8035ecd0,
		"GXSetDispCopyGamma": 0x8035ecd0,
		"gx::GXCopyDisp": 0x8035ecec,
		"GXCopyDisp": 0x8035ecec,
		"gx::GXCopyTex": 0x8035ee5c,
		"GXCopyTex": 0x8035ee5c,
		"gx::GXClearBoundingBox": 0x8035efec,
		"GXClearBoundingBox": 0x8035efec,
		"gx::GXInitLightAttn": 0x8035f024,
		"GXInitLightAttn": 0x8035f024,
		"gx::GXInitLightAttnA": 0x8035f040,
		"GXInitLightAttnA": 0x8035f040,
		"gx::GXInitLightAttnK": 0x8035f050,
		"GXInitLightAttnK": 0x8035f050,
		"gx::GXInitLightDistAttn": 0x8035f060,
		"GXInitLightDistAttn": 0x8035f060,
		"gx::GXInitLightPos": 0x8035f130,
		"GXInitLightPos": 0x8035f130,
		"gx::GXInitSpecularDir": 0x8035f140,
		"GXInitSpecularDir": 0x8035f140,
		"gx::GXInitLightColor": 0x8035f214,
		"GXInitLightColor": 0x8035f214,
		"gx::GXGetLightColor": 0x8035f23c,
		"GXGetLightColor": 0x8035f23c,
		"gx::GXLoadLightObjImm": 0x8035f26c,
		"GXLoadLightObjImm": 0x8035f26c,
		"gx::GXSetChanAmbColor": 0x8035f3b4,
		"GXSetChanAmbColor": 0x8035f3b4,
		"gx::GXSetChanMatColor": 0x8035f51c,
		"GXSetChanMatColor": 0x8035f51c,
		"gx::GXSetNumChans": 0x8035f684,
		"GXSetNumChans": 0x8035f684,
		"gx::GXSetChanCtrl": 0x8035f6d0,
		"GXSetChanCtrl": 0x8035f6d0,
		"gx::GXGetTexBufferSize": 0x8035f8b4,
		"GXGetTexBufferSize": 0x8035f8b4,
		"gx::__GetImageTileCount": 0x8035fa10,
		"__GetImageTileCount": 0x8035fa10,
		"gx::GXInitTexObj": 0x8035fad8,
		"GXInitTexObj": 0x8035fad8,
		"gx::GXInitTexObjCI": 0x8035fd4c,
		"GXInitTexObjCI": 0x8035fd4c,
		"gx::GXInitTexObjLOD": 0x8035fd94,
		"GXInitTexObjLOD": 0x8035fd94,
		"gx::GXGetTexObjAll": 0x8035ff28,
		"GXGetTexObjAll": 0x8035ff28,
		"gx::GXGetTexObjWidth": 0x8035ff90,
		"GXGetTexObjWidth": 0x8035ff90,
		"gx::GXGetTexObjHeight": 0x8035ffa0,
		"GXGetTexObjHeight": 0x8035ffa0,
		"gx::GXGetTexObjFmt": 0x8035ffb0,
		"GXGetTexObjFmt": 0x8035ffb0,
		"gx::GXLoadTexObjPreLoaded": 0x8035ffb8,
		"GXLoadTexObjPreLoaded": 0x8035ffb8,
		"gx::GXLoadTexObj": 0x80360160,
		"GXLoadTexObj": 0x80360160,
		"gx::GXInitTlutObj": 0x803601b4,
		"GXInitTlutObj": 0x803601b4,
		"gx::GXLoadTlut": 0x803601fc,
		"GXLoadTlut": 0x803601fc,
		"gx::GXInitTexCacheRegion": 0x80360298,
		"GXInitTexCacheRegion": 0x80360298,
		"gx::GXInitTlutRegion": 0x803603b8,
		"GXInitTlutRegion": 0x803603b8,
		"gx::GXInvalidateTexAll": 0x80360400,
		"GXInvalidateTexAll": 0x80360400,
		"gx::GXSetTexRegionCallback": 0x80360448,
		"GXSetTexRegionCallback": 0x80360448,
		"gx::GXSetTlutRegionCallback": 0x8036045c,
		"GXSetTlutRegionCallback": 0x8036045c,
		"gx::GXSetTexCoordScaleManually": 0x80360470,
		"GXSetTexCoordScaleManually": 0x80360470,
		"gx::GXSetTexCoordCylWrap": 0x8036050c,
		"GXSetTexCoordCylWrap": 0x8036050c,
		"gx::__SetSURegs": 0x80360590,
		"__SetSURegs": 0x80360590,
		"gx::__GXSetSUTexRegs": 0x8036065c,
		"__GXSetSUTexRegs": 0x8036065c,
		"gx::__GXSetTmemConfig": 0x803607d8,
		"__GXSetTmemConfig": 0x803607d8,
		"gx::GXSetTevIndirect": 0x80360a18,
		"GXSetTevIndirect": 0x80360a18,
		"gx::GXSetIndTexMtx": 0x80360ab4,
		"GXSetIndTexMtx": 0x80360ab4,
		"gx::GXSetIndTexCoordScale": 0x80360c14,
		"GXSetIndTexCoordScale": 0x80360c14,
		"gx::GXSetIndTexOrder": 0x80360de8,
		"GXSetIndTexOrder": 0x80360de8,
		"gx::GXSetNumIndStages": 0x80360f20,
		"GXSetNumIndStages": 0x80360f20,
		"gx::GXSetTevDirect": 0x80360f4c,
		"GXSetTevDirect": 0x80360f4c,
		"gx::GXSetTevIndWarp": 0x80360f94,
		"GXSetTevIndWarp": 0x80360f94,
		"gx::__GXUpdateBPMask": 0x80360ff8,
		"__GXUpdateBPMask": 0x80360ff8,
		"gx::__GXFlushTextureState": 0x803610c4,
		"__GXFlushTextureState": 0x803610c4,
		"gx::GXSetTevOp": 0x803610e8,
		"GXSetTevOp": 0x803610e8,
		"gx::GXSetTevColorIn": 0x8036128c,
		"GXSetTevColorIn": 0x8036128c,
		"gx::GXSetTevAlphaIn": 0x8036130c,
		"GXSetTevAlphaIn": 0x8036130c,
		"gx::GXSetTevColorOp": 0x80361390,
		"GXSetTevColorOp": 0x80361390,
		"gx::GXSetTevAlphaOp": 0x80361450,
		"GXSetTevAlphaOp": 0x80361450,
		"gx::GXSetTevColor": 0x80361510,
		"GXSetTevColor": 0x80361510,
		"gx::GXSetTevColorS10": 0x80361584,
		"GXSetTevColorS10": 0x80361584,
		"gx::GXSetTevKColor": 0x803615f8,
		"GXSetTevKColor": 0x803615f8,
		"gx::GXSetTevKColorSel": 0x8036166c,
		"GXSetTevKColorSel": 0x8036166c,
		"gx::GXSetTevKAlphaSel": 0x803616d8,
		"GXSetTevKAlphaSel": 0x803616d8,
		"gx::GXSetTevSwapMode": 0x80361744,
		"GXSetTevSwapMode": 0x80361744,
		"gx::GXSetTevSwapModeTable": 0x8036179c,
		"GXSetTevSwapModeTable": 0x8036179c,
		"gx::GXSetAlphaCompare": 0x8036183c,
		"GXSetAlphaCompare": 0x8036183c,
		"gx::GXSetZTexture": 0x8036188c,
		"GXSetZTexture": 0x8036188c,
		"gx::GXSetTevOrder": 0x80361910,
		"GXSetTevOrder": 0x80361910,
		"gx::GXSetNumTevStages": 0x80361aec,
		"GXSetNumTevStages": 0x80361aec,
		"gx::GXSetFog": 0x80361b20,
		"GXSetFog": 0x80361b20,
		"gx::GXSetFogRangeAdj": 0x80361cd0,
		"GXSetFogRangeAdj": 0x80361cd0,
		"gx::GXSetBlendMode": 0x80361dd0,
		"GXSetBlendMode": 0x80361dd0,
		"gx::GXSetColorUpdate": 0x80361ed4,
		"GXSetColorUpdate": 0x80361ed4,
		"gx::GXSetAlphaUpdate": 0x80361f14,
		"GXSetAlphaUpdate": 0x80361f14,
		"gx::GXSetZMode": 0x80361f54,
		"GXSetZMode": 0x80361f54,
		"gx::GXSetZCompLoc": 0x80361fcc,
		"GXSetZCompLoc": 0x80361fcc,
		"gx::GXSetPixelFmt": 0x8036200c,
		"GXSetPixelFmt": 0x8036200c,
		"gx::GXSetDither": 0x8036211c,
		"GXSetDither": 0x8036211c,
		"gx::GXSetDstAlpha": 0x8036215c,
		"GXSetDstAlpha": 0x8036215c,
		"gx::GXSetFieldMask": 0x803621b0,
		"GXSetFieldMask": 0x803621b0,
		"gx::GXSetFieldMode": 0x803621e8,
		"GXSetFieldMode": 0x803621e8,
		"gx::GXDrawSphere": 0x80362268,
		"GXDrawSphere": 0x80362268,
		"gx::GXDrawCubeFace": 0x803625e4,
		"GXDrawCubeFace": 0x803625e4,
		"gx::GXDrawCube": 0x803627fc,
		"GXDrawCube": 0x803627fc,
		"gx::__GXSetRange": 0x80362a4c,
		"__GXSetRange": 0x80362a4c,
		"gx::GXCallDisplayList": 0x80362a50,
		"GXCallDisplayList": 0x80362a50,
		"gx::GXProject": 0x80362ac0,
		"GXProject": 0x80362ac0,
		"gx::GXSetProjection": 0x80362c34,
		"GXSetProjection": 0x80362c34,
		"gx::GXGetProjectionv": 0x80362d08,
		"GXGetProjectionv": 0x80362d08,
		"gx::WriteMTXPS4x3": 0x80362d80,
		"WriteMTXPS4x3": 0x80362d80,
		"gx::WriteMTXPS3x3from3x4": 0x80362db4,
		"WriteMTXPS3x3from3x4": 0x80362db4,
		"gx::WriteMTXPS4x2": 0x80362de8,
		"WriteMTXPS4x2": 0x80362de8,
		"gx::GXLoadPosMtxImm": 0x80362e0c,
		"GXLoadPosMtxImm": 0x80362e0c,
		"gx::GXLoadPosMtxIndx": 0x80362e48,
		"GXLoadPosMtxIndx": 0x80362e48,
		"gx::GXLoadNrmMtxImm": 0x80362e78,
		"GXLoadNrmMtxImm": 0x80362e78,
		"gx::GXLoadNrmMtxIndx3x3": 0x80362eb8,
		"GXLoadNrmMtxIndx3x3": 0x80362eb8,
		"gx::GXSetCurrentMtx": 0x80362eec,
		"GXSetCurrentMtx": 0x80362eec,
		"gx::GXLoadTexMtxImm": 0x80362f28,
		"GXLoadTexMtxImm": 0x80362f28,
		"gx::GXSetViewportJitter": 0x80362fac,
		"GXSetViewportJitter": 0x80362fac,
		"gx::GXSetViewport": 0x803630c8,
		"GXSetViewport": 0x803630c8,
		"gx::GXGetViewportv": 0x803630ec,
		"GXGetViewportv": 0x803630ec,
		"gx::GXSetScissor": 0x80363138,
		"GXSetScissor": 0x80363138,
		"gx::GXSetScissorBoxOffset": 0x803631e8,
		"GXSetScissorBoxOffset": 0x803631e8,
		"gx::GXSetClipMode": 0x8036322c,
		"GXSetClipMode": 0x8036322c,
		"gx::__GXSetMatrixIndex": 0x80363254,
		"__GXSetMatrixIndex": 0x80363254,
		"gx::GXSetGPMetric": 0x803632d8,
		"GXSetGPMetric": 0x803632d8,
		"gx::GXClearGPMetric": 0x80363b70,
		"GXClearGPMetric": 0x80363b70,
		"gx::GXReadPixMetric": 0x80363b80,
		"GXReadPixMetric": 0x80363b80,
		"gx::GXClearPixMetric": 0x80363c10,
		"GXClearPixMetric": 0x80363c10,
		"OdemuExi2::DBClose": 0x80363c40,
		"DBClose": 0x80363c40,
		"OdemuExi2::DBOpen": 0x80363c44,
		"DBOpen": 0x80363c44,
		"OdemuExi2::DBWrite": 0x80363c48,
		"DBWrite": 0x80363c48,
		"OdemuExi2::DBRead": 0x80363ea8,
		"DBRead": 0x80363ea8,
		"OdemuExi2::DBQueryData": 0x80363f34,
		"DBQueryData": 0x80363f34,
		"OdemuExi2::DBInitInterrupts": 0x80363fd0,
		"DBInitInterrupts": 0x80363fd0,
		"OdemuExi2::DBInitComm": 0x80364024,
		"DBInitComm": 0x80364024,
		"OdemuExi2::DBGHandler": 0x8036409c,
		"DBGHandler": 0x8036409c,
		"OdemuExi2::MWCallback": 0x803640dc,
		"MWCallback": 0x803640dc,
		"OdemuExi2::DBGReadStatus": 0x80364118,
		"DBGReadStatus": 0x80364118,
		"OdemuExi2::DBGWrite": 0x803641c4,
		"DBGWrite": 0x803641c4,
		"OdemuExi2::DBGRead": 0x803642a0,
		"DBGRead": 0x803642a0,
		"OdemuExi2::DBGReadMailbox": 0x8036437c,
		"DBGReadMailbox": 0x8036437c,
		"OdemuExi2::DBGEXIImm": 0x80364428,
		"DBGEXIImm": 0x80364428,
		"amcstubs::EXI2_Init": 0x803646c0,
		"EXI2_Init": 0x803646c0,
		"amcstubs::EXI2_EnableInterrupts": 0x803646c4,
		"EXI2_EnableInterrupts": 0x803646c4,
		"amcstubs::EXI2_Poll": 0x803646c8,
		"EXI2_Poll": 0x803646c8,
		"amcstubs::EXI2_ReadN": 0x803646d0,
		"EXI2_ReadN": 0x803646d0,
		"amcstubs::EXI2_WriteN": 0x803646d8,
		"EXI2_WriteN": 0x803646d8,
		"amcstubs::EXI2_Reserve": 0x803646e0,
		"EXI2_Reserve": 0x803646e0,
		"amcstubs::EXI2_Unreserve": 0x803646e4,
		"EXI2_Unreserve": 0x803646e4,
		"amcstubs::AMC_IsStub": 0x803646e8,
		"AMC_IsStub": 0x803646e8,
		"odenotstub::Hu_IsStub": 0x803646f0,
		"Hu_IsStub": 0x803646f0,
		"gd::GDInitGDLObj": 0x803646f8,
		"GDInitGDLObj": 0x803646f8,
		"gd::GDFlushCurrToMem": 0x80364710,
		"GDFlushCurrToMem": 0x80364710,
		"gd::GDPadCurr32": 0x8036473c,
		"GDPadCurr32": 0x8036473c,
		"gd::GDOverflowed": 0x80364834,
		"GDOverflowed": 0x80364834,
		"gd::GDSetOverflowCallback": 0x80364864,
		"GDSetOverflowCallback": 0x80364864,
		"gd::GDSetVtxDescv": 0x8036486c,
		"GDSetVtxDescv": 0x8036486c,
		"gd::GDSetVtxAttrFmtv": 0x80364e68,
		"GDSetVtxAttrFmtv": 0x80364e68,
		"gd::GDSetArray": 0x80365488,
		"GDSetArray": 0x80365488,
		"gd::GDSetArrayRaw": 0x80365694,
		"GDSetArrayRaw": 0x80365694,
		"gd::GDSetCullMode": 0x8036589c,
		"GDSetCullMode": 0x8036589c,
		"gd::GDSetGenMode2": 0x80365a28,
		"GDSetGenMode2": 0x80365a28,
		"gd::GDSetLightAttn": 0x80365e64,
		"GDSetLightAttn": 0x80365e64,
		"gd::GDSetLightColor": 0x80366300,
		"GDSetLightColor": 0x80366300,
		"gd::GDSetLightPos": 0x803664a8,
		"GDSetLightPos": 0x803664a8,
		"gd::GDSetLightDir": 0x8036677c,
		"GDSetLightDir": 0x8036677c,
		"gd::GDSetChanMatColor": 0x80366a50,
		"GDSetChanMatColor": 0x80366a50,
		"gd::GDSetChanCtrl": 0x80366be8,
		"GDSetChanCtrl": 0x80366be8,
		"gd::GDSetBlendMode": 0x80366efc,
		"GDSetBlendMode": 0x80366efc,
		"gd::GDSetBlendModeEtc": 0x80367188,
		"GDSetBlendModeEtc": 0x80367188,
		"gd::GDSetZMode": 0x80367394,
		"GDSetZMode": 0x80367394,
		"gd::GDSetDstAlpha": 0x80367498,
		"GDSetDstAlpha": 0x80367498,
		"gd::GDSetTevOp": 0x80367584,
		"GDSetTevOp": 0x80367584,
		"gd::GDSetTevColorCalc": 0x80367818,
		"GDSetTevColorCalc": 0x80367818,
		"gd::GDSetTevAlphaCalcAndSwap": 0x80367a64,
		"GDSetTevAlphaCalcAndSwap": 0x80367a64,
		"gd::GDSetAlphaCompare": 0x80367cd8,
		"GDSetAlphaCompare": 0x80367cd8,
		"gd::GDSetTevOrder": 0x80367ddc,
		"GDSetTevOrder": 0x80367ddc,
		"gd::GDSetCurrentMtx": 0x80367f4c,
		"GDSetCurrentMtx": 0x80367f4c,
		"si::SIBusy": 0x80368318,
		"SIBusy": 0x80368318,
		"si::SIIsChanBusy": 0x80368338,
		"SIIsChanBusy": 0x80368338,
		"si::CompleteTransfer": 0x80368374,
		"CompleteTransfer": 0x80368374,
		"si::SIInterruptHandler": 0x80368670,
		"SIInterruptHandler": 0x80368670,
		"si::SIEnablePollingInterrupt": 0x803689b4,
		"SIEnablePollingInterrupt": 0x803689b4,
		"si::SIRegisterPollingHandler": 0x80368a4c,
		"SIRegisterPollingHandler": 0x80368a4c,
		"si::SIUnregisterPollingHandler": 0x80368b18,
		"SIUnregisterPollingHandler": 0x80368b18,
		"si::SIInit": 0x80368c0c,
		"SIInit": 0x80368c0c,
		"si::__SITransfer": 0x80368cb0,
		"__SITransfer": 0x80368cb0,
		"si::SIGetStatus": 0x80368ebc,
		"SIGetStatus": 0x80368ebc,
		"si::SISetCommand": 0x80368f38,
		"SISetCommand": 0x80368f38,
		"si::SITransferCommands": 0x80368f4c,
		"SITransferCommands": 0x80368f4c,
		"si::SISetXY": 0x80368f5c,
		"SISetXY": 0x80368f5c,
		"si::SIEnablePolling": 0x80368fc8,
		"SIEnablePolling": 0x80368fc8,
		"si::SIDisablePolling": 0x80369064,
		"SIDisablePolling": 0x80369064,
		"si::SIGetResponseRaw": 0x803690d0,
		"SIGetResponseRaw": 0x803690d0,
		"si::SIGetResponse": 0x803691a4,
		"SIGetResponse": 0x803691a4,
		"si::AlarmHandler": 0x80369268,
		"si::SITransfer": 0x803692f4,
		"SITransfer": 0x803692f4,
		"si::GetTypeCallback": 0x80369460,
		"GetTypeCallback": 0x80369460,
		"si::SIGetType": 0x803696f8,
		"SIGetType": 0x803696f8,
		"si::SIGetTypeAsync": 0x803698bc,
		"SIGetTypeAsync": 0x803698bc,
		"si::SISetSamplingRate": 0x803699f8,
		"SISetSamplingRate": 0x803699f8,
		"si::SIRefreshSamplingRate": 0x80369adc,
		"SIRefreshSamplingRate": 0x80369adc,
		"exi::SetExiInterruptMask": 0x80369b00,
		"SetExiInterruptMask": 0x80369b00,
		"exi::EXIImm": 0x80369bf4,
		"EXIImm": 0x80369bf4,
		"exi::EXIImmEx": 0x80369e50,
		"EXIImmEx": 0x80369e50,
		"exi::EXIDma": 0x80369ef0,
		"EXIDma": 0x80369ef0,
		"exi::EXISync": 0x80369fdc,
		"EXISync": 0x80369fdc,
		"exi::EXIClearInterrupts": 0x8036a214,
		"EXIClearInterrupts": 0x8036a214,
		"exi::EXISetExiCallback": 0x8036a25c,
		"EXISetExiCallback": 0x8036a25c,
		"exi::__EXIProbe": 0x8036a2d8,
		"__EXIProbe": 0x8036a2d8,
		"exi::EXIProbe": 0x8036a44c,
		"EXIProbe": 0x8036a44c,
		"exi::EXIProbeEx": 0x8036a4cc,
		"EXIProbeEx": 0x8036a4cc,
		"exi::EXIAttach": 0x8036a580,
		"EXIAttach": 0x8036a580,
		"exi::EXIDetach": 0x8036a68c,
		"EXIDetach": 0x8036a68c,
		"exi::EXISelect": 0x8036a748,
		"EXISelect": 0x8036a748,
		"exi::EXIDeselect": 0x8036a874,
		"EXIDeselect": 0x8036a874,
		"exi::EXIIntrruptHandler": 0x8036a984,
		"EXIIntrruptHandler": 0x8036a984,
		"exi::TCIntrruptHandler": 0x8036aa4c,
		"TCIntrruptHandler": 0x8036aa4c,
		"exi::EXTIntrruptHandler": 0x8036ac64,
		"EXTIntrruptHandler": 0x8036ac64,
		"exi::EXIInit": 0x8036ad2c,
		"EXIInit": 0x8036ad2c,
		"exi::EXILock": 0x8036ae40,
		"EXILock": 0x8036ae40,
		"exi::EXIUnlock": 0x8036af34,
		"EXIUnlock": 0x8036af34,
		"exi::EXIGetState": 0x8036b010,
		"EXIGetState": 0x8036b010,
		"exi::UnlockedHandler": 0x8036b028,
		"UnlockedHandler": 0x8036b028,
		"exi::EXIGetID": 0x8036b050,
		"EXIGetID": 0x8036b050,
		"exi::InitializeUART": 0x8036b3cc,
		"InitializeUART": 0x8036b3cc,
		"exi::ReadUARTN": 0x8036b43c,
		"ReadUARTN": 0x8036b43c,
		"exi::WriteUARTN": 0x8036b444,
		"WriteUARTN": 0x8036b444,
		"thp::THPVideoDecode": 0x8036b644,
		"THPVideoDecode": 0x8036b644,
		"thp::__THPSetupBuffers": 0x8036b888,
		"__THPSetupBuffers": 0x8036b888,
		"thp::__THPReadFrameHeader": 0x8036b8cc,
		"__THPReadFrameHeader": 0x8036b8cc,
		"thp::__THPReadScaneHeader": 0x8036ba08,
		"__THPReadScaneHeader": 0x8036ba08,
		"thp::__THPReadQuantizationTable": 0x8036bb24,
		"__THPReadQuantizationTable": 0x8036bb24,
		"thp::__THPReadHuffmanTableSpecification": 0x8036bee0,
		"__THPReadHuffmanTableSpecification": 0x8036bee0,
		"thp::__THPHuffGenerateSizeTable": 0x8036c0c0,
		"__THPHuffGenerateSizeTable": 0x8036c0c0,
		"thp::__THPHuffGenerateCodeTable": 0x8036c1b0,
		"__THPHuffGenerateCodeTable": 0x8036c1b0,
		"thp::__THPHuffGenerateDecoderTables": 0x8036c218,
		"__THPHuffGenerateDecoderTables": 0x8036c218,
		"thp::__THPRestartDefinition": 0x8036c3d4,
		"__THPRestartDefinition": 0x8036c3d4,
		"thp::__THPPrepBitStream": 0x8036c428,
		"__THPPrepBitStream": 0x8036c428,
		"thp::__THPDecompressYUV": 0x8036c674,
		"__THPDecompressYUV": 0x8036c674,
		"thp::__THPDecompressiMCURow512x448": 0x8036c780,
		"__THPDecompressiMCURow512x448": 0x8036c780,
		"thp::__THPDecompressiMCURow640x480": 0x8036e208,
		"__THPDecompressiMCURow640x480": 0x8036e208,
		"thp::__THPDecompressiMCURowNxN": 0x8036fc94,
		"__THPDecompressiMCURowNxN": 0x8036fc94,
		"thp::__THPHuffDecodeDCTCompY": 0x80371740,
		"__THPHuffDecodeDCTCompY": 0x80371740,
		"thp::__THPHuffDecodeDCTCompU": 0x80371dbc,
		"__THPHuffDecodeDCTCompU": 0x80371dbc,
		"thp::__THPHuffDecodeDCTCompV": 0x80372464,
		"__THPHuffDecodeDCTCompV": 0x80372464,
		"thp::THPInit": 0x80372b0c,
		"THPInit": 0x80372b0c,
		"thp::THPAudioDecode": 0x80372b84,
		"THPAudioDecode": 0x80372b84,
		"thp::__THPAudioGetNewSample": 0x80372fe8,
		"__THPAudioGetNewSample": 0x80372fe8,
		"thp::__THPAudioInitialize": 0x80373078,
		"__THPAudioInitialize": 0x80373078,
		"THPPlayer::PopDecodedAudioBuffer": 0x8001dab0,
		"PopDecodedAudioBuffer": 0x8001dab0,
		"THPPlayer::PushFreeAudioBuffer": 0x8001daf4,
		"PushFreeAudioBuffer": 0x8001daf4,
		"THPPlayer::AudioDecode": 0x8001db24,
		"AudioDecode": 0x8001db24,
		"THPPlayer::AudioDecoderForOnMemory": 0x8001dc20,
		"AudioDecoderForOnMemory": 0x8001dc20,
		"THPPlayer::AudioDecoder": 0x8001dcd0,
		"AudioDecoder": 0x8001dcd0,
		"THPPlayer::AudioDecodeThreadCancel": 0x8001dcf8,
		"AudioDecodeThreadCancel": 0x8001dcf8,
		"THPPlayer::AudioDecodeThreadStart": 0x8001dd34,
		"AudioDecodeThreadStart": 0x8001dd34,
		"THPPlayer::CreateAudioDecodeThread": 0x8001dd68,
		"CreateAudioDecodeThread": 0x8001dd68,
		"THPPlayer::THPGXYuv2RgbDraw": 0x8001de28,
		"THPGXYuv2RgbDraw": 0x8001de28,
		"THPPlayer::THPGXYuv2RgbSetup": 0x8001e00c,
		"THPGXYuv2RgbSetup": 0x8001e00c,
		"THPPlayer::THPGXRestore": 0x8001e4f0,
		"THPGXRestore": 0x8001e4f0,
		"THPPlayer::THPPlayerSetVolume": 0x8001e608,
		"THPPlayerSetVolume": 0x8001e608,
		"THPPlayer::MixAudio": 0x8001e744,
		"MixAudio": 0x8001e744,
		"THPPlayer::THPPlayerDrawDone": 0x8001e920,
		"THPPlayerDrawDone": 0x8001e920,
		"THPPlayer::THPPlayerGetState": 0x8001e994,
		"THPPlayerGetState": 0x8001e994,
		"THPPlayer::THPPlayerGetAudioInfo": 0x8001e9a4,
		"THPPlayerGetAudioInfo": 0x8001e9a4,
		"THPPlayer::THPPlayerGetVideoInfo": 0x8001e9ec,
		"THPPlayerGetVideoInfo": 0x8001e9ec,
		"THPPlayer::THPPlayerDrawCurrentFrame": 0x8001ea34,
		"THPPlayerDrawCurrentFrame": 0x8001ea34,
		"THPPlayer::ProperTimingForGettingNextFrame": 0x8001eb00,
		"ProperTimingForGettingNextFrame": 0x8001eb00,
		"THPPlayer::PlayControl": 0x8001ec24,
		"PlayControl": 0x8001ec24,
		"THPPlayer::THPPlayerPause": 0x8001eee8,
		"THPPlayerPause": 0x8001eee8,
		"THPPlayer::THPPlayerStop": 0x8001ef28,
		"THPPlayerStop": 0x8001ef28,
		"THPPlayer::THPPlayerPlay": 0x8001f000,
		"THPPlayerPlay": 0x8001f000,
		"THPPlayer::THPPlayerPrepare": 0x8001f05c,
		"THPPlayerPrepare": 0x8001f05c,
		"THPPlayer::PrepareReady": 0x8001f2cc,
		"PrepareReady": 0x8001f2cc,
		"THPPlayer::InitAllMessageQueue": 0x8001f2fc,
		"InitAllMessageQueue": 0x8001f2fc,
		"THPPlayer::THPPlayerSetBuffer": 0x8001f3cc,
		"THPPlayerSetBuffer": 0x8001f3cc,
		"THPPlayer::THPPlayerCalcNeedMemory": 0x8001f5fc,
		"THPPlayerCalcNeedMemory": 0x8001f5fc,
		"THPPlayer::THPPlayerClose": 0x8001f6a4,
		"THPPlayerClose": 0x8001f6a4,
		"THPPlayer::THPPlayerOpen": 0x8001f6fc,
		"THPPlayerOpen": 0x8001f6fc,
		"THPPlayer::THPPlayerQuit": 0x8001f98c,
		"THPPlayerQuit": 0x8001f98c,
		"THPPlayer::THPPlayerInit": 0x8001f9c0,
		"THPPlayerInit": 0x8001f9c0,
		"THPPlayer::audioCallbackWithMSound": 0x8001fa88,
		"audioCallbackWithMSound": 0x8001fa88,
		"THPPlayer::PushReadedBuffer2": 0x8001fb3c,
		"PushReadedBuffer2": 0x8001fb3c,
		"THPPlayer::PopReadedBuffer2": 0x8001fb6c,
		"PopReadedBuffer2": 0x8001fb6c,
		"THPPlayer::PushFreeReadBuffer": 0x8001fba0,
		"PushFreeReadBuffer": 0x8001fba0,
		"THPPlayer::PopReadedBuffer": 0x8001fbd0,
		"PopReadedBuffer": 0x8001fbd0,
		"THPPlayer::Reader": 0x8001fc04,
		"Reader": 0x8001fc04,
		"THPPlayer::ReadThreadCancel": 0x8001fcf4,
		"ReadThreadCancel": 0x8001fcf4,
		"THPPlayer::ReadThreadStart": 0x8001fd30,
		"ReadThreadStart": 0x8001fd30,
		"THPPlayer::CreateReadThread": 0x8001fd64,
		"CreateReadThread": 0x8001fd64,
		"THPPlayer::PopDecodedTextureSet": 0x8001fe00,
		"PopDecodedTextureSet": 0x8001fe00,
		"THPPlayer::PushFreeTextureSet": 0x8001fe44,
		"PushFreeTextureSet": 0x8001fe44,
		"THPPlayer::VideoDecode": 0x8001fe74,
		"VideoDecode": 0x8001fe74,
		"THPPlayer::VideoDecoderForOnMemory": 0x8001ffa4,
		"VideoDecoderForOnMemory": 0x8001ffa4,
		"THPPlayer::VideoDecoder": 0x800200d8,
		"VideoDecoder": 0x800200d8,
		"THPPlayer::VideoDecodeThreadCancel": 0x800201b4,
		"VideoDecodeThreadCancel": 0x800201b4,
		"THPPlayer::VideoDecodeThreadStart": 0x800201f0,
		"VideoDecodeThreadStart": 0x800201f0,
		"THPPlayer::CreateVideoDecodeThread": 0x80020224,
		"CreateVideoDecodeThread": 0x80020224,
		"TDLColorTexQuad::draw": 0x80224f0c,
		"TDLColorTexQuad::setEnd": 0x80224fac,
		"TDLColorTexQuad::requestCol": 0x80225144,
		"requestCol": 0x80225144,
		"TDLColorTexQuad::createBuffer": 0x80225328,
		"TDLTexQuad::draw": 0x80225408,
		"TDLTexQuad::setEnd": 0x80225510,
		"TDLTexQuad::request": 0x80225674,
		"TDLTexQuad::createBuffer": 0x80225810,
		"TDLTexQuad::createDLBuffer": 0x802258b0,
		"createDLBuffer": 0x802258b0,
		"TSilhouette::~TSilhouette": 0x80225968,
		"MarioUtil::SMS_UnifyMaterial": 0x802259dc,
		"SMS_UnifyMaterial": 0x802259dc,
		"MarioUtil::SMS_CalcMatAnmAndMakeDL": 0x80225a90,
		"SMS_CalcMatAnmAndMakeDL": 0x80225a90,
		"MarioUtil::SMS_ShowJoint": 0x80225b2c,
		"SMS_ShowJoint": 0x80225b2c,
		"MarioUtil::SMS_DrawInit": 0x80225b7c,
		"SMS_DrawInit": 0x80225b7c,
		"MarioUtil::SMS_MakeDLAndLock": 0x80225ba8,
		"SMS_MakeDLAndLock": 0x80225ba8,
		"MarioUtil::SMS_DrawShape": 0x80225c30,
		"SMS_DrawShape": 0x80225c30,
		"MarioUtil::SMS_SettingDrawShape": 0x80225c94,
		"SMS_SettingDrawShape": 0x80225c94,
		"MarioUtil::SMS_DrawCube": 0x80225d00,
		"SMS_DrawCube": 0x80225d00,
		"MarioUtil::SMS_CountPolygonNumInShape": 0x80225e80,
		"SMS_CountPolygonNumInShape": 0x80225e80,
		"MarioUtil::ViewFrustumClipCheck": 0x80225f5c,
		"ViewFrustumClipCheck": 0x80225f5c,
		"MarioUtil::SetViewFrustumClipCheckPerspective": 0x802260cc,
		"SetViewFrustumClipCheckPerspective": 0x802260cc,
		"MarioUtil::SetViewFrustumClipCheck": 0x80226174,
		"SetViewFrustumClipCheck": 0x80226174,
		"MarioUtil::SMS_ResetDamageFogEffect": 0x802264d8,
		"SMS_ResetDamageFogEffect": 0x802264d8,
		"MarioUtil::SMS_AddDamageFogEffect": 0x80226584,
		"SMS_AddDamageFogEffect": 0x80226584,
		"TTrembleModelEffect::reset": 0x802266a4,
		"TTrembleModelEffect::movement": 0x80226884,
		"JGeometry::TVec3<short><short>::sub": 0x80226d48,
		"TTrembleModelEffect::clash": 0x80226d7c,
		"clash": 0x80226d7c,
		"JGeometry::TVec3<short><short>::add": 0x80226f94,
		"TTrembleModelEffect::tremble": 0x80226fc8,
		"tremble": 0x80226fc8,
		"TTrembleModelEffect::init": 0x8022738c,
		"TSilhouette::perform": 0x80227914,
		"TSilhouette::setting": 0x80227d0c,
		"setting": 0x80227d0c,
		"TSilhouette::loadAfter": 0x80227ea8,
		"TSilhouette::load": 0x802280e4,
		"TLightWithDBSetManager::~TLightWithDBSetManager": 0x80228144,
		"TLightWithDBSetManager::getLightPos": 0x802281b8,
		"getLightPos": 0x802281b8,
		"TLightWithDBSetManager::makeDrawBuffer": 0x802281c0,
		"TLightWithDBSetManager::addChildGroupObj": 0x80228234,
		"addChildGroupObj": 0x80228234,
		"JGadget::TList_pointer<PQ26JDrama8TViewObj>::iterator::iterator": 0x80228364,
		"JGadget::TList_pointer<JDrama::TViewObj*>::end": 0x80228370,
		"TLightWithDBSetManager::perform": 0x80228394,
		"TLightWithDBSetManager::loadAfter": 0x80228490,
		"TLightWithDBSetManager::TLightWithDBSetManager": 0x80228534,
		"TLightWithDBSet::~TLightWithDBSet": 0x80228938,
		"TIndirectLightWithDBSet::makeDrawBuffer": 0x802289ac,
		"TLightDrawBuffer::setLight": 0x80228b40,
		"TMapObjectLightWithDBSet::makeDrawBuffer": 0x80228b74,
		"TObjectLightWithDBSet::makeDrawBuffer": 0x80228d08,
		"TPlayerLightWithDBSet::makeDrawBuffer": 0x80228eac,
		"TLightCommon::~TLightCommon": 0x8022905c,
		"TLightWithDBSet::resetLightDrawBuffer": 0x802290d0,
		"resetLightDrawBuffer": 0x802290d0,
		"TLightWithDBSet::changeLightDrawBuffer": 0x8022910c,
		"changeLightDrawBuffer": 0x8022910c,
		"TLightWithDBSet::perform": 0x80229178,
		"TLightDrawBuffer::perform": 0x802292c0,
		"TLightDrawBuffer::TLightDrawBuffer": 0x80229304,
		"TLightMario::getAmbColor": 0x80229430,
		"TLightMario::getLightColor": 0x80229510,
		"TLightMario::setLight": 0x80229610,
		"TLightMario::perform": 0x80229880,
		"TLightShadow::perform": 0x802298c0,
		"TLightCommon::perform": 0x802298fc,
		"TLightCommon::setLight": 0x80229a30,
		"TLightCommon::getLightPosition": 0x80229ca0,
		"getLightPosition": 0x80229ca0,
		"TLightCommon::getAmbColor": 0x80229cec,
		"TLightCommon::getLightColor": 0x80229d78,
		"TLightCommon::loadAfter": 0x80229e30,
		"TLightCommon::TLightCommon": 0x80229fbc,
		"TIndirectLightWithDBSet::~TIndirectLightWithDBSet": 0x8022a088,
		"TMapObjectLightWithDBSet::~TMapObjectLightWithDBSet": 0x8022a10c,
		"TObjectLightWithDBSet::~TObjectLightWithDBSet": 0x8022a190,
		"TPlayerLightWithDBSet::~TPlayerLightWithDBSet": 0x8022a214,
		"TLightDrawBuffer::~TLightDrawBuffer": 0x8022a298,
		"TLightMario::~TLightMario": 0x8022a30c,
		"TLightShadow::~TLightShadow": 0x8022a390,
		"MarioUtil::MsVECMag2": 0x8022a414,
		"MsVECMag2": 0x8022a414,
		"MarioUtil::MsVECNormalize": 0x8022a43c,
		"MsVECNormalize": 0x8022a43c,
		"MarioUtil::SMSCalcJumpVelocityXZ": 0x8022a468,
		"SMSCalcJumpVelocityXZ": 0x8022a468,
		"MarioUtil::SMSCalcJumpVelocityY": 0x8022a564,
		"SMSCalcJumpVelocityY": 0x8022a564,
		"MarioUtil::SMS_GoRotate": 0x8022a60c,
		"SMS_GoRotate": 0x8022a60c,
		"MarioUtil::MsIsInSight": 0x8022a6f4,
		"MsIsInSight": 0x8022a6f4,
		"MarioUtil::MsWrap": 0x8022a894,
		"MarioUtil::MsMtxSetTRS": 0x8022a8e8,
		"MsMtxSetTRS": 0x8022a8e8,
		"MarioUtil::MsMtxSetXYZRPH": 0x8022aa2c,
		"MsMtxSetXYZRPH": 0x8022aa2c,
		"MarioUtil::MsMtxSetRotRPH": 0x8022aadc,
		"MsMtxSetRotRPH": 0x8022aadc,
		"MarioUtil::MsGetRotFromZaxis": 0x8022abd4,
		"MsGetRotFromZaxis": 0x8022abd4,
		"MarioUtil::matan": 0x8022ae08,
		"matan": 0x8022ae08,
		"MarioUtil::FConverge": 0x8022b0ac,
		"FConverge": 0x8022b0ac,
		"MarioUtil::IConverge": 0x8022b0dc,
		"IConverge": 0x8022b0dc,
		"MarioUtil::SMS_GetActorMtx": 0x8022b10c,
		"SMS_GetActorMtx": 0x8022b10c,
		"TRope::moveHead": 0x8022b15c,
		"TRope::constraintTail": 0x8022b2e8,
		"constraintTail": 0x8022b2e8,
		"TRope::constraintHead": 0x8022b514,
		"constraintHead": 0x8022b514,
		"TRope::collision": 0x8022b6b8,
		"collision": 0x8022b6b8,
		"TRope::TRope": 0x8022b820,
		"TRopePoint::TRopePoint": 0x8022ba70,
		"MarioUtil::SMS_GetLightPerspectiveForEffectMtx": 0x8022ba74,
		"SMS_GetLightPerspectiveForEffectMtx": 0x8022ba74,
		"MarioUtil::SMS_MakeJointsToArc": 0x8022bae0,
		"SMS_MakeJointsToArc": 0x8022bae0,
		"TMultiMtxEffect::setUserArea": 0x8022bf88,
		"setUserArea": 0x8022bf88,
		"TMultiMtxEffect::setup": 0x8022bfd8,
		"JGeometry::TVec3<float><float>::__ct": 0x8022c4f0,
		"__ct": 0x8022c4f0,
		"TParamT<JGeometry::TVec3<float><float>>::TParamT": 0x8022c500,
		"MarioUtil::TMtxSwingRZReverseXZCallBack": 0x8022c578,
		"TMtxSwingRZReverseXZCallBack": 0x8022c578,
		"MarioUtil::TMtxSwingRZCallBack": 0x8022c624,
		"TMtxSwingRZCallBack": 0x8022c624,
		"TMtxSwingRZ::calcLocalXY": 0x8022c6b8,
		"calcLocalXY": 0x8022c6b8,
		"MarioUtil::TMtxTimeLagCallBack": 0x8022c918,
		"TMtxTimeLagCallBack": 0x8022c918,
		"TMtxTimeLag::calc": 0x8022c950,
		"MarioUtil::MtxToQuat": 0x8022cee4,
		"MtxToQuat": 0x8022cee4,
		"TMtxSwingRZ::getParams": 0x8022d114,
		"TMtxTimeLag::getParams": 0x8022d11c,
		"TMtxEffectBase::getParams": 0x8022d124,
		"TScreenTexture::~TScreenTexture": 0x8022d12c,
		"TScreenTexture::perform": 0x8022d1a0,
		"MarioUtil::SMS_FillScreenAlpha": 0x8022d1a4,
		"SMS_FillScreenAlpha": 0x8022d1a4,
		"TScreenTexture::replace": 0x8022d360,
		"replace": 0x8022d360,
		"TScreenTexture::load": 0x8022d474,
		"TAfterEffect::perform": 0x8022d4f8,
		"TAfterEffect::calcDashBlurValue": 0x8022dc98,
		"calcDashBlurValue": 0x8022dc98,
		"TAfterEffect::loadAfter": 0x8022dd74,
		"TAfterEffect::load": 0x8022ddec,
		"TAfterEffect::~TAfterEffect": 0x8022ded8,
		"TMBindShadowManager::~TMBindShadowManager": 0x8022df4c,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::erase": 0x8022e058,
		"JGadget::TList<P16TMBindShadowBody,Q27JGadget31TAllocator<P16TMBindShadowBody>>::iterator::iterator": 0x8022e0c4,
		"TMBindShadowManager::calcVtx": 0x8022e0cc,
		"calcVtx": 0x8022e0cc,
		"TMBindShadowManager::forceRequest": 0x8022ebbc,
		"forceRequest": 0x8022ebbc,
		"TMBindShadowManager::request": 0x8022ecec,
		"TMBindShadowManager::drawShadow": 0x8022f014,
		"drawShadow": 0x8022f014,
		"TMBindShadowManager::drawShadowGD": 0x8022fa40,
		"drawShadowGD": 0x8022fa40,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::~TSetup5$2216ShadowUtil_cpp": 0x80230384,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::~TSetup4$2207ShadowUtil_cpp": 0x802303e8,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::~TSetup3$2195ShadowUtil_cpp": 0x8023044c,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::~TSetup2$2190ShadowUtil_cpp": 0x802304b0,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::~TCylinder$2171ShadowUtil_cpp": 0x80230514,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::~TSetup1$2172ShadowUtil_cpp": 0x80230578,
		"TMBindShadowManager::drawShadowVolume": 0x802305dc,
		"drawShadowVolume": 0x802305dc,
		"MarioUtil::conectCubeSame": 0x80230e68,
		"conectCubeSame": 0x80230e68,
		"MarioUtil::conectCubeDiffer": 0x80230fac,
		"conectCubeDiffer": 0x80230fac,
		"TMBindShadowManager::perform": 0x80231108,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::insert": 0x802311d0,
		"TMBindShadowManager::load": 0x80231288,
		"TMBindShadowManager::TMBindShadowManager": 0x802313e4,
		"TAlphaShadowBlendQuad::TAlphaShadowBlendQuad": 0x8023161c,
		"TAlphaShadowQuadAry::TAlphaShadowQuadAry": 0x8023164c,
		"TAlphaShadowQuad::TAlphaShadowQuad": 0x80231664,
		"TCircleShadowRequest::TCircleShadowRequest": 0x80231680,
		"TModelShadowInfo::TModelShadowInfo": 0x802316c8,
		"TSquareShadowInfo::TSquareShadowInfo": 0x802316f4,
		"TMBindShadowBody::entryDrawShadow": 0x80231720,
		"entryDrawShadow": 0x80231720,
		"TMBindShadowBody::TMBindShadowBody": 0x802319f8,
		"TMBindShadowParts::calc": 0x80231dd0,
		"TMBindShadowParts::TMBindShadowParts": 0x80232048,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::makeDL": 0x80232334,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::makeDL": 0x80232394,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::makeDL": 0x802323f4,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::makeDL": 0x80232448,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::makeDL": 0x802324a8,
		"MarioUtil::GDOverflowCheck": 0x80232fec,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::makeDL": 0x80233024,
		"MarioUtil::ReInitTevStages": 0x80233174,
		"ReInitTevStages": 0x80233174,
		"MarioUtil::ReInitTransform": 0x802333e0,
		"ReInitTransform": 0x802333e0,
		"MarioUtil::ReInitGeometry": 0x8023364c,
		"ReInitGeometry": 0x8023364c,
		"MarioUtil::ReInitializeGX": 0x80233760,
		"ReInitializeGX": 0x80233760,
		"MarioUtil::SMS_EmitSinkInPollutionEffect": 0x802339b4,
		"SMS_EmitSinkInPollutionEffect": 0x802339b4,
		"MarioUtil::SMS_EmitRippleSea": 0x80233b9c,
		"SMS_EmitRippleSea": 0x80233b9c,
		"MarioUtil::SMS_EmitRipplePool": 0x80233c4c,
		"SMS_EmitRipplePool": 0x80233c4c,
		"MarioUtil::SMS_EmitRippleTiny": 0x80233cfc,
		"SMS_EmitRippleTiny": 0x80233cfc,
		"MarioUtil::SMS_CreateMinimumSDLModel": 0x80233d7c,
		"SMS_CreateMinimumSDLModel": 0x80233d7c,
		"MarioUtil::SMS_CreatePartsModel": 0x80233e00,
		"SMS_CreatePartsModel": 0x80233e00,
		"MarioUtil::SMS_RideMoveCalcLocalPos": 0x80233e70,
		"SMS_RideMoveCalcLocalPos": 0x80233e70,
		"MarioUtil::SMS_RideMoveByGroundActor": 0x80233f10,
		"SMS_RideMoveByGroundActor": 0x80233f10,
		"TMultiBtk::update": 0x802340a4,
		"TMultiBtk::setNthData": 0x80234130,
		"setNthData": 0x80234130,
		"TMultiBtk::TMultiBtk": 0x8023422c,
		"RumbleMgr::finishPause": 0x802342b0,
		"finishPause": 0x802342b0,
		"RumbleMgr::startPause": 0x802342c4,
		"startPause": 0x802342c4,
		"RumbleMgr::setActive": 0x80234338,
		"setActive": 0x80234338,
		"RumbleMgr::update": 0x802343ec,
		"RumbleMgr::reset": 0x802349c0,
		"RumbleMgr::init": 0x80234bb4,
		"RumbleMgr::RumbleMgr": 0x80234dc8,
		"RumbleControllerMgr::update": 0x80234f00,
		"RumbleControllerMgr::updateMotorCount": 0x80234fe4,
		"updateMotorCount": 0x80234fe4,
		"RumbleControllerMgr::stop": 0x80235064,
		"RumbleControllerMgr::reset": 0x80235250,
		"RumbleChannelMgr::update": 0x802353d8,
		"RumbleChannelMgr::RumbleChannelMgr": 0x80235688,
		"RumbleType::getIndex": 0x802356b4,
		"MarioUtil::SMS_ShowAllShapePacket": 0x80235728,
		"SMS_ShowAllShapePacket": 0x80235728,
		"MarioUtil::SMS_HideAllShapePacket": 0x80235828,
		"SMS_HideAllShapePacket": 0x80235828,
		"MarioUtil::SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x80235928,
		"SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x80235928,
		"MarioUtil::SMS_InitPacket_OneTevColorAndOneTevKColor": 0x802359b8,
		"SMS_InitPacket_OneTevColorAndOneTevKColor": 0x802359b8,
		"MarioUtil::SMS_InitPacket_OneTevKColorAndFog": 0x80235a50,
		"SMS_InitPacket_OneTevKColorAndFog": 0x80235a50,
		"MarioUtil::SMS_InitPacket_TwoTevKColor": 0x80235b38,
		"SMS_InitPacket_TwoTevKColor": 0x80235b38,
		"MarioUtil::SMS_InitPacket_OneTevKColor": 0x80235bc0,
		"SMS_InitPacket_OneTevKColor": 0x80235bc0,
		"MarioUtil::SMS_InitPacket_Fog": 0x80235c48,
		"SMS_InitPacket_Fog": 0x80235c48,
		"MarioUtil::SMS_InitPacket_ThreeTevColor": 0x80235cd4,
		"SMS_InitPacket_ThreeTevColor": 0x80235cd4,
		"MarioUtil::SMS_InitPacket_TwoTevColor": 0x80235d6c,
		"SMS_InitPacket_TwoTevColor": 0x80235d6c,
		"MarioUtil::SMS_InitPacket_OneTevColor": 0x80235df4,
		"SMS_InitPacket_OneTevColor": 0x80235df4,
		"MarioUtil::SMS_InitPacket_MatColor": 0x80235e7c,
		"SMS_InitPacket_MatColor": 0x80235e7c,
		"MarioUtil::ShapePacketCallBackFunc": 0x80235f04,
		"ShapePacketCallBackFunc": 0x80235f04,
		"MarioUtil::FifoSetFog": 0x80236694,
		"FifoSetFog": 0x80236694,
		"MarioUtil::FifoSetFogRangeAdj": 0x802367ec,
		"FifoSetFogRangeAdj": 0x802367ec,
		"TGDLStatic::make": 0x80236924,
		"make": 0x80236924,
		"TGDLStatic::alloc": 0x80236ab4,
		"TGDLStatic::~TGDLStatic": 0x80236b60,
		"TGDLStatic::TGDLSentinel::~TGDLSentinel": 0x80236bb4,
		"MarioUtil::TGDLStaticOverFlow": 0x80236c2c,
		"TGDLStaticOverFlow": 0x80236c2c,
		"MarioUtil::SMS_ChangeTextureAll": 0x80236c3c,
		"SMS_ChangeTextureAll": 0x80236c3c,
		"MarioUtil::SMS_GetSandRiseUpRatio": 0x80236d58,
		"SMS_GetSandRiseUpRatio": 0x80236d58,
		"MarioUtil::SMS_GetGroundActor": 0x80236da4,
		"SMS_GetGroundActor": 0x80236da4,
		"MarioUtil::SMS_GetMonteVillageAreaInMario": 0x80236dd8,
		"SMS_GetMonteVillageAreaInMario": 0x80236dd8,
		"Koga::ToolData::Attach": 0x80236fd4,
		"Attach": 0x80236fd4,
		"Koga::ToolData::~ToolData": 0x80236ff0,
		"Koga::ToolData::ToolData": 0x8023703c,
		"M3DUtil::M3UMtxCalcBlendAux": 0x802374d4,
		"M3UMtxCalcBlendAux": 0x802374d4,
		"M3UModel::setMtxCalc": 0x802378f0,
		"setMtxCalc": 0x802378f0,
		"M3UModel::perform": 0x802378f4,
		"M3UModel::entryOut": 0x802379cc,
		"M3UModel::entryIn": 0x80237a1c,
		"M3UModel::updateOut": 0x80237a98,
		"M3UModel::updateIn": 0x80237ae0,
		"M3UModel::updateInTexPatternAnm": 0x80237b2c,
		"updateInTexPatternAnm": 0x80237b2c,
		"M3UModel::updateInMotion": 0x80237b68,
		"M3UModel::changeAnmTexPattern": 0x80237c8c,
		"changeAnmTexPattern": 0x80237c8c,
		"M3UModel::changeMtxCalcAnmTransform": 0x80237cd0,
		"changeMtxCalcAnmTransform": 0x80237cd0,
		"M3UModelCommon::getMtxCalc": 0x80237d14,
		"MActor::updateMatAnm": 0x80237d70,
		"updateMatAnm": 0x80237d70,
		"MActor::entryOut": 0x80237e04,
		"MActorAnmBase::updateOut": 0x80237e80,
		"MActor::entryIn": 0x80237e84,
		"MActorAnmBase::updateIn": 0x80237f00,
		"MActor::updateOut": 0x80237f04,
		"MActor::updateIn": 0x80237fe8,
		"MActor::setBrkFromIndex": 0x802380cc,
		"setBrkFromIndex": 0x802380cc,
		"MActorAnmMatEach<J3DAnmTevRegKey>::setAnmFromIndex": 0x8023811c,
		"MActor::setBrk": 0x802381e4,
		"setBrk": 0x802381e4,
		"MActorAnmEach<J3DAnmTevRegKey>::setAnm": 0x80238234,
		"MActor::setBlk": 0x80238360,
		"setBlk": 0x80238360,
		"MActorAnmEach<J3DAnmClusterKey>::setAnm": 0x802383b0,
		"MActor::setBtkFromIndex": 0x802384dc,
		"setBtkFromIndex": 0x802384dc,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::setAnmFromIndex": 0x8023852c,
		"MActor::setBtk": 0x802385f4,
		"setBtk": 0x802385f4,
		"MActorAnmEach<J3DAnmTextureSRTKey>::setAnm": 0x80238644,
		"MActor::setBtpFromIndex": 0x80238770,
		"setBtpFromIndex": 0x80238770,
		"MActorAnmMatEach<J3DAnmTexPattern>::setAnmFromIndex": 0x802387d0,
		"MActor::setBtp": 0x80238898,
		"setBtp": 0x80238898,
		"MActorAnmEach<J3DAnmTexPattern>::setAnm": 0x802388e8,
		"MActor::setBpkFromIndex": 0x80238a14,
		"setBpkFromIndex": 0x80238a14,
		"MActorAnmMatEach<J3DAnmColorKey>::setAnmFromIndex": 0x80238a64,
		"MActor::setBpk": 0x80238b2c,
		"setBpk": 0x80238b2c,
		"MActorAnmEach<J3DAnmColorKey>::setAnm": 0x80238b7c,
		"MActorAnmEach<J3DAnmTransformKey>::setAnm": 0x80238ca8,
		"MActor::checkCurBckFromIndex": 0x80238dd4,
		"checkCurBckFromIndex": 0x80238dd4,
		"MActor::setBckFromIndex": 0x80238e04,
		"setBckFromIndex": 0x80238e04,
		"MActor::setBck": 0x80238e40,
		"setBck": 0x80238e40,
		"MActor::setFrameRate": 0x80238e7c,
		"setFrameRate": 0x80238e7c,
		"MActor::getCurAnmIdx": 0x80238e98,
		"getCurAnmIdx": 0x80238e98,
		"MActor::checkBckPass": 0x80238ebc,
		"checkBckPass": 0x80238ebc,
		"MActor::getFrameCtrl": 0x80238f08,
		"MActor::checkAnmFileExist": 0x80238f2c,
		"checkAnmFileExist": 0x80238f2c,
		"MActor::checkCurAnmFromIndex": 0x8023904c,
		"checkCurAnmFromIndex": 0x8023904c,
		"MActor::checkCurAnm": 0x80239084,
		"checkCurAnm": 0x80239084,
		"MActor::perform": 0x802391bc,
		"MActor::matAnmFrameUpdate": 0x80239394,
		"matAnmFrameUpdate": 0x80239394,
		"MActor::frameUpdate": 0x80239408,
		"frameUpdate": 0x80239408,
		"MActor::entry": 0x802394c8,
		"MActor::setLightType": 0x80239614,
		"setLightType": 0x80239614,
		"MActor::setLightData": 0x80239634,
		"setLightData": 0x80239634,
		"MActor::setLightID": 0x80239720,
		"setLightID": 0x80239720,
		"MActor::viewCalc": 0x80239734,
		"MActor::calc": 0x80239770,
		"MActor::calcAnm": 0x80239878,
		"calcAnm": 0x80239878,
		"MActor::updateOutSubBck": 0x80239a0c,
		"updateOutSubBck": 0x80239a0c,
		"MActor::updateInSubBck": 0x80239a98,
		"updateInSubBck": 0x80239a98,
		"MActor::setJointCallback": 0x80239b24,
		"setJointCallback": 0x80239b24,
		"MActor::offMakeDL": 0x80239b40,
		"offMakeDL": 0x80239b40,
		"MActor::unlockDLIfNeed": 0x80239b88,
		"unlockDLIfNeed": 0x80239b88,
		"MActor::resetDL": 0x80239bf8,
		"resetDL": 0x80239bf8,
		"MActor::initDL": 0x80239d3c,
		"initDL": 0x80239d3c,
		"MActor::setAnimation": 0x80239e64,
		"MActor::curAnmEndsNext": 0x80239edc,
		"curAnmEndsNext": 0x80239edc,
		"MActor::isCurAnmAlreadyEnd": 0x8023a048,
		"isCurAnmAlreadyEnd": 0x8023a048,
		"MActor::setModel": 0x8023a110,
		"MActorAnmBase::setModel": 0x8023a400,
		"MActor::MActor": 0x8023a408,
		"MActorAnmBase::MActorAnmBase": 0x8023a900,
		"MActorAnmBlk::verifySuffix": 0x8023a964,
		"MActorAnmBlk::setAnmFromIndex": 0x8023a98c,
		"MActorAnmBlk::updateOut": 0x8023aa0c,
		"MActorAnmBlk::updateIn": 0x8023aa34,
		"MActorAnmBrk::checkUseMaterialID": 0x8023aab0,
		"MActorAnmBrk::checkUseMaterialIDInit": 0x8023aaf0,
		"MActorAnmBrk::updateOut": 0x8023ab30,
		"MActorAnmBrk::updateIn": 0x8023ab5c,
		"MActorAnmBrk::setTevKColorAnmKeyPtr": 0x8023abb0,
		"setTevKColorAnmKeyPtr": 0x8023abb0,
		"J3DTevKColorAnm::~J3DTevKColorAnm": 0x8023acc0,
		"J3DTevKColorAnm::J3DTevKColorAnm": 0x8023ad00,
		"MActorAnmBrk::setTevColorAnmKeyPtr": 0x8023ad10,
		"setTevColorAnmKeyPtr": 0x8023ad10,
		"J3DTevColorAnm::~J3DTevColorAnm": 0x8023ae20,
		"J3DTevColorAnm::J3DTevColorAnm": 0x8023ae60,
		"MActorAnmBpk::updateOut": 0x8023ae70,
		"MActorAnmBpk::updateIn": 0x8023ae9c,
		"MActorAnmBpk::setMatColorAnmKeyPtr": 0x8023aee8,
		"setMatColorAnmKeyPtr": 0x8023aee8,
		"J3DMatColorAnm::~J3DMatColorAnm": 0x8023aff8,
		"J3DMatColorAnm::J3DMatColorAnm": 0x8023b038,
		"MActorAnmBpk::checkUseMaterialID": 0x8023b048,
		"MActorAnmBpk::checkUseMaterialIDInit": 0x8023b0a0,
		"MActorAnmBtk::updateOut": 0x8023b188,
		"MActorAnmBtk::updateIn": 0x8023b1b4,
		"MActorAnmBtk::setTexMtxAnmKeyPtr": 0x8023b204,
		"setTexMtxAnmKeyPtr": 0x8023b204,
		"J3DTexMtxAnm::~J3DTexMtxAnm": 0x8023b32c,
		"J3DTexMtxAnm::J3DTexMtxAnm": 0x8023b36c,
		"MActorAnmBtk::checkUseMaterialID": 0x8023b37c,
		"MActorAnmBtk::checkUseMaterialIDInit": 0x8023b3ec,
		"MActorAnmBtp::updateOut": 0x8023b4ec,
		"MActorAnmBtp::updateIn": 0x8023b518,
		"MActorAnmBtp::checkUseMaterialID": 0x8023b564,
		"MActorAnmBtp::checkUseMaterialIDInit": 0x8023b5bc,
		"MActorAnmBtp::setTexNoAnmFullPtr": 0x8023b6b0,
		"setTexNoAnmFullPtr": 0x8023b6b0,
		"MActorAnmBck::setAnmFromIndex": 0x8023b7c4,
		"MActorAnmBck::updateOut": 0x8023b8d4,
		"MActorAnmBck::updateIn": 0x8023b8f8,
		"MActorAnmBck::setModel": 0x8023b9d8,
		"J3DMtxCalcBasicAnm::J3DMtxCalcBasicAnm": 0x8023baa8,
		"MActorAnmBck::getOldMotionBlendFrame": 0x8023bb7c,
		"MActorAnmBck::setOldMotionBlendAnmPtr": 0x8023bbb0,
		"MActorAnmBck::getOldMotionBlendAnmPtr": 0x8023bbdc,
		"MActorAnmBck::setMotionBlendRatio": 0x8023bc10,
		"MActorAnmBck::getMotionBlendRatio": 0x8023bc3c,
		"MActorAnmBck::initNormalMotionBlend": 0x8023bc70,
		"initNormalMotionBlend": 0x8023bc70,
		"MActorAnmBck::initSimpleMotionBlend": 0x8023bcf0,
		"initSimpleMotionBlend": 0x8023bcf0,
		"MActorAnmBase::checkUseMaterialID": 0x8023bd80,
		"MActorAnmBase::checkUseMaterialIDInit": 0x8023bd84,
		"MActorAnmBrk::verifySuffix": 0x8023bd88,
		"MActorAnmBpk::verifySuffix": 0x8023bdb0,
		"MActorAnmBtk::verifySuffix": 0x8023bdd8,
		"MActorAnmBtp::verifySuffix": 0x8023be00,
		"MActorAnmBck::verifySuffix": 0x8023be28,
		"MActorAnmData::createSampleModelData": 0x8023be50,
		"createSampleModelData": 0x8023be50,
		"MActorAnmData::addFileTable": 0x8023beac,
		"addFileTable": 0x8023beac,
		"MActorAnmData::init": 0x8023c328,
		"MActorAnmData::partsNameToIdx": 0x8023c94c,
		"partsNameToIdx": 0x8023c94c,
		"M3DUtil::MActorCalcKeyCode": 0x8023c9ec,
		"MActorCalcKeyCode": 0x8023c9ec,
		"MActorAnmData::MActorAnmData": 0x8023ca1c,
		"MActorAnmDataBase::sortByFileNameRaw": 0x8023ca80,
		"sortByFileNameRaw": 0x8023ca80,
		"MActorAnmDataBase::checkLower": 0x8023cca0,
		"checkLower": 0x8023cca0,
		"MActorAnmDataEach<J3DAnmClusterKey>::loadAnmPtrArray": 0x8023cd68,
		"MActorAnmDataEach<J3DAnmTevRegKey>::loadAnmPtrArray": 0x8023ce58,
		"MActorAnmDataEach<J3DAnmTextureSRTKey>::loadAnmPtrArray": 0x8023cf48,
		"MActorAnmDataEach<J3DAnmTexPattern>::loadAnmPtrArray": 0x8023d038,
		"MActorAnmDataEach<J3DAnmColorKey>::loadAnmPtrArray": 0x8023d128,
		"MActorAnmDataEach<J3DAnmTransformKey>::loadAnmPtrArray": 0x8023d218,
		"SDLModel::~SDLModel": 0x8023d308,
		"SDLModel::viewCalcSimple": 0x8023d36c,
		"viewCalcSimple": 0x8023d36c,
		"SDLModel::entry": 0x8023d444,
		"JGadget::TList<SDLDrawBufToken*,JGadget::TAllocator<SDLDrawBufToken*>>::insert": 0x8023d5c4,
		"SDLModel::entryModelDataSDL": 0x8023d67c,
		"entryModelDataSDL": 0x8023d67c,
		"SDLMatPacket::~SDLMatPacket": 0x8023dd04,
		"SDLModel::SDLModel": 0x8023dd68,
		"SDLMatPacket::SDLMatPacket": 0x8023ddfc,
		"SDLModelData::entrySDLModels": 0x8023de38,
		"entrySDLModels": 0x8023de38,
		"SDLModelData::SDLModelData": 0x8023e034,
		"SDLModelData::recursiveEntry": 0x8023e098,
		"SDLModelData::entryNode": 0x8023e3a4,
		"entryNode": 0x8023e3a4,
		"SDLModelData::entrySameMat": 0x8023e430,
		"entrySameMat": 0x8023e430,
		"M3DUtil::SMS_MakeMActor": 0x8023e5c4,
		"SMS_MakeMActor": 0x8023e5c4,
		"M3DUtil::SMS_MakeMActorWithAnmData": 0x8023e63c,
		"SMS_MakeMActorWithAnmData": 0x8023e63c,
		"M3DUtil::SMS_MakeMActorsWithAnmData": 0x8023e6d8,
		"SMS_MakeMActorsWithAnmData": 0x8023e6d8,
		"M3DUtil::SMS_MakeSDLModelData": 0x8023e7bc,
		"SMS_MakeSDLModelData": 0x8023e7bc,
		"M3DUtil::SMS_MakeMActorFromSDLModelData": 0x8023e81c,
		"SMS_MakeMActorFromSDLModelData": 0x8023e81c,
		"SampleCtrlShape::SampleCtrlShape": 0x8023e8bc,
		"SampleCtrlMaterial::SampleCtrlMaterial": 0x8023e908,
		"SampleCtrlJoint::SampleCtrlJoint": 0x8023ede4,
		"SampleCtrlJoint::~SampleCtrlJoint": 0x8023ee48,
		"SampleCtrlMaterial::~SampleCtrlMaterial": 0x8023ee94,
		"SampleCtrlShape::~SampleCtrlShape": 0x8023eee0,
		"SampleCtrlModelData::SampleCtrlModelData": 0x8023ef2c,
		"SampleCtrlModelData::makeHierarchy": 0x8023f10c,
		"SampleCtrlModelData::~SampleCtrlModelData": 0x8023f208,
		"TMotionBlendCtrl::getOldMotionBlendFrame": 0x8023f254,
		"TMotionBlendCtrl::setOldMotionBlendAnmPtr": 0x8023f260,
		"TMotionBlendCtrl::getOldMotionBlendAnmPtr": 0x8023f26c,
		"TMotionBlendCtrl::setNewAnm": 0x8023f278,
		"setNewAnm": 0x8023f278,
		"TMotionBlendCtrl::keepCurAnm": 0x8023f29c,
		"keepCurAnm": 0x8023f29c,
		"TMotionBlendCtrl::setMotionBlendRatio": 0x8023f2b0,
		"TMotionBlendCtrl::getMotionBlendRatio": 0x8023f2bc,
		"TMotionBlendCtrl::execSimpleMotionBlend": 0x8023f2c8,
		"execSimpleMotionBlend": 0x8023f2c8,
		"TLodAnm::setBckAndBtpAnm": 0x8023f440,
		"setBckAndBtpAnm": 0x8023f440,
		"TLodAnm::setBtpAnm_": 0x8023f4a4,
		"setBtpAnm_": 0x8023f4a4,
		"TLodAnm::setBckAnm_": 0x8023f57c,
		"setBckAnm_": 0x8023f57c,
		"TLodAnm::TLodAnm": 0x8023f660,
		"TBaseParam::TBaseParam": 0x80287644,
		"TBaseParam::load": 0x80287694,
		"TMarioParticleManager::~TMarioParticleManager": 0x80287698,
		"System::SMSSetEmitterPolColor": 0x8028770c,
		"SMSSetEmitterPolColor": 0x8028770c,
		"TMarioParticleManager::getAvailableIdx": 0x80287828,
		"getAvailableIdx": 0x80287828,
		"TMarioParticleManager::emitTry": 0x8028794c,
		"emitTry": 0x8028794c,
		"TMarioParticleManager::emitParticleCallBack": 0x80287b04,
		"emitParticleCallBack": 0x80287b04,
		"TMarioParticleManager::emitAndBindToMtx": 0x80287c94,
		"emitAndBindToMtx": 0x80287c94,
		"TMarioParticleManager::emitAndBindToSRTMtxPtr": 0x80287d98,
		"emitAndBindToSRTMtxPtr": 0x80287d98,
		"TMarioParticleManager::emitAndBindToMtxPtr": 0x80287fdc,
		"emitAndBindToMtxPtr": 0x80287fdc,
		"TMarioParticleManager::emitAndBindToPosPtr": 0x80288220,
		"emitAndBindToPosPtr": 0x80288220,
		"TMarioParticleManager::emitWithRotate": 0x8028844c,
		"emitWithRotate": 0x8028844c,
		"TMarioParticleManager::emit": 0x8028856c,
		"TMarioParticleManager::perform": 0x80288780,
		"TMarioParticleManager::createEffectInfoAry": 0x80288b28,
		"createEffectInfoAry": 0x80288b28,
		"TMarioParticleManager::TMarioParticleManager": 0x80288bec,
		"TMarioParticleManager::TInfo::TInfo": 0x80288c58,
		"TMarioEmitterCallBackBindToSRTMtxPtr::draw": 0x80288c78,
		"TMarioEmitterCallBackBindToSRTMtxPtr::execute": 0x80288c7c,
		"TMarioEmitterCallBackBindToMtxPtr::draw": 0x80288ca8,
		"TMarioEmitterCallBackBindToMtxPtr::execute": 0x80288cac,
		"TMarioEmitterCallBackBindToPosPtr::draw": 0x80288cd8,
		"TMarioEmitterCallBackBindToPosPtr::execute": 0x80288cdc,
		"TEmitterIndirectViewObj::perform": 0x80288cfc,
		"TEmitterViewObj::perform": 0x80288db8,
		"TEmitterViewObj::TEmitterViewObj": 0x80288e5c,
		"TEmitterIndirectViewObj::~TEmitterIndirectViewObj": 0x80288ed4,
		"TEmitterViewObj::~TEmitterViewObj": 0x80288f58,
		"System::__sinit_EmitterViewObj_cpp": 0x80288fd0,
		"__sinit_EmitterViewObj_cpp": 0x80288fd0,
		"TEventWatcher::perform": 0x80288ffc,
		"TEventWatcher::launchScript": 0x8028903c,
		"launchScript": 0x8028903c,
		"TSpcTypedBinary<TEventWatcher>::initUserBuiltin": 0x80289200,
		"System::evIsWaterMelonIsReached": 0x80289ab0,
		"evIsWaterMelonIsReached": 0x80289ab0,
		"System::evInvalidatePad": 0x80289c20,
		"evInvalidatePad": 0x80289c20,
		"System::evOnNeutralMarioKey": 0x80289d64,
		"evOnNeutralMarioKey": 0x80289d64,
		"System::evWarpFrontToMario": 0x80289e04,
		"evWarpFrontToMario": 0x80289e04,
		"System::evAppear8RedCoinsAndTimer": 0x8028a038,
		"evAppear8RedCoinsAndTimer": 0x8028a038,
		"System::evAppearReadyGo": 0x8028a220,
		"evAppearReadyGo": 0x8028a220,
		"System::evSetEventForWaterMelon": 0x8028a2c0,
		"evSetEventForWaterMelon": 0x8028a2c0,
		"System::evStartAppearJetBalloon": 0x8028a484,
		"evStartAppearJetBalloon": 0x8028a484,
		"System::evWarpMario": 0x8028a6e0,
		"evWarpMario": 0x8028a6e0,
		"System::evSetCollision": 0x8028aa60,
		"evSetCollision": 0x8028aa60,
		"System::evChangeSunglass": 0x8028acd4,
		"evChangeSunglass": 0x8028acd4,
		"System::evStartMiss": 0x8028aec8,
		"evStartMiss": 0x8028aec8,
		"System::evStartEventSE": 0x8028af60,
		"evStartEventSE": 0x8028af60,
		"System::evStartSE": 0x8028b0e8,
		"evStartSE": 0x8028b0e8,
		"System::evStopBGM": 0x8028b24c,
		"evStopBGM": 0x8028b24c,
		"System::evPutNozzle": 0x8028b388,
		"evPutNozzle": 0x8028b388,
		"System::evEggYoshiStartFruit": 0x8028b558,
		"evEggYoshiStartFruit": 0x8028b558,
		"System::evStartBGM": 0x8028b728,
		"evStartBGM": 0x8028b728,
		"System::evManiCoinDown": 0x8028b860,
		"evManiCoinDown": 0x8028b860,
		"System::evSetEventID": 0x8028b8fc,
		"evSetEventID": 0x8028b8fc,
		"System::evSetTransScale": 0x8028bb54,
		"evSetTransScale": 0x8028bb54,
		"System::evIsInsideFastCube": 0x8028c1c8,
		"evIsInsideFastCube": 0x8028c1c8,
		"System::evIsFinishMareBottleDemo": 0x8028c488,
		"evIsFinishMareBottleDemo": 0x8028c488,
		"System::evStartMareBottleDemo": 0x8028c57c,
		"evStartMareBottleDemo": 0x8028c57c,
		"System::evSetMarioWaiting": 0x8028c68c,
		"evSetMarioWaiting": 0x8028c68c,
		"System::evIsInsideCube": 0x8028c734,
		"evIsInsideCube": 0x8028c734,
		"System::evKillWoodBox": 0x8028c8b8,
		"evKillWoodBox": 0x8028c8b8,
		"System::evRefreshWoodBox": 0x8028cb5c,
		"evRefreshWoodBox": 0x8028cb5c,
		"System::evCheckWoodBox": 0x8028ce00,
		"evCheckWoodBox": 0x8028ce00,
		"System::evStartMarioTalking": 0x8028d0ac,
		"evStartMarioTalking": 0x8028d0ac,
		"System::evChangeNozzle": 0x8028d144,
		"evChangeNozzle": 0x8028d144,
		"System::evAppearShineForWoodBox": 0x8028d2a0,
		"evAppearShineForWoodBox": 0x8028d2a0,
		"System::evAppearShineFromKageMario": 0x8028d40c,
		"evAppearShineFromKageMario": 0x8028d40c,
		"System::evAppearShineFromNPCWithoutDemo": 0x8028d6c8,
		"evAppearShineFromNPCWithoutDemo": 0x8028d6c8,
		"System::evAppearShine": 0x8028d958,
		"evAppearShine": 0x8028d958,
		"System::evAppearShineFromNPC": 0x8028db80,
		"evAppearShineFromNPC": 0x8028db80,
		"System::evAppearMushroom1up": 0x8028dee4,
		"evAppearMushroom1up": 0x8028dee4,
		"System::evKillMushroom1up": 0x8028e0dc,
		"evKillMushroom1up": 0x8028e0dc,
		"System::evKillShine": 0x8028e2ac,
		"evKillShine": 0x8028e2ac,
		"System::evGetTime": 0x8028e47c,
		"evGetTime": 0x8028e47c,
		"System::evMonteManReachFlag": 0x8028e518,
		"evMonteManReachFlag": 0x8028e518,
		"System::evStopTimer": 0x8028e604,
		"evStopTimer": 0x8028e604,
		"System::evStartMonteman": 0x8028e6a0,
		"evStartMonteman": 0x8028e6a0,
		"System::evStartTimer": 0x8028e82c,
		"evStartTimer": 0x8028e82c,
		"System::evInsertTimer": 0x8028e998,
		"evInsertTimer": 0x8028e998,
		"System::evForceCloseTalk": 0x8028ebcc,
		"evForceCloseTalk": 0x8028ebcc,
		"System::evRaiseBuilding": 0x8028ec64,
		"evRaiseBuilding": 0x8028ec64,
		"System::evIsMapEventFinishedAll": 0x8028edf4,
		"evIsMapEventFinishedAll": 0x8028edf4,
		"System::evStartOpenModelGate": 0x8028efc8,
		"evStartOpenModelGate": 0x8028efc8,
		"System::evStartEMarioDisappear": 0x8028f18c,
		"evStartEMarioDisappear": 0x8028f18c,
		"System::evStartEMarioGateDrawing": 0x8028f350,
		"evStartEMarioGateDrawing": 0x8028f350,
		"System::evStartEMarioRunAway": 0x8028f514,
		"evStartEMarioRunAway": 0x8028f514,
		"System::evIsEMarioDownWaitingToTalk": 0x8028f6d8,
		"evIsEMarioDownWaitingToTalk": 0x8028f6d8,
		"System::evIsEMarioReachedToGoal": 0x8028f8a0,
		"evIsEMarioReachedToGoal": 0x8028f8a0,
		"System::evLaunchEventClearDemo": 0x8028fa68,
		"evLaunchEventClearDemo": 0x8028fa68,
		"System::evIsBossDefeated": 0x8028fb18,
		"evIsBossDefeated": 0x8028fb18,
		"System::evSetGraffitoMultiplied": 0x8028fbc4,
		"evSetGraffitoMultiplied": 0x8028fbc4,
		"System::evIsGraffitoCoverage0": 0x8028fd70,
		"evIsGraffitoCoverage0": 0x8028fd70,
		"System::evGameOver": 0x8028fe1c,
		"evGameOver": 0x8028fe1c,
		"System::evRegisterMovie": 0x8028febc,
		"evRegisterMovie": 0x8028febc,
		"System::evSetNextStage": 0x80290000,
		"evSetNextStage": 0x80290000,
		"System::evGetPollutionLevel": 0x80290208,
		"evGetPollutionLevel": 0x80290208,
		"System::evGetRestTime": 0x802902a0,
		"evGetRestTime": 0x802902a0,
		"System::evSetPollutionIncreaseCount": 0x8029037c,
		"evSetPollutionIncreaseCount": 0x8029037c,
		"System::evSetAttentionTime": 0x80290434,
		"evSetAttentionTime": 0x80290434,
		"System::evSetTimeLimit": 0x802904ec,
		"evSetTimeLimit": 0x802904ec,
		"System::evSetDead4LiveActor": 0x80290640,
		"evSetDead4LiveActor": 0x80290640,
		"System::evSetHide4LiveActor": 0x8029086c,
		"evSetHide4LiveActor": 0x8029086c,
		"System::evIsOnLiveActorFlag": 0x80290a98,
		"evIsOnLiveActorFlag": 0x80290a98,
		"System::evPushNerve4LiveActor": 0x80290d00,
		"evPushNerve4LiveActor": 0x80290d00,
		"System::evSetFlagNPCCanTaken": 0x80290f54,
		"evSetFlagNPCCanTaken": 0x80290f54,
		"System::evIsTalkModeNow": 0x80291168,
		"evIsTalkModeNow": 0x80291168,
		"System::evSetValue2TalkVariable": 0x8029122c,
		"evSetValue2TalkVariable": 0x8029122c,
		"System::evGetTalkSelectedValue": 0x80291310,
		"evGetTalkSelectedValue": 0x80291310,
		"System::evGetTalkMode": 0x802913ac,
		"evGetTalkMode": 0x802913ac,
		"System::evSetTalkMsgID": 0x80291444,
		"evSetTalkMsgID": 0x80291444,
		"System::evGetTalkNPCName": 0x80291644,
		"evGetTalkNPCName": 0x80291644,
		"System::evGetTalkNPC": 0x80291784,
		"evGetTalkNPC": 0x80291784,
		"System::evIsNearActors": 0x8029182c,
		"evIsNearActors": 0x8029182c,
		"System::evIsNearSameActors": 0x80291bb0,
		"evIsNearSameActors": 0x80291bb0,
		"System::evSetFlagNPCDead": 0x802920b8,
		"evSetFlagNPCDead": 0x802920b8,
		"System::evSetFlagNPCDontThrow": 0x80292340,
		"evSetFlagNPCDontThrow": 0x80292340,
		"System::evSetFlagNPCDontTalk": 0x802925c8,
		"evSetFlagNPCDontTalk": 0x802925c8,
		"System::evGetNPCType": 0x80292850,
		"evGetNPCType": 0x80292850,
		"System::evGetNameRefName": 0x80292a30,
		"evGetNameRefName": 0x80292a30,
		"System::evGetNameRefHandle": 0x80292b98,
		"evGetNameRefHandle": 0x80292b98,
		"System::evSetSystemFlag": 0x80292ce8,
		"evSetSystemFlag": 0x80292ce8,
		"System::evGetSystemFlag": 0x80292ed4,
		"evGetSystemFlag": 0x80292ed4,
		"TSpcTypedInterp<TEventWatcher>::~TSpcTypedInterp": 0x80293010,
		"~TSpcTypedInterp": 0x80293010,
		"TSpcTypedBinary<TEventWatcher>::~TSpcTypedBinary": 0x80293074,
		"TSpcTypedInterp<TEventWatcher>::dispatchBuiltin": 0x802930d8,
		"System::__sinit_EventWatcher_cpp": 0x80293150,
		"__sinit_EventWatcher_cpp": 0x80293150,
		"TFlagManager::saveOption": 0x8029344c,
		"saveOption": 0x8029344c,
		"TFlagManager::loadOption": 0x802935ac,
		"loadOption": 0x802935ac,
		"TFlagManager::correctOptFlag": 0x802936e0,
		"correctOptFlag": 0x802936e0,
		"TFlagManager::resetOpt": 0x802937bc,
		"resetOpt": 0x802937bc,
		"TFlagManager::saveFail": 0x802937cc,
		"saveFail": 0x802937cc,
		"TFlagManager::saveSuccess": 0x80293804,
		"saveSuccess": 0x80293804,
		"TFlagManager::save": 0x8029385c,
		"TFlagManager::correctFlag": 0x802939f0,
		"correctFlag": 0x802939f0,
		"TFlagManager::firstStart": 0x80293ba8,
		"firstStart": 0x80293ba8,
		"TFlagManager::restore": 0x80293dfc,
		"restore": 0x80293dfc,
		"TFlagManager::load": 0x80294050,
		"TFlagManager::setNozzleRight": 0x8029439c,
		"setNozzleRight": 0x8029439c,
		"TFlagManager::getNozzleRight": 0x8029443c,
		"getNozzleRight": 0x8029443c,
		"TFlagManager::setBlueCoinFlag": 0x802944cc,
		"setBlueCoinFlag": 0x802944cc,
		"TFlagManager::getBlueCoinFlag": 0x80294580,
		"getBlueCoinFlag": 0x80294580,
		"TFlagManager::incGoldCoinFlag": 0x80294610,
		"incGoldCoinFlag": 0x80294610,
		"TFlagManager::setShineFlag": 0x802946ac,
		"setShineFlag": 0x802946ac,
		"TFlagManager::getShineFlag": 0x80294728,
		"getShineFlag": 0x80294728,
		"TFlagManager::incMario": 0x8029476c,
		"incMario": 0x8029476c,
		"TFlagManager::decFlag": 0x802947d0,
		"decFlag": 0x802947d0,
		"TFlagManager::incFlag": 0x802947f4,
		"incFlag": 0x802947f4,
		"TFlagManager::setBool": 0x802948e4,
		"setBool": 0x802948e4,
		"TFlagManager::getBool": 0x80294a24,
		"getBool": 0x80294a24,
		"TFlagManager::setFlag": 0x80294b1c,
		"setFlag": 0x80294b1c,
		"TFlagManager::getFlag": 0x80294d4c,
		"getFlag": 0x80294d4c,
		"TFlagManager::resetStage": 0x80294ef4,
		"resetStage": 0x80294ef4,
		"TFlagManager::resetGame": 0x802950a0,
		"resetGame": 0x802950a0,
		"TFlagManager::resetCard": 0x80295270,
		"resetCard": 0x80295270,
		"TFlagManager::start": 0x80295484,
		"TGCLogoDir::direct_dolby": 0x80295524,
		"direct_dolby": 0x80295524,
		"TGCLogoDir::direct_nlogo": 0x80295688,
		"direct_nlogo": 0x80295688,
		"TGCLogoDir::direct": 0x80295a0c,
		"TGCLogoDir::setup": 0x80295c10,
		"TGCLogoDir::TGCLogoDir": 0x80296330,
		"TNintendo2D::perform": 0x802963f0,
		"TNintendo2D::~TNintendo2D": 0x802965c0,
		"System::__sinit_GCLogoDir_cpp": 0x80296634,
		"__sinit_GCLogoDir_cpp": 0x80296634,
		"TGXAlphaUpdate::~TGXAlphaUpdate": 0x80296938,
		"TGXAlphaUpdate::perform": 0x802969ac,
		"TReInitGX::perform": 0x80296a00,
		"TSMSDrawInit::perform": 0x80296a28,
		"TJ3DSysSetViewMtx::perform": 0x80296a50,
		"TJ3DSysFlag::perform": 0x80296a84,
		"TReInitGX::~TReInitGX": 0x80296b08,
		"TSMSDrawInit::~TSMSDrawInit": 0x80296b7c,
		"TJ3DSysSetViewMtx::~TJ3DSysSetViewMtx": 0x80296bf0,
		"TJ3DSysFlag::~TJ3DSysFlag": 0x80296c64,
		"TMarDirector::registerEventWatcher": 0x80296cd8,
		"registerEventWatcher": 0x80296cd8,
		"TMarDirector::setup": 0x80296d60,
		"TMarDirector::setupThreadFunc": 0x80296dd4,
		"TMarDirector::TMarDirector": 0x80296df4,
		"TMarDirector::TDemoInfo::TDemoInfo": 0x80297170,
		"JGadget::TSingleNodeLinkList::Initialize_": 0x8029717c,
		"Initialize_": 0x8029717c,
		"System::__sinit_MarDirector_cpp": 0x80297194,
		"__sinit_MarDirector_cpp": 0x80297194,
		"TMarDirector::moveStage": 0x80297584,
		"moveStage": 0x80297584,
		"TMarDirector::updateGameMode": 0x802979b4,
		"updateGameMode": 0x802979b4,
		"TGameSequence::set": 0x8029823c,
		"TMarDirector::nextStateInitialize": 0x80298250,
		"nextStateInitialize": 0x80298250,
		"TMarDirector::setMario": 0x802988dc,
		"setMario": 0x802988dc,
		"TMarDirector::currentStateFinalize": 0x80298bb0,
		"currentStateFinalize": 0x80298bb0,
		"TMarDirector::changeState": 0x80298e80,
		"System::decideNextScenario": 0x802995ec,
		"decideNextScenario": 0x802995ec,
		"System::decideNextStage": 0x80299740,
		"decideNextStage": 0x80299740,
		"JDrama::TFlagT<unsigned_short><unsigned_short>::set": 0x80299824,
		"System::__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x8029982c,
		"__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x8029982c,
		"TMarDirector::direct": 0x80299838,
		"System::__sinit_MarDirectorDirect_cpp": 0x80299d48,
		"__sinit_MarDirectorDirect_cpp": 0x80299d48,
		"TMarDirector::fireStreamingMovie": 0x8029a044,
		"fireStreamingMovie": 0x8029a044,
		"TMarDirector::fireEndDemoCamera": 0x8029a22c,
		"fireEndDemoCamera": 0x8029a22c,
		"TMarDirector::fireStartDemoCamera": 0x8029a23c,
		"fireStartDemoCamera": 0x8029a23c,
		"TMarDirector::setNextStage": 0x8029a31c,
		"setNextStage": 0x8029a31c,
		"TMarDirector::movement": 0x8029a4ac,
		"TMarDirector::fireRideYoshi": 0x8029a4dc,
		"fireRideYoshi": 0x8029a4dc,
		"TMarDirector::fireGetStar": 0x8029a564,
		"fireGetStar": 0x8029a564,
		"TMarDirector::fireGetNozzle": 0x8029a5e0,
		"fireGetNozzle": 0x8029a5e0,
		"TMarDirector::fireGetBlueCoin": 0x8029a6f0,
		"fireGetBlueCoin": 0x8029a6f0,
		"TMarDirector::movement_game": 0x8029a788,
		"movement_game": 0x8029a788,
		"TMarDirector::findNearestTalkNPC": 0x8029a94c,
		"findNearestTalkNPC": 0x8029a94c,
		"TMarDirector::entryNPC": 0x8029aa0c,
		"entryNPC": 0x8029aa0c,
		"System::__sinit_MarDirectorEvent_cpp": 0x8029aa40,
		"__sinit_MarDirectorEvent_cpp": 0x8029aa40,
		"TMarDirector::setupPerformList_console": 0x8029ad3c,
		"setupPerformList_console": 0x8029ad3c,
		"TMarDirector::initECDisp": 0x8029ae4c,
		"initECDisp": 0x8029ae4c,
		"TMarDirector::initECTMir": 0x8029badc,
		"initECTMir": 0x8029badc,
		"TMarDirector::initECTGft": 0x8029bbd4,
		"initECTGft": 0x8029bbd4,
		"TMarDirector::preEntry": 0x8029c1a4,
		"preEntry": 0x8029c1a4,
		"TMarDirector::setup2": 0x8029c6f8,
		"setup2": 0x8029c6f8,
		"System::__sinit_MarDirectorSetup2_cpp": 0x8029ccb4,
		"__sinit_MarDirectorSetup2_cpp": 0x8029ccb4,
		"System::MarErrInit": 0x8029cfc0,
		"MarErrInit": 0x8029cfc0,
		"System::MarErrException": 0x8029d040,
		"MarErrException": 0x8029d040,
		"TMarNameRefGen::getNameRef": 0x8029d0dc,
		"TStagePositionInfo::~TStagePositionInfo": 0x8029edf8,
		"std::__copy<TStagePositionInfo,0,0>::copy": 0x8029ee5c,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::TVector": 0x8029f014,
		"TScenarioArchiveName::~TScenarioArchiveName": 0x8029f040,
		"std::__copy<TScenarioArchiveName,0,0>::copy": 0x8029f0a4,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::TVector": 0x8029f1c8,
		"TCubeGeneralInfo::TCubeGeneralInfo": 0x8029f1f4,
		"std::__copy<TCameraMapTool,0,0>::copy": 0x8029f29c,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::TVector": 0x8029f4a4,
		"TStageEventInfo::~TStageEventInfo": 0x8029f4d0,
		"std::__copy<TStageEventInfo,0,0>::copy": 0x8029f534,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::TVector": 0x8029f714,
		"TCubeManagerMarioIn::~TCubeManagerMarioIn": 0x8029f740,
		"TSunGlass::TSunGlass": 0x8029f7c4,
		"JGadget::TList_pointer<THitActor*>::TList_pointer": 0x8029f874,
		"TList_pointer": 0x8029f874,
		"TWaterSplash::TWaterSplash": 0x8029f918,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::searchF": 0x8029f91c,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::loadAfter": 0x8029f9b8,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::load": 0x8029fa18,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::erase": 0x8029fc10,
		"TStagePositionInfo::TStagePositionInfo": 0x8029fcf4,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::InsertRaw": 0x8029fd38,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::searchF": 0x802a01e8,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::loadAfter": 0x802a0284,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::load": 0x802a02e4,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::perform": 0x802a03f4,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::searchF": 0x802a04b0,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfterSuper": 0x802a0598,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfter": 0x802a05b8,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadSuper": 0x802a0670,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::load": 0x802a0690,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::searchF": 0x802a07d8,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::loadAfter": 0x802a0874,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::load": 0x802a08d4,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::erase": 0x802a0acc,
		"TCameraMapTool::TCameraMapTool": 0x802a0bb0,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::InsertRaw": 0x802a0c24,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::searchF": 0x802a1124,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::loadAfter": 0x802a11c0,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::load": 0x802a1220,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::searchF": 0x802a1330,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::loadAfter": 0x802a13cc,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::load": 0x802a142c,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::erase": 0x802a1604,
		"TScenarioArchiveName::TScenarioArchiveName": 0x802a16e8,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::InsertRaw": 0x802a171c,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::~TNameRefAryT": 0x802a1b08,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::~TNameRefPtrAryT": 0x802a1b8c,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::~TNameRefAryT": 0x802a1c04,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::~TNameRefAryT": 0x802a1c88,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::~TNameRefAryT": 0x802a1d0c,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::erase": 0x802a1d90,
		"TCubeManagerFast::~TCubeManagerFast": 0x802a1e0c,
		"TCubeManagerArea::~TCubeManagerArea": 0x802a1ea0,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::searchF": 0x802a1f34,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::loadAfter": 0x802a1fd0,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::load": 0x802a2030,
		"TStageEventInfo::TStageEventInfo": 0x802a2290,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::InsertRaw": 0x802a22fc,
		"TStageEventInfo::operator_=": 0x802a261c,
		"System::__sinit_MarNameRefGen_cpp": 0x802a2670,
		"__sinit_MarNameRefGen_cpp": 0x802a2670,
		"TMenuDirector::setFixedStageValue": 0x802a296c,
		"setFixedStageValue": 0x802a296c,
		"TMenuDirector::direct": 0x802a2da4,
		"TMenuDirector::rsetup": 0x802a369c,
		"TMenuDirector::setup": 0x802a3fb8,
		"TMenuDirector::setupThreadFunc": 0x802a40e4,
		"TMenuDirector::TMenuDirector": 0x802a41bc,
		"System::__sinit_MenuDir_cpp": 0x802a4290,
		"__sinit_MenuDir_cpp": 0x802a4290,
		"TParams::finalize": 0x802a4790,
		"TParams::init": 0x802a47a0,
		"TParamT<JGeometry::TVec3<float><float>>::load": 0x802a48d8,
		"TParamT<float><float>::load": 0x802a492c,
		"TParamT<long><long>::load": 0x802a4980,
		"TParamT<short><short>::load": 0x802a49d4,
		"TParamT<unsigned_char><unsigned_char>::load": 0x802a4a28,
		"TPerformList::~TPerformList": 0x802a4a7c,
		"TPerformList::load": 0x802a4cac,
		"JGadget::TSingleLinkList<TPerformLink,0>::Element_getNode": 0x802a4e0c,
		"JGadget::TSingleLinkList<12TPerformLink,0>::iterator::iterator": 0x802a4e10,
		"JGadget::TSingleNodeLinkList::end": 0x802a4e1c,
		"TPerformList::perform": 0x802a4e28,
		"System::SMSSetupMovieRenderingInfo": 0x802a4f00,
		"SMSSetupMovieRenderingInfo": 0x802a4f00,
		"System::SMSSetupGameRenderingInfo": 0x802a5010,
		"SMSSetupGameRenderingInfo": 0x802a5010,
		"System::SMSSetupTitleRenderingInfo": 0x802a514c,
		"SMSSetupTitleRenderingInfo": 0x802a514c,
		"System::SMSSetupTitleRenderMode": 0x802a5254,
		"SMSSetupTitleRenderMode": 0x802a5254,
		"System::SMSSetupGCLogoRenderingInfo": 0x802a5364,
		"SMSSetupGCLogoRenderingInfo": 0x802a5364,
		"System::SMSGetRederRect_Game": 0x802a541c,
		"SMSGetRederRect_Game": 0x802a541c,
		"TSnapTimeObj::~TSnapTimeObj": 0x802a5470,
		"TSnapTimeObj::perform": 0x802a54e4,
		"TTalkCursor::~TTalkCursor": 0x802a55c8,
		"TTalkCursor::associateNPC": 0x802a563c,
		"associateNPC": 0x802a563c,
		"TTalkCursor::perform": 0x802a56c8,
		"TTalkCursor::loadAfter": 0x802a5708,
		"System::SMS_ResetTexCacheRegion": 0x802a57f8,
		"SMS_ResetTexCacheRegion": 0x802a57f8,
		"TAlphaCatch::~TAlphaCatch": 0x802a5834,
		"TAlphaCatch::perform": 0x802a58a8,
		"TZBufferCatch::perform": 0x802a58ec,
		"TZBufferCatch::~TZBufferCatch": 0x802a5924,
		"TApplication::mountStageArchive": 0x802a5998,
		"mountStageArchive": 0x802a5998,
		"TApplication::drawDVDErr": 0x802a5b44,
		"drawDVDErr": 0x802a5b44,
		"TApplication::gameLoop": 0x802a5f50,
		"gameLoop": 0x802a5f50,
		"TTimeRec::crTimeAry": 0x802a6380,
		"crTimeAry": 0x802a6380,
		"TApplication::proc": 0x802a6398,
		"TApplication::checkAdditionalMovie": 0x802a67e8,
		"checkAdditionalMovie": 0x802a67e8,
		"TApplication::finalize": 0x802a69cc,
		"TApplication::initialize_nlogoAfter": 0x802a6a84,
		"initialize_nlogoAfter": 0x802a6a84,
		"TApplication::initialize_bootAfter": 0x802a6dd0,
		"initialize_bootAfter": 0x802a6dd0,
		"System::SetupThreadFuncLogo": 0x802a7080,
		"SetupThreadFuncLogo": 0x802a7080,
		"TApplication::setupThreadFuncLogo": 0x802a70a0,
		"setupThreadFuncLogo": 0x802a70a0,
		"TApplication::initialize": 0x802a73c4,
		"System::SetupThreadFuncBoot": 0x802a7878,
		"SetupThreadFuncBoot": 0x802a7878,
		"System::SMSSwitch2DArchive": 0x802a78b4,
		"SMSSwitch2DArchive": 0x802a78b4,
		"System::SMSMountAramArchive": 0x802a797c,
		"SMSMountAramArchive": 0x802a797c,
		"System::SMSLoadArchive": 0x802a7a34,
		"SMSLoadArchive": 0x802a7a34,
		"TApplication::TApplication": 0x802a7b08,
		"System::SMSGetAnmFrameRate": 0x802a7bd8,
		"SMSGetAnmFrameRate": 0x802a7bd8,
		"System::SMSGetVSyncTimesPerSec": 0x802a7c48,
		"SMSGetVSyncTimesPerSec": 0x802a7c48,
		"TMarioGamePad::~TMarioGamePad": 0x802a7cb0,
		"System::__sinit_Application_cpp": 0x802a7d14,
		"__sinit_Application_cpp": 0x802a7d14,
		"TScenarioArchiveName::load": 0x802a8010,
		"TMarioGamePad::read": 0x802a8054,
		"TMarioGamePad::onNeutralMarioKey": 0x802a80d4,
		"onNeutralMarioKey": 0x802a80d4,
		"TMarioGamePad::updateMeaning": 0x802a80e0,
		"updateMeaning": 0x802a80e0,
		"TMarioGamePad::reset": 0x802a897c,
		"System::__sinit_MarioGamePad_cpp": 0x802a89f4,
		"__sinit_MarioGamePad_cpp": 0x802a89f4,
		"TStageEventInfo::load": 0x802a8a00,
		"System::SMS_getShineIDofExStage": 0x802a8a98,
		"SMS_getShineIDofExStage": 0x802a8a98,
		"System::SMS_getShineStage": 0x802a8ac8,
		"SMS_getShineStage": 0x802a8ac8,
		"System::SMS_isOptionMap": 0x802a8ae0,
		"SMS_isOptionMap": 0x802a8ae0,
		"System::SMS_isDivingMap": 0x802a8afc,
		"SMS_isDivingMap": 0x802a8afc,
		"System::SMS_isMultiPlayerMap": 0x802a8b30,
		"SMS_isMultiPlayerMap": 0x802a8b30,
		"System::SMS_isExMap": 0x802a8b58,
		"SMS_isExMap": 0x802a8b58,
		"System::SMSGetGCLogoVideoWidth": 0x802a8ba0,
		"SMSGetGCLogoVideoWidth": 0x802a8ba0,
		"System::SMSGetGCLogoRenderHeight": 0x802a8ba8,
		"SMSGetGCLogoRenderHeight": 0x802a8ba8,
		"System::SMSGetGCLogoRenderWidth": 0x802a8bb0,
		"SMSGetGCLogoRenderWidth": 0x802a8bb0,
		"System::SMSGetTitleRenderHeight": 0x802a8bb8,
		"SMSGetTitleRenderHeight": 0x802a8bb8,
		"System::SMSGetTitleRenderWidth": 0x802a8bc0,
		"SMSGetTitleRenderWidth": 0x802a8bc0,
		"System::SMSGetGameRenderHeight": 0x802a8bc8,
		"SMSGetGameRenderHeight": 0x802a8bc8,
		"System::SMSGetGameRenderWidth": 0x802a8bd0,
		"SMSGetGameRenderWidth": 0x802a8bd0,
		"System::SMSGetTitleVideoWidth": 0x802a8c3c,
		"SMSGetTitleVideoWidth": 0x802a8c3c,
		"System::SMSGetGameVideoWidth": 0x802a8ca8,
		"SMSGetGameVideoWidth": 0x802a8ca8,
		"TStagePositionInfo::load": 0x802a8cb0,
		"TProcessMeter::TProcessMeter": 0x802a8d78,
		"TTimeRec::drawSyncCallback": 0x802a8db8,
		"TTimeRec::snapGXTime": 0x802a8e08,
		"snapGXTime": 0x802a8e08,
		"TTimeRec::flip": 0x802a8eb4,
		"flip": 0x802a8eb4,
		"TTimeArray::TTimeArray": 0x802a8f44,
		"TTimeRec::start": 0x802a8f50,
		"TTimeArray::append": 0x802a8fec,
		"TDrawSyncManager::pushBreakPoint": 0x802a9020,
		"pushBreakPoint": 0x802a9020,
		"TDrawSyncManager::drawSyncCallbackSub": 0x802a9078,
		"drawSyncCallbackSub": 0x802a9078,
		"TDrawSyncManager::setCallback": 0x802a913c,
		"setCallback": 0x802a913c,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::DestroyElement_": 0x802a9170,
		"TDrawSyncManager::threadFunc": 0x802a9184,
		"threadFunc": 0x802a9184,
		"TFifo::getLoopIdx": 0x802a92fc,
		"getLoopIdx": 0x802a92fc,
		"TDrawSyncManager::drawSyncCallback": 0x802a9318,
		"TDrawSyncManager::start": 0x802a934c,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::insert": 0x802a9484,
		"TDrawSyncManager::TDrawSyncTokenRange::TDrawSyncTokenRange": 0x802a982c,
		"TTHPRender::~TTHPRender": 0x802a983c,
		"TTHPRender::perform": 0x802a98b0,
		"TTHPRender::TTHPRender": 0x802a9920,
		"TMarNameRefGen::getNameRef_BossEnemy": 0x802a9998,
		"getNameRef_BossEnemy": 0x802a9998,
		"System::__sinit_MarNameRefGen_BossEnemy_cpp": 0x802aa41c,
		"__sinit_MarNameRefGen_BossEnemy_cpp": 0x802aa41c,
		"TMarNameRefGen::getNameRef_Enemy": 0x802aa718,
		"getNameRef_Enemy": 0x802aa718,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::TRotation3": 0x802ac7e0,
		"TNameKuriLauncherManager::~TNameKuriLauncherManager": 0x802ac8b0,
		"THamuKuriLauncherManager::~THamuKuriLauncherManager": 0x802ac924,
		"TMarNameRefGen::getNameRef_Map": 0x802ac998,
		"getNameRef_Map": 0x802ac998,
		"TMarNameRefGen::getNameRef_MapObj": 0x802accd0,
		"getNameRef_MapObj": 0x802accd0,
		"TTelesaSlot::TTelesaSlot": 0x802b0414,
		"TFence::TFence": 0x802b04ac,
		"TMarNameRefGen::getNameRef_NPC": 0x802b0628,
		"getNameRef_NPC": 0x802b0628,
		"TMareWManager::~TMareWManager": 0x802b1588,
		"TMareMManager::~TMareMManager": 0x802b161c,
		"TCardManager::cmdLoop": 0x802b16b0,
		"cmdLoop": 0x802b16b0,
		"TCardManager::writeOptionBlock_": 0x802b18d8,
		"writeOptionBlock_": 0x802b18d8,
		"TCardManager::writeBlock_": 0x802b1a70,
		"writeBlock_": 0x802b1a70,
		"TCardManager::readBlock_": 0x802b1c90,
		"readBlock_": 0x802b1c90,
		"TCardManager::getBookmarkInfos_": 0x802b1efc,
		"getBookmarkInfos_": 0x802b1efc,
		"TCardManager::open_": 0x802b20d0,
		"open_": 0x802b20d0,
		"TCardManager::setCardStat_": 0x802b2260,
		"setCardStat_": 0x802b2260,
		"TCardManager::filledInitData_": 0x802b24a4,
		"filledInitData_": 0x802b24a4,
		"TCardManager::createFile_": 0x802b27dc,
		"createFile_": 0x802b27dc,
		"TCardManager::mount_": 0x802b2914,
		"mount_": 0x802b2914,
		"System::detachCallback": 0x802b2b60,
		"detachCallback": 0x802b2b60,
		"TCardManager::getLastStatus": 0x802b2b70,
		"getLastStatus": 0x802b2b70,
		"TCardManager::writeOptionBlock": 0x802b2bc8,
		"writeOptionBlock": 0x802b2bc8,
		"TCardManager::getOptionWriteStream": 0x802b2c18,
		"getOptionWriteStream": 0x802b2c18,
		"TCardManager::getOptionReadStream": 0x802b2d1c,
		"getOptionReadStream": 0x802b2d1c,
		"TCardManager::readOptionBlock": 0x802b2d4c,
		"readOptionBlock": 0x802b2d4c,
		"TCardManager::writeBlock": 0x802b2d9c,
		"writeBlock": 0x802b2d9c,
		"TCardManager::getWriteStream": 0x802b2dfc,
		"getWriteStream": 0x802b2dfc,
		"TCardManager::getReadStream": 0x802b2e50,
		"getReadStream": 0x802b2e50,
		"TCardManager::readBlock": 0x802b2e80,
		"readBlock": 0x802b2e80,
		"TCardManager::getBookmarkInfos": 0x802b2ee0,
		"getBookmarkInfos": 0x802b2ee0,
		"TCardManager::createFile": 0x802b2f40,
		"createFile": 0x802b2f40,
		"TCardManager::format": 0x802b2f90,
		"format": 0x802b2f90,
		"TCardManager::unmount": 0x802b2fe0,
		"TCardManager::probe": 0x802b305c,
		"probe": 0x802b305c,
		"TCardManager::~TCardManager": 0x802b30e0,
		"TCardManager::TCardManager": 0x802b318c,
		"TCardManager::TCriteria::TCriteria": 0x802b3258,
		"System::cardmain": 0x802b3264,
		"cardmain": 0x802b3264,
		"TCardManager::copyTo": 0x802b3284,
		"copyTo": 0x802b3284,
		"TCardManager::decideUseSector": 0x802b3420,
		"decideUseSector": 0x802b3420,
		"TCardManager::TCriteria::set": 0x802b3490,
		"System::CalcCheckSum": 0x802b34f4,
		"CalcCheckSum": 0x802b34f4,
		"TMarDirector::loadParticleMario": 0x802b36e8,
		"loadParticleMario": 0x802b36e8,
		"TMarDirector::loadParticle": 0x802b494c,
		"loadParticle": 0x802b494c,
		"TMarDirector::initLoadParticle": 0x802b52cc,
		"initLoadParticle": 0x802b52cc,
		"TMarDirector::loadResource": 0x802b5458,
		"loadResource": 0x802b5458,
		"System::__sinit_MarDirectorLoadResource_cpp": 0x802b5834,
		"__sinit_MarDirectorLoadResource_cpp": 0x802b5834,
		"TMovieDirector::direct": 0x802b5b30,
		"TMovieDirector::decideNextMode": 0x802b63c8,
		"decideNextMode": 0x802b63c8,
		"TMovieDirector::rsetup": 0x802b666c,
		"TMovieDirector::setup": 0x802b6ea8,
		"TMovieDirector::setupThreadFunc": 0x802b6fdc,
		"TMovieDirector::TMovieDirector": 0x802b6ffc,
		"TMovieDirector::getStreamMovieName": 0x802b70b4,
		"getStreamMovieName": 0x802b70b4,
		"System::__sinit_MovieDirector_cpp": 0x802b7378,
		"__sinit_MovieDirector_cpp": 0x802b7378,
		"TMarDirector::createObjects": 0x802b767c,
		"createObjects": 0x802b767c,
		"TMarDirector::setupObjects": 0x802b76f4,
		"setupObjects": 0x802b76f4,
		"TMarDirector::decideMarioPosIdx": 0x802b97a8,
		"decideMarioPosIdx": 0x802b97a8,
		"System::__sinit_MarDirectorSetupObjects_cpp": 0x802b9a38,
		"__sinit_MarDirectorSetupObjects_cpp": 0x802b9a38,
		"MSStage::setPosPtr": 0x802b9d34,
		"setPosPtr": 0x802b9d34,
		"MSSTageSimpleEnvironment::proc": 0x802b9d38,
		"MSStageCubeSwitch::proc": 0x802b9d74,
		"MSStageCubeFadeMonte::proc": 0x802b9f4c,
		"MSStageCubeFade::proc": 0x802ba910,
		"MSStageDistFadeMonte::proc": 0x802bac5c,
		"MSStageDistFade::proc": 0x802bb000,
		"MSStageDistFade::MSStageDistFade": 0x802bb2d8,
		"MSStage::stageLoop": 0x802bb330,
		"stageLoop": 0x802bb330,
		"MSStage::init": 0x802bb35c,
		"MSMainProc::startStageBGM": 0x802bb6f8,
		"startStageBGM": 0x802bb6f8,
		"MSMainProc::endStageEntranceDemo": 0x802bb7dc,
		"endStageEntranceDemo": 0x802bb7dc,
		"MSMainProc::entranceDemoLoop": 0x802bb87c,
		"entranceDemoLoop": 0x802bb87c,
		"MSMainProc::startStageEntranceDemo": 0x802bb880,
		"startStageEntranceDemo": 0x802bb880,
		"MSMainProc::setMSoundEnterStage": 0x802bb920,
		"setMSoundEnterStage": 0x802bb920,
		"MSMainProc::setBossNotDamagedFlag": 0x802bc2f0,
		"setBossNotDamagedFlag": 0x802bc2f0,
		"MSMainProc::setBossLivesFlag2": 0x802bc2f8,
		"setBossLivesFlag2": 0x802bc2f8,
		"MSMainProc::setBossLivesFlagOnlyFlag": 0x802bc344,
		"setBossLivesFlagOnlyFlag": 0x802bc344,
		"MSMainProc::setBossLivesFlag": 0x802bc34c,
		"setBossLivesFlag": 0x802bc34c,
		"MSMainProc::fromTalkingCameraDemo": 0x802bc398,
		"fromTalkingCameraDemo": 0x802bc398,
		"MSMainProc::toTalkingCameraDemo": 0x802bc3c0,
		"toTalkingCameraDemo": 0x802bc3c0,
		"MSMainProc::fromInnerCameraDemo": 0x802bc42c,
		"fromInnerCameraDemo": 0x802bc42c,
		"MSMainProc::toInnerCameraDemo": 0x802bc43c,
		"toInnerCameraDemo": 0x802bc43c,
		"MSMainProc::getMonteVillageActorArea": 0x802bc44c,
		"getMonteVillageActorArea": 0x802bc44c,
		"System::__sinit_MSoundMainSide_cpp": 0x802bc56c,
		"__sinit_MSoundMainSide_cpp": 0x802bc56c,
		"TTargetArrow::~TTargetArrow": 0x802bc868,
		"TTargetArrow::setPos": 0x802bc8dc,
		"setPos": 0x802bc8dc,
		"TTargetArrow::perform": 0x802bc90c,
		"TTargetArrow::loadAfter": 0x802bc948,
		"TLiveActor::stopAnmSound": 0x80217954,
		"stopAnmSound": 0x80217954,
		"TLiveActor::getBasNameTable": 0x80217990,
		"TLiveActor::setCurAnmSound": 0x80217998,
		"setCurAnmSound": 0x80217998,
		"TLiveActor::setAnmSound": 0x80217a8c,
		"setAnmSound": 0x80217a8c,
		"TLiveActor::updateAnmSound": 0x80217b30,
		"TLiveActor::initAnmSound": 0x80217b98,
		"TLiveActor::getTakingMtx": 0x80217ca8,
		"TLiveActor::getFocalPoint": 0x80217cc8,
		"TLiveActor::getJointTransByIndex": 0x80217ce4,
		"getJointTransByIndex": 0x80217ce4,
		"TLiveActor::hasMapCollision": 0x80217d6c,
		"TLiveActor::getGravityY": 0x80217d88,
		"TLiveActor::calcVelocityToJumpToY": 0x80217d90,
		"calcVelocityToJumpToY": 0x80217d90,
		"TLiveActor::performOnlyDraw": 0x80217de4,
		"performOnlyDraw": 0x80217de4,
		"TLiveActor::perform": 0x80217ec0,
		"TLiveActor::drawObject": 0x80217fc8,
		"TLiveActor::requestShadow": 0x80218020,
		"TLiveActor::moveObject": 0x8021818c,
		"TLiveActor::setGroundCollision": 0x802182f0,
		"TLiveActor::getShadowType": 0x80218344,
		"TLiveActor::receiveMessage": 0x8021834c,
		"TLiveActor::kill": 0x80218354,
		"TLiveActor::calcRootMatrix": 0x80218370,
		"TLiveActor::control": 0x80218414,
		"TLiveActor::bind": 0x802184dc,
		"TLiveActor::load": 0x80218738,
		"TLiveActor::init": 0x802187d0,
		"TLiveActor::initLodAnm": 0x802189bc,
		"initLodAnm": 0x802189bc,
		"TLiveActor::getRootJointMtx": 0x80218a48,
		"TLiveActor::getModel": 0x80218a50,
		"getModel": 0x80218a50,
		"TLiveActor::calcRideMomentum": 0x80218a5c,
		"calcRideMomentum": 0x80218a5c,
		"Strategic::MsWrap": 0x80218c78,
		"TLiveActor::belongToGround": 0x80218cc0,
		"belongToGround": 0x80218cc0,
		"TLiveActor::calcRidePos": 0x80218d40,
		"calcRidePos": 0x80218d40,
		"TLiveActor::TLiveActor": 0x80218e70,
		"Strategic::__sinit_liveactor_cpp": 0x80218fa0,
		"__sinit_liveactor_cpp": 0x80218fa0,
		"TSpcTypedBinary<TLiveActor>::initUserBuiltin": 0x802192a4,
		"Strategic::linPushNerve": 0x80219398,
		"linPushNerve": 0x80219398,
		"Strategic::linSetSRT": 0x80219590,
		"linSetSRT": 0x80219590,
		"Strategic::linGetSRT": 0x80219980,
		"linGetSRT": 0x80219980,
		"Strategic::linSetAnmRate": 0x8021a118,
		"linSetAnmRate": 0x8021a118,
		"Strategic::linSetBls": 0x8021a38c,
		"linSetBls": 0x8021a38c,
		"Strategic::linSetBlk": 0x8021a4a0,
		"linSetBlk": 0x8021a4a0,
		"Strategic::linSetBtk": 0x8021a5c8,
		"linSetBtk": 0x8021a5c8,
		"Strategic::linSetBtp": 0x8021a6f0,
		"linSetBtp": 0x8021a6f0,
		"Strategic::linSetBpk": 0x8021a818,
		"linSetBpk": 0x8021a818,
		"Strategic::linSetBck": 0x8021a940,
		"linSetBck": 0x8021a940,
		"Strategic::NerveGetByIndex": 0x8021aa68,
		"NerveGetByIndex": 0x8021aa68,
		"TLiveManager::hasMapCollision": 0x8021ae00,
		"TLiveManager::getActorByFlag": 0x8021ae48,
		"getActorByFlag": 0x8021ae48,
		"TLiveManager::perform": 0x8021ae88,
		"TLiveManager::setFlagOutOfCube": 0x8021af84,
		"TLiveManager::clipActors": 0x8021b04c,
		"TLiveManager::clipActorsAux": 0x8021b074,
		"clipActorsAux": 0x8021b074,
		"TLiveManager::manageActor": 0x8021b19c,
		"manageActor": 0x8021b19c,
		"TLiveManager::load": 0x8021b1c8,
		"TLiveManager::createSpcBinary": 0x8021b208,
		"createSpcBinary": 0x8021b208,
		"TLiveManager::TLiveManager": 0x8021b28c,
		"TObjCheckList::TObjCheckList": 0x8021b2f8,
		"TObjHitCheck::TObjHitCheck": 0x8021b308,
		"TObjHitCheck::clearHitNum": 0x8021b4e0,
		"clearHitNum": 0x8021b4e0,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::begin": 0x8021b8f4,
		"TObjHitCheck::checkActorsHit": 0x8021b900,
		"checkActorsHit": 0x8021b900,
		"TObjHitCheck::entryGroup": 0x8021bc4c,
		"entryGroup": 0x8021bc4c,
		"TObjHitCheck::checkAndEntryGroup": 0x8021be24,
		"checkAndEntryGroup": 0x8021be24,
		"TObjHitCheck::checkWater": 0x8021c0e4,
		"checkWater": 0x8021c0e4,
		"TObjHitCheck::suffererIsInAttackArea": 0x8021c29c,
		"suffererIsInAttackArea": 0x8021c29c,
		"Strategic::checkDistance": 0x8021c2f0,
		"checkDistance": 0x8021c2f0,
		"TObjManager::searchF": 0x8021c364,
		"TObjManager::getModelDataKeeper": 0x8021c3f4,
		"getModelDataKeeper": 0x8021c3f4,
		"TObjManager::createAnmData": 0x8021c440,
		"TObjManager::createModelData": 0x8021c4a0,
		"TObjManager::createModelDataArrayBase": 0x8021c4d4,
		"createModelDataArrayBase": 0x8021c4d4,
		"TObjManager::createModelDataArray": 0x8021c5bc,
		"TObjManager::perform": 0x8021c5e4,
		"TObjManager::getMActorAnmData": 0x8021c6d0,
		"TObjManager::load": 0x8021c71c,
		"TObjManager::manageObj": 0x8021c7c4,
		"manageObj": 0x8021c7c4,
		"TObjManager::TObjManager": 0x8021c7e4,
		"TObjChara::getRes": 0x8021c870,
		"TObjChara::~TObjChara": 0x8021c8b0,
		"TObjChara::load": 0x8021c924,
		"TMActorKeeper::createMActorFromAllBmd": 0x8021cb5c,
		"createMActorFromAllBmd": 0x8021cb5c,
		"TMActorKeeper::createMActor": 0x8021cc74,
		"createMActor": 0x8021cc74,
		"TMActorKeeper::createMActorFromNthData": 0x8021cec8,
		"createMActorFromNthData": 0x8021cec8,
		"TMActorKeeper::createMActorFromDefaultBmd": 0x8021d008,
		"createMActorFromDefaultBmd": 0x8021d008,
		"TMActorKeeper::getMActor": 0x8021d12c,
		"TMActorKeeper::createAndRegister": 0x8021d228,
		"createAndRegister": 0x8021d228,
		"TModelDataKeeper::TModelDataKeeper": 0x8021d2e4,
		"TModelDataKeeper::getModelDataNum": 0x8021d300,
		"getModelDataNum": 0x8021d300,
		"TModelDataKeeper::getDataByName": 0x8021d32c,
		"getDataByName": 0x8021d32c,
		"TModelDataKeeper::getNthData": 0x8021d448,
		"getNthData": 0x8021d448,
		"TModelDataKeeper::createAndKeepData": 0x8021d4c0,
		"createAndKeepData": 0x8021d4c0,
		"TModelDataKeeper::loadModelData": 0x8021d5a4,
		"loadModelData": 0x8021d5a4,
		"TModelDataNode::registerDataAndJoinNewNode": 0x8021d61c,
		"registerDataAndJoinNewNode": 0x8021d61c,
		"TSpcInterp::update": 0x8021d680,
		"TSpcInterp::verifyArgNum": 0x8021db9c,
		"verifyArgNum": 0x8021db9c,
		"TSpcInterp::dump": 0x8021dcbc,
		"TSpcInterp::~TSpcInterp": 0x8021df54,
		"TSpcInterp::TSpcInterp": 0x8021e008,
		"TSpcStack<unsigned_long><unsigned_long>::~TSpcStack": 0x8021e20c,
		"TSpcStack<TSpcSlice>::~TSpcStack": 0x8021e26c,
		"TSpcSlice::TSpcSlice": 0x8021e2d0,
		"TSpcInterp::dispatchBuiltin": 0x8021e2e0,
		"TSpcInterp::dispatchBuiltinDefault": 0x8021e300,
		"dispatchBuiltinDefault": 0x8021e300,
		"TSpcInterp::execend": 0x8021e4f4,
		"execend": 0x8021e4f4,
		"TSpcInterp::execint1": 0x8021e530,
		"execint1": 0x8021e530,
		"TSpcInterp::execint0": 0x8021e5a8,
		"execint0": 0x8021e5a8,
		"TSpcInterp::execpop": 0x8021e61c,
		"execpop": 0x8021e61c,
		"TSpcInterp::execjmp": 0x8021e660,
		"execjmp": 0x8021e660,
		"TSpcInterp::execjne": 0x8021e6b8,
		"execjne": 0x8021e6b8,
		"TSpcInterp::execret0": 0x8021e7e0,
		"execret0": 0x8021e7e0,
		"TSpcInterp::execret": 0x8021e9bc,
		"execret": 0x8021e9bc,
		"TSpcInterp::execmkds": 0x8021eb44,
		"execmkds": 0x8021eb44,
		"TSpcInterp::execmkfr": 0x8021ec58,
		"execmkfr": 0x8021ec58,
		"TSpcInterp::execfunc": 0x8021ed44,
		"execfunc": 0x8021ed44,
		"TSpcInterp::execcall": 0x8021ee00,
		"execcall": 0x8021ee00,
		"TSpcInterp::execshr": 0x8021f044,
		"execshr": 0x8021f044,
		"TSpcInterp::execshl": 0x8021f214,
		"execshl": 0x8021f214,
		"TSpcInterp::execbor": 0x8021f3e4,
		"execbor": 0x8021f3e4,
		"TSpcInterp::execband": 0x8021f5b4,
		"execband": 0x8021f5b4,
		"TSpcInterp::execor": 0x8021f784,
		"execor": 0x8021f784,
		"TSpcSlice::getDataInt": 0x8021f950,
		"getDataInt": 0x8021f950,
		"TSpcInterp::execand": 0x8021f998,
		"execand": 0x8021f998,
		"TSpcInterp::execnot": 0x8021fb64,
		"execnot": 0x8021fb64,
		"TSpcInterp::execneg": 0x8021fc98,
		"execneg": 0x8021fc98,
		"TSpcInterp::execle": 0x8021fdb0,
		"execle": 0x8021fdb0,
		"TSpcSlice::getDataFloat": 0x8021ff8c,
		"getDataFloat": 0x8021ff8c,
		"TSpcInterp::execge": 0x8021ffe4,
		"execge": 0x8021ffe4,
		"TSpcInterp::execlt": 0x802201c0,
		"execlt": 0x802201c0,
		"TSpcInterp::execgt": 0x80220398,
		"execgt": 0x80220398,
		"TSpcInterp::execne": 0x80220570,
		"execne": 0x80220570,
		"TSpcSlice::operator_!=": 0x802206d8,
		"operator_!=": 0x802206d8,
		"TSpcInterp::execeq": 0x80220874,
		"execeq": 0x80220874,
		"TSpcSlice::operator_==": 0x802209dc,
		"TSpcInterp::execass": 0x80220b78,
		"execass": 0x80220b78,
		"TSpcInterp::execmod": 0x80220cd4,
		"execmod": 0x80220cd4,
		"TSpcInterp::execdiv": 0x80220eac,
		"execdiv": 0x80220eac,
		"TSpcInterp::execmul": 0x80221184,
		"execmul": 0x80221184,
		"TSpcInterp::execsub": 0x8022145c,
		"execsub": 0x8022145c,
		"TSpcInterp::execadd": 0x80221734,
		"execadd": 0x80221734,
		"TSpcInterp::execdec": 0x80221a0c,
		"execdec": 0x80221a0c,
		"TSpcInterp::execinc": 0x80221b78,
		"execinc": 0x80221b78,
		"TSpcInterp::execnop": 0x80221ce4,
		"execnop": 0x80221ce4,
		"TSpcInterp::execvar": 0x80221ce8,
		"execvar": 0x80221ce8,
		"TSpcInterp::execadr": 0x80221dfc,
		"execadr": 0x80221dfc,
		"TSpcInterp::fetchU32": 0x80221e80,
		"fetchU32": 0x80221e80,
		"TSpcInterp::execstr": 0x80221ed4,
		"execstr": 0x80221ed4,
		"TSpcBinary::getHeader": 0x80221fcc,
		"getHeader": 0x80221fcc,
		"TSpcInterp::execflt": 0x80221fd4,
		"execflt": 0x80221fd4,
		"TSpcInterp::execint": 0x8022209c,
		"execint": 0x8022209c,
		"TSpcInterp::fetchS32": 0x80222120,
		"fetchS32": 0x80222120,
		"TSpcBinary::bindSystemDataToSymbol": 0x80222174,
		"bindSystemDataToSymbol": 0x80222174,
		"TSpcBinary::searchSymbol": 0x80222250,
		"searchSymbol": 0x80222250,
		"TSpcBinary::initUserBuiltin": 0x80222308,
		"TSpcBinary::init": 0x8022230c,
		"TSpcBinary::~TSpcBinary": 0x802225ac,
		"TSpcBinary::TSpcBinary": 0x802225f8,
		"Strategic::spcTypeof": 0x8022260c,
		"spcTypeof": 0x8022260c,
		"Strategic::spcFloat": 0x80222778,
		"spcFloat": 0x80222778,
		"Strategic::spcInt": 0x80222954,
		"spcInt": 0x80222954,
		"Strategic::spcDump": 0x80222b14,
		"spcDump": 0x80222b14,
		"Strategic::spcPrint": 0x80222bf4,
		"spcPrint": 0x80222bf4,
		"Strategic::spcUnlock": 0x80222dec,
		"spcUnlock": 0x80222dec,
		"Strategic::spcLock": 0x80222ed0,
		"spcLock": 0x80222ed0,
		"Strategic::spcExit": 0x80222fb4,
		"spcExit": 0x80222fb4,
		"Strategic::spcYield": 0x8022309c,
		"spcYield": 0x8022309c,
		"TStrategy::~TStrategy": 0x80223180,
		"TStrategy::perform": 0x802231f4,
		"TStrategy::searchF": 0x8022337c,
		"TStrategy::loadAfter": 0x8022340c,
		"TStrategy::load": 0x80223480,
		"TStrategy::TStrategy": 0x80223598,
		"TIdxGroupObj::loadSuper": 0x80223650,
		"TIdxGroupObj::~TIdxGroupObj": 0x80223698,
		"TQuestionManager::~TQuestionManager": 0x802237c0,
		"TQuestionManager::perform": 0x80223834,
		"TQuestionManager::draw": 0x80223944,
		"TQuestionManager::makeDL": 0x80223ab8,
		"TQuestionManager::request": 0x80223be0,
		"TQuestionManager::load": 0x80223c74,
		"TQuestionRequest::TQuestionRequest": 0x80223d64,
		"TSMSSmplChara::~TSMSSmplChara": 0x80223d68,
		"TSMSSmplChara::getRes": 0x80223de8,
		"TSMSSmplChara::load": 0x80223e2c,
		"THitActor::THitActor": 0x80223e74,
		"THitActor::initHitActor": 0x80223fa0,
		"initHitActor": 0x80223fa0,
		"THitActor::perform": 0x8022406c,
		"THitActor::calcEntryRadius": 0x8022408c,
		"calcEntryRadius": 0x8022408c,
		"TBinder::~TBinder": 0x80224110,
		"TBinder::TBinder": 0x8022415c,
		"TSharedParts::perform": 0x8022416c,
		"TSharedParts::getConnectedMtx": 0x80224230,
		"getConnectedMtx": 0x80224230,
		"TMirrorActor::~TMirrorActor": 0x80224534,
		"TMirrorActor::TMirrorActor": 0x802245a8,
		"TMirrorActor::init": 0x80224620,
		"TMirrorActor::entryMirrorDrawBufferAlways": 0x8022481c,
		"entryMirrorDrawBufferAlways": 0x8022481c,
		"TMirrorActor::perform": 0x80224910,
		"TMirrorActor::checkIsInMirror": 0x80224a4c,
		"checkIsInMirror": 0x80224a4c,
		"Strategic::__sinit_MirrorActor_cpp": 0x80224c10,
		"__sinit_MirrorActor_cpp": 0x80224c10,
		"TMario::actnMain": 0x8023f6b8,
		"actnMain": 0x8023f6b8,
		"TMario::taking": 0x8023f910,
		"taking": 0x8023f910,
		"Player::__sinit_MarioAction_cpp": 0x8023fa34,
		"__sinit_MarioAction_cpp": 0x8023fa34,
		"TMario::demoMain": 0x8023fd30,
		"demoMain": 0x8023fd30,
		"TMario::footDowning": 0x80240070,
		"footDowning": 0x80240070,
		"TMario::electricDamage": 0x802401b8,
		"electricDamage": 0x802401b8,
		"TMario::warpOut": 0x8024033c,
		"warpOut": 0x8024033c,
		"TMario::toroccoStart": 0x802405f8,
		"toroccoStart": 0x802405f8,
		"TMario::waitingStart": 0x802406bc,
		"waitingStart": 0x802406bc,
		"TMario::returnStart": 0x802407bc,
		"returnStart": 0x802407bc,
		"TMario::rollingStart": 0x80240954,
		"rollingStart": 0x80240954,
		"TMario::isUnUsualStageStart": 0x80240a58,
		"isUnUsualStageStart": 0x80240a58,
		"TMario::warpIn": 0x80240c1c,
		"warpIn": 0x80240c1c,
		"TMario::jumpingDemoCommon": 0x802410e8,
		"jumpingDemoCommon": 0x802410e8,
		"TMario::readBillboard": 0x80241170,
		"readBillboard": 0x80241170,
		"TMario::winDemo": 0x80241378,
		"winDemo": 0x80241378,
		"Player::__sinit_MarioAutodemo_cpp": 0x8024145c,
		"__sinit_MarioAutodemo_cpp": 0x8024145c,
		"M3UModelMario::updateOut": 0x80241758,
		"M3UModelMario::updateIn": 0x802417a0,
		"M3UModelMario::updateInMotion": 0x802417d4,
		"M3UModelMario::changeMtxCalcSIAnmBQAnmTransform": 0x80241930,
		"changeMtxCalcSIAnmBQAnmTransform": 0x80241930,
		"TMarioCap::mtxEffectHide": 0x8024199c,
		"mtxEffectHide": 0x8024199c,
		"TMarioCap::mtxEffectShow": 0x80241a10,
		"mtxEffectShow": 0x80241a10,
		"TMarioCap::perform": 0x80241a84,
		"TMarioCap::createMirrorCap": 0x80242108,
		"createMirrorCap": 0x80242108,
		"TMarioCap::TMarioCap": 0x80242188,
		"TMario::considerTake": 0x80242618,
		"considerTake": 0x80242618,
		"TMario::damageExec": 0x8024280c,
		"JGeometry::TVec3<float><float>::operator*=": 0x80242da4,
		"operator*=": 0x80242da4,
		"TMario::calcDamagePos": 0x80242de8,
		"calcDamagePos": 0x80242de8,
		"TMario::loserExec": 0x802430fc,
		"loserExec": 0x802430fc,
		"TMario::normalizeNozzle": 0x8024324c,
		"normalizeNozzle": 0x8024324c,
		"TMario::resetNozzle": 0x802432b4,
		"resetNozzle": 0x802432b4,
		"TMario::trampleExec": 0x802432b8,
		"trampleExec": 0x802432b8,
		"TMario::canTake": 0x80243550,
		"canTake": 0x80243550,
		"TMario::isTakeSituation": 0x8024359c,
		"isTakeSituation": 0x8024359c,
		"TMario::dropObject": 0x8024379c,
		"dropObject": 0x8024379c,
		"TMario::getAttackAngle": 0x802437f0,
		"getAttackAngle": 0x802437f0,
		"TMario::decHP": 0x80243828,
		"decHP": 0x80243828,
		"TMario::incHP": 0x80243928,
		"incHP": 0x80243928,
		"TMario::rumbleStart": 0x80243a40,
		"rumbleStart": 0x80243a40,
		"Player::__sinit_MarioCollision_cpp": 0x80243a74,
		"__sinit_MarioCollision_cpp": 0x80243a74,
		"TMario::addDamageFog": 0x80243d70,
		"addDamageFog": 0x80243d70,
		"TMario::addDirty": 0x8024406c,
		"addDirty": 0x8024406c,
		"TMario::boxDrawPrepare": 0x8024418c,
		"boxDrawPrepare": 0x8024418c,
		"TMario::drawLogic": 0x80244388,
		"drawLogic": 0x80244388,
		"TMario::drawSpecial": 0x80244520,
		"drawSpecial": 0x80244520,
		"TMario::entryModels": 0x8024458c,
		"entryModels": 0x8024458c,
		"TMario::calcView": 0x802446c0,
		"calcView": 0x802446c0,
		"TMario::calcAnim": 0x80244800,
		"TMario::addUpper": 0x80244e74,
		"addUpper": 0x80244e74,
		"TMario::setUpperDamageRun": 0x80245028,
		"setUpperDamageRun": 0x80245028,
		"TMario::addCallBack": 0x802450c0,
		"addCallBack": 0x802450c0,
		"TMario::calcBaseMtx": 0x80245450,
		"calcBaseMtx": 0x80245450,
		"TMario::considerWaist": 0x80245fd0,
		"considerWaist": 0x80245fd0,
		"TMario::isUpperPumpingStyle": 0x80246368,
		"isUpperPumpingStyle": 0x80246368,
		"TMario::finalDrawInitialize": 0x8024638c,
		"finalDrawInitialize": 0x8024638c,
		"TMario::initMirrorModel": 0x8024645c,
		"initMirrorModel": 0x8024645c,
		"TMario::initModel": 0x80246578,
		"TMario::loadAnmTexPattern": 0x80247508,
		"loadAnmTexPattern": 0x80247508,
		"TMario::loadBas": 0x8024756c,
		"loadBas": 0x8024756c,
		"TMario::setReverseAnimation": 0x802475b4,
		"setReverseAnimation": 0x802475b4,
		"TMario::setAnimation": 0x80247670,
		"TMario::changeHand": 0x802479a8,
		"changeHand": 0x802479a8,
		"TMario::isAnimeLoopOrStop": 0x80247da8,
		"isAnimeLoopOrStop": 0x80247da8,
		"TMario::isLast1AnimeFrame": 0x80247dcc,
		"isLast1AnimeFrame": 0x80247dcc,
		"TMario::getMotionFrameCtrl": 0x80247e1c,
		"getMotionFrameCtrl": 0x80247e1c,
		"TMario::getCurrentFrame": 0x80247e28,
		"getCurrentFrame": 0x80247e28,
		"TMario::getTakenMtx": 0x80247e40,
		"getTakenMtx": 0x80247e40,
		"TMario::getTakingMtx": 0x80247e50,
		"TMario::getTrampleCt": 0x80247e6c,
		"getTrampleCt": 0x80247e6c,
		"TMario::setPositions": 0x80247eb4,
		"setPositions": 0x80247eb4,
		"TMario::takeOffGlass": 0x80247f58,
		"takeOffGlass": 0x80247f58,
		"TMario::wearGlass": 0x80247fa4,
		"wearGlass": 0x80247fa4,
		"TMario::isWearingHelm": 0x80247ff0,
		"isWearingHelm": 0x80247ff0,
		"TMario::isWearingCap": 0x80248020,
		"isWearingCap": 0x80248020,
		"TMario::setDivHelm": 0x80248050,
		"setDivHelm": 0x80248050,
		"TMario::getWallAngle": 0x802480a8,
		"getWallAngle": 0x802480a8,
		"TMario::getPumpFrame": 0x802480d8,
		"getPumpFrame": 0x802480d8,
		"TMario::getCenterAnmMtx": 0x802480e8,
		"getCenterAnmMtx": 0x802480e8,
		"TMario::getRootAnmMtx": 0x80248104,
		"getRootAnmMtx": 0x80248104,
		"Player::MarioFootDirLCtrl": 0x80248114,
		"MarioFootDirLCtrl": 0x80248114,
		"Player::MarioFootPosLCtrl": 0x802483a4,
		"MarioFootPosLCtrl": 0x802483a4,
		"Player::MarioFootDirRCtrl": 0x802484dc,
		"MarioFootDirRCtrl": 0x802484dc,
		"Player::MarioFootPosRCtrl": 0x8024876c,
		"MarioFootPosRCtrl": 0x8024876c,
		"Player::MarioWaistCtrl": 0x802488a4,
		"MarioWaistCtrl": 0x802488a4,
		"Player::MarioHeadCtrl": 0x80248b18,
		"MarioHeadCtrl": 0x80248b18,
		"TMarioAnimeData::isPumpOK": 0x80248f14,
		"isPumpOK": 0x80248f14,
		"Player::__sinit_MarioDraw_cpp": 0x80248f30,
		"__sinit_MarioDraw_cpp": 0x80248f30,
		"TMario::jumpMain": 0x8024922c,
		"jumpMain": 0x8024922c,
		"TMario::diving": 0x8024a2ac,
		"diving": 0x8024a2ac,
		"TMario::hipAttacking": 0x8024a6a8,
		"hipAttacking": 0x8024a6a8,
		"TMario::rocketing": 0x8024ac64,
		"rocketing": 0x8024ac64,
		"TMario::rocketCheck": 0x8024b09c,
		"rocketCheck": 0x8024b09c,
		"TMario::boardJumping": 0x8024b1a0,
		"boardJumping": 0x8024b1a0,
		"TMario::thrownDowning": 0x8024b34c,
		"thrownDowning": 0x8024b34c,
		"TMario::fireDowning": 0x8024b514,
		"fireDowning": 0x8024b514,
		"TMario::slipFalling": 0x8024b77c,
		"slipFalling": 0x8024b77c,
		"TMario::catchStop": 0x8024ba24,
		"catchStop": 0x8024ba24,
		"TMario::stayWall": 0x8024bb24,
		"stayWall": 0x8024bb24,
		"TMario::jumpDownCommon": 0x8024be0c,
		"jumpDownCommon": 0x8024be0c,
		"TMario::jumpCatch": 0x8024bf04,
		"jumpCatch": 0x8024bf04,
		"TMario::landing": 0x8024c1d0,
		"landing": 0x8024c1d0,
		"TMario::checkBackTrig": 0x8024c344,
		"checkBackTrig": 0x8024c344,
		"TMario::considerJumpRotate": 0x8024c3e0,
		"considerJumpRotate": 0x8024c3e0,
		"TMario::jumpingBasic": 0x8024c454,
		"jumpingBasic": 0x8024c454,
		"TMario::doJumping": 0x8024cad8,
		"doJumping": 0x8024cad8,
		"TMario::startJumpWall": 0x8024cdb0,
		"startJumpWall": 0x8024cdb0,
		"Player::__sinit_MarioJump_cpp": 0x8024ce80,
		"__sinit_MarioJump_cpp": 0x8024ce80,
		"TMario::perform": 0x8024d2a8,
		"TMario::isMario": 0x8024db0c,
		"isMario": 0x8024db0c,
		"Player::__sinit_MarioMain_cpp": 0x8024db28,
		"__sinit_MarioMain_cpp": 0x8024db28,
		"TMario::playerControl": 0x8024de38,
		"TYoshi::onYoshi": 0x8024e2e4,
		"TMario::gunExec": 0x8024e300,
		"gunExec": 0x8024e300,
		"TMario::checkWet": 0x8024e748,
		"checkWet": 0x8024e748,
		"TBGCheckData::isMarioThrough": 0x8024e950,
		"isMarioThrough": 0x8024e950,
		"TMario::thinkYoshiHeadCollision": 0x8024e9a4,
		"thinkYoshiHeadCollision": 0x8024e9a4,
		"TMario::getOffYoshi": 0x8024eb6c,
		"getOffYoshi": 0x8024eb6c,
		"TMario::thinkParams": 0x8024ec44,
		"thinkParams": 0x8024ec44,
		"TMario::thinkSand": 0x8024ef48,
		"thinkSand": 0x8024ef48,
		"TMario::thinkWaterSurface": 0x8024efe4,
		"thinkWaterSurface": 0x8024efe4,
		"TMario::thinkSituation": 0x8024f870,
		"thinkSituation": 0x8024f870,
		"TMario::calcGroundMtx": 0x8024fee4,
		"calcGroundMtx": 0x8024fee4,
		"TMario::stateMachine": 0x8025009c,
		"stateMachine": 0x8025009c,
		"TMario::checkPlayerAction": 0x80250198,
		"checkPlayerAction": 0x80250198,
		"TMario::checkRideReCalc": 0x80250204,
		"checkRideReCalc": 0x80250204,
		"TMario::checkRideMovement": 0x802502b0,
		"checkRideMovement": 0x802502b0,
		"TMario::checkCurrentPlane": 0x80250580,
		"checkCurrentPlane": 0x80250580,
		"TMario::getDmgMapCode": 0x8025103c,
		"getDmgMapCode": 0x8025103c,
		"TMario::checkGroundPlane": 0x802510b4,
		"checkGroundPlane": 0x802510b4,
		"TMario::makeHistory": 0x802511d8,
		"makeHistory": 0x802511d8,
		"TMario::checkStickRotate": 0x80251304,
		"checkStickRotate": 0x80251304,
		"TMario::checkController": 0x80251494,
		"TMario::checkThrowObject": 0x80252210,
		"checkThrowObject": 0x80252210,
		"TMario::checkReturn": 0x80252264,
		"TMario::checkEnforceJump": 0x80252384,
		"checkEnforceJump": 0x80252384,
		"MSound::startForceJumpSound": 0x802524bc,
		"startForceJumpSound": 0x802524bc,
		"TMario::checkSink": 0x8025259c,
		"checkSink": 0x8025259c,
		"TMario::thinkHeight": 0x802528b8,
		"thinkHeight": 0x802528b8,
		"TMario::thinkDirty": 0x80252a04,
		"thinkDirty": 0x80252a04,
		"TMario::dirtyLimitCheck": 0x80252bb0,
		"dirtyLimitCheck": 0x80252bb0,
		"TMario::checkGraffito": 0x80252bdc,
		"checkGraffito": 0x80252bdc,
		"TMario::checkGraffitoElec": 0x80253224,
		"checkGraffitoElec": 0x80253224,
		"TMario::checkGraffitoSlip": 0x802533dc,
		"checkGraffitoSlip": 0x802533dc,
		"TMario::checkGraffitoFire": 0x80253660,
		"checkGraffitoFire": 0x80253660,
		"TMario::checkAllMotions": 0x802538e0,
		"checkAllMotions": 0x802538e0,
		"TMario::changePlayerDropping": 0x80253a10,
		"changePlayerDropping": 0x80253a10,
		"TMario::changePlayerJumping": 0x80253a68,
		"changePlayerJumping": 0x80253a68,
		"TMario::changePlayerTriJump": 0x80253d54,
		"changePlayerTriJump": 0x80253d54,
		"TMario::changePlayerStatus": 0x80254034,
		"changePlayerStatus": 0x80254034,
		"TMario::throwMario": 0x80254200,
		"TMario::setStatusToJumping": 0x802543a0,
		"setStatusToJumping": 0x802543a0,
		"TMario::checkPlayerAround": 0x80254ef8,
		"checkPlayerAround": 0x80254ef8,
		"TMario::getSlideStopCatch": 0x80254f6c,
		"getSlideStopCatch": 0x80254f6c,
		"TMario::getSlideStopNormal": 0x802550ec,
		"getSlideStopNormal": 0x802550ec,
		"TMario::canSlipJump": 0x80255264,
		"canSlipJump": 0x80255264,
		"TMario::isSlipStart": 0x80255400,
		"isSlipStart": 0x80255400,
		"TMario::isFrontSlip": 0x80255570,
		"isFrontSlip": 0x80255570,
		"TMario::checkRoofPlane": 0x802555c0,
		"checkRoofPlane": 0x802555c0,
		"TMario::checkWallPlane": 0x802555fc,
		"checkWallPlane": 0x802555fc,
		"TMario::setPlayerVelocity": 0x80255734,
		"setPlayerVelocity": 0x80255734,
		"TMario::setNormalAttackArea": 0x80255794,
		"setNormalAttackArea": 0x80255794,
		"TMario::canBendBody": 0x802557d8,
		"canBendBody": 0x802557d8,
		"TMario::considerRotateJumpStart": 0x80255818,
		"considerRotateJumpStart": 0x80255818,
		"TMario::addVelocity": 0x802558a4,
		"addVelocity": 0x802558a4,
		"TMario::onYoshi": 0x802558c8,
		"TMario::windMove": 0x80255910,
		"windMove": 0x80255910,
		"TMario::flowMove": 0x80255944,
		"flowMove": 0x80255944,
		"TMario::warpRequest": 0x8025599c,
		"warpRequest": 0x8025599c,
		"TMario::moveRequest": 0x80255a8c,
		"TMario::isForceSlip": 0x80255d18,
		"isForceSlip": 0x80255d18,
		"TMario::getRidingMtx": 0x80255dc0,
		"getRidingMtx": 0x80255dc0,
		"TMario::isWallInFront": 0x80255e3c,
		"isWallInFront": 0x80255e3c,
		"TMario::isInvincible": 0x80255ea4,
		"isInvincible": 0x80255ea4,
		"TMario::isUnderWater": 0x80255f58,
		"isUnderWater": 0x80255f58,
		"TMario::canSquat": 0x80255fa0,
		"canSquat": 0x80255fa0,
		"TMario::getJumpSlideControl": 0x8025602c,
		"getJumpSlideControl": 0x8025602c,
		"TMario::getJumpAccelControl": 0x802560c8,
		"getJumpAccelControl": 0x802560c8,
		"Player::__sinit_MarioMove_cpp": 0x802560e4,
		"__sinit_MarioMove_cpp": 0x802560e4,
		"TMario::jumpProcess": 0x802563e0,
		"jumpProcess": 0x802563e0,
		"TMario::fallProcess": 0x8025654c,
		"fallProcess": 0x8025654c,
		"TMario::checkGroundAtJumping": 0x80256694,
		"checkGroundAtJumping": 0x80256694,
		"TMario::hangonCheck": 0x80256c74,
		"hangonCheck": 0x80256c74,
		"TMario::barProcess": 0x80256e64,
		"barProcess": 0x80256e64,
		"TMario::walkProcess": 0x802570c4,
		"walkProcess": 0x802570c4,
		"TMario::waitProcess": 0x80257184,
		"waitProcess": 0x80257184,
		"TMario::stopProcess": 0x802572a4,
		"stopProcess": 0x802572a4,
		"TMario::checkGroundAtWalking": 0x802572f4,
		"checkGroundAtWalking": 0x802572f4,
		"TMario::checkDescent": 0x80257590,
		"checkDescent": 0x80257590,
		"TMario::playerRefrection": 0x80257b60,
		"playerRefrection": 0x80257b60,
		"Player::__sinit_MarioPhysics_cpp": 0x80257bf8,
		"__sinit_MarioPhysics_cpp": 0x80257bf8,
		"TMarioInputReplay::reset": 0x80257ef4,
		"TMarioInputReplay::play": 0x80257f54,
		"TMarioInputReplay::init": 0x80258038,
		"TRecordValueManager<unsigned_char><unsigned_char>::reset": 0x80258128,
		"TRecordValueManager<unsigned_char><unsigned_char>::get": 0x80258148,
		"TRecordValueManager<unsigned_short><unsigned_short>::reset": 0x802581a0,
		"TRecordValueManager<unsigned_short><unsigned_short>::get": 0x802581c0,
		"TRecordValueManager<short><short>::reset": 0x80258218,
		"TRecordValueManager<short><short>::get": 0x80258238,
		"TRecordValueManager<float><float>::reset": 0x80258290,
		"TRecordValueManager<float><float>::get": 0x802582b0,
		"TMario::moveMain": 0x80258308,
		"moveMain": 0x80258308,
		"TMario::jumpSlipEvents": 0x80258d24,
		"jumpSlipEvents": 0x80258d24,
		"TMario::jumpSlipCommon": 0x80258e5c,
		"jumpSlipCommon": 0x80258e5c,
		"TMario::loserDown": 0x80258f94,
		"loserDown": 0x80258f94,
		"TMario::downingCommon": 0x802590b8,
		"downingCommon": 0x802590b8,
		"TMario::oilSlip": 0x80259208,
		"oilSlip": 0x80259208,
		"TMario::oilRun": 0x80259438,
		"oilRun": 0x80259438,
		"TMario::catching": 0x8025970c,
		"catching": 0x8025970c,
		"TMario::slipBackCommon": 0x80259860,
		"slipBackCommon": 0x80259860,
		"TMario::slipForeCommon": 0x80259940,
		"slipForeCommon": 0x80259940,
		"TMario::slippingBasic": 0x80259a08,
		"slippingBasic": 0x80259a08,
		"TMario::fireDashing": 0x80259d24,
		"fireDashing": 0x80259d24,
		"TMario::walkEnd": 0x80259eac,
		"walkEnd": 0x80259eac,
		"TMario::surfing": 0x8025a0f4,
		"surfing": 0x8025a0f4,
		"TMario::turnEnd": 0x8025a3d4,
		"turnEnd": 0x8025a3d4,
		"TMario::turnning": 0x8025a638,
		"turnning": 0x8025a638,
		"TMario::rotating": 0x8025aa24,
		"rotating": 0x8025aa24,
		"TMario::running": 0x8025ab4c,
		"running": 0x8025ab4c,
		"TMario::doPushingAnimation": 0x8025b2dc,
		"doPushingAnimation": 0x8025b2dc,
		"TMario::doSurfing": 0x8025b434,
		"doSurfing": 0x8025b434,
		"TMario::getSurfingParamsWater": 0x8025b844,
		"getSurfingParamsWater": 0x8025b844,
		"TMario::doRunning": 0x8025b878,
		"doRunning": 0x8025b878,
		"TMario::slopeProcess": 0x8025bb64,
		"slopeProcess": 0x8025bb64,
		"TMario::doSliding": 0x8025bcd8,
		"doSliding": 0x8025bcd8,
		"TMario::slideProcess": 0x8025c0c4,
		"slideProcess": 0x8025c0c4,
		"TMario::getSlideStickMult": 0x8025c48c,
		"getSlideStickMult": 0x8025c48c,
		"TMario::getChangeAngleSpeed": 0x8025c534,
		"getChangeAngleSpeed": 0x8025c534,
		"TMario::getSlopeSlideAccele": 0x8025c6e8,
		"getSlopeSlideAccele": 0x8025c6e8,
		"TMario::getSlopeNormalAccele": 0x8025c844,
		"getSlopeNormalAccele": 0x8025c844,
		"TMario::doRunningAnimation": 0x8025c9a0,
		"doRunningAnimation": 0x8025c9a0,
		"TMario::isRunningInWater": 0x8025cc90,
		"isRunningInWater": 0x8025cc90,
		"TMario::considerRotateStart": 0x8025ccd8,
		"considerRotateStart": 0x8025ccd8,
		"Player::__sinit_MarioRun_cpp": 0x8025cd68,
		"__sinit_MarioRun_cpp": 0x8025cd68,
		"TMario::specMain": 0x8025d064,
		"specMain": 0x8025d064,
		"TMario::fencePunch": 0x8025de30,
		"fencePunch": 0x8025de30,
		"TMario::fenceMove": 0x8025e0e8,
		"fenceMove": 0x8025e0e8,
		"TMario::pulling": 0x8025e8a8,
		"pulling": 0x8025e8a8,
		"TMario::getCurrentPullParams": 0x8025edac,
		"getCurrentPullParams": 0x8025edac,
		"TMario::wireRolling": 0x8025ee68,
		"wireRolling": 0x8025ee68,
		"TMario::wireHanging": 0x8025f59c,
		"wireHanging": 0x8025f59c,
		"TMario::changeWireHanging": 0x8025fb90,
		"changeWireHanging": 0x8025fb90,
		"TMario::wireSWait": 0x8025fc1c,
		"wireSWait": 0x8025fc1c,
		"TMario::wireWait": 0x8025ffa8,
		"wireWait": 0x8025ffa8,
		"TMario::wireMove": 0x802603f8,
		"wireMove": 0x802603f8,
		"TMario::getOnWirePosAngle": 0x80260530,
		"getOnWirePosAngle": 0x80260530,
		"TMario::hanging": 0x80260718,
		"hanging": 0x80260718,
		"TMario::startHangLanding": 0x80261144,
		"startHangLanding": 0x80261144,
		"TMario::moveRoof": 0x8026121c,
		"moveRoof": 0x8026121c,
		"TMario::roofCommonEvents": 0x80261480,
		"roofCommonEvents": 0x80261480,
		"TMario::doRoofMovingProcess": 0x80261580,
		"doRoofMovingProcess": 0x80261580,
		"TMario::hangingCheckRoof": 0x802616e0,
		"hangingCheckRoof": 0x802616e0,
		"TMario::barClimb": 0x8026187c,
		"barClimb": 0x8026187c,
		"TMario::barWait": 0x80261b48,
		"barWait": 0x80261b48,
		"Player::__sinit_MarioSpecial_cpp": 0x80261fac,
		"__sinit_MarioSpecial_cpp": 0x80261fac,
		"TMario::stateMachineUpper": 0x802622a8,
		"stateMachineUpper": 0x802622a8,
		"TMario::checkPumpEnable": 0x802624a0,
		"checkPumpEnable": 0x802624a0,
		"TMario::checkPumping": 0x80262674,
		"checkPumping": 0x80262674,
		"Player::__sinit_MarioUpper_cpp": 0x8026278c,
		"__sinit_MarioUpper_cpp": 0x8026278c,
		"TMario::askJumpIntoWaterEffectExist": 0x80262a88,
		"askJumpIntoWaterEffectExist": 0x80262a88,
		"TMario::sinkInSandEffect": 0x80262abc,
		"sinkInSandEffect": 0x80262abc,
		"TMario::kickFruitEffect": 0x80262b18,
		"kickFruitEffect": 0x80262b18,
		"TMario::toroccoEffect": 0x80262bbc,
		"toroccoEffect": 0x80262bbc,
		"TMario::sleepingEffectKill": 0x80262cdc,
		"sleepingEffectKill": 0x80262cdc,
		"TMario::sleepingEffect": 0x80262d1c,
		"sleepingEffect": 0x80262d1c,
		"TMario::kickRoofEffect": 0x80262d50,
		"kickRoofEffect": 0x80262d50,
		"TMario::elecEndEffect": 0x80262de4,
		"elecEndEffect": 0x80262de4,
		"TMario::elecEffect": 0x80262e18,
		"elecEffect": 0x80262e18,
		"TMario::rocketEffectStart": 0x80262e88,
		"rocketEffectStart": 0x80262e88,
		"TMario::meltInWaterEffect": 0x80262f54,
		"meltInWaterEffect": 0x80262f54,
		"TMario::emitSandEffect": 0x80263000,
		"emitSandEffect": 0x80263000,
		"TMario::emitDirtyFootPrint": 0x80263028,
		"emitDirtyFootPrint": 0x80263028,
		"TMario::emitFootPrintWithEffect": 0x80263050,
		"emitFootPrintWithEffect": 0x80263050,
		"TMario::emitRotateShootEffect": 0x802632ec,
		"emitRotateShootEffect": 0x802632ec,
		"TMario::emitBlurSpinJump": 0x80263344,
		"emitBlurSpinJump": 0x80263344,
		"TMario::emitBlurHipDropSuper": 0x802633f8,
		"emitBlurHipDropSuper": 0x802633f8,
		"TMario::emitBlurHipDrop": 0x8026349c,
		"emitBlurHipDrop": 0x8026349c,
		"TMario::warpOutEffect": 0x802634e0,
		"warpOutEffect": 0x802634e0,
		"TMario::warpInLight": 0x8026376c,
		"warpInLight": 0x8026376c,
		"TMario::warpInEffect": 0x802637a0,
		"warpInEffect": 0x802637a0,
		"TWarpInCallBack::execute": 0x8026391c,
		"TMario::surfingEffect": 0x80263aa0,
		"surfingEffect": 0x80263aa0,
		"TMario::frontSlipEffect": 0x80263c4c,
		"frontSlipEffect": 0x80263c4c,
		"TMario::treeSlipEffect": 0x80263dc0,
		"treeSlipEffect": 0x80263dc0,
		"TMario::wallSlipEffect": 0x80263e70,
		"wallSlipEffect": 0x80263e70,
		"TMario::blurEffect": 0x80263ea4,
		"blurEffect": 0x80263ea4,
		"TMario::runningRippleEffect": 0x80263ee4,
		"runningRippleEffect": 0x80263ee4,
		"TMario::swimmingBubbleEffect": 0x80263f3c,
		"swimmingBubbleEffect": 0x80263f3c,
		"TMario::bubbleFromBody": 0x80264010,
		"bubbleFromBody": 0x80264010,
		"TMario::bubbleFromMouth": 0x802640d4,
		"bubbleFromMouth": 0x802640d4,
		"TBubbleCallBack::execute": 0x80264144,
		"TMario::inOutWaterEffect": 0x802641e8,
		"inOutWaterEffect": 0x802641e8,
		"TMario::rippleEffect": 0x802643a0,
		"rippleEffect": 0x802643a0,
		"TMario::smallTouchDownEffect": 0x8026443c,
		"smallTouchDownEffect": 0x8026443c,
		"TMario::strongTouchDownEffect": 0x802644e0,
		"strongTouchDownEffect": 0x802644e0,
		"TMario::emitGetCoinEffect": 0x80264550,
		"emitGetCoinEffect": 0x80264550,
		"TMario::emitGetWaterEffect": 0x802645a8,
		"emitGetWaterEffect": 0x802645a8,
		"TMario::emitGetEffect": 0x802645dc,
		"emitGetEffect": 0x802645dc,
		"TMario::emitSweatSometimes": 0x80264628,
		"emitSweatSometimes": 0x80264628,
		"TMario::emitSweat": 0x8026465c,
		"emitSweat": 0x8026465c,
		"TMario::emitSmoke": 0x80264730,
		"emitSmoke": 0x80264730,
		"TMario::moveParticle": 0x80264884,
		"moveParticle": 0x80264884,
		"TMario::initParticle": 0x802648f0,
		"Player::__sinit_MarioParticle_cpp": 0x802649c8,
		"__sinit_MarioParticle_cpp": 0x802649c8,
		"TMario::waitMain": 0x80264cdc,
		"waitMain": 0x80264cdc,
		"TMario::jumpEndEvents": 0x802655b4,
		"jumpEndEvents": 0x802655b4,
		"TMario::jumpEndCommon": 0x8026562c,
		"jumpEndCommon": 0x8026562c,
		"TMario::squatStandup": 0x802656ac,
		"squatStandup": 0x802656ac,
		"TMario::squating": 0x802657c8,
		"squating": 0x802657c8,
		"TMario::getSideWalkValues": 0x80265b04,
		"getSideWalkValues": 0x80265b04,
		"TMario::sleeping": 0x80265bd4,
		"sleeping": 0x80265bd4,
		"TMario::sleepily": 0x80265d68,
		"sleepily": 0x80265d68,
		"TMario::waiting": 0x80265e88,
		"waiting": 0x80265e88,
		"TMario::changeMontemanWaitingAnim": 0x80266128,
		"changeMontemanWaitingAnim": 0x80266128,
		"TMario::stopCommon": 0x80266148,
		"stopCommon": 0x80266148,
		"TMario::waitingCommonEvents": 0x80266204,
		"waitingCommonEvents": 0x80266204,
		"TMario::canPut": 0x80266424,
		"canPut": 0x80266424,
		"TMario::canSleep": 0x802664e4,
		"canSleep": 0x802664e4,
		"TMario::startTalking": 0x802666a0,
		"startTalking": 0x802666a0,
		"Player::__sinit_MarioWait_cpp": 0x80266728,
		"__sinit_MarioWait_cpp": 0x80266728,
		"TSplashManager::~TSplashManager": 0x80266a24,
		"TSplashManager::perform": 0x80266ac4,
		"TSplashManager::draw": 0x80266b44,
		"TSplashManager::makeDL": 0x80266d64,
		"TSplashManager::move": 0x80266eec,
		"TSplashManager::newSplash": 0x80266fac,
		"newSplash": 0x80266fac,
		"TSplashManager::load": 0x80267050,
		"Player::__sinit_SplashManager_cpp": 0x802671e8,
		"__sinit_SplashManager_cpp": 0x802671e8,
		"TYoshiTongue::getTakingMtx": 0x80267580,
		"TYoshiTongue::checkTaking": 0x8026758c,
		"checkTaking": 0x8026758c,
		"TYoshiTongue::checkTaken": 0x80267590,
		"checkTaken": 0x80267590,
		"TYoshiTongue::entry": 0x80267594,
		"TYoshiTongue::viewCalc": 0x802675f0,
		"TYoshiTongue::calcAnim": 0x8026764c,
		"TYoshiTongue::movement": 0x802678c8,
		"JGeometry::TVec3<float><float>::operator_-=": 0x80268168,
		"operator_-=": 0x80268168,
		"TYoshiTongue::findTarget": 0x8026819c,
		"findTarget": 0x8026819c,
		"TYoshiTongue::canGo": 0x802684b0,
		"canGo": 0x802684b0,
		"TYoshiTongue::emit": 0x802685ec,
		"TYoshiTongue::initInLoadAfter": 0x80268780,
		"TYoshiTongue::init": 0x8026888c,
		"Player::__sinit_Tongue_cpp": 0x80268a80,
		"__sinit_Tongue_cpp": 0x80268a80,
		"TWaterGun::changeBackup": 0x80268d84,
		"changeBackup": 0x80268d84,
		"TWaterGun::damage": 0x80268e30,
		"damage": 0x80268e30,
		"TWaterGun::suck": 0x80268e80,
		"suck": 0x80268e80,
		"TWaterGun::emit": 0x80268f98,
		"TWaterGun::triggerPressureMovement": 0x8026923c,
		"triggerPressureMovement": 0x8026923c,
		"TWaterGun::rotateProp": 0x802692d4,
		"rotateProp": 0x802692d4,
		"TWaterGun::getEmitPosDirSpeed": 0x80269388,
		"getEmitPosDirSpeed": 0x80269388,
		"TWaterGun::getPressureMax": 0x80269448,
		"getPressureMax": 0x80269448,
		"TWaterGun::getPressure": 0x802694b4,
		"getPressure": 0x802694b4,
		"TWaterGun::isPressureOn": 0x80269520,
		"isPressureOn": 0x80269520,
		"TWaterGun::setAmountToRate": 0x8026959c,
		"setAmountToRate": 0x8026959c,
		"TWaterGun::getCurrentNozzle": 0x8026960c,
		"getCurrentNozzle": 0x8026960c,
		"TWaterGun::perform": 0x8026971c,
		"TWaterGun::calcAnimation": 0x80269868,
		"calcAnimation": 0x80269868,
		"TWaterGun::setBaseTRMtx": 0x80269af4,
		"setBaseTRMtx": 0x80269af4,
		"TWaterGun::movement": 0x80269be0,
		"TWaterGun::changeNozzle": 0x8026a164,
		"changeNozzle": 0x8026a164,
		"TWaterGun::getNozzleMtx": 0x8026a2a4,
		"getNozzleMtx": 0x8026a2a4,
		"TWaterGun::getEmitMtx": 0x8026a2c0,
		"getEmitMtx": 0x8026a2c0,
		"TWaterGun::initInLoadAfter": 0x8026a3b8,
		"TWaterGun::init": 0x8026a3bc,
		"TWaterGun::TWaterGun": 0x8026aa48,
		"TNozzleDeform::animation": 0x8026adf4,
		"TNozzleDeform::emit": 0x8026b580,
		"TNozzleDeform::movement": 0x8026b928,
		"TNozzleTrigger::animation": 0x8026ba50,
		"TNozzleTrigger::emit": 0x8026bfc4,
		"TNozzleTrigger::movement": 0x8026c2cc,
		"TNozzleTrigger::init": 0x8026c6e4,
		"TNozzleBase::animation": 0x8026c704,
		"TNozzleBase::emit": 0x8026cbbc,
		"TNozzleBase::emitCommon": 0x8026ce88,
		"emitCommon": 0x8026ce88,
		"TNozzleBase::movement": 0x8026d020,
		"TNozzleBase::calcGunAngle": 0x8026d0e8,
		"calcGunAngle": 0x8026d0e8,
		"TNozzleBase::init": 0x8026d21c,
		"TNozzleBase::TNozzleBase": 0x8026d240,
		"Player::WaterGunDivingCtrlR": 0x8026da40,
		"WaterGunDivingCtrlR": 0x8026da40,
		"Player::WaterGunDivingCtrlL": 0x8026dad0,
		"WaterGunDivingCtrlL": 0x8026dad0,
		"Player::RotateCtrl": 0x8026db60,
		"RotateCtrl": 0x8026db60,
		"Player::NozzleCtrl": 0x8026dbe4,
		"NozzleCtrl": 0x8026dbe4,
		"TNozzleBase::getWaistAngle": 0x8026dc90,
		"getWaistAngle": 0x8026dc90,
		"TNozzleDeform::getNozzleKind": 0x8026dc98,
		"Player::__sinit_WaterGun_cpp": 0x8026dca0,
		"__sinit_WaterGun_cpp": 0x8026dca0,
		"TYoshi::entry": 0x8026df9c,
		"TYoshi::viewCalc": 0x8026e2bc,
		"TYoshi::calcAnim": 0x8026e33c,
		"TYoshi::movement": 0x8026e778,
		"TYoshi::thinkHoldOut": 0x8026f4ac,
		"thinkHoldOut": 0x8026f4ac,
		"TYoshi::doEat": 0x8026f60c,
		"doEat": 0x8026f60c,
		"TYoshi::doSearch": 0x8026f730,
		"doSearch": 0x8026f730,
		"TYoshi::thinkUpper": 0x8026fc90,
		"thinkUpper": 0x8026fc90,
		"TYoshi::thinkAnimation": 0x8026fe38,
		"thinkAnimation": 0x8026fe38,
		"TYoshi::getOff": 0x8027022c,
		"getOff": 0x8027022c,
		"TYoshi::ride": 0x802703e8,
		"ride": 0x802703e8,
		"TYoshi::kill": 0x802704d8,
		"TYoshi::disappear": 0x802705f0,
		"disappear": 0x802705f0,
		"TYoshi::appearFromEgg": 0x80270704,
		"appearFromEgg": 0x80270704,
		"TYoshi::setEggYoshiPtr": 0x8027088c,
		"setEggYoshiPtr": 0x8027088c,
		"TYoshi::getEmitPosDir": 0x80270894,
		"getEmitPosDir": 0x80270894,
		"TYoshi::changeAnimation": 0x802708e0,
		"changeAnimation": 0x802708e0,
		"TYoshi::thinkBtp": 0x8027097c,
		"thinkBtp": 0x8027097c,
		"TYoshi::initInLoadAfter": 0x80270a2c,
		"TYoshi::init": 0x80270b00,
		"TYoshi::getMtxPtrFootR": 0x802715a4,
		"getMtxPtrFootR": 0x802715a4,
		"TYoshi::getMtxPtrFootL": 0x802715c0,
		"getMtxPtrFootL": 0x802715c0,
		"TYoshi::getFrameCtrl": 0x802715dc,
		"Player::YoshiHeadCtrl": 0x80271604,
		"YoshiHeadCtrl": 0x80271604,
		"Player::__sinit_Yoshi_cpp": 0x80271690,
		"__sinit_Yoshi_cpp": 0x80271690,
		"TMarioEffect::perform": 0x80271a10,
		"TMarioEffect::setJumpIntoWaterEffectSmall": 0x80271cf0,
		"setJumpIntoWaterEffectSmall": 0x80271cf0,
		"TMarioEffect::setJumpIntoWaterEffect": 0x80271e8c,
		"setJumpIntoWaterEffect": 0x80271e8c,
		"TMarioEffect::init": 0x802720c4,
		"Player::__sinit_MarioEffect_cpp": 0x802722d4,
		"__sinit_MarioEffect_cpp": 0x802722d4,
		"TMario::swimMain": 0x802725d8,
		"swimMain": 0x802725d8,
		"TMario::swimPaddle": 0x80272cd0,
		"swimPaddle": 0x80272cd0,
		"TMario::checkSwimJump": 0x80272e00,
		"checkSwimJump": 0x80272e00,
		"TMario::doSwimming": 0x80272f70,
		"doSwimming": 0x80272f70,
		"Player::__sinit_MarioSwim_cpp": 0x802732f4,
		"__sinit_MarioSwim_cpp": 0x802732f4,
		"Player::SMS_IsMarioRoofing": 0x802735f0,
		"SMS_IsMarioRoofing": 0x802735f0,
		"Player::SMS_IsMarioFencing": 0x8027361c,
		"SMS_IsMarioFencing": 0x8027361c,
		"Player::SMS_GetMarioRfPlane": 0x80273650,
		"SMS_GetMarioRfPlane": 0x80273650,
		"Player::SMS_GetMarioWlPlane": 0x8027365c,
		"SMS_GetMarioWlPlane": 0x8027365c,
		"Player::SMS_GetMarioGrPlane": 0x80273668,
		"SMS_GetMarioGrPlane": 0x80273668,
		"Player::SMS_WindMoveMario": 0x80273680,
		"SMS_WindMoveMario": 0x80273680,
		"Player::SMS_FlowMoveMario": 0x802736a8,
		"SMS_FlowMoveMario": 0x802736a8,
		"Player::SMS_MarioWarpRequest": 0x802736d0,
		"SMS_MarioWarpRequest": 0x802736d0,
		"Player::SMS_MarioMoveRequest": 0x802736f8,
		"SMS_MarioMoveRequest": 0x802736f8,
		"Player::SMS_IsMarioDashing": 0x8027372c,
		"SMS_IsMarioDashing": 0x8027372c,
		"Player::SMS_IsMarioOnYoshi": 0x80273760,
		"SMS_IsMarioOnYoshi": 0x80273760,
		"Player::SMS_IsMarioOpeningDoor": 0x80273794,
		"SMS_IsMarioOpeningDoor": 0x80273794,
		"Player::SMS_IsMarioOnWire": 0x802737bc,
		"SMS_IsMarioOnWire": 0x802737bc,
		"Player::SMS_IsMarioTouchGround4cm": 0x80273804,
		"SMS_IsMarioTouchGround4cm": 0x80273804,
		"Player::SMS_ThrowMario": 0x80273848,
		"SMS_ThrowMario": 0x80273848,
		"Player::SMS_SendMessageToMario": 0x80273870,
		"SMS_SendMessageToMario": 0x80273870,
		"Player::SMS_GetMarioWaterGun": 0x802738c0,
		"SMS_GetMarioWaterGun": 0x802738c0,
		"Player::SMS_GetMarioGravity": 0x802738cc,
		"SMS_GetMarioGravity": 0x802738cc,
		"Player::SMS_GetMarioGrLevel": 0x802738d8,
		"SMS_GetMarioGrLevel": 0x802738d8,
		"Player::SMS_GetMarioDamageRadius": 0x802738e4,
		"SMS_GetMarioDamageRadius": 0x802738e4,
		"Player::SMS_GetMarioHP": 0x802738f0,
		"SMS_GetMarioHP": 0x802738f0,
		"Player::SMS_IsMarioHeadSlideAttack": 0x802738fc,
		"SMS_IsMarioHeadSlideAttack": 0x802738fc,
		"Player::SMS_IsMarioStatusElecDamage": 0x80273928,
		"SMS_IsMarioStatusElecDamage": 0x80273928,
		"Player::SMS_IsMarioStatusThrownDown": 0x8027394c,
		"SMS_IsMarioStatusThrownDown": 0x8027394c,
		"Player::SMS_IsMarioStatusHipDrop": 0x80273970,
		"SMS_IsMarioStatusHipDrop": 0x80273970,
		"Player::SMS_IsMarioStatusTypeSwimming": 0x80273994,
		"SMS_IsMarioStatusTypeSwimming": 0x80273994,
		"Player::SMS_IsMarioStatusTypeJumping": 0x802739b4,
		"SMS_IsMarioStatusTypeJumping": 0x802739b4,
		"Player::SMS_GetMarioHitActor": 0x802739d4,
		"SMS_GetMarioHitActor": 0x802739d4,
		"Player::SMS_AskJumpIntoWaterEffectExist": 0x802739dc,
		"SMS_AskJumpIntoWaterEffectExist": 0x802739dc,
		"Player::SMS_GetYoshi": 0x80273a00,
		"SMS_GetYoshi": 0x80273a00,
		"Player::SMS_SetMarioAccessParams": 0x80273a0c,
		"SMS_SetMarioAccessParams": 0x80273a0c,
		"TMario::TSurfingParams::TSurfingParams": 0x80273a70,
		"TMario::TDirtyParams::TDirtyParams": 0x80273ecc,
		"TMario::TGraffitoParams::TGraffitoParams": 0x80274350,
		"TMario::TWireParams::TWireParams": 0x80274754,
		"TMario::TSwimParams::TSwimParams": 0x80274a80,
		"TMario::TRunParams::TRunParams": 0x80274fe8,
		"TMario::TJumpParams::TJumpParams": 0x8027540c,
		"TMario::TDeParams::TDeParams": 0x80275c64,
		"TMario::setGamePad": 0x802765ec,
		"setGamePad": 0x802765ec,
		"TMario::resetHistory": 0x802765f4,
		"resetHistory": 0x802765f4,
		"TMario::initValues": 0x802766b0,
		"TMario::loadAfter": 0x80276adc,
		"TMario::load": 0x80276bd0,
		"TMario::TMario": 0x80276cb4,
		"Player::__sinit_MarioInit_cpp": 0x8027bb24,
		"__sinit_MarioInit_cpp": 0x8027bb24,
		"TModelWaterManager::~TModelWaterManager": 0x8027be3c,
		"TModelWaterManager::perform": 0x8027beb0,
		"TModelWaterManager::drawRefracAndSpec": 0x8027c12c,
		"drawRefracAndSpec": 0x8027c12c,
		"TModelWaterManager::drawShineShadowVolume": 0x8027c67c,
		"drawShineShadowVolume": 0x8027c67c,
		"TModelWaterManager::drawMirror": 0x8027cc2c,
		"drawMirror": 0x8027cc2c,
		"TModelWaterManager::drawWaterVolume": 0x8027d418,
		"drawWaterVolume": 0x8027d418,
		"TModelWaterManager::drawSilhouette": 0x8027dd00,
		"drawSilhouette": 0x8027dd00,
		"TModelWaterManager::drawTouching": 0x8027e0ec,
		"drawTouching": 0x8027e0ec,
		"TModelWaterManager::calcVMAll": 0x8027e21c,
		"calcVMAll": 0x8027e21c,
		"TModelWaterManager::calcVMMtxWall": 0x8027e3a4,
		"calcVMMtxWall": 0x8027e3a4,
		"TModelWaterManager::calcVMMtxGround": 0x8027e4b8,
		"calcVMMtxGround": 0x8027e4b8,
		"TModelWaterManager::calcDrawVtx": 0x8027e5f4,
		"calcDrawVtx": 0x8027e5f4,
		"TModelWaterManager::calcWorldMinMax": 0x8027e8e0,
		"calcWorldMinMax": 0x8027e8e0,
		"TModelWaterManager::move": 0x8027ea48,
		"TBGCheckData::isWaterSlip": 0x8027fa9c,
		"isWaterSlip": 0x8027fa9c,
		"TModelWaterManager::garbageCollect": 0x8027fad0,
		"garbageCollect": 0x8027fad0,
		"TModelWaterManager::wind": 0x8027fbe8,
		"wind": 0x8027fbe8,
		"TModelWaterManager::askDoWaterHitCheck": 0x8027fc5c,
		"askDoWaterHitCheck": 0x8027fc5c,
		"TModelWaterManager::emitRequest": 0x8027fc84,
		"emitRequest": 0x8027fc84,
		"TModelWaterManager::makeEmit": 0x8027fd28,
		"makeEmit": 0x8027fd28,
		"TModelWaterManager::askHitWaterParticleOnGround": 0x8027fff4,
		"askHitWaterParticleOnGround": 0x8027fff4,
		"TModelWaterManager::loadAfter": 0x80280088,
		"TModelWaterManager::load": 0x80280184,
		"TWaterEmitInfo::TWaterEmitInfo": 0x802806f4,
		"Player::__sinit_ModelWaterManager_cpp": 0x80280adc,
		"__sinit_ModelWaterManager_cpp": 0x80280adc,
		"TMarioPositionObj::~TMarioPositionObj": 0x80280e1c,
		"TMarioPositionObj::perform": 0x80280e90,
		"TMarioPositionObj::load": 0x80280e94,
		"TMario::checkCollision": 0x80280fe8,
		"checkCollision": 0x80280fe8,
		"TMario::hangPole": 0x80282354,
		"hangPole": 0x80282354,
		"TMario::hitNormal": 0x802825e8,
		"hitNormal": 0x802825e8,
		"Player::__sinit_MarioCheckCol_cpp": 0x802827f8,
		"__sinit_MarioCheckCol_cpp": 0x802827f8,
		"TMario::receiveMessage": 0x80282af4,
		"TMario::getGesso": 0x80284db8,
		"getGesso": 0x80284db8,
		"Player::__sinit_MarioReceiveMsg_cpp": 0x80284edc,
		"__sinit_MarioReceiveMsg_cpp": 0x80284edc,
		"TMarioSoundValues::TMarioSoundValues": 0x802851d8,
		"TMario::startSoundActor": 0x8028522c,
		"TMario::stopVoice": 0x80285290,
		"stopVoice": 0x80285290,
		"TMario::startVoiceIfNoVoice": 0x802852d8,
		"startVoiceIfNoVoice": 0x802852d8,
		"TMario::startVoice": 0x8028537c,
		"startVoice": 0x8028537c,
		"TMario::getVoiceStatus": 0x802853f8,
		"getVoiceStatus": 0x802853f8,
		"TMario::soundTorocco": 0x80285464,
		"soundTorocco": 0x80285464,
		"TMario::animSound": 0x80285558,
		"animSound": 0x80285558,
		"TMario::soundMovement": 0x8028583c,
		"soundMovement": 0x8028583c,
		"Player::__sinit_MarioSound_cpp": 0x80287348,
		"__sinit_MarioSound_cpp": 0x80287348,
		"TBaseNPC::monteMESetAnmWhenNear": 0x80202428,
		"monteMESetAnmWhenNear": 0x80202428,
		"TBaseNPC::monteMESetAnmWhenFar": 0x8020264c,
		"monteMESetAnmWhenFar": 0x8020264c,
		"TBaseNPC::sunflowerReviving": 0x8020286c,
		"sunflowerReviving": 0x8020286c,
		"TBaseNPC::sunflowerReviveIn": 0x80202938,
		"sunflowerReviveIn": 0x80202938,
		"TBaseNPC::sunflowerDownIn_": 0x80202a14,
		"sunflowerDownIn_": 0x80202a14,
		"TBaseNPC::peachTiredIn_": 0x80202a50,
		"peachTiredIn_": 0x80202a50,
		"TBaseNPC::peachParasolOut_": 0x80202b0c,
		"peachParasolOut_": 0x80202b0c,
		"TBaseNPC::peachParasolIn_": 0x80202b3c,
		"peachParasolIn_": 0x80202b3c,
		"TBaseNPC::npcMareStanding": 0x80202b6c,
		"npcMareStanding": 0x80202b6c,
		"TBaseNPC::npcMareStandIn": 0x80202cc8,
		"npcMareStandIn": 0x80202cc8,
		"TBaseNPC::npcBlowning": 0x80202e1c,
		"npcBlowning": 0x80202e1c,
		"TBaseNPC::npcBlownIn": 0x80202e48,
		"npcBlownIn": 0x80202e48,
		"TBaseNPC::npcMadding": 0x80202f24,
		"npcMadding": 0x80202f24,
		"TBaseNPC::npcMadIn": 0x802031ec,
		"npcMadIn": 0x802031ec,
		"TBaseNPC::npcThrowing": 0x802032f8,
		"npcThrowing": 0x802032f8,
		"TBaseNPC::npcThrowIn": 0x802033a8,
		"npcThrowIn": 0x802033a8,
		"TBaseNPC::npcSinking": 0x8020347c,
		"npcSinking": 0x8020347c,
		"TBaseNPC::npcWetting": 0x802035c0,
		"npcWetting": 0x802035c0,
		"TBaseNPC::npcWetIn": 0x80204228,
		"npcWetIn": 0x80204228,
		"TBaseNPC::npcHappyIn": 0x80204520,
		"npcHappyIn": 0x80204520,
		"TBaseNPC::npcDanceIn": 0x80204604,
		"npcDanceIn": 0x80204604,
		"TBaseNPC::npcTakenIn": 0x802046e4,
		"npcTakenIn": 0x802046e4,
		"TBaseNPC::npcTalkOut": 0x802047b8,
		"npcTalkOut": 0x802047b8,
		"TBaseNPC::npcTalking": 0x80204984,
		"npcTalking": 0x80204984,
		"TBaseNPC::npcTalkIn": 0x80204b24,
		"npcTalkIn": 0x80204b24,
		"TBaseNPC::npcStepIn": 0x80204cb8,
		"npcStepIn": 0x80204cb8,
		"TBaseNPC::npcRecoverAfterIn": 0x80204d8c,
		"npcRecoverAfterIn": 0x80204d8c,
		"TBaseNPC::npcRecoverFromSinking": 0x80204e60,
		"npcRecoverFromSinking": 0x80204e60,
		"TBaseNPC::npcFallIn": 0x80205040,
		"npcFallIn": 0x80205040,
		"TBaseNPC::npcWaitIn": 0x80205114,
		"npcWaitIn": 0x80205114,
		"TBaseNPC::getNpcWaitAnmBase_": 0x802052ec,
		"getNpcWaitAnmBase_": 0x802052ec,
		"TBaseNPC::walkAnmRateChange_": 0x80205354,
		"walkAnmRateChange_": 0x80205354,
		"TBaseNPC::randomizeBckAndBtpFrame_": 0x80205780,
		"randomizeBckAndBtpFrame_": 0x80205780,
		"TBaseNPC::requestTalkAnm_": 0x802058d8,
		"requestTalkAnm_": 0x802058d8,
		"TBaseNPC::setKeepAnm_": 0x802059a4,
		"setKeepAnm_": 0x802059a4,
		"TBaseNPC::requestNpcAnm_": 0x802059fc,
		"requestNpcAnm_": 0x802059fc,
		"TBaseNPC::setNpcAnm_": 0x80205a9c,
		"setNpcAnm_": 0x80205a9c,
		"NPC::CLBPalFrame": 0x80205f10,
		"NPC::__sinit_NpcAnm_cpp": 0x80205f9c,
		"__sinit_NpcAnm_cpp": 0x80205f9c,
		"TBaseNPC::getPtrInitPollutionColor": 0x80206304,
		"getPtrInitPollutionColor": 0x80206304,
		"TBaseNPC::setBalloonMessage": 0x8020643c,
		"setBalloonMessage": 0x8020643c,
		"TBaseNPC::setDummyConnectActor": 0x80206460,
		"setDummyConnectActor": 0x80206460,
		"TBaseNPC::perform": 0x802064b0,
		"TBaseNPC::getAnmOffDist_": 0x80206c98,
		"getAnmOffDist_": 0x80206c98,
		"TBaseNPC::updateForbidCount_": 0x80206d9c,
		"updateForbidCount_": 0x80206d9c,
		"TBaseNPC::calcRootMatrix": 0x80206ddc,
		"TBaseNPC::execMotionBlend_": 0x80206f04,
		"execMotionBlend_": 0x80206f04,
		"TBaseNPC::moveObject": 0x80206f98,
		"TBaseNPC::receiveMessage": 0x802073e8,
		"TBaseNPC::getFocalPoint": 0x80207604,
		"TBaseNPC::getCursorPos": 0x80207638,
		"getCursorPos": 0x80207638,
		"TBaseNPC::isInMadSearchRange": 0x8020766c,
		"isInMadSearchRange": 0x8020766c,
		"TBaseNPC::isInBodyTurnSearchRange": 0x802076d8,
		"isInBodyTurnSearchRange": 0x802076d8,
		"TBaseNPC::isNeedNeckStraight": 0x80207744,
		"isNeedNeckStraight": 0x80207744,
		"TBaseNPC::isPartsAnmNpc": 0x80207894,
		"isPartsAnmNpc": 0x80207894,
		"TBaseNPC::isBehaveToWaterNpc": 0x80207910,
		"isBehaveToWaterNpc": 0x80207910,
		"TBaseNPC::isMadNpc": 0x80207948,
		"isMadNpc": 0x80207948,
		"TBaseNPC::isBeTrampledNpc": 0x80207a1c,
		"isBeTrampledNpc": 0x80207a1c,
		"TBaseNPC::isPollutionNpc": 0x80207bc4,
		"isPollutionNpc": 0x80207bc4,
		"TBaseNPC::isSmallNpc": 0x80207bfc,
		"isSmallNpc": 0x80207bfc,
		"TBaseNPC::isChild": 0x80207d34,
		"isChild": 0x80207d34,
		"TBaseNPC::isSunflower": 0x80207d6c,
		"isSunflower": 0x80207d6c,
		"TBaseNPC::isJellyFishMare": 0x80207d98,
		"isJellyFishMare": 0x80207d98,
		"TBaseNPC::isSpecialMareW": 0x80207dc8,
		"isSpecialMareW": 0x80207dc8,
		"TBaseNPC::isSpecialMareM": 0x80207df4,
		"isSpecialMareM": 0x80207df4,
		"TBaseNPC::isNormalMareW": 0x80207e20,
		"isNormalMareW": 0x80207e20,
		"TBaseNPC::isNormalMareM": 0x80207e40,
		"isNormalMareM": 0x80207e40,
		"TBaseNPC::isSpecialMonteW": 0x80207e60,
		"isSpecialMonteW": 0x80207e60,
		"TBaseNPC::isSpecialMonteM": 0x80207e80,
		"isSpecialMonteM": 0x80207e80,
		"TBaseNPC::isNormalMonteW": 0x80207eac,
		"isNormalMonteW": 0x80207eac,
		"TBaseNPC::isNormalMonteM": 0x80207ed8,
		"isNormalMonteM": 0x80207ed8,
		"TBaseNPC::loadAfter": 0x80207f04,
		"TBaseNPC::load": 0x80207f8c,
		"TBaseNPC::TBaseNPC": 0x80208068,
		"NPC::__sinit_NpcBase_cpp": 0x8020836c,
		"__sinit_NpcBase_cpp": 0x8020836c,
		"NPC::NPCNeckCallBack": 0x80208670,
		"NPCNeckCallBack": 0x80208670,
		"NPC::CLBEaseOutInbetween": 0x80208a98,
		"NPC::CLBPalIntSpeed": 0x80208b3c,
		"CLBPalIntSpeed": 0x80208b3c,
		"TSunflowerSManager::~TSunflowerSManager": 0x80208b90,
		"TSunflowerSManager::createModelData": 0x80208c04,
		"TSunflowerLManager::createModelData": 0x80208c38,
		"TRaccoonDogManager::createModelData": 0x80208c6c,
		"TPeachManager::createModelData": 0x80208ca0,
		"TKinojiiManager::createModelData": 0x80208cd4,
		"TKinopioManager::createModelData": 0x80208d08,
		"TMareWBaseManager::createModelData": 0x80208d78,
		"TMareMBaseManager::createModelData": 0x80208de4,
		"TMonteWCManager::createModelData": 0x80208e50,
		"TMonteWBManager::createModelData": 0x80208eb8,
		"TMonteWAManager::createModelData": 0x80208f24,
		"TMonteWManager::createModelData": 0x80208fc8,
		"TMonteMHManager::createModelData": 0x8020906c,
		"TMonteMGManager::createModelData": 0x802090d4,
		"TMonteMFManager::createModelData": 0x8020913c,
		"TMonteMEManager::createModelData": 0x802091a4,
		"TMonteMDManager::createModelData": 0x802091d8,
		"TMonteMCManager::createModelData": 0x80209244,
		"TMonteMBManager::createModelData": 0x802092e8,
		"TMonteMAManager::createModelData": 0x80209354,
		"TMonteMManager::createModelData": 0x802093f8,
		"TSunflowerLManager::load": 0x8020949c,
		"TRaccoonDogManager::load": 0x802094d8,
		"TPeachManager::load": 0x8020954c,
		"TKinojiiManager::load": 0x802095c0,
		"TKinopioManager::load": 0x80209634,
		"TMareWBManager::load": 0x802096a8,
		"TMareWAManager::load": 0x8020971c,
		"TMareMDManager::load": 0x80209790,
		"TMareMCManager::load": 0x80209804,
		"TMareMBManager::load": 0x80209878,
		"TMareMAManager::load": 0x802098ec,
		"TMonteWCManager::load": 0x80209960,
		"TMonteMHManager::load": 0x802099d4,
		"TMonteMGManager::load": 0x80209a48,
		"TMonteMFManager::load": 0x80209abc,
		"TMonteWSpecialManager::createAnmData": 0x80209b30,
		"TMonteMSpecialManager::createAnmData": 0x80209b50,
		"TMonteWBaseManager::createAnmData": 0x80209b70,
		"TMonteMBaseManager::createAnmData": 0x80209bcc,
		"TMareBaseManager::getBmt_": 0x80209c28,
		"TMareWBaseManager::TMareWBaseManager": 0x80209ca4,
		"TMareBaseManager::~TMareBaseManager": 0x80209d98,
		"TMareMBaseManager::TMareMBaseManager": 0x80209e0c,
		"TMonteWBaseManager::TMonteWBaseManager": 0x80209f00,
		"TMonteMBaseManager::TMonteMBaseManager": 0x80209fa4,
		"TNPCManager::perform": 0x8020a048,
		"TNPCManager::clipEnemies": 0x8020a1b4,
		"TNPCManager::getPartsSDLModelData": 0x8020a374,
		"getPartsSDLModelData": 0x8020a374,
		"TNPCManager::getBmt_": 0x8020a3e8,
		"TNPCManager::makePartsModelData_": 0x8020a3f0,
		"makePartsModelData_": 0x8020a3f0,
		"TNPCManager::load": 0x8020a540,
		"TNPCManager::TNPCManager": 0x8020a574,
		"TMareJellyFishManager::createModelData": 0x8020a694,
		"TMareJellyFishManager::perform": 0x8020a770,
		"TMareJellyFishManager::TMareJellyFishManager": 0x8020a774,
		"TBoardNpcManager::createModelData": 0x8020a828,
		"TBoardNpcManager::clipActors": 0x8020a85c,
		"TMonteWBManager::~TMonteWBManager": 0x8020a990,
		"TMonteWAManager::~TMonteWAManager": 0x8020aa14,
		"TMonteWManager::~TMonteWManager": 0x8020aa98,
		"TMonteMEManager::~TMonteMEManager": 0x8020ab1c,
		"TMonteMDManager::~TMonteMDManager": 0x8020abb0,
		"TMonteMCManager::~TMonteMCManager": 0x8020ac34,
		"TMonteMBManager::~TMonteMBManager": 0x8020acb8,
		"TMonteMAManager::~TMonteMAManager": 0x8020ad3c,
		"TMonteMManager::~TMonteMManager": 0x8020adc0,
		"TSunflowerLManager::~TSunflowerLManager": 0x8020ae44,
		"TRaccoonDogManager::~TRaccoonDogManager": 0x8020aeb8,
		"TPeachManager::~TPeachManager": 0x8020af2c,
		"TKinojiiManager::~TKinojiiManager": 0x8020afa0,
		"TKinopioManager::~TKinopioManager": 0x8020b014,
		"TMareWBManager::~TMareWBManager": 0x8020b088,
		"TMareWAManager::~TMareWAManager": 0x8020b11c,
		"TMareMDManager::~TMareMDManager": 0x8020b1b0,
		"TMareMCManager::~TMareMCManager": 0x8020b244,
		"TMareMBManager::~TMareMBManager": 0x8020b2d8,
		"TMareMAManager::~TMareMAManager": 0x8020b36c,
		"TMonteWCManager::~TMonteWCManager": 0x8020b400,
		"TMonteMHManager::~TMonteMHManager": 0x8020b494,
		"TMonteMGManager::~TMonteMGManager": 0x8020b528,
		"TMonteMFManager::~TMonteMFManager": 0x8020b5bc,
		"TMareJellyFishManager::~TMareJellyFishManager": 0x8020b840,
		"TBoardNpcManager::~TBoardNpcManager": 0x8020b8c4,
		"TNerveNPCMareStand::~TNerveNPCMareStand": 0x8020b958,
		"TNerveNPCMareStand::execute": 0x8020b9b4,
		"TNerveNPCMareStand::theNerve": 0x8020ba0c,
		"TNerveNPCBlown::execute": 0x8020ba70,
		"TNerveNPCBlown::theNerve": 0x8020bb84,
		"TNerveNPCBlown::~TNerveNPCBlown": 0x8020bbe8,
		"TNerveNPCMad::execute": 0x8020bc44,
		"TNerveNPCMad::theNerve": 0x8020bc9c,
		"TNerveNPCMad::~TNerveNPCMad": 0x8020bd00,
		"TNerveNPCThrow::execute": 0x8020bd5c,
		"TNerveNPCThrow::theNerve": 0x8020bdb4,
		"TNerveNPCThrow::~TNerveNPCThrow": 0x8020be18,
		"TNerveNPCTalk::execute": 0x8020be74,
		"TNerveNPCTalk::theNerve": 0x8020bf24,
		"TNerveNPCTalk::~TNerveNPCTalk": 0x8020bf88,
		"TNerveNPCSetPosAfterSinkBottom::execute": 0x8020bfe4,
		"TNerveNPCSetPosAfterSinkBottom::theNerve": 0x8020c00c,
		"TNerveNPCSetPosAfterSinkBottom::~TNerveNPCSetPosAfterSinkBottom": 0x8020c070,
		"TNerveNPCRecoverAfter::execute": 0x8020c0cc,
		"TNerveNPCRecoverAfter::theNerve": 0x8020c138,
		"TNerveNPCRecoverAfter::~TNerveNPCRecoverAfter": 0x8020c19c,
		"TNerveNPCRecoverFromSink::execute": 0x8020c1f8,
		"TNerveNPCRecoverFromSink::theNerve": 0x8020c2b4,
		"TNerveNPCRecoverFromSink::~TNerveNPCRecoverFromSink": 0x8020c318,
		"TNerveNPCSink::execute": 0x8020c374,
		"TNerveNPCSink::theNerve": 0x8020c39c,
		"TNerveNPCSink::~TNerveNPCSink": 0x8020c400,
		"TNerveNPCWet::execute": 0x8020c45c,
		"TNerveNPCWet::theNerve": 0x8020c4b4,
		"TNerveNPCWet::~TNerveNPCWet": 0x8020c518,
		"TNerveNPCTurnToMario::execute": 0x8020c574,
		"TNerveNPCWaitMarioApproach::~TNerveNPCWaitMarioApproach": 0x8020c8dc,
		"TNerveNPCTurnToMario::theNerve": 0x8020c938,
		"TNerveNPCTurnToMario::~TNerveNPCTurnToMario": 0x8020c99c,
		"TNerveNPCWaitMarioApproach::execute": 0x8020c9f8,
		"TNerveNPCWaitMarioApproach::theNerve": 0x8020cbbc,
		"TNerveNPCWaitContinue::execute": 0x8020cc20,
		"TNerveNPCWaitContinue::theNerve": 0x8020cc68,
		"TNerveNPCWaitContinue::~TNerveNPCWaitContinue": 0x8020cccc,
		"TNerveNPCGraphWait::execute": 0x8020cd28,
		"TNerveNPCGraphWander::~TNerveNPCGraphWander": 0x8020cea8,
		"TNerveNPCGraphWait::theNerve": 0x8020cf04,
		"TNerveNPCGraphWait::~TNerveNPCGraphWait": 0x8020cf68,
		"TNerveNPCUTurn::execute": 0x8020cfc4,
		"TNerveNPCUTurn::theNerve": 0x8020d0a0,
		"TNerveNPCUTurn::~TNerveNPCUTurn": 0x8020d104,
		"TNerveNPCGraphWander::execute": 0x8020d160,
		"TGraphTracer::getCurGraphIndex": 0x8020d514,
		"getCurGraphIndex": 0x8020d514,
		"TNerveNPCGraphWander::theNerve": 0x8020d51c,
		"TNpcParams::TNpcParams": 0x8020d580,
		"TNpcSaveIndividual::TNpcSaveIndividual": 0x8020d6a0,
		"TNpcSaveNormal::TNpcSaveNormal": 0x8020ded4,
		"TNpcSaveStageFarClip::TNpcSaveStageFarClip": 0x8020e4d0,
		"TNpcEvent::reviveOneSunflower": 0x8020e784,
		"reviveOneSunflower": 0x8020e784,
		"NPC::ReviveSunflowerCallBack": 0x8020e8d8,
		"ReviveSunflowerCallBack": 0x8020e8d8,
		"TNpcEvent::initDownSunflowerNum": 0x8020e960,
		"initDownSunflowerNum": 0x8020e960,
		"TNpcEvent::initNpcBuiltin": 0x8020e9a8,
		"initNpcBuiltin": 0x8020e9a8,
		"NPC::evCheckMonteClear": 0x8020eb58,
		"evCheckMonteClear": 0x8020eb58,
		"NPC::evIsDemoMode": 0x8020ed08,
		"evIsDemoMode": 0x8020ed08,
		"NPC::evFireStartDemoCamera": 0x8020edc8,
		"evFireStartDemoCamera": 0x8020edc8,
		"NPC::evSetFruitType": 0x8020ef18,
		"evSetFruitType": 0x8020ef18,
		"NPC::evGetFruitNum": 0x8020f1f8,
		"evGetFruitNum": 0x8020f1f8,
		"NPC::evResetFruitNum": 0x8020f42c,
		"evResetFruitNum": 0x8020f42c,
		"NPC::evNpcDanceOffHappyOn": 0x8020f568,
		"evNpcDanceOffHappyOn": 0x8020f568,
		"NPC::evNpcDanceOn": 0x8020f6b4,
		"evNpcDanceOn": 0x8020f6b4,
		"NPC::evSetNpcTalkForbidCount": 0x8020f7f0,
		"evSetNpcTalkForbidCount": 0x8020f7f0,
		"NPC::evSetNpcBalloonMessage": 0x8020f9dc,
		"evSetNpcBalloonMessage": 0x8020f9dc,
		"NPC::evOnTalkToDummyNpc": 0x8020fc80,
		"evOnTalkToDummyNpc": 0x8020fc80,
		"NPC::evConnectDummyNpc": 0x8020fd78,
		"evConnectDummyNpc": 0x8020fd78,
		"NPC::ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x8020ff38,
		"ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x8020ff38,
		"NPC::ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x8021011c,
		"ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x8021011c,
		"NPC::evIsGameModeNormal": 0x80210330,
		"evIsGameModeNormal": 0x80210330,
		"NPC::evIsNpcSinkBottom": 0x802103d8,
		"evIsNpcSinkBottom": 0x802103d8,
		"NPC::evCheckLatestNerve4Npc": 0x80210548,
		"evCheckLatestNerve4Npc": 0x80210548,
		"NPC::evCheckCurNerve4Npc": 0x8021071c,
		"evCheckCurNerve4Npc": 0x8021071c,
		"NPC::evGetAddressFromViewObjName": 0x802108ec,
		"evGetAddressFromViewObjName": 0x802108ec,
		"NPC::__sinit_NpcEvent_cpp": 0x80210a40,
		"__sinit_NpcEvent_cpp": 0x80210a40,
		"NPC::SMSGetNpcInitData": 0x80210d3c,
		"SMSGetNpcInitData": 0x80210d3c,
		"NPC::__sinit_NpcInitData_cpp": 0x80210d54,
		"__sinit_NpcInitData_cpp": 0x80210d54,
		"TBaseNPC::setIndividualDifference_": 0x80210d70,
		"setIndividualDifference_": 0x80210d70,
		"TBaseNPC::init": 0x80211654,
		"TNpcInbetween::execMotionBlend": 0x80211d68,
		"execMotionBlend": 0x80211d68,
		"TNpcInbetween::execPosInbetween": 0x80211f44,
		"execPosInbetween": 0x80211f44,
		"TNpcParts::partsPerform": 0x80212020,
		"partsPerform": 0x80212020,
		"TNpcParts::partsFrameUpdate": 0x802121d0,
		"partsFrameUpdate": 0x802121d0,
		"TNpcParts::getPartsMActor": 0x80212238,
		"getPartsMActor": 0x80212238,
		"TNpcParts::setPartsAnmFrame": 0x8021225c,
		"setPartsAnmFrame": 0x8021225c,
		"TNpcParts::addJellyFishParts": 0x802123e0,
		"addJellyFishParts": 0x802123e0,
		"TNpcParts::TNpcParts": 0x80212558,
		"NPC::SMS_InitChangeNpcColor": 0x80212988,
		"SMS_InitChangeNpcColor": 0x80212988,
		"TBaseNPC::getBasNameTable": 0x80212bb8,
		"TBaseNPC::kill": 0x80212d40,
		"TBaseNPC::setPosAndInitAfterSinkBottom": 0x80212d44,
		"setPosAndInitAfterSinkBottom": 0x80212d44,
		"TBaseNPC::changeNerveProc_": 0x80213140,
		"changeNerveProc_": 0x80213140,
		"TBaseNPC::isNowCanTaken": 0x802137b0,
		"isNowCanTaken": 0x802137b0,
		"TBaseNPC::isStateGoToMad_": 0x802138e0,
		"isStateGoToMad_": 0x802138e0,
		"TBaseNPC::behaveToSandBomb_": 0x80213954,
		"behaveToSandBomb_": 0x80213954,
		"TBaseNPC::behaveToHitObject_": 0x80213b70,
		"behaveToHitObject_": 0x80213b70,
		"TBaseNPC::behaveToBeTrampled_": 0x80213fe0,
		"behaveToBeTrampled_": 0x80213fe0,
		"TBaseNPC::behaveToBeTaken_": 0x802144e8,
		"behaveToBeTaken_": 0x802144e8,
		"TBaseNPC::releaseTaken_": 0x802145d0,
		"releaseTaken_": 0x802145d0,
		"TBaseNPC::changeNerveToMad_": 0x802146c4,
		"changeNerveToMad_": 0x802146c4,
		"TBaseNPC::changeNerveFromTalk_": 0x80214788,
		"changeNerveFromTalk_": 0x80214788,
		"TBaseNPC::isNerveCanGoToMad": 0x80214970,
		"isNerveCanGoToMad": 0x80214970,
		"TBaseNPC::isNerveCanGoToTalk": 0x80214a14,
		"isNerveCanGoToTalk": 0x80214a14,
		"TBaseNPC::isNerveMaybeDontCalcAnim1": 0x80214b44,
		"isNerveMaybeDontCalcAnim1": 0x80214b44,
		"TBaseNPC::isNerveMaybeDontCalcAnim0": 0x80214bb8,
		"isNerveMaybeDontCalcAnim0": 0x80214bb8,
		"TBaseNPC::isNerveMaybeDontMovement": 0x80214c20,
		"isNerveMaybeDontMovement": 0x80214c20,
		"TBaseNPC::isNerveWalk": 0x80214c94,
		"isNerveWalk": 0x80214c94,
		"NPC::__sinit_NpcChange_cpp": 0x80214d08,
		"__sinit_NpcChange_cpp": 0x80214d08,
		"TNpcThrow::throwMario": 0x80215004,
		"TNpcTrample::updateTrample": 0x80215148,
		"updateTrample": 0x80215148,
		"TNpcTrample::startTrample": 0x8021523c,
		"startTrample": 0x8021523c,
		"TBaseNPC::emitParticle_": 0x8021529c,
		"TBaseNPC::isPolWaitCEffectEmitTime_": 0x802159bc,
		"isPolWaitCEffectEmitTime_": 0x802159bc,
		"TBaseNPC::emitHappyEffect_": 0x80215b0c,
		"emitHappyEffect_": 0x80215b0c,
		"TBaseNPC::emitSinkEffect_": 0x80215c70,
		"emitSinkEffect_": 0x80215c70,
		"TBaseNPC::getEffectScale_": 0x80215cc8,
		"getEffectScale_": 0x80215cc8,
		"NPC::IsCheckPassFrame": 0x80215d1c,
		"IsCheckPassFrame": 0x80215d1c,
		"TBaseNPC::setSmokeEffectMtxPtr_": 0x80215da8,
		"setSmokeEffectMtxPtr_": 0x80215da8,
		"TBaseNPC::setPollutionEffectMtxPtr_": 0x80215e34,
		"setPollutionEffectMtxPtr_": 0x80215e34,
		"TBaseNPC::setNoteEffectMtxPtr_": 0x80215f8c,
		"setNoteEffectMtxPtr_": 0x80215f8c,
		"TBaseNPC::setHappyEffectMtxPtr_": 0x80216034,
		"setHappyEffectMtxPtr_": 0x80216034,
		"NPC::SMSGetNpcInitAnmData": 0x80216138,
		"SMSGetNpcInitAnmData": 0x80216138,
		"TBaseNPC::setKinoActionFlag_": 0x8021614c,
		"setKinoActionFlag_": 0x8021614c,
		"TBaseNPC::setMareActionFlag_": 0x80216180,
		"setMareActionFlag_": 0x80216180,
		"TBaseNPC::setMonteActionFlag_": 0x802161b4,
		"setMonteActionFlag_": 0x802161b4,
		"TNpcCoin::updateCoin": 0x802161e8,
		"updateCoin": 0x802161e8,
		"TNpcCoin::requestAppearCoin": 0x80216384,
		"requestAppearCoin": 0x80216384,
		"TNpcCoin::TNpcCoin": 0x802165f8,
		"NPC::__sinit_NpcCoin_cpp": 0x80216670,
		"__sinit_NpcCoin_cpp": 0x80216670,
		"TNpcBalloon::updateBalloon": 0x8021696c,
		"updateBalloon": 0x8021696c,
		"TNpcBalloon::setNextMessage": 0x802169d8,
		"setNextMessage": 0x802169d8,
		"TBaseNPC::isTurnToMarioWhenApproach": 0x802169e4,
		"isTurnToMarioWhenApproach": 0x802169e4,
		"TBaseNPC::isTurnToMarioWhenTalk": 0x80216a48,
		"isTurnToMarioWhenTalk": 0x80216a48,
		"TBaseNPC::isNeedTurnToFirstState": 0x80216abc,
		"isNeedTurnToFirstState": 0x80216abc,
		"TBaseNPC::execTurnToFirstState": 0x80216ba4,
		"execTurnToFirstState": 0x80216ba4,
		"TBaseNPC::execUTurn": 0x80216c88,
		"execUTurn": 0x80216c88,
		"TBaseNPC::execWalk": 0x80216e68,
		"TBaseNPC::bind": 0x80217258,
		"TBaseNPC::setVariableDamageRadius_": 0x80217470,
		"setVariableDamageRadius_": 0x80217470,
		"TBaseNPC::execNpcObjCollision_": 0x8021754c,
		"execNpcObjCollision_": 0x8021754c,
		"TBaseNPC::initNpcObjCollision_": 0x80217878,
		"initNpcObjCollision_": 0x80217878,
		"MAnmSoundNPC::startAnimSound": 0x800129c4,
		"MAnmSound::setSpeedModifySound": 0x80012d78,
		"MAnmSound::startAnimSound": 0x80012df4,
		"MAnmSound::animeLoop": 0x80012e6c,
		"animeLoop": 0x80012e6c,
		"MAnmSound::initAnmSound": 0x80012eb0,
		"MAnmSound::MAnmSound": 0x80012ed0,
		"MSound::__sinit_MAnmSound_cpp": 0x80012f14,
		"__sinit_MAnmSound_cpp": 0x80012f14,
		"MSound::getMapInfoGround": 0x80013210,
		"MSound::getSwitch": 0x80013218,
		"getSwitch": 0x80013218,
		"MSound::getBstSwitch": 0x80013278,
		"getBstSwitch": 0x80013278,
		"MSound::gateCheck": 0x800132b4,
		"MSound::cameraLooksAtMario": 0x80013304,
		"cameraLooksAtMario": 0x80013304,
		"MSound::startSoundActorSpecial": 0x8001335c,
		"startSoundActorSpecial": 0x8001335c,
		"MSound::startBeeSe": 0x800134cc,
		"startBeeSe": 0x800134cc,
		"MSound::getWallSound": 0x8001367c,
		"getWallSound": 0x8001367c,
		"MSound::checkMarioVoicePlaying": 0x800136dc,
		"checkMarioVoicePlaying": 0x800136dc,
		"MSound::stopMarioVoice": 0x80013700,
		"stopMarioVoice": 0x80013700,
		"MSound::getMarioVoiceID": 0x80013770,
		"getMarioVoiceID": 0x80013770,
		"MSound::startMarioVoice": 0x800137a8,
		"startMarioVoice": 0x800137a8,
		"MSound::playTimer": 0x80013e90,
		"playTimer": 0x80013e90,
		"MSound::setSeExtParameter": 0x80013f7c,
		"MSoundSESystem::MSRandVol::getRandomVolumeNormal": 0x80014064,
		"getRandomVolumeNormal": 0x80014064,
		"MSound::stopAllSound": 0x800140b8,
		"stopAllSound": 0x800140b8,
		"MSound::fadeOutAllSound": 0x80014148,
		"fadeOutAllSound": 0x80014148,
		"MSound::resetAudioAll": 0x80014258,
		"resetAudioAll": 0x80014258,
		"MSound::setCategoryVOLs": 0x8001432c,
		"setCategoryVOLs": 0x8001432c,
		"MSound::talkModeOut": 0x800143e8,
		"talkModeOut": 0x800143e8,
		"MSound::talkModeIn": 0x80014530,
		"talkModeIn": 0x80014530,
		"MSound::demoModeOut": 0x8001462c,
		"demoModeOut": 0x8001462c,
		"MSound::demoModeIn": 0x80014744,
		"demoModeIn": 0x80014744,
		"MSound::pauseOff": 0x80014818,
		"pauseOff": 0x80014818,
		"MSound::pauseOn": 0x80014a38,
		"pauseOn": 0x80014a38,
		"MSound::initSound": 0x80014b7c,
		"initSound": 0x80014b7c,
		"MSound::startSoundSetGrp": 0x80014c90,
		"MSound::startSoundSet": 0x80014d1c,
		"MSound::mainLoop": 0x80014da8,
		"mainLoop": 0x80014da8,
		"MSound::MSound": 0x80014e70,
		"JAICamera::JAICamera": 0x800151b4,
		"MSound::getDistFromCamera": 0x80015250,
		"getDistFromCamera": 0x80015250,
		"MSound::setPlayerInfo": 0x8001527c,
		"setPlayerInfo": 0x8001527c,
		"MSound::setCameraInfo": 0x80015378,
		"MSound::checkWaveOnAram": 0x800153cc,
		"checkWaveOnAram": 0x800153cc,
		"MSound::exitStage": 0x80015500,
		"exitStage": 0x80015500,
		"MSound::enterStage": 0x80015640,
		"enterStage": 0x80015640,
		"MSound::loadWave": 0x8001569c,
		"MSound::loadGroupWave": 0x800156ec,
		"MSound::setRegisterTrackCallback": 0x800157b0,
		"MSound::makeSound": 0x800157d8,
		"MSHandle::MSHandle": 0x8001586c,
		"MSSeCallBack::setParameterSeqSync": 0x800158a8,
		"MSSeCallBack::setWaterCameraFir": 0x80015db4,
		"setWaterCameraFir": 0x80015db4,
		"MSound::__sinit_MSound_cpp": 0x8001624c,
		"__sinit_MSound_cpp": 0x8001624c,
		"MSBgm::setStageBgmYoshiPercussion": 0x80016548,
		"setStageBgmYoshiPercussion": 0x80016548,
		"MSBgm::setDolby": 0x800165fc,
		"MSBgm::setPan": 0x80016644,
		"MSBgm::setVolume": 0x8001668c,
		"MSBgm::setTrackVolume": 0x800166f8,
		"setTrackVolume": 0x800166f8,
		"MSBgm::stopTrackBGMs": 0x80016740,
		"stopTrackBGMs": 0x80016740,
		"MSBgm::stopTrackBGM": 0x800167ec,
		"stopTrackBGM": 0x800167ec,
		"MSBgm::stopBGM": 0x8001686c,
		"stopBGM": 0x8001686c,
		"MSBgm::getHandle": 0x8001694c,
		"getHandle": 0x8001694c,
		"MSBgm::startBGM": 0x80016978,
		"startBGM": 0x80016978,
		"MSBgm::getSceneNo": 0x80016ac0,
		"getSceneNo": 0x80016ac0,
		"MSBgm::init": 0x80016c60,
		"JALList<MSBgm>::JALList": 0x80016ce8,
		"JALList": 0x80016ce8,
		"JALListS<MSBgm,unsigned_long><MSBgm,unsigned_long>::search": 0x80016d44,
		"MSound::__sinit_MSoundBGM_cpp": 0x80016d78,
		"__sinit_MSoundBGM_cpp": 0x80016d78,
		"JADPrm<unsigned_char><unsigned_char>::JADPrm": 0x80017074,
		"MSound::__sinit_MSoundDebug_cpp": 0x8001707c,
		"__sinit_MSoundDebug_cpp": 0x8001707c,
		"MSSceneSE::sortMaxTrans": 0x80017378,
		"sortMaxTrans": 0x80017378,
		"MSSceneSE::frameLoop": 0x8001754c,
		"frameLoop": 0x8001754c,
		"MSSceneSE::MSSceneSE": 0x80017964,
		"MSound::__sinit_MSoundScene_cpp": 0x80017ae0,
		"__sinit_MSoundScene_cpp": 0x80017ae0,
		"MSoundSESystem::MSoundSE::checkMonoSound": 0x80017ddc,
		"checkMonoSound": 0x80017ddc,
		"MSoundSESystem::MSoundSE::startSoundNpcActor": 0x80017eb0,
		"startSoundNpcActor": 0x80017eb0,
		"MSoundSESystem::MSoundSE::getNewIDBySurfaceCode": 0x80017fc0,
		"getNewIDBySurfaceCode": 0x80017fc0,
		"MSoundSESystem::MSoundSE::startSoundActorInner": 0x800180d8,
		"startSoundActorInner": 0x800180d8,
		"MSoundSESystem::MSoundSE::checkSoundArea": 0x80018498,
		"checkSoundArea": 0x80018498,
		"MSoundSESystem::MSoundSE::startSoundActorWithInfo": 0x800185f4,
		"startSoundActorWithInfo": 0x800185f4,
		"MSoundSESystem::MSoundSE::startSoundSystemSE": 0x80018864,
		"MSoundSESystem::MSoundSE::startSoundActor": 0x800189d4,
		"MSoundSESystem::MSoundSE::getRandomID": 0x80018a14,
		"getRandomID": 0x80018a14,
		"MSoundSESystem::MSoundSE::construct": 0x80018c80,
		"construct": 0x80018c80,
		"MSoundSESystem::MSRandPlay::randPlay": 0x80019f8c,
		"randPlay": 0x80019f8c,
		"MSoundSESystem::MSRandPlay::MSRandPlay": 0x8001a150,
		"MSoundSESystem::MSRandPlay::startSeRandPlay": 0x8001a1f0,
		"startSeRandPlay": 0x8001a1f0,
		"MSoundSESystem::MSRandPlayVec::~MSRandPlayVec": 0x8001a250,
		"MSoundSESystem::MSRandPlayVec::MSRandPlayVec": 0x8001a2b0,
		"MSoundSESystem::MSRandPlay::createRandPlayVec": 0x8001a308,
		"createRandPlayVec": 0x8001a308,
		"MSoundSESystem::MSRandPlay::registerTrans": 0x8001a3ac,
		"registerTrans": 0x8001a3ac,
		"MSoundSESystem::MSRandVol::getRandVol": 0x8001a400,
		"getRandVol": 0x8001a400,
		"MSoundSESystem::MSRandVol::MSRandVol": 0x8001a47c,
		"MSound::__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x8001a524,
		"__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x8001a524,
		"MSSetSoundTL<MSSetSoundGrp>::MSSetSoundTL": 0x8001a594,
		"JALListFrameLoop<MSSetSoundGrp>::frameLoopDyna": 0x8001a7ec,
		"MSound::__ct__9JADPrm<l>FlPCc": 0x8001a7f0,
		"__ct__9JADPrm<l>FlPCc": 0x8001a7f0,
		"MSound::__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x8001a800,
		"__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x8001a800,
		"MSound::__sinit_MSoundSE_cpp": 0x8001a854,
		"__sinit_MSoundSE_cpp": 0x8001a854,
		"JSUList<MSoundSESystem::MSRandPlay>::~JSUList": 0x8001abac,
		"JSUList<MSoundSESystem::MSRandVol>::~JSUList": 0x8001ac04,
		"MSSetSoundGrp::startSoundSetGrp": 0x8001ac64,
		"MSSetSound::startSoundSet": 0x8001ad04,
		"MSSetSound::init": 0x8001ae68,
		"JALListGrp<MSSetSoundGrp,unsigned_long,MSSetSoundMember><MSSetSoundGrp,unsigned_long,MSSetSoundMember>::searchGroup": 0x8001b3f8,
		"MSSetSoundTL<MSSetSound>::startSoundSetDyna": 0x8001b454,
		"JALListD<MSSetSoundMember,unsigned_long><MSSetSoundMember,unsigned_long>::searchD": 0x8001bba0,
		"searchD": 0x8001bba0,
		"MSSetSoundTL<MSSetSound>::MSSetSoundTL": 0x8001bbcc,
		"MSSetSoundTL<MSSetSoundGrp>::startSoundSetDyna": 0x8001be24,
		"JALListFrameLoop<MSSetSound>::frameLoopDyna": 0x8001c570,
		"MSound::__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x8001c574,
		"__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x8001c574,
		"MSound::__sinit_MSoundStruct_cpp": 0x8001c5c8,
		"__sinit_MSoundStruct_cpp": 0x8001c5c8,
		"MSHandle::calcVolume": 0x8001c8cc,
		"calcVolume": 0x8001c8cc,
		"MSHandle::setDistanceVolumeCommon": 0x8001c9ac,
		"MSHandle::setSeDistanceVolume": 0x8001ca50,
		"MSHandle::calcDolby": 0x8001cb48,
		"calcDolby": 0x8001cb48,
		"MSHandle::setSeDistanceDolby": 0x8001cc38,
		"MSHandle::calcPan": 0x8001cc8c,
		"MSHandle::setSeDistancePan": 0x8001cdac,
		"MSHandle::setSeDistancePitch": 0x8001ce4c,
		"MSHandle::setSeDistanceParameters": 0x8001cf60,
		"MSHandle::MSACos": 0x8001d0b0,
		"MSACos": 0x8001d0b0,
		"MSound::__sinit_MSHandle_cpp": 0x8001d10c,
		"__sinit_MSHandle_cpp": 0x8001d10c,
		"MSBgmXFade::xFadeBgmForce": 0x8001d408,
		"xFadeBgmForce": 0x8001d408,
		"MSBgmXFade::xFadeBgm": 0x8001d4e4,
		"xFadeBgm": 0x8001d4e4,
		"MSModBgm::changeTempo": 0x8001d5f4,
		"changeTempo": 0x8001d5f4,
		"MSModBgm::loop": 0x8001d67c,
		"loop": 0x8001d67c,
		"MSModBgm::modBgm": 0x8001d6b8,
		"modBgm": 0x8001d6b8,
		"MSound::__sinit_MSModBgm_cpp": 0x8001d7b4,
		"__sinit_MSModBgm_cpp": 0x8001d7b4,
		"TWoodBarrel::getFlushTime": 0x801aebdc,
		"TMapObjGeneral::getLivingTime": 0x801aebe4,
		"TMapObjGeneral::checkIllegalAttr": 0x801aebec,
		"TWoodBarrel::TWoodBarrel": 0x801aebf0,
		"TWoodBarrel::load": 0x801aecc0,
		"TWoodBarrel::loadAfter": 0x801aed18,
		"TWoodBarrel::control": 0x801aed80,
		"TWoodBarrel::receiveMessage": 0x801aee24,
		"TWoodBarrel::touchActor": 0x801aee64,
		"TWoodBarrel::touchPlayer": 0x801aef30,
		"TWoodBarrel::touchGround": 0x801aef7c,
		"TWoodBarrel::touchWall": 0x801af000,
		"TWoodBarrel::appear": 0x801af02c,
		"TWoodBarrel::appeared": 0x801af0ac,
		"TWoodBarrel::kill": 0x801af160,
		"TWoodBarrel::breaking": 0x801af208,
		"TWoodBarrel::hold": 0x801af288,
		"TWoodBarrel::put": 0x801af2e0,
		"MoveBG::__sinit_WoodBarrel_cpp": 0x801af3a4,
		"__sinit_WoodBarrel_cpp": 0x801af3a4,
		"TMapObjBase::TMapObjBase": 0x801af6a8,
		"TMapObjBase::load": 0x801af750,
		"TMapObjBase::loadAfter": 0x801af834,
		"TMapObjBase::initAndRegister": 0x801af874,
		"initAndRegister": 0x801af874,
		"TMapObjBase::receiveMessage": 0x801af944,
		"TMapObjBase::calcRootMatrix": 0x801af9a0,
		"TMapObjBase::getRootJointMtx": 0x801afa4c,
		"TMapObjBase::getShadowType": 0x801afa80,
		"TMapObjBase::perform": 0x801afb48,
		"TMapObjBase::setGroundCollision": 0x801aff74,
		"TMapObjBase::control": 0x801b00f8,
		"TMapObjBase::ensureTakeSituation": 0x801b0270,
		"TMapObjBase::touchActor": 0x801b02d0,
		"TMapObjBase::touchPlayer": 0x801b037c,
		"TMapObjBase::touchEnemy": 0x801b03b8,
		"TMapObjBase::touchBoss": 0x801b03f4,
		"touchBoss": 0x801b03f4,
		"TMapObjBase::makeObjAppeared": 0x801b0430,
		"TMapObjBase::makeObjDead": 0x801b0738,
		"TMapObjBase::makeObjDefault": 0x801b08f4,
		"TMapObjBase::startAnim": 0x801b09d4,
		"startAnim": 0x801b09d4,
		"TMapObjBase::startBck": 0x801b0bc8,
		"startBck": 0x801b0bc8,
		"TMapObjBase::startControlAnim": 0x801b0bf8,
		"startControlAnim": 0x801b0bf8,
		"TMapObjBase::animIsFinished": 0x801b0c74,
		"animIsFinished": 0x801b0c74,
		"TMapObjBase::hasAnim": 0x801b0cf4,
		"hasAnim": 0x801b0cf4,
		"TMapObjBase::hasModelOrAnimData": 0x801b0d3c,
		"hasModelOrAnimData": 0x801b0d3c,
		"TMapObjBase::startSound": 0x801b0d90,
		"startSound": 0x801b0d90,
		"TMapObjBase::soundBas": 0x801b0e88,
		"soundBas": 0x801b0e88,
		"TMapObjBase::setUpMapCollision": 0x801b0f2c,
		"setUpMapCollision": 0x801b0f2c,
		"TMapObjBase::setUpCurrentMapCollision": 0x801b1058,
		"setUpCurrentMapCollision": 0x801b1058,
		"TMapObjBase::removeMapCollision": 0x801b1130,
		"removeMapCollision": 0x801b1130,
		"TMapObjBase::setObjHitData": 0x801b118c,
		"setObjHitData": 0x801b118c,
		"TMapObjBase::sleep": 0x801b1238,
		"TMapObjBase::awake": 0x801b12ac,
		"TMapObjBase::getSDLModelFlag": 0x801b12f0,
		"TMapObjBase::changeObjSRT": 0x801b12f8,
		"changeObjSRT": 0x801b12f8,
		"TMapObjBase::changeObjMtx": 0x801b1368,
		"changeObjMtx": 0x801b1368,
		"MoveBG::__sinit_MapObjBase_cpp": 0x801b1460,
		"__sinit_MapObjBase_cpp": 0x801b1460,
		"TMapObjGeneral::getFlushTime": 0x801b1764,
		"TMapObjManager::initKeyCode": 0x801b176c,
		"initKeyCode": 0x801b176c,
		"TMapObjGeneral::initMapObj": 0x801b17dc,
		"TMapObjBase::initMapObj": 0x801b1824,
		"TMapObjBase::initActorData": 0x801b1ad0,
		"initActorData": 0x801b1ad0,
		"TMapObjBase::initModelData": 0x801b1c34,
		"initModelData": 0x801b1c34,
		"TMapObjBase::makeMActors": 0x801b1d64,
		"TMapObjBase::initMActor": 0x801b2070,
		"initMActor": 0x801b2070,
		"TMapObjBase::initBckMoveData": 0x801b211c,
		"initBckMoveData": 0x801b211c,
		"TMapObjBase::initObjCollisionData": 0x801b2204,
		"initObjCollisionData": 0x801b2204,
		"TMapObjBase::initMapCollisionData": 0x801b238c,
		"TMapObjBase::checkIllegalAttr": 0x801b2448,
		"TMapObjBase::initUnique": 0x801b244c,
		"MoveBG::__sinit_MapObjInit_cpp": 0x801b2c90,
		"__sinit_MapObjInit_cpp": 0x801b2c90,
		"TMapObjGeneral::TMapObjGeneral": 0x801b2f94,
		"TMapObjGeneral::loadAfter": 0x801b2ff0,
		"TMapObjGeneral::receiveMessage": 0x801b305c,
		"TMapObjGeneral::perform": 0x801b3364,
		"TMapObjGeneral::calcRootMatrix": 0x801b345c,
		"TMapObjGeneral::control": 0x801b35f8,
		"TMapObjGeneral::bind": 0x801b36b8,
		"TMapObjGeneral::calcVelocity": 0x801b3938,
		"TMapObjGeneral::checkGroundCollision": 0x801b3adc,
		"TMapObjGeneral::touchGround": 0x801b3b8c,
		"TMapObjGeneral::checkRoofCollision": 0x801b3d64,
		"checkRoofCollision": 0x801b3d64,
		"TMapObjGeneral::touchRoof": 0x801b3df0,
		"TMapObjGeneral::checkWallCollision": 0x801b3dfc,
		"TMapObjGeneral::touchWall": 0x801b3ee4,
		"TMapObjGeneral::work": 0x801b3f2c,
		"work": 0x801b3f2c,
		"TMapObjGeneral::appear": 0x801b401c,
		"TMapObjGeneral::kill": 0x801b4114,
		"TMapObjGeneral::ensureTakeSituation": 0x801b4194,
		"TMapObjGeneral::hold": 0x801b4200,
		"TMapObjGeneral::recover": 0x801b4274,
		"recover": 0x801b4274,
		"TMapObjGeneral::touchPlayer": 0x801b437c,
		"TMapObjGeneral::touchWater": 0x801b43d0,
		"TMapObjGeneral::receiveMessageFromPlayer": 0x801b444c,
		"receiveMessageFromPlayer": 0x801b444c,
		"TMapObjGeneral::makeObjBuried": 0x801b4470,
		"makeObjBuried": 0x801b4470,
		"TMapObjGeneral::makeObjRecovered": 0x801b44dc,
		"makeObjRecovered": 0x801b44dc,
		"TMapObjGeneral::appeared": 0x801b4528,
		"TMapObjGeneral::appearing": 0x801b4580,
		"TMapObjGeneral::breaking": 0x801b4644,
		"TMapObjGeneral::sinking": 0x801b46c4,
		"sinking": 0x801b46c4,
		"TMapObjGeneral::recovering": 0x801b47e4,
		"recovering": 0x801b47e4,
		"TMapObjGeneral::holding": 0x801b48f8,
		"holding": 0x801b48f8,
		"TMapObjGeneral::touchingPlayer": 0x801b4950,
		"touchingPlayer": 0x801b4950,
		"TMapObjGeneral::touchingWater": 0x801b49a4,
		"touchingWater": 0x801b49a4,
		"TMapObjGeneral::thrown": 0x801b49f8,
		"TMapObjGeneral::put": 0x801b4bdc,
		"TMapObjGeneral::sink": 0x801b4cec,
		"sink": 0x801b4cec,
		"TMapObjGeneral::waitToAppear": 0x801b4d54,
		"waitToAppear": 0x801b4d54,
		"TMapObjGeneral::waitingToRecover": 0x801b4d78,
		"waitingToRecover": 0x801b4d78,
		"TMapObjGeneral::waitingToAppear": 0x801b4dd0,
		"TMapObjGeneral::isPollutedGround": 0x801b4f30,
		"isPollutedGround": 0x801b4f30,
		"MoveBG::__sinit_MapObjGeneral_cpp": 0x801b5024,
		"__sinit_MapObjGeneral_cpp": 0x801b5024,
		"TMapObjBaseManager::~TMapObjBaseManager": 0x801b5320,
		"TMapObjBaseManager::TMapObjBaseManager": 0x801b53b4,
		"TMapObjBaseManager::load": 0x801b53fc,
		"TMapObjBaseManager::getObjNumWithActorType": 0x801b5454,
		"getObjNumWithActorType": 0x801b5454,
		"TMapObjBaseManager::createModelData": 0x801b54a8,
		"TMapObjBaseManager::clipActors": 0x801b54dc,
		"TMapObjBaseManager::getActorTypeByEventID": 0x801b5510,
		"getActorTypeByEventID": 0x801b5510,
		"TMapObjBaseManager::newAndRegisterObjByEventID": 0x801b5610,
		"newAndRegisterObjByEventID": 0x801b5610,
		"TMapObjBaseManager::newAndRegisterObj": 0x801b5c84,
		"newAndRegisterObj": 0x801b5c84,
		"MoveBG::newUniqueObjByName": 0x801b5db0,
		"newUniqueObjByName": 0x801b5db0,
		"MoveBG::newItemByName": 0x801b6cc0,
		"newItemByName": 0x801b6cc0,
		"TMapObjBaseManager::makeObjAppeared": 0x801b6d54,
		"TMapObjManager::TMapObjManager": 0x801b709c,
		"TMapObjManager::load": 0x801b71cc,
		"TMapObjManager::loadAfter": 0x801b768c,
		"TMapObjManager::entryStaticDrawBufferSun": 0x801b7868,
		"entryStaticDrawBufferSun": 0x801b7868,
		"TMapObjManager::entryStaticDrawBufferShadow": 0x801b78b8,
		"entryStaticDrawBufferShadow": 0x801b78b8,
		"TMerryPole::getRootJointMtx": 0x801b798c,
		"TMapObjManager::~TMapObjManager": 0x801b7994,
		"TMapObjManager::hasMapCollision": 0x801b7a28,
		"MoveBG::__sinit_MapObjManager_cpp": 0x801b7a30,
		"__sinit_MapObjManager_cpp": 0x801b7a30,
		"TMapObjTurn::TMapObjTurn": 0x801b7dd0,
		"TMapObjTurn::initMapObj": 0x801b7ebc,
		"TMapObjTurn::loadAfter": 0x801b7f2c,
		"TMapObjTurn::receiveMessage": 0x801b7f6c,
		"TMapObjTurn::control": 0x801b8008,
		"TMapObjTurn::turn": 0x801b8590,
		"turn": 0x801b8590,
		"TMapObjTurn::touchWater": 0x801b8684,
		"TMapObjMessenger::TMapObjMessenger": 0x801b8818,
		"TMapObjMessenger::receiveMessage": 0x801b8864,
		"TMapObjLibWave::TMapObjLibWave": 0x801b8894,
		"TMapObjLibWave::movement": 0x801b893c,
		"TMapObjLibWave::getCurrentHeight": 0x801b8994,
		"getCurrentHeight": 0x801b8994,
		"TMapObjLibWave::push": 0x801b89cc,
		"TMapObjBase::emitAndBindScale": 0x801b8a70,
		"emitAndBindScale": 0x801b8a70,
		"TMapObjBase::emitAndRotateScale": 0x801b8b64,
		"emitAndRotateScale": 0x801b8b64,
		"TMapObjBase::emitAndSRT": 0x801b8c54,
		"emitAndSRT": 0x801b8c54,
		"TMapObjBase::emitColumnWater": 0x801b8d34,
		"emitColumnWater": 0x801b8d34,
		"TMapObjBase::marioHipAttack": 0x801b8d88,
		"marioHipAttack": 0x801b8d88,
		"TMapObjBase::marioHeadAttack": 0x801b8df8,
		"marioHeadAttack": 0x801b8df8,
		"TMapObjBase::sendMsg": 0x801b8efc,
		"sendMsg": 0x801b8efc,
		"TMapObjBase::waterHitPlane": 0x801b8f8c,
		"waterHitPlane": 0x801b8f8c,
		"TMapObjBase::getWaterPos": 0x801b9018,
		"getWaterPos": 0x801b9018,
		"TMapObjBase::getWaterSpeed": 0x801b9030,
		"getWaterSpeed": 0x801b9030,
		"TMapObjBase::getWaterPlane": 0x801b9048,
		"getWaterPlane": 0x801b9048,
		"TMapObjBase::getWaterID": 0x801b9060,
		"getWaterID": 0x801b9060,
		"TMapObjBase::getDistance": 0x801b9068,
		"getDistance": 0x801b9068,
		"TMapObjBase::getDistanceXZ": 0x801b90e4,
		"getDistanceXZ": 0x801b90e4,
		"TMapObjBase::getRotYFromAxisZ": 0x801b9148,
		"getRotYFromAxisZ": 0x801b9148,
		"TMapObjBase::getRotYFromAxisX": 0x801b9184,
		"getRotYFromAxisX": 0x801b9184,
		"TMapObjBase::makeVecToLocalZ": 0x801b91c0,
		"makeVecToLocalZ": 0x801b91c0,
		"TMapObjBase::getNormalVecFromTarget": 0x801b922c,
		"getNormalVecFromTarget": 0x801b922c,
		"TMapObjBase::getNormalVecFromTargetXZ": 0x801b9270,
		"getNormalVecFromTargetXZ": 0x801b9270,
		"TMapObjBase::rotateVecByAxisY": 0x801b92b4,
		"rotateVecByAxisY": 0x801b92b4,
		"TMapObjBase::getVerticalVecToTargetXZ": 0x801b94d0,
		"getVerticalVecToTargetXZ": 0x801b94d0,
		"JGeometry::SMatrix33C<float><float>::at": 0x801b963c,
		"at": 0x801b963c,
		"JGeometry::SMatrix33C<float><float>::SMatrix33C": 0x801b9650,
		"SMatrix33C": 0x801b9650,
		"TMapObjBase::calcReflectingVelocity": 0x801b9654,
		"calcReflectingVelocity": 0x801b9654,
		"TMapObjBase::makeObjMtxRotByAxis": 0x801b96c0,
		"makeObjMtxRotByAxis": 0x801b96c0,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setRotate": 0x801b9854,
		"TMapObjBase::makeMtxRotByAxis": 0x801b99a8,
		"makeMtxRotByAxis": 0x801b99a8,
		"TMapObjBase::concatOnlyRotFromRight": 0x801b9b4c,
		"concatOnlyRotFromRight": 0x801b9b4c,
		"TMapObjBase::concatOnlyRotFromLeft": 0x801b9bb8,
		"concatOnlyRotFromLeft": 0x801b9bb8,
		"TMapObjBase::updateObjMtx": 0x801b9c24,
		"updateObjMtx": 0x801b9c24,
		"TMapObjBase::updateRootMtxTrans": 0x801b9cdc,
		"updateRootMtxTrans": 0x801b9cdc,
		"TMapObjBase::makeRootMtxRotX": 0x801b9d2c,
		"makeRootMtxRotX": 0x801b9d2c,
		"TMapObjBase::setRootMtxRotY": 0x801b9ddc,
		"setRootMtxRotY": 0x801b9ddc,
		"TMapObjBase::makeRootMtxRotY": 0x801b9e90,
		"makeRootMtxRotY": 0x801b9e90,
		"TMapObjBase::setRootMtxRotZ": 0x801b9f40,
		"setRootMtxRotZ": 0x801b9f40,
		"TMapObjBase::makeRootMtxRotZ": 0x801b9ff4,
		"makeRootMtxRotZ": 0x801b9ff4,
		"TMapObjBase::makeLowerStr": 0x801ba0a4,
		"makeLowerStr": 0x801ba0a4,
		"TMapObjBase::moveJoint": 0x801ba0f8,
		"moveJoint": 0x801ba0f8,
		"TMapObjBase::getJointTransX": 0x801ba168,
		"getJointTransX": 0x801ba168,
		"TMapObjBase::getJointTransZ": 0x801ba170,
		"getJointTransZ": 0x801ba170,
		"TMapObjBase::setJointTransX": 0x801ba178,
		"setJointTransX": 0x801ba178,
		"TMapObjBase::setJointTransY": 0x801ba1c8,
		"setJointTransY": 0x801ba1c8,
		"TMapObjBase::setJointTransZ": 0x801ba218,
		"setJointTransZ": 0x801ba218,
		"TMapObjBase::getJointScaleY": 0x801ba268,
		"getJointScaleY": 0x801ba268,
		"TMapObjBase::setJointScaleY": 0x801ba270,
		"setJointScaleY": 0x801ba270,
		"TMapObjBase::calcMap": 0x801ba2c0,
		"calcMap": 0x801ba2c0,
		"TMapObjBase::getBuildingJointObj": 0x801ba300,
		"getBuildingJointObj": 0x801ba300,
		"TMapObjBase::getBuildingJoint": 0x801ba328,
		"getBuildingJoint": 0x801ba328,
		"TMapObjBase::newAndInitBuildingCollisionMove": 0x801ba354,
		"newAndInitBuildingCollisionMove": 0x801ba354,
		"TMapObjBase::newAndInitBuildingCollisionWarp": 0x801ba3e8,
		"newAndInitBuildingCollisionWarp": 0x801ba3e8,
		"TMapObjBase::joinToGroup": 0x801ba47c,
		"joinToGroup": 0x801ba47c,
		"TMapObjBase::startAllAnim": 0x801ba520,
		"startAllAnim": 0x801ba520,
		"TMapObjBase::initPacketMatColor": 0x801ba650,
		"initPacketMatColor": 0x801ba650,
		"TMapObjBase::isFruit": 0x801ba6cc,
		"isFruit": 0x801ba6cc,
		"TMapObjBase::isCoin": 0x801ba7a0,
		"isCoin": 0x801ba7a0,
		"TMapObjBase::throwObjFromPointWithRot": 0x801ba814,
		"throwObjFromPointWithRot": 0x801ba814,
		"TMapObjBase::throwObjToFrontFromPoint": 0x801ba8d8,
		"throwObjToFrontFromPoint": 0x801ba8d8,
		"TMapObjBase::throwObjToFront": 0x801ba9ec,
		"throwObjToFront": 0x801ba9ec,
		"TMapObjBase::checkOnManhole": 0x801bab04,
		"checkOnManhole": 0x801bab04,
		"TMapObjBase::loadHideObjInfo": 0x801bab8c,
		"loadHideObjInfo": 0x801bab8c,
		"TMapObjBase::isDemo": 0x801bac68,
		"isDemo": 0x801bac68,
		"TMapObjBase::isHideObj": 0x801bacc0,
		"isHideObj": 0x801bacc0,
		"MoveBG::__sinit_MapObjLib_cpp": 0x801bae58,
		"__sinit_MapObjLib_cpp": 0x801bae58,
		"TNozzleBox::TNozzleBox": 0x801bb200,
		"TNozzleBox::load": 0x801bb284,
		"TNozzleBox::loadAfter": 0x801bb49c,
		"TNozzleBox::control": 0x801bb674,
		"TNozzleBox::touchPlayer": 0x801bb6cc,
		"TNozzleBox::receiveMessage": 0x801bb794,
		"TNozzleBox::breaking": 0x801bb904,
		"TNozzleBox::makeModelValid": 0x801bb94c,
		"makeModelValid": 0x801bb94c,
		"TItemNozzle::load": 0x801bb9dc,
		"TItemNozzle::initMapObj": 0x801bbaa0,
		"TItemNozzle::control": 0x801bbbec,
		"TItemNozzle::appearing": 0x801bbc0c,
		"TItemNozzle::receiveMessage": 0x801bbc30,
		"TItemNozzle::put": 0x801bbcf4,
		"TItemNozzle::touchPlayer": 0x801bbd0c,
		"TEggYoshi::TEggYoshi": 0x801bbe9c,
		"TEggYoshi::load": 0x801bbef0,
		"TEggYoshi::receiveMessage": 0x801bc12c,
		"TEggYoshi::startFruit": 0x801bc398,
		"startFruit": 0x801bc398,
		"TEggYoshi::perform": 0x801bc468,
		"TEggYoshi::control": 0x801bc5a8,
		"TEggYoshi::touchActor": 0x801bc7c4,
		"TEggYoshi::touchFruit": 0x801bc898,
		"TEggYoshi::decideRandomLoveFruit": 0x801bca1c,
		"decideRandomLoveFruit": 0x801bca1c,
		"TShine::TShine": 0x801bcb54,
		"TShine::loadBeforeInit": 0x801bcc18,
		"TShine::loadAfter": 0x801bcd08,
		"TShine::initMapObj": 0x801bcd70,
		"TShine::makeMActors": 0x801bcdd4,
		"TShine::kill": 0x801bced0,
		"TShine::appearWithDemo": 0x801bcf04,
		"appearWithDemo": 0x801bcf04,
		"TShine::appearSimple": 0x801bcfb0,
		"appearSimple": 0x801bcfb0,
		"TShine::appearWithTimeCallback": 0x801bd0b8,
		"appearWithTimeCallback": 0x801bd0b8,
		"TShine::appearWithTime": 0x801bd120,
		"appearWithTime": 0x801bd120,
		"TShine::touchPlayer": 0x801bd334,
		"TShine::receiveMessage": 0x801bd3dc,
		"TShine::perform": 0x801bd590,
		"TShine::control": 0x801bd5f0,
		"TShine::movingCircle": 0x801bdc38,
		"movingCircle": 0x801bdc38,
		"TShine::calc": 0x801bdda8,
		"TCoinBlue::TCoinBlue": 0x801be088,
		"TCoinBlue::load": 0x801be1a4,
		"TCoinBlue::loadBeforeInit": 0x801be210,
		"TCoinBlue::taken": 0x801be264,
		"TCoinBlue::makeObjAppeared": 0x801be330,
		"TCoinRed::TCoinRed": 0x801be398,
		"TCoinRed::taken": 0x801be428,
		"TCoinEmpty::TCoinEmpty": 0x801be528,
		"TCoinEmpty::kill": 0x801be5a8,
		"TCoinEmpty::makeObjAppeared": 0x801be5ac,
		"TCoinEmpty::appear": 0x801be5b0,
		"TFlowerCoin::load": 0x801be5b4,
		"TCoin::TCoin": 0x801be608,
		"TCoin::initMapObj": 0x801be674,
		"TCoin::loadAfter": 0x801be6e4,
		"TCoin::perform": 0x801be7cc,
		"TCoin::makeObjAppeared": 0x801bea2c,
		"TCoin::appear": 0x801bea70,
		"TCoin::appearWithoutSound": 0x801beba8,
		"appearWithoutSound": 0x801beba8,
		"TCoin::makeObjDead": 0x801bec44,
		"TCoin::taken": 0x801bec88,
		"TItem::TItem": 0x801bee14,
		"TItem::load": 0x801bee68,
		"TItem::initMapObj": 0x801beea0,
		"TItem::perform": 0x801beedc,
		"TItem::appear": 0x801bef68,
		"TItem::killByTimer": 0x801befb4,
		"TItem::appearing": 0x801befe8,
		"TItem::calc": 0x801bf0cc,
		"TItem::calcRootMatrix": 0x801bf244,
		"TItem::receiveMessage": 0x801bf270,
		"TItem::touchPlayer": 0x801bf2c0,
		"TItem::taken": 0x801bf33c,
		"TItem::appeared": 0x801bf3c8,
		"TEggYoshi::getHitObjNumMax": 0x801bf5f4,
		"MoveBG::__sinit_Item_cpp": 0x801bf908,
		"__sinit_Item_cpp": 0x801bf908,
		"TItemManager::~TItemManager": 0x801bfc54,
		"TItemManager::hasMapCollision": 0x801bfce8,
		"TItemManager::TItemManager": 0x801bfcf0,
		"TItemManager::load": 0x801bfd7c,
		"TItemManager::loadAfter": 0x801bfdfc,
		"TItemManager::newAndRegisterCoinReal": 0x801bfed0,
		"newAndRegisterCoinReal": 0x801bfed0,
		"TItemManager::perform": 0x801bff20,
		"TItemManager::newAndRegisterCoin": 0x801bffe4,
		"newAndRegisterCoin": 0x801bffe4,
		"TItemManager::makeShineAppearWithDemoOffset": 0x801c00cc,
		"makeShineAppearWithDemoOffset": 0x801c00cc,
		"TItemManager::makeShineAppearWithDemo": 0x801c018c,
		"makeShineAppearWithDemo": 0x801c018c,
		"TItemManager::makeShineAppearWithTime": 0x801c0234,
		"makeShineAppearWithTime": 0x801c0234,
		"TItemManager::resetNozzleBoxesModel": 0x801c02e4,
		"resetNozzleBoxesModel": 0x801c02e4,
		"MoveBG::__sinit_ItemManager_cpp": 0x801c03c4,
		"__sinit_ItemManager_cpp": 0x801c03c4,
		"TBasketReverse::initMapObj": 0x801c0744,
		"TBasketReverse::kill": 0x801c0774,
		"TRedCoinSwitch::TRedCoinSwitch": 0x801c082c,
		"TRedCoinSwitch::load": 0x801c088c,
		"TRedCoinSwitch::loadAfter": 0x801c0940,
		"TRedCoinSwitch::control": 0x801c09e4,
		"TRedCoinSwitch::receiveMessage": 0x801c0a9c,
		"TMapObjSwitch::TMapObjSwitch": 0x801c0b5c,
		"TMapObjSwitch::load": 0x801c0bf0,
		"TMapObjSwitch::receiveMessage": 0x801c0cf8,
		"TMapObjSwitch::control": 0x801c0e18,
		"THideObjInfo::THideObjInfo": 0x801c0e70,
		"THideObjInfo::load": 0x801c0f80,
		"THideObjInfo::action": 0x801c0ffc,
		"TMapObjWaterSpray::TMapObjWaterSpray": 0x801c109c,
		"TMapObjWaterSpray::load": 0x801c1118,
		"TMapObjWaterSpray::calc": 0x801c12d4,
		"TDamageObj::load": 0x801c13e4,
		"TDamageObj::init": 0x801c1500,
		"TDamageObj::perform": 0x801c1570,
		"TMapObjStartDemo::load": 0x801c15c8,
		"TMapObjStartDemo::touchPlayer": 0x801c1618,
		"TMapObjChangeStageHipDrop::initMapObj": 0x801c1648,
		"TMapObjChangeStageHipDrop::touchPlayer": 0x801c16a4,
		"TMapObjChangeStage::load": 0x801c1720,
		"TMapObjChangeStage::touchPlayer": 0x801c1770,
		"TMapObjBillboard::touchWater": 0x801c17ec,
		"TMapObjBillboard::touchActor": 0x801c19f8,
		"TManhole::TManhole": 0x801c1ae0,
		"TManhole::initMapObj": 0x801c1b4c,
		"TManhole::loadAfter": 0x801c1bc0,
		"TManhole::makeManholeUnuseful": 0x801c1c00,
		"makeManholeUnuseful": 0x801c1c00,
		"TManhole::setGroundCollision": 0x801c1c64,
		"TManhole::calc": 0x801c1d50,
		"TManhole::appeared": 0x801c1e28,
		"TManhole::animationFinished": 0x801c1fe8,
		"animationFinished": 0x801c1fe8,
		"TManhole::touchPlayer": 0x801c216c,
		"TDoor::TDoor": 0x801c2480,
		"TDoor::load": 0x801c24cc,
		"TDoor::touchPlayer": 0x801c2528,
		"MoveBG::__sinit_MapObjTown_cpp": 0x801c2b74,
		"__sinit_MapObjTown_cpp": 0x801c2b74,
		"TSuperHipDropBlock::loadAfter": 0x801c2f6c,
		"TSuperHipDropBlock::receiveMessage": 0x801c2ff0,
		"TTelesaBlock::setGroundCollision": 0x801c3090,
		"TTelesaBlock::perform": 0x801c30e4,
		"TTelesaBlock::initMapObj": 0x801c3280,
		"TJuiceBlock::kill": 0x801c330c,
		"TJuiceBlock::moveObject": 0x801c3340,
		"TJuiceBlock::initMapObj": 0x801c3398,
		"TBrickBlock::initMapObj": 0x801c33ec,
		"TBrickBlock::receiveMessage": 0x801c34b4,
		"TBrickBlock::kill": 0x801c3590,
		"TIceBlock::initMapObj": 0x801c3660,
		"TIceBlock::calc": 0x801c36f0,
		"TIceBlock::control": 0x801c3754,
		"TIceBlock::touchWater": 0x801c3934,
		"TIceBlock::getSDLModelFlag": 0x801c3abc,
		"TLeanBlock::TLeanBlock": 0x801c3ac4,
		"TLeanBlock::initMapObj": 0x801c3b6c,
		"TLeanBlock::calcDefaultMtx": 0x801c3bec,
		"TLeanBlock::calcLeanMtx": 0x801c3c24,
		"calcLeanMtx": 0x801c3c24,
		"TLeanBlock::control": 0x801c3d74,
		"TLeanBlock::touchPlayer": 0x801c3ee0,
		"TSandBlock::initMapObj": 0x801c3f84,
		"TSandBlock::control": 0x801c4038,
		"TSandBlock::touchPlayer": 0x801c4294,
		"TBreakableBlock::touchPlayer": 0x801c42e4,
		"MoveBG::__sinit_MapObjBlock_cpp": 0x801c461c,
		"__sinit_MapObjBlock_cpp": 0x801c461c,
		"TWoodLog::control": 0x801c49f4,
		"TBellWatermill::TBellWatermill": 0x801c4aec,
		"TBellWatermill::loadAfter": 0x801c4b68,
		"TBellWatermill::control": 0x801c4c98,
		"TBellWatermill::touchWater": 0x801c5474,
		"TBiancoBell::TBiancoBell": 0x801c54dc,
		"TBiancoBell::initMapObj": 0x801c552c,
		"TBiancoBell::touchPlayer": 0x801c55c0,
		"TBiancoBell::touchWater": 0x801c56e0,
		"TLampSeesawMain::TLampSeesawMain": 0x801c5804,
		"TLampSeesawMain::loadAfter": 0x801c5910,
		"TLampSeesawMain::control": 0x801c59d4,
		"TLampSeesawMain::touchPlayer": 0x801c5bc0,
		"TLampSeesawMain::pushDown": 0x801c5c0c,
		"TLampSeesaw::TLampSeesaw": 0x801c5c24,
		"TLampSeesaw::load": 0x801c5c78,
		"TLampSeesaw::touchPlayer": 0x801c5cf0,
		"TLampSeesaw::pushDown": 0x801c5d40,
		"TLeafBoatRotten::TLeafBoatRotten": 0x801c5d44,
		"TLeafBoatRotten::load": 0x801c5e28,
		"TLeafBoatRotten::perform": 0x801c5e94,
		"TLeafBoatRotten::control": 0x801c5eb4,
		"TLeafBoat::TLeafBoat": 0x801c6170,
		"TLeafBoat::initMapObj": 0x801c6208,
		"TLeafBoat::calc": 0x801c6250,
		"TLeafBoat::control": 0x801c6328,
		"TLeafBoat::bind": 0x801c64ec,
		"TLeafBoat::touchWall": 0x801c6734,
		"TLeafBoat::touchActor": 0x801c686c,
		"TBiancoMiniWindmill::TBiancoMiniWindmill": 0x801c6a1c,
		"TBiancoMiniWindmill::initMapObj": 0x801c6ae8,
		"TBiancoMiniWindmill::control": 0x801c6c04,
		"TBiancoMiniWindmill::calc": 0x801c6c74,
		"TBiancoMiniWindmill::touchWater": 0x801c6e10,
		"TBiancoWatermillVertical::TBiancoWatermillVertical": 0x801c6f2c,
		"TBiancoWatermillVertical::load": 0x801c6f90,
		"TBiancoWatermillVertical::loadAfter": 0x801c6ff0,
		"TBiancoWatermillVertical::control": 0x801c70b4,
		"TBiancoWatermillVertical::setGroundCollision": 0x801c727c,
		"TBiancoWatermillVertical::touchWater": 0x801c72f0,
		"TBiancoWatermill::TBiancoWatermill": 0x801c7468,
		"TBiancoWatermill::initMapObj": 0x801c74bc,
		"TBiancoWatermill::control": 0x801c752c,
		"TBiancoWatermill::touchWater": 0x801c75b0,
		"TBiancoWatermill::turnByEnemy": 0x801c75b8,
		"turnByEnemy": 0x801c75b8,
		"TMapObjRootPakkun::initMapObj": 0x801c75bc,
		"TMapObjRootPakkun::drawObject": 0x801c761c,
		"TBigWindmill::load": 0x801c76b0,
		"TBigWindmill::control": 0x801c7790,
		"MoveBG::__sinit_MapObjBianco_cpp": 0x801c7e38,
		"__sinit_MapObjBianco_cpp": 0x801c7e38,
		"TWaterHitPictureHideObj::getObjAppearPos": 0x801c8230,
		"TPictureTelesa::control": 0x801c8238,
		"TPictureTelesa::touchActor": 0x801c8284,
		"TPictureTelesa::afterFinishedAnim": 0x801c83e8,
		"TPanelRevolve::control": 0x801c8490,
		"TPanelRevolve::touchPlayer": 0x801c84fc,
		"TPanelRevolve::receiveMessage": 0x801c859c,
		"TChestRevolve::control": 0x801c8634,
		"TChestRevolve::touchWater": 0x801c8698,
		"TWarpAreaActor::TWarpAreaActor": 0x801c8704,
		"TWarpAreaActor::load": 0x801c8754,
		"TWarpAreaActor::perform": 0x801c8810,
		"TSirenaCasinoRoof::getSDLModelFlag": 0x801c88ac,
		"TSirenaCasinoRoof::perform": 0x801c88b4,
		"TSirenaCasinoRoof::initMapObj": 0x801c8914,
		"TSirenabossWall::getSDLModelFlag": 0x801c89e8,
		"TSirenabossWall::drawObject": 0x801c89f0,
		"TSirenabossWall::perform": 0x801c8a24,
		"TSirenabossWall::initMapObj": 0x801c8a84,
		"TSakuCasino::calcRootMatrix": 0x801c8b48,
		"TSakuCasino::loadAfter": 0x801c8c7c,
		"TSakuCasino::initMapObj": 0x801c8ce0,
		"TSakuCasino::TSakuCasino": 0x801c8df0,
		"TCloset::touchWater": 0x801c8e4c,
		"TCloset::calcRootMatrix": 0x801c8fac,
		"TCloset::moveObject": 0x801c90d8,
		"TCloset::initMapObj": 0x801c9464,
		"TCloset::TCloset": 0x801c965c,
		"TDonchou::touchWater": 0x801c9708,
		"TDonchou::calcRootMatrix": 0x801c9734,
		"TDonchou::loadAfter": 0x801c99a8,
		"TDonchou::initMapObj": 0x801c9a70,
		"TDonchou::TDonchou": 0x801c9b88,
		"TCasinoPanelGate::touchWater": 0x801c9be4,
		"TCasinoPanelGate::calcRootMatrix": 0x801c9e68,
		"TCasinoPanelGate::moveObject": 0x801c9f34,
		"TCasinoPanelGate::initMapObj": 0x801ca348,
		"TCasinoPanelGate::TCasinoPanelGate": 0x801ca448,
		"TItemSlotDrum::getResultFromAng": 0x801ca4f4,
		"TItemSlotDrum::getForcastResult": 0x801ca538,
		"TItemSlotDrum::generateItem": 0x801ca694,
		"TItemSlotDrum::touchWater": 0x801cab80,
		"TItemSlotDrum::calcRootMatrix": 0x801cad10,
		"TItemSlotDrum::moveObject": 0x801cae40,
		"TItemSlotDrum::loadAfter": 0x801cb3ac,
		"TItemSlotDrum::TItemSlotDrum": 0x801cb458,
		"TSlotDrum::touchWater": 0x801cb584,
		"TSlotDrum::calcRootMatrix": 0x801cb6ac,
		"TSlotDrum::moveObject": 0x801cb75c,
		"TSlotDrum::initNeonMatColor": 0x801cbc28,
		"TSlotDrum::initMapObj": 0x801cbce8,
		"TSlotDrum::TSlotDrum": 0x801cbe78,
		"TSirenaRollMapObj::TSirenaRollMapObj": 0x801cbf1c,
		"MoveBG::partsRollCallback": 0x801cbfa8,
		"partsRollCallback": 0x801cbfa8,
		"TRoulette::switchStop": 0x801cc108,
		"switchStop": 0x801cc108,
		"TRoulette::setRollSp": 0x801cc228,
		"setRollSp": 0x801cc228,
		"TRoulette::calcRootMatrix": 0x801cc24c,
		"TRoulette::moveObject": 0x801cc2f0,
		"TRoulette::perform": 0x801cc3e4,
		"TRoulette::initMapObj": 0x801cc444,
		"TRoulette::TRoulette": 0x801cc608,
		"TRouletteSw::perform": 0x801cc6dc,
		"TRouletteSw::receiveMessage": 0x801cc710,
		"TCloset::getRollAngY": 0x801ccae4,
		"TCasinoPanelGate::getRollAngX": 0x801ccc14,
		"MoveBG::__sinit_MapObjSirena_cpp": 0x801ccdc8,
		"__sinit_MapObjSirena_cpp": 0x801ccdc8,
		"TFruitLauncher::loadAfter": 0x801cd1b8,
		"TFruitLauncher::fireObj": 0x801cd40c,
		"fireObj": 0x801cd40c,
		"TLiveActor::getMActor": 0x801cd9d8,
		"TFruitSwitch::receiveMessage": 0x801cd9e0,
		"TSurfGesoObj::initMapObj": 0x801cda60,
		"TRiccoWatermill::TRiccoWatermill": 0x801cdb70,
		"TRiccoWatermill::loadAfter": 0x801cdbdc,
		"TRiccoWatermill::calc": 0x801cdcbc,
		"TRiccoWatermill::control": 0x801cdcdc,
		"TRiccoWatermill::touchWater": 0x801ce0e4,
		"TCraneCargo::calc": 0x801ce1d4,
		"TCraneCargo::control": 0x801ce218,
		"TCraneUpDown::initMapObj": 0x801ce248,
		"TCraneUpDown::control": 0x801ce368,
		"TCraneRotY::load": 0x801ce66c,
		"TCraneRotY::control": 0x801ce728,
		"TCraneRotY::calc": 0x801ce8c4,
		"MoveBG::__sinit_MapObjRicco_cpp": 0x801cec2c,
		"__sinit_MapObjRicco_cpp": 0x801cec2c,
		"TSandEgg::getSDLModelFlag": 0x801cf00c,
		"TMammaMirrorMapOperator::TMammaMirrorMapOperator": 0x801cf014,
		"TMammaMirrorMapOperator::loadAfter": 0x801cf1b0,
		"TMammaMirrorMapOperator::perform": 0x801cf46c,
		"TGoalWatermelon::TGoalWatermelon": 0x801cf6bc,
		"TGoalWatermelon::load": 0x801cf71c,
		"TGoalWatermelon::loadAfter": 0x801cf794,
		"TGoalWatermelon::control": 0x801cf844,
		"TGoalWatermelon::touchActor": 0x801cf8c4,
		"TSandBird::TSandBird": 0x801cf9d0,
		"TSandBird::initMapObj": 0x801cfaa4,
		"TSandBird::nameIsObj": 0x801cfb34,
		"TSandBird::makeObjFromJointName": 0x801cfb70,
		"TSandBird::control": 0x801cfbfc,
		"TMammaYacht::initMapObj": 0x801cfe40,
		"TMammaYacht::control": 0x801cff14,
		"TMammaBlockRotate::TMammaBlockRotate": 0x801cffb4,
		"TMammaBlockRotate::load": 0x801d000c,
		"TMammaBlockRotate::initMapObj": 0x801d00d4,
		"TMammaBlockRotate::control": 0x801d024c,
		"TMammaBlockRotate::touchWater": 0x801d04ac,
		"TShiningStone::TShiningStone": 0x801d04fc,
		"TShiningStone::load": 0x801d0564,
		"TShiningStone::perform": 0x801d07b4,
		"TShiningStone::putOnLight": 0x801d088c,
		"putOnLight": 0x801d088c,
		"TLeanMirror::TLeanMirror": 0x801d0b2c,
		"TLeanMirror::load": 0x801d0bec,
		"TLeanMirror::initMapObj": 0x801d0d28,
		"TLeanMirror::getSDLModelFlag": 0x801d0e00,
		"TLeanMirror::loadAfter": 0x801d0e08,
		"TLeanMirror::control": 0x801d0f30,
		"TLeanMirror::controlShake": 0x801d1174,
		"controlShake": 0x801d1174,
		"TLeanMirror::controlGoTarget": 0x801d14a8,
		"controlGoTarget": 0x801d14a8,
		"MoveBG::startCameraShakeSE": 0x801d1664,
		"startCameraShakeSE": 0x801d1664,
		"TLeanMirror::release": 0x801d166c,
		"TLeanMirror::touchEnemy": 0x801d18bc,
		"TLeanMirror::touchPlayer": 0x801d199c,
		"TLeanMirror::receiveMessage": 0x801d1ab0,
		"TLeanMirror::draw": 0x801d1ccc,
		"TSandCastle::TSandCastle": 0x801d1e2c,
		"TSandCastle::initMapObj": 0x801d1fe8,
		"TSandCastle::loadAfter": 0x801d202c,
		"TSandCastle::findTriggerActor": 0x801d20e0,
		"TSandCastle::calcRootMatrix": 0x801d2140,
		"TSandCastle::waitBeforeExplode": 0x801d2180,
		"MoveBG::SandCastleCallBack": 0x801d2200,
		"SandCastleCallBack": 0x801d2200,
		"TSandCastle::explode": 0x801d2294,
		"TSandCastle::expanded": 0x801d23fc,
		"TSandCastle::withering": 0x801d24f0,
		"TSandBombBase::TSandBombBase": 0x801d2630,
		"TSandBombBase::initMapObj": 0x801d26b0,
		"TSandBombBase::loadAfter": 0x801d27e0,
		"TSandBombBase::findTriggerActor": 0x801d2838,
		"TSandBombBase::control": 0x801d2880,
		"TSandBombBase::grow": 0x801d2b18,
		"TSandBombBase::waitBeforeExplode": 0x801d2b24,
		"TSandBombBase::explode": 0x801d2b38,
		"TSandBombBase::exploding": 0x801d2c78,
		"exploding": 0x801d2c78,
		"TSandBombBase::expanded": 0x801d2dfc,
		"TSandBombBase::withered": 0x801d2ebc,
		"withered": 0x801d2ebc,
		"TSandBomb::initMapObj": 0x801d2ef0,
		"TSandBomb::getSDLModelFlag": 0x801d2f10,
		"TSandBomb::touchWater": 0x801d2f18,
		"TSandBomb::makeObjAppeared": 0x801d3064,
		"TSandLeafBase::initMapObj": 0x801d30a8,
		"TSandLeafBase::control": 0x801d313c,
		"TSandLeafBase::grow": 0x801d32fc,
		"TSandBase::TSandBase": 0x801d3488,
		"TSandBase::withering": 0x801d34e0,
		"TSandLeaf::control": 0x801d358c,
		"TSandLeaf::touchWater": 0x801d35e4,
		"TMammaMirrorMapOperator::~TMammaMirrorMapOperator": 0x801d3618,
		"TMapObjBall::getDepthAtFloating": 0x801d3794,
		"MoveBG::__sinit_MapObjMamma_cpp": 0x801d3c1c,
		"__sinit_MapObjMamma_cpp": 0x801d3c1c,
		"TPinnaCoaster::TPinnaCoaster": 0x801d400c,
		"TPinnaCoaster::initMapObj": 0x801d4068,
		"TPinnaCoaster::control": 0x801d4160,
		"TAmiKing::touchPlayer": 0x801d42f8,
		"TAmiKing::bind": 0x801d431c,
		"TAmiKing::moveObject": 0x801d44f0,
		"TAmiKing::initMapObj": 0x801d4858,
		"TAmiKing::loadAfter": 0x801d48e0,
		"TWaterRecoverObj::touchPlayer": 0x801d493c,
		"TPinnaEntrance::loadAfter": 0x801d49cc,
		"TBalloonKoopaJr::load": 0x801d4a34,
		"TBalloonKoopaJr::kill": 0x801d4b54,
		"TBalloonKoopaJr::touchActor": 0x801d4c00,
		"TChangeStageMerrygoround::calc": 0x801d4c2c,
		"TChangeStageMerrygoround::touchPlayer": 0x801d4c90,
		"TMerrygoround::TMerrygoround": 0x801d4d64,
		"TMerrygoround::initMapObj": 0x801d4e60,
		"TMerrygoround::draw": 0x801d514c,
		"TMerrygoround::control": 0x801d5150,
		"TShellCup::TShellCup": 0x801d5308,
		"TPinnaShell::TPinnaShell": 0x801d5408,
		"TShellCup::initMapObj": 0x801d54b0,
		"TShellCup::loadAfter": 0x801d5700,
		"TShellCup::perform": 0x801d5878,
		"MoveBG::MsMtxSetRotX": 0x801d59c4,
		"MsMtxSetRotX": 0x801d59c4,
		"TShellCup::control": 0x801d5a40,
		"TPinnaShell::control": 0x801d5aa4,
		"TPinnaShell::receiveMessage": 0x801d5e18,
		"TViking::TViking": 0x801d5ec8,
		"TViking::initMapObj": 0x801d5fd0,
		"TViking::loadAfter": 0x801d6090,
		"TViking::reset": 0x801d60d0,
		"TViking::control": 0x801d6104,
		"TViking::roll": 0x801d6268,
		"roll": 0x801d6268,
		"THorizontalViking::initMapObj": 0x801d660c,
		"THorizontalViking::reset": 0x801d6664,
		"THorizontalViking::control": 0x801d6698,
		"TFerrisWheel::TFerrisWheel": 0x801d67bc,
		"TFerrisWheel::initMapObj": 0x801d6814,
		"TFerrisWheel::control": 0x801d6938,
		"TFerrisWheel::becomeCalmlyCallback": 0x801d6ad0,
		"becomeCalmlyCallback": 0x801d6ad0,
		"TAmiKing::touchWater": 0x801d6bd4,
		"MoveBG::__sinit_MapObjPinna_cpp": 0x801d7060,
		"__sinit_MapObjPinna_cpp": 0x801d7060,
		"TGateShadow::~TGateShadow": 0x801d73bc,
		"TGateShadow::perform": 0x801d7430,
		"MoveBG::__sinit_MapObjSample_cpp": 0x801d7434,
		"__sinit_MapObjSample_cpp": 0x801d7434,
		"TMareEventPoint::load": 0x801d77b4,
		"TMareEventPoint::receiveMessage": 0x801d7808,
		"TMareCork::drawObject": 0x801d78fc,
		"TMareCork::getTakingMtx": 0x801d79e0,
		"TMareCork::calcRootMatrix": 0x801d79f4,
		"TMareCork::moveObject": 0x801d7aec,
		"TMareCork::loadAfter": 0x801d7b60,
		"TMareFall::load": 0x801d7cac,
		"TMareFall::calc": 0x801d7d3c,
		"TMuddyBoat::TMuddyBoat": 0x801d7dfc,
		"TMuddyBoat::initMapObj": 0x801d7e98,
		"TMuddyBoat::getSDLModelFlag": 0x801d7f68,
		"TMuddyBoat::calc": 0x801d7f70,
		"TMuddyBoat::control": 0x801d8128,
		"TMuddyBoat::bind": 0x801d83c0,
		"TMapObjBase::getObjCollisionHeightOffset": 0x801d8914,
		"getObjCollisionHeightOffset": 0x801d8914,
		"TMuddyBoat::kill": 0x801d891c,
		"TMuddyBoat::calcRootMatrix": 0x801d8a04,
		"TMuddyBoat::moveByWater": 0x801d8a08,
		"moveByWater": 0x801d8a08,
		"TMapObjPuncher::load": 0x801d8bb8,
		"TMapObjPuncher::control": 0x801d8c38,
		"TMapObjPuncher::touchPlayer": 0x801d8d2c,
		"TWireBell::TWireBell": 0x801d8ea0,
		"TWireBell::loadAfter": 0x801d8f1c,
		"TWireBell::control": 0x801d8f58,
		"TWireBell::draw": 0x801d8ff8,
		"TWireBell::initDraw": 0x801d915c,
		"TMapObjGrowTree::TMapObjGrowTree": 0x801d9368,
		"TMapObjGrowTree::initMapObj": 0x801d93c8,
		"TMapObjGrowTree::loadAfter": 0x801d942c,
		"TMapObjGrowTree::control": 0x801d9460,
		"TMapObjGrowTree::touchWater": 0x801d9734,
		"TMapObjElasticCode::initMapObj": 0x801d9a1c,
		"TMapObjElasticCode::control": 0x801d9a68,
		"TMapObjElasticCode::draw": 0x801d9b78,
		"TCogwheel::TCogwheel": 0x801d9d6c,
		"TCogwheel::initMapObj": 0x801d9df8,
		"TCogwheel::control": 0x801da084,
		"TCogwheel::calc": 0x801da244,
		"TCogwheel::draw": 0x801da308,
		"TCogwheel::initDraw": 0x801da594,
		"TCogwheelScale::TCogwheelScale": 0x801da7a0,
		"TCogwheelScale::control": 0x801da818,
		"TCogwheelScale::touchPlayer": 0x801da8c8,
		"TCogwheelScale::receiveMessage": 0x801da9d0,
		"TCogwheelScale::touchWater": 0x801daa1c,
		"MoveBG::__sinit_MapObjMare_cpp": 0x801daee4,
		"__sinit_MapObjMare_cpp": 0x801daee4,
		"TMapObjFlagManager::~TMapObjFlagManager": 0x801db248,
		"TMapObjFlagManager::TMapObjFlagManager": 0x801db2bc,
		"TMapObjFlagManager::TMapObjFlagInfo::TMapObjFlagInfo": 0x801db348,
		"TMapObjFlagManager::load": 0x801db358,
		"TMapObjFlagManager::registerObj": 0x801db3ec,
		"registerObj": 0x801db3ec,
		"TMapObjFlagManager::perform": 0x801dba14,
		"TMapObjFlagManager::initDraw": 0x801dbc24,
		"TMapObjFlag::TMapObjFlag": 0x801dbdec,
		"TMapObjFlag::load": 0x801dbee0,
		"TMapObjFlag::init": 0x801dbf34,
		"TMapObjFlag::updateVertex": 0x801dc214,
		"updateVertex": 0x801dc214,
		"TMapObjFlag::draw": 0x801dc34c,
		"MoveBG::__sinit_MapObjFlag_cpp": 0x801dc688,
		"__sinit_MapObjFlag_cpp": 0x801dc688,
		"TMapObjWave::~TMapObjWave": 0x801dc98c,
		"TMapObjWave::TMapObjWave": 0x801dca00,
		"TMapObjWave::load": 0x801dcc08,
		"TMapObjWave::perform": 0x801dcdd8,
		"TMapObjWave::updateTime": 0x801dce60,
		"updateTime": 0x801dce60,
		"TMapObjWave::updateHeightAndAlpha": 0x801dcf04,
		"updateHeightAndAlpha": 0x801dcf04,
		"TMapObjWave::draw": 0x801dd21c,
		"TMapObjWave::noWave": 0x801dd548,
		"noWave": 0x801dd548,
		"TMapObjWave::getHeight": 0x801dd568,
		"TMapObjWave::getWaveHeight": 0x801dd694,
		"getWaveHeight": 0x801dd694,
		"TMapObjWave::initDraw": 0x801dd720,
		"MoveBG::__sinit_MapObjWave_cpp": 0x801dda4c,
		"__sinit_MapObjWave_cpp": 0x801dda4c,
		"TMapObjFloatOnSea::TMapObjFloatOnSea": 0x801dddec,
		"TMapObjFloatOnSea::initMapObj": 0x801dde54,
		"TMapObjFloatOnSea::calc": 0x801ddf74,
		"TMapObjFloatOnSea::control": 0x801de018,
		"TMapObjFloatOnSea::touchPlayer": 0x801de098,
		"MoveBG::__sinit_MapObjFloat_cpp": 0x801de0dc,
		"__sinit_MapObjFloat_cpp": 0x801de0dc,
		"TMapObjPlane::hasMapCollision": 0x801de464,
		"TSandPlane::load": 0x801de46c,
		"TRockPlane::load": 0x801de4e8,
		"TMapObjPlane::TMapObjPlane": 0x801de564,
		"TMapObjPlane::load": 0x801de5d8,
		"TMapObjPlane::makeMountain": 0x801de744,
		"makeMountain": 0x801de744,
		"TMapObjPlane::perform": 0x801de8a0,
		"TMapObjPlane::receiveMessage": 0x801de8ec,
		"TMapObjPlane::depress": 0x801de94c,
		"depress": 0x801de94c,
		"TMapObjPlane::calcNrm": 0x801debfc,
		"calcNrm": 0x801debfc,
		"TMapObjPlane::updateCheckData": 0x801df0c0,
		"updateCheckData": 0x801df0c0,
		"TMapObjPlane::draw": 0x801df290,
		"TMapObjPlane::initDraw": 0x801df468,
		"MoveBG::__sinit_MapObjPlane_cpp": 0x801df7f0,
		"__sinit_MapObjPlane_cpp": 0x801df7f0,
		"TRideCloud::perform": 0x801dfba0,
		"TRideCloud::control": 0x801dfbd8,
		"TRideCloud::getShadowType": 0x801dfedc,
		"TRideCloud::load": 0x801dfee4,
		"TRideCloud::initMapObj": 0x801e0030,
		"TRideCloud::calcRootMatrix": 0x801e0064,
		"TRideCloud::setGroundCollision": 0x801e0110,
		"TRideCloud::touchWater": 0x801e0188,
		"TRideCloud::TRideCloud": 0x801e01b0,
		"MoveBG::__sinit_MapObjCloud_cpp": 0x801e02bc,
		"__sinit_MapObjCloud_cpp": 0x801e02bc,
		"TBigWatermelon::TBigWatermelon": 0x801e065c,
		"TBigWatermelon::initMapObj": 0x801e0750,
		"TBigWatermelon::loadAfter": 0x801e08a4,
		"TBigWatermelon::receiveMessage": 0x801e0920,
		"TBigWatermelon::checkWallCollision": 0x801e0a5c,
		"TBigWatermelon::startEvent": 0x801e0a7c,
		"TBigWatermelon::control": 0x801e0c9c,
		"TBigWatermelon::appearing": 0x801e0f2c,
		"TBigWatermelon::kill": 0x801e103c,
		"TBigWatermelon::touchActor": 0x801e119c,
		"TBigWatermelon::touchGround": 0x801e1494,
		"TBigWatermelon::rebound": 0x801e14b4,
		"TBigWatermelon::touchWall": 0x801e16b8,
		"TBigWatermelon::touchWaterSurface": 0x801e16d8,
		"TCoverFruit::loadAfter": 0x801e1748,
		"TCoverFruit::receiveMessage": 0x801e17a0,
		"TCoverFruit::calcRootMatrix": 0x801e1840,
		"TRandomFruit::TRandomFruit": 0x801e1984,
		"TRandomFruit::initMapObj": 0x801e1ab4,
		"TResetFruit::TResetFruit": 0x801e1bf4,
		"TResetFruit::initMapObj": 0x801e1c5c,
		"TResetFruit::receiveMessage": 0x801e1ca0,
		"TResetFruit::getLivingTime": 0x801e207c,
		"TResetFruit::makeObjAppeared": 0x801e2084,
		"TResetFruit::killByTimer": 0x801e21b4,
		"TResetFruit::perform": 0x801e21d0,
		"TResetFruit::control": 0x801e23b4,
		"TResetFruit::appearing": 0x801e29e4,
		"TResetFruit::breaking": 0x801e2ae4,
		"TResetFruit::kicked": 0x801e2c00,
		"TResetFruit::makeObjLiving": 0x801e2ea4,
		"makeObjLiving": 0x801e2ea4,
		"TResetFruit::touchGround": 0x801e2f24,
		"TResetFruit::touchActor": 0x801e304c,
		"TResetFruit::touchWater": 0x801e3180,
		"TResetFruit::touchWaterSurface": 0x801e32d0,
		"TResetFruit::touchPollution": 0x801e33d4,
		"TResetFruit::hold": 0x801e3500,
		"TResetFruit::thrown": 0x801e364c,
		"TResetFruit::makeObjWaitingToAppear": 0x801e3680,
		"makeObjWaitingToAppear": 0x801e3680,
		"TResetFruit::waitingToAppear": 0x801e374c,
		"TResetFruit::checkGroundCollision": 0x801e3888,
		"TMapObjBall::TMapObjBall": 0x801e3a20,
		"TMapObjBall::initMapObj": 0x801e3ac8,
		"TMapObjBall::receiveMessage": 0x801e3fbc,
		"TMapObjBall::control": 0x801e40b4,
		"TMapObjBall::makeObjAppeared": 0x801e41c4,
		"TMapObjBall::makeObjDefault": 0x801e42bc,
		"TMapObjBall::checkWallCollision": 0x801e4314,
		"TMapObjBall::calcCurrentMtx": 0x801e43f0,
		"calcCurrentMtx": 0x801e43f0,
		"TMapObjBall::touchActor": 0x801e4820,
		"TMapObjBall::boundByActor": 0x801e4974,
		"boundByActor": 0x801e4974,
		"TMapObjBall::touchWater": 0x801e4ec8,
		"TMapObjBall::kicked": 0x801e4fc8,
		"TMapObjBall::hold": 0x801e51e4,
		"TMapObjBall::put": 0x801e527c,
		"TMapObjBall::touchGround": 0x801e52bc,
		"TMapObjBall::rebound": 0x801e5590,
		"TMapObjBall::touchWaterSurface": 0x801e5718,
		"TMapObjBall::touchPollution": 0x801e5744,
		"TMapObjBall::touchWall": 0x801e5770,
		"TMapObjBall::touchRoof": 0x801e5ad4,
		"MoveBG::__sinit_MapObjBall_cpp": 0x801e5c40,
		"__sinit_MapObjBall_cpp": 0x801e5c40,
		"TAirportEventSink::~TAirportEventSink": 0x801e5f64,
		"TAirportEventSink::TAirportEventSink": 0x801e5ff8,
		"TAirportEventSink::loadAfter": 0x801e605c,
		"TAirportEventSink::watch": 0x801e60f0,
		"TAirportEventSink::control": 0x801e61c0,
		"TAirportEventSink::finishControl": 0x801e6234,
		"TAirportSwitch::TAirportSwitch": 0x801e62c4,
		"TAirportSwitch::loadAfter": 0x801e6310,
		"TAirportSwitch::breaking": 0x801e6384,
		"MoveBG::__sinit_MapObjAirport_cpp": 0x801e64ec,
		"__sinit_MapObjAirport_cpp": 0x801e64ec,
		"TTurboNozzleDoor::touchPlayer": 0x801e6874,
		"TTurboNozzleDoor::loadAfter": 0x801e69e0,
		"TDemoCannon::perform": 0x801e6b3c,
		"TDemoCannon::startDemo": 0x801e6de4,
		"TDemoCannon::initMapObj": 0x801e6e50,
		"TDemoCannon::loadAfter": 0x801e6fac,
		"TMareGate::loadAfter": 0x801e7100,
		"TMareGate::control": 0x801e7158,
		"TMapObjSmoke::load": 0x801e71c0,
		"TMapObjSmoke::control": 0x801e721c,
		"TMapObjSmoke::touchWater": 0x801e7248,
		"TDptMonteFence::touchPlayer": 0x801e729c,
		"TBellDolpic::control": 0x801e7344,
		"TBellDolpic::receiveMessage": 0x801e7554,
		"TBellDolpic::touchPlayer": 0x801e76cc,
		"TBellDolpic::ring": 0x801e76f0,
		"ring": 0x801e76f0,
		"TBellDolpic::calcRootMatrix": 0x801e788c,
		"TBellDolpic::initMapObj": 0x801e78f4,
		"TBellDolpic::TBellDolpic": 0x801e79c4,
		"TMonumentShine::control": 0x801e7a4c,
		"TMonumentShine::receiveMessage": 0x801e7ce8,
		"TMonumentShine::hitByWater": 0x801e7e2c,
		"hitByWater": 0x801e7e2c,
		"TMonumentShine::initMapObj": 0x801e7fb8,
		"TMonumentShine::TMonumentShine": 0x801e8068,
		"MoveBG::__sinit_MapObjDolpic_cpp": 0x801e8400,
		"__sinit_MapObjDolpic_cpp": 0x801e8400,
		"TMapObjRevivalPollution::~TMapObjRevivalPollution": 0x801e8734,
		"TMapObjRevivalPollution::TMapObjRevivalPollution": 0x801e87a8,
		"TMapObjRevivalPollution::load": 0x801e8818,
		"TMapObjRevivalPollution::loadAfter": 0x801e8900,
		"TMapObjRevivalPollution::perform": 0x801e89ac,
		"TRevivalPolluter::TRevivalPolluter": 0x801e8a0c,
		"TPolluterBase::TPolluterBase": 0x801e8a34,
		"TPolluterBase::load": 0x801e8a80,
		"TPolluterBase::perform": 0x801e8ba0,
		"MoveBG::__sinit_MapObjPollution_cpp": 0x801e8c80,
		"__sinit_MapObjPollution_cpp": 0x801e8c80,
		"TMapObjGrassManager::~TMapObjGrassManager": 0x801e8f84,
		"TMapObjGrassManager::TMapObjGrassManager": 0x801e8ff8,
		"TMapObjGrassManager::load": 0x801e90bc,
		"TMapObjGrassManager::perform": 0x801e910c,
		"TMapObjGrassManager::initDrawNear": 0x801e9344,
		"initDrawNear": 0x801e9344,
		"TMapObjGrassGroup::TMapObjGrassGroup": 0x801e9590,
		"TMapObjGrassGroup::load": 0x801e95f4,
		"TMapObjGrassGroup::drawFar": 0x801e9880,
		"drawFar": 0x801e9880,
		"TMapObjGrassGroup::drawNear": 0x801e99a8,
		"drawNear": 0x801e99a8,
		"MoveBG::__sinit_MapObjGrass_cpp": 0x801e9b50,
		"__sinit_MapObjGrass_cpp": 0x801e9b50,
		"TMapObjPoleManager::~TMapObjPoleManager": 0x801e9e64,
		"TMapObjPoleManager::TMapObjPoleManager": 0x801e9ed8,
		"TMapObjPoleManager::TMapObjPoleInfo::TMapObjPoleInfo": 0x801e9f64,
		"TMapObjPoleManager::load": 0x801e9f74,
		"TMapObjPoleManager::perform": 0x801e9fb0,
		"TMapObjPoleManager::initDraw": 0x801ea05c,
		"TMapObjPole::draw": 0x801ea22c,
		"MoveBG::__sinit_MapObjPole_cpp": 0x801ea384,
		"__sinit_MapObjPole_cpp": 0x801ea384,
		"TMapObjWaterFilter::TMapObjWaterFilter": 0x801ea6ec,
		"TMapObjWaterFilter::init": 0x801ea7f4,
		"TMapObjWaterFilter::perform": 0x801ea840,
		"TMapObjSeaIndirect::TMapObjSeaIndirect": 0x801ea9d4,
		"TMapObjSeaIndirect::init": 0x801eaacc,
		"TMapObjSeaIndirect::perform": 0x801eabf4,
		"MoveBG::__sinit_MapObjWater_cpp": 0x801eac64,
		"__sinit_MapObjWater_cpp": 0x801eac64,
		"TModelGate::getTakingMtx": 0x801eb00c,
		"TModelGate::perform": 0x801eb014,
		"TModelGate::receiveMessage": 0x801ebbdc,
		"TModelGate::screenBlur": 0x801ebd84,
		"screenBlur": 0x801ebd84,
		"TModelGate::startOpen": 0x801ebfd4,
		"startOpen": 0x801ebfd4,
		"TModelGate::loadAfter": 0x801ec048,
		"MoveBG::__sinit_ModelGate_cpp": 0x801ec8c0,
		"__sinit_ModelGate_cpp": 0x801ec8c0,
		"TRailFence::TRailFence": 0x801ecc60,
		"TRailFence::load": 0x801eccec,
		"TRailFence::initMapCollisionData": 0x801ecd8c,
		"TRailFence::control": 0x801ecdac,
		"TRailFence::goOnRail": 0x801ecf68,
		"goOnRail": 0x801ecf68,
		"TRailFence::receiveMessage": 0x801ed184,
		"TFenceWaterH::changeStatusToWait": 0x801ed210,
		"TFenceWaterH::changeStatusToGo": 0x801ed248,
		"TFenceWaterH::control": 0x801ed2b8,
		"TFenceWater::initMapObj": 0x801ed580,
		"TFenceWater::initMapCollisionData": 0x801ed6d8,
		"TFenceWater::control": 0x801ed6f8,
		"TFenceWater::controlRotation": 0x801ed7ec,
		"controlRotation": 0x801ed7ec,
		"TFenceWater::changeStatusToWait": 0x801ed920,
		"TFenceWater::changeStatusToGo": 0x801ed938,
		"TFenceWater::receiveMessage": 0x801ed99c,
		"TFenceWater::draw": 0x801eda14,
		"TRevolvingFenceInner::initMapObj": 0x801eda18,
		"TRevolvingFenceInner::initMapCollisionData": 0x801edafc,
		"TRevolvingFenceInner::control": 0x801edbac,
		"TRevolvingFenceInner::setGroundCollision": 0x801edbf8,
		"TRevolvingFenceInner::controlGroundRoof": 0x801edd00,
		"controlGroundRoof": 0x801edd00,
		"TRevolvingFenceInner::controlWall": 0x801ede04,
		"controlWall": 0x801ede04,
		"MoveBG::MsMtxSetRotY": 0x801ee0c4,
		"MsMtxSetRotY": 0x801ee0c4,
		"TRevolvingFenceInner::receiveMessage": 0x801ee188,
		"TRevolvingFenceOuter::initMapCollisionData": 0x801ee424,
		"TRevolvingFenceOuter::receiveMessage": 0x801ee5a4,
		"TFence::initMapObj": 0x801ee600,
		"TFence::initMapCollisionData": 0x801ee64c,
		"TFence::receiveMessage": 0x801ee7c4,
		"MoveBG::__sinit_MapObjFence_cpp": 0x801eea70,
		"__sinit_MapObjFence_cpp": 0x801eea70,
		"TMapObjOptionWall::TMapObjOptionWall": 0x801eee20,
		"TMapObjOptionWall::init": 0x801eee6c,
		"TMapObjOptionWall::offCollision": 0x801eeedc,
		"offCollision": 0x801eeedc,
		"TMapObjOptionWall::onCollision": 0x801eef0c,
		"onCollision": 0x801eef0c,
		"TFileLoadBlock::TFileLoadBlock": 0x801eef3c,
		"TFileLoadBlock::initMapObj": 0x801eefa0,
		"TFileLoadBlock::loadAfter": 0x801ef088,
		"TFileLoadBlock::receiveMessage": 0x801ef208,
		"TFileLoadBlock::touchPlayer": 0x801ef2fc,
		"TFileLoadBlock::makeBlockRock": 0x801ef3ec,
		"makeBlockRock": 0x801ef3ec,
		"TFileLoadBlock::makeBlockNormal": 0x801ef424,
		"makeBlockNormal": 0x801ef424,
		"MoveBG::__sinit_MapObjOption_cpp": 0x801ef4e0,
		"__sinit_MapObjOption_cpp": 0x801ef4e0,
		"TWoodBlock::load": 0x801ef888,
		"TWoodBlock::calcRecycle": 0x801ef9bc,
		"TWoodBlock::TWoodBlock": 0x801efc1c,
		"TRollBlock::control": 0x801efd50,
		"TRollBlock::calcRootMatrix": 0x801efdc4,
		"TRollBlock::getRootJointMtx": 0x801eff00,
		"TRollBlock::setGroundCollision": 0x801eff24,
		"TRollBlock::load": 0x801eff84,
		"TRollBlock::TRollBlock": 0x801f002c,
		"TRailBlock::control": 0x801f007c,
		"TRailBlock::calcRootMatrix": 0x801f0628,
		"TRailBlock::getRootJointMtx": 0x801f06c0,
		"TRailBlock::initMapObj": 0x801f06e4,
		"TRailBlock::TRailBlock": 0x801f0764,
		"TNormalLift::perform": 0x801f0820,
		"TNormalLift::setGroundCollision": 0x801f087c,
		"TNormalLift::control": 0x801f0938,
		"TNormalLift::initMapObj": 0x801f0aec,
		"TNormalLift::readRailFlag": 0x801f0b30,
		"TNormalLift::load": 0x801f0c24,
		"TNormalLift::resetPosition": 0x801f0d60,
		"TNormalLift::TNormalLift": 0x801f0e18,
		"TRailMapObj::perform": 0x801f0eb8,
		"TRailMapObj::control": 0x801f0ef0,
		"TRailMapObj::readRailFlag": 0x801f100c,
		"TRailMapObj::getShadowType": 0x801f1064,
		"TRailMapObj::setGroundCollision": 0x801f106c,
		"TRailMapObj::load": 0x801f1108,
		"TRailMapObj::initMapObj": 0x801f11e4,
		"TRailMapObj::resetPosition": 0x801f1228,
		"TRailMapObj::calcRecycle": 0x801f12d4,
		"TRailMapObj::checkMarioRiding": 0x801f1428,
		"TRailMapObj::moveToNextNode": 0x801f1520,
		"moveToNextNode": 0x801f1520,
		"TRailMapObj::resetStep": 0x801f17d8,
		"resetStep": 0x801f17d8,
		"TRailMapObj::initGraphTracer": 0x801f1858,
		"initGraphTracer": 0x801f1858,
		"TRailMapObj::TRailMapObj": 0x801f19cc,
		"TFluffManager::TFluffManager": 0x801f1c08,
		"TFluffManager::load": 0x801f1c84,
		"TFluffManager::loadAfter": 0x801f1e18,
		"TFluffManager::control": 0x801f21dc,
		"TFluff::TFluff": 0x801f2548,
		"TFluff::initMapObj": 0x801f25d4,
		"TFluff::appear": 0x801f2610,
		"TFluff::control": 0x801f2804,
		"TFluff::kill": 0x801f2b34,
		"TFluff::move": 0x801f2b98,
		"TFluff::touchWater": 0x801f2dd4,
		"TGoalFlag::initMapObj": 0x801f2e60,
		"TGoalFlag::touchActor": 0x801f2e80,
		"TSwingBoard::TSwingBoard": 0x801f2f64,
		"TSwingBoard::load": 0x801f300c,
		"TSwingBoard::control": 0x801f3228,
		"TSwingBoard::draw": 0x801f351c,
		"TSwingBoard::initDraw": 0x801f3630,
		"TSwingBoard::drawOneRope": 0x801f383c,
		"THangingBridge::THangingBridge": 0x801f39d8,
		"THangingBridge::loadAfter": 0x801f3a5c,
		"THangingBridge::perform": 0x801f3ff8,
		"THangingBridge::initDraw": 0x801f40fc,
		"THangingBridge::drawRopeBetweenBoards": 0x801f4350,
		"drawRopeBetweenBoards": 0x801f4350,
		"THangingBridge::drawUpper": 0x801f4a8c,
		"THangingBridge::drawLowerPlus": 0x801f4c70,
		"drawLowerPlus": 0x801f4c70,
		"THangingBridge::drawLowerMinus": 0x801f4eec,
		"drawLowerMinus": 0x801f4eec,
		"THangingBridgeBoard::THangingBridgeBoard": 0x801f5160,
		"THangingBridgeBoard::initMapObj": 0x801f51fc,
		"THangingBridgeBoard::setGroundCollision": 0x801f5240,
		"THangingBridgeBoard::calcDefaultMtx": 0x801f5334,
		"THangingBridgeBoard::control": 0x801f539c,
		"THangingBridgeBoard::drawOneRope": 0x801f5614,
		"TJumpMushroom::load": 0x801f57a0,
		"TJumpMushroom::receiveMessage": 0x801f5804,
		"TMapObjMonteRoot::initMapObj": 0x801f582c,
		"TFluff::getRadiusAtY": 0x801f5904,
		"TGoalFlag::getRadiusAtY": 0x801f5990,
		"THangingBridge::~THangingBridge": 0x801f5a1c,
		"MoveBG::__sinit_MapObjMonte_cpp": 0x801f5c34,
		"__sinit_MapObjMonte_cpp": 0x801f5c34,
		"TMapObjTree::getRadiusAtY": 0x801f6004,
		"TMapObjTreeScale::TMapObjTreeScale": 0x801f6030,
		"TMapObjTreeScale::loadAfter": 0x801f62b8,
		"TMapObjTreeScale::control": 0x801f63f4,
		"TMapObjTreeScale::touchWater": 0x801f67b0,
		"TMapObjTree::TMapObjTree": 0x801f683c,
		"TMapObjTree::initMapObj": 0x801f68b4,
		"TMapObjTree::initEach": 0x801f6a64,
		"initEach": 0x801f6a64,
		"TMapObjTree::perform": 0x801f6bd8,
		"TMapObjTree::controlLeaf": 0x801f6c74,
		"controlLeaf": 0x801f6c74,
		"TMapObjTree::touchPlayer": 0x801f6e30,
		"TMapObjLeaf::TMapObjLeaf": 0x801f6ef4,
		"MoveBG::__sinit_MapObjTree_cpp": 0x801f6f8c,
		"__sinit_MapObjTree_cpp": 0x801f6f8c,
		"TMapObjSteam::load": 0x801f7334,
		"TMapObjSteam::control": 0x801f7390,
		"TJointCoin::TJointCoin": 0x801f73bc,
		"TJointCoin::initMapObj": 0x801f7414,
		"TJointCoin::nameIsObj": 0x801f75e0,
		"TJointCoin::loadAfter": 0x801f761c,
		"TJointCoin::makeObjFromJointName": 0x801f76fc,
		"TJointCoin::makeObj": 0x801f7820,
		"makeObj": 0x801f7820,
		"TJointCoin::control": 0x801f79c4,
		"TMapObjNail::TMapObjNail": 0x801f7ae0,
		"TMapObjNail::receiveMessage": 0x801f7b2c,
		"MoveBG::__sinit_MapObjEx_cpp": 0x801f7d0c,
		"__sinit_MapObjEx_cpp": 0x801f7d0c,
		"TPoolManager::TPoolManager": 0x801f8020,
		"TPoolManager::subWaterLevel": 0x801f8060,
		"subWaterLevel": 0x801f8060,
		"TPoolManager::getWaterLevel": 0x801f8108,
		"getWaterLevel": 0x801f8108,
		"TPool::TPool": 0x801f8170,
		"TPool::load": 0x801f81ec,
		"TPool::makeObjAppeared": 0x801f8230,
		"TPool::draw": 0x801f8264,
		"TPoolManager::~TPoolManager": 0x801f8464,
		"MoveBG::__sinit_Pool_cpp": 0x801f84f8,
		"__sinit_Pool_cpp": 0x801f84f8,
		"TBathtub::getNumKillerBurstable": 0x801f8880,
		"getNumKillerBurstable": 0x801f8880,
		"TBathtub::isKillerAttackable": 0x801f8a2c,
		"isKillerAttackable": 0x801f8a2c,
		"TBathtub::getNumKillerLaunchable": 0x801f8a48,
		"getNumKillerLaunchable": 0x801f8a48,
		"TBathtub::TBathtub": 0x801f8b8c,
		"JGeometry::SMatrix33R<float><float>::SMatrix33R": 0x801f8c7c,
		"SMatrix33R": 0x801f8c7c,
		"TBathtub::load": 0x801f8c80,
		"TBathtub::updatePosture_": 0x801f9158,
		"updatePosture_": 0x801f9158,
		"TBathtub::getNextGrip": 0x801f9754,
		"getNextGrip": 0x801f9754,
		"TBathtub::getNextJuncture": 0x801f99a4,
		"getNextJuncture": 0x801f99a4,
		"TBathtub::getNearGrip": 0x801f9be4,
		"getNearGrip": 0x801f9be4,
		"TBathtub::calcRootMatrix": 0x801f9db0,
		"TBathtub::allowsTumble": 0x801f9ee4,
		"allowsTumble": 0x801f9ee4,
		"TBathtub::startDemo": 0x801fa168,
		"TBathtub::setupCollisions_": 0x801fa404,
		"setupCollisions_": 0x801fa404,
		"TBathtub::calcBathtubData": 0x801fa898,
		"calcBathtubData": 0x801fa898,
		"TBathtub::control": 0x801fac4c,
		"TBathtub::perform": 0x801fb0f8,
		"TBathtub::getRootJointMtx": 0x801fb3fc,
		"TBathtub::receiveMessage": 0x801fb438,
		"TBathtub::getKoopaJrMtxInDemo": 0x801fb4f8,
		"getKoopaJrMtxInDemo": 0x801fb4f8,
		"TBathtub::getPeachMtxInDemo": 0x801fb514,
		"getPeachMtxInDemo": 0x801fb514,
		"TBathtub::getSubmarineMtxInDemo": 0x801fb530,
		"getSubmarineMtxInDemo": 0x801fb530,
		"TBathtub::getTakingMtx": 0x801fb54c,
		"TBathtub::tumble": 0x801fb568,
		"tumble": 0x801fb568,
		"TBathtub::getNumGripsDead": 0x801fb5f0,
		"getNumGripsDead": 0x801fb5f0,
		"TBathtub::quake": 0x801fb674,
		"quake": 0x801fb674,
		"TBathtub::hipdrop": 0x801fb7b0,
		"hipdrop": 0x801fb7b0,
		"TBathtub::loadAfter": 0x801fb894,
		"TBathtubGrip::control": 0x801fb988,
		"TBathtubGrip::calcRootMatrix": 0x801fbd1c,
		"TBathtubGrip::getRootJointMtx": 0x801fbf18,
		"TBathtubGrip::receiveMessage": 0x801fbf3c,
		"TBathtubGrip::perform": 0x801fc260,
		"TBathtubGrip::TBathtubGrip": 0x801fc330,
		"TBathtubGrip::kill": 0x801fc718,
		"TBathtubGripPartsHard::receiveMessage": 0x801fc7c8,
		"TBathtubGripPartsFragile::receiveMessage": 0x801fc804,
		"TBathtubGripParts::getRootJointMtx": 0x801fc834,
		"TBathtubParams::TBathtubParams": 0x801fc87c,
		"MoveBG::__sinit_MapObjCorona_cpp": 0x801fcef0,
		"__sinit_MapObjCorona_cpp": 0x801fcef0,
		"TJumpBase::control": 0x801fd298,
		"TJumpBase::calcRootMatrix": 0x801fd7ac,
		"TJumpBase::getRootJointMtx": 0x801fd85c,
		"TJumpBase::receiveMessage": 0x801fd86c,
		"TJumpBase::ensureTakeSituation": 0x801fd9d4,
		"TJumpBase::initMapObj": 0x801fda18,
		"TJumpBase::TJumpBase": 0x801fda88,
		"TMushroom1up::perform": 0x801fdad4,
		"TMushroom1up::control": 0x801fdbb4,
		"TMushroom1up::load": 0x801fe02c,
		"TMushroom1up::initMapObj": 0x801fe068,
		"TMushroom1up::makeObjAppeared": 0x801fe0e8,
		"TMushroom1up::touchPlayer": 0x801fe1fc,
		"TMushroom1up::TMushroom1up": 0x801fe294,
		"MoveBG::__sinit_MapObjItem2_cpp": 0x801fe384,
		"__sinit_MapObjItem2_cpp": 0x801fe384,
		"TWoodBox::TWoodBox": 0x801fe72c,
		"TWoodBox::loadAfter": 0x801fe858,
		"TWoodBox::kill": 0x801fe958,
		"TBreakHideObj::initMapObj": 0x801fec40,
		"TBreakHideObj::control": 0x801fecf8,
		"TBreakHideObj::receiveMessage": 0x801fed74,
		"TBreakHideObj::kill": 0x801fee40,
		"THideObjPictureTwin::THideObjPictureTwin": 0x801feea0,
		"THideObjPictureTwin::initMapObj": 0x801ff018,
		"THideObjPictureTwin::loadAfter": 0x801ff060,
		"THideObjPictureTwin::afterFinishedAnim": 0x801ff138,
		"TWaterHitPictureHideObj::TWaterHitPictureHideObj": 0x801ff2ec,
		"TWaterHitPictureHideObj::load": 0x801ff398,
		"TWaterHitPictureHideObj::loadAfter": 0x801ff554,
		"TWaterHitPictureHideObj::receiveMessage": 0x801ff8b8,
		"TWaterHitPictureHideObj::control": 0x801ffa50,
		"TWaterHitPictureHideObj::touchActor": 0x801ffb28,
		"TWaterHitPictureHideObj::touchWater": 0x801ffb58,
		"TWaterHitPictureHideObj::forward": 0x801ffcac,
		"forward": 0x801ffcac,
		"TWaterHitPictureHideObj::afterFinishedAnim": 0x801ffd88,
		"THipDropHideObj::touchPlayer": 0x801ffe74,
		"TFruitBasketEvent::TFruitBasketEvent": 0x801ffed4,
		"TFruitBasketEvent::reset": 0x80200094,
		"TFruitBasketEvent::getFruitNum": 0x802000b0,
		"getFruitNum": 0x802000b0,
		"TFruitBasketEvent::countFruit": 0x802000c0,
		"TFruitBasket::loadAfter": 0x802001a4,
		"TFruitBasket::touchFruit": 0x802002cc,
		"TFruitBasket::countFruit": 0x80200368,
		"TFruitHitHideObj::load": 0x80200514,
		"TFruitHitHideObj::touchActor": 0x802005a0,
		"TFruitHitHideObj::touchFruit": 0x802005fc,
		"TWaterHitHideObj::load": 0x80200690,
		"TWaterHitHideObj::touchWater": 0x8020071c,
		"THideObj::touchPlayer": 0x80200780,
		"THideObjBase::THideObjBase": 0x802007ec,
		"THideObjBase::load": 0x80200854,
		"THideObjBase::loadAfter": 0x802008e0,
		"THideObjBase::receiveMessage": 0x802009d8,
		"THideObjBase::emitEffect": 0x80200a6c,
		"THideObjBase::appearObjFromPoint": 0x80200aa4,
		"appearObjFromPoint": 0x80200aa4,
		"THideObjBase::appearObj": 0x80200bfc,
		"appearObj": 0x80200bfc,
		"THideObjPictureTwin::getObjAppearPos": 0x80200ce4,
		"MoveBG::__sinit_MapObjHide_cpp": 0x80200f60,
		"__sinit_MapObjHide_cpp": 0x80200f60,
		"TLampTrapIron::perform": 0x80201338,
		"TLampTrapIron::control": 0x802013dc,
		"TLampTrapIron::receiveMessage": 0x80201464,
		"TLampTrapIron::loadAfter": 0x80201508,
		"TLampTrapIron::initMapObj": 0x80201638,
		"TLampTrapIron::TLampTrapIron": 0x80201680,
		"TLampTrapIronHit::perform": 0x802016d4,
		"TLampTrapIronHit::receiveMessage": 0x802017b0,
		"TLampTrapSpike::perform": 0x802017e0,
		"TLampTrapSpike::control": 0x80201840,
		"TLampTrapSpike::receiveMessage": 0x80201c8c,
		"TLampTrapSpike::loadAfter": 0x80201cac,
		"TLampTrapSpike::initMapObj": 0x80201ddc,
		"TLampTrapSpike::TLampTrapSpike": 0x80201e14,
		"TLampTrapSpikeHit::perform": 0x80201e6c,
		"TLampTrapSpikeHit::receiveMessage": 0x80201f50,
		"MoveBG::__sinit_MapObjTrap_cpp": 0x8020210c,
		"__sinit_MapObjTrap_cpp": 0x8020210c,
		"TJointModel::getJ3DModelDataFlag": 0x80187ea0,
		"TJointObj::newJointObj": 0x80187ea8,
		"TJointModel::TJointModel": 0x80187ee8,
		"TJointModel::initJointModel": 0x80187f38,
		"TJointModel::initActor": 0x80187f84,
		"initActor": 0x80187f84,
		"TJointModel::perform": 0x801880c8,
		"Map::__sinit_JointModel_cpp": 0x8018810c,
		"__sinit_JointModel_cpp": 0x8018810c,
		"TJointModelManager::~TJointModelManager": 0x80188408,
		"JGadget::TList<16MActorSubAnmInfo,Q27JGadget30TAllocator<16MActorSubAnmInfo>>::iterator::iterator": 0x8018858c,
		"TJointModelManager::newJointModel": 0x80188594,
		"TJointModelManager::TJointModelManager": 0x801885d4,
		"TJointModelManager::initJointModel": 0x801886c4,
		"TJointModelManager::perform": 0x801887ac,
		"Map::__sinit_JointModelManager_cpp": 0x8018881c,
		"__sinit_JointModelManager_cpp": 0x8018881c,
		"TJointObj::TJointObj": 0x80188b18,
		"TJointObj::initJointObj": 0x80188b48,
		"initJointObj": 0x80188b48,
		"TJointObj::initChildren": 0x80188bfc,
		"initChildren": 0x80188bfc,
		"TJointObj::kill": 0x80188ce4,
		"TJointObj::alive": 0x80188dcc,
		"alive": 0x80188dcc,
		"TJointObj::sleep": 0x80188e94,
		"TJointObj::awake": 0x80188f8c,
		"TJointObj::sit": 0x80189068,
		"sit": 0x80189068,
		"TJointObj::stand": 0x80189138,
		"stand": 0x80189138,
		"Map::__sinit_JointObj_cpp": 0x80189208,
		"__sinit_JointObj_cpp": 0x80189208,
		"TMap::~TMap": 0x80189504,
		"TMap::TMap": 0x80189578,
		"TMap::load": 0x80189678,
		"TMap::loadAfter": 0x801896fc,
		"TMap::perform": 0x80189720,
		"TMap::changeModel": 0x80189804,
		"TMap::checkGroundExactY": 0x8018988c,
		"checkGroundExactY": 0x8018988c,
		"TMap::checkGroundIgnoreWaterThrough": 0x80189920,
		"checkGroundIgnoreWaterThrough": 0x80189920,
		"TMap::checkRoofIgnoreWaterThrough": 0x801899ac,
		"checkRoofIgnoreWaterThrough": 0x801899ac,
		"TMap::isTouchedWallsAndMoveXZ": 0x801899d8,
		"isTouchedWallsAndMoveXZ": 0x801899d8,
		"TMap::isTouchedOneWallAndMoveXZ": 0x80189a10,
		"isTouchedOneWallAndMoveXZ": 0x80189a10,
		"TMap::isTouchedOneWall": 0x80189abc,
		"isTouchedOneWall": 0x80189abc,
		"TMap::intersectLine": 0x80189b5c,
		"TMap::isInArea": 0x80189b80,
		"TMap::getIllegalCheckData": 0x80189bc4,
		"getIllegalCheckData": 0x80189bc4,
		"TMap::update": 0x80189bd0,
		"Map::initStage": 0x80189e34,
		"initStage": 0x80189e34,
		"Map::initStageCommon": 0x80189fe4,
		"initStageCommon": 0x80189fe4,
		"Map::initPinnaParco": 0x8018a2c4,
		"initPinnaParco": 0x8018a2c4,
		"Map::initMare": 0x8018a3a8,
		"initMare": 0x8018a3a8,
		"Map::initMonte": 0x8018a698,
		"initMonte": 0x8018a698,
		"Map::__sinit_Map_cpp": 0x8018a858,
		"__sinit_Map_cpp": 0x8018a858,
		"TMapCollisionData::polygonIsInGrid": 0x8018ab54,
		"polygonIsInGrid": 0x8018ab54,
		"Map::checkLinesCollision": 0x8018b18c,
		"checkLinesCollision": 0x8018b18c,
		"TMapCollisionData::intersectLine": 0x8018b264,
		"Map::bgIntersectLine": 0x8018bdc4,
		"bgIntersectLine": 0x8018bdc4,
		"TMapCollisionData::checkGround": 0x8018c18c,
		"TMapCollisionData::checkGroundList": 0x8018c334,
		"checkGroundList": 0x8018c334,
		"TMapCollisionData::checkRoof": 0x8018c4cc,
		"TMapCollisionData::checkRoofList": 0x8018c628,
		"checkRoofList": 0x8018c628,
		"TMapCollisionData::checkWalls": 0x8018c770,
		"TMapCollisionData::checkWallList": 0x8018c890,
		"checkWallList": 0x8018c890,
		"Map::__sinit_MapCheck_cpp": 0x8018cccc,
		"__sinit_MapCheck_cpp": 0x8018cccc,
		"TMapCollisionData::TMapCollisionData": 0x8018cfc8,
		"TMapCollisionData::init": 0x8018d0b4,
		"TBGCheckListRoot::TBGCheckListRoot": 0x8018d4dc,
		"TMapCollisionData::initMoveCollision": 0x8018d520,
		"initMoveCollision": 0x8018d520,
		"TBGCheckListWarp::TBGCheckListWarp": 0x8018d55c,
		"TBGCheckList::TBGCheckList": 0x8018d590,
		"TBGCheckListWarp::setPreNode": 0x8018d5ac,
		"TBGCheckList::setPreNode": 0x8018d5b4,
		"Map::__sinit_MapCollisionData_cpp": 0x8018d5b8,
		"__sinit_MapCollisionData_cpp": 0x8018d5b8,
		"TMapCollisionWarp::TMapCollisionWarp": 0x8018d8bc,
		"TMapCollisionWarp::init": 0x8018d94c,
		"TMapCollisionWarp::remove": 0x8018d9b8,
		"TMapCollisionWarp::setUpTrans": 0x8018da28,
		"TMapCollisionWarp::setUp": 0x8018dac0,
		"TMapCollisionMove::TMapCollisionMove": 0x8018db90,
		"TMapCollisionMove::moveTrans": 0x8018dd24,
		"TMapCollisionMove::move": 0x8018dd88,
		"TMapCollisionStatic::TMapCollisionStatic": 0x8018de2c,
		"TMapCollisionStatic::init": 0x8018deb8,
		"TMapCollisionStatic::setUp": 0x8018df34,
		"TMapCollisionBase::init": 0x8018df88,
		"TMapCollisionBase::setAllActor": 0x8018e140,
		"setAllActor": 0x8018e140,
		"TMapCollisionBase::setAllData": 0x8018e170,
		"setAllData": 0x8018e170,
		"TMapCollisionBase::setAllBGType": 0x8018e1a0,
		"setAllBGType": 0x8018e1a0,
		"TMapCollisionBase::setVertexData": 0x8018e1cc,
		"setVertexData": 0x8018e1cc,
		"TMapCollisionMove::moveSRT": 0x8018e22c,
		"TMapCollisionStatic::remove": 0x8018e318,
		"TMapCollisionManager::TMapCollisionManager": 0x8018e31c,
		"TMapCollisionManager::init": 0x8018e394,
		"TMapCollisionManager::createCollision": 0x8018e4fc,
		"createCollision": 0x8018e4fc,
		"TMapCollisionManager::changeCollision": 0x8018e5e0,
		"changeCollision": 0x8018e5e0,
		"TMapDrawWall::~TMapDrawWall": 0x8018e658,
		"TMap::draw": 0x8018e6cc,
		"TMapDrawWall::TMapDrawWall": 0x8018e6d0,
		"TMapDrawWall::load": 0x8018e750,
		"TMapDrawWall::perform": 0x8018e78c,
		"Map::__sinit_MapDraw_cpp": 0x8018eab4,
		"__sinit_MapDraw_cpp": 0x8018eab4,
		"TMapEvent::startControl": 0x8018ee34,
		"TMapEvent::getBuilding": 0x8018ee40,
		"TMapEvent::TMapEvent": 0x8018ee5c,
		"TMapEvent::load": 0x8018ef1c,
		"TMapEvent::perform": 0x8018ef5c,
		"TMapEvent::finishControl": 0x8018f048,
		"TMapEvent::isFinishedAll": 0x8018f09c,
		"Map::__sinit_MapEvent_cpp": 0x8018f0cc,
		"__sinit_MapEvent_cpp": 0x8018f0cc,
		"TMapEventSinkShadowMario::~TMapEventSinkShadowMario": 0x8018f3c8,
		"TMapEventSink::watch": 0x8018f45c,
		"TMapEventSinkShadowMario::initWithBuildingNum": 0x8018f464,
		"TMapEventSinkShadowMario::initBuilding": 0x8018f534,
		"TMapEventSinkShadowMario::loadAfter": 0x8018f5f4,
		"TMapEventSinkShadowMario::raiseBuilding": 0x8018f6bc,
		"raiseBuilding": 0x8018f6bc,
		"TMapEventSinkShadowMario::rising": 0x8018f6ec,
		"J3DTransformInfo::operator_=": 0x8018f778,
		"TMapEventSinkBianco::load": 0x8018f7c4,
		"TMapEventSinkBianco::loadAfter": 0x8018f8bc,
		"TMapEventSinkBianco::watch": 0x8018fa34,
		"TMapEventSinkBianco::startControl": 0x8018fb48,
		"TMapEventSinkBianco::control": 0x8018fcd0,
		"TMapEventSinkBianco::rising": 0x8018fd54,
		"TMapEventSinkBianco::finishControl": 0x8018fde0,
		"TMapEventSinkInPollutionReset::loadAfter": 0x8018ffb4,
		"TMapEventSinkInPollutionReset::makeBuildingRecovered": 0x801900e8,
		"TMapEventSinkInPollution::loadAfter": 0x80190284,
		"TMapEventSinkInPollution::initBuriedBuilding": 0x8019031c,
		"initBuriedBuilding": 0x8019031c,
		"TMapEventSinkInPollution::watch": 0x801903c4,
		"TMapEventSink::TMapEventSink": 0x80190474,
		"TMapEventSink::load": 0x80190510,
		"TMapEventSink::initWithBuildingNum": 0x8019061c,
		"TMapEventSink::initBuilding": 0x801906cc,
		"TMapEventSink::startControl": 0x8019077c,
		"TMapEventSink::control": 0x80190938,
		"TMapEventSink::rising": 0x80190a98,
		"TMapEventSink::finishControl": 0x80190b34,
		"TMapEventSink::makeBuildingRecovered": 0x80190bb8,
		"TMapEventSink::isFinishedAll": 0x80190ce8,
		"TMapEventSink::getPollutionObj": 0x80190d24,
		"getPollutionObj": 0x80190d24,
		"TMapEventSink::getSinkOffsetY": 0x80190d58,
		"getSinkOffsetY": 0x80190d58,
		"TMapEventSink::isBuried": 0x80190d6c,
		"isBuried": 0x80190d6c,
		"TMapEventSink::getBuilding": 0x80190d88,
		"TMapEventSinkBianco::~TMapEventSinkBianco": 0x80190dac,
		"Map::__sinit_MapEventSink_cpp": 0x80190ffc,
		"__sinit_MapEventSink_cpp": 0x80190ffc,
		"TMapCollisionBase::initCheckData": 0x801912f8,
		"initCheckData": 0x801912f8,
		"TMapCollisionBase::initAllCheckData": 0x801913ac,
		"initAllCheckData": 0x801913ac,
		"TMapCollisionBase::update": 0x801915e8,
		"TMapCollisionBase::updateTrans": 0x8019167c,
		"updateTrans": 0x8019167c,
		"TMapCollisionBase::setCheckData": 0x80191814,
		"setCheckData": 0x80191814,
		"TMapCollisionMove::setList": 0x80191a78,
		"setList": 0x80191a78,
		"TBGCheckData::setVertex": 0x80191adc,
		"setVertex": 0x80191adc,
		"Map::__sinit_MapMakeData_cpp": 0x80191ca4,
		"__sinit_MapMakeData_cpp": 0x80191ca4,
		"TMapCollisionData::removeCheckListData": 0x80191fa0,
		"removeCheckListData": 0x80191fa0,
		"TMapCollisionData::updateCheckListNode": 0x80192200,
		"updateCheckListNode": 0x80192200,
		"TMapCollisionData::addCheckDataToGrid": 0x80192300,
		"addCheckDataToGrid": 0x80192300,
		"TMapCollisionData::getGridArea": 0x80192878,
		"getGridArea": 0x80192878,
		"Map::addGroundNode": 0x80192a58,
		"addGroundNode": 0x80192a58,
		"Map::addRoofNode": 0x80192aa0,
		"addRoofNode": 0x80192aa0,
		"Map::addWallNode": 0x80192ae8,
		"addWallNode": 0x80192ae8,
		"Map::addAfterPreNode": 0x80192b30,
		"addAfterPreNode": 0x80192b30,
		"TMapCollisionData::allocCheckList": 0x80192bc4,
		"allocCheckList": 0x80192bc4,
		"TMapCollisionData::getEntryID": 0x80192c30,
		"getEntryID": 0x80192c30,
		"TMapCollisionData::allocCheckData": 0x80192c74,
		"allocCheckData": 0x80192c74,
		"TMirrorMapDrawBuf::~TMirrorMapDrawBuf": 0x80192c90,
		"TMirrorMapDrawBuf::perform": 0x80192d14,
		"TMirrorModelManager::TMirrorModelManager": 0x80192d60,
		"TMirrorModelManager::load": 0x80192de8,
		"TMirrorModelManager::loadAfter": 0x80192f94,
		"TMirrorModelManager::perform": 0x801930a4,
		"JGeometry::TVec3<float><float>::scaleAdd": 0x801934dc,
		"scaleAdd": 0x801934dc,
		"TMirrorModel::calc": 0x80193510,
		"TMirrorModelManager::isInMirror": 0x80193524,
		"isInMirror": 0x80193524,
		"TMirrorModelManager::isUpperThanMirrorPlane": 0x80193568,
		"isUpperThanMirrorPlane": 0x80193568,
		"TMirrorModel::getD": 0x80193648,
		"getD": 0x80193648,
		"TMirrorModel::getNormalVec": 0x80193650,
		"getNormalVec": 0x80193650,
		"TMirrorModelObj::init": 0x80193658,
		"TMirrorModelObj::calc": 0x801937a8,
		"TMirrorModelObj::setPlane": 0x801937dc,
		"TMirrorModel::TMirrorModel": 0x80193890,
		"TMirrorModel::init": 0x801938cc,
		"TMirrorModel::initPlaneInfo": 0x801939f4,
		"initPlaneInfo": 0x801939f4,
		"TMirrorModel::setPlane": 0x80193bd8,
		"TMirrorCamera::TMirrorCamera": 0x80193c78,
		"TMirrorCamera::drawSetting": 0x80193f20,
		"drawSetting": 0x80193f20,
		"TMirrorCamera::perform": 0x80193fbc,
		"TMirrorModelManager::~TMirrorModelManager": 0x80194074,
		"Map::__sinit_MapMirror_cpp": 0x80194154,
		"__sinit_MapMirror_cpp": 0x80194154,
		"TMapModel::getJ3DModelDataFlag": 0x80194458,
		"TMapModelManager::TMapModelManager": 0x80194460,
		"TMapModelManager::init": 0x801944a4,
		"TMapModel::initJointModel": 0x80194534,
		"TMapModel::initUnderpass": 0x801945c4,
		"initUnderpass": 0x801945c4,
		"TMapModel::perform": 0x80194844,
		"TMapModelManager::~TMapModelManager": 0x801949e4,
		"TMapModelManager::newJointModel": 0x80194b3c,
		"Map::__sinit_MapModel_cpp": 0x80194ba4,
		"__sinit_MapModel_cpp": 0x80194ba4,
		"TMapWarp::TMapWarp": 0x80194ea0,
		"TMapWarp::init": 0x80194ebc,
		"TMapWarp::TMapWarpInfo::TMapWarpInfo": 0x801951e4,
		"TMapWarp::initModel": 0x801951e8,
		"TMapWarp::watchToWarp": 0x80195280,
		"watchToWarp": 0x80195280,
		"TMapWarp::changeModel": 0x801955a0,
		"Map::__sinit_MapWarp_cpp": 0x8019563c,
		"__sinit_MapWarp_cpp": 0x8019563c,
		"TMapObjSoundGroup::~TMapObjSoundGroup": 0x80195938,
		"TMapObjSoundGroup::TMapObjSoundGroup": 0x801959ac,
		"TMapObjSoundGroup::load": 0x80195a20,
		"TMapObjSoundGroup::perform": 0x80195b14,
		"TMapModelActor::perform": 0x80195ca4,
		"TMapStaticObj::TMapStaticObj": 0x80195d80,
		"TMapStaticObj::load": 0x80195de4,
		"TMapStaticObj::loadAfter": 0x80195e28,
		"TMapStaticObj::init": 0x80195e6c,
		"TMapStaticObj::initModel": 0x80196264,
		"TMapStaticObj::initUnique": 0x80196394,
		"TMapStaticObj::perform": 0x80196614,
		"TMapStaticObj::getModelData": 0x80196904,
		"getModelData": 0x80196904,
		"Map::__sinit_MapStaticObject_cpp": 0x80196a1c,
		"__sinit_MapStaticObject_cpp": 0x80196a1c,
		"TMapWire::TMapWire": 0x80196d28,
		"TMapWire::init": 0x80196da4,
		"TMapWire::getPointPosOnWire": 0x801974c0,
		"getPointPosOnWire": 0x801974c0,
		"TMapWire::getPosInWire": 0x80197650,
		"TMapWire::move": 0x801977ec,
		"TMapWire::calcViewAndDBEntry": 0x80197a6c,
		"calcViewAndDBEntry": 0x80197a6c,
		"TMapWire::setFootPointsAtHanged": 0x80197abc,
		"setFootPointsAtHanged": 0x80197abc,
		"TMapWire::getPointPosAtHanged": 0x80197d54,
		"getPointPosAtHanged": 0x80197d54,
		"TMapWire::release": 0x80197df8,
		"TMapWire::getPointPowerAtReleased": 0x8019823c,
		"getPointPowerAtReleased": 0x8019823c,
		"TMapWire::drawUpper": 0x80198278,
		"TMapWire::drawLower": 0x801983a8,
		"drawLower": 0x801983a8,
		"TMapWirePoint::TMapWirePoint": 0x801985b4,
		"Map::__sinit_MapWire_cpp": 0x801985dc,
		"__sinit_MapWire_cpp": 0x801985dc,
		"TMapWireManager::~TMapWireManager": 0x801988d8,
		"TMapWireManager::TMapWireManager": 0x8019894c,
		"TMapWireManager::load": 0x80198a00,
		"TMapWireManager::loadAfter": 0x80198bb0,
		"JGadget::TList_pointer<THitActor*>::insert": 0x80198cb8,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::getChildren": 0x80198d04,
		"getChildren": 0x80198d04,
		"JDrama::TNameRef::search": 0x80198d0c,
		"JDrama::TNameRefGen::getRootNameRef": 0x80198d64,
		"getRootNameRef": 0x80198d64,
		"JDrama::TNameRefGen::getInstance": 0x80198d6c,
		"getInstance": 0x80198d6c,
		"TMapWireManager::perform": 0x80198e10,
		"TMapWireManager::getPointPosInNthWire": 0x80198fc8,
		"getPointPosInNthWire": 0x80198fc8,
		"TMapWireManager::getWireNo": 0x80199028,
		"getWireNo": 0x80199028,
		"TMapWireActorManager::doActorToWire": 0x8019904c,
		"doActorToWire": 0x8019904c,
		"Map::initDraw": 0x80199230,
		"TMapWireActor::TMapWireActor": 0x80199378,
		"TMapWireActor::receiveMessage": 0x801993e4,
		"TMapWireActor::getTipPoints": 0x80199418,
		"getTipPoints": 0x80199418,
		"TMapWireActor::getPosInWire": 0x80199454,
		"TMapWireActor::getTakingMtx": 0x801995fc,
		"Map::__sinit_MapWireManager_cpp": 0x80199604,
		"__sinit_MapWireManager_cpp": 0x80199604,
		"TMapXlu::TMapXlu": 0x80199914,
		"TMapXlu::init": 0x80199924,
		"TMapXlu::changeXluJoint": 0x80199a38,
		"changeXluJoint": 0x80199a38,
		"TMapXlu::changeNormalJoint": 0x80199b50,
		"changeNormalJoint": 0x80199b50,
		"Map::__sinit_MapXlu_cpp": 0x80199c50,
		"__sinit_MapXlu_cpp": 0x80199c50,
		"TPollutionLayer::action": 0x80199f4c,
		"TPollutionLayer::getPlaneType": 0x8019a318,
		"TPollutionLayer::fire": 0x8019a320,
		"fire": 0x8019a320,
		"TPollutionLayer::getPollutedPos": 0x8019a470,
		"getPollutedPos": 0x8019a470,
		"TPollutionLayer::getPollutedPosNear": 0x8019a598,
		"getPollutedPosNear": 0x8019a598,
		"TPollutionLayer::getTexPosS": 0x8019a7dc,
		"TPollutionLayer::isInArea": 0x8019a808,
		"Map::__sinit_PollutionAction_cpp": 0x8019a848,
		"__sinit_PollutionAction_cpp": 0x8019a848,
		"TPollutionRevivalTexStamp::TPollutionRevivalTexStamp": 0x8019ab44,
		"TPollutionTexStamp::TPollutionTexStamp": 0x8019ab70,
		"TPollutionLayerTaskInfo::TPollutionLayerTaskInfo": 0x8019ab90,
		"TPollutionTexStamp::pushTask": 0x8019abac,
		"pushTask": 0x8019abac,
		"TPollutionCounterLayer::TPollutionCounterLayer": 0x8019ac28,
		"TPollutionJointObjTaskInfo::TPollutionJointObjTaskInfo": 0x8019acf8,
		"TPollutionModelTaskInfo::TPollutionModelTaskInfo": 0x8019ad0c,
		"TPollutionCounterLayer::init": 0x8019ad1c,
		"TPollutionCounterLayer::offLayer": 0x8019afa0,
		"offLayer": 0x8019afa0,
		"TPollutionCounterLayer::stampIsCleanType": 0x8019afc0,
		"stampIsCleanType": 0x8019afc0,
		"TPollutionCounterLayer::registerLayer": 0x8019afe8,
		"registerLayer": 0x8019afe8,
		"TPollutionCounterLayer::registerTexStamp": 0x8019b034,
		"registerTexStamp": 0x8019b034,
		"TPollutionCounterLayer::registerRevivalTexStamp": 0x8019b0d8,
		"registerRevivalTexStamp": 0x8019b0d8,
		"TPollutionCounterLayer::pushModelStampTask": 0x8019b120,
		"pushModelStampTask": 0x8019b120,
		"TPollutionCounterLayer::calcViewMtx": 0x8019b16c,
		"calcViewMtx": 0x8019b16c,
		"TPollutionCounterLayer::pushJointObjStampTask": 0x8019b2ec,
		"pushJointObjStampTask": 0x8019b2ec,
		"TPollutionCounterLayer::resetTask": 0x8019b334,
		"resetTask": 0x8019b334,
		"TPollutionCounterLayer::countTexDegree": 0x8019b3a0,
		"countTexDegree": 0x8019b3a0,
		"TPollutionCounterLayer::cleanProhibitArea": 0x8019b5f4,
		"cleanProhibitArea": 0x8019b5f4,
		"TPollutionCounterLayer::drawRevivalTexStamp": 0x8019b7d8,
		"drawRevivalTexStamp": 0x8019b7d8,
		"Map::initGXforStamp": 0x8019bac4,
		"initGXforStamp": 0x8019bac4,
		"Map::doTask": 0x8019bd90,
		"doTask": 0x8019bd90,
		"TPollutionCounterLayer::drawJointObjStamp": 0x8019bf80,
		"drawJointObjStamp": 0x8019bf80,
		"Map::initGXforPollutionLayer": 0x8019c208,
		"initGXforPollutionLayer": 0x8019c208,
		"Map::drawTex": 0x8019c5c8,
		"drawTex": 0x8019c5c8,
		"TPollutionCounterObj::TPollutionCounterObj": 0x8019c6ac,
		"TPollutionCounterObj::init": 0x8019c6ec,
		"TPollutionCounterObj::registerPollutionObj": 0x8019c970,
		"registerPollutionObj": 0x8019c970,
		"TPollutionCounterObj::countObjDegree": 0x8019ca18,
		"countObjDegree": 0x8019ca18,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setEular": 0x8019ccec,
		"Map::initDrawObjGX": 0x8019cd94,
		"initDrawObjGX": 0x8019cd94,
		"TPollutionCounterBase::drawSyncCallback": 0x8019cf4c,
		"Map::drawBlack": 0x8019cfd4,
		"drawBlack": 0x8019cfd4,
		"TPollutionCounterObj::getCounterNo": 0x8019d160,
		"TPollutionCounterObj::getTokenNo": 0x8019d168,
		"TPollutionCounterLayer::getCounterNo": 0x8019d170,
		"TPollutionCounterLayer::getTokenNo": 0x8019d178,
		"Map::__sinit_PollutionCount_cpp": 0x8019d180,
		"__sinit_PollutionCount_cpp": 0x8019d180,
		"TPollutionManager::~TPollutionManager": 0x8019d47c,
		"TPollutionManager::TPollutionManager": 0x8019d518,
		"TPollutionManager::load": 0x8019d58c,
		"TPollutionManager::setDataAddress": 0x8019d6f0,
		"setDataAddress": 0x8019d6f0,
		"TPollutionManager::newJointModel": 0x8019d73c,
		"TPollutionManager::perform": 0x8019d8c8,
		"TPollutionManager::cleanedAll": 0x8019d960,
		"cleanedAll": 0x8019d960,
		"TPollutionManager::isPolluted": 0x8019da6c,
		"TPollutionManager::getPollutionDegree": 0x8019db20,
		"getPollutionDegree": 0x8019db20,
		"TPollutionManager::getPollutionType": 0x8019dc18,
		"getPollutionType": 0x8019dc18,
		"TPollutionManager::stampGround": 0x8019dcd4,
		"stampGround": 0x8019dcd4,
		"TPollutionManager::clean": 0x8019ddb4,
		"clean": 0x8019ddb4,
		"TPollutionManager::stamp": 0x8019de84,
		"TPollutionManager::stampModel": 0x8019df44,
		"TPollutionLayerWallMinusX::getPlaneType": 0x8019dfe4,
		"TPollutionLayerWallMinusX::getTexPosS": 0x8019dfec,
		"TPollutionLayerWallPlusX::isInArea": 0x8019e018,
		"TPollutionLayerWallPlusX::isInAreaSize": 0x8019e058,
		"TPollutionLayerWallBase::getTexPosT": 0x8019e0a8,
		"TPollutionLayer::getTexResource": 0x8019e0d4,
		"TPollutionLayer::newJointObj": 0x8019e0e4,
		"TPollutionLayer::getJ3DModelDataFlag": 0x8019e124,
		"TPollutionLayerWallMinusZ::getPlaneType": 0x8019e12c,
		"TPollutionLayerWallMinusZ::getTexPosS": 0x8019e134,
		"TPollutionLayerWallPlusZ::isInArea": 0x8019e160,
		"TPollutionLayerWallPlusZ::isInAreaSize": 0x8019e1a0,
		"Map::__sinit_PollutionManager_cpp": 0x8019e1f0,
		"__sinit_PollutionManager_cpp": 0x8019e1f0,
		"TPollutionObj::TPollutionObj": 0x8019e4ec,
		"TPollutionObj::initAreaInfo": 0x8019e544,
		"initAreaInfo": 0x8019e544,
		"TPollutionLayer::getTexPosT": 0x8019e690,
		"TPollutionObj::isCleaned": 0x8019e6bc,
		"isCleaned": 0x8019e6bc,
		"TPollutionObj::updateDepthMap": 0x8019e6dc,
		"updateDepthMap": 0x8019e6dc,
		"TPollutionObj::getDepthFromMap": 0x8019e780,
		"getDepthFromMap": 0x8019e780,
		"TPollutionObj::newJointObj": 0x8019e9b4,
		"Map::__sinit_PollutionObj_cpp": 0x8019ea1c,
		"__sinit_PollutionObj_cpp": 0x8019ea1c,
		"TPollutionPos::TPollutionPos": 0x8019ed18,
		"TPollutionPos::init": 0x8019ed48,
		"TPollutionPos::worldToTexSize": 0x8019ed90,
		"worldToTexSize": 0x8019ed90,
		"TPollutionPos::worldToDepth": 0x8019edb0,
		"worldToDepth": 0x8019edb0,
		"TPollutionPos::isProhibit": 0x8019edd8,
		"isProhibit": 0x8019edd8,
		"TPollutionPos::isSame": 0x8019ee54,
		"TPollutionPos::getDepthWorld": 0x8019ef28,
		"getDepthWorld": 0x8019ef28,
		"TPollutionPos::getEdgeDegree": 0x8019efa4,
		"getEdgeDegree": 0x8019efa4,
		"Map::__sinit_PollutionPos_cpp": 0x8019f0f8,
		"__sinit_PollutionPos_cpp": 0x8019f0f8,
		"TShimmer::TShimmer": 0x8019f460,
		"TShimmer::load": 0x8019f5ac,
		"TShimmer::loadAfter": 0x8019f740,
		"TShimmer::perform": 0x8019f83c,
		"Map::__sinit_Shimmer_cpp": 0x8019fac4,
		"__sinit_Shimmer_cpp": 0x8019fac4,
		"TSky::TSky": 0x8019fe34,
		"TSky::load": 0x8019ff4c,
		"TSky::perform": 0x8019ffe4,
		"Map::__sinit_Sky_cpp": 0x801a033c,
		"__sinit_Sky_cpp": 0x801a033c,
		"TMapEventSirenaSink::~TMapEventSirenaSink": 0x801a0640,
		"TMapEventSirenaSink::initPollution": 0x801a06d4,
		"initPollution": 0x801a06d4,
		"TMapEventSirenaSink::makePollutionRecovered": 0x801a06d8,
		"makePollutionRecovered": 0x801a06d8,
		"TMapEventSirenaSink::TMapEventSirenaSink": 0x801a06dc,
		"TMapEventSirenaSink::load": 0x801a0740,
		"TMapEventSirenaSink::loadAfter": 0x801a0838,
		"TMapEventSirenaSink::watch": 0x801a08dc,
		"Map::__sinit_MapEventSirena_cpp": 0x801a09f4,
		"__sinit_MapEventSirena_cpp": 0x801a09f4,
		"TPollutionLayer::isInAreaSize": 0x801a0cf0,
		"TPollutionLayer::TPollutionLayer": 0x801a0d40,
		"TPollutionLayer::initJointModel": 0x801a0e00,
		"TPollutionLayer::initLayerInfo": 0x801a0fb4,
		"TPollutionLayer::initTexImage": 0x801a10b4,
		"initTexImage": 0x801a10b4,
		"TPollutionLayer::perform": 0x801a1288,
		"TPollutionLayer::isPolluted": 0x801a12e8,
		"TPollutionLayer::stamp": 0x801a1440,
		"TPollutionLayer::cleaned": 0x801a158c,
		"cleaned": 0x801a158c,
		"TPollutionLayer::appearItem": 0x801a1960,
		"appearItem": 0x801a1960,
		"TPollutionLayer::stampModel": 0x801a1964,
		"TPollutionLayerWallBase::TPollutionLayerWallBase": 0x801a19dc,
		"TPollutionLayerWallPlusX::initLayerInfo": 0x801a1a24,
		"TPollutionLayerWallPlusX::stamp": 0x801a1a78,
		"TPollutionLayerWallPlusX::getTexPosS": 0x801a1b78,
		"TPollutionLayerWallPlusZ::initLayerInfo": 0x801a1ba4,
		"TPollutionLayerWallPlusZ::stamp": 0x801a1be8,
		"TPollutionLayerWave::initJointModel": 0x801a1ce8,
		"TPollutionLayerWave::getTexResource": 0x801a1dfc,
		"TPollutionLayerWave::perform": 0x801a1e3c,
		"TPollutionLayerWave::draw": 0x801a1e7c,
		"TPollutionLayerWave::initGX": 0x801a2000,
		"initGX": 0x801a2000,
		"TPollutionLayerWallPlusX::getPlaneType": 0x801a2220,
		"TPollutionLayerWallPlusZ::getPlaneType": 0x801a2228,
		"TPollutionLayerWave::getPlaneType": 0x801a2230,
		"Map::__sinit_PollutionLayer_cpp": 0x801a2238,
		"__sinit_PollutionLayer_cpp": 0x801a2238,
		"TPollutionTest::loadAfter": 0x801a2534,
		"TPollutionTest::~TPollutionTest": 0x801a2554,
		"TPollutionTest::perform": 0x801a25c8,
		"Map::__sinit_PollutionEvent_cpp": 0x801a25cc,
		"__sinit_PollutionEvent_cpp": 0x801a25cc,
		"TMapCheckGroundPlane::TMapCheckGroundPlane": 0x801a28c8,
		"TMapCheckGroundPlane::init": 0x801a28f0,
		"TMapCheckGroundPlane::checkPlaneGround": 0x801a29b8,
		"checkPlaneGround": 0x801a29b8,
		"TMapCheckGroundPlane::getCheckData": 0x801a2aec,
		"getCheckData": 0x801a2aec,
		"Map::__sinit_MapCollisionPlane_cpp": 0x801a2b10,
		"__sinit_MapCollisionPlane_cpp": 0x801a2b10,
		"TMarineSnow::perform": 0x801a2e78,
		"TMarineSnow::loadAfter": 0x801a2ed4,
		"TMarineSnow::TMarineSnow": 0x801a2f2c,
		"TBGCheckData::TBGCheckData": 0x801a3038,
		"TBGCheckData::getPlaneType": 0x801a3090,
		"TBGCheckData::getActiveJumpPower": 0x801a3124,
		"getActiveJumpPower": 0x801a3124,
		"Map::__sinit_MapData_cpp": 0x801a3188,
		"__sinit_MapData_cpp": 0x801a3188,
		"TDolpicEventRiccoMammaGate::~TDolpicEventRiccoMammaGate": 0x801a3484,
		"TDolpicEventRiccoMammaGate::TDolpicEventRiccoMammaGate": 0x801a3518,
		"TDolpicEventRiccoMammaGate::load": 0x801a35a0,
		"TDolpicEventRiccoMammaGate::loadAfter": 0x801a3820,
		"TDolpicEventRiccoMammaGate::watch": 0x801a38f8,
		"TDolpicEventRiccoMammaGate::control": 0x801a3b08,
		"TDolpicEventRiccoMammaGate::isFinishedAll": 0x801a3cf8,
		"TDolpicEventBiancoGate::TDolpicEventBiancoGate": 0x801a3d28,
		"TDolpicEventBiancoGate::loadAfter": 0x801a3d74,
		"TDolpicEventBiancoGate::watch": 0x801a3e00,
		"TDolpicEventBiancoGate::control": 0x801a3e70,
		"TDolpicEventBiancoGate::isFinishedAll": 0x801a3f24,
		"TDolpicEventBiancoGate::~TDolpicEventBiancoGate": 0x801a3f54,
		"Map::__sinit_MapEventDolpic_cpp": 0x801a3fe8,
		"__sinit_MapEventDolpic_cpp": 0x801a3fe8,
		"TMareEventBumpyWall::TMareEventBumpyWall": 0x801a4368,
		"TMareEventBumpyWall::load": 0x801a43d0,
		"TMareEventBumpyWall::control": 0x801a44dc,
		"TMareEventBumpyWall::bumpUpX": 0x801a4588,
		"bumpUpX": 0x801a4588,
		"TMareEventBumpyWall::bumpDownX": 0x801a46d8,
		"bumpDownX": 0x801a46d8,
		"TMareEventBumpyWall::bumpUpZ": 0x801a482c,
		"bumpUpZ": 0x801a482c,
		"TMareEventBumpyWall::bumpDownZ": 0x801a497c,
		"bumpDownZ": 0x801a497c,
		"TMareEventBumpyWall::touchWater": 0x801a4acc,
		"TMareEventDepressWall::TMareEventDepressWall": 0x801a4b78,
		"TMareEventDepressWall::init1stEvent": 0x801a4c1c,
		"init1stEvent": 0x801a4c1c,
		"TMareEventDepressWall::init2ndEvent": 0x801a4cd0,
		"init2ndEvent": 0x801a4cd0,
		"TMareEventDepressWall::init3rdEvent": 0x801a4d84,
		"init3rdEvent": 0x801a4d84,
		"TMareEventDepressWall::initCommon": 0x801a4f0c,
		"initCommon": 0x801a4f0c,
		"TMareEventDepressWall::startEvent": 0x801a5384,
		"TMareEventDepressWall::perform": 0x801a543c,
		"TMareEventDepressWall::depressing": 0x801a5558,
		"depressing": 0x801a5558,
		"TMareEventDepressWall::rising": 0x801a59a4,
		"TMareEventWallRock::TMareEventWallRock": 0x801a5d0c,
		"TMareEventWallRock::load": 0x801a5d80,
		"TMareWallRock::TMareWallRock": 0x801a5f00,
		"TMareWallRock::load": 0x801a5f8c,
		"TMareWallRock::loadAfter": 0x801a5fac,
		"TMareWallRock::initEffect": 0x801a616c,
		"initEffect": 0x801a616c,
		"TMareWallRock::perform": 0x801a62f0,
		"TMareWallRock::movement": 0x801a6350,
		"TMareWallRock::appear": 0x801a66d8,
		"TMareEventDepressWall::~TMareEventDepressWall": 0x801a6870,
		"TMareEventWallRock::~TMareEventWallRock": 0x801a68e4,
		"TMareEventWallRock::perform": 0x801a6958,
		"Map::__sinit_MapEventMare_cpp": 0x801a695c,
		"__sinit_MapEventMare_cpp": 0x801a695c,
		"TBathWaterManager::~TBathWaterManager": 0x801a6c68,
		"TBathWaterManager::perform": 0x801a6d14,
		"JGeometry::TBox<JGeometry::TVec3<float><float>>::operator_=": 0x801a8098,
		"TBathtubData::getPos": 0x801a80cc,
		"getPos": 0x801a80cc,
		"JMath::TRandom_fast_::get_ufloat_1": 0x801a826c,
		"get_ufloat_1": 0x801a826c,
		"JGeometry::TVec3<float><float>::setMax": 0x801a82b0,
		"setMax": 0x801a82b0,
		"JGeometry::TVec3<float><float>::setMin": 0x801a82fc,
		"setMin": 0x801a82fc,
		"TBathWater::TDrop::calcBathtub": 0x801a8348,
		"calcBathtub": 0x801a8348,
		"TBathtubData::getGravityDir": 0x801a8b3c,
		"getGravityDir": 0x801a8b3c,
		"TBathWaterManager::throwMario": 0x801a8d78,
		"TBathWaterManager::getWaterHeight": 0x801a9070,
		"getWaterHeight": 0x801a9070,
		"TBathWaterManager::initializeIfYet_": 0x801a90bc,
		"initializeIfYet_": 0x801a90bc,
		"TBathWaterManager::loadAfter": 0x801a9d78,
		"TBathWaterMeshRenderer::clearHeightMap": 0x801aa160,
		"clearHeightMap": 0x801aa160,
		"TBathWaterManager::load": 0x801aa31c,
		"TBathWaterManager::TBathWaterManager": 0x801aa3ac,
		"TBathWater::TDrop::TDrop": 0x801aa530,
		"TBathWaterPreprocessor::~TBathWaterPreprocessor": 0x801aa534,
		"TBathWaterPreprocessor::perform": 0x801aa5a8,
		"Map::init_tobj_resource": 0x801aa610,
		"init_tobj_resource": 0x801aa610,
		"Map::draw_mist": 0x801aa6cc,
		"draw_mist": 0x801aa6cc,
		"@unnamed@::clearEFB_alpha": 0x801aae98,
		"clearEFB_alpha": 0x801aae98,
		"Map::drawCap": 0x801ab1a4,
		"drawCap": 0x801ab1a4,
		"TBathWaterGlobalParams::TBathWaterGlobalParams": 0x801ab2a4,
		"TBathWaterParams::TBathWaterParams": 0x801ab790,
		"TBathWaterMeshRenderer::getHeight": 0x801abbec,
		"TBathWaterMeshRenderer::prerender": 0x801abcb4,
		"JGeometry::SMatrix44C<float><float>::SMatrix44C": 0x801ac6f4,
		"SMatrix44C": 0x801ac6f4,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setLookDir": 0x801ac6f8,
		"setLookDir": 0x801ac6f8,
		"TBathWaterMeshRenderer::render": 0x801ac8d8,
		"TBathWaterMeshRenderer::calcCoord": 0x801ad6fc,
		"calcCoord": 0x801ad6fc,
		"TBathWaterMeshRenderer::makeNormalMap": 0x801adb30,
		"makeNormalMap": 0x801adb30,
		"TBathWaterMeshRenderer::makeHeightMap": 0x801add40,
		"makeHeightMap": 0x801add40,
		"TBathWaterFlatRenderer::prerender": 0x801ade50,
		"TBathWaterFlatRenderer::getHeight": 0x801ade54,
		"TBathWaterFlatRenderer::render": 0x801ade5c,
		"Map::__sinit_BathWaterManager_cpp": 0x801ae7c4,
		"__sinit_BathWaterManager_cpp": 0x801ae7c4,
		"TStickyStainManager::~TStickyStainManager": 0x801aeac8,
		"TStickyStainManager::perform": 0x801aeb3c,
		"TCoord2D::update": 0x8013eab0,
		"TCoord2D::setValue": 0x8013eb58,
		"setValue": 0x8013eb58,
		"TCoord2D::TCoord2D": 0x8013ebd0,
		"TExPane::update": 0x8013ebf0,
		"TExPane::TExPane": 0x8013eed4,
		"TFlashPane::~TFlashPane": 0x8013efa8,
		"TFlashPane::perform": 0x8013f01c,
		"TMenuPlane::perform": 0x8013f08c,
		"TMenuPlane::TMenuPlane": 0x8013f218,
		"TMenuBase::perform": 0x8013f3e8,
		"TMenuPlane::~TMenuPlane": 0x8013f4dc,
		"TMenuBase::~TMenuBase": 0x8013f550,
		"TSMSFader::setFadeStatus": 0x8013f638,
		"setFadeStatus": 0x8013f638,
		"TSMSFader::setDisplaySize": 0x8013f680,
		"setDisplaySize": 0x8013f680,
		"TSMSFader::load": 0x8013f6a8,
		"TSMSFader::setColor": 0x8013f7c0,
		"TSMSFader::startFadeoutT": 0x8013f808,
		"startFadeoutT": 0x8013f808,
		"TSMSFader::startFadeinT": 0x8013f834,
		"startFadeinT": 0x8013f834,
		"TSMSFader::startWipe": 0x8013f860,
		"startWipe": 0x8013f860,
		"TSMSFader::requestWipe": 0x8013f870,
		"requestWipe": 0x8013f870,
		"TSMSFader::drawFadeinout": 0x8013fa54,
		"drawFadeinout": 0x8013fa54,
		"TSMSFader::draw": 0x8013fc88,
		"TSMSFader::update": 0x8013fe24,
		"TSMSFader::perform": 0x8013ff80,
		"TSMSFader::TSMSFader": 0x80140008,
		"@unnamed@::draw_wipe_box": 0x801400cc,
		"draw_wipe_box": 0x801400cc,
		"@unnamed@::fill_rect": 0x80140390,
		"fill_rect": 0x80140390,
		"GC2D::__sinit_ScrnFader_cpp": 0x801404cc,
		"__sinit_ScrnFader_cpp": 0x801404cc,
		"TGCConsole2::~TGCConsole2": 0x801407c8,
		"TGCConsole2::perform": 0x8014083c,
		"TGCConsole2::drawWater": 0x801441e0,
		"drawWater": 0x801441e0,
		"TGCConsole2::drawJuice": 0x80144840,
		"drawJuice": 0x80144840,
		"TGCConsole2::processDisappearBalloon": 0x80144e58,
		"processDisappearBalloon": 0x80144e58,
		"TGCConsole2::processAppearBalloon": 0x8014502c,
		"processAppearBalloon": 0x8014502c,
		"TGCConsole2::processAppearTimer": 0x80145140,
		"processAppearTimer": 0x80145140,
		"TGCConsole2::processAppearRed": 0x801455cc,
		"processAppearRed": 0x801455cc,
		"TGCConsole2::processAppearJet": 0x801458e4,
		"processAppearJet": 0x801458e4,
		"TGCConsole2::checkChangeTelopArray": 0x80145bac,
		"checkChangeTelopArray": 0x80145bac,
		"TGCConsole2::processDrawTelop": 0x80145d38,
		"processDrawTelop": 0x80145d38,
		"TGCConsole2::processAppearMario": 0x80145de0,
		"processAppearMario": 0x80145de0,
		"TGCConsole2::processAppearCoin": 0x80146104,
		"processAppearCoin": 0x80146104,
		"TGCConsole2::processAppearTank": 0x80146468,
		"processAppearTank": 0x80146468,
		"TGCConsole2::processDownCoin": 0x801466f0,
		"processDownCoin": 0x801466f0,
		"TGCConsole2::processAppearStar": 0x80146a60,
		"processAppearStar": 0x80146a60,
		"TBlendPane::setPaneBlend": 0x80144d84,
		"setPaneBlend": 0x80144d84,
		"TExPane::setPaneOffset": 0x80147178,
		"setPaneOffset": 0x80147178,
		"TCoord2D::roundf": 0x80147244,
		"roundf": 0x80147244,
		"TGCConsole2::processInsertLife": 0x8014728c,
		"processInsertLife": 0x8014728c,
		"TGCConsole2::processAppearLife": 0x80147450,
		"processAppearLife": 0x80147450,
		"TGCConsole2::getFinishedTime": 0x80147548,
		"getFinishedTime": 0x80147548,
		"TGCConsole2::stopMoveTimer": 0x80147550,
		"stopMoveTimer": 0x80147550,
		"TGCConsole2::startMoveTimer": 0x80147568,
		"startMoveTimer": 0x80147568,
		"TGCConsole2::setTimer": 0x8014836c,
		"setTimer": 0x8014836c,
		"TGCConsole2::processMoveNozzle": 0x80148e24,
		"processMoveNozzle": 0x80148e24,
		"TGCConsole2::startAppearMario": 0x80148f64,
		"startAppearMario": 0x80148f64,
		"TGCConsole2::startDisappearMario": 0x80149158,
		"startDisappearMario": 0x80149158,
		"TGCConsole2::drawWaterBack": 0x801492a4,
		"drawWaterBack": 0x801492a4,
		"TGCConsole2::startAppearStar": 0x80149b00,
		"startAppearStar": 0x80149b00,
		"TGCConsole2::startDisappearStar": 0x80149ecc,
		"startDisappearStar": 0x80149ecc,
		"TGCConsole2::startAppearBalloon": 0x8014a1ec,
		"startAppearBalloon": 0x8014a1ec,
		"TGCConsole2::startDisappearBalloon": 0x8014a4a4,
		"startDisappearBalloon": 0x8014a4a4,
		"TGCConsole2::pauseOut": 0x8014a4fc,
		"pauseOut": 0x8014a4fc,
		"TGCConsole2::pauseIn": 0x8014a890,
		"pauseIn": 0x8014a890,
		"TGCConsole2::startAppearRedCoin": 0x8014a9bc,
		"startAppearRedCoin": 0x8014a9bc,
		"TGCConsole2::startInsertJetBalloon": 0x8014ab60,
		"startInsertJetBalloon": 0x8014ab60,
		"TGCConsole2::startAppearJetBalloon": 0x8014ad04,
		"startAppearJetBalloon": 0x8014ad04,
		"TGCConsole2::startInsertTimer": 0x8014ae30,
		"startInsertTimer": 0x8014ae30,
		"TGCConsole2::startAppearTimer": 0x8014afcc,
		"startAppearTimer": 0x8014afcc,
		"TGCConsole2::startDisappearTimer": 0x8014b1d8,
		"startDisappearTimer": 0x8014b1d8,
		"TGCConsole2::startDisappearTelop": 0x8014b308,
		"startDisappearTelop": 0x8014b308,
		"TGCConsole2::startAppearTelop": 0x8014b450,
		"startAppearTelop": 0x8014b450,
		"TGCConsole2::startDownLeftBot": 0x8014b628,
		"startDownLeftBot": 0x8014b628,
		"TGCConsole2::startAppearLife": 0x8014b9ec,
		"startAppearLife": 0x8014b9ec,
		"TGCConsole2::resetLife": 0x8014bf54,
		"resetLife": 0x8014bf54,
		"TGCConsole2::startInsertLife": 0x8014c05c,
		"startInsertLife": 0x8014c05c,
		"TGCConsole2::startDisappearCoin": 0x8014c518,
		"startDisappearCoin": 0x8014c518,
		"TGCConsole2::startAppearCoin": 0x8014c7e8,
		"startAppearCoin": 0x8014c7e8,
		"TGCConsole2::startAppearTank": 0x8014cafc,
		"startAppearTank": 0x8014cafc,
		"TGCConsole2::endCameraDemo": 0x8014cc20,
		"endCameraDemo": 0x8014cc20,
		"TGCConsole2::startCameraDemo": 0x8014ce84,
		"startCameraDemo": 0x8014ce84,
		"TGCConsole2::entryHelpActor": 0x8014d7a4,
		"entryHelpActor": 0x8014d7a4,
		"TGCConsole2::loadAfter": 0x8014d884,
		"TGCConsole2::load": 0x8014ecfc,
		"TGCConsole2::TGCConsole2": 0x8014fbbc,
		"JUTPoint::JUTPoint": 0x801500c4,
		"GC2D::__sinit_GCConsole2_cpp": 0x80150120,
		"__sinit_GCConsole2_cpp": 0x80150120,
		"TTalk2D2::~TTalk2D2": 0x801504a0,
		"TTalk2D2::openWindow": 0x80150514,
		"openWindow": 0x80150514,
		"TTalk2D2::setTagParam": 0x801509e8,
		"setTagParam": 0x801509e8,
		"TTalk2D2::setupTextBox": 0x801515a0,
		"setupTextBox": 0x801515a0,
		"TTalk2D2::setupBoardTextBox": 0x80151978,
		"setupBoardTextBox": 0x80151978,
		"TTalk2D2::perform": 0x80151c88,
		"TTalk2D2::eraseBoardWindow": 0x801522c0,
		"eraseBoardWindow": 0x801522c0,
		"TTalk2D2::eraseNormalWindow": 0x80152358,
		"eraseNormalWindow": 0x80152358,
		"TTalk2D2::closeNormalWindow": 0x8015257c,
		"closeNormalWindow": 0x8015257c,
		"TTalk2D2::checkControler": 0x8015275c,
		"checkControler": 0x8015275c,
		"TTalk2D2::moveTalkWindow": 0x80152a78,
		"moveTalkWindow": 0x80152a78,
		"TTalk2D2::checkBoardControler": 0x80152d50,
		"checkBoardControler": 0x80152d50,
		"TTalk2D2::moveBoardWindow": 0x80152f08,
		"moveBoardWindow": 0x80152f08,
		"TTalk2D2::openNormalWindow": 0x80152fb0,
		"openNormalWindow": 0x80152fb0,
		"TTalk2D2::openBoardWindow": 0x8015325c,
		"openBoardWindow": 0x8015325c,
		"TTalk2D2::makeBoxLine": 0x80153340,
		"makeBoxLine": 0x80153340,
		"TTalk2D2::openTalkWindow": 0x80153824,
		"openTalkWindow": 0x80153824,
		"TTalk2D2::forceCloseTalk": 0x80153a38,
		"forceCloseTalk": 0x80153a38,
		"TTalk2D2::setMessageID": 0x80153ad8,
		"setMessageID": 0x80153ad8,
		"TTalk2D2::loadAfter": 0x80153ed0,
		"TTalk2D2::load": 0x80154454,
		"TTalk2D2::TTalk2D2": 0x801547fc,
		"GC2D::__sinit_Talk2D2_cpp": 0x8015499c,
		"__sinit_Talk2D2_cpp": 0x8015499c,
		"TBoundPane::update": 0x80154c98,
		"TBoundPane::setPaneSize": 0x80155018,
		"TBoundPane::setPanePosition": 0x8015508c,
		"setPanePosition": 0x8015508c,
		"TBoundPane::TBoundPane": 0x80155100,
		"TPauseMenu2::~TPauseMenu2": 0x80155204,
		"TPauseMenu2::drawAppearPane": 0x80155278,
		"drawAppearPane": 0x80155278,
		"TPauseMenu2::setDrawEnd": 0x801554a0,
		"setDrawEnd": 0x801554a0,
		"TPauseMenu2::setDrawStart": 0x801554f8,
		"setDrawStart": 0x801554f8,
		"TPauseMenu2::getNextState": 0x801556c8,
		"TPauseMenu2::perform": 0x80155788,
		"TPauseMenu2::disappearWindow": 0x801560c8,
		"disappearWindow": 0x801560c8,
		"TPauseMenu2::appearWindow": 0x80156504,
		"appearWindow": 0x80156504,
		"TPauseMenu2::loadAfter": 0x801568bc,
		"TPauseMenu2::load": 0x80156b0c,
		"TPauseMenu2::TPauseMenu2": 0x80156e3c,
		"GC2D::__sinit_PauseMenu2_cpp": 0x80156f50,
		"__sinit_PauseMenu2_cpp": 0x80156f50,
		"TMessageLoader::getMessageEntry": 0x8015724c,
		"getMessageEntry": 0x8015724c,
		"TMessageLoader::parseBlock": 0x80157278,
		"parseBlock": 0x80157278,
		"JSUIosBase::JSUIosBase": 0x801574b4,
		"TMessageLoader::loadMessageData": 0x801574cc,
		"loadMessageData": 0x801574cc,
		"TSwitchHelpActor::check": 0x80157658,
		"TSwitchHelpActor::TSwitchHelpActor": 0x8015768c,
		"THelpActor::check": 0x80157780,
		"THelpActor::perform": 0x801577a0,
		"THelpActor::loadAfter": 0x801578f8,
		"THelpActor::load": 0x801579a4,
		"THelpActor::THelpActor": 0x80157a48,
		"GC2D::SMSGetMessageData": 0x80157ab4,
		"SMSGetMessageData": 0x80157ab4,
		"GC2D::SMSMakeTextBuffer": 0x80157d9c,
		"SMSMakeTextBuffer": 0x80157d9c,
		"TCardSave::~TCardSave": 0x80157e7c,
		"TCardSave::getNextState": 0x80157ef0,
		"TCardSave::execMovement_": 0x80157f30,
		"execMovement_": 0x80157f30,
		"TCardSave::waitForAnyKeyBM": 0x8015b238,
		"TCardSave::waitForSelect3": 0x8015ba6c,
		"waitForSelect3": 0x8015ba6c,
		"TCardSave::waitForSelect2": 0x8015c414,
		"waitForSelect2": 0x8015c414,
		"TCardSave::waitForSelectOver": 0x8015caf4,
		"waitForSelectOver": 0x8015caf4,
		"TCardSave::waitForAnyKey": 0x8015d10c,
		"TCardSave::drawMessageBM": 0x8015d614,
		"TCardSave::drawMessage": 0x8015db40,
		"TCardSave::waitForChoiceBM": 0x8015de58,
		"TCardSave::waitForChoice": 0x8015f8e4,
		"TCardSave::waitForStop": 0x80161298,
		"waitForStop": 0x80161298,
		"TCardSave::perform": 0x80162028,
		"TCardSave::init": 0x8016210c,
		"TCardSave::initData": 0x801621d8,
		"TCardSave::load": 0x80163440,
		"TCardSave::TCardSave": 0x80163480,
		"TCardSave::changeMode": 0x80163680,
		"GC2D::__sinit_CardSave_cpp": 0x80163730,
		"__sinit_CardSave_cpp": 0x80163730,
		"TCardLoad::~TCardLoad": 0x80163a2c,
		"TCardLoad::changeScene": 0x80163aa0,
		"changeScene": 0x80163aa0,
		"TCardLoad::setSelected": 0x801651e4,
		"setSelected": 0x801651e4,
		"TCardLoad::selectFunction": 0x80165258,
		"selectFunction": 0x80165258,
		"TCardLoad::selectBookmark": 0x80166ba8,
		"selectBookmark": 0x80166ba8,
		"TCardLoad::drawMessageBM": 0x80167ae4,
		"TCardLoad::drawMessage": 0x80168304,
		"TCardLoad::waitForStart": 0x80168810,
		"waitForStart": 0x80168810,
		"TCardLoad::waitForAnyKeyBM": 0x80169198,
		"TCardLoad::waitForAnyKey": 0x80169a40,
		"TCardLoad::waitForChoiceBM": 0x80169f9c,
		"TCardLoad::waitForChoice": 0x8016b10c,
		"TCardLoad::changeMode": 0x8016bf84,
		"TCardLoad::titleDraw": 0x8016c060,
		"titleDraw": 0x8016c060,
		"TCardLoad::perform": 0x8016cba8,
		"JSUInputStream::JSUInputStream": 0x8016d9d0,
		"TCardLoad::loadAfter": 0x8016d9f4,
		"TCardLoad::setupScoreScreen": 0x8016daf8,
		"setupScoreScreen": 0x8016daf8,
		"TCardLoad::load": 0x8016e544,
		"TCardLoad::TCardLoad": 0x8016f89c,
		"GC2D::__sinit_CardLoad_cpp": 0x8016fb1c,
		"__sinit_CardLoad_cpp": 0x8016fb1c,
		"TConsoleStr::~TConsoleStr": 0x8016fe18,
		"TConsoleStr::startOpenWipe": 0x8016fe8c,
		"startOpenWipe": 0x8016fe8c,
		"TConsoleStr::startCloseWipe": 0x8017004c,
		"startCloseWipe": 0x8017004c,
		"TConsoleStr::processScenario": 0x801705e0,
		"processScenario": 0x801705e0,
		"TConsoleStr::processMiss": 0x801706b0,
		"processMiss": 0x801706b0,
		"TConsoleStr::processShineGet": 0x80170a10,
		"processShineGet": 0x80170a10,
		"TConsoleStr::processGo": 0x80170d18,
		"processGo": 0x80170d18,
		"TConsoleStr::processReady": 0x801713ac,
		"processReady": 0x801713ac,
		"TConsoleStr::startAppearScenario": 0x801718e4,
		"startAppearScenario": 0x801718e4,
		"TConsoleStr::startAppearMiss": 0x80171a28,
		"startAppearMiss": 0x80171a28,
		"TConsoleStr::startAppearShineGet": 0x80171b90,
		"startAppearShineGet": 0x80171b90,
		"TConsoleStr::startAppearGo": 0x80171bb8,
		"startAppearGo": 0x80171bb8,
		"TConsoleStr::startAppearReady": 0x80171c2c,
		"startAppearReady": 0x80171c2c,
		"TConsoleStr::perform": 0x80171ca0,
		"TConsoleStr::loadAfter": 0x801723dc,
		"TConsoleStr::load": 0x80172418,
		"TConsoleStr::getWipeCloseTime": 0x801727d8,
		"getWipeCloseTime": 0x801727d8,
		"TConsoleStr::TConsoleStr": 0x80172800,
		"GC2D::__sinit_ConsoleStr_cpp": 0x801728b4,
		"__sinit_ConsoleStr_cpp": 0x801728b4,
		"TSelectMenu::~TSelectMenu": 0x8017291c,
		"TSelectMenu::startOpenWindow": 0x80172990,
		"startOpenWindow": 0x80172990,
		"TSelectMenu::getPrevIndex": 0x80172bdc,
		"getPrevIndex": 0x80172bdc,
		"TSelectMenu::getNextIndex": 0x80172c34,
		"getNextIndex": 0x80172c34,
		"TSelectMenu::perform": 0x80172c90,
		"TSelectMenu::startMove": 0x8017443c,
		"startMove": 0x8017443c,
		"TSelectMenu::initData": 0x8017449c,
		"TSelectMenu::TSelectMenu": 0x801753d0,
		"TSelectGrad::perform": 0x80175560,
		"TSelectGrad::setStageColor": 0x8017591c,
		"setStageColor": 0x8017591c,
		"TSelectGrad::TSelectGrad": 0x80175a4c,
		"TSelectGrad::~TSelectGrad": 0x80175b54,
		"GC2D::__sinit_SelectMenu_cpp": 0x80175bc8,
		"__sinit_SelectMenu_cpp": 0x80175bc8,
		"TSelectDir::direct": 0x80175ec4,
		"TSelectDir::changeOrder": 0x80176188,
		"changeOrder": 0x80176188,
		"TSelectDir::rsetup": 0x801761b0,
		"TSelectDir::setupThreadFunc": 0x801773e0,
		"TSelectDir::setup": 0x80177400,
		"TSelectDir::TSelectDir": 0x80177538,
		"GC2D::__sinit_SelectDir_cpp": 0x80177678,
		"__sinit_SelectDir_cpp": 0x80177678,
		"TSelectShine::~TSelectShine": 0x80177984,
		"TSelectShine::move": 0x801779d0,
		"TSelectShine::TSelectShine": 0x80177ea0,
		"TSelectShineManager::perform": 0x80178158,
		"JGeometry::TVec2<float><float>::sub": 0x801785f4,
		"TSelectShineManager::startDecrease": 0x80178628,
		"startDecrease": 0x80178628,
		"TSelectShineManager::startIncrease": 0x8017872c,
		"startIncrease": 0x8017872c,
		"TSelectShineManager::startClose": 0x80178830,
		"startClose": 0x80178830,
		"TSelectShineManager::initData": 0x8017894c,
		"TSelectShineManager::TSelectShineManager": 0x80178eb4,
		"TSelectShineManager::~TSelectShineManager": 0x80178f78,
		"GC2D::__sinit_SelectShine2_cpp": 0x80178fec,
		"__sinit_SelectShine2_cpp": 0x80178fec,
		"TBlendPane::update": 0x8017900c,
		"TBlendPane::TBlendPane": 0x8017910c,
		"TGuide::~TGuide": 0x8017915c,
		"TGuide::perform": 0x801791d0,
		"TExPane::setPaneSize": 0x801798f0,
		"TExPane::setPaneAlpha": 0x801799b4,
		"setPaneAlpha": 0x801799b4,
		"TGuide::appearGuidePane": 0x80179a54,
		"appearGuidePane": 0x80179a54,
		"TGuide::placeMario": 0x80179e0c,
		"placeMario": 0x80179e0c,
		"TGuide::changeBotStatus": 0x8017a060,
		"changeBotStatus": 0x8017a060,
		"TGuide::checkPoint": 0x8017a6bc,
		"checkPoint": 0x8017a6bc,
		"TGuide::linkSelect": 0x8017a7f0,
		"linkSelect": 0x8017a7f0,
		"TGuide::startMoveCursor": 0x8017b450,
		"startMoveCursor": 0x8017b450,
		"TGuide::setup": 0x8017b464,
		"TGuide::resetScore": 0x8017b4c0,
		"resetScore": 0x8017b4c0,
		"TGuide::resetObjects": 0x8017bdf8,
		"resetObjects": 0x8017bdf8,
		"TGuide::load": 0x8017c180,
		"TGuide::TGuide": 0x8017cb84,
		"GC2D::__sinit_Guide_cpp": 0x8017ccc8,
		"__sinit_Guide_cpp": 0x8017ccc8,
		"TSunShine::~TSunShine": 0x8017cfc4,
		"TSunShine::loadAfter": 0x8017d048,
		"TSunShine::perform": 0x8017d0a4,
		"TSunGlass::load": 0x8017d180,
		"TSunGlass::loadAfter": 0x8017d1bc,
		"TSunGlass::perform": 0x8017d264,
		"TSunGlass::draw": 0x8017d354,
		"TSunGlass::startFade": 0x8017d574,
		"startFade": 0x8017d574,
		"TShineFader::~TShineFader": 0x8017d760,
		"TShineFader::load": 0x8017d7f4,
		"TShineFader::registFadeout": 0x8017d814,
		"registFadeout": 0x8017d814,
		"TShineFader::perform": 0x8017d858,
		"TShineFader::update": 0x8017d8d4,
		"TProgSelect::~TProgSelect": 0x8017d9f4,
		"TProgSelect::perform": 0x8017da68,
		"TProgSelect::TProgSelect": 0x8017dd80,
		"GC2D::Hx_Test5": 0x8017df74,
		"Hx_Test5": 0x8017df74,
		"GC2D::Hx_Test4": 0x8017e46c,
		"Hx_Test4": 0x8017e46c,
		"GC2D::Hxs1_Test2": 0x8017e810,
		"Hxs1_Test2": 0x8017e810,
		"GC2D::Hx_Test2R": 0x8017eaf0,
		"Hx_Test2R": 0x8017eaf0,
		"GC2D::Hx_Test2": 0x8017ef1c,
		"Hx_Test2": 0x8017ef1c,
		"GC2D::Hxs1_Test1": 0x8017f30c,
		"Hxs1_Test1": 0x8017f30c,
		"GC2D::Hx_Test1": 0x8017f520,
		"Hx_Test1": 0x8017f520,
		"GC2D::Hx_MovieStartSyncEx": 0x8017f6c0,
		"Hx_MovieStartSyncEx": 0x8017f6c0,
		"GC2D::Hx_Logo": 0x8017f764,
		"Hx_Logo": 0x8017f764,
		"GC2D::Hxs_PenDraw": 0x8017fb50,
		"Hxs_PenDraw": 0x8017fb50,
		"GC2D::Hxs_Logo_MagDraw": 0x8017fd28,
		"Hxs_Logo_MagDraw": 0x8017fd28,
		"GC2D::Hxs_Logo_TexDraw": 0x8017fed0,
		"Hxs_Logo_TexDraw": 0x8017fed0,
		"GC2D::Hxs_Logo_TexSetup": 0x801800fc,
		"Hxs_Logo_TexSetup": 0x801800fc,
		"GC2D::Hxs_Logo_ExtraDraw": 0x80180284,
		"Hxs_Logo_ExtraDraw": 0x80180284,
		"GC2D::Hx_GameOver": 0x8018040c,
		"Hx_GameOver": 0x8018040c,
		"GC2D::Hxs_GameOver": 0x80180824,
		"Hxs_GameOver": 0x80180824,
		"GC2D::Hx_Door": 0x80180d80,
		"Hx_Door": 0x80180d80,
		"GC2D::Hxs_FrBufferMorf2B": 0x80180f64,
		"Hxs_FrBufferMorf2B": 0x80180f64,
		"GC2D::Hxs_FrBufferMorf2": 0x80181170,
		"Hxs_FrBufferMorf2": 0x80181170,
		"GC2D::Hxs2_Circle": 0x801813d4,
		"Hxs2_Circle": 0x801813d4,
		"GC2D::Hxs1_Circle": 0x801817a4,
		"Hxs1_Circle": 0x801817a4,
		"GC2D::Hx_Circle": 0x80181ab4,
		"Hx_Circle": 0x80181ab4,
		"GC2D::Hx_MotionUpdate": 0x80181d74,
		"Hx_MotionUpdate": 0x80181d74,
		"GC2D::Hx_MotionSet": 0x80181de0,
		"Hx_MotionSet": 0x80181de0,
		"GC2D::Hx_TimerCountDown": 0x80181e58,
		"Hx_TimerCountDown": 0x80181e58,
		"GC2D::Hx_UpdateWipe": 0x80181e80,
		"Hx_UpdateWipe": 0x80181e80,
		"GC2D::Hx_GetWipeType": 0x80181fc0,
		"Hx_GetWipeType": 0x80181fc0,
		"GC2D::dummy_handler": 0x80181fd4,
		"dummy_handler": 0x80181fd4,
		"GC2D::Hx_StartWipe": 0x80181fd8,
		"Hx_StartWipe": 0x80181fd8,
		"GC2D::Hx_RemoveResource": 0x80182074,
		"Hx_RemoveResource": 0x80182074,
		"GC2D::Hx_ProvideResourceEx": 0x801820e0,
		"Hx_ProvideResourceEx": 0x801820e0,
		"GC2D::Hx_ProvideResource": 0x80182138,
		"Hx_ProvideResource": 0x80182138,
		"GC2D::Hx_ResetWipe": 0x801821c0,
		"Hx_ResetWipe": 0x801821c0,
		"GC2D::Hx_Warning": 0x801821fc,
		"Hx_Warning": 0x801821fc,
		"GC2D::Frb2_RendBox": 0x80182200,
		"Frb2_RendBox": 0x80182200,
		"GC2D::Frb2_InitBlackBox": 0x801822b0,
		"Frb2_InitBlackBox": 0x801822b0,
		"GC2D::Frb2_InitGx": 0x80182338,
		"Frb2_InitGx": 0x80182338,
		"GC2D::Hx_FrBufferMorf": 0x80182478,
		"Hx_FrBufferMorf": 0x80182478,
		"GC2D::__Hx_FrBufferMorf": 0x801824b4,
		"__Hx_FrBufferMorf": 0x801824b4,
		"GC2D::Hx_SetVFilter": 0x80182724,
		"Hx_SetVFilter": 0x80182724,
		"GC2D::Hx_GetFrBuffer": 0x80182a20,
		"Hx_GetFrBuffer": 0x80182a20,
		"GC2D::Hgx_ReadTexture": 0x80182ad0,
		"Hgx_ReadTexture": 0x80182ad0,
		"GC2D::Hgx_init_tobj_resource": 0x80182b58,
		"Hgx_init_tobj_resource": 0x80182b58,
		"GC2D::Hx_GxInit": 0x80182bf8,
		"Hx_GxInit": 0x80182bf8,
		"GC2D::Hx_CameraInit": 0x80182d60,
		"Hx_CameraInit": 0x80182d60,
		"TMovieSubTitle::~TMovieSubTitle": 0x80182f34,
		"TMovieSubTitle::setCurMessage": 0x80182fa8,
		"setCurMessage": 0x80182fa8,
		"TMovieSubTitle::perform": 0x80183060,
		"TMovieSubTitle::setupResource": 0x80183274,
		"setupResource": 0x80183274,
		"TMovieSubTitle::TMovieSubTitle": 0x80183408,
		"TOptionControl::resetChangedSetting": 0x80183490,
		"resetChangedSetting": 0x80183490,
		"TOptionControl::isChangedSetting": 0x8018351c,
		"isChangedSetting": 0x8018351c,
		"MSound::startSoundSystemSE": 0x80183a20,
		"TOptionControl::setType": 0x80183a9c,
		"setType": 0x80183a9c,
		"TOptionControl::movementOption2Card": 0x80183c50,
		"movementOption2Card": 0x80183c50,
		"TOptionControl::movementOption": 0x80183d48,
		"movementOption": 0x80183d48,
		"JGeometry::TUtil<int><int>::mod": 0x80183f60,
		"JGeometry::TUtil<long><long>::clamp": 0x80183fa0,
		"clamp": 0x80183fa0,
		"TOptionControl::movementCard2Option": 0x80183fc0,
		"movementCard2Option": 0x80183fc0,
		"TOptionControl::draw": 0x801840b8,
		"TOptionControl::loadSetting": 0x801840e8,
		"loadSetting": 0x801840e8,
		"TOptionControl::load": 0x801845b8,
		"TOptionSoundUnit::setInfluencedAlphaRecursive": 0x80184790,
		"JSUTree<J2DPane>::getObject": 0x8018487c,
		"getObject": 0x8018487c,
		"TOptionSoundUnit::adjustView": 0x8018488c,
		"TOptionSoundUnit::setState": 0x80184ca0,
		"TOptionSoundUnit::typeToFlag": 0x80185050,
		"typeToFlag": 0x80185050,
		"TOptionSoundUnit::flagToType": 0x8018508c,
		"flagToType": 0x8018508c,
		"TOptionSoundUnit::update": 0x801850c8,
		"TOptionSoundUnit::initSurroundAnm": 0x8018539c,
		"initSurroundAnm": 0x8018539c,
		"TOptionSoundUnit::initSteleoAnm": 0x80185714,
		"initSteleoAnm": 0x80185714,
		"TOptionSoundUnit::TOptionSoundUnit": 0x80185944,
		"@unnamed@::ArrayWrapper<TPatternAnmControl*>::ArrayWrapper": 0x80185d3c,
		"ArrayWrapper": 0x80185d3c,
		"TOptionRumbleUnit::setInfluencedAlphaRecursive": 0x801866a0,
		"TOptionRumbleUnit::setState": 0x8018678c,
		"TOptionRumbleUnit::adjustView": 0x80186b94,
		"TOptionRumbleUnit::update": 0x80186ca8,
		"TOptionRumbleUnit::TOptionRumbleUnit": 0x8018706c,
		"TPatternAnmControl::hide": 0x80187470,
		"hide": 0x80187470,
		"TPatternAnmControl::show": 0x801874ec,
		"show": 0x801874ec,
		"TPatternAnmControl::update": 0x8018758c,
		"TPatternAnmControl::setupAnm": 0x8018769c,
		"setupAnm": 0x8018769c,
		"GC2D::__sinit_Option_cpp": 0x801877c8,
		"__sinit_Option_cpp": 0x801877c8,
		"TMovieRumble::~TMovieRumble": 0x80187ac4,
		"TMovieRumble::checkRumbleOff": 0x80187b38,
		"checkRumbleOff": 0x80187b38,
		"TMovieRumble::perform": 0x80187c44,
		"TMovieRumble::init": 0x80187cc4,
		"TMovieRumble::TMovieRumble": 0x80187e24,
		"TConductor::perform": 0x80033ed8,
		"TConductor::searchF": 0x80034348,
		"TConductor::genEnemyFromPollution": 0x8003455c,
		"genEnemyFromPollution": 0x8003455c,
		"TConductor::killEnemiesWithin": 0x800348a8,
		"killEnemiesWithin": 0x800348a8,
		"TConductor::makeOneEnemyAppear": 0x80034980,
		"makeOneEnemyAppear": 0x80034980,
		"TConductor::makeEnemyAppear": 0x80034b14,
		"makeEnemyAppear": 0x80034b14,
		"TConductor::isBossDefeated": 0x80034d40,
		"isBossDefeated": 0x80034d40,
		"TConductor::getManagerByName": 0x80034f20,
		"getManagerByName": 0x80034f20,
		"TConductor::getGraphByName": 0x80034fdc,
		"TConductor::init": 0x80035010,
		"TConductor::registerEnemyInfoTable": 0x80035140,
		"registerEnemyInfoTable": 0x80035140,
		"TConductor::registerSDLModelData": 0x80035148,
		"registerSDLModelData": 0x80035148,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::insert": 0x80035190,
		"TConductor::registerAreaCylinderManager": 0x80035248,
		"registerAreaCylinderManager": 0x80035248,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::insert": 0x80035290,
		"TConductor::registerGenerator": 0x80035348,
		"registerGenerator": 0x80035348,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::insert": 0x80035390,
		"TConductor::registerOtherObj": 0x80035448,
		"registerOtherObj": 0x80035448,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::insert": 0x80035490,
		"TConductor::registerAloneActor": 0x80035548,
		"registerAloneActor": 0x80035548,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::insert": 0x80035590,
		"TConductor::registerEnemyManager": 0x80035648,
		"registerEnemyManager": 0x80035648,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::insert": 0x80035690,
		"TConductor::registerManager": 0x80035748,
		"registerManager": 0x80035748,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::insert": 0x80035790,
		"TConductor::initGraphGroup": 0x80035848,
		"TConductor::makeGraphGroup": 0x8003586c,
		"makeGraphGroup": 0x8003586c,
		"TConductor::~TConductor": 0x800358c8,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::erase": 0x80035cec,
		"JGadget::TList<P12TLiveManager,Q27JGadget27TAllocator<P12TLiveManager>>::iterator::iterator": 0x80035d58,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::erase": 0x80035d78,
		"JGadget::TList<P13TEnemyManager,Q27JGadget28TAllocator<P13TEnemyManager>>::iterator::iterator": 0x80035de4,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::erase": 0x80035e04,
		"JGadget::TList<P10TLiveActor,Q27JGadget25TAllocator<P10TLiveActor>>::iterator::iterator": 0x80035e70,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::erase": 0x80035e90,
		"JGadget::TList<PQ26JDrama8TViewObj,Q27JGadget31TAllocator<PQ26JDrama8TViewObj>>::iterator::iterator": 0x80035efc,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::erase": 0x80035f1c,
		"JGadget::TList<P20TAreaCylinderManager,Q27JGadget35TAllocator<P20TAreaCylinderManager>>::iterator::iterator": 0x80035f88,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::erase": 0x80035fa8,
		"JGadget::TList<P10TGenerator,Q27JGadget25TAllocator<P10TGenerator>>::iterator::iterator": 0x80036014,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::erase": 0x80036034,
		"JGadget::TList<P12SDLModelData,Q27JGadget27TAllocator<P12SDLModelData>>::iterator::iterator": 0x800360a0,
		"TConductor::TConductor": 0x800360a8,
		"TEffectModel::control": 0x8003630c,
		"TEffectExplosion::generate": 0x80036394,
		"TEffectExplosion::reset": 0x800364f4,
		"TEffectExplosion::init": 0x80036618,
		"TEffectExplosionManager::createModelData": 0x8003673c,
		"TEffectExplosionManager::createEnemyInstance": 0x80036770,
		"TEffectExplosionManager::loadAfter": 0x800367e0,
		"TEffectExplosionManager::load": 0x800368a4,
		"TEffectExplosionManager::TEffectExplosionManager": 0x80036910,
		"TEffectModelManager::~TEffectModelManager": 0x80036958,
		"TEffectColumSand::generate": 0x800369bc,
		"TEffectColumSand::reset": 0x80036a74,
		"TEffectColumSand::init": 0x80036ba8,
		"TEffectColumSandManager::createModelData": 0x80036c70,
		"TEffectColumSandManager::createEnemyInstance": 0x80036ca4,
		"TEffectColumSandManager::loadAfter": 0x80036d14,
		"TEffectColumSandManager::load": 0x80036d6c,
		"TEffectColumSandManager::TEffectColumSandManager": 0x80036dd8,
		"TEffectBombColumWater::generate": 0x80036e20,
		"TEffectBombColumWater::reset": 0x80036f84,
		"TEffectBombColumWater::init": 0x800370d8,
		"TEffectBombColumWaterManager::createModelData": 0x800371ac,
		"TEffectBombColumWaterManager::createEnemyInstance": 0x800371e0,
		"TEffectBombColumWaterManager::loadAfter": 0x80037250,
		"TEffectBombColumWaterManager::load": 0x80037314,
		"TEffectBombColumWaterManager::TEffectBombColumWaterManager": 0x80037380,
		"TEffectColumWater::generate": 0x800373c8,
		"TEffectColumWater::reset": 0x80037500,
		"TEffectColumWater::init": 0x80037654,
		"TEffectColumWaterManager::createModelData": 0x80037728,
		"TEffectColumWaterManager::createEnemyInstance": 0x8003775c,
		"TEffectColumWaterManager::loadAfter": 0x800377cc,
		"TEffectColumWaterManager::load": 0x80037858,
		"TEffectColumWaterManager::TEffectColumWaterManager": 0x800378c4,
		"TEffectModel::calcRootMatrix": 0x8003790c,
		"TEffectModel::moveObject": 0x80037a00,
		"TEffectModel::reset": 0x80037a64,
		"TEffectModel::init": 0x80037b28,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::insert": 0x80037b94,
		"TEffectObjManager::perform": 0x80037c4c,
		"TEffectObjManager::load": 0x80037d20,
		"TEffectObjManager::TEffectObjManager": 0x80037d40,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::erase": 0x80037e58,
		"TEffectObjBase::behaveToWater": 0x80037ec4,
		"TEffectObjBase::moveObject": 0x80037fac,
		"TEffectObjBase::receiveMessage": 0x8003817c,
		"TEffectObjBase::perform": 0x800381bc,
		"TEffectObjBase::reset": 0x80038214,
		"TEffectObjBase::init": 0x80038240,
		"TEffectObjBase::load": 0x800382a0,
		"TEffectObjBase::TEffectObjBase": 0x80038328,
		"TEffectBiancoFunsui::emitEffect": 0x80038380,
		"TEffectBiancoFunsui::loadAfter": 0x80038450,
		"TEffectPinnaFunsui::emitEffect": 0x800384c0,
		"TEffectPinnaFunsui::loadAfter": 0x80038590,
		"TSimpleEffect::perform": 0x80038600,
		"TEffectExplosionManager::~TEffectExplosionManager": 0x80038634,
		"TEffectColumSandManager::~TEffectColumSandManager": 0x8003872c,
		"TEffectBombColumWaterManager::~TEffectBombColumWaterManager": 0x80038824,
		"TEffectColumWaterManager::~TEffectColumWaterManager": 0x8003891c,
		"TEffectObjManager::~TEffectObjManager": 0x80038990,
		"JGadget::TList<P14TEffectObjBase,Q27JGadget29TAllocator<P14TEffectObjBase>>::iterator::iterator": 0x80038a9c,
		"Enemy::__sinit_effectObj_cpp": 0x80038c9c,
		"__sinit_effectObj_cpp": 0x80038c9c,
		"TEMarioManager::~TEMarioManager": 0x80038fe0,
		"TEMarioManager::createEnemyInstance": 0x80039044,
		"TEMarioManager::load": 0x800390a0,
		"TEMarioManager::TEMarioManager": 0x8003910c,
		"TEMario::perform": 0x80039148,
		"TEMario::forceDisappear": 0x80039438,
		"forceDisappear": 0x80039438,
		"TEMario::startGateDrawing": 0x80039460,
		"TEMario::startMonteReplay": 0x80039484,
		"TEMario::startRunAway": 0x800394a8,
		"TEMario::isDownWaitingToTalk": 0x800394cc,
		"isDownWaitingToTalk": 0x800394cc,
		"TEMario::isReachedToGate": 0x800394ec,
		"isReachedToGate": 0x800394ec,
		"TEMario::isGoal": 0x8003950c,
		"isGoal": 0x8003950c,
		"TEMario::kill": 0x8003952c,
		"TEMario::receiveMessage": 0x8003956c,
		"TEMario::init": 0x80039600,
		"TEMario::loadAfter": 0x800397b4,
		"TEMario::load": 0x80039810,
		"TEMario::TEMario": 0x80039bb0,
		"Enemy::__sinit_emario_cpp": 0x80039c60,
		"__sinit_emario_cpp": 0x80039c60,
		"TSpineEnemy::perform": 0x80039f64,
		"TSpineEnemy::checkCurAnmEnd": 0x8003a028,
		"checkCurAnmEnd": 0x8003a028,
		"TSpineEnemy::getCurAnmFrameNo": 0x8003a0c4,
		"getCurAnmFrameNo": 0x8003a0c4,
		"TSpineEnemy::doShortCut": 0x8003a160,
		"doShortCut": 0x8003a160,
		"TSpineEnemy::zigzagToCurPathNode": 0x8003a480,
		"zigzagToCurPathNode": 0x8003a480,
		"TSpineEnemy::walkToCurPathNode": 0x8003a9b0,
		"walkToCurPathNode": 0x8003a9b0,
		"TSpineEnemy::turnToCurPathNode": 0x8003ae94,
		"turnToCurPathNode": 0x8003ae94,
		"TSpineEnemy::goToDirLimitedNextGraphNode": 0x8003b078,
		"goToDirLimitedNextGraphNode": 0x8003b078,
		"TSpineEnemy::goToDirectedNextGraphNode": 0x8003b228,
		"goToDirectedNextGraphNode": 0x8003b228,
		"TSpineEnemy::goToExclusiveNextGraphNode": 0x8003b33c,
		"goToExclusiveNextGraphNode": 0x8003b33c,
		"JGeometry::TVec3<float><float>::operator_=": 0x8003b588,
		"TSpineEnemy::goToRandomEscapeGraphNode": 0x8003b5a4,
		"goToRandomEscapeGraphNode": 0x8003b5a4,
		"TSpineEnemy::goToRandomNextGraphNode": 0x8003b6ac,
		"goToRandomNextGraphNode": 0x8003b6ac,
		"TSpineEnemy::jumpToNextGraphNode": 0x8003b7b0,
		"jumpToNextGraphNode": 0x8003b7b0,
		"TSpineEnemy::goToShortestNextGraphNode": 0x8003b8d0,
		"goToShortestNextGraphNode": 0x8003b8d0,
		"TSpineEnemy::setGoalPathFromGraph": 0x8003b9f4,
		"setGoalPathFromGraph": 0x8003b9f4,
		"TSpineEnemy::isInSight": 0x8003baa0,
		"isInSight": 0x8003baa0,
		"TSpineEnemy::receiveMessage": 0x8003bad4,
		"TSpineEnemy::updateSquareToMario": 0x8003bb34,
		"updateSquareToMario": 0x8003bb34,
		"TSpineEnemy::calcTurnSpeedToReach": 0x8003bb6c,
		"calcTurnSpeedToReach": 0x8003bb6c,
		"TSpineEnemy::calcMinimumTurnRadius": 0x8003bc4c,
		"calcMinimumTurnRadius": 0x8003bc4c,
		"TSpineEnemy::resetSRTV": 0x8003bce0,
		"resetSRTV": 0x8003bce0,
		"TSpineEnemy::resetToPosition": 0x8003be2c,
		"resetToPosition": 0x8003be2c,
		"TSpineEnemy::getSaveParam": 0x8003bf38,
		"TSpineEnemy::calcRootMatrix": 0x8003bf44,
		"TSpineEnemy::calcEnemyRootMatrix": 0x8003bfe0,
		"calcEnemyRootMatrix": 0x8003bfe0,
		"TSpineEnemy::load": 0x8003c39c,
		"TSpineEnemy::reset": 0x8003c460,
		"TSpineEnemy::init": 0x8003c518,
		"TSpineEnemy::TSpineEnemy": 0x8003c608,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::~TSolidStack": 0x8003c794,
		"TSolidStack<TPathNode>::~TSolidStack": 0x8003c7e0,
		"TPathNode::TPathNode": 0x8003c82c,
		"TSpineBase<TLiveActor>::~TSpineBase": 0x8003c848,
		"~TSpineBase": 0x8003c848,
		"Enemy::__sinit_enemy_cpp": 0x8003c9b0,
		"__sinit_enemy_cpp": 0x8003c9b0,
		"TEnemyPolluteModel::~TEnemyPolluteModel": 0x8003ccb4,
		"TEnemyPolluteModel::setAnm": 0x8003cd28,
		"TEnemyPolluteModel::perform": 0x8003cd2c,
		"TEnemyPolluteModel::TEnemyPolluteModel": 0x8003ce10,
		"TEnemyPolluteModelManager::generatePolluteModel": 0x8003cee0,
		"generatePolluteModel": 0x8003cee0,
		"TEnemyPolluteModelManager::perform": 0x8003d068,
		"TEnemyPolluteModelManager::init": 0x8003d178,
		"TEnemyAttachment::perform": 0x8003d1b0,
		"TEnemyAttachment::behaveToHost": 0x8003d2d4,
		"TEnemyAttachment::calcRootMatrix": 0x8003d2d8,
		"TEnemyAttachment::sendMessage": 0x8003d37c,
		"TEnemyAttachment::moveObject": 0x8003d430,
		"TEnemyAttachment::set": 0x8003d4cc,
		"TEnemyAttachment::kill": 0x8003d508,
		"TEnemyAttachment::rebirth": 0x8003d524,
		"TEnemyAttachment::bind": 0x8003d548,
		"TEnemyAttachment::setBehavior": 0x8003d4c8,
		"TEnemyAttachment::getNowGravity": 0x8003d7c8,
		"TEnemyAttachment::recoverScale": 0x8003d7d0,
		"TEnemyAttachment::forceKill": 0x8003d81c,
		"TEnemyAttachment::behaveToHitWall": 0x8003d8d4,
		"TEnemyAttachment::behaveToHitGround": 0x8003d900,
		"TEnemyAttachment::loadInit": 0x8003d954,
		"TEnemyAttachment::TEnemyAttachment": 0x8003d9d0,
		"TEnemyPolluteModelManager::~TEnemyPolluteModelManager": 0x8003da30,
		"TEnemyAttachment::appear": 0x8003db10,
		"TEnemyAttachment::receiveMessage": 0x8003db2c,
		"TEnemyManager::copyAnmMtx": 0x8003dbf0,
		"copyAnmMtx": 0x8003dbf0,
		"TEnemyManager::countLivingEnemy": 0x8003dda4,
		"countLivingEnemy": 0x8003dda4,
		"TEnemyManager::killChildrenWithin": 0x8003de0c,
		"killChildrenWithin": 0x8003de0c,
		"TEnemyManager::killChildren": 0x8003dee4,
		"killChildren": 0x8003dee4,
		"TEnemyManager::getFarOutEnemy": 0x8003df1c,
		"getFarOutEnemy": 0x8003df1c,
		"TEnemyManager::getDeadEnemy": 0x8003dfbc,
		"getDeadEnemy": 0x8003dfbc,
		"TEnemyManager::getNearestEnemy": 0x8003e024,
		"getNearestEnemy": 0x8003e024,
		"TEnemyManager::perform": 0x8003e0e4,
		"TEnemyManager::performShared": 0x8003e368,
		"performShared": 0x8003e368,
		"TEnemyManager::copyFromShared": 0x8003e75c,
		"copyFromShared": 0x8003e75c,
		"TEnemyManager::updateAnmSoundShared": 0x8003e9cc,
		"updateAnmSoundShared": 0x8003e9cc,
		"TEnemyManager::setSharedFlags": 0x8003eb24,
		"setSharedFlags": 0x8003eb24,
		"TEnemyManager::clipEnemies": 0x8003ec04,
		"TEnemyManager::createEnemies": 0x8003ec48,
		"TEnemyManager::createEnemyInstance": 0x8003edb4,
		"TEnemyManager::load": 0x8003edbc,
		"TEnemyManager::getSharedMActorSet": 0x8003ee18,
		"getSharedMActorSet": 0x8003ee18,
		"TEnemyManager::createSharedMActorSet": 0x8003ee60,
		"createSharedMActorSet": 0x8003ee60,
		"TSharedMActorSet::TSharedMActorSet": 0x8003ef4c,
		"TEnemyManager::~TEnemyManager": 0x8003ef60,
		"TEnemyManager::TEnemyManager": 0x8003eff4,
		"TSharedMActorSet::init": 0x8003f0f0,
		"TSpineEnemyParams::TSpineEnemyParams": 0x8003f258,
		"Enemy::__sinit_enemymanager_cpp": 0x8003f43c,
		"__sinit_enemymanager_cpp": 0x8003f43c,
		"TEnemyMario::perform": 0x8003f814,
		"TEnemyMario::drawHPMeter": 0x8003fdc4,
		"drawHPMeter": 0x8003fdc4,
		"TEnemyMario::damageExec": 0x80040068,
		"TEnemyMario::playerControl": 0x8004006c,
		"TEnemyMario::checkController": 0x8004010c,
		"TEnemyMario::checkReturn": 0x800406cc,
		"TEnemyMario::reachGoal": 0x8004080c,
		"reachGoal": 0x8004080c,
		"TEnemyMario::thinkTrample": 0x8004082c,
		"thinkTrample": 0x8004082c,
		"TEnemyMario::hitWater": 0x80040888,
		"TEnemyMario::consider": 0x80040a3c,
		"consider": 0x80040a3c,
		"JGeometry::TRotation3<JGeometry::TMatrix44<JGeometry::SMatrix44C<float><float>>>::TRotation3": 0x80041290,
		"TPathNode::getPoint": 0x8004129c,
		"TEnemyMario::startGateDrawing": 0x800412bc,
		"TEnemyMario::emWaitingToInviteMario": 0x80041320,
		"emWaitingToInviteMario": 0x80041320,
		"TEnemyMario::decideDoingAfterCarry": 0x800414bc,
		"decideDoingAfterCarry": 0x800414bc,
		"TEnemyMario::emRunAwayToNearestNode": 0x80041620,
		"emRunAwayToNearestNode": 0x80041620,
		"TEnemyMario::findRunAwayNearestNode": 0x80041b00,
		"findRunAwayNearestNode": 0x80041b00,
		"TEnemyMario::startRunAway": 0x80041da4,
		"TEnemyMario::emDownAnimation": 0x80041db8,
		"emDownAnimation": 0x80041db8,
		"TEnemyMario::emReplayJumpToNearestNode": 0x80041ee4,
		"emReplayJumpToNearestNode": 0x80041ee4,
		"TEnemyMario::emReplay": 0x800426c8,
		"emReplay": 0x800426c8,
		"TEnemyMario::emDisappearToGate": 0x800428fc,
		"emDisappearToGate": 0x800428fc,
		"TEnemyMario::startDisappear": 0x80042a68,
		"startDisappear": 0x80042a68,
		"TEnemyMario::emWalkAround": 0x80042b24,
		"emWalkAround": 0x80042b24,
		"TEnemyMario::emJumping": 0x80042cec,
		"emJumping": 0x80042cec,
		"TEnemyMario::emWaiting": 0x80042e48,
		"emWaiting": 0x80042e48,
		"TEnemyMario::tryTake": 0x80042f60,
		"tryTake": 0x80042f60,
		"TEnemyMario::startMonteReplay": 0x80043050,
		"TEnemyMario::initEnemyValues": 0x80043198,
		"initEnemyValues": 0x80043198,
		"TEnemyMario::initModel": 0x8004440c,
		"TEnemyMario::initValues": 0x80044ca4,
		"Enemy::__sinit_enemyMario_cpp": 0x80044fd4,
		"__sinit_enemyMario_cpp": 0x80044fd4,
		"TMtxCalcFootInv::TMtxCalcFootInv": 0x80045510,
		"Enemy::FeetInvCalc": 0x800457bc,
		"FeetInvCalc": 0x800457bc,
		"TNerveGessoTurn::~TNerveGessoTurn": 0x800462f0,
		"TNerveGessoTurn::execute": 0x8004634c,
		"TNerveGessoLand::execute": 0x80046450,
		"TNerveGessoLand::~TNerveGessoLand": 0x800464c4,
		"TNerveGessoFindMario::execute": 0x80046520,
		"TNerveGessoFindMario::~TNerveGessoFindMario": 0x8004658c,
		"TNerveGessoRolling::execute": 0x800465e8,
		"TNerveGessoRolling::~TNerveGessoRolling": 0x800466bc,
		"TNerveGessoFall::execute": 0x80046718,
		"TNerveGessoFall::~TNerveGessoFall": 0x80046e28,
		"TNerveGessoPollute::execute": 0x80046e84,
		"TNerveGessoPollute::~TNerveGessoPollute": 0x80046fe0,
		"TNerveGessoPunch::execute": 0x8004703c,
		"TNerveGessoPunch::~TNerveGessoPunch": 0x800470a8,
		"TNerveGessoFreeze::execute": 0x80047104,
		"TNerveGessoFreeze::~TNerveGessoFreeze": 0x80047550,
		"TNerveGessoStay::execute": 0x800475ac,
		"TNerveGessoStay::~TNerveGessoStay": 0x800477b8,
		"TGessoPolluteObj::sendMessage": 0x80047814,
		"TGessoPolluteObj::calcRootMatrix": 0x800478b8,
		"TGessoPolluteObj::set": 0x80047938,
		"TGessoPolluteObj::rebirth": 0x80047a78,
		"TGessoPolluteObj::pollute": 0x80047bc0,
		"TGessoPolluteObj::getNowGravity": 0x80047c34,
		"TGessoPolluteObj::loadInit": 0x80047c54,
		"TLandGesso::load": 0x80047d60,
		"TSurfGesso::perform": 0x80047da8,
		"TSurfGesso::load": 0x80047ddc,
		"TGesso::getBasNameTable": 0x80047e24,
		"TGesso::initAttacker": 0x80047e30,
		"TGesso::rollCheck": 0x80047e80,
		"rollCheck": 0x80047e80,
		"TGesso::behaveToFindMario": 0x80048198,
		"TGesso::genRandomItem": 0x800483f8,
		"TGesso::calcRootMatrix": 0x8004846c,
		"TGesso::kill": 0x800485d4,
		"TGesso::bind": 0x80048624,
		"TGesso::setWaitAnm": 0x800488dc,
		"TGesso::setWalkAnm": 0x80048960,
		"TGesso::getGravityY": 0x80048990,
		"TGesso::setDeadAnm": 0x800489c4,
		"TGesso::setAfterDeadEffect": 0x80048a8c,
		"TGesso::pollute": 0x80048ad0,
		"TGesso::setPolluteGoal": 0x80048cb4,
		"setPolluteGoal": 0x80048cb4,
		"TGesso::setBehavior": 0x80048e90,
		"TGesso::attackToMario": 0x80049054,
		"TGesso::doKeepDistance": 0x80049310,
		"TGesso::isResignationAttack": 0x8004935c,
		"TGesso::walkBehavior": 0x80049390,
		"TGesso::behaveToWater": 0x800495dc,
		"TGesso::load": 0x800499b0,
		"TGesso::reset": 0x80049a88,
		"TGesso::init": 0x80049c24,
		"TGesso::TGesso": 0x80049d8c,
		"Enemy::GessoBodyCallback": 0x80049ea0,
		"GessoBodyCallback": 0x80049ea0,
		"TGessoManager::createModelData": 0x8004a050,
		"TGessoManager::initSetEnemies": 0x8004a084,
		"TGessoManager::perform": 0x8004a140,
		"TGessoManager::clipEnemies": 0x8004a200,
		"TGessoManager::createEnemyInstance": 0x8004a328,
		"TGessoManager::loadAfter": 0x8004a370,
		"TGessoManager::load": 0x8004a390,
		"TGessoManager::TGessoManager": 0x8004a3e8,
		"TGessoPolluteModel::setAnm": 0x8004a494,
		"TGessoPolluteModelManager::init": 0x8004a4e4,
		"TGessoSaveLoadParams::TGessoSaveLoadParams": 0x8004a5ac,
		"TGesso::setRunAnm": 0x8004a948,
		"TSmallEnemy::isEatenByYosshi": 0x8004a974,
		"TSmallEnemy::jumpBehavior": 0x8004a97c,
		"jumpBehavior": 0x8004a97c,
		"TSmallEnemy::behaveToTaken": 0x8004a980,
		"TSmallEnemy::behaveToRelease": 0x8004a984,
		"TSmallEnemy::setGenerateAnm": 0x8004a988,
		"TSmallEnemy::setFreezeAnm": 0x8004a98c,
		"TSmallEnemy::setMeltAnm": 0x8004a990,
		"TSmallEnemy::isHitValid": 0x8004a994,
		"TSmallEnemy::isInhibitedForceMove": 0x8004a9c0,
		"TSmallEnemy::endHitWaterJump": 0x8004a9c8,
		"TSmallEnemy::setDeadEffect": 0x8004a9cc,
		"setDeadEffect": 0x8004a9cc,
		"TSurfGesso::isFindMario": 0x8004aad8,
		"TGessoManager::~TGessoManager": 0x8004ac18,
		"TGessoPolluteModel::~TGessoPolluteModel": 0x8004ac8c,
		"TGessoPolluteModelManager::~TGessoPolluteModelManager": 0x8004ad10,
		"Enemy::__sinit_gesso_cpp": 0x8004ad94,
		"__sinit_gesso_cpp": 0x8004ad94,
		"TGraphTracer::traceSpline": 0x8004b0b0,
		"traceSpline": 0x8004b0b0,
		"TGraphTracer::calcSplineSpeed": 0x8004b274,
		"calcSplineSpeed": 0x8004b274,
		"TGraphTracer::moveTo": 0x8004b4e4,
		"moveTo": 0x8004b4e4,
		"TGraphTracer::setTo": 0x8004b5a4,
		"setTo": 0x8004b5a4,
		"TGraphTracer::TGraphTracer": 0x8004b650,
		"TGraphGroup::perform": 0x8004b680,
		"TGraphGroup::getGraphByName": 0x8004b6d8,
		"TGraphGroup::initGraphGroup": 0x8004b77c,
		"TGraphGroup::TGraphGroup": 0x8004b960,
		"TGraphWeb::getNeighborNodeIndexByFlag": 0x8004baac,
		"getNeighborNodeIndexByFlag": 0x8004baac,
		"TGraphWeb::getNearestPosOnGraphLink": 0x8004bba0,
		"getNearestPosOnGraphLink": 0x8004bba0,
		"TGraphWeb::isDummy": 0x8004be68,
		"isDummy": 0x8004be68,
		"TGraphWeb::indexToPoint": 0x8004be8c,
		"indexToPoint": 0x8004be8c,
		"TGraphWeb::startIsEnd": 0x8004bf18,
		"startIsEnd": 0x8004bf18,
		"TGraphWeb::initGoalIndex": 0x8004bf90,
		"initGoalIndex": 0x8004bf90,
		"TGraphWeb::calcGraphDirection": 0x8004c054,
		"calcGraphDirection": 0x8004c054,
		"TGraphWeb::findNearestVisibleIndex": 0x8004c108,
		"findNearestVisibleIndex": 0x8004c108,
		"TGraphWeb::findNearestNodeIndex": 0x8004c2c0,
		"findNearestNodeIndex": 0x8004c2c0,
		"TGraphWeb::getEscapeDirLimited": 0x8004c3bc,
		"getEscapeDirLimited": 0x8004c3bc,
		"TGraphWeb::getRandomButDirLimited": 0x8004c838,
		"getRandomButDirLimited": 0x8004c838,
		"TGraphWeb::getAimToDirNextIndex": 0x8004cc64,
		"getAimToDirNextIndex": 0x8004cc64,
		"TGraphWeb::getEscapeFromMarioIndex": 0x8004ce84,
		"getEscapeFromMarioIndex": 0x8004ce84,
		"TGraphWeb::getRandomNextIndex": 0x8004d0d4,
		"getRandomNextIndex": 0x8004d0d4,
		"TGraphWeb::getShortestNextIndex": 0x8004d22c,
		"getShortestNextIndex": 0x8004d22c,
		"TGraphWeb::translateNodes": 0x8004d408,
		"translateNodes": 0x8004d408,
		"TGraphWeb::filterRailNode": 0x8004d5fc,
		"filterRailNode": 0x8004d5fc,
		"TGraphWeb::~TGraphWeb": 0x8004d748,
		"TGraphWeb::TGraphWeb": 0x8004d794,
		"TSplineRail::getPosAndRot": 0x8004d8f8,
		"getPosAndRot": 0x8004d8f8,
		"TSplinePath::getPoint": 0x8004db2c,
		"TSplineRail::TSplineRail": 0x8004dc0c,
		"TGraphNode::getPoint": 0x8004e1b8,
		"TGraphNode::TGraphNode": 0x8004e22c,
		"TNerveDoroHanePrepareAttack::~TNerveDoroHanePrepareAttack": 0x8004e24c,
		"TNerveDoroHanePrepareAttack::execute": 0x8004e2a8,
		"TNerveDoroHaneHitWater::execute": 0x8004e328,
		"TNerveDoroHaneHitWater::~TNerveDoroHaneHitWater": 0x8004e4a0,
		"TNerveDoroHaneRise::execute": 0x8004e4fc,
		"TNerveDoroHaneRise::~TNerveDoroHaneRise": 0x8004e698,
		"TNerveFireHamuKuriRecover::execute": 0x8004e6f4,
		"TFireHamuKuri::setBckAnm": 0x8004e7d8,
		"TNerveFireHamuKuriRecover::~TNerveFireHamuKuriRecover": 0x8004e7f8,
		"TNerveDoroHamuKuriRobCap::execute": 0x8004e854,
		"TNerveDoroHamuKuriRobCap::~TNerveDoroHamuKuriRobCap": 0x8004e9f8,
		"TNerveHaneHamuKuriMoveOnGraph::execute": 0x8004ea54,
		"TNerveHaneHamuKuriMoveOnGraph::~TNerveHaneHamuKuriMoveOnGraph": 0x8004ed54,
		"TNerveHaneHamuKuriUpWait::execute": 0x8004edb0,
		"TNerveHaneHamuKuriUpWait::~TNerveHaneHamuKuriUpWait": 0x8004ef38,
		"TNerveDangoHamuKuriWait::execute": 0x8004ef94,
		"TNerveDangoHamuKuriWait::~TNerveDangoHamuKuriWait": 0x8004f048,
		"TNerveHamuKuriJitabata::execute": 0x8004f0a4,
		"TNerveHamuKuriJitabata::~TNerveHamuKuriJitabata": 0x8004f1d4,
		"TNerveHamuKuriLand::execute": 0x8004f230,
		"TNerveHamuKuriLand::~TNerveHamuKuriLand": 0x8004f2b0,
		"TNerveHamuKuriWallDie::execute": 0x8004f30c,
		"TNerveHamuKuriWallDie::~TNerveHamuKuriWallDie": 0x8004f5ac,
		"TNerveHamuKuriBoundFreeze::execute": 0x8004f608,
		"TNerveHamuKuriBoundFreeze::~TNerveHamuKuriBoundFreeze": 0x8004f91c,
		"TNerveHamuKuriGoForSearchActor::execute": 0x8004f978,
		"TNerveHamuKuriGoForSearchActor::~TNerveHamuKuriGoForSearchActor": 0x8004fb64,
		"TDoroHamuKuri::isCollidMove": 0x8004fbc0,
		"TDoroHamuKuri::onHaveCap": 0x8004ff7c,
		"TDoroHamuKuri::setBehavior": 0x8004ff9c,
		"TDoroHamuKuri::attackToMario": 0x8005020c,
		"TDoroHamuKuri::setMActorAndKeeper": 0x800502f0,
		"TDoroHamuKuri::kill": 0x8005035c,
		"TDoroHamuKuri::reset": 0x8005037c,
		"TDoroHamuKuri::init": 0x800503f4,
		"TDoroHamuKuri::TDoroHamuKuri": 0x800505c4,
		"TFireHamuKuri::changeTevColor": 0x800506a4,
		"changeTevColor": 0x800506a4,
		"TFireHamuKuri::sendAttackMsgToMario": 0x80050870,
		"TFireHamuKuri::setWalkAnm": 0x800508ac,
		"TFireHamuKuri::isHitValid": 0x800508dc,
		"TFireHamuKuri::walkBehavior": 0x8005097c,
		"TFireHamuKuri::calcRootMatrix": 0x80050af8,
		"TFireHamuKuri::moveObject": 0x80050ccc,
		"TFireHamuKuri::setMActorAndKeeper": 0x80050d00,
		"TFireHamuKuri::reset": 0x80050da0,
		"TFireHamuKuri::behaveToWater": 0x80050e58,
		"THamuKuri::canDoJitabata": 0x80051238,
		"TFireHamuKuri::init": 0x8005125c,
		"TFireHamuKuri::TFireHamuKuri": 0x80051338,
		"TBossDangoHamuKuri::generateBody": 0x8005138c,
		"generateBody": 0x8005138c,
		"TBossDangoHamuKuri::genEventCoin": 0x80051518,
		"TBossDangoHamuKuri::moveObject": 0x800515f4,
		"TBossDangoHamuKuri::setGenerateAnm": 0x8005164c,
		"TBossDangoHamuKuri::reset": 0x800516bc,
		"TBossDangoHamuKuri::perform": 0x80051790,
		"TBossDangoHamuKuri::init": 0x800517b0,
		"TBossDangoHamuKuri::TBossDangoHamuKuri": 0x800518ec,
		"TDangoHamuKuri::swingBody": 0x80051a18,
		"swingBody": 0x80051a18,
		"TDangoHamuKuri::behaveToWater": 0x80051bec,
		"TDangoHamuKuri::forceKill": 0x8005208c,
		"TDangoHamuKuri::isHitValid": 0x800521ec,
		"TDangoHamuKuri::receiveMessage": 0x80052214,
		"TDangoHamuKuri::reset": 0x80052414,
		"TDangoHamuKuri::calcRootMatrix": 0x800524d8,
		"TDangoHamuKuri::setRunAnm": 0x800526b4,
		"TDangoHamuKuri::getTakingMtx": 0x80052708,
		"TDangoHamuKuri::attackToMario": 0x800527d0,
		"TDangoHamuKuri::isCollidMove": 0x80052930,
		"TDangoHamuKuri::updateAnmSound": 0x80052950,
		"TDangoHamuKuri::moveObject": 0x80052994,
		"TDangoHamuKuri::changeByJuice": 0x800529ec,
		"TDangoHamuKuri::perform": 0x80052a20,
		"TDangoHamuKuri::init": 0x80052aac,
		"TDangoHamuKuri::TDangoHamuKuri": 0x80052bac,
		"THaneHamuKuri2::isReachedToGoal": 0x80052c24,
		"THaneHamuKuri2::walkBehavior": 0x80052ccc,
		"THaneHamuKuri2::sendAttackMsgToMario": 0x80052e38,
		"THaneHamuKuri2::reset": 0x80052e58,
		"THaneHamuKuri2::THaneHamuKuri2": 0x80052f44,
		"TDoroHaneKuri::isCollidMove": 0x80053054,
		"TDoroHaneKuri::setBehavior": 0x8005311c,
		"TDoroHaneKuri::behaveToWater": 0x800531e4,
		"TDoroHaneKuri::setMActorAndKeeper": 0x80053304,
		"TDoroHaneKuri::attackToMario": 0x80053370,
		"TDoroHaneKuri::onHaveCap": 0x8005352c,
		"TDoroHaneKuri::reset": 0x80053548,
		"TDoroHaneKuri::init": 0x800535d8,
		"TDoroHaneKuri::TDoroHaneKuri": 0x800537a8,
		"THaneHamuKuri::getBasNameTable": 0x80053824,
		"THaneHamuKuri::isHitValid": 0x80053830,
		"THaneHamuKuri::isCollidMove": 0x8005385c,
		"THaneHamuKuri::setDeadAnm": 0x8005387c,
		"THaneHamuKuri::setBckAnm": 0x80053954,
		"THaneHamuKuri::setCrashAnm": 0x80053974,
		"THaneHamuKuri::behaveToWater": 0x800539a4,
		"THaneHamuKuri::setRollAnm": 0x800539e8,
		"THaneHamuKuri::setRunAnm": 0x80053a18,
		"THaneHamuKuri::setWalkAnm": 0x80053a48,
		"THaneHamuKuri::setWaitAnm": 0x80053a78,
		"THaneHamuKuri::setMActorAndKeeper": 0x80053aa8,
		"THaneHamuKuri::attackToMario": 0x80053b14,
		"THaneHamuKuri::isReachedToGoal": 0x80053b84,
		"THaneHamuKuri::bind": 0x80053c2c,
		"THaneHamuKuri::walkBehavior": 0x80053e0c,
		"THaneHamuKuri::reset": 0x800546ac,
		"THaneHamuKuri::moveObject": 0x80054720,
		"THaneHamuKuri::init": 0x80054740,
		"THaneHamuKuri::THaneHamuKuri": 0x80054824,
		"THamuKuri::forceRoll": 0x80054884,
		"forceRoll": 0x80054884,
		"THamuKuri::isCollidMove": 0x80054a88,
		"THamuKuri::isHitValid": 0x80054f40,
		"THamuKuri::isResignationAttack": 0x8005507c,
		"THamuKuri::getTakingMtx": 0x80055168,
		"THamuKuri::getBasNameTable": 0x80055268,
		"THamuKuri::initAttacker": 0x80055274,
		"THamuKuri::walkBehavior": 0x800552f8,
		"THamuKuri::setCrashAnm": 0x80055338,
		"THamuKuri::setRollAnm": 0x8005543c,
		"THamuKuri::setRunAnm": 0x8005546c,
		"THamuKuri::setWaitAnm": 0x8005549c,
		"THamuKuri::setDeadAnm": 0x800554cc,
		"THamuKuri::setWalkAnm": 0x8005561c,
		"THamuKuri::setGenerateAnm": 0x8005564c,
		"THamuKuri::setBckAnm": 0x8005567c,
		"THamuKuri::endHitWaterJump": 0x8005569c,
		"THamuKuri::setAfterDeadEffect": 0x800556e8,
		"THamuKuri::genRandomItem": 0x800558d0,
		"THamuKuri::getGravityY": 0x800558f0,
		"THamuKuri::makeCapFly": 0x80055960,
		"makeCapFly": 0x80055960,
		"THamuKuri::onHaveCap": 0x80055cc4,
		"THamuKuri::selectCapHolder": 0x80055cd0,
		"selectCapHolder": 0x80055cd0,
		"THamuKuri::setBehavior": 0x80055d80,
		"THamuKuri::moveObject": 0x80055ef4,
		"THamuKuri::attackToMario": 0x800560b4,
		"THamuKuri::behaveToFindMario": 0x80056198,
		"THamuKuri::jumpToSearchActor": 0x800561f4,
		"jumpToSearchActor": 0x800561f4,
		"THamuKuri::isFindMario": 0x800563a8,
		"THamuKuri::behaveToWater": 0x80056430,
		"THamuKuri::bind": 0x8005666c,
		"THamuKuri::reset": 0x800568cc,
		"THamuKuri::setMActorAndKeeper": 0x80056920,
		"THamuKuri::init": 0x80056a04,
		"THamuKuri::THamuKuri": 0x80056a94,
		"TDoroHamuKuriManager::perform": 0x80056b14,
		"TDoroHamuKuriManager::createModelData": 0x80056bc0,
		"TDoroHamuKuriManager::createEnemyInstance": 0x80056bf4,
		"TDoroHamuKuriManager::loadAfter": 0x80056c50,
		"TDoroHamuKuriManager::load": 0x80056da8,
		"TDoroHamuKuriManager::TDoroHamuKuriManager": 0x80056e14,
		"THamuKuriManager::~THamuKuriManager": 0x80056e78,
		"TDoroHige::perform": 0x80056eec,
		"TFireHamuKuriManager::createModelData": 0x80056f40,
		"TFireHamuKuriManager::initSetEnemies": 0x80056f74,
		"TFireHamuKuriManager::createEnemyInstance": 0x80057108,
		"TFireHamuKuriManager::load": 0x80057174,
		"TFireHamuKuriManager::TFireHamuKuriManager": 0x80057224,
		"TBossDangoHamuKuriManager::createEnemyInstance": 0x80057284,
		"TBossDangoHamuKuriManager::load": 0x800572e8,
		"TBossDangoHamuKuriManager::TBossDangoHamuKuriManager": 0x80057398,
		"TDangoHamuKuriManager::~TDangoHamuKuriManager": 0x80057408,
		"TDoroHaneKuriManager::perform": 0x8005748c,
		"TDangoHamuKuriManager::createModelDataArray": 0x80057538,
		"TDangoHamuKuriManager::createEnemyInstance": 0x800575a8,
		"TDangoHamuKuriManager::load": 0x800575f0,
		"TDangoHamuKuriManager::TDangoHamuKuriManager": 0x8005765c,
		"TDoroHaneKuriManager::createModelData": 0x800576bc,
		"TDoroHaneKuriManager::createEnemyInstance": 0x800576f0,
		"TDoroHaneKuriManager::loadAfter": 0x80057754,
		"TDoroHaneKuriManager::load": 0x800578ac,
		"TDoroHaneKuriManager::TDoroHaneKuriManager": 0x80057a0c,
		"THaneHamuKuriManager::~THaneHamuKuriManager": 0x80057a7c,
		"THaneHamuKuriManager::createAnmData": 0x80057b00,
		"THaneHamuKuriManager::createModelData": 0x80057b20,
		"THaneHamuKuriManager::createEnemyInstance": 0x80057b54,
		"THaneHamuKuriManager::load": 0x80057b9c,
		"THaneHamuKuriManager::THaneHamuKuriManager": 0x80057cfc,
		"THamuKuriManager::createEnemyInstance": 0x80057d5c,
		"THamuKuriManager::checkSerialKill": 0x80057da4,
		"checkSerialKill": 0x80057da4,
		"THamuKuriManager::requestSerialKill": 0x80057f14,
		"requestSerialKill": 0x80057f14,
		"THamuKuriManager::setSearchHamuKuri": 0x80058004,
		"setSearchHamuKuri": 0x80058004,
		"THamuKuriManager::perform": 0x800582c8,
		"THamuKuriManager::createAnmData": 0x80058350,
		"THamuKuriManager::createModelData": 0x800583b0,
		"THamuKuriManager::loadAfter": 0x800583e4,
		"THamuKuriManager::load": 0x800584f8,
		"THamuKuriManager::THamuKuriManager": 0x80058564,
		"THamuKuriSaveLoadParams::THamuKuriSaveLoadParams": 0x800585b8,
		"THamuKuriLauncher::stateLaunch": 0x8005887c,
		"THamuKuriLauncher::drawObject": 0x80058a4c,
		"TBossDangoHamuKuri::changeByJuice": 0x80058bac,
		"TBossDangoHamuKuri::isFindMario": 0x80058bb4,
		"THaneHamuKuri2::forceKill": 0x80058c58,
		"THaneHamuKuri2::isHitValid": 0x80058c5c,
		"THaneHamuKuri2::behaveToWater": 0x80058c64,
		"THaneHamuKuri::setBehavior": 0x80058c68,
		"THaneHamuKuri::setGenerateAnm": 0x80058c6c,
		"THaneHamuKuri::canDoJitabata": 0x80058c70,
		"TDoroHamuKuriManager::~TDoroHamuKuriManager": 0x80058db0,
		"TSmallEnemyManager::initSetEnemies": 0x80058e34,
		"TDoroHige::~TDoroHige": 0x80058e38,
		"TFireHamuKuriManager::~TFireHamuKuriManager": 0x80058ebc,
		"TBossDangoHamuKuriManager::~TBossDangoHamuKuriManager": 0x80058f40,
		"TBossDangoHamuKuriManager::clipEnemies": 0x80058fd4,
		"TDangoHamuKuriManager::clipEnemies": 0x80058fd8,
		"TDoroHaneKuriManager::~TDoroHaneKuriManager": 0x80058fdc,
		"Enemy::__sinit_hamukuri_cpp": 0x800590f4,
		"__sinit_hamukuri_cpp": 0x800590f4,
		"TNerveHino2WaitAnm::~TNerveHino2WaitAnm": 0x800594d0,
		"TNerveHino2WaitAnm::execute": 0x8005952c,
		"TNerveHino2Freeze::execute": 0x80059570,
		"TNerveHino2Freeze::~TNerveHino2Freeze": 0x800595fc,
		"TNerveHino2Stamp::execute": 0x80059658,
		"TNerveHino2GraphWander::~TNerveHino2GraphWander": 0x800598cc,
		"TNerveHino2Stamp::~TNerveHino2Stamp": 0x80059928,
		"TNerveHino2Die::execute": 0x80059984,
		"TNerveHino2Die::~TNerveHino2Die": 0x80059bb0,
		"TNerveHino2Burst::execute": 0x80059c0c,
		"TNerveHino2Burst::~TNerveHino2Burst": 0x80059e6c,
		"TNerveHino2Squat::execute": 0x80059ec8,
		"TNerveHino2Squat::~TNerveHino2Squat": 0x8005a018,
		"TNerveHino2Damage::execute": 0x8005a074,
		"TNerveHino2Damage::~TNerveHino2Damage": 0x8005a4a8,
		"TNerveHino2Pollute::execute": 0x8005a504,
		"TNerveHino2Pollute::~TNerveHino2Pollute": 0x8005a8b4,
		"TNerveHino2PrePol::execute": 0x8005a910,
		"TNerveHino2PrePol::~TNerveHino2PrePol": 0x8005ab14,
		"TNerveHino2Turn::execute": 0x8005ab70,
		"TNerveHino2Turn::~TNerveHino2Turn": 0x8005ae1c,
		"TNerveHino2Landing::execute": 0x8005ae78,
		"TNerveHino2Landing::~TNerveHino2Landing": 0x8005af38,
		"TNerveHino2JumpIn::execute": 0x8005af94,
		"TNerveHino2Fly::~TNerveHino2Fly": 0x8005b100,
		"TNerveHino2JumpIn::~TNerveHino2JumpIn": 0x8005b15c,
		"TNerveHino2Fly::execute": 0x8005b1b8,
		"TNerveHino2GraphWander::execute": 0x8005b300,
		"TNerveHino2Appear::execute": 0x8005b7e0,
		"TNerveHino2Appear::~TNerveHino2Appear": 0x8005b8d0,
		"THinokuri2::perform": 0x8005b92c,
		"THinokuri2::moveObject": 0x8005bb64,
		"THinokuri2::receiveMessage": 0x8005c27c,
		"THinokuri2::receiveMessageLv2": 0x8005c2f0,
		"receiveMessageLv2": 0x8005c2f0,
		"THinokuri2::receiveMessageLv1": 0x8005c680,
		"receiveMessageLv1": 0x8005c680,
		"THinokuri2::receiveMessageLv0": 0x8005c914,
		"receiveMessageLv0": 0x8005c914,
		"THinokuri2::changeBck": 0x8005cb94,
		"THinokuri2::updateAnmSound": 0x8005cdb0,
		"THinokuri2::setLevel": 0x8005ce18,
		"setLevel": 0x8005ce18,
		"THinokuri2::kill": 0x8005cf40,
		"THinokuri2::reset": 0x8005cfac,
		"THinokuri2::init": 0x8005d18c,
		"THinokuri2::THinokuri2": 0x8005d6ec,
		"Enemy::Hino2HeadCallback": 0x8005d994,
		"Hino2HeadCallback": 0x8005d994,
		"THino2Mask::perform": 0x8005db88,
		"THino2Mask::THino2Mask": 0x8005de70,
		"THino2Hit::receiveMessage": 0x8005df28,
		"THino2Hit::perform": 0x8005e050,
		"THinokuri2Manager::createEnemyInstance": 0x8005e54c,
		"THinokuri2Manager::load": 0x8005e594,
		"THinokuri2Manager::createModelData": 0x8005e600,
		"THinokuri2Manager::THinokuri2Manager": 0x8005e634,
		"THino2Params::THino2Params": 0x8005e670,
		"THinokuri2Manager::~THinokuri2Manager": 0x8005ee90,
		"Enemy::__sinit_hinokuri2_cpp": 0x8005eef4,
		"__sinit_hinokuri2_cpp": 0x8005eef4,
		"TNerveMameGessoWait::~TNerveMameGessoWait": 0x8005f288,
		"TNerveMameGessoWait::execute": 0x8005f2e4,
		"TNerveMameGessoGraphJumpWander::~TNerveMameGessoGraphJumpWander": 0x8005f438,
		"TNerveMameGessoObject::execute": 0x8005f494,
		"TNerveMameGessoObject::~TNerveMameGessoObject": 0x8005f7c0,
		"TNerveMameGessoThrown::execute": 0x8005f81c,
		"TNerveMameGessoThrown::~TNerveMameGessoThrown": 0x8005fa64,
		"TNerveMameGessoPickUp::execute": 0x8005fac0,
		"TNerveMameGessoPickUp::~TNerveMameGessoPickUp": 0x8005fb74,
		"TNerveMameGessoTrample::execute": 0x8005fbd0,
		"TNerveMameGessoTrample::~TNerveMameGessoTrample": 0x8005fcc4,
		"TNerveMameGessoJitabata::execute": 0x8005fd20,
		"TNerveMameGessoJitabata::~TNerveMameGessoJitabata": 0x8005ff1c,
		"TNerveMameGessoDamage::execute": 0x8005ff78,
		"TNerveMameGessoDamage::~TNerveMameGessoDamage": 0x800602b4,
		"TNerveMameGessoGraphJumpWander::execute": 0x80060310,
		"TMameGesso::getBasNameTable": 0x8006095c,
		"TMameGesso::doKeepDistance": 0x80060968,
		"TMameGesso::isInhibitedForceMove": 0x80060998,
		"TMameGesso::calcObjCollision": 0x800609a0,
		"calcObjCollision": 0x800609a0,
		"TMameGesso::isCollidMove": 0x80060b10,
		"TMameGesso::behaveToRelease": 0x80060bbc,
		"TMameGesso::behaveToTaken": 0x80060ce0,
		"TMameGesso::behaveToWater": 0x80060df8,
		"TMameGesso::setDeadAnm": 0x80060f70,
		"TMameGesso::setFreezeAnm": 0x80060f7c,
		"TMameGesso::setWaitAnm": 0x80060fb4,
		"TMameGesso::getGravityY": 0x8006105c,
		"TMameGesso::kill": 0x80061154,
		"TMameGesso::isHitValid": 0x80061508,
		"TMameGesso::reset": 0x80061624,
		"TMameGesso::calcRootMatrix": 0x80061714,
		"TMameGesso::attackToMario": 0x80061830,
		"TMameGesso::setMActorAndKeeper": 0x800618c8,
		"TMameGesso::moveObject": 0x80061934,
		"TMameGesso::init": 0x800619c8,
		"TMameGesso::load": 0x80061ae4,
		"TMameGesso::TMameGesso": 0x80061b2c,
		"TMameGessoManager::perform": 0x80061bc0,
		"TMameGessoManager::initSetEnemies": 0x80061c7c,
		"TMameGessoManager::createEnemyInstance": 0x80061c80,
		"TMameGessoManager::loadAfter": 0x80061cc8,
		"TMameGessoManager::load": 0x80061ce8,
		"TMameGessoManager::TMameGessoManager": 0x80061d40,
		"TMameGessoSaveLoadParams::TMameGessoSaveLoadParams": 0x80061d7c,
		"TMameGesso::changeByJuice": 0x80062050,
		"TMameGesso::isEatenByYosshi": 0x80062058,
		"TMameGesso::forceKill": 0x80062060,
		"TSmallEnemy::setBehavior": 0x80062064,
		"TSmallEnemy::setWalkAnm": 0x80062068,
		"TSmallEnemy::setRunAnm": 0x8006206c,
		"TMameGessoManager::~TMameGessoManager": 0x8006210c,
		"Enemy::__sinit_mameGesso_cpp": 0x80062180,
		"__sinit_mameGesso_cpp": 0x80062180,
		"TNerveNKFollowMario::~TNerveNKFollowMario": 0x800623f4,
		"TNerveNKFollowMario::execute": 0x80062450,
		"TNerveNameKuriJumpAttackPrepare::~TNerveNameKuriJumpAttackPrepare": 0x800625dc,
		"TNerveNKFollowMario::theNerve": 0x80062638,
		"TNerveNameKuriDrawPollute::execute": 0x8006269c,
		"TNerveNameKuriDrawPollute::theNerve": 0x800626a4,
		"TNerveNameKuriDrawPollute::~TNerveNameKuriDrawPollute": 0x80062708,
		"TNerveNameKuriDiffuse::execute": 0x80062764,
		"TNerveNameKuriDiffuse::theNerve": 0x80062798,
		"TNerveNameKuriDiffuse::~TNerveNameKuriDiffuse": 0x800627fc,
		"TNerveNameKuriExplosion::execute": 0x80062858,
		"TNerveNameKuriExplosion::theNerve": 0x800628cc,
		"TNerveNameKuriExplosion::~TNerveNameKuriExplosion": 0x80062930,
		"TNerveNameKuriJumpAttackPrepare::execute": 0x8006298c,
		"TNerveNameKuriJumpAttack::~TNerveNameKuriJumpAttack": 0x80062b78,
		"TNerveNameKuriJumpAttackPrepare::theNerve": 0x80062bd4,
		"TNerveNameKuriJumpAttack::execute": 0x80062c38,
		"TNerveNameKuriJumpAttack::theNerve": 0x80063120,
		"TNerveNameKuriLand::execute": 0x80063184,
		"TNerveNameKuriLand::theNerve": 0x80063214,
		"TNerveNameKuriLand::~TNerveNameKuriLand": 0x80063278,
		"TDiffusionNameKuriManager::createEnemyInstance": 0x800632d4,
		"TDiffusionNameKuriManager::load": 0x800633cc,
		"TNameKuri::getBasNameTable": 0x80063670,
		"TNameKuri::isCollidMove": 0x8006367c,
		"TNameKuri::isHitValid": 0x80063778,
		"TNameKuri::endHitWaterJump": 0x800637bc,
		"TNameKuri::behaveToFindMario": 0x800637d0,
		"TNameKuri::attackToMario": 0x800638ac,
		"TNameKuri::reset": 0x8006397c,
		"TNameKuri::setMActorAndKeeper": 0x80063ab4,
		"TNameKuri::setMeltAnm": 0x80063b20,
		"TNameKuri::setWaitAnm": 0x80063c78,
		"TNameKuri::setAfterDeadEffect": 0x80063ca8,
		"TNameKuri::setDeadAnm": 0x80063d24,
		"TNameKuri::setWalkAnm": 0x80063e7c,
		"TNameKuri::setGenerateAnm": 0x80063eac,
		"TNameKuri::setBckAnm": 0x80063f10,
		"TNameKuri::getGravityY": 0x80063f30,
		"TNameKuri::behaveToWater": 0x80063fd4,
		"TNameKuri::setBehavior": 0x80064114,
		"TNameKuri::moveObject": 0x80064118,
		"TNameKuri::perform": 0x80064344,
		"TNameKuri::calcRootMatrix": 0x80064464,
		"TNameKuri::init": 0x80064804,
		"TNameKuri::TNameKuri": 0x800649b8,
		"Enemy::NameKuriScaleCallback": 0x80064a2c,
		"NameKuriScaleCallback": 0x80064a2c,
		"Enemy::NameKuriAttackCallback": 0x80064b1c,
		"NameKuriAttackCallback": 0x80064b1c,
		"TNameIndParCallback::draw": 0x80064cb0,
		"TNameIndParCallback::execute": 0x80064cb4,
		"TNameKuriManager::perform": 0x8006506c,
		"TNameKuriManager::createModelData": 0x8006508c,
		"TNameKuriManager::createEnemyInstance": 0x800650c0,
		"TNameKuriManager::initSetEnemies": 0x8006514c,
		"TNameKuriManager::loadAfter": 0x800652c0,
		"TNameKuriManager::load": 0x80065324,
		"TNameKuriManager::TNameKuriManager": 0x800655c8,
		"TNameKuriLauncher::stateLaunch": 0x80065614,
		"TDiffusionNameKuriManager::~TDiffusionNameKuriManager": 0x800657a4,
		"Enemy::__sinit_namekuri_cpp": 0x80065928,
		"__sinit_namekuri_cpp": 0x80065928,
		"TNerveStayPakkunAppear::~TNerveStayPakkunAppear": 0x80065c3c,
		"TNerveStayPakkunAppear::execute": 0x80065c98,
		"TNervePakkunStay::~TNervePakkunStay": 0x80065e4c,
		"TNerveStayPakkunHide::execute": 0x80065ea8,
		"TNerveStayPakkunHide::~TNerveStayPakkunHide": 0x80066158,
		"TNervePakkunFreeze::execute": 0x800661b4,
		"TNervePakkunFreeze::~TNervePakkunFreeze": 0x800662ec,
		"TNervePakkunShoot::execute": 0x80066348,
		"TNervePakkunShoot::~TNervePakkunShoot": 0x800664a8,
		"TNervePakkunHide::execute": 0x80066504,
		"TNervePakkunAppear::~TNervePakkunAppear": 0x8006666c,
		"TNervePakkunHide::~TNervePakkunHide": 0x800666c8,
		"TNervePakkunAppear::execute": 0x80066724,
		"TNervePakkunStay::execute": 0x80066838,
		"TNervePakkunGenerate::execute": 0x800672ec,
		"TNervePakkunGenerate::~TNervePakkunGenerate": 0x800674e8,
		"TStayPakkun::getSaveParam": 0x80067544,
		"TStayPakkun::shoot": 0x80067550,
		"TStayPakkun::kill": 0x80067580,
		"TStayPakkun::shootIn": 0x80067600,
		"TStayPakkun::isHitValid": 0x80067720,
		"TStayPakkun::setBehavior": 0x80067930,
		"TStayPakkun::calcRootMatrix": 0x80067a6c,
		"TStayPakkun::genRandomItem": 0x80067a90,
		"TStayPakkun::setDeadAnm": 0x80067bec,
		"TStayPakkun::reset": 0x80067c1c,
		"TStayPakkun::init": 0x80067c84,
		"TStayPakkun::load": 0x80067db8,
		"TPakkunSeed::forceKill": 0x80067e9c,
		"TPakkunSeed::set": 0x80067f84,
		"TPakkunSeed::rebirth": 0x8006802c,
		"TPakkunSeed::shoot": 0x80068250,
		"TPakkunSeed::appear": 0x800682ac,
		"TPakkunSeed::getNowGravity": 0x800682d4,
		"TPakkunSeed::behaveToHitGround": 0x80068324,
		"TPakkunSeed::calcRootMatrix": 0x80068440,
		"TPakkunSeed::behaveToHitWall": 0x800684a8,
		"TPakkunSeed::behaveToHost": 0x8006852c,
		"TPakkunSeed::moveObject": 0x80068550,
		"TPakkunSeed::loadInit": 0x80068654,
		"TPakkun::getBasNameTable": 0x800687d4,
		"TPakkun::shoot": 0x800687e0,
		"TPakkun::shootIn": 0x80068810,
		"TPakkun::reset": 0x80068860,
		"TPakkun::setMActorAndKeeper": 0x800688a8,
		"TPakkun::behaveToWater": 0x80068914,
		"TPakkun::onShootLiner": 0x80068b50,
		"onShootLiner": 0x80068b50,
		"TPakkun::perform": 0x80068cac,
		"TPakkun::setDeadAnm": 0x80068e14,
		"TPakkun::setFreezeAnm": 0x80068e50,
		"TPakkun::setWaitAnm": 0x80068e80,
		"TPakkun::kill": 0x80068eb0,
		"TPakkun::isInhibitedForceMove": 0x80068ef0,
		"TPakkun::init": 0x80068ef8,
		"TPakkun::load": 0x800691a0,
		"TPakkun::TPakkun": 0x80069260,
		"TPakkunManager::clipEnemies": 0x800692c4,
		"TPakkunManager::createEnemyInstance": 0x800694b0,
		"TPakkunManager::createModelData": 0x800694f8,
		"TPakkunManager::loadAfter": 0x8006952c,
		"TPakkunManager::load": 0x8006954c,
		"TPakkunManager::TPakkunManager": 0x80069a80,
		"Enemy::PakkunRootCallback2": 0x80069ad4,
		"PakkunRootCallback2": 0x80069ad4,
		"Enemy::PakkunRootCallback": 0x80069b88,
		"PakkunRootCallback": 0x80069b88,
		"Enemy::PakkunSeedCallback": 0x80069cec,
		"PakkunSeedCallback": 0x80069cec,
		"TStayPakkun::setAfterDeadEffect": 0x80069dfc,
		"TPakkun::isCollidMove": 0x80069e00,
		"TPakkun::decHpByWater": 0x80069e08,
		"TSmallEnemy::initAttacker": 0x80069e0c,
		"TPakkunManager::~TPakkunManager": 0x80069fbc,
		"Enemy::__sinit_pakkun_cpp": 0x8006a030,
		"__sinit_pakkun_cpp": 0x8006a030,
		"TNerveSmallEnemyChange::~TNerveSmallEnemyChange": 0x8006a344,
		"TNerveSmallEnemyChange::execute": 0x8006a3a0,
		"TNerveSmallEnemyChange::theNerve": 0x8006a494,
		"TNerveSmallEnemyWait::execute": 0x8006a4f8,
		"TSmallEnemy::setWaitAnm": 0x8006a590,
		"TNerveSmallEnemyWait::theNerve": 0x8006a594,
		"TNerveSmallEnemyWait::~TNerveSmallEnemyWait": 0x8006a5f8,
		"TNerveSmallEnemyHitWaterJump::execute": 0x8006a654,
		"TNerveSmallEnemyHitWaterJump::theNerve": 0x8006a85c,
		"TNerveSmallEnemyHitWaterJump::~TNerveSmallEnemyHitWaterJump": 0x8006a8c0,
		"TNerveSmallEnemyJump::execute": 0x8006a91c,
		"TNerveSmallEnemyJump::theNerve": 0x8006aa2c,
		"TNerveSmallEnemyJump::~TNerveSmallEnemyJump": 0x8006aa90,
		"TNerveSmallEnemyFreeze::execute": 0x8006aaec,
		"TNerveSmallEnemyFreeze::theNerve": 0x8006ab8c,
		"TNerveSmallEnemyFreeze::~TNerveSmallEnemyFreeze": 0x8006abf0,
		"TNerveSmallEnemyDie::execute": 0x8006ac4c,
		"TNerveSmallEnemyDie::~TNerveSmallEnemyDie": 0x8006af94,
		"TSmallEnemy::setDeadAnm": 0x8006aff0,
		"TNerveSmallEnemyDie::theNerve": 0x8006aff4,
		"TSmallEnemy::perform": 0x8006b058,
		"TSmallEnemy::behaveToHitOthers": 0x8006b0d4,
		"behaveToHitOthers": 0x8006b0d4,
		"TSmallEnemy::isHitWallInBound": 0x8006b21c,
		"isHitWallInBound": 0x8006b21c,
		"TSmallEnemy::isEaten": 0x8006b354,
		"isEaten": 0x8006b354,
		"TSmallEnemy::expandCollision": 0x8006b3f0,
		"expandCollision": 0x8006b3f0,
		"TSmallEnemy::setBckAnm": 0x8006b52c,
		"TSmallEnemy::generateEffectColumWater": 0x8006b5a0,
		"TSmallEnemy::isFindMarioFromParam": 0x8006b630,
		"isFindMarioFromParam": 0x8006b630,
		"TSmallEnemy::isMarioInWater": 0x8006b6ec,
		"isMarioInWater": 0x8006b6ec,
		"TSmallEnemy::isFindMario": 0x8006b7bc,
		"TSmallEnemy::kill": 0x8006b928,
		"TSmallEnemy::decHpByWater": 0x8006bab8,
		"TSmallEnemy::changeOut": 0x8006bb04,
		"TSmallEnemy::scalingChangeActor": 0x8006bbe0,
		"TSmallEnemy::changeMove": 0x8006bc74,
		"changeMove": 0x8006bc74,
		"TSmallEnemy::getChangeBlockTime": 0x8006c0d0,
		"TSmallEnemy::changeByJuice": 0x8006c0d8,
		"TSmallEnemy::receiveMessage": 0x8006c340,
		"TSmallEnemy::updateAnmSound": 0x8006c570,
		"TSmallEnemy::moveObject": 0x8006c590,
		"TSmallEnemy::isCollidMove": 0x8006c9f0,
		"TSmallEnemy::generateItem": 0x8006ca5c,
		"TSmallEnemy::setAfterDeadEffect": 0x8006cb64,
		"TSmallEnemy::genEventCoin": 0x8006cc5c,
		"TSmallEnemy::genRandomItem": 0x8006cf60,
		"TSmallEnemy::forceKill": 0x8006cff0,
		"TSmallEnemy::reset": 0x8006d214,
		"TSmallEnemy::attackToMario": 0x8006d648,
		"TSmallEnemy::sendAttackMsgToMario": 0x8006d758,
		"TSmallEnemy::behaveToWater": 0x8006d77c,
		"TSmallEnemy::loadAfter": 0x8006d8f4,
		"TSmallEnemy::load": 0x8006d928,
		"TSmallEnemy::init": 0x8006d998,
		"TSmallEnemy::setMActorAndKeeper": 0x8006dd24,
		"TSmallEnemy::TSmallEnemy": 0x8006dd8c,
		"TSmallEnemyManager::getHolder": 0x8006de18,
		"getHolder": 0x8006de18,
		"TSmallEnemyManager::createEnemies": 0x8006de8c,
		"TSmallEnemyManager::loadAfter": 0x8006decc,
		"TSmallEnemyManager::load": 0x8006df24,
		"TSmallEnemyManager::createModelData": 0x8006df44,
		"TSmallEnemyManager::TSmallEnemyManager": 0x8006df78,
		"TSmallEnemyParams::TSmallEnemyParams": 0x8006dfc4,
		"Enemy::__sinit_smallEnemy_cpp": 0x8006e508,
		"__sinit_smallEnemy_cpp": 0x8006e508,
		"TSpider::bind": 0x8006e80c,
		"TSpider::~TSpider": 0x8006ed80,
		"TSpider::TSpider": 0x8006ede4,
		"TSplinePath::calcSpline": 0x8006ee38,
		"calcSpline": 0x8006ee38,
		"TSplinePath::calcTable": 0x8006ef1c,
		"calcTable": 0x8006ef1c,
		"TSplinePath::makeTable": 0x8006f07c,
		"makeTable": 0x8006f07c,
		"TSplinePath::TSplinePath": 0x8006f3e0,
		"TNerveTypicalGraphWander::~TNerveTypicalGraphWander": 0x8006f4f8,
		"TNerveTypicalGraphWander::execute": 0x8006f554,
		"TNerveTypicalGraphWander::theNerve": 0x8006f658,
		"TTypicalManager::createEnemyInstance": 0x8006f6bc,
		"TTypicalManager::load": 0x8006f744,
		"TTypicalManager::TTypicalManager": 0x8006f804,
		"TTypicalEnemy::init": 0x8006f840,
		"TTypicalEnemy::TTypicalEnemy": 0x8006f8f8,
		"TTypicalManager::~TTypicalManager": 0x8006f960,
		"TWalker::setMode": 0x8006fa38,
		"setMode": 0x8006fa38,
		"TWalker::bind": 0x8006faa4,
		"TWalker::reset": 0x80070708,
		"TWalker::~TWalker": 0x80070728,
		"TWalker::TWalker": 0x800707a0,
		"TSolidStack<TBGCheckData_const*>::~TSolidStack": 0x8007085c,
		"Enemy::calcFarthestVertex": 0x800708a8,
		"calcFarthestVertex": 0x800708a8,
		"TNerveWalkerTraceMario::~TNerveWalkerTraceMario": 0x80070a70,
		"TNerveWalkerTraceMario::execute": 0x80070acc,
		"TNerveWalkerTraceMario::theNerve": 0x80070d88,
		"TNerveWalkerEscape::execute": 0x80070dec,
		"TNerveWalkerEscape::theNerve": 0x80070f4c,
		"TNerveWalkerEscape::~TNerveWalkerEscape": 0x80070fb0,
		"TNerveWalkerPostAttack::execute": 0x8007100c,
		"TNerveWalkerPostAttack::theNerve": 0x800710a4,
		"TNerveWalkerPostAttack::~TNerveWalkerPostAttack": 0x80071108,
		"TNerveWalkerAttack::execute": 0x80071164,
		"TNerveWalkerAttack::theNerve": 0x800712e0,
		"TNerveWalkerAttack::~TNerveWalkerAttack": 0x80071344,
		"TNerveWalkerGraphWander::execute": 0x800713a0,
		"TNerveWalkerGraphWander::theNerve": 0x8007147c,
		"TNerveWalkerGraphWander::~TNerveWalkerGraphWander": 0x800714e0,
		"TNerveWalkerGenerate::execute": 0x8007153c,
		"TNerveWalkerGenerate::theNerve": 0x8007161c,
		"TNerveWalkerGenerate::~TNerveWalkerGenerate": 0x80071680,
		"TWalkerEnemy::initialGraphNode": 0x800716dc,
		"initialGraphNode": 0x800716dc,
		"TWalkerEnemy::isReachedToGoalXZ": 0x80071708,
		"TWalkerEnemy::isResignationAttack": 0x800717d0,
		"TWalkerEnemy::initAttacker": 0x800718ac,
		"TWalkerEnemy::behaveToFindMario": 0x800718d0,
		"TWalkerEnemy::walkBehavior": 0x80071be8,
		"TWalkerEnemy::reset": 0x80071cfc,
		"TWalkerEnemy::attackToMario": 0x80071e60,
		"TWalkerEnemy::moveObject": 0x80072014,
		"TWalkerEnemy::init": 0x800721e4,
		"TWalkerEnemy::TWalkerEnemy": 0x80072310,
		"TWalkerEnemyParams::TWalkerEnemyParams": 0x80072354,
		"Enemy::__sinit_walkerEnemy_cpp": 0x80072498,
		"__sinit_walkerEnemy_cpp": 0x80072498,
		"TNerveBGRoll::~TNerveBGRoll": 0x8007279c,
		"TNerveBGRoll::execute": 0x800727f8,
		"MActorAnmEach<J3DAnmTransformKey>::setFrameCtrl": 0x80072f14,
		"setFrameCtrl": 0x80072f14,
		"MActorAnmDataEach<J3DAnmTransformKey>::getAnmPtr": 0x80072fa0,
		"getAnmPtr": 0x80072fa0,
		"TMActorKeeper::getMActorAnmData": 0x80072fc4,
		"TNerveBGRoll::theNerve": 0x80072fcc,
		"TNerveBGPolDrop::execute": 0x80073030,
		"TNerveBGPolDrop::~TNerveBGPolDrop": 0x8007336c,
		"TNerveBGPolDrop::theNerve": 0x800733c8,
		"TNerveBGPollute::execute": 0x8007342c,
		"TNerveBGPollute::theNerve": 0x8007369c,
		"TNerveBGPollute::~TNerveBGPollute": 0x80073700,
		"TNerveBGDie::execute": 0x8007375c,
		"TNerveBGDie::theNerve": 0x80073e70,
		"TNerveBGDie::~TNerveBGDie": 0x80073ed4,
		"TNerveBGTug::execute": 0x80073f30,
		"TNerveBGTug::theNerve": 0x800743cc,
		"TNerveBGTug::~TNerveBGTug": 0x80074430,
		"TNerveBGTentacleDamage::execute": 0x8007448c,
		"TNerveBGTentacleDamage::~TNerveBGTentacleDamage": 0x80074754,
		"TNerveBGTentacleDamage::theNerve": 0x800747b0,
		"TNerveBGBeakDamage::execute": 0x80074814,
		"TNerveBGBeakDamage::theNerve": 0x80074d94,
		"TNerveBGBeakDamage::~TNerveBGBeakDamage": 0x80074df8,
		"TNerveBGEyeDamage::execute": 0x80074e54,
		"TNerveBGEyeDamage::theNerve": 0x800750f8,
		"TNerveBGEyeDamage::~TNerveBGEyeDamage": 0x8007515c,
		"TNerveBGWait::execute": 0x800751b8,
		"TNerveBGWait::theNerve": 0x800755bc,
		"TNerveBGWait::~TNerveBGWait": 0x80075620,
		"TBossGessoManager::load": 0x8007567c,
		"TBossGessoManager::initJParticle": 0x800756f0,
		"TBossGessoManager::createModelData": 0x80075bd4,
		"TBossGessoManager::TBossGessoManager": 0x80075c08,
		"TBossGesso::perform": 0x80075c44,
		"TBossGesso::calcRootMatrix": 0x80076610,
		"TBossGesso::reset": 0x800767d8,
		"TBossGesso::moveObject": 0x800768a0,
		"Enemy::MsGetRotFromZaxisY": 0x80076fa4,
		"MsGetRotFromZaxisY": 0x80076fa4,
		"Enemy::SMS_GetMarioPos": 0x8007706c,
		"SMS_GetMarioPos": 0x8007706c,
		"TBossGesso::doAttackShoot": 0x80077074,
		"doAttackShoot": 0x80077074,
		"TBossGesso::doAttackUnison": 0x80077280,
		"doAttackUnison": 0x80077280,
		"TBossGesso::doAttackSkipRope": 0x80077530,
		"doAttackSkipRope": 0x80077530,
		"TBossGesso::doAttackDouble": 0x8007770c,
		"doAttackDouble": 0x8007770c,
		"TBossGesso::doAttackSingle": 0x800779c0,
		"doAttackSingle": 0x800779c0,
		"TBossGesso::receiveMessage": 0x80078418,
		"TBossGesso::getBasNameTable": 0x80078470,
		"TBossGesso::beakHeld": 0x8007847c,
		"beakHeld": 0x8007847c,
		"TBossGesso::tentacleHeld": 0x80078498,
		"tentacleHeld": 0x80078498,
		"TBossGesso::launchPolDrop": 0x80078500,
		"TBossGesso::changeAllTentacleState": 0x800785fc,
		"changeAllTentacleState": 0x800785fc,
		"TBossGesso::gotTentacleDamage": 0x800786a0,
		"gotTentacleDamage": 0x800786a0,
		"TBossGesso::changeAttackMode": 0x80078834,
		"changeAttackMode": 0x80078834,
		"TBossGesso::stopIfRoll": 0x80078e50,
		"stopIfRoll": 0x80078e50,
		"TBossGesso::is2ndFightNow": 0x80078f6c,
		"is2ndFightNow": 0x80078f6c,
		"TBossGesso::showMessage": 0x80078f8c,
		"TBossGesso::lenFromToeToMario": 0x80079010,
		"lenFromToeToMario": 0x80079010,
		"TBossGesso::rumblePad": 0x800791ac,
		"TBossGesso::init": 0x8007930c,
		"TBossGesso::TBossGesso": 0x80079bcc,
		"TBGBinder::bind": 0x80079ca0,
		"TBGBodyHit::perform": 0x8007a2f4,
		"TBGBodyHit::receiveMessage": 0x8007a35c,
		"TBGEyeHit::perform": 0x8007a3c4,
		"TBGEyeHit::receiveMessage": 0x8007a414,
		"TBGBeakHit::perform": 0x8007a6d0,
		"TBGBeakHit::receiveMessage": 0x8007ad28,
		"TBGBeakHit::moveRequest": 0x8007b488,
		"TBGBeakHit::getTakingMtx": 0x8007b638,
		"TBossGessoParams::TBossGessoParams": 0x8007b640,
		"TBossGessoManager::~TBossGessoManager": 0x8007bbec,
		"TBGBinder::~TBGBinder": 0x8007bcbc,
		"TBossGessoMtxCalc::~TBossGessoMtxCalc": 0x8007bd20,
		"Enemy::__sinit_bossgesso_cpp": 0x8007bf70,
		"__sinit_bossgesso_cpp": 0x8007bf70,
		"TNerveElecCarapaceReturn::~TNerveElecCarapaceReturn": 0x8007c2c8,
		"TNerveElecCarapaceReturn::execute": 0x8007c324,
		"TNerveElecNokonokoFreeze::~TNerveElecNokonokoFreeze": 0x8007c6b4,
		"TNerveElecCarapaceWait::execute": 0x8007c710,
		"TNerveElecCarapaceWait::~TNerveElecCarapaceWait": 0x8007c72c,
		"TNerveElecCarapaceMove::execute": 0x8007c788,
		"TNerveElecNokonokoCollect::~TNerveElecNokonokoCollect": 0x8007cc80,
		"TNerveElecCarapaceMove::~TNerveElecCarapaceMove": 0x8007ccdc,
		"TNerveElecNokonokoAttack::execute": 0x8007cd38,
		"TNerveElecNokonokoAttack::~TNerveElecNokonokoAttack": 0x8007cdc4,
		"TNerveElecNokonokoRebirth::execute": 0x8007ce20,
		"TNerveElecNokonokoRebirth::~TNerveElecNokonokoRebirth": 0x8007cf38,
		"TNerveElecNokonokoFreeze::execute": 0x8007cf94,
		"TNerveElecNokonokoTurn::execute": 0x8007d298,
		"TNerveElecNokonokoTurn::~TNerveElecNokonokoTurn": 0x8007d4bc,
		"TNerveElecNokonokoCollect::execute": 0x8007d518,
		"TNerveElecNokonokoShoot::execute": 0x8007d7f4,
		"TNerveElecNokonokoShoot::~TNerveElecNokonokoShoot": 0x8007d9ec,
		"TElecCarapace::reflect": 0x8007da48,
		"reflect": 0x8007da48,
		"TElecCarapace::receiveMessage": 0x8007dc5c,
		"TElecCarapace::sendMessage": 0x8007dcec,
		"TElecCarapace::calcRootMatrix": 0x8007dee4,
		"TElecCarapace::bind": 0x8007e0e0,
		"TElecCarapace::shoot": 0x8007e120,
		"TElecCarapace::appear": 0x8007e414,
		"TElecCarapace::getNowGravity": 0x8007e47c,
		"TElecCarapace::behaveToHitWall": 0x8007e4b0,
		"TElecCarapace::kill": 0x8007e5b0,
		"TElecCarapace::behaveToHitGround": 0x8007e5d0,
		"TElecCarapace::setBehavior": 0x8007e690,
		"TElecCarapace::perform": 0x8007e6f8,
		"TElecCarapace::loadInit": 0x8007e848,
		"TElecCarapace::TElecCarapace": 0x8007ea38,
		"TElecNokonoko::genRandomItem": 0x8007eab4,
		"TElecNokonoko::setMeltAnm": 0x8007eb68,
		"TElecNokonoko::setDeadAnm": 0x8007ec3c,
		"TElecNokonoko::setRunAnm": 0x8007ec6c,
		"TElecNokonoko::setWalkAnm": 0x8007ecbc,
		"TElecNokonoko::setWaitAnm": 0x8007ed0c,
		"TElecNokonoko::getBasNameTable": 0x8007ed44,
		"TElecNokonoko::behaveToWater": 0x8007ed50,
		"TElecNokonoko::behaveToFindMario": 0x8007eef8,
		"TElecNokonoko::isResignationAttack": 0x8007f08c,
		"TElecNokonoko::receiveMessage": 0x8007f1e4,
		"TElecNokonoko::sendAttackMsgToMario": 0x8007f368,
		"TElecNokonoko::calcRootMatrix": 0x8007f3a4,
		"TElecNokonoko::attackToMario": 0x8007f740,
		"TElecNokonoko::moveObject": 0x8007f950,
		"TElecNokonoko::setMActorAndKeeper": 0x8007f9c8,
		"TElecNokonoko::load": 0x8007fa60,
		"TElecNokonoko::rest": 0x8007faa0,
		"rest": 0x8007faa0,
		"TElecNokonoko::init": 0x8007fad4,
		"TElecNokonoko::TElecNokonoko": 0x8007fc4c,
		"TElecNokonokoManager::perform": 0x8007fca0,
		"TElecNokonokoManager::clipEnemies": 0x8007fd40,
		"TElecNokonokoManager::createModelData": 0x8007fe68,
		"TElecNokonokoManager::createEnemyInstance": 0x8007fe9c,
		"TElecNokonokoManager::initSetEnemies": 0x8007ff08,
		"TElecNokonokoManager::load": 0x8007ff0c,
		"TElecNokonokoManager::TElecNokonokoManager": 0x800800d8,
		"TElecCarapace::rebirth": 0x80080198,
		"TElecCarapace::recoverScale": 0x8008019c,
		"TElecCarapace::getPhaseShift": 0x800801a0,
		"TElecNokonokoManager::~TElecNokonokoManager": 0x80080258,
		"Enemy::__sinit_elecNokonoko_cpp": 0x800802cc,
		"__sinit_elecNokonoko_cpp": 0x800802cc,
		"TNerveKageMarioModokiWait::~TNerveKageMarioModokiWait": 0x800805d8,
		"TNerveKageMarioModokiWait::execute": 0x80080634,
		"TKageMarioModoki::init": 0x800807d0,
		"TKageMarioModoki::load": 0x800808d4,
		"TKageMarioModokiManager::createModelData": 0x80080914,
		"TKageMarioModokiManager::createEnemyInstance": 0x80080948,
		"TKageMarioModokiManager::load": 0x800809a4,
		"TNerveTelesaTrample::execute": 0x80080a10,
		"TNerveTelesaTrample::~TNerveTelesaTrample": 0x80080a70,
		"TNerveTelesaAttackMario::execute": 0x80080acc,
		"TNerveTelesaAttackMario::~TNerveTelesaAttackMario": 0x80080d98,
		"TNerveTelesaFreeze::execute": 0x80080df4,
		"TNerveTelesaFreeze::~TNerveTelesaFreeze": 0x80081014,
		"TNerveTelesaDie::execute": 0x80081070,
		"TNerveTelesaDie::~TNerveTelesaDie": 0x800812d4,
		"TNerveTelesaImitate::execute": 0x80081330,
		"TNerveTelesaImitate::~TNerveTelesaImitate": 0x800816e0,
		"TMarioModokiTelesa::init": 0x8008173c,
		"TMarioModokiTelesa::load": 0x800817d0,
		"TMarioModokiTelesa::TMarioModokiTelesa": 0x80081b8c,
		"TBoxTelesa::isHitValid": 0x80081c74,
		"TBoxTelesa::reset": 0x80081dac,
		"TBoxTelesa::load": 0x80082058,
		"TBoxTelesa::TBoxTelesa": 0x80082160,
		"TLoopTelesa::load": 0x800821a4,
		"TLoopTelesa::TLoopTelesa": 0x8008221c,
		"TSeeTelesa::load": 0x80082260,
		"TSeeTelesa::TSeeTelesa": 0x800822e8,
		"TTelesa::changeTevKColor": 0x8008232c,
		"changeTevKColor": 0x8008232c,
		"TTelesa::isCollidMove": 0x80082544,
		"TTelesa::setAttacker": 0x80082564,
		"setAttacker": 0x80082564,
		"TTelesa::initItemAttacker": 0x800826d8,
		"initItemAttacker": 0x800826d8,
		"TTelesa::initAttacker": 0x80082944,
		"TTelesa::kill": 0x80082c28,
		"TTelesa::forceKill": 0x80082d64,
		"TTelesa::getGravityY": 0x80082e3c,
		"TTelesa::reduceFlyForce": 0x80082e60,
		"reduceFlyForce": 0x80082e60,
		"TTelesa::setWaitAnm": 0x80082efc,
		"TTelesa::setWalkAnm": 0x80082f2c,
		"TTelesa::getBasNameTable": 0x80082fa0,
		"TTelesa::changeOut": 0x80082fac,
		"TTelesa::scalingChangeActor": 0x80083088,
		"TTelesa::changeByJuice": 0x80083104,
		"TTelesa::isReachedToGoal": 0x80083324,
		"TTelesa::bind": 0x800833ec,
		"TTelesa::moveObject": 0x80083730,
		"TTelesa::calcRootMatrix": 0x80083764,
		"TTelesa::walkBehavior": 0x8008396c,
		"TTelesa::behaveToWater": 0x80083b2c,
		"TTelesa::attackToMario": 0x80083dbc,
		"TTelesa::setBehavior": 0x80083e38,
		"TTelesa::drawObject": 0x80083f9c,
		"TTelesa::perform": 0x80083fc8,
		"TTelesa::reset": 0x80084124,
		"TTelesa::setMActorAndKeeper": 0x800843c8,
		"TTelesa::init": 0x80084434,
		"TTelesa::load": 0x800846cc,
		"TTelesa::TTelesa": 0x8008472c,
		"TTelesaManager::setFlagOutOfCube": 0x800847cc,
		"TTelesaManager::telesaForceKill": 0x800848a0,
		"telesaForceKill": 0x800848a0,
		"TTelesaManager::createModelData": 0x80084968,
		"TTelesaManager::createEnemies": 0x8008499c,
		"TTelesaManager::createEnemyInstance": 0x80084a7c,
		"TTelesaManager::load": 0x80084ac0,
		"TTelesaManager::TTelesaManager": 0x80084b70,
		"TTelesaSaveLoadParams::TTelesaSaveLoadParams": 0x80084bbc,
		"TKageMarioModokiManager::~TKageMarioModokiManager": 0x80084f9c,
		"TTelesa::isFindMario": 0x80085010,
		"TTelesa::decHpByWater": 0x80085018,
		"TTelesa::isInhibitedForceMove": 0x8008501c,
		"TTelesa::getChangeBlockTime": 0x80085024,
		"TBoxTelesa::isEatenByYosshi": 0x800850c8,
		"TTelesaManager::~TTelesaManager": 0x800852a4,
		"Enemy::__sinit_telesa_cpp": 0x80085318,
		"__sinit_telesa_cpp": 0x80085318,
		"TNerveFireWanwanEscape::~TNerveFireWanwanEscape": 0x80085644,
		"TNerveFireWanwanEscape::execute": 0x800856a0,
		"TNerveFireWanwanRecover::~TNerveFireWanwanRecover": 0x80085940,
		"TNerveFireWanwanEscape::theNerve": 0x8008599c,
		"TNerveFireWanwanFreeze::execute": 0x80085a00,
		"TNerveFireWanwanFreeze::theNerve": 0x80085b70,
		"TNerveFireWanwanFreeze::~TNerveFireWanwanFreeze": 0x80085bd4,
		"TNerveFireWanwanFly::execute": 0x80085c30,
		"TNerveFireWanwanFly::~TNerveFireWanwanFly": 0x80085f2c,
		"TNerveFireWanwanHungTail::execute": 0x80085f88,
		"TNerveFireWanwanHungTail::~TNerveFireWanwanHungTail": 0x800861f0,
		"TNerveFireWanwanDie::execute": 0x8008624c,
		"TNerveFireWanwanDie::theNerve": 0x800864ac,
		"TNerveFireWanwanDie::~TNerveFireWanwanDie": 0x80086510,
		"TNerveFireWanwanRecover::execute": 0x8008656c,
		"TNerveFireWanwanRecover::theNerve": 0x800867b0,
		"TNerveFireWanwanRecoverGraph::execute": 0x80086814,
		"TNerveFireWanwanGraphWander::~TNerveFireWanwanGraphWander": 0x80086db8,
		"JGeometry::TQuat4<float><float>::slerp": 0x80086e5c,
		"slerp": 0x80086e5c,
		"TNerveFireWanwanRecoverGraph::~TNerveFireWanwanRecoverGraph": 0x800870a4,
		"TNerveFireWanwanTired::execute": 0x80087100,
		"TNerveFireWanwanFindMario::~TNerveFireWanwanFindMario": 0x800872c8,
		"TNerveFireWanwanTired::~TNerveFireWanwanTired": 0x80087324,
		"TNerveFireWanwanAttack::execute": 0x80087380,
		"TNerveFireWanwanAttack::~TNerveFireWanwanAttack": 0x80087630,
		"TNerveFireWanwanFindMario::execute": 0x8008768c,
		"TNerveFireWanwanTurn::execute": 0x80087ba0,
		"TNerveFireWanwanTurn::theNerve": 0x80087dbc,
		"TNerveFireWanwanTurn::~TNerveFireWanwanTurn": 0x80087e20,
		"TNerveFireWanwanGraphWander::execute": 0x80087e7c,
		"TNerveFireWanwanGraphWander::theNerve": 0x80088014,
		"TFireWanwan::isCollidMove": 0x80088078,
		"TFireWanwan::doKeepDistance": 0x80088080,
		"TFireWanwan::getBasNameTable": 0x80088094,
		"TFireWanwan::getGravityY": 0x800880a0,
		"TFireWanwan::checkWalls": 0x800881c8,
		"TFireWanwan::bindPoint": 0x800883e4,
		"bindPoint": 0x800883e4,
		"TFireWanwan::bindBody": 0x800887bc,
		"bindBody": 0x800887bc,
		"TFireWanwan::bind": 0x80088b34,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setQuat": 0x80089338,
		"setQuat": 0x80089338,
		"TFireWanwan::attackToMario": 0x800893d8,
		"TFireWanwan::sendAttackMsgToMario": 0x800895b4,
		"TTakeActor::isTaken": 0x800895b8,
		"isTaken": 0x800895b8,
		"TFireWanwan::initEscapeNextGraphNode": 0x800895d4,
		"initEscapeNextGraphNode": 0x800895d4,
		"TFireWanwan::checkHitActors": 0x800897d8,
		"TFireWanwan::emitEffects": 0x80089aa4,
		"TFireWanwan::updatePollute": 0x8008a000,
		"updatePollute": 0x8008a000,
		"TFireWanwan::updateRumble": 0x8008a1c8,
		"updateRumble": 0x8008a1c8,
		"TFireWanwan::moveObject": 0x8008a3c0,
		"TFireWanwan::calcRootMatrix": 0x8008aaa8,
		"TFireWanwan::perform": 0x8008ac70,
		"TFireWanwan::isHitValid": 0x8008adb8,
		"TFireWanwan::kill": 0x8008adc0,
		"TFireWanwan::behaveToWater": 0x8008aed8,
		"TFireWanwan::receiveMessage": 0x8008b260,
		"TFireWanwan::isMissMario": 0x8008b3b8,
		"isMissMario": 0x8008b3b8,
		"TFireWanwan::isFindMario": 0x8008b578,
		"TFireWanwan::reset": 0x8008b5e4,
		"TFireWanwan::setMActorAndKeeper": 0x8008b738,
		"TFireWanwan::init": 0x8008b7a4,
		"TFireWanwan::TFireWanwan": 0x8008ba9c,
		"TFireWanwanTailHit::getHostPos": 0x8008baf8,
		"getHostPos": 0x8008baf8,
		"TFireWanwanTailHit::moveRequest": 0x8008bb04,
		"TFireWanwanTailHit::getTakingMtx": 0x8008bc28,
		"TFireWanwanTailHit::movementBody": 0x8008bc30,
		"movementBody": 0x8008bc30,
		"TFireWanwanTailHit::performNodes": 0x8008c044,
		"performNodes": 0x8008c044,
		"TFireWanwanTailHit::perform": 0x8008c30c,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::operator_[]": 0x8008c968,
		"operator_[]": 0x8008c968,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::size": 0x8008c978,
		"size": 0x8008c978,
		"TFireWanwanTailHit::init": 0x8008c980,
		"TTailRubber::Node::Node": 0x8008ce58,
		"TFireWanwanTailHit::receiveMessage": 0x8008ce5c,
		"TFireWanwanTailNode::perform": 0x8008d0e0,
		"TFireWanwanManager::perform": 0x8008d2d0,
		"TFireWanwanManager::createModelData": 0x8008d56c,
		"TFireWanwanManager::load": 0x8008d5a0,
		"TFireWanwanManager::TFireWanwanManager": 0x8008d5f8,
		"TFireWanwanSaveLoadParams::TFireWanwanSaveLoadParams": 0x8008d654,
		"TTailRubber::getLength": 0x8008dc0c,
		"TTailRubber::restrict": 0x8008dcec,
		"restrict": 0x8008dcec,
		"TTailRubber::adjust": 0x8008e160,
		"TTailRubber::bindOne": 0x8008e618,
		"bindOne": 0x8008e618,
		"TFireWanwanManager::~TFireWanwanManager": 0x8008e86c,
		"MyUtil::value_lerp": 0x8008e8e0,
		"value_lerp": 0x8008e8e0,
		"Enemy::__sinit_fireWanwan_cpp": 0x8008ebb8,
		"__sinit_fireWanwan_cpp": 0x8008ebb8,
		"TStageEnemyInfo::~TStageEnemyInfo": 0x8008eec4,
		"TStageEnemyInfoTable::getMatchedInfo": 0x8008ef28,
		"getMatchedInfo": 0x8008ef28,
		"TStageEnemyInfoTable::TStageEnemyInfoTable": 0x8008f03c,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::~TNameRefPtrAryT": 0x8008f0c8,
		"TStageEnemyInfo::load": 0x8008f140,
		"TStageEnemyInfoTable::~TStageEnemyInfoTable": 0x8008f1cc,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::loadAfter": 0x8008f254,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::searchF": 0x8008f2b4,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::load": 0x8008f350,
		"TOneShotGenerator::receiveMessage": 0x8008f4e4,
		"TOneShotGenerator::loadAfter": 0x8008f5dc,
		"TOneShotGenerator::load": 0x8008f710,
		"TOneShotGenerator::TOneShotGenerator": 0x8008f760,
		"TGenerator::perform": 0x8008f7c0,
		"TGenerator::load": 0x8008f8e0,
		"TGenerator::TGenerator": 0x8008fa88,
		"TGenerator::~TGenerator": 0x8008fb0c,
		"TNerveBPCannonL::~TNerveBPCannonL": 0x8008fb88,
		"TNerveBPCannonL::execute": 0x8008fbe4,
		"TNerveBPWaitL::~TNerveBPWaitL": 0x8008fd1c,
		"TNerveBPCannonL::theNerve": 0x8008fd78,
		"TNerveBPWaitL::execute": 0x8008fddc,
		"TNerveBPWaitL::theNerve": 0x80090010,
		"TNerveBPBreakSleep::execute": 0x80090074,
		"TNerveBPTakeOff::~TNerveBPTakeOff": 0x80090168,
		"TNerveBPBreakSleep::theNerve": 0x800901c4,
		"TNerveBPBreakSleep::~TNerveBPBreakSleep": 0x80090228,
		"TNerveBPSleep::execute": 0x80090284,
		"TNerveBPSleep::theNerve": 0x800902bc,
		"TNerveBPSleep::~TNerveBPSleep": 0x80090320,
		"TNerveBPFall::execute": 0x8009037c,
		"TNerveBPTornado::~TNerveBPTornado": 0x80090898,
		"TNerveBPWait::~TNerveBPWait": 0x800908f4,
		"TNerveBPVomit::~TNerveBPVomit": 0x80090950,
		"TNerveBPFall::theNerve": 0x800909ac,
		"TNerveBPFall::~TNerveBPFall": 0x80090a10,
		"TNerveBPHover::execute": 0x80090a6c,
		"TNerveBPFly::~TNerveBPFly": 0x80090df4,
		"TNerveBPFlyPivot::~TNerveBPFlyPivot": 0x80090e50,
		"TNerveBPFlyCannon::~TNerveBPFlyCannon": 0x80090eac,
		"TNerveBPHover::~TNerveBPHover": 0x80090f08,
		"TNerveBPHover::theNerve": 0x80090f64,
		"TNerveBPFlyPivot::execute": 0x80090fc8,
		"TNerveBPFlyPivot::theNerve": 0x80091074,
		"TNerveBPFlyCannon::execute": 0x800910d8,
		"TNerveBPFlyCannon::theNerve": 0x8009116c,
		"TNerveBPTouchDown::execute": 0x800911d0,
		"TNerveBPTouchDown::theNerve": 0x80091360,
		"TNerveBPTouchDown::~TNerveBPTouchDown": 0x800913c4,
		"TNerveBPFly::execute": 0x80091420,
		"TNerveBPFly::theNerve": 0x800916ec,
		"TNerveBPTakeOff::execute": 0x80091750,
		"TNerveBPTakeOff::theNerve": 0x80091978,
		"TNerveBPDie::execute": 0x800919dc,
		"TNerveBPDie::theNerve": 0x80091af4,
		"TNerveBPDie::~TNerveBPDie": 0x80091b58,
		"TNerveBPPreDie::execute": 0x80091bb4,
		"TNerveBPPreDie::theNerve": 0x80091d8c,
		"TNerveBPPreDie::~TNerveBPPreDie": 0x80091df0,
		"TNerveBPJumpReact::execute": 0x80091e4c,
		"TNerveBPJumpReact::theNerve": 0x80091eb0,
		"TNerveBPJumpReact::~TNerveBPJumpReact": 0x80091f14,
		"TNerveBPStompReact::execute": 0x80091f70,
		"TNerveBPStompReact::theNerve": 0x800920ac,
		"TNerveBPStompReact::~TNerveBPStompReact": 0x80092110,
		"TNerveBPSwing::execute": 0x8009216c,
		"TNerveBPSwing::theNerve": 0x8009221c,
		"TNerveBPSwing::~TNerveBPSwing": 0x80092280,
		"TNerveBPGetUp::execute": 0x800922dc,
		"TNerveBPGetUp::theNerve": 0x80092394,
		"TNerveBPGetUp::~TNerveBPGetUp": 0x800923f8,
		"TNerveBPTumbleOut::execute": 0x80092454,
		"TNerveBPTumbleOut::theNerve": 0x800926c8,
		"TNerveBPTumbleOut::~TNerveBPTumbleOut": 0x8009272c,
		"TNerveBPTumble::execute": 0x80092788,
		"TNerveBPTumble::theNerve": 0x80092900,
		"TNerveBPTumble::~TNerveBPTumble": 0x80092964,
		"TNerveBPTumbleIn::execute": 0x800929c0,
		"TNerveBPTumbleIn::theNerve": 0x80092b14,
		"TNerveBPTumbleIn::~TNerveBPTumbleIn": 0x80092b78,
		"TNerveBPSwallow::execute": 0x80092bd4,
		"TNerveBPSwallow::theNerve": 0x80092dc4,
		"TNerveBPSwallow::~TNerveBPSwallow": 0x80092e28,
		"TNerveBPPivot::execute": 0x80092e84,
		"TNerveBPPivot::theNerve": 0x80092fdc,
		"TNerveBPPivot::~TNerveBPPivot": 0x80093040,
		"TNerveBPTornado::execute": 0x8009309c,
		"TNerveBPTornado::theNerve": 0x80093218,
		"TNerveBPVomit::execute": 0x8009327c,
		"TNerveBPVomit::theNerve": 0x800935ec,
		"TNerveBPCannon::execute": 0x80093650,
		"TNerveBPCannon::theNerve": 0x80093774,
		"TNerveBPCannon::~TNerveBPCannon": 0x800937d8,
		"TNerveBPWait::execute": 0x80093834,
		"TNerveBPWait::theNerve": 0x8009448c,
		"TBossPakkunManager::load": 0x800944f0,
		"TBossPakkunManager::createModelData": 0x800947b4,
		"TBossPakkunManager::TBossPakkunManager": 0x80094810,
		"TBossPakkun::perform": 0x8009485c,
		"TBossPakkun::receiveMessage": 0x8009502c,
		"TBossPakkun::kill": 0x8009527c,
		"TBossPakkun::setGroundCollision": 0x800952fc,
		"TBossPakkun::getBasNameTable": 0x80095480,
		"TBossPakkun::changeBck": 0x8009548c,
		"TBossPakkun::launchPolDrop": 0x80095804,
		"TBossPakkun::gotHipDropDamage": 0x80095a0c,
		"gotHipDropDamage": 0x80095a0c,
		"TBossPakkun::showMessage": 0x80095fb4,
		"TBossPakkun::rumblePad": 0x80096024,
		"TBossPakkun::checkMarioRiding": 0x80096184,
		"TBossPakkun::init": 0x8009622c,
		"TBossPakkun::TBossPakkun": 0x800969fc,
		"TBossPakkunMtxCalc::calcHeadDir": 0x80096b20,
		"calcHeadDir": 0x80096b20,
		"TBossPakkunMtxCalc::calcBellyScale": 0x80096ee4,
		"calcBellyScale": 0x80096ee4,
		"TBPNavel::perform": 0x80097154,
		"TBPNavel::receiveMessage": 0x800971bc,
		"TBPHeadHit::perform": 0x800972cc,
		"TBPHeadHit::throwActor": 0x80097390,
		"throwActor": 0x80097390,
		"TBPHeadHit::receiveMessage": 0x800975e0,
		"TBPTornado::perform": 0x80097ba8,
		"TBPTornado::TBPTornado": 0x800982d4,
		"TBPVomit::perform": 0x800983c8,
		"TBPPolDrop::perform": 0x80098498,
		"TBPPolDrop::move": 0x8009870c,
		"TBPPolDrop::TBPPolDrop": 0x80098a18,
		"TBossPakkunParams::TBossPakkunParams": 0x80098b54,
		"TBossPakkunManager::~TBossPakkunManager": 0x80098fac,
		"TBossPakkunMtxCalc::~TBossPakkunMtxCalc": 0x8009907c,
		"TBPVomit::~TBPVomit": 0x800992b4,
		"Enemy::__sinit_bosspakkun_cpp": 0x800993ac,
		"__sinit_bosspakkun_cpp": 0x800993ac,
		"TNerveTobiPukuSwimWander::~TNerveTobiPukuSwimWander": 0x800996e4,
		"TNerveTobiPukuSwimWander::execute": 0x80099740,
		"TNerveTobiPukuReturnLaunch::execute": 0x800997f4,
		"TNerveTobiPukuPrepareFly::~TNerveTobiPukuPrepareFly": 0x80099a48,
		"TNerveTobiPukuReturnLaunch::~TNerveTobiPukuReturnLaunch": 0x80099aa4,
		"TNerveTobiPukuPrepareFly::execute": 0x80099b00,
		"TNerveTobiPukuBound::execute": 0x80099ca8,
		"TNerveTobiPukuLand::~TNerveTobiPukuLand": 0x80099e70,
		"TNerveTobiPukuBound::~TNerveTobiPukuBound": 0x80099ecc,
		"TNerveTobiPukuLand::execute": 0x80099f28,
		"TNerveTobiPukuPitiPiti::~TNerveTobiPukuPitiPiti": 0x8009a4d0,
		"TNerveTobiPukuDie::execute": 0x8009a52c,
		"TNerveTobiPukuDie::~TNerveTobiPukuDie": 0x8009a728,
		"TNerveTobiPukuPitiPiti::execute": 0x8009a784,
		"TNerveTobiPukuFall::execute": 0x8009a89c,
		"TNerveTobiPukuFall::~TNerveTobiPukuFall": 0x8009aa80,
		"TNerveTobiPukuHitWater::execute": 0x8009aadc,
		"TNerveTobiPukuHitWater::~TNerveTobiPukuHitWater": 0x8009ad2c,
		"TNerveTobiPukuAttack::execute": 0x8009ad88,
		"TNerveTobiPukuAttack::~TNerveTobiPukuAttack": 0x8009af20,
		"TNerveTobiPukuFly::execute": 0x8009af7c,
		"TNerveTobiPukuFly::~TNerveTobiPukuFly": 0x8009b110,
		"TNerveTobiPukuGenerate::execute": 0x8009b16c,
		"TNerveTobiPukuGenerate::~TNerveTobiPukuGenerate": 0x8009b318,
		"TMoePuku::getBasNameTable": 0x8009b374,
		"TMoePuku::generateEffectColumWater": 0x8009b380,
		"TMoePuku::setJumpStartAnm": 0x8009b4ec,
		"TMoePuku::setFallEndLandAnm": 0x8009b53c,
		"TMoePuku::setDeadAnm": 0x8009b56c,
		"TMoePuku::setDownLandAnm": 0x8009b59c,
		"TMoePuku::setDownAirAnm": 0x8009b5cc,
		"TMoePuku::setFallAnm": 0x8009b5fc,
		"TMoePuku::setPichiAnm": 0x8009b62c,
		"TMoePuku::setAttackAnm": 0x8009b65c,
		"TMoePuku::setSwimAnm": 0x8009b68c,
		"TMoePuku::setJumpAnm": 0x8009b6bc,
		"TMoePuku::isJumpStartBck": 0x8009b6ec,
		"TMoePuku::isFallEndLandBck": 0x8009b71c,
		"TMoePuku::isAttackBck": 0x8009b74c,
		"TMoePuku::isDeadBck": 0x8009b77c,
		"TMoePuku::isJumpBck": 0x8009b7ac,
		"TMoePuku::isPichiEffect": 0x8009b7dc,
		"TMoePuku::hitWater": 0x8009b80c,
		"TMoePuku::calcRootMatrix": 0x8009b8cc,
		"TPukuPuku::reset": 0x8009bb14,
		"TPukuPuku::init": 0x8009bc50,
		"TPukuPuku::load": 0x8009bd24,
		"TPukuPuku::TPukuPuku": 0x8009bd6c,
		"TTobiPuku::getBasNameTable": 0x8009be4c,
		"TTobiPuku::scalingChangeActor": 0x8009be58,
		"TTobiPuku::initAttacker": 0x8009beec,
		"TTobiPuku::changeOut": 0x8009bfd0,
		"TTobiPuku::genEventCoin": 0x8009c070,
		"TTobiPuku::forceKill": 0x8009c09c,
		"TTobiPuku::kill": 0x8009c1f4,
		"TTobiPuku::hitWater": 0x8009c370,
		"TTobiPuku::getGravityY": 0x8009c4c4,
		"TTobiPuku::attackToMario": 0x8009c4e4,
		"TTobiPuku::generateEffectColumWater": 0x8009c660,
		"TTobiPuku::isReachedToGoalXZ": 0x8009c77c,
		"TTobiPuku::swimEffect": 0x8009c844,
		"TTobiPuku::walkBehavior": 0x8009c8f4,
		"TTobiPuku::behaveToWater": 0x8009c9c4,
		"TTobiPuku::setJumpStartAnm": 0x8009cb10,
		"TTobiPuku::setFallEndLandAnm": 0x8009cb60,
		"TTobiPuku::setDeadAnm": 0x8009cb90,
		"TTobiPuku::setDownLandAnm": 0x8009cbc0,
		"TTobiPuku::setDownAirAnm": 0x8009cbf0,
		"TTobiPuku::setFallAnm": 0x8009cc20,
		"TTobiPuku::setPichiAnm": 0x8009cc50,
		"TTobiPuku::setAttackAnm": 0x8009cc80,
		"TTobiPuku::setSwimAnm": 0x8009ccb0,
		"TTobiPuku::setJumpAnm": 0x8009cce0,
		"TTobiPuku::isJumpStartBck": 0x8009cd10,
		"TTobiPuku::isFallEndLandBck": 0x8009cd40,
		"TTobiPuku::isAttackBck": 0x8009cd70,
		"TTobiPuku::isDeadBck": 0x8009cda0,
		"TTobiPuku::isJumpBck": 0x8009cdd0,
		"TTobiPuku::isPichiEffect": 0x8009ce00,
		"TTobiPuku::calcRootMatrix": 0x8009ce30,
		"TTobiPuku::hitWall": 0x8009cf84,
		"hitWall": 0x8009cf84,
		"TTobiPuku::moveObject": 0x8009d0e0,
		"TTobiPuku::reset": 0x8009d150,
		"TTobiPuku::init": 0x8009d228,
		"TTobiPuku::TTobiPuku": 0x8009d294,
		"TMoePukuLaunchPad::launch": 0x8009d348,
		"TTobiPukuLaunchPad::forceLaunch": 0x8009d3a8,
		"forceLaunch": 0x8009d3a8,
		"TTobiPukuLaunchPad::launch": 0x8009d58c,
		"TTobiPukuLaunchPad::reset": 0x8009d5ec,
		"TTobiPukuLaunchPad::load": 0x8009d624,
		"TTobiPukuLaunchPad::init": 0x8009d6a4,
		"TTobiPukuLaunchPad::perform": 0x8009d6f4,
		"TTobiPukuLaunchPad::TTobiPukuLaunchPad": 0x8009d7b0,
		"TMoePukuManager::createEnemyInstance": 0x8009d808,
		"TTobiPukuManager::createEnemyInstance": 0x8009d864,
		"TTobiPukuManager::load": 0x8009d8ac,
		"TTobiPukuManager::TTobiPukuManager": 0x8009da1c,
		"TMoePukuLaunchPadManager::createEnemyInstance": 0x8009da58,
		"TTobiPukuLaunchPadManager::perform": 0x8009db60,
		"TTobiPukuLaunchPadManager::createEnemyInstance": 0x8009dbf8,
		"TTobiPukuLaunchPadManager::load": 0x8009dc68,
		"TTobiPukuLaunchPadManager::TTobiPukuLaunchPadManager": 0x8009ddd8,
		"Enemy::TobiPukuRollCallback": 0x8009de1c,
		"TobiPukuRollCallback": 0x8009de1c,
		"TMoePuku::swimEffect": 0x8009e040,
		"TTobiPuku::isInhibitedForceMove": 0x8009e044,
		"TMoePukuManager::~TMoePukuManager": 0x8009e234,
		"TMoePukuLaunchPadManager::~TMoePukuLaunchPadManager": 0x8009e32c,
		"Enemy::__sinit_tobiPuku_cpp": 0x8009e424,
		"__sinit_tobiPuku_cpp": 0x8009e424,
		"TNerveTinKoopaBreak::~TNerveTinKoopaBreak": 0x8009e748,
		"TNerveTinKoopaBreak::execute": 0x8009e7a4,
		"TNerveTinKoopaDamage::execute": 0x8009eb9c,
		"TNerveTinKoopaDamage::~TNerveTinKoopaDamage": 0x8009ed18,
		"TNerveTinKoopaWait::execute": 0x8009ed74,
		"TNerveTinKoopaWait::~TNerveTinKoopaWait": 0x8009ee54,
		"TTinKoopaManager::createEnemyInstance": 0x8009eeb0,
		"TTinKoopaManager::loadAfter": 0x8009eeb8,
		"TTinKoopaManager::load": 0x8009efbc,
		"TTinKoopaManager::createModelData": 0x8009f014,
		"TTinKoopaManager::TTinKoopaManager": 0x8009f048,
		"TTinKoopa::emitTinKoopaEffects": 0x8009f084,
		"emitTinKoopaEffects": 0x8009f084,
		"TTinKoopa::checkTinKoopaFirstFlameMessage": 0x8009fc88,
		"checkTinKoopaFirstFlameMessage": 0x8009fc88,
		"TTinKoopa::checkTinKoopaKillerApproachingMessage": 0x8009fd94,
		"checkTinKoopaKillerApproachingMessage": 0x8009fd94,
		"TTinKoopa::launchKiller": 0x8009ff28,
		"TTinKoopa::hitParts": 0x800a002c,
		"hitParts": 0x800a002c,
		"TTinKoopa::receiveMessage": 0x800a0280,
		"TTinKoopa::getBasNameTable": 0x800a02bc,
		"TTinKoopa::perform": 0x800a02c8,
		"TTinKoopa::resetTinKoopa": 0x800a0554,
		"resetTinKoopa": 0x800a0554,
		"TTinKoopa::reset": 0x800a0668,
		"TTinKoopa::calcCoasterDistance": 0x800a08e4,
		"calcCoasterDistance": 0x800a08e4,
		"TTinKoopa::TTinKoopa": 0x800a0990,
		"TTinKoopaPartsBase::perform": 0x800a0a20,
		"TTinKoopaPartsBase::receiveMessage": 0x800a0b50,
		"TTinKoopaPartsBase::emitPartsTrackEffects": 0x800a0dd0,
		"emitPartsTrackEffects": 0x800a0dd0,
		"TTinKoopaPartsBase::startBreaking": 0x800a0eac,
		"startBreaking": 0x800a0eac,
		"TTinKoopaPartsBase::reset": 0x800a10b8,
		"TTinKoopaPartsBase::initTinKoopaPartsBase": 0x800a1104,
		"initTinKoopaPartsBase": 0x800a1104,
		"TTinKoopaLaunchOrder::checkOrder": 0x800a12e4,
		"checkOrder": 0x800a12e4,
		"TTinKoopaFlame::emitFlameEffects": 0x800a1450,
		"emitFlameEffects": 0x800a1450,
		"TTinKoopaFlame::perform": 0x800a1684,
		"TTinKoopaFlame::receiveMessage": 0x800a17cc,
		"TTinKoopa::makeLaunchSchedule": 0x800a18b4,
		"makeLaunchSchedule": 0x800a18b4,
		"TTinKoopa::init": 0x800a1a90,
		"TTinKoopaParams::TTinKoopaParams": 0x800a2074,
		"TTinKoopaManager::~TTinKoopaManager": 0x800a2378,
		"TTinKoopaManager::hasMapCollision": 0x800a23dc,
		"TTinKoopaMtxCalc::~TTinKoopaMtxCalc": 0x800a23e4,
		"TTinKoopa::hasMapCollision": 0x800a25ec,
		"Enemy::__sinit_tinkoopa_cpp": 0x800a25f4,
		"__sinit_tinkoopa_cpp": 0x800a25f4,
		"TCommonLauncherManager::~TCommonLauncherManager": 0x800a291c,
		"TCommonLauncherManager::load": 0x800a2990,
		"TCommonLauncherManager::createModelData": 0x800a29b0,
		"TCommonLauncherManager::TCommonLauncherManager": 0x800a29e4,
		"TCommonLauncher::perform": 0x800a2a90,
		"TCommonLauncher::getBasNameTable": 0x800a2bfc,
		"TCommonLauncher::stateDie": 0x800a2c08,
		"TCommonLauncher::stateLaunch": 0x800a2dfc,
		"TCommonLauncher::stateNormal": 0x800a2f9c,
		"TCommonLauncher::stateHitByWater": 0x800a3044,
		"TCommonLauncher::stateInitial": 0x800a30f8,
		"TCommonLauncher::load": 0x800a3128,
		"TCommonLauncher::init": 0x800a317c,
		"TCommonLauncher::TCommonLauncher": 0x800a3468,
		"TLauncherManager::load": 0x800a3554,
		"TLauncherManager::TLauncherManager": 0x800a3614,
		"TLauncher::stateDie": 0x800a3650,
		"TLauncher::stateLaunch": 0x800a36e0,
		"TLauncher::stateNormal": 0x800a375c,
		"TLauncher::stateHitByWater": 0x800a37a4,
		"TLauncher::stateInitial": 0x800a3824,
		"TLauncher::changeState": 0x800a3860,
		"TLauncher::getProperEnemy": 0x800a3868,
		"getProperEnemy": 0x800a3868,
		"TLauncher::resetLaunchTimer": 0x800a38cc,
		"resetLaunchTimer": 0x800a38cc,
		"TLauncher::control": 0x800a3920,
		"TLauncher::bind": 0x800a3a18,
		"TLauncher::receiveMessage": 0x800a3a1c,
		"TLauncher::init": 0x800a3b04,
		"TLauncher::TLauncher": 0x800a3c50,
		"Enemy::__sinit_launcher_cpp": 0x800a3d34,
		"__sinit_launcher_cpp": 0x800a3d34,
		"TNerveBWFall::~TNerveBWFall": 0x800a4040,
		"TNerveBWFall::execute": 0x800a409c,
		"TNerveBWGraphWander::~TNerveBWGraphWander": 0x800a429c,
		"TNerveBWFall::theNerve": 0x800a42f8,
		"TNerveBWShake::execute": 0x800a435c,
		"TNerveBWShake::theNerve": 0x800a44f4,
		"TNerveBWShake::~TNerveBWShake": 0x800a4558,
		"TNerveBWJumpAway::execute": 0x800a45b4,
		"TNerveBWJumpAway::theNerve": 0x800a4840,
		"TNerveBWJumpAway::~TNerveBWJumpAway": 0x800a48a4,
		"TNerveBWDie::execute": 0x800a4900,
		"TNerveBWDie::~TNerveBWDie": 0x800a4d60,
		"TNerveBWDie::theNerve": 0x800a4dbc,
		"TNerveBWJumpToBath::execute": 0x800a4e20,
		"TNerveBWJumpToBath::theNerve": 0x800a5154,
		"TNerveBWJumpToBath::~TNerveBWJumpToBath": 0x800a51b8,
		"TNerveBWWakeup::execute": 0x800a5214,
		"TNerveBWWakeup::theNerve": 0x800a53a8,
		"TNerveBWWakeup::~TNerveBWWakeup": 0x800a540c,
		"TNerveBWStun::execute": 0x800a5468,
		"TNerveBWStun::theNerve": 0x800a577c,
		"TNerveBWStun::~TNerveBWStun": 0x800a57e0,
		"TNerveBWJump::execute": 0x800a583c,
		"TNerveBWJump::theNerve": 0x800a59bc,
		"TNerveBWJump::~TNerveBWJump": 0x800a5a20,
		"TNerveBWBark::execute": 0x800a5a7c,
		"TNerveBWBark::theNerve": 0x800a5cf8,
		"TNerveBWBark::~TNerveBWBark": 0x800a5d5c,
		"TNerveBWRoll::execute": 0x800a5db8,
		"TNerveBWRoll::~TNerveBWRoll": 0x800a5ef8,
		"TNerveBWRoll::theNerve": 0x800a5f64,
		"TNerveBWGraphWander::execute": 0x800a5fc8,
		"TNerveBWGraphWander::theNerve": 0x800a69b4,
		"TBossWanwanManager::load": 0x800a6a18,
		"TBossWanwanManager::createModelData": 0x800a6c10,
		"TBossWanwanManager::createEnemyInstance": 0x800a6c44,
		"TBossWanwanManager::TBossWanwanManager": 0x800a6c8c,
		"TBossWanwan::perform": 0x800a6cc8,
		"TBossWanwan::emitEffects": 0x800a752c,
		"TBossWanwan::control": 0x800a79b0,
		"TBossWanwan::slideToCurPathNode": 0x800a7ccc,
		"slideToCurPathNode": 0x800a7ccc,
		"TBossWanwan::calcRootMatrix": 0x800a7f84,
		"TBossWanwan::receiveMessage": 0x800a8068,
		"TBossWanwan::shakeCamera": 0x800a82b8,
		"shakeCamera": 0x800a82b8,
		"TBossWanwan::init": 0x800a8434,
		"TBossWanwan::TBossWanwan": 0x800a8bc4,
		"TBWBinder::bind": 0x800a8ecc,
		"TBWHit::perform": 0x800a9a1c,
		"TBWHit::receiveMessage": 0x800a9ad8,
		"TBWPicket::perform": 0x800a9b08,
		"TBWPicket::getTakingMtx": 0x800aa038,
		"TBWPicket::moveRequest": 0x800aa040,
		"TBWPicket::receiveMessage": 0x800aa1f8,
		"TBWLeash::perform": 0x800aa32c,
		"TBWLeash::TBWLeash": 0x800aa860,
		"TBWLeashNode::perform": 0x800aab9c,
		"TBWLeashNode::calcMatrix": 0x800aadc8,
		"calcMatrix": 0x800aadc8,
		"TBWLeashNode::calcTemperature": 0x800ab08c,
		"calcTemperature": 0x800ab08c,
		"TBWParams::TBWParams": 0x800ab130,
		"TBossWanwanManager::~TBossWanwanManager": 0x800ab4a8,
		"TBossWanwan::kill": 0x800ab578,
		"TBossWanwanMtxCalc::~TBossWanwanMtxCalc": 0x800ab57c,
		"TBWBinder::~TBWBinder": 0x800ab628,
		"TBWLeash::~TBWLeash": 0x800ab7ac,
		"Enemy::__sinit_bosswanwan_cpp": 0x800ab8a4,
		"__sinit_bosswanwan_cpp": 0x800ab8a4,
		"TNerveChuuHanaWait::~TNerveChuuHanaWait": 0x800abc1c,
		"TNerveChuuHanaWait::execute": 0x800abc78,
		"TNerveChuuHanaJumpPrepare::execute": 0x800abce4,
		"TNerveChuuHanaJumpPrepare::~TNerveChuuHanaJumpPrepare": 0x800abe88,
		"TNerveChuuHanaAttack::execute": 0x800abee4,
		"TNerveChuuHanaFall2::~TNerveChuuHanaFall2": 0x800ac2e4,
		"TNerveChuuHanaWalkOnPanel::~TNerveChuuHanaWalkOnPanel": 0x800ac340,
		"TNerveChuuHanaAttack::~TNerveChuuHanaAttack": 0x800ac39c,
		"TNerveChuuHanaObject::execute": 0x800ac3f8,
		"TNerveChuuHanaObject::~TNerveChuuHanaObject": 0x800ac400,
		"TNerveChuuHanaFall2::execute": 0x800ac45c,
		"TNerveChuuHanaFall::execute": 0x800ac588,
		"TNerveChuuHanaFall::~TNerveChuuHanaFall": 0x800ac590,
		"TNerveChuuHanaRoll::execute": 0x800ac5ec,
		"TNerveChuuHanaKeepBalance::~TNerveChuuHanaKeepBalance": 0x800ac80c,
		"TNerveChuuHanaRoll::~TNerveChuuHanaRoll": 0x800ac868,
		"TNerveChuuHanaStick::execute": 0x800ac8c4,
		"TNerveChuuHanaStick::~TNerveChuuHanaStick": 0x800acb6c,
		"TNerveChuuHanaKeepBalance::execute": 0x800acbc8,
		"TNerveChuuHanaForceJumped::execute": 0x800acfb4,
		"TNerveChuuHanaForceJumped::~TNerveChuuHanaForceJumped": 0x800ad264,
		"TNerveChuuHanaWalkOnPanel::execute": 0x800ad2c0,
		"TChuuHana::getBasNameTable": 0x800ad548,
		"TChuuHana::checkStretchType": 0x800ad554,
		"checkStretchType": 0x800ad554,
		"TChuuHana::setGoal": 0x800ada24,
		"setGoal": 0x800ada24,
		"TChuuHana::willFall": 0x800adb8c,
		"willFall": 0x800adb8c,
		"TChuuHana::getGravityY": 0x800add8c,
		"TChuuHana::forceKill": 0x800adff0,
		"TChuuHana::kill": 0x800ae114,
		"TChuuHana::setWalkAnm": 0x800ae188,
		"TChuuHana::receiveMessage": 0x800ae22c,
		"TChuuHana::bind": 0x800ae3bc,
		"TChuuHana::calcRootMatrix": 0x800ae6a4,
		"TChuuHana::isCollidMove": 0x800ae928,
		"TChuuHana::moveObject": 0x800aed24,
		"TChuuHana::attackToMario": 0x800af0b0,
		"TChuuHana::behaveToWater": 0x800af314,
		"TChuuHana::setBckAnm": 0x800af92c,
		"TChuuHana::reset": 0x800af9b8,
		"TChuuHana::perform": 0x800afb3c,
		"TChuuHana::setMActorAndKeeper": 0x800afbf8,
		"TChuuHana::init": 0x800afc64,
		"TChuuHana::TChuuHana": 0x800afdb4,
		"TChuuHanaAseParCallback::draw": 0x800afe68,
		"TChuuHanaAseParCallback::execute": 0x800afe6c,
		"Enemy::ChuuHanaBodyCallback": 0x800afee0,
		"ChuuHanaBodyCallback": 0x800afee0,
		"TChuuHanaManager::initSetEnemies": 0x800b0184,
		"TChuuHanaManager::createEnemyInstance": 0x800b030c,
		"TChuuHanaManager::perform": 0x800b0354,
		"TChuuHanaManager::load": 0x800b04a4,
		"TChuuHanaManager::TChuuHanaManager": 0x800b04fc,
		"TChuuHanaSaveLoadParams::TChuuHanaSaveLoadParams": 0x800b055c,
		"TChuuHana::isFindMario": 0x800b0a40,
		"TChuuHanaManager::~TChuuHanaManager": 0x800b0ae4,
		"Enemy::__sinit_chuuhana_cpp": 0x800b0b58,
		"__sinit_chuuhana_cpp": 0x800b0b58,
		"TNerveGorogoroDie::~TNerveGorogoroDie": 0x800b0e5c,
		"TNerveGorogoroDie::execute": 0x800b0eb8,
		"TNerveGorogoroRollOnGraph::execute": 0x800b10ec,
		"TNerveGorogoroRollOnGraph::~TNerveGorogoroRollOnGraph": 0x800b11ac,
		"TGorogoro::generateByGateKeeper": 0x800b1208,
		"generateByGateKeeper": 0x800b1208,
		"TGorogoro::setMActorAndKeeper": 0x800b178c,
		"TGorogoro::isRolling": 0x800b17f8,
		"TGorogoro::getBasNameTable": 0x800b18a4,
		"TGorogoro::bound": 0x800b18b0,
		"TGorogoro::setMeltAnm": 0x800b1918,
		"TGorogoro::setDeadAnm": 0x800b1a10,
		"TGorogoro::flagJump": 0x800b1adc,
		"TGorogoro::walkBehavior": 0x800b1bb4,
		"TGorogoro::boundSE": 0x800b1ea8,
		"TGorogoro::rollSE": 0x800b1f20,
		"TGorogoro::behaveToWater": 0x800b1f98,
		"TGorogoro::forceKill": 0x800b21ec,
		"TGorogoro::kill": 0x800b23d8,
		"TGorogoro::reset": 0x800b252c,
		"TGorogoro::calcRootMatrix": 0x800b2584,
		"TGorogoro::perform": 0x800b2778,
		"TGorogoro::init": 0x800b2804,
		"TGorogoroManager::perform": 0x800b2a64,
		"TGorogoroManager::createModelData": 0x800b2f88,
		"TGorogoroManager::initSetEnemies": 0x800b2fbc,
		"TGorogoroManager::createEnemyInstance": 0x800b3124,
		"TGorogoroManager::loadAfter": 0x800b31ac,
		"TGorogoroManager::load": 0x800b3248,
		"TGorogoroManager::TGorogoroManager": 0x800b33b8,
		"TGorogoroPolluteModel::setAnm": 0x800b3410,
		"TGorogoroPolluteModelManager::init": 0x800b3460,
		"TNerveIgaigaShootFromCannon::execute": 0x800b3530,
		"TNerveIgaigaRollOnGraph::~TNerveIgaigaRollOnGraph": 0x800b36a8,
		"TNerveIgaigaShootFromCannon::~TNerveIgaigaShootFromCannon": 0x800b3704,
		"TNerveIgaigaWaterHit::execute": 0x800b3760,
		"TNerveIgaigaWaterHit::~TNerveIgaigaWaterHit": 0x800b39d0,
		"TNerveIgaigaRollOnGraph::execute": 0x800b3a2c,
		"TIgaiga::shoot": 0x800b3b4c,
		"TIgaiga::bound": 0x800b3c14,
		"TIgaiga::isHitValid": 0x800b3cb8,
		"TIgaiga::getBasNameTable": 0x800b3cd8,
		"TIgaiga::setMeltAnm": 0x800b3ce4,
		"TIgaiga::setDeadAnm": 0x800b3f48,
		"TIgaiga::setWalkAnm": 0x800b40b0,
		"TIgaiga::isReachedToGoalXZ": 0x800b40e0,
		"TIgaiga::walkBehavior": 0x800b419c,
		"TIgaiga::boundSE": 0x800b4338,
		"TIgaiga::rollSE": 0x800b43b0,
		"TIgaiga::moveObject": 0x800b43f8,
		"TIgaiga::kill": 0x800b4684,
		"TIgaiga::reset": 0x800b46ac,
		"TIgaiga::behaveToWater": 0x800b47ec,
		"TIgaiga::isRolling": 0x800b4938,
		"TIgaiga::calcRootMatrix": 0x800b4a78,
		"TIgaiga::perform": 0x800b4a9c,
		"TIgaiga::setMActorAndKeeper": 0x800b4abc,
		"TIgaiga::init": 0x800b4b28,
		"TIgaiga::TIgaiga": 0x800b4c30,
		"Enemy::RollEnemyBodyCallback": 0x800b4cd4,
		"RollEnemyBodyCallback": 0x800b4cd4,
		"TRollEnemy::isRolling": 0x800b4e04,
		"TIgaigaManager::perform": 0x800b4e0c,
		"TIgaigaManager::initSetEnemies": 0x800b4e6c,
		"TIgaigaManager::createEnemyInstance": 0x800b4f28,
		"TIgaigaManager::createModelData": 0x800b4f70,
		"TIgaigaManager::load": 0x800b4fa4,
		"TIgaigaManager::TIgaigaManager": 0x800b5128,
		"TIgaigaPolluteModel::setAnm": 0x800b5174,
		"TIgaigaPolluteModelManager::init": 0x800b51c4,
		"TRollEnemy::setBehavior": 0x800b5294,
		"TRollEnemy::isReachedToGoalXZ": 0x800b54bc,
		"TRollEnemy::isCollidMove": 0x800b5570,
		"TRollEnemy::flagJump": 0x800b55f0,
		"TRollEnemy::attackToMario": 0x800b56c8,
		"TRollEnemy::behaveToWater": 0x800b56ec,
		"TRollEnemy::walkBehavior": 0x800b5884,
		"TRollEnemy::rollSE": 0x800b5a90,
		"TRollEnemy::boundSE": 0x800b5a94,
		"TRollEnemy::bound": 0x800b5a98,
		"TRollEnemy::reset": 0x800b5a9c,
		"TRollEnemy::TRollEnemy": 0x800b5c94,
		"TRollEnemy::setAfterDeadEffect": 0x800b5d04,
		"TGorogoroManager::~TGorogoroManager": 0x800b5da4,
		"TGorogoroPolluteModel::~TGorogoroPolluteModel": 0x800b5e18,
		"TGorogoroPolluteModelManager::~TGorogoroPolluteModelManager": 0x800b5e9c,
		"TIgaigaManager::~TIgaigaManager": 0x800b5fbc,
		"TIgaigaPolluteModel::~TIgaigaPolluteModel": 0x800b6030,
		"TIgaigaPolluteModelManager::~TIgaigaPolluteModelManager": 0x800b60b4,
		"Enemy::__sinit_igaiga_cpp": 0x800b6138,
		"__sinit_igaiga_cpp": 0x800b6138,
		"TNervePoihanaTrapped::~TNervePoihanaTrapped": 0x800b644c,
		"TNervePoihanaTrapped::execute": 0x800b64a8,
		"TNervePoihanaFreeze::~TNervePoihanaFreeze": 0x800b6978,
		"TNervePoihanaThrow::execute": 0x800b69d4,
		"TNervePoihanaThrow::~TNervePoihanaThrow": 0x800b6ba0,
		"TNervePoihanaFreeze::execute": 0x800b6bfc,
		"TNervePoihanaSleep::execute": 0x800b6dfc,
		"TNervePoihanaSleep::~TNervePoihanaSleep": 0x800b7130,
		"TSleepPoiHana::load": 0x800b718c,
		"TSleepPoiHana::TSleepPoiHana": 0x800b71d4,
		"TPoiHanaRed::attackToMario": 0x800b72f8,
		"TPoiHanaRed::init": 0x800b7520,
		"TPoiHana::getBasNameTable": 0x800b756c,
		"TPoiHana::changeByJuice": 0x800b7578,
		"TPoiHana::genEventCoin": 0x800b75c8,
		"TPoiHana::isMoving": 0x800b76f8,
		"isMoving": 0x800b76f8,
		"TPoiHana::getGravityY": 0x800b77dc,
		"TPoiHana::generateItem": 0x800b7878,
		"TPoiHana::calcRootMatrix": 0x800b7890,
		"TPoiHana::doKeepDistance": 0x800b7c20,
		"TPoiHana::isInhibitedForceMove": 0x800b7c54,
		"TPoiHana::walkBehavior": 0x800b7c70,
		"TPoiHana::isCollidMove": 0x800b7de8,
		"TPoiHana::isHitValid": 0x800b7fe4,
		"TPoiHana::setDeadAnm": 0x800b80b0,
		"TPoiHana::setFreezeAnm": 0x800b82f8,
		"TPoiHana::setRunAnm": 0x800b8328,
		"TPoiHana::setWaitAnm": 0x800b8358,
		"TPoiHana::setWalkAnm": 0x800b8388,
		"TPoiHana::attackToMario": 0x800b83b8,
		"TPoiHana::behaveToWater": 0x800b85c4,
		"TPoiHana::bind": 0x800b86d4,
		"TPoiHana::perform": 0x800b87f4,
		"TPoiHana::moveObject": 0x800b8848,
		"TPoiHana::reset": 0x800b8b24,
		"TPoiHana::setMActorAndKeeper": 0x800b8b74,
		"TPoiHana::init": 0x800b8be0,
		"TPoiHana::load": 0x800b8e64,
		"TPoiHana::TPoiHana": 0x800b8ea4,
		"TPoiHanaCollision::receiveMessage": 0x800b8f18,
		"TPoiHanaManager::initSetEnemies": 0x800b8f48,
		"TPoiHanaManager::perform": 0x800b8fe8,
		"TPoiHanaManager::createEnemyInstance": 0x800b9008,
		"TPoiHanaManager::load": 0x800b906c,
		"TPoiHanaManager::TPoiHanaManager": 0x800b9280,
		"TPoiHanaManager::~TPoiHanaManager": 0x800b9478,
		"Enemy::__sinit_poihana_cpp": 0x800b94ec,
		"__sinit_poihana_cpp": 0x800b94ec,
		"TNerveTamaNokoWait::~TNerveTamaNokoWait": 0x800b9808,
		"TNerveTamaNokoWait::execute": 0x800b9864,
		"TNerveTamaNokoHitWater::execute": 0x800b99ec,
		"TNerveTamaNokoSleep::~TNerveTamaNokoSleep": 0x800b9d24,
		"TNerveTamaNokoHitWater::~TNerveTamaNokoHitWater": 0x800b9d80,
		"TNerveTamaNokoSink::execute": 0x800b9ddc,
		"TNerveTamaNokoSink::~TNerveTamaNokoSink": 0x800b9ff4,
		"TNerveTamaNokoThrown::execute": 0x800ba050,
		"TNerveTamaNokoThrown::~TNerveTamaNokoThrown": 0x800ba15c,
		"TNerveTamaNokoPickUp::execute": 0x800ba1b8,
		"TNerveTamaNokoPickUp::~TNerveTamaNokoPickUp": 0x800ba26c,
		"TNerveTamaNokoDown::execute": 0x800ba2c8,
		"TNerveTamaNokoDown::~TNerveTamaNokoDown": 0x800ba54c,
		"TNerveTamaNokoAttack::execute": 0x800ba5a8,
		"TNerveTamaNokoAttack::~TNerveTamaNokoAttack": 0x800bad58,
		"TNerveTamaNokoSleep::execute": 0x800badb4,
		"TTamaNoko::isCollidMove": 0x800bae5c,
		"TTamaNoko::isReachedToGoal": 0x800baf28,
		"TTamaNoko::setDeadAnm": 0x800baff0,
		"TTamaNoko::setWalkAnm": 0x800bb020,
		"TTamaNoko::getGravityY": 0x800bb050,
		"TTamaNoko::getBasNameTable": 0x800bb144,
		"TTamaNoko::setAfterDeadEffect": 0x800bb150,
		"TTamaNoko::landEffect": 0x800bb250,
		"landEffect": 0x800bb250,
		"TTamaNoko::requestShadow": 0x800bb578,
		"TTamaNoko::calcRootMatrix": 0x800bb754,
		"TTamaNoko::doKeepDistance": 0x800bbb7c,
		"TTamaNoko::attackToMario": 0x800bbc08,
		"TTamaNoko::isHitValid": 0x800bbcc8,
		"TTamaNoko::receiveMessage": 0x800bbd5c,
		"TTamaNoko::changeByJuice": 0x800bbeb4,
		"TTamaNoko::behaveToRelease": 0x800bbebc,
		"TTamaNoko::behaveToTaken": 0x800bbfe0,
		"TTamaNoko::walkBehavior": 0x800bc0f8,
		"TTamaNoko::behaveToWater": 0x800bc624,
		"TTamaNoko::behaveToFindMario": 0x800bc804,
		"TTamaNoko::moveObject": 0x800bc8a8,
		"TTamaNoko::perform": 0x800bc93c,
		"TTamaNoko::reset": 0x800bc9a8,
		"TTamaNoko::setMActorAndKeeper": 0x800bca00,
		"TTamaNoko::init": 0x800bca6c,
		"TTamaNoko::load": 0x800bcb64,
		"TTamaNoko::TTamaNoko": 0x800bcba4,
		"TTamaNokoManager::createModelData": 0x800bcc04,
		"TTamaNokoManager::createEnemyInstance": 0x800bcc38,
		"TTamaNokoManager::initSetEnemies": 0x800bcc80,
		"TTamaNokoManager::loadAfter": 0x800bcdac,
		"TTamaNokoManager::load": 0x800bce08,
		"TTamaNokoManager::TTamaNokoManager": 0x800bd01c,
		"TTamaNokoFlower::perform": 0x800bd058,
		"TTamaNoko::forceKill": 0x800bd400,
		"TTamaNokoManager::~TTamaNokoManager": 0x800bd4a0,
		"TTamaNokoFlower::~TTamaNokoFlower": 0x800bd514,
		"Enemy::__sinit_tamaNoko_cpp": 0x800bd598,
		"__sinit_tamaNoko_cpp": 0x800bd598,
		"TNerveBossTelesaFallDemo::~TNerveBossTelesaFallDemo": 0x800bd89c,
		"TNerveBossTelesaFallDemo::execute": 0x800bd8f8,
		"TNerveBossTelesaHideWait::~TNerveBossTelesaHideWait": 0x800bdae4,
		"TNerveBossTelesaFreeze::execute": 0x800bdb40,
		"TNerveBossTelesaFreeze::~TNerveBossTelesaFreeze": 0x800bdcf0,
		"TNerveBossTelesaPrepareSlot::execute": 0x800bdd4c,
		"TNerveBossTelesaHide::~TNerveBossTelesaHide": 0x800be3b4,
		"TNerveBossTelesaPrepareSlot::~TNerveBossTelesaPrepareSlot": 0x800be410,
		"TNerveBossTelesaSpitSlotItem::execute": 0x800be46c,
		"TNerveBossTelesaSpitSlotItem::~TNerveBossTelesaSpitSlotItem": 0x800be6bc,
		"TNerveBossTelesaSlotStart::execute": 0x800be718,
		"TNerveBossTelesaSlotStart::~TNerveBossTelesaSlotStart": 0x800be9cc,
		"TNerveBossTelesaAppear::execute": 0x800bea28,
		"TNerveBossTelesaAppear::~TNerveBossTelesaAppear": 0x800bedf4,
		"TNerveBossTelesaHideWait::execute": 0x800bee50,
		"TNerveBossTelesaHide::execute": 0x800bf050,
		"TNerveBossTelesaSpit::execute": 0x800bf228,
		"TNerveBossTelesaSpit::~TNerveBossTelesaSpit": 0x800bf358,
		"TNerveBossTelesaDie::execute": 0x800bf3b4,
		"TNerveBossTelesaDie::~TNerveBossTelesaDie": 0x800bfc7c,
		"TBossTelesa::forceHide": 0x800bfcd8,
		"forceHide": 0x800bfcd8,
		"TBossTelesa::forceAllItemKill": 0x800bfe74,
		"forceAllItemKill": 0x800bfe74,
		"TBossTelesa::generateSlotItem": 0x800bff68,
		"generateSlotItem": 0x800bff68,
		"TBossTelesa::rouletteStart": 0x800c0abc,
		"rouletteStart": 0x800c0abc,
		"TBossTelesa::genAttacker": 0x800c0d78,
		"genAttacker": 0x800c0d78,
		"TBossTelesa::getBasNameTable": 0x800c10ec,
		"TBossTelesa::flashItem": 0x800c10f8,
		"flashItem": 0x800c10f8,
		"TBossTelesa::slotFall": 0x800c137c,
		"slotFall": 0x800c137c,
		"TBossTelesa::rouletteFall": 0x800c14c4,
		"rouletteFall": 0x800c14c4,
		"TBossTelesa::damageRecover": 0x800c162c,
		"damageRecover": 0x800c162c,
		"TBossTelesa::setSpicy": 0x800c18ac,
		"setSpicy": 0x800c18ac,
		"TBossTelesa::checkHitObject": 0x800c1a44,
		"checkHitObject": 0x800c1a44,
		"TBossTelesa::receiveMessage": 0x800c1d0c,
		"TBossTelesa::perform": 0x800c1d14,
		"TBossTelesa::calcRootMatrix": 0x800c1e68,
		"TBossTelesa::getTakingMtx": 0x800c23dc,
		"TBossTelesa::kill": 0x800c2444,
		"TBossTelesa::moveObject": 0x800c255c,
		"TBossTelesa::reset": 0x800c2e40,
		"TBossTelesa::loadAfter": 0x800c2f68,
		"TBossTelesa::init": 0x800c3c74,
		"TBossTelesa::TBossTelesa": 0x800c4400,
		"TTelesaSlot::getResultFromAng": 0x800c44bc,
		"TTelesaSlot::getForcastResult": 0x800c4564,
		"TTelesaSlot::getSlotResult": 0x800c4694,
		"getSlotResult": 0x800c4694,
		"TTelesaSlot::isRollDrum": 0x800c4720,
		"isRollDrum": 0x800c4720,
		"TTelesaSlot::forceStopSlot": 0x800c476c,
		"forceStopSlot": 0x800c476c,
		"TTelesaSlot::touchWater": 0x800c48e8,
		"TTelesaSlot::moveStart": 0x800c48f0,
		"moveStart": 0x800c48f0,
		"TTelesaSlot::moveObject": 0x800c4994,
		"TTelesaSlot::calcRootMatrix": 0x800c4dec,
		"TTelesaSlot::randomReset": 0x800c4eb0,
		"randomReset": 0x800c4eb0,
		"TTelesaSlot::initMapObj": 0x800c4f9c,
		"TBossTelesaKillSmallEnemy::checkHit": 0x800c5120,
		"TBossTelesaTongue::receiveMessage": 0x800c5258,
		"TBossTelesaBody::receiveMessage": 0x800c537c,
		"TBossTelesaManager::perform": 0x800c55c4,
		"TBossTelesaManager::createModelData": 0x800c55e4,
		"TBossTelesaManager::createEnemyInstance": 0x800c5618,
		"TBossTelesaManager::load": 0x800c5660,
		"TBossTelesaManager::TBossTelesaManager": 0x800c56cc,
		"TBossTelesaSaveLoadParams::TBossTelesaSaveLoadParams": 0x800c5708,
		"TNerveBubbleSplit::execute": 0x800c5aa8,
		"TNerveBubbleSplit::~TNerveBubbleSplit": 0x800c5b68,
		"TNerveBubbleLive::execute": 0x800c5bc4,
		"TBubble::appendEnemy": 0x800c5fac,
		"appendEnemy": 0x800c5fac,
		"TNerveBubbleLive::~TNerveBubbleLive": 0x800c61c0,
		"TBubble::getBasNameTable": 0x800c621c,
		"TBubble::getTakingMtx": 0x800c6228,
		"TBubble::setDeadAnm": 0x800c6238,
		"TBubble::calcRootMatrix": 0x800c6268,
		"TBubble::attackToMario": 0x800c6330,
		"TBubble::behaveToWater": 0x800c637c,
		"TBubble::kill": 0x800c6468,
		"TBubble::getGravityY": 0x800c658c,
		"TBubble::split": 0x800c65bc,
		"split": 0x800c65bc,
		"TBubble::reset": 0x800c6774,
		"TBubble::init": 0x800c6888,
		"TBubbleManager::createModelData": 0x800c69b0,
		"TBubbleManager::createEnemyInstance": 0x800c69e4,
		"TBubbleManager::load": 0x800c6a74,
		"TBubbleManager::TBubbleManager": 0x800c6c10,
		"TTelesaSlot::initNeonMatColor": 0x800c6e44,
		"TBossTelesaManager::~TBossTelesaManager": 0x800c70c4,
		"TBossTelesaManager::clipEnemies": 0x800c7128,
		"TBubble::setAfterDeadEffect": 0x800c712c,
		"TBubbleManager::~TBubbleManager": 0x800c71cc,
		"Enemy::__sinit_bosstelesa_cpp": 0x800c7240,
		"__sinit_bosstelesa_cpp": 0x800c7240,
		"TNerveRHGraphWander::~TNerveRHGraphWander": 0x800c7574,
		"TNerveRHGraphWander::execute": 0x800c75d0,
		"TRiccoHookManager::createEnemyInstance": 0x800c78b0,
		"TRiccoHookManager::load": 0x800c78b8,
		"TRiccoHookManager::createModelData": 0x800c79e4,
		"TRiccoHookManager::TRiccoHookManager": 0x800c7a18,
		"TRiccoHook::perform": 0x800c7a54,
		"TRiccoHook::receiveMessage": 0x800c7b44,
		"TRiccoHook::kill": 0x800c7b4c,
		"TRiccoHook::init": 0x800c7b50,
		"TRiccoHook::TRiccoHook": 0x800c7dac,
		"THookTake::perform": 0x800c7dfc,
		"THookTake::receiveMessage": 0x800c7ee0,
		"THookTake::getRadiusAtY": 0x800c7f28,
		"THookTake::getTakingMtx": 0x800c7f5c,
		"TRiccoHookManager::~TRiccoHookManager": 0x800c7f64,
		"TNerveBombHeiExplosion::~TNerveBombHeiExplosion": 0x800c83dc,
		"TNerveBombHeiExplosion::execute": 0x800c8438,
		"TNerveBombHeiThrown::execute": 0x800c86c0,
		"TNerveBombHeiThrown::~TNerveBombHeiThrown": 0x800c8874,
		"TNerveBombHeiPickUp::execute": 0x800c88d0,
		"TNerveBombHeiPickUp::~TNerveBombHeiPickUp": 0x800c88fc,
		"TNerveBombHeiWaitExplosion::execute": 0x800c8958,
		"TNerveBombHeiWaitExplosion::~TNerveBombHeiWaitExplosion": 0x800c8bc8,
		"TNerveBombHeiWalkExplosion::execute": 0x800c8c24,
		"TNerveBombHeiWalkExplosion::~TNerveBombHeiWalkExplosion": 0x800c8dd4,
		"TNerveBombHeiAttack::execute": 0x800c8e30,
		"TNerveBombHeiAttack::~TNerveBombHeiAttack": 0x800c8f20,
		"TNerveBombHeiGenerate::execute": 0x800c8f7c,
		"TNerveBombHeiGenerate::~TNerveBombHeiGenerate": 0x800c91b0,
		"TBombHei::getBasNameTable": 0x800c920c,
		"TBombHei::isDamageToCannon": 0x800c9218,
		"isDamageToCannon": 0x800c9218,
		"TBombHei::forceKill": 0x800c9308,
		"TBombHei::isCollidMove": 0x800c9514,
		"TBombHei::moveObject": 0x800c9858,
		"TBombHei::walkBehavior": 0x800c9abc,
		"TBombHei::getGravityY": 0x800c9b40,
		"TBombHei::reset": 0x800c9bd0,
		"TBombHei::behaveToRelease": 0x800c9c28,
		"TBombHei::behaveToTaken": 0x800c9da8,
		"TBombHei::attackToMario": 0x800c9efc,
		"TBombHei::calcRootMatrix": 0x800c9f88,
		"TBombHei::setDeadAnm": 0x800ca044,
		"TBombHei::setFreezeAnm": 0x800ca120,
		"TBombHei::setWalkAnm": 0x800ca150,
		"TBombHei::genEventCoin": 0x800ca180,
		"TBombHei::kill": 0x800ca290,
		"TBombHei::isHitValid": 0x800ca424,
		"TBombHei::changeOut": 0x800ca47c,
		"TBombHei::behaveToWater": 0x800ca570,
		"TBombHei::setMActorAndKeeper": 0x800ca684,
		"TBombHei::init": 0x800ca704,
		"TBombHei::TBombHei": 0x800ca7fc,
		"TBombHeiManager::createEnemyInstance": 0x800ca858,
		"TBombHeiManager::createModelData": 0x800ca8c8,
		"TBombHeiManager::load": 0x800ca8fc,
		"TBombHeiManager::TBombHeiManager": 0x800caa8c,
		"TBombHei::setAfterDeadEffect": 0x800caad0,
		"TBombHei::doKeepDistance": 0x800caad4,
		"TBombHeiManager::~TBombHeiManager": 0x800cab88,
		"Enemy::__sinit_bombhei_cpp": 0x800cac00,
		"__sinit_bombhei_cpp": 0x800cac00,
		"TNerveCannonObject::~TNerveCannonObject": 0x800caf04,
		"TNerveCannonObject::execute": 0x800caf60,
		"TNerveCannonDamageDemo::execute": 0x800cb140,
		"TNerveCannonDamageDemo::~TNerveCannonDamageDemo": 0x800cb36c,
		"TNerveCannonDamage::execute": 0x800cb3c8,
		"TNerveCannonSearch::~TNerveCannonSearch": 0x800cb9dc,
		"TNerveCannonDamage::~TNerveCannonDamage": 0x800cba38,
		"TNerveCannonClose::execute": 0x800cba94,
		"TNerveCannonOpen::~TNerveCannonOpen": 0x800cbdcc,
		"TNerveCannonClose::~TNerveCannonClose": 0x800cbe28,
		"TNerveCannonForceBombShoot::execute": 0x800cbe84,
		"TNerveCannonForceBombShoot::~TNerveCannonForceBombShoot": 0x800cc130,
		"TNerveCannonShoot::execute": 0x800cc18c,
		"TNerveCannonShoot::~TNerveCannonShoot": 0x800cc528,
		"TNerveCannonSearch::execute": 0x800cc584,
		"TNerveCannonOpen::execute": 0x800ccc48,
		"TCannon::startChorobeiShout": 0x800cce10,
		"startChorobeiShout": 0x800cce10,
		"TCannon::isObject": 0x800cce14,
		"isObject": 0x800cce14,
		"TCannon::setKillerGoalPoint": 0x800cce6c,
		"setKillerGoalPoint": 0x800cce6c,
		"TCannon::killerShoot": 0x800cd0ac,
		"killerShoot": 0x800cd0ac,
		"TCannon::bombShoot": 0x800cd9a4,
		"bombShoot": 0x800cd9a4,
		"TCannon::bombSet": 0x800cdb70,
		"bombSet": 0x800cdb70,
		"TCannon::getTakingMtx": 0x800cddd4,
		"TCannon::calcRootMatrix": 0x800cde98,
		"TCannon::perform": 0x800ce324,
		"TCannon::getBasNameTable": 0x800ce7c0,
		"TCannon::receiveMessage": 0x800ce7cc,
		"TCannon::moveObject": 0x800ce814,
		"TCannon::reset": 0x800ceaf0,
		"TCannon::init": 0x800cec18,
		"TCannon::loadAfter": 0x800cf1fc,
		"TCannon::load": 0x800cf3ac,
		"TCannon::TCannon": 0x800cf454,
		"TCannonDom::perform": 0x800cf51c,
		"TCannonDom::TCannonDom": 0x800cf614,
		"TChorobei::receiveMessage": 0x800cf724,
		"TChorobei::checkHit": 0x800cf72c,
		"TChorobei::perform": 0x800cf9b8,
		"TChorobei::TChorobei": 0x800cfae0,
		"TCannonManager::createEnemyInstance": 0x800cfbf4,
		"TCannonManager::load": 0x800cfc38,
		"TCannonManager::TCannonManager": 0x800cfc90,
		"TCannonSaveLoadParams::TCannonSaveLoadParams": 0x800cfccc,
		"TCannon::isCollidMove": 0x800cff70,
		"TCannon::isHitVallid": 0x800cff78,
		"isHitVallid": 0x800cff78,
		"TCannon::isInhibitedForceMove": 0x800cff80,
		"TCannonDom::~TCannonDom": 0x800d000c,
		"TCannonManager::~TCannonManager": 0x800d0114,
		"TCannonManager::clipEnemies": 0x800d0188,
		"Enemy::__sinit_cannon_cpp": 0x800d018c,
		"__sinit_cannon_cpp": 0x800d018c,
		"TNerveBossEelSleepOnBottom::~TNerveBossEelSleepOnBottom": 0x800d0498,
		"TNerveBossEelSleepOnBottom::execute": 0x800d04f4,
		"TNerveBossEelSleepOnBottom::theNerve": 0x800d0688,
		"TNerveBossEelMouthOpenWait::execute": 0x800d06ec,
		"TNerveBossEelEat::~TNerveBossEelEat": 0x800d0bf4,
		"TNerveBossEelMouthOpenWait::theNerve": 0x800d0c50,
		"TNerveBossEelMouthOpenWait::~TNerveBossEelMouthOpenWait": 0x800d0cb4,
		"TNerveBossEelDie::execute": 0x800d0d10,
		"TNerveBossEelDie::theNerve": 0x800d1190,
		"TNerveBossEelDie::~TNerveBossEelDie": 0x800d11f4,
		"TNerveBossEelEat::execute": 0x800d1250,
		"TNerveBossEelQuickBack::~TNerveBossEelQuickBack": 0x800d1884,
		"TNerveBossEelEat::theNerve": 0x800d18e0,
		"TNerveBossEelQuickBack::execute": 0x800d1944,
		"TNerveBossEelQuickBack::theNerve": 0x800d1a68,
		"TNerveBossEelSlowBack::execute": 0x800d1acc,
		"TNerveBossEelSlowBack::theNerve": 0x800d1af4,
		"TNerveBossEelSlowBack::~TNerveBossEelSlowBack": 0x800d1b58,
		"Enemy::ExecBackNerve_Sub": 0x800d1bb4,
		"ExecBackNerve_Sub": 0x800d1bb4,
		"TNerveBossEelSecondSpin::~TNerveBossEelSecondSpin": 0x800d1f5c,
		"TNerveBossEelOutWait::execute": 0x800d1fb8,
		"TNerveBossEelOutWait::~TNerveBossEelOutWait": 0x800d256c,
		"TNerveBossEelOutWait::theNerve": 0x800d25c8,
		"TNerveBossEelAppear::execute": 0x800d262c,
		"TNerveBossEelAppear::theNerve": 0x800d2978,
		"TNerveBossEelAppear::~TNerveBossEelAppear": 0x800d29dc,
		"TNerveBossEelSecondSpin::execute": 0x800d2a38,
		"TNerveBossEelSecondSpin::theNerve": 0x800d2e48,
		"TNerveBossEelFirstSpin::execute": 0x800d2eac,
		"TNerveBossEelFirstSpin::theNerve": 0x800d31f4,
		"TNerveBossEelFirstSpin::~TNerveBossEelFirstSpin": 0x800d3258,
		"TNerveBossEelWaitAppear::execute": 0x800d32b4,
		"TNerveBossEelWaitAppear::theNerve": 0x800d34a0,
		"TNerveBossEelWaitAppear::~TNerveBossEelWaitAppear": 0x800d3504,
		"TBossEel::getBasNameTable": 0x800d3560,
		"Enemy::hoseiDiveCameraCallback": 0x800d356c,
		"hoseiDiveCameraCallback": 0x800d356c,
		"TBossEel::isInBossEelMoguDemo": 0x800d35cc,
		"isInBossEelMoguDemo": 0x800d35cc,
		"TBossEel::perform": 0x800d3628,
		"TBossEel::collideToMario": 0x800d4260,
		"collideToMario": 0x800d4260,
		"TBossEel::forceShedTears": 0x800d4630,
		"forceShedTears": 0x800d4630,
		"TBossEel::shedTears": 0x800d4754,
		"shedTears": 0x800d4754,
		"TBossEel::updateTearsCnt": 0x800d48bc,
		"updateTearsCnt": 0x800d48bc,
		"TBossEel::getTakingMtx": 0x800d4b50,
		"TBossEel::init": 0x800d4b64,
		"TBossEelTearsRecoverCollision::perform": 0x800d56e8,
		"TBossEelTearsRecoverCollision::behaveToMario": 0x800d5798,
		"TBossEelTearsRecoverCollision::initCollision": 0x800d57dc,
		"TBossEelBarrierCollision::behaveToMario": 0x800d5830,
		"TBossEelBarrierCollision::initCollision": 0x800d589c,
		"TBossEelAwaCollision::perform": 0x800d58f0,
		"TBossEelAwaCollision::behaveToMario": 0x800d5a24,
		"TBossEelAwaCollision::initCollision": 0x800d5aa0,
		"TBossEelBodyCollision::initCollision": 0x800d5af4,
		"TBossEelCollision::behaveToMario": 0x800d5b50,
		"TBossEelCollision::initCollision": 0x800d5d78,
		"TBossEelCollision::perform": 0x800d5db8,
		"TNerveBEelTearsMarioRecover::~TNerveBEelTearsMarioRecover": 0x800d5e94,
		"TBossEel::TBossEel": 0x800d5ef0,
		"TBossEelHeartCoin::generate": 0x800d5fd8,
		"TBossEelHeartCoin::perform": 0x800d60a4,
		"TBossEelEye::perform": 0x800d6304,
		"TBossEelEye::TBossEelEye": 0x800d65b4,
		"TBossEelVortex::reset": 0x800d66fc,
		"TBossEelVortex::perform": 0x800d6720,
		"TBossEelTooth::perform": 0x800d6a70,
		"TBossEelTooth::receiveMessage": 0x800d7080,
		"TBossEelTooth::TBossEelTooth": 0x800d73b4,
		"TBossEelManager::clipEnemies": 0x800d75dc,
		"TBossEelManager::createModelData": 0x800d7604,
		"TBossEelManager::loadAfter": 0x800d7638,
		"TBossEelSaveParams::TBossEelSaveParams": 0x800d78dc,
		"TNerveOilBallStay::execute": 0x800d7f50,
		"TNerveOilBallStay::theNerve": 0x800d7fdc,
		"TNerveOilBallStay::~TNerveOilBallStay": 0x800d8040,
		"TOilBall::calcRootMatrix": 0x800d809c,
		"TOilBall::moveObject": 0x800d80bc,
		"TNerveBEelTearsSplit::~TNerveBEelTearsSplit": 0x800d8428,
		"TNerveBEelTearsMoveUp::~TNerveBEelTearsMoveUp": 0x800d8484,
		"TOilBall::reset": 0x800d84e0,
		"TNerveBEelTearsGenerate::~TNerveBEelTearsGenerate": 0x800d8670,
		"TOilBall::load": 0x800d86cc,
		"TNerveBEelTearsSplit::execute": 0x800d872c,
		"TNerveBEelTearsSplit::theNerve": 0x800d897c,
		"TNerveBEelTearsMarioRecover::execute": 0x800d89e0,
		"TNerveBEelTearsMarioRecover::theNerve": 0x800d8b40,
		"TNerveBEelTearsWaterHit::execute": 0x800d8ba4,
		"TNerveBEelTearsWaterHit::theNerve": 0x800d8e68,
		"TNerveBEelTearsWaterHit::~TNerveBEelTearsWaterHit": 0x800d8ecc,
		"TNerveBEelTearsMoveUp::execute": 0x800d8f28,
		"TNerveBEelTearsMoveUp::theNerve": 0x800d8f94,
		"TNerveBEelTearsGenerate::execute": 0x800d8ff8,
		"TNerveBEelTearsGenerate::theNerve": 0x800d90f0,
		"TBEelTears::getBasNameTable": 0x800d9154,
		"TBEelTears::reset": 0x800d9160,
		"TBEelTears::kill": 0x800d924c,
		"TBEelTears::receiveMessage": 0x800d9278,
		"TBEelTears::perform": 0x800d9474,
		"TBEelTears::calcRootMatrix": 0x800d95c0,
		"TBEelTears::moveObject": 0x800d9728,
		"TBEelTears::setMActorAndKeeper": 0x800d9af0,
		"TBEelTears::init": 0x800d9b70,
		"TBEelTears::TBEelTears": 0x800d9e8c,
		"TBEelTearsManager::splitTears": 0x800d9eec,
		"splitTears": 0x800d9eec,
		"TBEelTearsManager::createEnemies": 0x800da168,
		"TBEelTearsManager::createEnemyInstance": 0x800da220,
		"TBEelTearsManager::perform": 0x800da298,
		"TBEelTearsManager::createModelData": 0x800da394,
		"TBEelTearsManager::loadAfter": 0x800da3c8,
		"TBEelTearsManager::load": 0x800da48c,
		"TBEelTearsManager::TBEelTearsManager": 0x800da4f8,
		"TBEelTearsSaveLoadParams::TBEelTearsSaveLoadParams": 0x800da534,
		"TBEelTearsDrop::perform": 0x800da8dc,
		"TBEelTearsDrop::TBEelTearsDrop": 0x800daa2c,
		"TBossEel::hasMapCollision": 0x800dacc4,
		"TBossEel::receiveMessage": 0x800daccc,
		"TBossEelHeartCoin::~TBossEelHeartCoin": 0x800daf44,
		"TBossEelEye::~TBossEelEye": 0x800dafc8,
		"TBossEelManager::~TBossEelManager": 0x800db154,
		"TBEelTearsManager::~TBEelTearsManager": 0x800db2a8,
		"Enemy::__sinit_bosseel_cpp": 0x800db390,
		"__sinit_bosseel_cpp": 0x800db390,
		"TNerveKillerExplosion::~TNerveKillerExplosion": 0x800db6e4,
		"TNerveKillerExplosion::execute": 0x800db740,
		"TKiller::isFindMario": 0x800db9e4,
		"TKiller::calcRootMatrix": 0x800dba9c,
		"TKiller::bind": 0x800dbe64,
		"TNerveFlyEnemyChaseFly::~TNerveFlyEnemyChaseFly": 0x800dc25c,
		"TKiller::setColorType": 0x800dc2b8,
		"setColorType": 0x800dc2b8,
		"TKiller::reset": 0x800dc2fc,
		"TKiller::changeOut": 0x800dc410,
		"TKiller::flyBehavior": 0x800dc504,
		"TKiller::isCollidMove": 0x800dc5bc,
		"TKiller::isRollFly": 0x800dc720,
		"isRollFly": 0x800dc720,
		"TKiller::setChaseFlyAnm": 0x800dc7cc,
		"TKiller::setNormalFlyAnm": 0x800dc7fc,
		"TKiller::getBasNameTable": 0x800dc860,
		"TKiller::attackToMario": 0x800dc86c,
		"TKiller::setDeadAnm": 0x800dc9bc,
		"TKiller::isHitValid": 0x800dca60,
		"TKiller::genEventCoin": 0x800dcad4,
		"TKiller::behaveToWater": 0x800dccb8,
		"TNerveFlyEnemyNormalFly::~TNerveFlyEnemyNormalFly": 0x800dcec8,
		"TKiller::setMActorAndKeeper": 0x800dcf24,
		"TKiller::init": 0x800dd078,
		"TKiller::TKiller": 0x800dd218,
		"Enemy::KillerBodyCallback": 0x800dd328,
		"KillerBodyCallback": 0x800dd328,
		"TKillerManager::createEnemyInstance": 0x800dd520,
		"TFlyEnemy::TFlyEnemy": 0x800dd588,
		"TKillerManager::createModelData": 0x800dd5e8,
		"TKillerManager::load": 0x800dd61c,
		"TKillerManager::TKillerManager": 0x800dd83c,
		"TNerveFlyEnemyChaseFly::execute": 0x800dd880,
		"TFlyEnemy::flyBehavior": 0x800dddc8,
		"Enemy::MsSin": 0x800ddddc,
		"MsSin": 0x800ddddc,
		"Enemy::MsCos": 0x800dde14,
		"MsCos": 0x800dde14,
		"TFlyEnemy::setChaseFlyAnm": 0x800dde94,
		"TNerveFlyEnemyNormalFly::execute": 0x800dde98,
		"TFlyEnemy::setNormalFlyAnm": 0x800de0e8,
		"TFlyEnemy::bind": 0x800de0ec,
		"TFlyEnemy::calcChaseParam": 0x800de190,
		"calcChaseParam": 0x800de190,
		"TFlyEnemy::fly": 0x800de3c0,
		"fly": 0x800de3c0,
		"TFlyEnemy::reset": 0x800de604,
		"TFlyEnemy::getGravityY": 0x800de654,
		"TFlyEnemy::init": 0x800de6e4,
		"TKiller::forceKill": 0x800de728,
		"TFlyEnemy::setAfterDeadEffect": 0x800de72c,
		"TKillerManager::~TKillerManager": 0x800de7cc,
		"Enemy::__sinit_killer_cpp": 0x800de840,
		"__sinit_killer_cpp": 0x800de840,
		"TBeamManager::~TBeamManager": 0x800deb4c,
		"TBeamManager::perform": 0x800debc0,
		"TBeamManager::requestCone": 0x800decf0,
		"requestCone": 0x800decf0,
		"TBeamManager::setupMaterial": 0x800dede8,
		"setupMaterial": 0x800dede8,
		"TBeamManager::TBeamManager": 0x800deec0,
		"TConeBeam::drawConeBeam": 0x800def6c,
		"drawConeBeam": 0x800def6c,
		"TConeBeam::calcVertices": 0x800df0e8,
		"calcVertices": 0x800df0e8,
		"TConeBeam::drawConeBeamAux": 0x800df778,
		"drawConeBeamAux": 0x800df778,
		"TConeBeam::TConeBeam": 0x800df944,
		"TNerveSamboHeadHitWall::~TNerveSamboHeadHitWall": 0x800df9c4,
		"TNerveSamboHeadHitWall::execute": 0x800dfa20,
		"TNerveSamboHeadRecoverWater::execute": 0x800dfc34,
		"TNerveSamboHeadRecoverWater::~TNerveSamboHeadRecoverWater": 0x800dfcc0,
		"TNerveSamboHeadHitWater::execute": 0x800dfd1c,
		"TNerveSamboHeadAttack::~TNerveSamboHeadAttack": 0x800e021c,
		"TNerveSamboHeadHitWater::~TNerveSamboHeadHitWater": 0x800e0278,
		"TNerveSamboHeadHide::execute": 0x800e02d4,
		"TNerveSamboHeadAppear::~TNerveSamboHeadAppear": 0x800e0514,
		"TNerveSamboHeadHide::~TNerveSamboHeadHide": 0x800e0570,
		"TNerveSamboHeadAttack::execute": 0x800e05cc,
		"TNerveSamboHeadAppear::execute": 0x800e094c,
		"TSamboHead::getBasNameTable": 0x800e0bcc,
		"TSamboHead::genEventCoin": 0x800e0bd8,
		"TSamboHead::calcRootMatrix": 0x800e0ea4,
		"TSamboHead::setAfterDeadEffect": 0x800e0ec8,
		"TSamboHead::setDeadAnm": 0x800e0ff8,
		"TSamboHead::getGravityY": 0x800e1028,
		"TSamboHead::attackToMario": 0x800e1120,
		"TSamboHead::behaveToWater": 0x800e12a4,
		"TSamboHead::kill": 0x800e15cc,
		"TSamboHead::reset": 0x800e168c,
		"TSamboHead::setMActorAndKeeper": 0x800e16e0,
		"TSamboHead::init": 0x800e174c,
		"TSamboHead::load": 0x800e189c,
		"TSamboHead::TSamboHead": 0x800e195c,
		"TSamboHeadManager::createEnemyInstance": 0x800e19bc,
		"TSamboHeadManager::createModelData": 0x800e1a34,
		"TSamboHeadManager::load": 0x800e1a68,
		"TSamboHeadManager::TSamboHeadManager": 0x800e1d00,
		"Enemy::SamboHeadRollCallback": 0x800e1d44,
		"SamboHeadRollCallback": 0x800e1d44,
		"TNerveHanaSamboFreeze::execute": 0x800e2048,
		"TNerveHanaSamboFreeze::~TNerveHanaSamboFreeze": 0x800e2144,
		"TNerveHanaSamboDie::execute": 0x800e21a0,
		"TNerveHanaSamboDie::~TNerveHanaSamboDie": 0x800e23dc,
		"TNerveHanaSamboHide::execute": 0x800e2438,
		"TNerveHanaSamboAppear::~TNerveHanaSamboAppear": 0x800e26cc,
		"TNerveHanaSamboHide::~TNerveHanaSamboHide": 0x800e2728,
		"TNerveHanaSamboAttack::execute": 0x800e2784,
		"TNerveHanaSamboWait::~TNerveHanaSamboWait": 0x800e2978,
		"TNerveHanaSamboAttack::~TNerveHanaSamboAttack": 0x800e29d4,
		"TNerveHanaSamboWait::execute": 0x800e2a30,
		"TNerveHanaSamboAppear::execute": 0x800e2c3c,
		"THanaSambo::createPollen": 0x800e2e8c,
		"createPollen": 0x800e2e8c,
		"THanaSambo::perform": 0x800e3034,
		"THanaSambo::getBasNameTable": 0x800e3094,
		"THanaSambo::setDeadAnm": 0x800e30a0,
		"THanaSambo::setWaitAnm": 0x800e3140,
		"THanaSambo::reset": 0x800e3184,
		"THanaSambo::kill": 0x800e31d0,
		"THanaSambo::drawObject": 0x800e3390,
		"THanaSambo::moveObject": 0x800e33d0,
		"THanaSambo::setMActorAndKeeper": 0x800e354c,
		"THanaSambo::init": 0x800e35cc,
		"THanaSambo::load": 0x800e387c,
		"THanaSambo::THanaSambo": 0x800e393c,
		"THanaSamboHead::receiveMessage": 0x800e39b8,
		"THanaSamboManager::createModelData": 0x800e3b30,
		"THanaSamboManager::createEnemyInstance": 0x800e3b64,
		"THanaSamboManager::load": 0x800e3bf8,
		"THanaSamboManager::THanaSamboManager": 0x800e3e0c,
		"TSamboFlower::drawObject": 0x800e3e48,
		"TSamboFlower::moveObject": 0x800e3f00,
		"TSamboFlower::reset": 0x800e40a8,
		"TSamboFlower::receiveMessage": 0x800e4114,
		"TSamboFlower::setMActorAndKeeper": 0x800e4200,
		"TSamboFlower::init": 0x800e4298,
		"TSamboFlower::loadAfter": 0x800e43ac,
		"TSamboFlower::load": 0x800e4430,
		"TSamboFlowerManager::dropLeaf": 0x800e44b0,
		"dropLeaf": 0x800e44b0,
		"TSamboFlowerManager::perform": 0x800e46e0,
		"TSamboFlowerManager::loadAfter": 0x800e4798,
		"TSamboFlowerManager::createEnemyInstance": 0x800e4b50,
		"TSamboFlowerManager::createModelData": 0x800e4c00,
		"TSamboFlowerManager::load": 0x800e4c34,
		"TSamboFlowerSaveLoadParams::TSamboFlowerSaveLoadParams": 0x800e4ca0,
		"TSamboLeaf::perform": 0x800e4f40,
		"TSamboFlowerCoinUnit::checkGenCoin": 0x800e5164,
		"checkGenCoin": 0x800e5164,
		"TSamboHeadManager::~TSamboHeadManager": 0x800e5554,
		"THanaSambo::behaveToWater": 0x800e55c8,
		"THanaSambo::isHitValid": 0x800e55cc,
		"THanaSambo::isCollidMove": 0x800e55f0,
		"THanaSamboManager::~THanaSamboManager": 0x800e5700,
		"TSamboFlower::control": 0x800e5774,
		"TSamboFlowerManager::~TSamboFlowerManager": 0x800e57e4,
		"TSamboLeaf::~TSamboLeaf": 0x800e5848,
		"Enemy::__sinit_hanasambo_cpp": 0x800e58bc,
		"__sinit_hanasambo_cpp": 0x800e58bc,
		"TNervePopoThrown::~TNervePopoThrown": 0x800e5bd8,
		"TNervePopoThrown::execute": 0x800e5c34,
		"TNervePopoWait::execute": 0x800e5ccc,
		"TNervePopoWait::~TNervePopoWait": 0x800e5dbc,
		"TNervePopoExplosion::execute": 0x800e5e18,
		"TNervePopoExplosion::~TNervePopoExplosion": 0x800e601c,
		"TNervePopoFly::execute": 0x800e6078,
		"TNervePopoFly::~TNervePopoFly": 0x800e635c,
		"TNervePopoAttack::execute": 0x800e63b8,
		"TNervePopoAttack::~TNervePopoAttack": 0x800e6550,
		"TNervePopoPossessedNozzle::execute": 0x800e65ac,
		"TNervePopoPossessedNozzle::~TNervePopoPossessedNozzle": 0x800e677c,
		"TPopo::getBasNameTable": 0x800e67d8,
		"TPopo::thrownByChorobei": 0x800e67e4,
		"thrownByChorobei": 0x800e67e4,
		"TPopo::possessedIn": 0x800e6870,
		"possessedIn": 0x800e6870,
		"TPopo::explosion": 0x800e6984,
		"explosion": 0x800e6984,
		"TPopo::flyBehavior": 0x800e6ad0,
		"TPopo::isCollidMove": 0x800e6c94,
		"TPopo::isFindMario": 0x800e6de4,
		"TPopo::isHitValid": 0x800e6eb4,
		"TPopo::bind": 0x800e6f94,
		"TPopo::forceKill": 0x800e7380,
		"TPopo::kill": 0x800e75a4,
		"TPopo::calcRootMatrix": 0x800e7604,
		"TPopo::attackToMario": 0x800e7ac8,
		"TPopo::walkBehavior": 0x800e7d70,
		"TPopo::behaveToFindMario": 0x800e8250,
		"TPopo::getGravityY": 0x800e843c,
		"TPopo::behaveToWater": 0x800e85f0,
		"TPopo::checkTrigger": 0x800e8898,
		"checkTrigger": 0x800e8898,
		"TPopo::reset": 0x800e8ba8,
		"TPopo::setMActorAndKeeper": 0x800e8cec,
		"TPopo::perform": 0x800e8d6c,
		"TPopo::init": 0x800e8dc0,
		"TPopo::load": 0x800e900c,
		"TPopo::TPopo": 0x800e906c,
		"Enemy::PopoNonScaleCallback": 0x800e90e8,
		"PopoNonScaleCallback": 0x800e90e8,
		"Enemy::PopoPossessedCallback": 0x800e9284,
		"PopoPossessedCallback": 0x800e9284,
		"Enemy::PopoRollCallback": 0x800e9634,
		"PopoRollCallback": 0x800e9634,
		"TPopoCollision::receiveMessage": 0x800e9864,
		"TPopoManager::perform": 0x800e9940,
		"TPopoManager::createModelData": 0x800e9a00,
		"TPopoManager::initSetEnemies": 0x800e9a34,
		"TPopoManager::createEnemyInstance": 0x800e9a74,
		"TPopoManager::load": 0x800e9ab8,
		"TPopoManager::TPopoManager": 0x800e9b5c,
		"TPopoSaveLoadParams::TPopoSaveLoadParams": 0x800e9bb4,
		"TPopoManager::~TPopoManager": 0x800e9fd4,
		"Enemy::__sinit_popo_cpp": 0x800ea048,
		"__sinit_popo_cpp": 0x800ea048,
		"TNerveSBH_Fall::~TNerveSBH_Fall": 0x800ea354,
		"TNerveSBH_Fall::execute": 0x800ea3b0,
		"TNerveSBH_SleepContinue::~TNerveSBH_SleepContinue": 0x800ea4ec,
		"TNerveSBH_Fall::theNerve": 0x800ea548,
		"TNerveSBH_SleepContinue::execute": 0x800ea5ac,
		"TNerveSBH_SleepContinue::theNerve": 0x800ea5b4,
		"TSleepBossHanachan::startFall": 0x800ea618,
		"startFall": 0x800ea618,
		"TSleepBossHanachan::getBasNameTable": 0x800ea704,
		"TSleepBossHanachan::calcRootMatrix": 0x800ea70c,
		"TSleepBossHanachan::init": 0x800ea710,
		"TSleepBossHanachanManager::createModelData": 0x800ea8d0,
		"TSleepBossHanachanManager::~TSleepBossHanachanManager": 0x800ea988,
		"TDemoBossHanachan::receiveMessage": 0x800eaa70,
		"TDemoBossHanachan::initBase": 0x800eaa78,
		"initBase": 0x800eaa78,
		"TDemoBossHanachanManager::clipEnemies": 0x800eab78,
		"TDemoBossHanachanSaveParams::TDemoBossHanachanSaveParams": 0x800eaba4,
		"TNerveFruitsBoatBckTrace::~TNerveFruitsBoatBckTrace": 0x800eacdc,
		"TNerveFruitsBoatBckTrace::execute": 0x800ead38,
		"TNerveFruitsBoatGraphWander::execute": 0x800eae98,
		"TNerveFruitsBoatGraphWander::~TNerveFruitsBoatGraphWander": 0x800eb2bc,
		"TFruitsBoatManager::createEnemyInstance": 0x800eb360,
		"TFruitsBoatManager::load": 0x800eb368,
		"TFruitsBoatManager::createModelData": 0x800eb468,
		"TFruitsBoatManager::TFruitsBoatManager": 0x800eb50c,
		"TFruitsBoat::requestShadow": 0x800eb55c,
		"TFruitsBoat::moveObject": 0x800eb6bc,
		"TFruitsBoat::calcRootMatrix": 0x800ebef4,
		"TFruitsBoat::setGroundCollision": 0x800ebfa4,
		"TFruitsBoat::receiveMessage": 0x800ec148,
		"TFruitsBoat::init": 0x800ec150,
		"TFruitsBoat::load": 0x800ec5f4,
		"TFruitsBoat::getRootJointMtx": 0x800ec74c,
		"TFruitsBoat::setBckTrack": 0x800ec75c,
		"setBckTrack": 0x800ec75c,
		"TFruitsBoat::TFruitsBoat": 0x800ec874,
		"TFruitsBoatManager::~TFruitsBoatManager": 0x800ec8fc,
		"Enemy::__sinit_fruitsboat_cpp": 0x800ec9cc,
		"__sinit_fruitsboat_cpp": 0x800ec9cc,
		"TSphereLink::setDegreeZAndRevisionPosXZ": 0x800ecd54,
		"setDegreeZAndRevisionPosXZ": 0x800ecd54,
		"TSphereLink::moveHead": 0x800ecf70,
		"TBGCheckData::isIllegalData": 0x800ed344,
		"isIllegalData": 0x800ed344,
		"TSphereLink::TSphereLink": 0x800ed360,
		"TSpherePoint::TSpherePoint": 0x800ed540,
		"TWaterHitActor::receiveMessage": 0x800ed544,
		"TWaterHitActor::onWaterHitCounter": 0x800ed5b4,
		"onWaterHitCounter": 0x800ed5b4,
		"Enemy::BHSCalcRevisionDistXZByRotateZ": 0x800ed5c0,
		"BHSCalcRevisionDistXZByRotateZ": 0x800ed5c0,
		"Enemy::BHSCalcCentrifugalForce": 0x800ed64c,
		"BHSCalcCentrifugalForce": 0x800ed64c,
		"TBossHanachan::hasMapCollision": 0x800ed970,
		"TBossHanachan::removeAllMapCollision": 0x800ed978,
		"removeAllMapCollision": 0x800ed978,
		"TBossHanachan::execDamage": 0x800ed9fc,
		"execDamage": 0x800ed9fc,
		"TBossHanachan::goToInitialRecoverGraphNode": 0x800edcdc,
		"goToInitialRecoverGraphNode": 0x800edcdc,
		"TBossHanachan::execSlip": 0x800edd74,
		"execSlip": 0x800edd74,
		"TBossHanachan::execWalk": 0x800ee114,
		"TBossHanachan::getBodyMaxRotateZ": 0x800ee318,
		"getBodyMaxRotateZ": 0x800ee318,
		"TBossHanachan::checkFallDecideAndSetup": 0x800ee420,
		"checkFallDecideAndSetup": 0x800ee420,
		"TBossHanachan::isTumbleCompletelyAllBody": 0x800ee528,
		"isTumbleCompletelyAllBody": 0x800ee528,
		"TBossHanachan::perform": 0x800ee624,
		"TBossHanachan::moveObject": 0x800efe48,
		"TBossHanachan::bind": 0x800eff1c,
		"TBossHanachan::kill": 0x800f0228,
		"Enemy::CalcRevisionPosByRotateZ": 0x800f022c,
		"CalcRevisionPosByRotateZ": 0x800f022c,
		"TBossHanachan::throwMario_": 0x800f02fc,
		"throwMario_": 0x800f02fc,
		"TBossHanachan::init": 0x800f067c,
		"TBossHanachan::setRandomWeakBodyIndex": 0x800f0bc4,
		"setRandomWeakBodyIndex": 0x800f0bc4,
		"TBossHanachan::TBossHanachan": 0x800f0c2c,
		"TBossHanachanManager::hasMapCollision": 0x800f0d14,
		"TBossHanachanManager::clipEnemies": 0x800f0d1c,
		"TBossHanachanManager::loadAfter": 0x800f0d48,
		"TBossHanachanManager::createModelData": 0x800f0dd4,
		"TBossHanachanManager::TBossHanachanManager": 0x800f0e2c,
		"TBossHanachanManager::~TBossHanachanManager": 0x800f0f14,
		"Enemy::__sinit_BossHanachanMain_cpp": 0x800f0f78,
		"__sinit_BossHanachanMain_cpp": 0x800f0f78,
		"TNerveBossHanachanDead::~TNerveBossHanachanDead": 0x800f127c,
		"TNerveBossHanachanDead::execute": 0x800f12d8,
		"TNerveBossHanachanDead::theNerve": 0x800f1344,
		"TNerveBossHanachanSnort::execute": 0x800f13a8,
		"TNerveBossHanachanGraphWander::~TNerveBossHanachanGraphWander": 0x800f1500,
		"TNerveBossHanachanSnort::theNerve": 0x800f155c,
		"TNerveBossHanachanSnort::~TNerveBossHanachanSnort": 0x800f15c0,
		"TNerveBossHanachanDamage::execute": 0x800f161c,
		"TNerveBossHanachanGetUp::~TNerveBossHanachanGetUp": 0x800f1714,
		"TNerveBossHanachanDamage::theNerve": 0x800f1770,
		"TNerveBossHanachanDamage::~TNerveBossHanachanDamage": 0x800f17d4,
		"TNerveBossHanachanGetUp::execute": 0x800f1830,
		"TNerveBossHanachanGetUp::theNerve": 0x800f1914,
		"TNerveBossHanachanDown::execute": 0x800f1978,
		"TNerveBossHanachanDown::theNerve": 0x800f1a58,
		"TNerveBossHanachanDown::~TNerveBossHanachanDown": 0x800f1abc,
		"TNerveBossHanachanTumble::execute": 0x800f1b18,
		"TNerveBossHanachanTumble::theNerve": 0x800f1c34,
		"TNerveBossHanachanTumble::~TNerveBossHanachanTumble": 0x800f1c98,
		"TNerveBossHanachanGraphWander::execute": 0x800f1cf4,
		"TNerveBossHanachanGraphWander::theNerve": 0x800f1de4,
		"Enemy::__sinit_BossHanachanNerve_cpp": 0x800f1e48,
		"__sinit_BossHanachanNerve_cpp": 0x800f1e48,
		"TBossHanachan::changeAnmRateAndFrameUpdate_": 0x800f2144,
		"changeAnmRateAndFrameUpdate_": 0x800f2144,
		"TBossHanachan::isAllBckAlreadyEnd": 0x800f27b0,
		"isAllBckAlreadyEnd": 0x800f27b0,
		"TBossHanachan::isFinishedGetUp": 0x800f2868,
		"isFinishedGetUp": 0x800f2868,
		"TBossHanachan::considerSetAnm": 0x800f28c4,
		"considerSetAnm": 0x800f28c4,
		"TBossHanachan::setAnmTimerWhenDead": 0x800f2938,
		"setAnmTimerWhenDead": 0x800f2938,
		"TBossHanachan::setAnmTimerWhenDamage": 0x800f2a84,
		"setAnmTimerWhenDamage": 0x800f2a84,
		"TBossHanachan::setAnmTimerWhenSnort": 0x800f2bd0,
		"setAnmTimerWhenSnort": 0x800f2bd0,
		"TBossHanachan::setAnmTimerWhenGetUp": 0x800f2c48,
		"setAnmTimerWhenGetUp": 0x800f2c48,
		"TBossHanachan::setTumbleAnm": 0x800f2cbc,
		"setTumbleAnm": 0x800f2cbc,
		"TBossHanachan::setHeadAndBodyAnm": 0x800f2e60,
		"setHeadAndBodyAnm": 0x800f2e60,
		"TBossHanachanPartsHead::receiveMessage": 0x800f3004,
		"TBossHanachanPartsBody::receiveMessage": 0x800f319c,
		"TBossHanachanPartsHead::setAnm_": 0x800f33c0,
		"TBossHanachanPartsBody::setAnm_": 0x800f34dc,
		"TBossHanachanPartsBase::considerSetAnm_": 0x800f3610,
		"considerSetAnm_": 0x800f3610,
		"TBossHanachanPartsBase::calcRotateZWhenGetUp_": 0x800f3d44,
		"calcRotateZWhenGetUp_": 0x800f3d44,
		"TBossHanachanPartsBase::getSandActor_": 0x800f3df8,
		"getSandActor_": 0x800f3df8,
		"TBossHanachanPartsBase::copyFrameFromOldAnmToNewAnm_": 0x800f3e4c,
		"copyFrameFromOldAnmToNewAnm_": 0x800f3e4c,
		"TBossHanachanPartsBase::isCurBckAlreadyEnd_": 0x800f3ee0,
		"isCurBckAlreadyEnd_": 0x800f3ee0,
		"TBossHanachanPartsBase::setDamageFog_": 0x800f3fb8,
		"setDamageFog_": 0x800f3fb8,
		"TBossHanachanPartsBase::entryCircleShadow_": 0x800f40a8,
		"entryCircleShadow_": 0x800f40a8,
		"TBossHanachanPartsBase::moveMapCollision_": 0x800f4170,
		"moveMapCollision_": 0x800f4170,
		"TBossHanachanPartsBase::changeTumbleAnmRate_": 0x800f41c0,
		"changeTumbleAnmRate_": 0x800f41c0,
		"TBossHanachanPartsBody::initFootHitActor_": 0x800f427c,
		"initFootHitActor_": 0x800f427c,
		"TBossHanachanPartsBase::initMapCollisionAndHitActor_": 0x800f4420,
		"initMapCollisionAndHitActor_": 0x800f4420,
		"TBossHanachanPartsHead::TBossHanachanPartsHead": 0x800f4640,
		"TBossHanachanPartsBody::TBossHanachanPartsBody": 0x800f476c,
		"TBossHanachanPartsBase::TBossHanachanPartsBase": 0x800f4870,
		"Enemy::CLBPalFrame": 0x800f4b64,
		"Enemy::__sinit_BossHanachanParts_cpp": 0x800f4bc0,
		"__sinit_BossHanachanParts_cpp": 0x800f4bc0,
		"TBossHanachanChangeSaveParams::TBossHanachanChangeSaveParams": 0x800f4ed4,
		"TBossHanachanCommonSaveParams::TBossHanachanCommonSaveParams": 0x800f551c,
		"TNerveAmiNokoFreeze::~TNerveAmiNokoFreeze": 0x800f5a9c,
		"TNerveAmiNokoFreeze::execute": 0x800f5af8,
		"TNerveAmiNokoDie::execute": 0x800f5c14,
		"TNerveAmiNokoDie::~TNerveAmiNokoDie": 0x800f60bc,
		"TNerveAmiNokoTurn::execute": 0x800f6118,
		"TNerveAmiNokoWalkOnFence::~TNerveAmiNokoWalkOnFence": 0x800f6628,
		"TNerveAmiNokoTurn::~TNerveAmiNokoTurn": 0x800f6684,
		"TNerveAmiNokoWalkOnFence::execute": 0x800f66e0,
		"TAmiNoko::getBasNameTable": 0x800f6b58,
		"TAmiNoko::getGravityY": 0x800f6b64,
		"TAmiNoko::perform": 0x800f6bf0,
		"TAmiNoko::bind": 0x800f6c6c,
		"TAmiNoko::calcRootMatrix": 0x800f6e98,
		"TAmiNoko::isHitValid": 0x800f7a50,
		"TAmiNoko::setWalkAnm": 0x800f7ba8,
		"TAmiNoko::attackToMario": 0x800f7bfc,
		"TAmiNoko::behaveToWater": 0x800f7e24,
		"TAmiNoko::reset": 0x800f7f44,
		"TAmiNoko::setMActorAndKeeper": 0x800f7f64,
		"TAmiNoko::init": 0x800f7fd0,
		"TAmiNoko::load": 0x800f81f4,
		"TAmiNoko::TAmiNoko": 0x800f823c,
		"TAmiHit::perform": 0x800f82e4,
		"TAmiHit::receiveMessage": 0x800f84a0,
		"TAmiNokoManager::createEnemyInstance": 0x800f84d0,
		"TAmiNokoManager::createModelData": 0x800f84d8,
		"TAmiNokoManager::load": 0x800f850c,
		"TAmiNokoManager::TAmiNokoManager": 0x800f85e8,
		"TAmiNoko::isCollidMove": 0x800f86c0,
		"TAmiNokoManager::~TAmiNokoManager": 0x800f874c,
		"Enemy::__sinit_amiNoko_cpp": 0x800f87c0,
		"__sinit_amiNoko_cpp": 0x800f87c0,
		"TNerveBGKLaunchName::~TNerveBGKLaunchName": 0x800f8acc,
		"TNerveBGKLaunchName::execute": 0x800f8b28,
		"TNerveBGKAppear::~TNerveBGKAppear": 0x800f8c4c,
		"TNerveBGKLaunchGoro::execute": 0x800f8ca8,
		"TNerveBGKSleep::~TNerveBGKSleep": 0x800f8e7c,
		"TNerveBGKLaunchGoro::~TNerveBGKLaunchGoro": 0x800f8ed8,
		"TNerveBGKDive::execute": 0x800f8f34,
		"TNerveBGKDive::~TNerveBGKDive": 0x800f913c,
		"TNerveBGKDie::execute": 0x800f9198,
		"TNerveBGKDie::~TNerveBGKDie": 0x800f95a4,
		"TNerveBGKAwakeDamage::execute": 0x800f9600,
		"TNerveBGKWait::~TNerveBGKWait": 0x800f9800,
		"TNerveBGKWait2::~TNerveBGKWait2": 0x800f985c,
		"TNerveBGKAwakeDamage::~TNerveBGKAwakeDamage": 0x800f98b8,
		"TNerveBGKSleepDamage::execute": 0x800f9914,
		"TNerveBGKSleepDamage::~TNerveBGKSleepDamage": 0x800f9ae8,
		"TNerveBGKWait2::execute": 0x800f9b44,
		"TNerveBGKWait::execute": 0x800f9f08,
		"TNerveBGKAppear::execute": 0x800fa4c8,
		"TNerveBGKSleep::execute": 0x800fa760,
		"TBiancoGateKeeper::perform": 0x800faa54,
		"TBiancoGateKeeper::controlCollision": 0x800fada4,
		"TBiancoGateKeeper::emitParticles": 0x800faf20,
		"emitParticles": 0x800faf20,
		"TBiancoGateKeeper::getBasNameTable": 0x800fb0dc,
		"TBiancoGateKeeper::isDamageFogSituation": 0x800fb0e8,
		"isDamageFogSituation": 0x800fb0e8,
		"TBiancoGateKeeper::isHeadHitActive": 0x800fb254,
		"isHeadHitActive": 0x800fb254,
		"TBiancoGateKeeper::getRumblePow": 0x800fb340,
		"getRumblePow": 0x800fb340,
		"TBiancoGateKeeper::launchNamekuri": 0x800fb41c,
		"launchNamekuri": 0x800fb41c,
		"TBiancoGateKeeper::changeBck": 0x800fb718,
		"TBiancoGateKeeper::kill": 0x800fb9d4,
		"TBiancoGateKeeper::init": 0x800fba10,
		"TBiancoGateKeeper::TBiancoGateKeeper": 0x800fc170,
		"TBiancoGateKeeperManager::createModelData": 0x800fc75c,
		"TBiancoGateKeeperManager::load": 0x800fc790,
		"TBiancoGateKeeperManager::initJParticle": 0x800fc8cc,
		"TBiancoGateKeeperManager::TBiancoGateKeeperManager": 0x800fca50,
		"TGateKeeperBase::perform": 0x800fca8c,
		"TGateKeeperBase::receiveMessage": 0x800fcbc4,
		"TGateKeeperBase::kill": 0x800fcc64,
		"TGKHitObj::perform": 0x800fcc74,
		"TGKHitObj::receiveMessage": 0x800fcd00,
		"TBGKMtxCalc::~TBGKMtxCalc": 0x800fcec0,
		"TBiancoGateKeeperManager::~TBiancoGateKeeperManager": 0x800fcf6c,
		"Enemy::__sinit_gatekeeper_cpp": 0x800fd054,
		"__sinit_gatekeeper_cpp": 0x800fd054,
		"TBossHanachan::emitCamShake_": 0x800fd384,
		"emitCamShake_": 0x800fd384,
		"TBossHanachan::emitOneTimeSandPillar_": 0x800fd618,
		"emitOneTimeSandPillar_": 0x800fd618,
		"TBossHanachan::emitParticle_": 0x800fd74c,
		"TBossHanachan::staticLoadParticle": 0x800fdb60,
		"staticLoadParticle": 0x800fdb60,
		"Enemy::__sinit_BossHanachanEffect_cpp": 0x800fde94,
		"__sinit_BossHanachanEffect_cpp": 0x800fde94,
		"TEggGenManager::~TEggGenManager": 0x800fe190,
		"TEggGenManager::load": 0x800fe1f4,
		"TEggGenManager::createModelData": 0x800fe260,
		"TEggGenManager::TEggGenManager": 0x800fe294,
		"TEggGenerator::control": 0x800fe2d0,
		"TEggGenerator::init": 0x800fe348,
		"TEggGenerator::TEggGenerator": 0x800fe438,
		"TNerveSealDie::~TNerveSealDie": 0x800fe508,
		"TNerveSealDie::execute": 0x800fe564,
		"TNerveSealSleep::~TNerveSealSleep": 0x800fe750,
		"TNerveSealWait::execute": 0x800fe7ac,
		"TNerveSealWait::~TNerveSealWait": 0x800fe8e8,
		"TNerveSealSleep::execute": 0x800fe944,
		"TSealManager::load": 0x800fea70,
		"TSealManager::createModelData": 0x800fea90,
		"TSealManager::TSealManager": 0x800feac4,
		"TSeal::perform": 0x800feb00,
		"TSeal::calcRootMatrix": 0x800fec24,
		"TSeal::receiveMessage": 0x800fecc8,
		"TSeal::init": 0x800feec8,
		"TSeal::TSeal": 0x800ff1a0,
		"TSealManager::~TSealManager": 0x800ff1f8,
		"Enemy::__sinit_seal_cpp": 0x800ff2c8,
		"__sinit_seal_cpp": 0x800ff2c8,
		"TBGPolDrop::perform": 0x800ff638,
		"TBGPolDrop::launch": 0x800ff86c,
		"TBGPolDrop::move": 0x800ff8c8,
		"TBGPolDrop::TBGPolDrop": 0x800ffb18,
		"Enemy::__sinit_bgpoldrop_cpp": 0x800ffc34,
		"__sinit_bgpoldrop_cpp": 0x800ffc34,
		"TBGTentacle::~TBGTentacle": 0x800fff38,
		"TBGTentacle::perform": 0x800fffac,
		"TBGTentacle::resetAllNodes": 0x8010032c,
		"resetAllNodes": 0x8010032c,
		"TBGTentacle::calcAttackGuideAnm": 0x801004a0,
		"calcAttackGuideAnm": 0x801004a0,
		"TBGTentacle::decideAtkColExists": 0x80100920,
		"decideAtkColExists": 0x80100920,
		"TBGTentacle::calcAtkParticleAndSE": 0x80100ae0,
		"calcAtkParticleAndSE": 0x80100ae0,
		"TBGTentacle::decideOwnState": 0x80100f70,
		"decideOwnState": 0x80100f70,
		"TBGTentacle::moveConstraint": 0x801012a0,
		"moveConstraint": 0x801012a0,
		"TBGTentacle::moveNode": 0x8010172c,
		"moveNode": 0x8010172c,
		"TBGTentacle::changeStateAndFixNodes": 0x8010208c,
		"changeStateAndFixNodes": 0x8010208c,
		"TBGTentacle::setAttackTarget": 0x80102358,
		"setAttackTarget": 0x80102358,
		"TBGTentacle::beatNode": 0x801027c4,
		"beatNode": 0x801027c4,
		"TBGTentacle::TBGTentacle": 0x80102960,
		"TBGTentacle::TNode::calcPosition": 0x80102fd0,
		"calcPosition": 0x80102fd0,
		"TBGTentacle::TNode::calcVelocity": 0x80103318,
		"TBGTentacle::TNode::TNode": 0x80103700,
		"TBGAttackHit::perform": 0x80103734,
		"TBGTakeHit::perform": 0x80103b48,
		"TBGTakeHit::receiveMessage": 0x8010427c,
		"TBGTakeHit::moveRequest": 0x801043e0,
		"TBGTakeHit::getTakingMtx": 0x801046c8,
		"TBGTentacle::TTentacleParams::TTentacleParams": 0x80104e8c,
		"Enemy::__sinit_bgtentacle_cpp": 0x80105440,
		"__sinit_bgtentacle_cpp": 0x80105440,
		"TEffectEnemy::setDeadAnm": 0x80105870,
		"TEffectEnemy::sendAttackMsgToMario": 0x801058ec,
		"TEffectEnemy::behaveToWater": 0x80105970,
		"TEffectEnemy::reset": 0x801059b0,
		"TEffectEnemy::perform": 0x801059d0,
		"TEffectEnemy::forceKill": 0x80105b20,
		"TEffectEnemy::kill": 0x80105c48,
		"TEffectEnemy::setMActorAndKeeper": 0x80105c98,
		"TEffectEnemy::init": 0x80105d04,
		"TEffectEnemy::TEffectEnemy": 0x80105d3c,
		"TEffectEnemyManager::initSetEnemies": 0x80105d88,
		"TEffectEnemyManager::createEnemyInstance": 0x80105d8c,
		"TEffectEnemyManager::loadAfter": 0x80105df0,
		"TEffectEnemyManager::load": 0x80105e10,
		"TEffectEnemyManager::~TEffectEnemyManager": 0x80105e68,
		"Enemy::__sinit_effectEnemy_cpp": 0x80105edc,
		"__sinit_effectEnemy_cpp": 0x80105edc,
		"TNerveHauntLegHaunt::~TNerveHauntLegHaunt": 0x801061e0,
		"TNerveHauntLegHaunt::execute": 0x8010623c,
		"THauntLeg::getTakingMtx": 0x80106530,
		"THauntLeg::getBasNameTable": 0x801065d0,
		"THauntLeg::isCollidMove": 0x801065dc,
		"THauntLeg::attackToMario": 0x80106730,
		"THauntLeg::setDeadAnm": 0x80106780,
		"THauntLeg::setRunAnm": 0x801067e8,
		"THauntLeg::setWalkAnm": 0x80106818,
		"THauntLeg::setWaitAnm": 0x80106848,
		"THauntLeg::setGenerateAnm": 0x80106878,
		"THauntLeg::calcRootMatrix": 0x801068a8,
		"THauntLeg::reset": 0x80106cb0,
		"THauntLeg::setMActorAndKeeper": 0x80106ce4,
		"THauntLeg::init": 0x80106d50,
		"THauntedObject::receiveMessage": 0x80106ebc,
		"THauntLegManager::createModelData": 0x80106f10,
		"THauntLegManager::initSetEnemies": 0x80106f44,
		"THauntLegManager::createEnemyInstance": 0x80107108,
		"THauntLegManager::load": 0x8010717c,
		"THauntLegManager::THauntLegManager": 0x801071d4,
		"Enemy::HauntLegCallback": 0x80107218,
		"HauntLegCallback": 0x80107218,
		"THauntLegManager::~THauntLegManager": 0x801074a8,
		"Enemy::__sinit_hauntLeg_cpp": 0x8010751c,
		"__sinit_hauntLeg_cpp": 0x8010751c,
		"TAreaCylinderManager::~TAreaCylinderManager": 0x80107828,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::erase": 0x80107934,
		"JGadget::TList<P13TAreaCylinder,Q27JGadget28TAllocator<P13TAreaCylinder>>::iterator::iterator": 0x801079a0,
		"TAreaCylinderManager::perform": 0x801079a8,
		"TAreaCylinderManager::getCylinderContains": 0x801079ac,
		"getCylinderContains": 0x801079ac,
		"TAreaCylinderManager::contain": 0x80107a74,
		"contain": 0x80107a74,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::insert": 0x80107b40,
		"TAreaCylinder::perform": 0x80107bf8,
		"TAreaCylinder::load": 0x80107bfc,
		"TAreaCylinder::TAreaCylinder": 0x80107e58,
		"TAreaCylinder::~TAreaCylinder": 0x80107ed4,
		"TNerveWireTrapGoWait::~TNerveWireTrapGoWait": 0x80107f48,
		"TNerveWireTrapGoWait::execute": 0x80107fa4,
		"TNerveWireTrapWait::execute": 0x80107ffc,
		"TNerveWireTrapWait::~TNerveWireTrapWait": 0x80108020,
		"TNerveWireTrapSearch::execute": 0x8010807c,
		"TNerveWireTrapSearch::~TNerveWireTrapSearch": 0x80108304,
		"TNerveWireTrapOnewayMoveEnd::execute": 0x80108360,
		"TNerveWireTrapOnewayMoveEnd::~TNerveWireTrapOnewayMoveEnd": 0x8010844c,
		"TNerveWireTrapOnewayMove::execute": 0x801084a8,
		"TNerveWireTrapOnewayMoveStart::~TNerveWireTrapOnewayMoveStart": 0x80108838,
		"TNerveWireTrapOnewayMove::~TNerveWireTrapOnewayMove": 0x80108894,
		"TNerveWireTrapOnewayMoveStart::execute": 0x801088f0,
		"TNerveWireTrapReturnMove::execute": 0x801089ac,
		"TNerveWireTrapReturnMove::~TNerveWireTrapReturnMove": 0x80108b94,
		"TWireTrapManager::createModelData": 0x80108bf0,
		"TWireTrapManager::load": 0x80108c24,
		"TWireTrapManager::TWireTrapManager": 0x80108d34,
		"TWireTrap::getWireBinder": 0x80108d70,
		"getWireBinder": 0x80108d70,
		"TWireTrap::getNerveFromMode": 0x80108d78,
		"getNerveFromMode": 0x80108d78,
		"TWireTrap::getWireDir": 0x80108e9c,
		"getWireDir": 0x80108e9c,
		"TWireTrap::checkHitActors": 0x80108ea8,
		"TWireBinder::getDir": 0x80109448,
		"getDir": 0x80109448,
		"TWireTrap::moveObject": 0x80109450,
		"TWireTrap::calcRootMatrix": 0x80109520,
		"TWireTrap::kill": 0x80109b58,
		"TWireTrap::receiveMessage": 0x80109c60,
		"TWireTrap::load": 0x80109e6c,
		"TWireTrap::init": 0x8010a09c,
		"TWireTrap::TWireTrap": 0x8010a244,
		"TWireTrapManager::~TWireTrapManager": 0x8010a294,
		"Enemy::__sinit_wireTrap_cpp": 0x8010a364,
		"__sinit_wireTrap_cpp": 0x8010a364,
		"TBossHanachanPartsBase::getBasNameTable": 0x8010a668,
		"TNerveRocketWait::~TNerveRocketWait": 0x8010a67c,
		"TNerveRocketWait::execute": 0x8010a6d8,
		"TNerveRocketFly::execute": 0x8010a728,
		"TNerveRocketFly::~TNerveRocketFly": 0x8010a9c0,
		"TNerveRocketPossessedNozzle::execute": 0x8010aa1c,
		"TNerveRocketPossessedNozzle::~TNerveRocketPossessedNozzle": 0x8010acb8,
		"TRocket::getBasNameTable": 0x8010ad14,
		"TRocket::isAttack": 0x8010ad20,
		"TRocket::isCollidMove": 0x8010adac,
		"TRocket::getGravityY": 0x8010aeb4,
		"TRocket::setDeadAnm": 0x8010af4c,
		"TRocket::bind": 0x8010b038,
		"TRocket::behaveToWater": 0x8010b280,
		"TRocket::attackToMario": 0x8010b2ac,
		"TRocket::reset": 0x8010b3d8,
		"TRocket::setMActorAndKeeper": 0x8010b4b8,
		"TRocket::calcRootMatrix": 0x8010b524,
		"TRocket::init": 0x8010b8f0,
		"TRocket::load": 0x8010b9b8,
		"TRocket::TRocket": 0x8010ba18,
		"TRocketManager::perform": 0x8010ba68,
		"TRocketManager::createModelData": 0x8010bb1c,
		"TRocketManager::initSetEnemies": 0x8010bb50,
		"TRocketManager::createEnemyInstance": 0x8010bcb4,
		"TRocketManager::loadAfter": 0x8010bd1c,
		"TRocketManager::load": 0x8010bd3c,
		"TRocketManager::TRocketManager": 0x8010be68,
		"TRocketManager::~TRocketManager": 0x8010bf3c,
		"TRocketManager::clipEnemies": 0x8010bfb0,
		"Enemy::__sinit_rocket_cpp": 0x8010bfb4,
		"__sinit_rocket_cpp": 0x8010bfb4,
		"TNerveKazekunHitWater::~TNerveKazekunHitWater": 0x8010c2b8,
		"TNerveKazekunHitWater::execute": 0x8010c314,
		"TNerveKazekunDisappear::~TNerveKazekunDisappear": 0x8010c478,
		"TNerveKazekunHitWater::theNerve": 0x8010c4d4,
		"TNerveKazekunWait::execute": 0x8010c538,
		"TNerveKazekunSearch::~TNerveKazekunSearch": 0x8010c624,
		"TNerveKazekunWait::~TNerveKazekunWait": 0x8010c680,
		"TNerveKazekunDisappear::execute": 0x8010c6dc,
		"TNerveKazekunAttack::execute": 0x8010c818,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::getQuat": 0x8010cdac,
		"TNerveKazekunAttack::theNerve": 0x8010d06c,
		"TNerveKazekunAttack::~TNerveKazekunAttack": 0x8010d0d0,
		"TNerveKazekunPreAttack::execute": 0x8010d12c,
		"TNerveKazekunPreAttack::theNerve": 0x8010d364,
		"TNerveKazekunPreAttack::~TNerveKazekunPreAttack": 0x8010d3c8,
		"TNerveKazekunTurn::execute": 0x8010d424,
		"TNerveKazekunTurn::~TNerveKazekunTurn": 0x8010d65c,
		"TNerveKazekunAppear::execute": 0x8010d6b8,
		"TNerveKazekunAppear::~TNerveKazekunAppear": 0x8010d7d0,
		"TNerveKazekunSearch::execute": 0x8010d82c,
		"TKazekunManager::createModelData": 0x8010d938,
		"TKazekunManager::load": 0x8010d96c,
		"TKazekunManager::TKazekunManager": 0x8010da00,
		"TKazekunParams::TKazekunParams": 0x8010da3c,
		"TKazekun::doAttackPose": 0x8010dd3c,
		"doAttackPose": 0x8010dd3c,
		"TKazekun::flyAroundMario": 0x8010e260,
		"flyAroundMario": 0x8010e260,
		"TKazekun::setDeadAnm": 0x8010e5f4,
		"TKazekun::isCollidMove": 0x8010e644,
		"TKazekun::attackToMario": 0x8010e64c,
		"TKazekun::getBasNameTable": 0x8010e734,
		"TKazekun::behaveToWater": 0x8010e740,
		"TKazekun::bind": 0x8010e894,
		"TKazekun::calcRootMatrix": 0x8010e8c8,
		"TKazekun::reset": 0x8010eb0c,
		"TKazekun::init": 0x8010eb84,
		"TKazekun::TKazekun": 0x8010ed88,
		"Enemy::SMS_CalcToDirMatrix": 0x8010ede0,
		"SMS_CalcToDirMatrix": 0x8010ede0,
		"TKazekunManager::~TKazekunManager": 0x8010f01c,
		"Enemy::__sinit_Kazekun_cpp": 0x8010f114,
		"__sinit_Kazekun_cpp": 0x8010f114,
		"TBossMantaManager::~TBossMantaManager": 0x8010f418,
		"TBossMantaParams::TBossMantaParams": 0x8010f47c,
		"TBossMantaManager::spawn": 0x8010f7c4,
		"spawn": 0x8010f7c4,
		"TBossMantaManager::createEnemies": 0x8010f9c0,
		"TBossMantaManager::setupEfbAlpha": 0x8010fb14,
		"setupEfbAlpha": 0x8010fb14,
		"TBossMantaManager::perform": 0x8010fdc8,
		"TBossMantaManager::updateMantaEscape": 0x8010fe5c,
		"updateMantaEscape": 0x8010fe5c,
		"TBossMantaManager::drawMantaShadow": 0x8010ffb4,
		"drawMantaShadow": 0x8010ffb4,
		"TBossMantaManager::createEnemyInstance": 0x80110664,
		"TBossMantaManager::createModelData": 0x801106ac,
		"TBossMantaManager::loadAfter": 0x801106e0,
		"TBossMantaManager::load": 0x8011088c,
		"TBossMantaManager::TBossMantaManager": 0x801108f8,
		"TBossMantaAdditionalCollision::perform": 0x801109cc,
		"TBossMantaAdditionalCollision::receiveMessage": 0x80110b6c,
		"TBossMantaAdditionalCollisionSet::update": 0x80110bac,
		"TBossMantaAdditionalCollisionSet::adapt": 0x80110d8c,
		"adapt": 0x80110d8c,
		"TBossMantaAdditionalCollisionSet::TBossMantaAdditionalCollisionSet": 0x80110e60,
		"TBossMantaManager::TMantaMessageState::update": 0x80110fc8,
		"TNerveMantaSpawn::~TNerveMantaSpawn": 0x8011117c,
		"TBossMantaManager::TMantaBattleState::update": 0x801111d8,
		"TBossManta::updateAttractor": 0x801114ec,
		"updateAttractor": 0x801114ec,
		"TBossManta::getPolluteRadius": 0x80111bbc,
		"getPolluteRadius": 0x80111bbc,
		"TNerveMantaMove::~TNerveMantaMove": 0x80111c38,
		"TBossManta::calcRootMatrix": 0x80111c94,
		"TBossManta::control": 0x80111db4,
		"TBossManta::initNthGeneration": 0x80112010,
		"initNthGeneration": 0x80112010,
		"TNerveMantaAppearDemo::~TNerveMantaAppearDemo": 0x801127b8,
		"TBossManta::receiveMessage": 0x80112814,
		"TBossManta::collidedWithWater": 0x80112864,
		"collidedWithWater": 0x80112864,
		"TNerveMantaDeath::~TNerveMantaDeath": 0x80112cf0,
		"TNerveMantaHitWater::~TNerveMantaHitWater": 0x80112d4c,
		"TBossManta::moveObject": 0x80112da8,
		"TBossManta::init": 0x80112f88,
		"TBossManta::getIntoGraphVec": 0x8011321c,
		"getIntoGraphVec": 0x8011321c,
		"TBossManta::TBossManta": 0x801134ac,
		"TNerveMantaAppearDemo::execute": 0x80113548,
		"TNerveMantaDeath::execute": 0x801136f4,
		"TNerveMantaSpawn::execute": 0x801137e0,
		"TNerveMantaHitWater::execute": 0x8011397c,
		"TNerveMantaMove::execute": 0x80113b6c,
		"TNerveMantaHitWater::theNerve": 0x80114520,
		"TBossManta::drawObject": 0x80114674,
		"TBossManta::reset": 0x80114678,
		"Enemy::__sinit_bossManta_cpp": 0x8011467c,
		"__sinit_bossManta_cpp": 0x8011467c,
		"TWireBinder::~TWireBinder": 0x80114988,
		"TWireBinder::isEndWire": 0x801149ec,
		"isEndWire": 0x801149ec,
		"TWireBinder::isOnWire": 0x80114a54,
		"isOnWire": 0x80114a54,
		"TWireBinder::getDirAtPos": 0x80114b28,
		"getDirAtPos": 0x80114b28,
		"TWireBinder::bind": 0x80114c64,
		"TMapWireManager::getWire": 0x80114f1c,
		"getWire": 0x80114f1c,
		"TWireBinder::init": 0x80114f2c,
		"TNerveYumboFreeze::~TNerveYumboFreeze": 0x80115038,
		"TNerveYumboFreeze::execute": 0x80115094,
		"TNerveYumboDancing::~TNerveYumboDancing": 0x801151c4,
		"TNerveYumboAttack::execute": 0x80115220,
		"TNerveYumboAppearing::~TNerveYumboAppearing": 0x80115450,
		"TNerveYumboAttack::theNerve": 0x801154ac,
		"TNerveYumboAttack::~TNerveYumboAttack": 0x80115510,
		"TNerveYumboAppearing::execute": 0x8011556c,
		"TNerveYumboHiding::execute": 0x8011579c,
		"TNerveYumboHiding::theNerve": 0x80115948,
		"TNerveYumboHiding::~TNerveYumboHiding": 0x801159ac,
		"TNerveYumboDancing::execute": 0x80115a08,
		"TYumbo::getBasNameTable": 0x80115cb8,
		"TYumboManager::createModelData": 0x80115cc4,
		"TYumboManager::load": 0x80115cf8,
		"TYumboManager::TYumboManager": 0x80115ec4,
		"TYumbo::attackToMario": 0x80115f08,
		"TYumbo::doKeepDistance": 0x80115fb4,
		"TYumbo::setDeadAnm": 0x80116044,
		"TYumbo::shotSeeds": 0x80116074,
		"shotSeeds": 0x80116074,
		"TYumbo::behaveToWater": 0x8011656c,
		"TYumbo::perform": 0x801166c4,
		"TYumbo::moveObject": 0x80116744,
		"TYumbo::receiveMessage": 0x80116948,
		"TYumbo::reset": 0x80116a50,
		"TYumbo::init": 0x80116a54,
		"TYumbo::TYumbo": 0x80116c90,
		"TYumboSeed::perform": 0x80116ce0,
		"TYumboSeed::init": 0x80116ee4,
		"TYumboManager::~TYumboManager": 0x8011703c,
		"Enemy::__sinit_yunbo_cpp": 0x80117134,
		"__sinit_yunbo_cpp": 0x80117134,
		"TKoopaJrSubmarineManager::~TKoopaJrSubmarineManager": 0x80117440,
		"TKoopaJrSubmarineManager::createEnemyInstance": 0x801174a4,
		"TKoopaJrSubmarineManager::loadAfter": 0x801174ec,
		"TKoopaJrSubmarineManager::load": 0x80117520,
		"TKoopaJrSubmarineManager::createModelData": 0x8011758c,
		"TKoopaJrSubmarineManager::TKoopaJrSubmarineManager": 0x801175c0,
		"TNerveKoopaJrSubmarineLaunchKiller::execute": 0x801175fc,
		"TNerveKoopaJrSubmarineLaunchKiller::~TNerveKoopaJrSubmarineLaunchKiller": 0x80117660,
		"TNerveKoopaJrSubmarineCannonOpenClose::execute": 0x801176bc,
		"TNerveKoopaJrSubmarineCannonOpenClose::~TNerveKoopaJrSubmarineCannonOpenClose": 0x80117724,
		"TNerveKoopaJrSubmarineWait::execute": 0x80117780,
		"TNerveKoopaJrSubmarineWait::~TNerveKoopaJrSubmarineWait": 0x80117808,
		"TKoopaJrSubmarine::checkNerve": 0x80117864,
		"checkNerve": 0x80117864,
		"TNerveKoopaJrWait::~TNerveKoopaJrWait": 0x80117bdc,
		"JGeometry::TUtil<float><float>::mod": 0x80117c38,
		"TKoopaJrSubmarine::makeRoundVelocity": 0x80117c94,
		"makeRoundVelocity": 0x80117c94,
		"TKoopaJrSubmarine::makeRelativeAngle": 0x80117f70,
		"makeRelativeAngle": 0x80117f70,
		"TKoopaJrSubmarine::getBasNameTable": 0x80118168,
		"TKoopaJrSubmarine::makeKillerVelocity": 0x80118170,
		"makeKillerVelocity": 0x80118170,
		"TKoopaJrSubmarine::launchKiller": 0x8011887c,
		"TKoopaJrSubmarine::appearShineKiller": 0x801189b4,
		"appearShineKiller": 0x801189b4,
		"TKoopaJrSubmarine::receiveMessage": 0x80118af8,
		"TKoopaJrSubmarine::calcRootMatrix": 0x80118b78,
		"TKoopaJrSubmarine::bind": 0x80119004,
		"TKoopaJrSubmarine::moveSwing": 0x801190f8,
		"moveSwing": 0x801190f8,
		"TKoopaJrSubmarine::makeCollisionPositions": 0x801193d0,
		"makeCollisionPositions": 0x801193d0,
		"TKoopaJrSubmarine::perform": 0x801194ac,
		"TKoopaJrSubmarine::resetKoopaJrSubmarine": 0x8011964c,
		"resetKoopaJrSubmarine": 0x8011964c,
		"TKoopaJrSubmarine::reset": 0x80119770,
		"TKoopaJrSubmarine::init": 0x801197a4,
		"TKoopaJrSubmarine::TKoopaJrSubmarine": 0x80119bec,
		"TKoopaJrManager::createEnemyInstance": 0x80119c60,
		"TKoopaJrManager::loadAfter": 0x80119c68,
		"TKoopaJrManager::load": 0x80119cc4,
		"TKoopaJrManager::createModelData": 0x80119d1c,
		"TKoopaJrManager::TKoopaJrManager": 0x80119d50,
		"TNerveKoopaJrYahoo::execute": 0x80119d8c,
		"TNerveKoopaJrYahoo::~TNerveKoopaJrYahoo": 0x80119e1c,
		"TNerveKoopaJrLaunch::execute": 0x80119e78,
		"TNerveKoopaJrLaunch::~TNerveKoopaJrLaunch": 0x80119f08,
		"TNerveKoopaJrDemo::execute": 0x80119f64,
		"TNerveKoopaJrDemo::~TNerveKoopaJrDemo": 0x80119fd8,
		"TNerveKoopaJrDamage::execute": 0x8011a034,
		"TNerveKoopaJrDamage::theNerve": 0x8011a0d0,
		"TNerveKoopaJrDamage::~TNerveKoopaJrDamage": 0x8011a134,
		"TNerveKoopaJrWait::execute": 0x8011a190,
		"TKoopaJr::checkNerveKillerHit": 0x8011a23c,
		"checkNerveKillerHit": 0x8011a23c,
		"TKoopaJr::checkNerveKillerLaunchFast": 0x8011a368,
		"checkNerveKillerLaunchFast": 0x8011a368,
		"TKoopaJr::checkNerveKillerLaunchNormal": 0x8011a58c,
		"checkNerveKillerLaunchNormal": 0x8011a58c,
		"TSpineBase<TLiveActor>::pushNerve": 0x8011a7b0,
		"pushNerve": 0x8011a7b0,
		"TKoopaJr::receiveMessage": 0x8011a804,
		"TKoopaJr::getBasNameTable": 0x8011aa04,
		"TKoopaJr::calcRootMatrix": 0x8011aa10,
		"TKoopaJr::perform": 0x8011ab0c,
		"TKoopaJr::reset": 0x8011afdc,
		"TKoopaJr::init": 0x8011b048,
		"TKoopaJr::TKoopaJr": 0x8011b290,
		"TCallbackHitActor::receiveMessage": 0x8011b304,
		"TKoopaJrSubmarineParams::TKoopaJrSubmarineParams": 0x8011b334,
		"TKoopaJrParams::TKoopaJrParams": 0x8011b8a0,
		"TDirectionCalc::r2d": 0x8011baa0,
		"r2d": 0x8011baa0,
		"TDirectionCalc::d2r": 0x8011bab4,
		"d2r": 0x8011bab4,
		"TDirectionCalc::absDirection": 0x8011bac8,
		"absDirection": 0x8011bac8,
		"TDirectionCalc::calcDirectionVector": 0x8011bb6c,
		"calcDirectionVector": 0x8011bb6c,
		"TDirectionCalc::makeDirection": 0x8011bbd0,
		"makeDirection": 0x8011bbd0,
		"TDirectionCalc::calcTurnDirection": 0x8011bc08,
		"calcTurnDirection": 0x8011bc08,
		"TDirectionCalc::sub": 0x8011bd0c,
		"TDirectionCalc::calcNearerDirection": 0x8011bdac,
		"calcNearerDirection": 0x8011bdac,
		"TKoopaJrManager::~TKoopaJrManager": 0x8011bf20,
		"Enemy::__sinit_koopajr_cpp": 0x8011c074,
		"__sinit_koopajr_cpp": 0x8011c074,
		"TNerveKumokunPreFly::~TNerveKumokunPreFly": 0x8011c388,
		"TNerveKumokunPreFly::execute": 0x8011c3e4,
		"TNerveKumokunFly::~TNerveKumokunFly": 0x8011c520,
		"TNerveKumokunFly::execute": 0x8011c57c,
		"TBGCheckData::getNormal": 0x8011c9b8,
		"getNormal": 0x8011c9b8,
		"TNerveKumokunPostFreeze::execute": 0x8011c9c0,
		"TNerveKumokunSearch::~TNerveKumokunSearch": 0x8011cb80,
		"TNerveKumokunPostFreeze::~TNerveKumokunPostFreeze": 0x8011cbdc,
		"TNerveKumokunFreeze::execute": 0x8011cc38,
		"TNerveKumokunFreeze::~TNerveKumokunFreeze": 0x8011cea8,
		"TNerveKumokunWait::execute": 0x8011cf04,
		"JGeometry::TQuat4<float><float>::rotate": 0x8011d308,
		"rotate": 0x8011d308,
		"JGeometry::TVec3<float><float>::negate": 0x8011d3a0,
		"negate": 0x8011d3a0,
		"JGeometry::TVec4<float><float>::xyz": 0x8011d3c8,
		"xyz": 0x8011d3c8,
		"TKumokun::getQuat": 0x8011d3f0,
		"TNerveKumokunWait::theNerve": 0x8011d3f8,
		"TNerveKumokunWait::~TNerveKumokunWait": 0x8011d45c,
		"TNerveKumokunSearch::execute": 0x8011d4b8,
		"TNerveKumokunPreWalk::~TNerveKumokunPreWalk": 0x8011da90,
		"TNerveKumokunSearch::theNerve": 0x8011db00,
		"TNerveKumokunPostWalk::execute": 0x8011db64,
		"TNerveKumokunPostWalk::theNerve": 0x8011dd24,
		"TNerveKumokunPostWalk::~TNerveKumokunPostWalk": 0x8011dd88,
		"TNerveKumokunWalk::execute": 0x8011dde4,
		"TNerveKumokunWalk::~TNerveKumokunWalk": 0x8011dfe8,
		"TNerveKumokunPreWalk::execute": 0x8011e044,
		"TNerveKumokunPreWalk::theNerve": 0x8011e220,
		"TKumokunManager::createModelData": 0x8011e284,
		"TKumokunManager::load": 0x8011e2b8,
		"TKumokunManager::TKumokunManager": 0x8011e4a0,
		"TKumokun::getPlaneNormal": 0x8011e4dc,
		"getPlaneNormal": 0x8011e4dc,
		"TKumokun::isCollidMove": 0x8011e518,
		"TKumokun::doKeepDistance": 0x8011e520,
		"TKumokun::isAttack": 0x8011e8c0,
		"TKumokun::isOnSamePlaneWithMario": 0x8011ea50,
		"isOnSamePlaneWithMario": 0x8011ea50,
		"TKumokun::rotateGoalDirToLocal": 0x8011edd4,
		"rotateGoalDirToLocal": 0x8011edd4,
		"TKumokun::decideTargetAtDir": 0x8011ef18,
		"decideTargetAtDir": 0x8011ef18,
		"TKumokun::attackToMario": 0x8011f240,
		"TKumokun::calcRootMatrix": 0x8011f400,
		"TKumokun::setDeadAnm": 0x8011f798,
		"TKumokun::changeBck": 0x8011f9d8,
		"TKumokun::behaveToWater": 0x8011fae0,
		"TKumokun::receiveMessage": 0x8011fb8c,
		"TKumokun::control": 0x80120010,
		"TKumokun::moveObject": 0x80120058,
		"TKumokun::bindOnFlying": 0x8012013c,
		"bindOnFlying": 0x8012013c,
		"TKumokun::checkOnMovingRoof": 0x801203f8,
		"checkOnMovingRoof": 0x801203f8,
		"TKumokun::checkOnMovingFloor": 0x80120790,
		"checkOnMovingFloor": 0x80120790,
		"TKumokun::checkOnMovingWall": 0x80120a24,
		"checkOnMovingWall": 0x80120a24,
		"TKumokun::bind": 0x80120d98,
		"TKumokun::reset": 0x8012148c,
		"TKumokun::initAttachPlane": 0x80121490,
		"initAttachPlane": 0x80121490,
		"TKumokun::init": 0x801218a8,
		"TKumokun::getBasNameTable": 0x80121a88,
		"TKumokun::TKumokun": 0x80121b00,
		"TSolidStack<char_const*>::~TSolidStack": 0x80121b90,
		"TWallAtGraph::init": 0x80121bdc,
		"JGeometry::TPartition3<float><float>::TPartition3": 0x80121efc,
		"TPartition3": 0x80121efc,
		"TKumokunManager::~TKumokunManager": 0x80121f00,
		"TKoopaManager::~TKoopaManager": 0x80122018,
		"TKoopaManager::loadAfter": 0x8012207c,
		"TKoopaManager::load": 0x801221d4,
		"TKoopaManager::createModelData": 0x801227d0,
		"TKoopaManager::createEnemyInstance": 0x80122804,
		"TKoopaManager::TKoopaManager": 0x8012280c,
		"TKoopa::calcRootMatrix": 0x80122848,
		"TKoopa::receiveMessage": 0x80122b54,
		"TKoopa::perform": 0x80122b74,
		"TNerveKoopaTumble::~TNerveKoopaTumble": 0x80123038,
		"TNerveKoopaTurn::~TNerveKoopaTurn": 0x801230a4,
		"TKoopa::reset": 0x80123100,
		"TKoopa::getBasNameTable": 0x801231e4,
		"TKoopa::init": 0x801231f0,
		"TNerveKoopaProvoke::~TNerveKoopaProvoke": 0x8012362c,
		"TKoopa::loadAfter": 0x80123688,
		"TKoopa::load": 0x801238a8,
		"TKoopa::TKoopa": 0x801238c8,
		"TKoopa::updateAnmSound": 0x80123930,
		"TKoopa::fall": 0x801239f8,
		"fall": 0x801239f8,
		"TNerveKoopaFall::~TNerveKoopaFall": 0x80123a90,
		"TKoopa::getTargetDir": 0x80123aec,
		"getTargetDir": 0x80123aec,
		"TKoopa::stagger": 0x80123be8,
		"stagger": 0x80123be8,
		"TNerveKoopaStagger::~TNerveKoopaStagger": 0x80123edc,
		"TNerveKoopaGetShowered::~TNerveKoopaGetShowered": 0x80123f38,
		"TNerveKoopaGetDown::~TNerveKoopaGetDown": 0x80123f94,
		"TNerveKoopaFlame::~TNerveKoopaFlame": 0x80123ff0,
		"TKoopa::getShowered": 0x8012405c,
		"getShowered": 0x8012405c,
		"TNerveKoopaWait::~TNerveKoopaWait": 0x8012449c,
		"TKoopa::effectsTumble": 0x80124508,
		"effectsTumble": 0x80124508,
		"TKoopa::getDown": 0x801245b4,
		"getDown": 0x801245b4,
		"TKoopa::allowsLaunch": 0x801248fc,
		"allowsLaunch": 0x801248fc,
		"TKoopa::getNeckFocus": 0x80124994,
		"getNeckFocus": 0x80124994,
		"TKoopa::isFlaming": 0x80124c80,
		"isFlaming": 0x80124c80,
		"TKoopa::getFlameDirRate": 0x80124cc8,
		"getFlameDirRate": 0x80124cc8,
		"TKoopa::changeAnm": 0x80124e28,
		"changeAnm": 0x80124e28,
		"TKoopa::setUpHitActors": 0x80124f08,
		"TKoopa::getFlameDirDegree": 0x80125d74,
		"getFlameDirDegree": 0x80125d74,
		"TKoopaBody::attack_": 0x80125dd0,
		"TKoopaBody::receiveMessage": 0x80125e48,
		"TKoopaHead::attack_": 0x801260fc,
		"TKoopaHead::receiveMessage": 0x80126174,
		"TKoopaHand::attack_": 0x8012648c,
		"TKoopaHand::receiveMessage": 0x801264c8,
		"TKoopaFlame::attack_": 0x801264d0,
		"TKoopaFlame::receiveMessage": 0x80126594,
		"TKoopaFlame::control": 0x801265b0,
		"TKoopaParts::perform": 0x801266a0,
		"TKoopaParts::control": 0x80126738,
		"TKoopaParts::TKoopaParts": 0x8012673c,
		"TNerveKoopaGetDown::execute": 0x80126894,
		"TNerveKoopaGetShowered::execute": 0x80126c38,
		"TNerveKoopaStagger::execute": 0x80126d34,
		"TNerveKoopaProvoke::execute": 0x80126e30,
		"TNerveKoopaFlame::execute": 0x80126f98,
		"TNerveKoopaTurnR::~TNerveKoopaTurnR": 0x80127a4c,
		"TNerveKoopaTurnL::~TNerveKoopaTurnL": 0x80127ab8,
		"TEnemyManager::getSaveParam": 0x80127b24,
		"TNerveKoopaFall::execute": 0x80127b3c,
		"TNerveKoopaTumble::execute": 0x80127c10,
		"TNerveKoopaWait::execute": 0x80127de0,
		"TNerveKoopaTurnR::execute": 0x801286bc,
		"TNerveKoopaTurnL::execute": 0x8012884c,
		"Enemy::__sinit_Koopa_cpp": 0x80128cc0,
		"__sinit_Koopa_cpp": 0x80128cc0,
		"TNerveKukkuRecoverGraph::~TNerveKukkuRecoverGraph": 0x80128fec,
		"TNerveKukkuRecoverGraph::execute": 0x80129048,
		"TNerveKukkuGraphWander::~TNerveKukkuGraphWander": 0x801291b4,
		"TNerveKukkuPostFall::execute": 0x80129210,
		"TNerveKukkuPostFall::theNerve": 0x8012934c,
		"TNerveKukkuPostFall::~TNerveKukkuPostFall": 0x801293b0,
		"TNerveKukkuFall::execute": 0x8012940c,
		"TNerveKukkuFall::theNerve": 0x801296a4,
		"TNerveKukkuFall::~TNerveKukkuFall": 0x80129708,
		"TNerveKukkuGraphWander::execute": 0x80129764,
		"TKukku::getBasNameTable": 0x80129b4c,
		"TKukkuManager::createModelData": 0x80129b58,
		"TKukkuManager::load": 0x80129b8c,
		"TKukkuManager::TKukkuManager": 0x80129e2c,
		"TKukku::setAfterDeadEffect": 0x80129e68,
		"TKukku::setDeadAnm": 0x80129eb4,
		"TKukku::dropCoins": 0x80129ef4,
		"dropCoins": 0x80129ef4,
		"TKukku::calcMomentum": 0x8012a334,
		"calcMomentum": 0x8012a334,
		"TKukku::updateRotation": 0x8012a450,
		"updateRotation": 0x8012a450,
		"TKukku::behaveToWater": 0x8012a698,
		"TKukku::perform": 0x8012a848,
		"TKukku::bind": 0x8012a8c8,
		"TKukku::calcRootMatrix": 0x8012a8e8,
		"TKukku::control": 0x8012acc0,
		"TKukku::receiveMessage": 0x8012acf8,
		"TKukku::reset": 0x8012ad88,
		"TKukku::init": 0x8012adb8,
		"TKukku::TKukku": 0x8012b034,
		"TKukkuBall::perform": 0x8012b080,
		"TKukkuBall::init": 0x8012b324,
		"TKukkuManager::~TKukkuManager": 0x8012b4c8,
		"Enemy::__sinit_Kukku_cpp": 0x8012b5c0,
		"__sinit_Kukku_cpp": 0x8012b5c0,
		"TNerveAmenboHitWater::~TNerveAmenboHitWater": 0x8012b8cc,
		"TNerveAmenboHitWater::execute": 0x8012b928,
		"TNerveAmenboSearch::~TNerveAmenboSearch": 0x8012bbc0,
		"TNerveAmenboWalk::execute": 0x8012bc1c,
		"TNerveAmenboWalk::~TNerveAmenboWalk": 0x8012bf74,
		"TNerveAmenboPreAttack::execute": 0x8012bfd0,
		"TNerveAmenboPreAttack::~TNerveAmenboPreAttack": 0x8012c150,
		"TNerveAmenboTurn::execute": 0x8012c1ac,
		"TNerveAmenboTurn::~TNerveAmenboTurn": 0x8012c46c,
		"TNerveAmenboSearch::execute": 0x8012c4c8,
		"JGeometry::TVec4<float><float>::operator_=": 0x8012ca5c,
		"TAmenbo::getQuat": 0x8012ca80,
		"TAmenbo::getBasNameTable": 0x8012ca98,
		"TAmenboManager::createModelData": 0x8012caa4,
		"TAmenboManager::load": 0x8012cad8,
		"TAmenboManager::TAmenboManager": 0x8012cd4c,
		"TAmenbo::deactivateJumpBase": 0x8012cd88,
		"deactivateJumpBase": 0x8012cd88,
		"TAmenbo::isFindOutMario": 0x8012ce28,
		"isFindOutMario": 0x8012ce28,
		"TAmenbo::changeByJuice": 0x8012cfac,
		"TAmenbo::setDeadAnm": 0x8012cffc,
		"TAmenbo::attackToMario": 0x8012d04c,
		"TAmenbo::doKeepDistance": 0x8012d130,
		"TAmenbo::isCollidMove": 0x8012d204,
		"TAmenbo::forceKill": 0x8012d214,
		"TAmenbo::calcRootMatrix": 0x8012d294,
		"TAmenbo::behaveToWater": 0x8012d3f4,
		"TAmenbo::receiveMessage": 0x8012d4c0,
		"TMapCollisionBase::isSetUp": 0x8012d510,
		"isSetUp": 0x8012d510,
		"TAmenbo::perform": 0x8012d540,
		"TAmenbo::control": 0x8012d5cc,
		"TAmenbo::bind": 0x8012d9c0,
		"TAmenbo::kill": 0x8012dc98,
		"TAmenbo::reset": 0x8012dcc8,
		"TAmenbo::init": 0x8012dccc,
		"TAmenbo::TAmenbo": 0x8012df2c,
		"TAmenbo::EffectOnJoint::EffectOnJoint": 0x8012dfa0,
		"TAmenboManager::~TAmenboManager": 0x8012e028,
		"TBathtubPeachManager::~TBathtubPeachManager": 0x8012e0a4,
		"TBathtubPeachManager::load": 0x8012e108,
		"TBathtubPeachManager::createModelData": 0x8012e280,
		"TBathtubPeachManager::createEnemyInstance": 0x8012e2b4,
		"TBathtubPeachManager::TBathtubPeachManager": 0x8012e2bc,
		"TBathtubPeach::calcRootMatrix": 0x8012e2f8,
		"TBathtubPeach::receiveMessage": 0x8012e3a4,
		"TBathtubPeach::getRootJointMtx": 0x8012e3c4,
		"TBathtubPeach::perform": 0x8012e3e8,
		"TBathtubPeach::reset": 0x8012e408,
		"TBathtubPeach::init": 0x8012e53c,
		"TNervePeachEscape::~TNervePeachEscape": 0x8012e5f8,
		"TBathtubPeach::getBasNameTable": 0x8012e654,
		"TBathtubPeach::TBathtubPeach": 0x8012e660,
		"TNervePeachEscape::execute": 0x8012e6d8,
		"JGeometry::TVec2<float><float>::dot": 0x8012ec04,
		"TNervePeachStagger::~TNervePeachStagger": 0x8012ec20,
		"TNervePeachStagger::execute": 0x8012ec7c,
		"Enemy::__sinit_BathtubPeach_cpp": 0x8012ede4,
		"__sinit_BathtubPeach_cpp": 0x8012ede4,
		"TBathtubKillerManager::~TBathtubKillerManager": 0x8012f0e8,
		"TBathtubKillerManager::createEnemyInstance": 0x8012f15c,
		"TBathtubKillerManager::createModelData": 0x8012f1d0,
		"TBathtubKillerManager::countActiveKillers": 0x8012f204,
		"countActiveKillers": 0x8012f204,
		"TBathtubKillerManager::loadAfter": 0x8012f270,
		"TBathtubKillerManager::load": 0x8012f38c,
		"TBathtubKillerManager::TBathtubKillerManager": 0x8012f3f8,
		"TNerveBathtubKillerExplosion::execute": 0x8012f434,
		"TNerveBathtubKillerExplosion::theNerve": 0x8012f5d0,
		"TNerveBathtubKillerExplosion::~TNerveBathtubKillerExplosion": 0x8012f634,
		"TNerveBathtubKillerBreak::execute": 0x8012f690,
		"TNerveBathtubKillerBreak::theNerve": 0x8012f7ac,
		"TNerveBathtubKillerBreak::~TNerveBathtubKillerBreak": 0x8012f810,
		"TNerveBathtubKillerStraight::execute": 0x8012f86c,
		"TNerveBathtubKillerStraight::~TNerveBathtubKillerStraight": 0x8012f9fc,
		"TNerveBathtubKillerChaseStraight::execute": 0x8012fa58,
		"TNerveBathtubKillerChase::~TNerveBathtubKillerChase": 0x8012fe98,
		"TNerveBathtubKillerChaseStraight::~TNerveBathtubKillerChaseStraight": 0x8012fef4,
		"TNerveBathtubKillerChase::execute": 0x8012ff50,
		"TNerveBathtubKillerWander::execute": 0x801302e0,
		"TNerveBathtubKillerWander::~TNerveBathtubKillerWander": 0x80130698,
		"TBathtubKiller::isAboided": 0x801306f4,
		"isAboided": 0x801306f4,
		"TBathtubKiller::getBasNameTable": 0x80130a38,
		"TBathtubKiller::behaveToWater": 0x80130a44,
		"TBathtubKiller::isCollidMove": 0x80130b5c,
		"TBathtubKiller::attackToMario": 0x80130f88,
		"TBathtubKiller::receiveMessage": 0x8013111c,
		"TBathtubKiller::calcRootMatrix": 0x80131388,
		"TBathtubKiller::getGravityY": 0x80131418,
		"TBathtubKiller::makeQuat": 0x80131448,
		"makeQuat": 0x80131448,
		"TBathtubKiller::moveChasing": 0x80131a44,
		"moveChasing": 0x80131a44,
		"TBathtubKiller::makeInitialVelocity": 0x80131ca0,
		"makeInitialVelocity": 0x80131ca0,
		"TBathtubKiller::perform": 0x80132044,
		"TBathtubKiller::bind": 0x801324d0,
		"TBathtubKiller::generateItemBathtubKiller": 0x801328bc,
		"generateItemBathtubKiller": 0x801328bc,
		"TBathtubKiller::resetBathtubKiller": 0x80132b48,
		"resetBathtubKiller": 0x80132b48,
		"TBathtubKiller::reset": 0x80132eb0,
		"TBathtubKiller::setMActorAndKeeper": 0x80132f20,
		"TBathtubKiller::init": 0x80133090,
		"TBathtubKiller::TBathtubKiller": 0x80133110,
		"TBathtubKillerParams::TBathtubKillerParams": 0x8013315c,
		"Enemy::__sinit_BathtubKiller_cpp": 0x80133908,
		"__sinit_BathtubKiller_cpp": 0x80133908,
		"TCoasterKillerManager::~TCoasterKillerManager": 0x80133c0c,
		"TCoasterKillerManager::createEnemyInstance": 0x80133c80,
		"TCoasterKillerManager::createModelData": 0x80133db4,
		"TCoasterKillerManager::loadAfter": 0x80133de8,
		"TCoasterKillerManager::load": 0x80133e1c,
		"TCoasterKillerManager::TCoasterKillerManager": 0x80133f40,
		"TNerveCoasterKillerExplosion::execute": 0x80133f84,
		"TNerveCoasterKillerExplosion::~TNerveCoasterKillerExplosion": 0x80134104,
		"TCoasterKiller::setDeadAnm": 0x80134160,
		"TCoasterKiller::setNormalFlyAnm": 0x80134214,
		"TCoasterKiller::getBasNameTable": 0x80134268,
		"TCoasterKiller::behaveToWater": 0x80134274,
		"TCoasterKiller::isCollidMove": 0x8013438c,
		"TCoasterKiller::attackToMario": 0x801345b8,
		"TCoasterKiller::setMActorAndKeeper": 0x801346ec,
		"TCoasterKiller::perform": 0x80134840,
		"TCoasterKiller::reset": 0x801349a8,
		"TCoasterKiller::init": 0x801349f8,
		"TNerveCoasterEnemyWander::~TNerveCoasterEnemyWander": 0x80134b38,
		"TCoasterKiller::TCoasterKiller": 0x80134b94,
		"TNerveCoasterEnemyWander::execute": 0x80134bf4,
		"TCoasterEnemy::setWalkAnm": 0x80134d2c,
		"TCoasterEnemy::setNormalFlyAnm": 0x80134d58,
		"TCoasterEnemy::calcRootMatrix": 0x80134d5c,
		"TCoasterEnemy::moveCoaster": 0x80134dec,
		"moveCoaster": 0x80134dec,
		"TCoasterEnemy::makeCoasterGoalPath": 0x8013549c,
		"makeCoasterGoalPath": 0x8013549c,
		"TCoasterEnemy::getGravityY": 0x801354d8,
		"TCoasterEnemy::perform": 0x801354e0,
		"TCoasterEnemy::reset": 0x8013550c,
		"TCoasterEnemy::bind": 0x8013555c,
		"TCoasterEnemy::moveObject": 0x80135638,
		"TCoasterEnemy::init": 0x80135658,
		"Enemy::__sinit_coasterkiller_cpp": 0x801357dc,
		"__sinit_coasterkiller_cpp": 0x801357dc,
		"TNerveDebuTelesaWait::~TNerveDebuTelesaWait": 0x80135ae8,
		"TNerveDebuTelesaWait::execute": 0x80135b44,
		"TDebuTelesaManager::clipEnemies": 0x80135b94,
		"TDebuTelesaManager::createModelData": 0x80135c7c,
		"TDebuTelesaManager::load": 0x80135cb0,
		"TDebuTelesaManager::TDebuTelesaManager": 0x80135d60,
		"TDebuTelesa::setDeadAnm": 0x80135d9c,
		"TDebuTelesa::doKeepDistance": 0x80135dcc,
		"TDebuTelesa::isCollidMove": 0x80135dd4,
		"TDebuTelesa::attackToMario": 0x80135ddc,
		"TDebuTelesa::behaveToWater": 0x80135e08,
		"TDebuTelesa::getBasNameTable": 0x80135e0c,
		"TDebuTelesa::receiveMessage": 0x80135e14,
		"TDebuTelesa::kill": 0x80135ec4,
		"TDebuTelesa::calcRootMatrix": 0x80135ee4,
		"TDebuTelesa::reset": 0x80135ff4,
		"TDebuTelesa::init": 0x80135ff8,
		"TDebuTelesa::TDebuTelesa": 0x80136124,
		"TDebuTelesaManager::~TDebuTelesaManager": 0x80136174,
		"TDebuTelesa::changeByJuice": 0x8013626c,
		"Enemy::__sinit_DebuTelesa_cpp": 0x80136274,
		"__sinit_DebuTelesa_cpp": 0x80136274,
		"TNerveTabePukuDrag::~TNerveTabePukuDrag": 0x80136578,
		"TNerveTabePukuDrag::execute": 0x801365d4,
		"TNerveTabePukuRecoverGraph::~TNerveTabePukuRecoverGraph": 0x80136934,
		"TNerveTabePukuDrag::theNerve": 0x801369a0,
		"TNerveTabePukuDive::execute": 0x80136a04,
		"TNerveTabePukuDive::theNerve": 0x80136bc8,
		"TNerveTabePukuDive::~TNerveTabePukuDive": 0x80136c2c,
		"TNerveTabePukuBite::execute": 0x80136c88,
		"TNerveTabePukuBite::theNerve": 0x80136d80,
		"TNerveTabePukuBite::~TNerveTabePukuBite": 0x80136de4,
		"TNerveTabePukuAttack::execute": 0x80136e40,
		"TNerveTabePukuAttack::~TNerveTabePukuAttack": 0x801371d0,
		"TNerveTabePukuRecoverGraph::execute": 0x8013722c,
		"TNerveTabePukuGraphWander::~TNerveTabePukuGraphWander": 0x80137430,
		"TNerveTabePukuRecoverGraph::theNerve": 0x8013748c,
		"TNerveTabePukuFound::execute": 0x801374f0,
		"TNerveTabePukuFound::~TNerveTabePukuFound": 0x80137798,
		"TNerveTabePukuGraphWander::execute": 0x801377f4,
		"TTabePukuManager::createModelData": 0x801379dc,
		"TTabePukuManager::load": 0x80137a10,
		"TTabePukuManager::TTabePukuManager": 0x80137c4c,
		"TTabePuku::swimTo": 0x80137c88,
		"swimTo": 0x80137c88,
		"TTabePuku::doKeepDistance": 0x8013849c,
		"TTabePuku::isFindMario": 0x801385a8,
		"TTabePuku::forceKill": 0x801385c8,
		"TTabePuku::behaveToWater": 0x801385cc,
		"TTabePuku::attackToMario": 0x801385d0,
		"TTabePuku::getBasNameTable": 0x801387a8,
		"TTabePuku::getTakingMtx": 0x801387b4,
		"TTabePuku::receiveMessage": 0x80138938,
		"TTabePuku::calcRootMatrix": 0x80138974,
		"TTabePuku::bind": 0x80138b34,
		"TTabePuku::control": 0x80138ce0,
		"TTabePuku::perform": 0x80138e2c,
		"TTabePuku::reset": 0x80138e90,
		"TTabePuku::init": 0x80138e9c,
		"TTabePuku::TTabePuku": 0x8013904c,
		"TTPHitActor::bind": 0x8013909c,
		"TTPHitActor::updateTerrainCollsion": 0x8013933c,
		"updateTerrainCollsion": 0x8013933c,
		"TTPHitActor::receiveMessage": 0x801394e0,
		"TTPHitActor::init": 0x80139510,
		"TTabePukuManager::~TTabePukuManager": 0x80139600,
		"Enemy::__sinit_TabePuku_cpp": 0x8013977c,
		"__sinit_TabePuku_cpp": 0x8013977c,
		"TBathtubBinder::float_": 0x80139aa0,
		"float_": 0x80139aa0,
		"TBathtubBinder::bind": 0x80139f1c,
		"TBathtubBinder::init": 0x80139f54,
		"TBathtubBinder::~TBathtubBinder": 0x8013a07c,
		"TBathtubBinder::TBathtubBinder": 0x8013a0e0,
		"TLimitKoopaManager::~TLimitKoopaManager": 0x8013a128,
		"TLimitKoopaManager::loadAfter": 0x8013a18c,
		"TLimitKoopaManager::load": 0x8013a2b4,
		"TLimitKoopaManager::createModelData": 0x8013a878,
		"TLimitKoopaManager::createEnemyInstance": 0x8013a8ac,
		"TLimitKoopaManager::TLimitKoopaManager": 0x8013a8b4,
		"TNerveLimitKoopaStagger::~TNerveLimitKoopaStagger": 0x8013a8f0,
		"TNerveLimitKoopaGetShowered::~TNerveLimitKoopaGetShowered": 0x8013a94c,
		"TNerveLimitKoopaGetDown::~TNerveLimitKoopaGetDown": 0x8013a9a8,
		"TNerveLimitKoopaTumble::~TNerveLimitKoopaTumble": 0x8013aa04,
		"TNerveLimitKoopaTurn::~TNerveLimitKoopaTurn": 0x8013aa70,
		"TLimitKoopa::setUpHitActors": 0x8013aacc,
		"TLimitKoopa::calcRootMatrix": 0x8013af0c,
		"TLimitKoopa::receiveMessage": 0x8013af60,
		"TLimitKoopa::getGravityY": 0x8013af80,
		"TLimitKoopa::startHipDrop": 0x8013af90,
		"startHipDrop": 0x8013af90,
		"TLimitKoopa::bind": 0x8013b198,
		"TLimitKoopa::perform": 0x8013b300,
		"TLimitKoopa::reset": 0x8013b668,
		"TLimitKoopa::init": 0x8013b70c,
		"TNerveLimitKoopaWait::~TNerveLimitKoopaWait": 0x8013b8d4,
		"TLimitKoopa::loadAfter": 0x8013b940,
		"TLimitKoopa::load": 0x8013be6c,
		"TLimitKoopa::TLimitKoopa": 0x8013be8c,
		"TLimitKoopaBody::attack_": 0x8013bf14,
		"TLimitKoopaBody::receiveMessage": 0x8013bf50,
		"TLimitKoopaHead::attack_": 0x8013bf58,
		"TLimitKoopaHead::receiveMessage": 0x8013bf94,
		"TLimitKoopaHand::attack_": 0x8013c188,
		"TLimitKoopaHand::receiveMessage": 0x8013c1c4,
		"TLimitKoopaFlame::attack_": 0x8013c1cc,
		"TLimitKoopaFlame::receiveMessage": 0x8013c26c,
		"TLimitKoopaParts::perform": 0x8013c288,
		"TNerveLimitKoopaGetDown::execute": 0x8013c30c,
		"TNerveLimitKoopaGetShowered::execute": 0x8013c490,
		"TNerveLimitKoopaStagger::execute": 0x8013c52c,
		"TNerveLimitKoopaTumble::execute": 0x8013c5c8,
		"TNerveLimitKoopaWait::execute": 0x8013c664,
		"TNerveLimitKoopaHipDropStart::~TNerveLimitKoopaHipDropStart": 0x8013c88c,
		"TNerveLimitKoopaHipDropStart::execute": 0x8013c91c,
		"TNerveLimitKoopaHipDropJump::~TNerveLimitKoopaHipDropJump": 0x8013ca44,
		"TNerveLimitKoopaHipDropJump::execute": 0x8013caa0,
		"Enemy::__sinit_limitkoopa_cpp": 0x8013ce10,
		"__sinit_limitkoopa_cpp": 0x8013ce10,
		"TLimitKoopaJrManager::~TLimitKoopaJrManager": 0x8013d13c,
		"TLimitKoopaJrManager::createEnemyInstance": 0x8013d1a0,
		"TLimitKoopaJrManager::loadAfter": 0x8013d1a8,
		"TLimitKoopaJrManager::load": 0x8013d1ac,
		"TLimitKoopaJrManager::createModelData": 0x8013d204,
		"TLimitKoopaJrManager::TLimitKoopaJrManager": 0x8013d238,
		"TNerveLimitKoopaJrYahoo::execute": 0x8013d274,
		"TNerveLimitKoopaJrWait::~TNerveLimitKoopaJrWait": 0x8013d38c,
		"TNerveLimitKoopaJrYahoo::~TNerveLimitKoopaJrYahoo": 0x8013d3e8,
		"TNerveLimitKoopaJrLaunch::execute": 0x8013d444,
		"TNerveLimitKoopaJrLaunch::~TNerveLimitKoopaJrLaunch": 0x8013d578,
		"TNerveLimitKoopaJrWait::execute": 0x8013d5d4,
		"TNerveLimitKoopaJrRun::~TNerveLimitKoopaJrRun": 0x8013d948,
		"TNerveLimitKoopaJrRun::execute": 0x8013d9a4,
		"TLimitKoopaJr::moveRun": 0x8013db4c,
		"moveRun": 0x8013db4c,
		"TLimitKoopaJr::receiveMessage": 0x8013def0,
		"TLimitKoopaJr::getBasNameTable": 0x8013df08,
		"TLimitKoopaJr::calcRootMatrix": 0x8013df14,
		"TLimitKoopaJr::bind": 0x8013dfe8,
		"TLimitKoopaJr::perform": 0x8013dfec,
		"TLimitKoopaJr::reset": 0x8013e188,
		"TLimitKoopaJr::init": 0x8013e204,
		"TLimitKoopaJr::TLimitKoopaJr": 0x8013e40c,
		"TLimitKoopaJrParams::TLimitKoopaJrParams": 0x8013e488,
		"Enemy::__sinit_limitkoopajr_cpp": 0x8013e7ac,
		"__sinit_limitkoopajr_cpp": 0x8013e7ac,
		"CPolarSubCamera::execGroundCheck_": 0x800202e8,
		"execGroundCheck_": 0x800202e8,
		"CPolarSubCamera::execRoofCheck_": 0x80020438,
		"execRoofCheck_": 0x80020438,
		"CPolarSubCamera::execWallCheck_": 0x8002057c,
		"execWallCheck_": 0x8002057c,
		"CPolarSubCamera::isNeedWallCheck_": 0x800207b0,
		"isNeedWallCheck_": 0x800207b0,
		"CPolarSubCamera::isNeedRoofCheck_": 0x80020870,
		"isNeedRoofCheck_": 0x80020870,
		"CPolarSubCamera::isNeedGroundCheck_": 0x80020930,
		"isNeedGroundCheck_": 0x80020930,
		"CPolarSubCamera::calcInHouseNo_": 0x80020a9c,
		"calcInHouseNo_": 0x80020a9c,
		"CPolarSubCamera::execCameraModeChangeProc_": 0x80021120,
		"execCameraModeChangeProc_": 0x80021120,
		"CPolarSubCamera::isChangeToParallelCameraCByMoveBG_": 0x80021b10,
		"isChangeToParallelCameraCByMoveBG_": 0x80021b10,
		"CPolarSubCamera::isChangeToParallelCameraByMoveBG_": 0x80021b58,
		"isChangeToParallelCameraByMoveBG_": 0x80021b58,
		"CPolarSubCamera::isChangeToCancanCamera_": 0x80021c54,
		"isChangeToCancanCamera_": 0x80021c54,
		"CPolarSubCamera::isChangeToBossGesoCamera_": 0x80021c80,
		"isChangeToBossGesoCamera_": 0x80021c80,
		"CPolarSubCamera::doLButtonCameraOff_": 0x80021d10,
		"doLButtonCameraOff_": 0x80021d10,
		"CPolarSubCamera::execFrontRotate_": 0x80021e38,
		"execFrontRotate_": 0x80021e38,
		"CPolarSubCamera::changeCamModeSpecifyCamMapToolAndFrame_": 0x80021f1c,
		"changeCamModeSpecifyCamMapToolAndFrame_": 0x80021f1c,
		"CPolarSubCamera::changeCamModeSpecifyCamMapTool_": 0x80021f70,
		"changeCamModeSpecifyCamMapTool_": 0x80021f70,
		"CPolarSubCamera::changeCamModeSpecifyFrame_": 0x80021fec,
		"changeCamModeSpecifyFrame_": 0x80021fec,
		"CPolarSubCamera::changeCamModeSub_": 0x80022020,
		"changeCamModeSub_": 0x80022020,
		"TTargetCamera::operator_=": 0x80022694,
		"CPolarSubCamera::setUpFromLButtonCamera_": 0x80022728,
		"setUpFromLButtonCamera_": 0x80022728,
		"CPolarSubCamera::setUpToLButtonCamera_": 0x80022738,
		"setUpToLButtonCamera_": 0x80022738,
		"CPolarSubCamera::getCameraInbetweenFrame_": 0x800227bc,
		"getCameraInbetweenFrame_": 0x800227bc,
		"Camera::__sinit_CameraChange_cpp": 0x80022ae8,
		"__sinit_CameraChange_cpp": 0x80022ae8,
		"CPolarSubCamera::controlByCameraCode_": 0x80022de4,
		"controlByCameraCode_": 0x80022de4,
		"CPolarSubCamera::getFinalAngleZ": 0x80022fd8,
		"getFinalAngleZ": 0x80022fd8,
		"CPolarSubCamera::getOffsetAngleY": 0x80022fec,
		"getOffsetAngleY": 0x80022fec,
		"CPolarSubCamera::getOffsetAngleX": 0x80022ff8,
		"getOffsetAngleX": 0x80022ff8,
		"CPolarSubCamera::perform": 0x80023004,
		"JGeometry::TUtil<float><float>::one": 0x8002348c,
		"one": 0x8002348c,
		"Camera::MsSqrtf": 0x800234a4,
		"MsSqrtf": 0x800234a4,
		"CPolarSubCamera::ctrlGameCamera_": 0x800234e8,
		"ctrlGameCamera_": 0x800234e8,
		"CPolarSubCamera::calcFinalPosAndAt_": 0x80023950,
		"calcFinalPosAndAt_": 0x80023950,
		"CPolarSubCamera::calcPosAndAt_": 0x80023ae0,
		"calcPosAndAt_": 0x80023ae0,
		"CPolarSubCamera::calcSlopeAngleX_": 0x80024a84,
		"calcSlopeAngleX_": 0x80024a84,
		"TMario::checkStatusType": 0x80024d7c,
		"checkStatusType": 0x80024d7c,
		"CPolarSubCamera::isMomentDefinite_": 0x80024d98,
		"isMomentDefinite_": 0x80024d98,
		"CPolarSubCamera::execInvalidAutoChase_": 0x80024e20,
		"execInvalidAutoChase_": 0x80024e20,
		"CPolarSubCamera::isMarioCrabWalk_": 0x80024e30,
		"isMarioCrabWalk_": 0x80024e30,
		"CPolarSubCamera::isMarioAimWithGun_": 0x80024ed0,
		"isMarioAimWithGun_": 0x80024ed0,
		"CPolarSubCamera::onMoveApproach_": 0x80024f70,
		"onMoveApproach_": 0x80024f70,
		"CPolarSubCamera::offMoveApproach_": 0x80025030,
		"offMoveApproach_": 0x80025030,
		"CPolarSubCamera::rotateY_ByStickX_": 0x80025040,
		"rotateY_ByStickX_": 0x80025040,
		"CPolarSubCamera::rotateX_ByStickY_": 0x800250d0,
		"rotateX_ByStickY_": 0x800250d0,
		"CPolarSubCamera::calcNowTargetFromPosAndAt_": 0x80025194,
		"calcNowTargetFromPosAndAt_": 0x80025194,
		"CPolarSubCamera::calcDistFromXRotRatio_": 0x800252d8,
		"calcDistFromXRotRatio_": 0x800252d8,
		"CPolarSubCamera::calcAngleXFromXRotRatio_": 0x80025308,
		"calcAngleXFromXRotRatio_": 0x80025308,
		"CPolarSubCamera::getUsualLookat": 0x80025338,
		"getUsualLookat": 0x80025338,
		"CPolarSubCamera::getToroccoMtx_": 0x800253a4,
		"getToroccoMtx_": 0x800253a4,
		"CPolarSubCamera::isNowInbetween": 0x800253bc,
		"isNowInbetween": 0x800253bc,
		"CPolarSubCamera::loadAfter": 0x800253dc,
		"Camera::JetCoasterDemoCallBack": 0x80025c0c,
		"JetCoasterDemoCallBack": 0x80025c0c,
		"CPolarSubCamera::CPolarSubCamera": 0x80025c84,
		"CPolarSubCamera::killHeightPan_": 0x80026430,
		"killHeightPan_": 0x80026430,
		"CPolarSubCamera::execHeightPan_": 0x8002645c,
		"execHeightPan_": 0x8002645c,
		"CPolarSubCamera::isNotHeightPanCamMode_": 0x800266a8,
		"isNotHeightPanCamMode_": 0x800266a8,
		"CPolarSubCamera::killHeightPanWhenChangeCamMode_": 0x80026738,
		"killHeightPanWhenChangeCamMode_": 0x80026738,
		"TCameraInbetween::execCameraInbetween": 0x8002682c,
		"execCameraInbetween": 0x8002682c,
		"TCameraInbetween::initCameraInbetween": 0x80026bc4,
		"initCameraInbetween": 0x80026bc4,
		"TCameraInbetween::startCameraInbetween": 0x80026c64,
		"startCameraInbetween": 0x80026c64,
		"TCameraInbetween::addMoveCameraAndMario": 0x80026ccc,
		"TCameraInbetween::warpPosAndAt": 0x80026db4,
		"TCameraInbetween::TCameraInbetween": 0x80026e3c,
		"TCameraKindParam::inbetweenData": 0x80026eb4,
		"inbetweenData": 0x80026eb4,
		"TCameraKindParam::copySaveParam": 0x800273d4,
		"copySaveParam": 0x800273d4,
		"Camera::CLBCalcNearNinePos": 0x80027550,
		"CLBCalcNearNinePos": 0x80027550,
		"JGeometry::TRotation3<JGeometry::TMatrix33<JGeometry::SMatrix33C<float><float>>>::setRotate": 0x80027c7c,
		"Camera::CLBCalcScaleTranslateMatrix": 0x80027dd0,
		"CLBCalcScaleTranslateMatrix": 0x80027dd0,
		"Camera::CLBCalcRotateZXYTranslateMatrix": 0x80027e20,
		"CLBCalcRotateZXYTranslateMatrix": 0x80027e20,
		"Camera::CLBCalcPointInCubeRatio": 0x80027f70,
		"CLBCalcPointInCubeRatio": 0x80027f70,
		"Camera::CLBIsPointInCube": 0x80028144,
		"CLBIsPointInCube": 0x80028144,
		"Camera::CLBRotatePosAndUp": 0x80028340,
		"CLBRotatePosAndUp": 0x80028340,
		"Camera::CLBRevisionLookatByAngleX": 0x800287ec,
		"CLBRevisionLookatByAngleX": 0x800287ec,
		"Camera::CLBPolarToCross": 0x800289b4,
		"CLBPolarToCross": 0x800289b4,
		"Camera::CLBCrossToPolar": 0x80028a4c,
		"CLBCrossToPolar": 0x80028a4c,
		"Camera::CLBChaseSpecialDecrease": 0x80028b54,
		"CLBChaseSpecialDecrease": 0x80028b54,
		"Camera::CLBChaseDecrease": 0x80028bd4,
		"CLBChaseDecrease": 0x80028bd4,
		"Camera::CLBChaseAngleDecrease": 0x80028c48,
		"CLBChaseAngleDecrease": 0x80028c48,
		"Camera::CLBCalc2DFPos": 0x80028cac,
		"CLBCalc2DFPos": 0x80028cac,
		"Camera::__sinit_cameralib_cpp": 0x80028e1c,
		"__sinit_cameralib_cpp": 0x80028e1c,
		"TCameraMarioData::isMarioClimb": 0x80028e38,
		"isMarioClimb": 0x80028e38,
		"TCameraMarioData::isMarioLeanMirror": 0x80028e74,
		"isMarioLeanMirror": 0x80028e74,
		"TCameraMarioData::isMarioSlider": 0x80028ed0,
		"isMarioSlider": 0x80028ed0,
		"TCameraMarioData::isMarioIndoor": 0x80028f38,
		"isMarioIndoor": 0x80028f38,
		"TCameraMarioData::isMarioRocketing": 0x80028fa8,
		"isMarioRocketing": 0x80028fa8,
		"TCameraMarioData::isMarioGoDown": 0x80028ffc,
		"isMarioGoDown": 0x80028ffc,
		"TCameraMarioData::calcAndSetMarioData": 0x80029038,
		"calcAndSetMarioData": 0x80029038,
		"TCameraMarioData::TCameraMarioData": 0x800291a4,
		"CPolarSubCamera::ctrlLButtonCamera_": 0x800291d0,
		"ctrlLButtonCamera_": 0x800291d0,
		"CPolarSubCamera::getNozzleTopPos_": 0x800293e0,
		"getNozzleTopPos_": 0x800293e0,
		"CPolarSubCamera::calcNoticeTargetYrot_": 0x800294f0,
		"calcNoticeTargetYrot_": 0x800294f0,
		"CPolarSubCamera::execNoticeOnOffProc_": 0x800296f4,
		"execNoticeOnOffProc_": 0x800296f4,
		"CPolarSubCamera::getNoticeActor_": 0x800297b8,
		"getNoticeActor_": 0x800297b8,
		"CPolarSubCamera::setNoticeInfo": 0x80029af0,
		"setNoticeInfo": 0x80029af0,
		"CPolarSubCamera::ctrlNormalOrTowerCamera_": 0x80029d5c,
		"ctrlNormalOrTowerCamera_": 0x80029d5c,
		"CPolarSubCamera::calcTowerCenterPos_": 0x8002a210,
		"calcTowerCenterPos_": 0x8002a210,
		"TCamSaveKindParam::TCamSaveKindParam": 0x8002a3e8,
		"TCamSaveEx::TCamSaveEx": 0x8002b7c8,
		"TCamSaveJetCoaster::TCamSaveJetCoaster": 0x8002bcb8,
		"TCamSaveShake::TCamSaveShake": 0x8002be14,
		"TCamSaveNotice::TCamSaveNotice": 0x8002bfac,
		"TCameraShake::execShake": 0x8002c1c0,
		"execShake": 0x8002c1c0,
		"TCameraShake::keepShake": 0x8002c718,
		"keepShake": 0x8002c718,
		"TCameraShake::startShake": 0x8002c99c,
		"startShake": 0x8002c99c,
		"TCameraShake::getUseShakeData_": 0x8002cac8,
		"getUseShakeData_": 0x8002cac8,
		"TCameraShake::TCameraShake": 0x8002cd8c,
		"CPolarSubCamera::ctrlTalkCamera_": 0x8002cf20,
		"ctrlTalkCamera_": 0x8002cf20,
		"CPolarSubCamera::makeMtxForPrevTalk": 0x8002cf68,
		"makeMtxForPrevTalk": 0x8002cf68,
		"CPolarSubCamera::makeMtxForTalk": 0x8002d000,
		"makeMtxForTalk": 0x8002d000,
		"TLensFlare::~TLensFlare": 0x8002d0e0,
		"TLensFlare::perform": 0x8002d154,
		"TLensFlare::TLensFlare": 0x8002d790,
		"Camera::CLBEaseOutInbetween": 0x8002d8d8,
		"TLensGlow::~TLensGlow": 0x8002d8fc,
		"TLensGlow::perform": 0x8002d99c,
		"TLensGlow::TLensGlow": 0x8002decc,
		"TSunMgr::~TSunMgr": 0x8002e1f4,
		"TSunMgr::getAddColor": 0x8002e2a0,
		"getAddColor": 0x8002e2a0,
		"TSunMgr::perform": 0x8002e2d0,
		"TSunMgr::load": 0x8002e47c,
		"TSunMgr::TSunMgr": 0x8002e644,
		"Camera::__sinit_sunmgr_cpp": 0x8002e6ec,
		"__sinit_sunmgr_cpp": 0x8002e6ec,
		"TSunModel::getZBufValue": 0x8002ea70,
		"getZBufValue": 0x8002ea70,
		"TSunModel::perform": 0x8002eb0c,
		"TSunModel::calcDispRatioAndScreenPos_": 0x8002ef2c,
		"calcDispRatioAndScreenPos_": 0x8002ef2c,
		"Camera::CLBScreenFPosToSPos": 0x8002f050,
		"CLBScreenFPosToSPos": 0x8002f050,
		"TSunModel::calcOtherFPosFromCenterAndRadius_": 0x8002f164,
		"calcOtherFPosFromCenterAndRadius_": 0x8002f164,
		"TSunModel::load": 0x8002f220,
		"TSunModel::TSunModel": 0x8002f570,
		"JGeometry::TVec2<short><short>::TVec2": 0x8002f7c8,
		"Camera::SMS_IsInSameCameraCube": 0x8002f8a8,
		"SMS_IsInSameCameraCube": 0x8002f8a8,
		"Camera::SMS_IsInOtherFastCube": 0x8002f9c0,
		"SMS_IsInOtherFastCube": 0x8002f9c0,
		"TCubeManagerArea::isInAreaCube": 0x8002fae8,
		"isInAreaCube": 0x8002fae8,
		"TCubeManagerBase::calcPointInCubeRatio": 0x8002fc34,
		"calcPointInCubeRatio": 0x8002fc34,
		"TCubeManagerBase::isInCube": 0x8002fc80,
		"isInCube": 0x8002fc80,
		"TCubeManagerBase::getInCubeNo": 0x8002fcf0,
		"getInCubeNo": 0x8002fcf0,
		"TCubeManagerBase::getDataNo": 0x8002fd88,
		"getDataNo": 0x8002fd88,
		"TCubeManagerBase::perform": 0x8002fdbc,
		"TCubeManagerBase::load": 0x8002fdc0,
		"TCameraMapTool::calcPosAndAt": 0x80030180,
		"calcPosAndAt": 0x80030180,
		"TCameraMapTool::load": 0x80030254,
		"TCubeStreamInfo::~TCubeStreamInfo": 0x80030330,
		"TCubeStreamInfo::load": 0x800303a4,
		"TCubeCameraInfo::load": 0x80030544,
		"TCubeGeneralInfo::load": 0x800306a8,
		"TCubeCameraInfo::~TCubeCameraInfo": 0x800307dc,
		"CPolarSubCamera::ctrlMultiPlayerCamera_": 0x800308b4,
		"ctrlMultiPlayerCamera_": 0x800308b4,
		"CPolarSubCamera::removeMultiPlayer": 0x80030c28,
		"removeMultiPlayer": 0x80030c28,
		"CPolarSubCamera::addMultiPlayer": 0x80030cc0,
		"addMultiPlayer": 0x80030cc0,
		"CPolarSubCamera::createMultiPlayer": 0x80030d1c,
		"createMultiPlayer": 0x80030d1c,
		"TMultiPlayerData::TMultiPlayerData": 0x80030db4,
		"TCameraJetCoaster::TCameraJetCoaster": 0x80030dcc,
		"CPolarSubCamera::ctrlJetCoasterCamera_": 0x80030e74,
		"ctrlJetCoasterCamera_": 0x80030e74,
		"Camera::__sinit_CameraJetCoaster_cpp": 0x80031954,
		"__sinit_CameraJetCoaster_cpp": 0x80031954,
		"TCameraBck::setFrame": 0x80031c50,
		"setFrame": 0x80031c50,
		"TCameraBck::updateDemo": 0x80031cc4,
		"updateDemo": 0x80031cc4,
		"TCameraBck::endDemo": 0x80031eb8,
		"endDemo": 0x80031eb8,
		"TCameraBck::getTotalDemoFrames": 0x80031ee0,
		"getTotalDemoFrames": 0x80031ee0,
		"TCameraBck::startDemo": 0x80031f40,
		"TCameraBck::isFileExist": 0x80031f80,
		"isFileExist": 0x80031f80,
		"TCameraBck::TCameraBck": 0x80031fa8,
		"TCameraOption::moveToDown": 0x800320ac,
		"moveToDown": 0x800320ac,
		"TCameraOption::moveToUp": 0x800320d4,
		"moveToUp": 0x800320d4,
		"TCameraOption::moveToLoadFromTitle": 0x800320fc,
		"moveToLoadFromTitle": 0x800320fc,
		"TCameraOption::TCameraOption": 0x80032130,
		"CPolarSubCamera::ctrlOptionCamera_": 0x800322a4,
		"ctrlOptionCamera_": 0x800322a4,
		"CPolarSubCamera::isNormalDeadDemo": 0x8003262c,
		"isNormalDeadDemo": 0x8003262c,
		"CPolarSubCamera::isHellDeadDemo": 0x8003264c,
		"isHellDeadDemo": 0x8003264c,
		"CPolarSubCamera::execDeadDemoProc_": 0x8003266c,
		"execDeadDemoProc_": 0x8003266c,
		"CPolarSubCamera::ctrlNormalDeadDemo_": 0x80032740,
		"ctrlNormalDeadDemo_": 0x80032740,
		"CPolarSubCamera::getRestDemoFrames": 0x800328e4,
		"getRestDemoFrames": 0x800328e4,
		"CPolarSubCamera::isSimpleDemoCamera": 0x800328f0,
		"isSimpleDemoCamera": 0x800328f0,
		"CPolarSubCamera::endDemoCamera": 0x8003293c,
		"endDemoCamera": 0x8003293c,
		"CPolarSubCamera::startDemoCamera": 0x80032a84,
		"startDemoCamera": 0x80032a84,
		"CPolarSubCamera::startGateDemoCamera": 0x80032bdc,
		"startGateDemoCamera": 0x80032bdc,
		"CPolarSubCamera::updateGateDemoCamera_": 0x80032cf4,
		"updateGateDemoCamera_": 0x80032cf4,
		"CPolarSubCamera::updateDemoCamera_": 0x80032dd8,
		"updateDemoCamera_": 0x80032dd8,
		"CPolarSubCamera::addMoveCameraAndMario": 0x8003312c,
		"CPolarSubCamera::isSlopeCameraMode": 0x80033738,
		"isSlopeCameraMode": 0x80033738,
		"CPolarSubCamera::isOverHipAttackSpecifyMode": 0x80033768,
		"isOverHipAttackSpecifyMode": 0x80033768,
		"CPolarSubCamera::isDefiniteCameraSpecifyMode": 0x80033814,
		"isDefiniteCameraSpecifyMode": 0x80033814,
		"CPolarSubCamera::isFixCameraSpecifyMode": 0x80033848,
		"isFixCameraSpecifyMode": 0x80033848,
		"CPolarSubCamera::isRailCameraSpecifyMode": 0x80033870,
		"isRailCameraSpecifyMode": 0x80033870,
		"CPolarSubCamera::isFollowCameraSpecifyMode": 0x80033878,
		"isFollowCameraSpecifyMode": 0x80033878,
		"CPolarSubCamera::isTowerCameraSpecifyMode": 0x800338b4,
		"isTowerCameraSpecifyMode": 0x800338b4,
		"CPolarSubCamera::isNormalCameraCompletely": 0x800338e8,
		"isNormalCameraCompletely": 0x800338e8,
		"CPolarSubCamera::isNormalCameraSpecifyMode": 0x80033978,
		"isNormalCameraSpecifyMode": 0x80033978,
		"CPolarSubCamera::isTalkCameraInbetween": 0x800339a4,
		"isTalkCameraInbetween": 0x800339a4,
		"CPolarSubCamera::isTalkCameraSpecifyMode": 0x80033a9c,
		"isTalkCameraSpecifyMode": 0x80033a9c,
		"CPolarSubCamera::isJetCoaster1stCamera": 0x80033ae8,
		"isJetCoaster1stCamera": 0x80033ae8,
		"CPolarSubCamera::isLButtonCameraInbetween": 0x80033b1c,
		"isLButtonCameraInbetween": 0x80033b1c,
		"CPolarSubCamera::isLButtonCameraSpecifyMode": 0x80033ba4,
		"isLButtonCameraSpecifyMode": 0x80033ba4,
		"CPolarSubCamera::execSecureView_": 0x80033bb8,
		"execSecureView_": 0x80033bb8,
		"CPolarSubCamera::calcSecureViewTarget_": 0x80033db8,
		"calcSecureViewTarget_": 0x80033db8,
		"TBoidLeader::~TBoidLeader": 0x8000566c,
		"TBoidLeader::calcForces": 0x800056e0,
		"calcForces": 0x800056e0,
		"TBoidLeader::calcGoalForce": 0x80005ab0,
		"calcGoalForce": 0x80005ab0,
		"TBoidLeader::perform": 0x80005d14,
		"TBoidLeader::setGraph": 0x80005e7c,
		"setGraph": 0x80005e7c,
		"TBoidLeader::calcBoids": 0x80005f60,
		"calcBoids": 0x80005f60,
		"JGeometry::TVec3<float><float>::div": 0x80006890,
		"div": 0x80006890,
		"TBoidLeader::TBoidLeader": 0x800068c0,
		"TBoid::TBoid": 0x80006ad0,
		"TFishoidManager::~TFishoidManager": 0x80006b60,
		"TFishoidManager::createModelData": 0x80006bcc,
		"TFishoidManager::TFishoidManager": 0x80006c00,
		"TFishoid::createRealoidActor": 0x80006c3c,
		"TFishoid::load": 0x80006e7c,
		"TFishoid::init": 0x800070a4,
		"TFishoid::perform": 0x80007218,
		"TFishoid::TFishoid": 0x800073a0,
		"TFish::init": 0x80007490,
		"TRealoid::perform": 0x800074a0,
		"TRealoid::clipBoids": 0x80007618,
		"clipBoids": 0x80007618,
		"TRealoid::loadDefault": 0x800076ec,
		"loadDefault": 0x800076ec,
		"TRealoid::TRealoid": 0x80007898,
		"TRealoidActor::getTakingMtx": 0x800078f0,
		"TRealoidActor::checkHitActors": 0x800078f8,
		"TRealoidActor::calcRootMatrix": 0x80007990,
		"TRealoidActor::perform": 0x80007c08,
		"TRealoidActor::TRealoidActor": 0x80007c80,
		"TAnimalBase::execWalk": 0x80008024,
		"Animal::MsClamp": 0x80008434,
		"TAnimalBase::getRotationFlyToDir": 0x8000849c,
		"getRotationFlyToDir": 0x8000849c,
		"TAnimalBase::resetRandomCurPathNode": 0x8000868c,
		"resetRandomCurPathNode": 0x8000868c,
		"TAnimalBase::perform": 0x800088a8,
		"TAnimalBase::receiveMessage": 0x80008be0,
		"TAnimalBase::calcRootMatrix": 0x80008be8,
		"TAnimalBase::loadAfter": 0x80008bec,
		"TAnimalBase::load": 0x80008c34,
		"TAnimalBase::initNoLoad_": 0x80008cd4,
		"initNoLoad_": 0x80008cd4,
		"TAnimalBase::init": 0x80008f70,
		"TAnimalBase::TAnimalBase": 0x80009200,
		"Animal::SMS_Eular2Quat": 0x80009258,
		"SMS_Eular2Quat": 0x80009258,
		"Animal::__sinit_AnimalBase_cpp": 0x8000947c,
		"__sinit_AnimalBase_cpp": 0x8000947c,
		"TMewManager::~TMewManager": 0x80009ca8,
		"TMewManager::createModelData": 0x80009d1c,
		"TMewManager::loadAfter": 0x80009d50,
		"TMewManager::load": 0x80009d8c,
		"TAnimalManagerBase::clipEnemies": 0x80009e08,
		"TAnimalManagerBase::TAnimalManagerBase": 0x80009f08,
		"Animal::__sinit_AnimalManager_cpp": 0x80009fbc,
		"__sinit_AnimalManager_cpp": 0x80009fbc,
		"TAnimalSaveIndividual::TAnimalSaveIndividual": 0x8000a2b8,
		"TNerveAnimalGraphWander::~TNerveAnimalGraphWander": 0x8000a4c8,
		"TNerveAnimalGraphWander::execute": 0x8000a524,
		"TNerveAnimalGraphWander::theNerve": 0x8000aad4,
		"TNerveAnimalBirdLanding::~TNerveAnimalBirdLanding": 0x8000abc4,
		"TNerveAnimalBirdLanding::execute": 0x8000ac20,
		"TNerveAnimalBirdWaitOnGround::~TNerveAnimalBirdWaitOnGround": 0x8000aed4,
		"TNerveAnimalBirdGraphWander::~TNerveAnimalBirdGraphWander": 0x8000af30,
		"TNerveAnimalBirdPreLanding::execute": 0x8000af8c,
		"TNerveAnimalBirdPreLanding::theNerve": 0x8000b1fc,
		"TNerveAnimalBirdPreLanding::~TNerveAnimalBirdPreLanding": 0x8000b260,
		"TNerveAnimalBirdComeback::execute": 0x8000b2bc,
		"TNerveAnimalBirdComeback::theNerve": 0x8000b578,
		"TNerveAnimalBirdComeback::~TNerveAnimalBirdComeback": 0x8000b5dc,
		"TNerveAnimalBirdChangeToCoin::execute": 0x8000b638,
		"TNerveAnimalBirdChangeToCoin::theNerve": 0x8000b79c,
		"TNerveAnimalBirdChangeToCoin::~TNerveAnimalBirdChangeToCoin": 0x8000b800,
		"TNerveAnimalBirdGraphWander::execute": 0x8000b85c,
		"TNerveAnimalBirdTakeoff::execute": 0x8000bb7c,
		"TNerveAnimalBirdTakeoff::~TNerveAnimalBirdTakeoff": 0x8000bcec,
		"TNerveAnimalBirdWalkOnGround::execute": 0x8000bd48,
		"TNerveAnimalBirdWalkOnGround::theNerve": 0x8000c120,
		"TNerveAnimalBirdWalkOnGround::~TNerveAnimalBirdWalkOnGround": 0x8000c184,
		"TNerveAnimalBirdActionOnGround::execute": 0x8000c1e0,
		"TNerveAnimalBirdActionOnGround::theNerve": 0x8000c49c,
		"TNerveAnimalBirdActionOnGround::~TNerveAnimalBirdActionOnGround": 0x8000c500,
		"TNerveAnimalBirdWaitOnGround::execute": 0x8000c55c,
		"TNerveAnimalBirdWaitOnGround::theNerve": 0x8000c804,
		"TAnimalBirdManager::createModelData": 0x8000c868,
		"TAnimalBirdManager::loadAfter": 0x8000c89c,
		"TAnimalBirdManager::load": 0x8000c8e8,
		"TAnimalBirdManager::TAnimalBirdManager": 0x8000c954,
		"TAnimalBirdParams::TAnimalBirdParams": 0x8000c990,
		"TAnimalBird::doLanding": 0x8000cd08,
		"doLanding": 0x8000cd08,
		"TAnimalBird::doFlyToCurPathNode": 0x8000d0cc,
		"doFlyToCurPathNode": 0x8000d0cc,
		"TAnimalBird::isFindMario": 0x8000d468,
		"TAnimalBird::getBasNameTable": 0x8000d570,
		"TAnimalBird::bind": 0x8000d57c,
		"TAnimalBird::moveObject": 0x8000d678,
		"TAnimalBird::calcRootMatrix": 0x8000da34,
		"TAnimalBird::receiveMessage": 0x8000dac0,
		"TAnimalBird::loadAfter": 0x8000de64,
		"TAnimalBird::load": 0x8000dea8,
		"TAnimalBird::initParams": 0x8000dffc,
		"initParams": 0x8000dffc,
		"TAnimalBird::init": 0x8000e14c,
		"TAnimalBird::TAnimalBird": 0x8000e284,
		"TAnimalBirdManager::~TAnimalBirdManager": 0x8000e2d4,
		"Animal::__sinit_Bird_cpp": 0x8000e424,
		"__sinit_Bird_cpp": 0x8000e424,
		"TNerveBeeHiveReset::~TNerveBeeHiveReset": 0x8000e728,
		"TNerveBeeHiveReset::execute": 0x8000e784,
		"TNerveBeeHiveWait::~TNerveBeeHiveWait": 0x8000e8d4,
		"TNerveBeeHiveMarioWaterIn::execute": 0x8000e930,
		"TNerveBeeHiveAttack::~TNerveBeeHiveAttack": 0x8000ec1c,
		"TNerveBeeHiveMarioWaterIn::~TNerveBeeHiveMarioWaterIn": 0x8000ecbc,
		"TNerveBeeHiveAttack::execute": 0x8000ed18,
		"TNerveBeeHiveBreak::execute": 0x8000f0a8,
		"TNerveBeeHiveBreak::~TNerveBeeHiveBreak": 0x8000f33c,
		"TNerveBeeHiveFall::execute": 0x8000f398,
		"TNerveBeeHiveFall::~TNerveBeeHiveFall": 0x8000f61c,
		"TNerveBeeHiveWait::execute": 0x8000f678,
		"TBeeHiveManager::createModelData": 0x8000f8f8,
		"TBeeHiveManager::load": 0x8000f92c,
		"TBeeHiveManager::TBeeHiveManager": 0x8000fb44,
		"TBeeHive::getCenterOfGravity": 0x8000fb80,
		"getCenterOfGravity": 0x8000fb80,
		"TBeeHive::appearBee": 0x8000feac,
		"appearBee": 0x8000feac,
		"TBeeHive::doWait": 0x8000ff10,
		"doWait": 0x8000ff10,
		"TBeeHive::calcRootMatrix": 0x80010604,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setSQ": 0x800107b4,
		"setSQ": 0x800107b4,
		"TBeeHive::controlSound": 0x800108b4,
		"controlSound": 0x800108b4,
		"TBeeHive::controlCollision": 0x80010980,
		"TBeeHive::bind": 0x80010a40,
		"TBeeHive::control": 0x80010cd4,
		"TBeeHive::perform": 0x80010d10,
		"TBeeHive::receiveMessage": 0x80010d64,
		"TBeeHive::createRealoidActor": 0x800112b4,
		"TBeeHive::load": 0x80011328,
		"TBeeHive::receiveMessageFromChild": 0x80011518,
		"receiveMessageFromChild": 0x80011518,
		"TBeeHive::reset": 0x80011610,
		"TBeeHive::init": 0x800119b8,
		"TBeeHive::TBeeHive": 0x80011ab4,
		"TBee::receiveMessage": 0x80011b00,
		"TBee::init": 0x80011bb4,
		"TBeeHiveManager::~TBeeHiveManager": 0x80011c98,
		"Animal::__sinit_BeeHive_cpp": 0x80011e1c,
		"__sinit_BeeHive_cpp": 0x80011e1c,
		"TButterfloidManager::~TButterfloidManager": 0x80012130,
		"TButterfloidManager::createModelData": 0x80012194,
		"TButterfloidManager::TButterfloidManager": 0x800121c8,
		"TButterfloid::createRealoidActor": 0x80012204,
		"TButterfloid::load": 0x80012278,
		"TButterfloid::init": 0x800124f8,
		"TButterfloid::TButterfloid": 0x800125c4,
		"TButterfly::receiveMessage": 0x80012628,
		"TButterfly::init": 0x800127a4,
		"Runtime.PPCEABI.H::__init_cpp_exceptions_reference": 0x803730c0,
		"__init_cpp_exceptions_reference": 0x803730c0,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions_reference": 0x80373484,
		"__fini_cpp_exceptions_reference": 0x80373484,
		"MSound::@3445": 0x80373ea0,
		"MSound::@3446": 0x80373eb8,
		"MSound::@3447": 0x80373ed0,
		"MSound::@3448": 0x80373ee4,
		"MSound::@3449": 0x80373ef4,
		"MSound::@3305": 0x803743d4,
		"MSound::@3306": 0x803743e4,
		"MSound::@3307": 0x80374400,
		"MSound::@3308": 0x80374418,
		"Camera::@2163": 0x80374748,
		"Camera::@2168": 0x80374778,
		"Camera::@1852": 0x80374838,
		"@1852": 0x80374838,
		"Camera::@1853": 0x80374854,
		"@1853": 0x80374854,
		"Camera::@1849": 0x803748b8,
		"@1849": 0x803748b8,
		"Enemy::@2679": 0x80376e3c,
		"Enemy::@2622": 0x80376ee8,
		"Enemy::@2781": 0x8037717c,
		"Enemy::@2782": 0x80377188,
		"Enemy::@2784": 0x803771a0,
		"Enemy::@6427": 0x80377874,
		"@6427": 0x80377874,
		"Enemy::@6428": 0x8037789c,
		"@6428": 0x8037789c,
		"Enemy::@6429": 0x803778c0,
		"@6429": 0x803778c0,
		"Enemy::@6430": 0x80377900,
		"@6430": 0x80377900,
		"Enemy::@6713": 0x80377be8,
		"@6713": 0x80377be8,
		"Enemy::@6714": 0x80377c04,
		"@6714": 0x80377c04,
		"Enemy::@6715": 0x80377c1c,
		"@6715": 0x80377c1c,
		"Enemy::@4996": 0x80377fc8,
		"Enemy::@5219": 0x80377fec,
		"Enemy::@5243": 0x8037800c,
		"Enemy::@5344": 0x8037815c,
		"Enemy::@2239": 0x8037826c,
		"Enemy::@2451": 0x803782b0,
		"Enemy::@2452": 0x803782e8,
		"Enemy::@2453": 0x8037831c,
		"Enemy::tevColorData$3142": 0x803785fc,
		"tevColorData$3142": 0x803785fc,
		"Enemy::@7550": 0x803786c0,
		"@7550": 0x803786c0,
		"Enemy::@7734": 0x80378710,
		"@7734": 0x80378710,
		"Enemy::@7743": 0x80378748,
		"@7743": 0x80378748,
		"Enemy::@7754": 0x80378754,
		"@7754": 0x80378754,
		"Enemy::@7776": 0x8037877c,
		"@7776": 0x8037877c,
		"Enemy::@7820": 0x803787bc,
		"@7820": 0x803787bc,
		"Enemy::@7824": 0x803787d4,
		"@7824": 0x803787d4,
		"Enemy::@7827": 0x803787e4,
		"@7827": 0x803787e4,
		"Enemy::@7837": 0x80378800,
		"@7837": 0x80378800,
		"Enemy::@7903": 0x80378810,
		"@7903": 0x80378810,
		"Enemy::@7925": 0x80378884,
		"@7925": 0x80378884,
		"Enemy::@8178": 0x803788cc,
		"@8178": 0x803788cc,
		"Enemy::@2432": 0x80379284,
		"Enemy::@2463": 0x80379314,
		"Enemy::@2464": 0x8037933c,
		"Enemy::@2485": 0x803793cc,
		"Enemy::xzTable$2561": 0x803793e4,
		"xzTable$2561": 0x803793e4,
		"Enemy::@3813": 0x80379404,
		"Enemy::@3647": 0x803796e0,
		"Enemy::@3649": 0x803796f8,
		"Enemy::@4256": 0x803797b4,
		"Enemy::@4522": 0x803797d0,
		"Enemy::@4523": 0x803797ec,
		"Enemy::@4524": 0x803797f8,
		"Enemy::@4677": 0x80379860,
		"Enemy::@4856": 0x80379abc,
		"Enemy::@5110": 0x80379ad8,
		"Enemy::@5111": 0x80379aec,
		"Enemy::@5112": 0x80379afc,
		"Enemy::idxarray$3678": 0x8037a3b8,
		"idxarray$3678": 0x8037a3b8,
		"Enemy::entry$3710": 0x8037a468,
		"entry$3710": 0x8037a468,
		"Enemy::@4701": 0x8037a4fc,
		"Enemy::@4702": 0x8037a510,
		"Enemy::@4703": 0x8037a524,
		"Enemy::@4709": 0x8037a550,
		"Enemy::@5588": 0x8037a588,
		"@5588": 0x8037a588,
		"Enemy::@5600": 0x8037a758,
		"@5600": 0x8037a758,
		"Enemy::@5601": 0x8037a77c,
		"@5601": 0x8037a77c,
		"Enemy::@5602": 0x8037a7a0,
		"@5602": 0x8037a7a0,
		"Enemy::@5603": 0x8037a7c8,
		"@5603": 0x8037a7c8,
		"Enemy::@5604": 0x8037a7ec,
		"@5604": 0x8037a7ec,
		"Enemy::@5605": 0x8037a814,
		"@5605": 0x8037a814,
		"Enemy::@5606": 0x8037a83c,
		"@5606": 0x8037a83c,
		"Enemy::@5607": 0x8037a864,
		"Enemy::@5608": 0x8037a88c,
		"@5608": 0x8037a88c,
		"Enemy::@5609": 0x8037a8b0,
		"@5609": 0x8037a8b0,
		"Enemy::@5610": 0x8037a8d4,
		"@5610": 0x8037a8d4,
		"Enemy::@5611": 0x8037a8f8,
		"@5611": 0x8037a8f8,
		"Enemy::@5612": 0x8037a91c,
		"@5612": 0x8037a91c,
		"Enemy::@8143": 0x8037a94c,
		"@8143": 0x8037a94c,
		"Enemy::@8144": 0x8037a960,
		"@8144": 0x8037a960,
		"Enemy::@8148": 0x8037a96c,
		"@8148": 0x8037a96c,
		"Enemy::@9198": 0x8037aa58,
		"@9198": 0x8037aa58,
		"Enemy::@9199": 0x8037aa6c,
		"@9199": 0x8037aa6c,
		"Enemy::@9201": 0x8037aa80,
		"@9201": 0x8037aa80,
		"Enemy::@9203": 0x8037aa94,
		"@9203": 0x8037aa94,
		"Enemy::@9204": 0x8037aaac,
		"@9204": 0x8037aaac,
		"Enemy::@9206": 0x8037aac4,
		"@9206": 0x8037aac4,
		"Enemy::@9208": 0x8037aadc,
		"@9208": 0x8037aadc,
		"Enemy::@9209": 0x8037aaf4,
		"@9209": 0x8037aaf4,
		"Enemy::@9211": 0x8037ab08,
		"@9211": 0x8037ab08,
		"Enemy::@9213": 0x8037ab1c,
		"@9213": 0x8037ab1c,
		"Enemy::@9214": 0x8037ab30,
		"@9214": 0x8037ab30,
		"Enemy::@9215": 0x8037ab44,
		"@9215": 0x8037ab44,
		"Enemy::@9216": 0x8037ab50,
		"@9216": 0x8037ab50,
		"Enemy::@9217": 0x8037ab64,
		"@9217": 0x8037ab64,
		"Enemy::@9219": 0x8037ab74,
		"@9219": 0x8037ab74,
		"Enemy::@9220": 0x8037ab88,
		"@9220": 0x8037ab88,
		"Enemy::@9221": 0x8037ab9c,
		"@9221": 0x8037ab9c,
		"Enemy::@9223": 0x8037abac,
		"@9223": 0x8037abac,
		"Enemy::@9224": 0x8037abbc,
		"@9224": 0x8037abbc,
		"Enemy::@9225": 0x8037abcc,
		"@9225": 0x8037abcc,
		"Enemy::@9226": 0x8037abdc,
		"@9226": 0x8037abdc,
		"Enemy::@9228": 0x8037abec,
		"@9228": 0x8037abec,
		"Enemy::@2142": 0x8037afb4,
		"Enemy::@2383": 0x8037b030,
		"Enemy::@3396": 0x8037b110,
		"Enemy::@5203": 0x8037b30c,
		"Enemy::@5292": 0x8037b31c,
		"Enemy::@5300": 0x8037b328,
		"Enemy::@5301": 0x8037b33c,
		"Enemy::@5404": 0x8037b368,
		"@5404": 0x8037b368,
		"Enemy::@5405": 0x8037b378,
		"Enemy::@5406": 0x8037b388,
		"Enemy::@7291": 0x8037b66c,
		"@7291": 0x8037b66c,
		"Enemy::@7292": 0x8037b698,
		"@7292": 0x8037b698,
		"Enemy::@7431": 0x8037b6e0,
		"@7431": 0x8037b6e0,
		"Enemy::@7432": 0x8037b6ec,
		"@7432": 0x8037b6ec,
		"Enemy::@8403": 0x8037b714,
		"@8403": 0x8037b714,
		"Enemy::@8767": 0x8037b734,
		"@8767": 0x8037b734,
		"Enemy::@8952": 0x8037b748,
		"@8952": 0x8037b748,
		"Enemy::@9152": 0x8037b978,
		"@9152": 0x8037b978,
		"Enemy::entry$3613": 0x8037be7c,
		"entry$3613": 0x8037be7c,
		"Enemy::entry$3618": 0x8037befc,
		"entry$3618": 0x8037befc,
		"Enemy::@4135": 0x8037bf88,
		"Enemy::@4136": 0x8037bf98,
		"Enemy::@5868": 0x8037c108,
		"Enemy::@6558": 0x8037c204,
		"Enemy::@6559": 0x8037c210,
		"Enemy::@6560": 0x8037c220,
		"Enemy::@7227": 0x8037c2bc,
		"@7227": 0x8037c2bc,
		"Enemy::@7228": 0x8037c2c8,
		"@7228": 0x8037c2c8,
		"Enemy::@7229": 0x8037c2d8,
		"@7229": 0x8037c2d8,
		"Enemy::@7231": 0x8037c2f4,
		"@7231": 0x8037c2f4,
		"Enemy::@8204": 0x8037c300,
		"@8204": 0x8037c300,
		"Enemy::@8339": 0x8037c470,
		"@8339": 0x8037c470,
		"Enemy::@8340": 0x8037c480,
		"@8340": 0x8037c480,
		"Enemy::@8341": 0x8037c494,
		"@8341": 0x8037c494,
		"Enemy::@8343": 0x8037c4a8,
		"@8343": 0x8037c4a8,
		"Enemy::@4823": 0x8037c784,
		"@4823": 0x8037c784,
		"Enemy::@4902": 0x8037c800,
		"Enemy::@4991": 0x8037c890,
		"Enemy::@3482": 0x8037ce0c,
		"Enemy::entry$3481": 0x8037ce20,
		"entry$3481": 0x8037ce20,
		"Enemy::@3525": 0x8037d248,
		"Enemy::@5220": 0x8037d2a4,
		"Enemy::@6086": 0x8037d328,
		"@6086": 0x8037d328,
		"Enemy::@2488": 0x8037d5d4,
		"Enemy::entry$3473": 0x8037d774,
		"entry$3473": 0x8037d774,
		"Enemy::@5001": 0x8037d840,
		"Enemy::@5002": 0x8037d86c,
		"Enemy::@5003": 0x8037d894,
		"Enemy::@5004": 0x8037d8bc,
		"Enemy::@5005": 0x8037d8e4,
		"Enemy::@5006": 0x8037d90c,
		"Enemy::@5007": 0x8037d934,
		"Enemy::@7578": 0x8037d9f4,
		"Enemy::@7583": 0x8037da38,
		"Enemy::@7584": 0x8037da4c,
		"Enemy::@5626": 0x8037dcd8,
		"@5626": 0x8037dcd8,
		"Enemy::@5679": 0x8037dce4,
		"Enemy::@3331": 0x8037e0dc,
		"Enemy::@4605": 0x8037e144,
		"Enemy::@4606": 0x8037e164,
		"Enemy::@4639": 0x8037e1a8,
		"Enemy::@5388": 0x8037e234,
		"@5388": 0x8037e234,
		"Enemy::@4425": 0x8037e540,
		"Enemy::@2420": 0x8037e614,
		"Enemy::@2632": 0x8037e658,
		"Enemy::@2634": 0x8037e6c4,
		"Enemy::@5041": 0x8037e98c,
		"Enemy::@5042": 0x8037e9a0,
		"Enemy::@5043": 0x8037e9b0,
		"Enemy::@5044": 0x8037e9c4,
		"Enemy::xzTable$3483": 0x8037ec88,
		"xzTable$3483": 0x8037ec88,
		"Enemy::@3930": 0x8037eca8,
		"Enemy::@6147": 0x8037eda0,
		"Enemy::@8534": 0x8037f338,
		"@8534": 0x8037f338,
		"Enemy::@8537": 0x8037f344,
		"@8537": 0x8037f344,
		"Enemy::@8597": 0x8037f35c,
		"@8597": 0x8037f35c,
		"Enemy::@9057": 0x8037f4cc,
		"@9057": 0x8037f4cc,
		"Enemy::entry$2585": 0x8037f628,
		"entry$2585": 0x8037f628,
		"Enemy::@2748": 0x8037f678,
		"Enemy::@2750": 0x8037f688,
		"Enemy::@3194": 0x8037f86c,
		"Enemy::xzTable$3109": 0x8037faf8,
		"xzTable$3109": 0x8037faf8,
		"Enemy::@5160": 0x8037fba0,
		"Enemy::@5161": 0x8037fbb4,
		"Enemy::@6075": 0x8037fd44,
		"@6075": 0x8037fd44,
		"Enemy::@6171": 0x8037fe6c,
		"Enemy::@2547": 0x8037fea0,
		"Enemy::@2548": 0x8037fed0,
		"Enemy::@2549": 0x8037ff08,
		"Enemy::@2550": 0x8037ff3c,
		"Enemy::@3087": 0x8037ffec,
		"Enemy::entry$3303": 0x80380040,
		"entry$3303": 0x80380040,
		"Enemy::eyeTable$3618": 0x803800cc,
		"eyeTable$3618": 0x803800cc,
		"Enemy::@7886": 0x8038029c,
		"@7886": 0x8038029c,
		"Enemy::@7887": 0x803802ac,
		"@7887": 0x803802ac,
		"Enemy::@7945": 0x803802c4,
		"@7945": 0x803802c4,
		"Enemy::@7946": 0x803802ec,
		"Enemy::@7947": 0x80380314,
		"Enemy::@7948": 0x8038033c,
		"Enemy::@7949": 0x80380368,
		"Enemy::@7950": 0x80380394,
		"@7950": 0x80380394,
		"Enemy::@7951": 0x803803bc,
		"@7951": 0x803803bc,
		"Enemy::@7952": 0x803803e8,
		"@7952": 0x803803e8,
		"Enemy::@7953": 0x80380410,
		"@7953": 0x80380410,
		"Enemy::@8065": 0x803804e4,
		"@8065": 0x803804e4,
		"Enemy::@8066": 0x803804f8,
		"@8066": 0x803804f8,
		"Enemy::@8067": 0x8038050c,
		"@8067": 0x8038050c,
		"Enemy::@8068": 0x80380520,
		"@8068": 0x80380520,
		"Enemy::@8069": 0x80380530,
		"@8069": 0x80380530,
		"Enemy::@8901": 0x803807bc,
		"@8901": 0x803807bc,
		"Enemy::@8995": 0x803807e4,
		"@8995": 0x803807e4,
		"Enemy::@9003": 0x80380808,
		"@9003": 0x80380808,
		"Enemy::@9045": 0x80380818,
		"@9045": 0x80380818,
		"Enemy::@9046": 0x80380844,
		"@9046": 0x80380844,
		"Enemy::@9047": 0x80380870,
		"@9047": 0x80380870,
		"Enemy::@9050": 0x80380898,
		"@9050": 0x80380898,
		"Enemy::@3806": 0x80380c10,
		"Enemy::@3091": 0x80381078,
		"Enemy::@4303": 0x80381174,
		"Enemy::@4305": 0x80381188,
		"Enemy::@4306": 0x8038119c,
		"@4306": 0x8038119c,
		"Enemy::@5669": 0x803812ac,
		"Enemy::@5670": 0x803812c4,
		"Enemy::@5676": 0x803812dc,
		"Enemy::@5682": 0x803812ec,
		"Enemy::@5683": 0x80381304,
		"Enemy::@5738": 0x803813e4,
		"@5738": 0x803813e4,
		"Enemy::@5739": 0x803813f4,
		"@5739": 0x803813f4,
		"Enemy::@5740": 0x80381404,
		"@5740": 0x80381404,
		"Enemy::@2260": 0x80381424,
		"Enemy::entry$2763": 0x80381a88,
		"entry$2763": 0x80381a88,
		"Enemy::entry$2766": 0x80381ab0,
		"entry$2766": 0x80381ab0,
		"Enemy::entry$2770": 0x80381ad8,
		"entry$2770": 0x80381ad8,
		"Enemy::entry$2991": 0x80382a78,
		"entry$2991": 0x80382a78,
		"Enemy::entry$2257": 0x8038307c,
		"entry$2257": 0x8038307c,
		"Enemy::@2268": 0x80383094,
		"Enemy::idx$3289": 0x80383370,
		"idx$3289": 0x80383370,
		"Enemy::zangle$3566": 0x80383380,
		"zangle$3566": 0x80383380,
		"Enemy::zangle$3571": 0x80383390,
		"zangle$3571": 0x80383390,
		"Enemy::zangle$3577": 0x803833b0,
		"zangle$3577": 0x803833b0,
		"Enemy::@6640": 0x80383428,
		"@6640": 0x80383428,
		"Enemy::@6641": 0x80383434,
		"@6641": 0x80383434,
		"Enemy::@6643": 0x80383444,
		"@6643": 0x80383444,
		"Enemy::tevColorData1$2783": 0x80383670,
		"tevColorData1$2783": 0x80383670,
		"Enemy::tevColorData2$2784": 0x803836b0,
		"tevColorData2$2784": 0x803836b0,
		"Enemy::entry$2671": 0x80383838,
		"entry$2671": 0x80383838,
		"Enemy::@2591": 0x80383fa0,
		"Enemy::entry$2840": 0x80383fd0,
		"entry$2840": 0x80383fd0,
		"Enemy::@2774": 0x80384af4,
		"Enemy::entry$2876": 0x80384b34,
		"entry$2876": 0x80384b34,
		"Enemy::entry$3159": 0x80384df4,
		"entry$3159": 0x80384df4,
		"Enemy::entry$3343": 0x80384e54,
		"entry$3343": 0x80384e54,
		"Enemy::@4805": 0x80384ebc,
		"@4805": 0x80384ebc,
		"Enemy::@6031": 0x803850c4,
		"Enemy::@6035": 0x803850f0,
		"Enemy::@6037": 0x80385100,
		"Enemy::@6038": 0x80385118,
		"Enemy::@6039": 0x80385130,
		"Enemy::@6040": 0x80385148,
		"Enemy::entry$2662": 0x8038563c,
		"entry$2662": 0x8038563c,
		"Enemy::@3441": 0x80385b3c,
		"Enemy::entry$3100": 0x80385f38,
		"entry$3100": 0x80385f38,
		"Enemy::@4520": 0x8038607c,
		"Enemy::@4521": 0x80386088,
		"Enemy::@4780": 0x803860b0,
		"Enemy::@2388": 0x803861e0,
		"Enemy::@2394": 0x80386250,
		"Enemy::entry$2529": 0x80386280,
		"entry$2529": 0x80386280,
		"Enemy::@4426": 0x80386400,
		"Enemy::entry$2978": 0x80386548,
		"entry$2978": 0x80386548,
		"Enemy::@3230": 0x803866f8,
		"Enemy::@3254": 0x80386718,
		"Enemy::@5689": 0x80386790,
		"Enemy::@5690": 0x803867ac,
		"Enemy::@5692": 0x803867c4,
		"Enemy::@5694": 0x803867d4,
		"Enemy::@2623": 0x80386d18,
		"Enemy::entry$2837": 0x80386d54,
		"entry$2837": 0x80386d54,
		"Enemy::@2574": 0x80386ee0,
		"Enemy::entry$2870": 0x80386f18,
		"entry$2870": 0x80386f18,
		"Enemy::@4864": 0x80386ff0,
		"Enemy::entry$3215": 0x80387208,
		"entry$3215": 0x80387208,
		"Enemy::entry$3047": 0x80387674,
		"entry$3047": 0x80387674,
		"Enemy::@3799": 0x8038775c,
		"GC2D::@6844": 0x80387920,
		"GC2D::@6845": 0x80387954,
		"GC2D::@10981": 0x80387970,
		"@10981": 0x80387970,
		"GC2D::@11626": 0x80387980,
		"@11626": 0x80387980,
		"GC2D::@11630": 0x80387990,
		"@11630": 0x80387990,
		"GC2D::@11631": 0x8038799c,
		"@11631": 0x8038799c,
		"GC2D::@11632": 0x803879ac,
		"@11632": 0x803879ac,
		"GC2D::@11847": 0x803879b8,
		"@11847": 0x803879b8,
		"GC2D::@11848": 0x803879c8,
		"@11848": 0x803879c8,
		"GC2D::@11849": 0x803879e8,
		"@11849": 0x803879e8,
		"GC2D::@11850": 0x80387a00,
		"@11850": 0x80387a00,
		"GC2D::@3547": 0x80387d74,
		"GC2D::@3548": 0x80387d84,
		"GC2D::@3549": 0x80387d94,
		"GC2D::@3550": 0x80387da4,
		"GC2D::@3626": 0x80387db4,
		"GC2D::@3627": 0x80387dd0,
		"GC2D::@4186": 0x80387e04,
		"GC2D::@4187": 0x80387e44,
		"GC2D::@4950": 0x80387e84,
		"GC2D::@4951": 0x80387e94,
		"GC2D::@4952": 0x80387eb4,
		"GC2D::@4953": 0x80387ecc,
		"GC2D::@4954": 0x80387ee8,
		"GC2D::@6781": 0x80387fa8,
		"GC2D::@6782": 0x80387fcc,
		"GC2D::@7095": 0x80387fe8,
		"@7095": 0x80387fe8,
		"GC2D::@7097": 0x80387ff8,
		"@7097": 0x80387ff8,
		"GC2D::@7098": 0x80388004,
		"@7098": 0x80388004,
		"GC2D::@7099": 0x80388028,
		"GC2D::@7100": 0x80388048,
		"GC2D::@7101": 0x80388064,
		"GC2D::@2359": 0x80388098,
		"GC2D::@2360": 0x803880c8,
		"GC2D::@2361": 0x80388100,
		"GC2D::@2362": 0x80388134,
		"GC2D::@2741": 0x80388174,
		"GC2D::@7762": 0x80388190,
		"@7762": 0x80388190,
		"GC2D::@7763": 0x803881a4,
		"@7763": 0x803881a4,
		"GC2D::@7764": 0x803881b8,
		"@7764": 0x803881b8,
		"GC2D::@7765": 0x803881cc,
		"@7765": 0x803881cc,
		"GC2D::@8322": 0x803881dc,
		"GC2D::@8323": 0x803881f4,
		"GC2D::@8324": 0x80388200,
		"GC2D::@8325": 0x80388210,
		"GC2D::@8326": 0x8038821c,
		"GC2D::@8328": 0x80388240,
		"GC2D::@3958": 0x8038838c,
		"GC2D::@3959": 0x803883a4,
		"GC2D::@3960": 0x803883c4,
		"GC2D::@3963": 0x803883e4,
		"GC2D::@3964": 0x80388400,
		"GC2D::@3965": 0x8038841c,
		"GC2D::@3966": 0x80388438,
		"GC2D::@1871": 0x80388970,
		"Map::@3230": 0x803890c4,
		"Map::@3312": 0x803890ec,
		"Map::@3313": 0x80389108,
		"Map::@3314": 0x80389118,
		"Map::point_name_table$2630": 0x803892b8,
		"point_name_table$2630": 0x803892b8,
		"Map::@3022": 0x80389e08,
		"Map::@3330": 0x80389e2c,
		"Map::@3331": 0x80389e38,
		"Map::@3332": 0x80389e50,
		"Map::@3358": 0x80389e74,
		"Map::@3359": 0x80389e8c,
		"Map::@3482": 0x80389ea4,
		"Map::@3483": 0x80389ebc,
		"Map::@3034": 0x8038a3fc,
		"Map::@2995": 0x8038a5f8,
		"Map::@2996": 0x8038a610,
		"MoveBG::JuiceBlock_hit_data_table": 0x8038c698,
		"JuiceBlock_hit_data_table": 0x8038c698,
		"MoveBG::JuiceBlock_obj_hit_info": 0x8038c6a8,
		"JuiceBlock_obj_hit_info": 0x8038c6a8,
		"MoveBG::entry$3271": 0x80390598,
		"entry$3271": 0x80390598,
		"MoveBG::@3475": 0x803905a4,
		"MoveBG::@3478": 0x803905c0,
		"MoveBG::@3479": 0x803905cc,
		"MoveBG::@3480": 0x803905d8,
		"MoveBG::@3481": 0x803905e4,
		"MoveBG::@3482": 0x803905f4,
		"MoveBG::@3483": 0x80390600,
		"MoveBG::@3762": 0x80390610,
		"MoveBG::@3764": 0x80390620,
		"MoveBG::@3765": 0x8039062c,
		"MoveBG::@4156": 0x803909b4,
		"MoveBG::@4157": 0x803909c0,
		"MoveBG::@4158": 0x803909dc,
		"MoveBG::@4159": 0x803909f8,
		"MoveBG::@4096": 0x80390e90,
		"MoveBG::@4097": 0x80390eb0,
		"MoveBG::@4098": 0x80390ec8,
		"MoveBG::@4099": 0x80390ee4,
		"MoveBG::@4304": 0x80390efc,
		"MoveBG::@4565": 0x80390f1c,
		"@4565": 0x80390f1c,
		"MoveBG::@4583": 0x80390f40,
		"MoveBG::@4746": 0x80390f6c,
		"MoveBG::@2694": 0x80390fac,
		"MoveBG::@2695": 0x80390fb8,
		"MoveBG::@3683": 0x803914dc,
		"@3683": 0x803914dc,
		"MoveBG::@3684": 0x803914f0,
		"MoveBG::@4029": 0x80391508,
		"MoveBG::@4239": 0x8039155c,
		"MoveBG::@4293": 0x8039157c,
		"MoveBG::@2226": 0x8039159c,
		"MoveBG::@2282": 0x803915b0,
		"MoveBG::@2285": 0x8039164c,
		"MoveBG::@4019": 0x803916c4,
		"MoveBG::@4151": 0x803916f4,
		"MoveBG::@4200": 0x80391720,
		"MoveBG::@4624": 0x80391730,
		"MoveBG::@5221": 0x80391744,
		"MoveBG::@3723": 0x80391b74,
		"MoveBG::@3752": 0x80391b88,
		"MoveBG::@3861": 0x80391be0,
		"MoveBG::@3877": 0x80391bf0,
		"MoveBG::@3878": 0x80391c14,
		"MoveBG::@4111": 0x80391c60,
		"MoveBG::@4113": 0x80391c90,
		"MoveBG::@4114": 0x80391cb0,
		"MoveBG::@4115": 0x80391cd0,
		"MoveBG::@4603": 0x80391da4,
		"@4603": 0x80391da4,
		"MoveBG::@4604": 0x80391db8,
		"MoveBG::@4605": 0x80391dcc,
		"MoveBG::@4814": 0x80391de0,
		"@4814": 0x80391de0,
		"MoveBG::@4824": 0x80391df8,
		"MoveBG::@4839": 0x80391e08,
		"MoveBG::@4995": 0x80391e1c,
		"MoveBG::@5009": 0x80391e88,
		"MoveBG::@5257": 0x80391e94,
		"MoveBG::@3506": 0x80392068,
		"MoveBG::@3701": 0x803921a4,
		"MoveBG::@4259": 0x80392224,
		"MoveBG::@4127": 0x8039243c,
		"MoveBG::@4128": 0x8039244c,
		"MoveBG::@2502": 0x80392558,
		"MoveBG::@3554": 0x80394080,
		"MoveBG::@3555": 0x803940a4,
		"MoveBG::@4464": 0x80394164,
		"@4464": 0x80394164,
		"MoveBG::@4466": 0x80394174,
		"@4466": 0x80394174,
		"MoveBG::@4467": 0x80394184,
		"@4467": 0x80394184,
		"MoveBG::@5405": 0x803941b0,
		"MoveBG::@5406": 0x803941d0,
		"MoveBG::@5407": 0x803941f0,
		"MoveBG::@5408": 0x80394214,
		"MoveBG::@5835": 0x80394238,
		"MoveBG::@5836": 0x80394268,
		"MoveBG::@5839": 0x80394298,
		"MoveBG::@5960": 0x803942dc,
		"MoveBG::@5961": 0x803942f0,
		"MoveBG::@5962": 0x803942fc,
		"MoveBG::@5963": 0x8039430c,
		"MoveBG::@5964": 0x8039431c,
		"@5964": 0x8039431c,
		"MoveBG::@5965": 0x8039432c,
		"@5965": 0x8039432c,
		"NPC::@2618": 0x80395b00,
		"NPC::@2619": 0x80395b10,
		"NPC::@2620": 0x80395b20,
		"NPC::@2621": 0x80395b30,
		"NPC::@2622": 0x80395b40,
		"NPC::@2671": 0x80395b50,
		"NPC::@2674": 0x80395b5c,
		"NPC::@2675": 0x80395b70,
		"NPC::@2712": 0x80395b88,
		"NPC::@2713": 0x80395ba4,
		"NPC::@2714": 0x80395bb8,
		"NPC::@2715": 0x80395bd0,
		"NPC::@2716": 0x80395be0,
		"NPC::@2717": 0x80395bf4,
		"NPC::@2718": 0x80395c08,
		"NPC::@2719": 0x80395c24,
		"NPC::@2720": 0x80395c34,
		"NPC::@2766": 0x80395cf4,
		"NPC::@2767": 0x80395d14,
		"NPC::@2768": 0x80395d20,
		"NPC::@3121": 0x80395d3c,
		"Strategic::@2779": 0x8039d1b8,
		"Strategic::@2780": 0x8039d1d8,
		"Strategic::@2582": 0x8039d7ec,
		"Strategic::@2583": 0x8039d808,
		"Player::@2307": 0x8039decc,
		"Player::@2470": 0x8039dedc,
		"Player::@2471": 0x8039def4,
		"Player::@2472": 0x8039df0c,
		"Player::@2473": 0x8039df34,
		"Player::@2474": 0x8039df50,
		"Player::@2475": 0x8039df60,
		"Player::@2429": 0x8039df70,
		"Player::@5173": 0x8039ea00,
		"Player::@5174": 0x8039ea0c,
		"Player::@5175": 0x8039ea1c,
		"Player::@5651": 0x8039ea2c,
		"Player::@5653": 0x8039ea44,
		"Player::@5654": 0x8039ea50,
		"@5654": 0x8039ea50,
		"Player::@5655": 0x8039ea5c,
		"@5655": 0x8039ea5c,
		"Player::@5656": 0x8039ea68,
		"@5656": 0x8039ea68,
		"Player::@5657": 0x8039ea74,
		"@5657": 0x8039ea74,
		"Player::@5658": 0x8039ea80,
		"@5658": 0x8039ea80,
		"Player::@5659": 0x8039ea8c,
		"Player::@2650": 0x8039ee94,
		"Player::@2651": 0x8039eebc,
		"Player::@2652": 0x8039eee4,
		"Player::@3043": 0x8039efac,
		"Player::@2685": 0x8039f12c,
		"Player::@2687": 0x8039f138,
		"Player::@4118": 0x8039f3a0,
		"Player::@4119": 0x8039f3b8,
		"Player::@4429": 0x8039f410,
		"Player::@4430": 0x8039f420,
		"Player::@4431": 0x8039f438,
		"Player::@4436": 0x8039f488,
		"Player::@4437": 0x8039f498,
		"Player::@4438": 0x8039f4b0,
		"Player::@4439": 0x8039f4c8,
		"Player::@4483": 0x8039f4d4,
		"Player::@4484": 0x8039f4e0,
		"Player::@4485": 0x8039f504,
		"Player::@4486": 0x8039f52c,
		"Player::@4487": 0x8039f550,
		"Player::@4488": 0x8039f55c,
		"Player::@4489": 0x8039f580,
		"Player::@4490": 0x8039f58c,
		"@4490": 0x8039f58c,
		"Player::@6089": 0x8039f5fc,
		"Player::@6092": 0x8039f608,
		"Player::@6094": 0x8039f614,
		"Player::@6096": 0x8039f620,
		"Player::@6097": 0x8039f62c,
		"Player::@6099": 0x8039f638,
		"Player::@6101": 0x8039f648,
		"Player::@6102": 0x8039f654,
		"Player::@6103": 0x8039f664,
		"@6103": 0x8039f664,
		"Player::@6104": 0x8039f670,
		"@6104": 0x8039f670,
		"Player::@6105": 0x8039f67c,
		"@6105": 0x8039f67c,
		"Player::@6106": 0x8039f68c,
		"@6106": 0x8039f68c,
		"Player::@6107": 0x8039f698,
		"@6107": 0x8039f698,
		"Player::@6108": 0x8039f6a4,
		"@6108": 0x8039f6a4,
		"Player::@6110": 0x8039f6b0,
		"@6110": 0x8039f6b0,
		"Player::@6112": 0x8039f6bc,
		"@6112": 0x8039f6bc,
		"Player::@6113": 0x8039f6c8,
		"@6113": 0x8039f6c8,
		"Player::@6114": 0x8039f6d8,
		"@6114": 0x8039f6d8,
		"Player::@6115": 0x8039f6e4,
		"@6115": 0x8039f6e4,
		"Player::@6116": 0x8039f6f0,
		"@6116": 0x8039f6f0,
		"Player::@6117": 0x8039f700,
		"@6117": 0x8039f700,
		"Player::@6118": 0x8039f714,
		"@6118": 0x8039f714,
		"Player::@6120": 0x8039f728,
		"@6120": 0x8039f728,
		"Player::@6121": 0x8039f734,
		"@6121": 0x8039f734,
		"Player::@6122": 0x8039f744,
		"@6122": 0x8039f744,
		"Player::@6123": 0x8039f750,
		"@6123": 0x8039f750,
		"Player::@6124": 0x8039f75c,
		"@6124": 0x8039f75c,
		"Player::@6126": 0x8039f76c,
		"@6126": 0x8039f76c,
		"Player::@6128": 0x8039f77c,
		"@6128": 0x8039f77c,
		"Player::@6129": 0x8039f78c,
		"Player::@6131": 0x8039f7a0,
		"Player::@6133": 0x8039f7b4,
		"Player::@6135": 0x8039f7c4,
		"Player::@6136": 0x8039f7d8,
		"Player::@6137": 0x8039f7ec,
		"Player::@6138": 0x8039f800,
		"Player::@6140": 0x8039f810,
		"Player::@2177": 0x8039f82c,
		"Player::@2233": 0x8039f840,
		"Player::@2234": 0x8039f870,
		"Player::@2235": 0x8039f8a8,
		"Player::@2236": 0x8039f8dc,
		"Player::@4689": 0x8039f954,
		"Player::@4957": 0x8039f97c,
		"Player::@4961": 0x8039f9a0,
		"Player::@4962": 0x8039f9bc,
		"Player::@4963": 0x8039f9d8,
		"Player::@4964": 0x8039f9f0,
		"Player::@4965": 0x8039fa0c,
		"Player::@4975": 0x8039fa18,
		"Player::@4976": 0x8039fa24,
		"Player::@4978": 0x8039fa30,
		"Player::@4979": 0x8039fa4c,
		"Player::@4980": 0x8039fa68,
		"Player::@4981": 0x8039fa8c,
		"Player::@4982": 0x8039faa8,
		"Player::@4983": 0x8039fac8,
		"Player::@4984": 0x8039fae4,
		"Player::@4985": 0x8039fb04,
		"Player::@4986": 0x8039fb24,
		"Player::@4987": 0x8039fb44,
		"Player::@4991": 0x8039fbb8,
		"Player::@4992": 0x8039fbd4,
		"Player::@4993": 0x8039fbf4,
		"Player::@4994": 0x8039fc14,
		"Player::@4995": 0x8039fc34,
		"Player::@4996": 0x8039fc50,
		"Player::@4997": 0x8039fc70,
		"Player::@4998": 0x8039fc8c,
		"Player::@2237": 0x8039fcbc,
		"Player::@2293": 0x8039fcd0,
		"Player::@2294": 0x8039fd00,
		"Player::@2759": 0x8039fde8,
		"Player::@2358": 0x8039fe8c,
		"Player::@2546": 0x8039ff00,
		"Player::@2547": 0x8039ff14,
		"Player::@2548": 0x8039ff2c,
		"Player::@2549": 0x8039ff40,
		"Player::@2550": 0x8039ff54,
		"Player::@2552": 0x8039ff64,
		"Player::@2554": 0x8039ff74,
		"Player::@2581": 0x8039ff94,
		"Player::@2582": 0x8039ffa0,
		"Player::@2584": 0x8039ffac,
		"Player::@2588": 0x8039ffb8,
		"Player::@2607": 0x8039ffc8,
		"Player::@2609": 0x8039ffd4,
		"Player::@2611": 0x8039ffe4,
		"Player::@2613": 0x8039fff0,
		"Player::@2626": 0x8039fffc,
		"Player::@2754": 0x803a00f0,
		"Player::@2755": 0x803a0100,
		"Player::@3073": 0x803a053c,
		"Player::@3074": 0x803a054c,
		"Player::@3135": 0x803a06ec,
		"Player::@3136": 0x803a0700,
		"Player::@3137": 0x803a0714,
		"Player::@3138": 0x803a0728,
		"Player::@3235": 0x803a089c,
		"Player::@3236": 0x803a08ac,
		"Player::@3238": 0x803a08b8,
		"Player::@3239": 0x803a08c4,
		"Player::@3313": 0x803a0928,
		"Player::@3314": 0x803a0938,
		"Player::@3317": 0x803a096c,
		"Player::@3318": 0x803a0980,
		"Player::@3319": 0x803a0990,
		"Player::@3320": 0x803a099c,
		"Player::@3321": 0x803a09a8,
		"Player::@3359": 0x803a0a5c,
		"Player::@3361": 0x803a0a70,
		"Player::@3363": 0x803a0a88,
		"Player::@3550": 0x803a0c34,
		"Player::@3551": 0x803a0c44,
		"Player::@3555": 0x803a0c60,
		"Player::@3556": 0x803a0c6c,
		"Player::@3558": 0x803a0c78,
		"Player::@3962": 0x803a10a8,
		"Player::@4075": 0x803a13d4,
		"Player::@4076": 0x803a13f0,
		"Player::@4077": 0x803a1408,
		"Player::@6512": 0x803a141c,
		"@6512": 0x803a141c,
		"Player::@6513": 0x803a1428,
		"@6513": 0x803a1428,
		"Player::@6514": 0x803a1444,
		"@6514": 0x803a1444,
		"Player::@6515": 0x803a1464,
		"@6515": 0x803a1464,
		"Player::@4262": 0x803a1e60,
		"System::@3448": 0x803a1ff8,
		"System::@3462": 0x803a2008,
		"System::@3701": 0x803a2018,
		"System::@3702": 0x803a2028,
		"System::@3703": 0x803a2038,
		"System::@3704": 0x803a204c,
		"System::@3705": 0x803a205c,
		"System::@3706": 0x803a2068,
		"System::@3707": 0x803a207c,
		"System::@3854": 0x803a2674,
		"System::@4323": 0x803a26a8,
		"System::@4847": 0x803a26bc,
		"System::@4869": 0x803a26c8,
		"System::@5607": 0x803a26f8,
		"System::@5797": 0x803a2704,
		"System::@2349": 0x803a2878,
		"System::@2350": 0x803a28a8,
		"System::@2351": 0x803a28e0,
		"System::@2352": 0x803a2914,
		"System::@2688": 0x803a2938,
		"System::@2690": 0x803a2944,
		"System::@3911": 0x803a2968,
		"System::@3913": 0x803a297c,
		"System::@3914": 0x803a2994,
		"System::@4272": 0x803a2a30,
		"System::sStrMapFile": 0x803a3158,
		"sStrMapFile": 0x803a3158,
		"System::@2951": 0x803a3288,
		"System::@4625": 0x803a3294,
		"System::@4626": 0x803a32a0,
		"System::@4627": 0x803a32b8,
		"System::@4628": 0x803a32c4,
		"System::@4629": 0x803a32d4,
		"System::@4630": 0x803a32e0,
		"System::@4631": 0x803a32f0,
		"System::@4632": 0x803a3304,
		"System::@4633": 0x803a3318,
		"System::@5540": 0x803a3cfc,
		"System::@5823": 0x803a3d10,
		"System::@3482": 0x803a4468,
		"System::@5353": 0x803a7188,
		"System::@5354": 0x803a7198,
		"System::@5355": 0x803a71a4,
		"System::@5356": 0x803a71b4,
		"System::@5357": 0x803a71c0,
		"System::@5358": 0x803a71d4,
		"System::@5359": 0x803a71f4,
		"System::@5360": 0x803a7200,
		"System::@5361": 0x803a7210,
		"System::@5362": 0x803a7220,
		"System::@5363": 0x803a7230,
		"System::@5364": 0x803a723c,
		"System::@5365": 0x803a724c,
		"System::@5366": 0x803a725c,
		"System::@5367": 0x803a7270,
		"@5367": 0x803a7270,
		"System::@5368": 0x803a727c,
		"System::@3391": 0x803a899c,
		"System::@3392": 0x803a89b0,
		"System::@3393": 0x803a89c0,
		"System::@3394": 0x803a89d4,
		"System::@3395": 0x803a89ec,
		"System::@3396": 0x803a8a00,
		"System::@3397": 0x803a8a14,
		"System::@3398": 0x803a8a28,
		"System::@3399": 0x803a8a3c,
		"System::@2060": 0x803a8bb0,
		"System::@2061": 0x803a8bc0,
		"System::@2062": 0x803a8bd0,
		"System::@2063": 0x803a8bdc,
		"System::@2064": 0x803a8bec,
		"@2064": 0x803a8bec,
		"System::@2065": 0x803a8bfc,
		"System::@2066": 0x803a8c10,
		"System::@2067": 0x803a8c1c,
		"@2067": 0x803a8c1c,
		"System::@2068": 0x803a8c2c,
		"@2068": 0x803a8c2c,
		"System::@2070": 0x803a8c48,
		"System::@2071": 0x803a8c58,
		"System::@2072": 0x803a8c64,
		"System::@2073": 0x803a8c74,
		"System::@2074": 0x803a8c84,
		"System::@2075": 0x803a8c94,
		"System::@2076": 0x803a8ca4,
		"System::@2077": 0x803a8cb0,
		"System::@2078": 0x803a8cbc,
		"System::@2079": 0x803a8cc8,
		"System::@2936": 0x803a8ce4,
		"System::@2937": 0x803a8cf8,
		"System::@2938": 0x803a8d0c,
		"System::@2939": 0x803a8d1c,
		"System::@2941": 0x803a8d28,
		"System::@2942": 0x803a8d3c,
		"System::@2943": 0x803a8d48,
		"System::@2944": 0x803a8d58,
		"System::@2945": 0x803a8d64,
		"System::@2946": 0x803a8d74,
		"System::@2948": 0x803a8d84,
		"System::@2995": 0x803a8d90,
		"System::@3092": 0x803a8db8,
		"JSystem::@1727": 0x803a9318,
		"@1727": 0x803a9318,
		"JSystem::@1728": 0x803a932c,
		"@1728": 0x803a932c,
		"JSystem::@114": 0x803a9348,
		"JSystem::@447": 0x803a9374,
		"@447": 0x803a9374,
		"JSystem::@548": 0x803a9394,
		"@548": 0x803a9394,
		"JSystem::@1809": 0x803a9400,
		"JSystem::@1810": 0x803a9414,
		"JSystem::@1811": 0x803a9434,
		"JSystem::@438": 0x803a9450,
		"@438": 0x803a9450,
		"JSystem::@439": 0x803a9464,
		"@439": 0x803a9464,
		"JSystem::@302": 0x803a94a8,
		"JSystem::@593": 0x803a9564,
		"@593": 0x803a9564,
		"JSystem::@594": 0x803a9590,
		"@594": 0x803a9590,
		"JSystem::@595": 0x803a95bc,
		"@595": 0x803a95bc,
		"JSystem::@596": 0x803a95e4,
		"@596": 0x803a95e4,
		"JSystem::@597": 0x803a9614,
		"@597": 0x803a9614,
		"JSystem::@606": 0x803a963c,
		"JSystem::@607": 0x803a964c,
		"JSystem::@688": 0x803a9668,
		"JSystem::@689": 0x803a968c,
		"JSystem::@720": 0x803a969c,
		"@720": 0x803a969c,
		"JSystem::@721": 0x803a96d4,
		"@721": 0x803a96d4,
		"JSystem::@723": 0x803a96e4,
		"@723": 0x803a96e4,
		"JSystem::@727": 0x803a9748,
		"@727": 0x803a9748,
		"JSystem::@729": 0x803a9758,
		"@729": 0x803a9758,
		"JSystem::@799": 0x803a97a0,
		"JSystem::@800": 0x803a97d0,
		"JSystem::@801": 0x803a97e4,
		"JSystem::@802": 0x803a97f0,
		"JSystem::@803": 0x803a980c,
		"JSystem::@805": 0x803a9834,
		"JSystem::@806": 0x803a9848,
		"JSystem::@1643": 0x803a9898,
		"JSystem::@1644": 0x803a98ac,
		"JSystem::@288": 0x803a98c8,
		"JSystem::@305": 0x803a9930,
		"JSystem::@365": 0x803a9a00,
		"@365": 0x803a9a00,
		"JSystem::@366": 0x803a9a18,
		"@366": 0x803a9a18,
		"JSystem::@367": 0x803a9a2c,
		"@367": 0x803a9a2c,
		"JSystem::@368": 0x803a9a40,
		"@368": 0x803a9a40,
		"JSystem::@1545": 0x803a9a60,
		"JSystem::@1558": 0x803a9a8c,
		"JSystem::@1560": 0x803a9ab0,
		"JSystem::@1495": 0x803a9b98,
		"@1495": 0x803a9b98,
		"JSystem::@1496": 0x803a9bac,
		"@1496": 0x803a9bac,
		"JSystem::@1497": 0x803a9bb8,
		"@1497": 0x803a9bb8,
		"JSystem::@1498": 0x803a9bcc,
		"@1498": 0x803a9bcc,
		"JSystem::@1499": 0x803a9be0,
		"@1499": 0x803a9be0,
		"JSystem::@1566": 0x803a9c20,
		"JSystem::@1567": 0x803a9c34,
		"JSystem::@1628": 0x803a9c40,
		"JSystem::@1701": 0x803a9c68,
		"JSystem::@1702": 0x803a9c90,
		"@1702": 0x803a9c90,
		"JSystem::@1709": 0x803a9cdc,
		"JSystem::@1710": 0x803a9cfc,
		"JSystem::@1711": 0x803a9d18,
		"JSystem::@1722": 0x803a9d34,
		"@1722": 0x803a9d34,
		"JSystem::@1723": 0x803a9d5c,
		"JSystem::@1724": 0x803a9d84,
		"@1724": 0x803a9d84,
		"JSystem::@1757": 0x803a9da0,
		"JSystem::@1775": 0x803a9db8,
		"@1775": 0x803a9db8,
		"JSystem::@1776": 0x803a9de4,
		"@1776": 0x803a9de4,
		"JSystem::@1777": 0x803a9df4,
		"@1777": 0x803a9df4,
		"JSystem::@1778": 0x803a9e08,
		"JSystem::@1795": 0x803a9e30,
		"JSystem::@2006": 0x803a9e4c,
		"JSystem::@2007": 0x803a9e84,
		"JSystem::@2193": 0x803a9ea8,
		"JSystem::@83": 0x803a9ed8,
		"JSystem::@84": 0x803a9ee8,
		"JSystem::@321": 0x803a9f08,
		"JSystem::@1454": 0x803a9f60,
		"@1454": 0x803a9f60,
		"JSystem::@914": 0x803a9f70,
		"@914": 0x803a9f70,
		"JSystem::@1249": 0x803a9f7c,
		"@1249": 0x803a9f7c,
		"JSystem::@1251": 0x803a9f88,
		"@1251": 0x803a9f88,
		"JSystem::@329": 0x803a9f98,
		"JSystem::@838": 0x803a9fa8,
		"@838": 0x803a9fa8,
		"JSystem::@839": 0x803a9fb8,
		"@839": 0x803a9fb8,
		"JSystem::@885": 0x803a9fe0,
		"@885": 0x803a9fe0,
		"JSystem::@813": 0x803aa050,
		"@813": 0x803aa050,
		"JSystem::@999": 0x803aa0b0,
		"@999": 0x803aa0b0,
		"JSystem::@95": 0x803aa0c0,
		"JSystem::@96": 0x803aa0d0,
		"JSystem::@97": 0x803aa0e0,
		"JSystem::@98": 0x803aa0f4,
		"JSystem::@99": 0x803aa104,
		"JSystem::@110": 0x803aa118,
		"JSystem::@272": 0x803aa130,
		"@272": 0x803aa130,
		"JSystem::@289": 0x803aa150,
		"JSystem::halftofull$376": 0x803aa164,
		"halftofull$376": 0x803aa164,
		"JSystem::@258": 0x803aa228,
		"@258": 0x803aa228,
		"JSystem::@903": 0x803aa270,
		"JSystem::@881": 0x803aa280,
		"@881": 0x803aa280,
		"JSystem::@882": 0x803aa290,
		"@882": 0x803aa290,
		"JSystem::@632": 0x803aa2a8,
		"@632": 0x803aa2a8,
		"JSystem::@753": 0x803aa2b4,
		"JSystem::@1461": 0x803aa2cc,
		"@1461": 0x803aa2cc,
		"JSystem::@1462": 0x803aa2d8,
		"@1462": 0x803aa2d8,
		"JSystem::@1463": 0x803aa2ec,
		"@1463": 0x803aa2ec,
		"JSystem::@1464": 0x803aa2f8,
		"@1464": 0x803aa2f8,
		"JSystem::@1465": 0x803aa304,
		"@1465": 0x803aa304,
		"JSystem::@1468": 0x803aa310,
		"@1468": 0x803aa310,
		"JSystem::@1473": 0x803aa320,
		"@1473": 0x803aa320,
		"JSystem::@1474": 0x803aa32c,
		"@1474": 0x803aa32c,
		"JSystem::@1475": 0x803aa338,
		"@1475": 0x803aa338,
		"JSystem::@1476": 0x803aa344,
		"@1476": 0x803aa344,
		"JSystem::@1480": 0x803aa354,
		"@1480": 0x803aa354,
		"JSystem::@1481": 0x803aa360,
		"@1481": 0x803aa360,
		"JSystem::@1482": 0x803aa36c,
		"@1482": 0x803aa36c,
		"JSystem::@49": 0x803aa408,
		"@49": 0x803aa408,
		"JSystem::@50": 0x803aa41c,
		"@50": 0x803aa41c,
		"JSystem::@61": 0x803aa434,
		"JSystem::@293": 0x803aa450,
		"JSystem::@1143": 0x803aa470,
		"@1143": 0x803aa470,
		"JSystem::@1144": 0x803aa480,
		"@1144": 0x803aa480,
		"JSystem::@1578": 0x803aa490,
		"JSystem::@395": 0x803aa4a0,
		"@395": 0x803aa4a0,
		"JSystem::@415": 0x803aa4ac,
		"@415": 0x803aa4ac,
		"JSystem::@416": 0x803aa4e8,
		"@416": 0x803aa4e8,
		"JSystem::@417": 0x803aa4f8,
		"@417": 0x803aa4f8,
		"JSystem::@463": 0x803aa558,
		"JSystem::@530": 0x803aa568,
		"@530": 0x803aa568,
		"JSystem::@537": 0x803aa5b0,
		"@537": 0x803aa5b0,
		"JASystem::Driver::polys_table": 0x803aa5d0,
		"polys_table": 0x803aa5d0,
		"JSystem::@119": 0x803aa5e0,
		"@119": 0x803aa5e0,
		"JSystem::@211": 0x803aa5ec,
		"@211": 0x803aa5ec,
		"JASystem::Driver::relTableSampleCell": 0x803aa5f8,
		"relTableSampleCell": 0x803aa5f8,
		"JASystem::Driver::relTableSqRoot": 0x803aa63c,
		"relTableSqRoot": 0x803aa63c,
		"JASystem::Driver::relTableSquare": 0x803aa680,
		"relTableSquare": 0x803aa680,
		"JSystem::@197": 0x803aa6c8,
		"JSystem::@216": 0x803aa6d4,
		"@216": 0x803aa6d4,
		"JASystem::Arglist": 0x803aa6e0,
		"Arglist": 0x803aa6e0,
		"JSystem::@351": 0x803aa7fc,
		"@351": 0x803aa7fc,
		"JSystem::@442": 0x803aa840,
		"@442": 0x803aa840,
		"JSystem::@444": 0x803aa868,
		"@444": 0x803aa868,
		"JSystem::@445": 0x803aa87c,
		"@445": 0x803aa87c,
		"JSystem::@451": 0x803aa8d0,
		"@451": 0x803aa8d0,
		"Runtime.PPCEABI.H::__ptmf_null": 0x803aa8e0,
		"__ptmf_null": 0x803aa8e0,
		"Runtime.PPCEABI.H::__constants": 0x803aa8f0,
		"__constants": 0x803aa8f0,
		"MSL_C.PPCEABI.bare.H::__ctype_map": 0x803aa990,
		"__ctype_map": 0x803aa990,
		"MSL_C.PPCEABI.bare.H::__lower_map": 0x803aaa90,
		"__lower_map": 0x803aaa90,
		"MSL_C.PPCEABI.bare.H::__upper_map": 0x803aab90,
		"__upper_map": 0x803aab90,
		"MSL_C.PPCEABI.bare.H::@stringBase0": 0x803aac90,
		"@stringBase0": 0x803aac90,
		"MSL_C.PPCEABI.bare.H::atan_coeff$96": 0x803aad38,
		"atan_coeff$96": 0x803aad38,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_hi$97": 0x803aad54,
		"onep_one_over_xisqr_hi$97": 0x803aad54,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_lo$98": 0x803aad6c,
		"onep_one_over_xisqr_lo$98": 0x803aad6c,
		"MSL_C.PPCEABI.bare.H::atan_xi_hi$99": 0x803aad84,
		"atan_xi_hi$99": 0x803aad84,
		"MSL_C.PPCEABI.bare.H::atan_xi_lo$100": 0x803aada0,
		"atan_xi_lo$100": 0x803aada0,
		"MSL_C.PPCEABI.bare.H::one_over_xi_hi$101": 0x803aadbc,
		"one_over_xi_hi$101": 0x803aadbc,
		"MSL_C.PPCEABI.bare.H::one_over_xi_lo$102": 0x803aadd4,
		"one_over_xi_lo$102": 0x803aadd4,
		"MSL_C.PPCEABI.bare.H::tmp_float": 0x803aadf0,
		"tmp_float": 0x803aadf0,
		"MSL_C.PPCEABI.bare.H::__two_to_log2e_m1_tI": 0x803aae00,
		"__two_to_log2e_m1_tI": 0x803aae00,
		"MSL_C.PPCEABI.bare.H::__one_over_F": 0x803ab0c8,
		"__one_over_F": 0x803ab0c8,
		"MSL_C.PPCEABI.bare.H::__sincos_on_quadrant": 0x803ab2cc,
		"__sincos_on_quadrant": 0x803ab2cc,
		"MSL_C.PPCEABI.bare.H::__sincos_poly": 0x803ab2ec,
		"__sincos_poly": 0x803ab2ec,
		"MSL_C.PPCEABI.bare.H::__log2_F": 0x803ab318,
		"__log2_F": 0x803ab318,
		"MSL_C.PPCEABI.bare.H::__two_to_x": 0x803ab51c,
		"__two_to_x": 0x803ab51c,
		"MSL_C.PPCEABI.bare.H::__exp_to_x$105": 0x803ab540,
		"__exp_to_x$105": 0x803ab540,
		"TRK_MINNOW_DOLPHIN::@40": 0x803ab560,
		"TRK_MINNOW_DOLPHIN::gTRKMemMap": 0x803ab580,
		"gTRKMemMap": 0x803ab580,
		"TRK_MINNOW_DOLPHIN::@233": 0x803ab590,
		"@233": 0x803ab590,
		"TRK_MINNOW_DOLPHIN::@238": 0x803ab5a4,
		"@238": 0x803ab5a4,
		"TRK_MINNOW_DOLPHIN::@243": 0x803ab5b8,
		"@243": 0x803ab5b8,
		"thp::__THPJpegNaturalOrder": 0x803ab5d0,
		"__THPJpegNaturalOrder": 0x803ab5d0,
		"MarioUtil::@2036": 0x8039d828,
		"MarioUtil::@2195": 0x8039d834,
		"MarioUtil::@3559": 0x8039d844,
		"MarioUtil::lightName$1906": 0x8039d874,
		"lightName$1906": 0x8039d874,
		"MarioUtil::ambName$1907": 0x8039d888,
		"ambName$1907": 0x8039d888,
		"MarioUtil::lightName$1917": 0x8039d8a8,
		"lightName$1917": 0x8039d8a8,
		"MarioUtil::ambName$1918": 0x8039d8c0,
		"ambName$1918": 0x8039d8c0,
		"MarioUtil::lightName$1928": 0x8039d8e4,
		"lightName$1928": 0x8039d8e4,
		"MarioUtil::ambName$1929": 0x8039d8fc,
		"ambName$1929": 0x8039d8fc,
		"MarioUtil::@1931": 0x8039d920,
		"MarioUtil::@1932": 0x8039d934,
		"MarioUtil::lightName$1942": 0x8039d948,
		"lightName$1942": 0x8039d948,
		"MarioUtil::ambName$1943": 0x8039d960,
		"ambName$1943": 0x8039d960,
		"MarioUtil::@1945": 0x8039d984,
		"MarioUtil::@1946": 0x8039d998,
		"MarioUtil::@2007": 0x8039d9ac,
		"MarioUtil::@2223": 0x8039d9c4,
		"MarioUtil::@2224": 0x8039d9d8,
		"MarioUtil::@2225": 0x8039d9f0,
		"MarioUtil::@2296": 0x8039da2c,
		"MarioUtil::@2477": 0x8039da3c,
		"MarioUtil::@2843": 0x8039da4c,
		"MarioUtil::@1819": 0x8039da6c,
		"MarioUtil::@1820": 0x8039da78,
		"MarioUtil::@1846": 0x8039da88,
		"@1846": 0x8039da88,
		"MarioUtil::@2544": 0x8039da94,
		"MarioUtil::@2545": 0x8039daa8,
		"MarioUtil::@2546": 0x8039dab4,
		"MarioUtil::@2547": 0x8039dac0,
		"MarioUtil::@2548": 0x8039dacc,
		"MarioUtil::@2549": 0x8039dad8,
		"MarioUtil::@2556": 0x8039dae4,
		"MarioUtil::@1831": 0x8039daf0,
		"MarioUtil::@1809": 0x8039db14,
		"MarioUtil::@1974": 0x8039db28,
		"MarioUtil::@1975": 0x8039db38,
		"MarioUtil::@2149": 0x8039db48,
		"MarioUtil::@2150": 0x8039db6c,
		"MarioUtil::calctablex$2412": 0x8039db90,
		"calctablex$2412": 0x8039db90,
		"MarioUtil::calctablez$2413": 0x8039dba0,
		"calctablez$2413": 0x8039dba0,
		"MarioUtil::@4135": 0x8039dbb0,
		"MarioUtil::@4136": 0x8039dbcc,
		"MarioUtil::@4137": 0x8039dbe8,
		"MarioUtil::@4138": 0x8039dc00,
		"MarioUtil::@17": 0x8039dc18,
		"MarioUtil::@18": 0x8039dce8,
		"MarioUtil::@19": 0x8039dcf8,
		"@19": 0x8039dcf8,
		"MarioUtil::@20": 0x8039dd08,
		"@20": 0x8039dd08,
		"MarioUtil::@21": 0x8039dd18,
		"@21": 0x8039dd18,
		"MarioUtil::@22": 0x8039dd2c,
		"MarioUtil::@23": 0x8039dd40,
		"@23": 0x8039dd40,
		"MarioUtil::@24": 0x8039dd50,
		"@24": 0x8039dd50,
		"MarioUtil::@25": 0x8039dd60,
		"MarioUtil::@26": 0x8039dd70,
		"@26": 0x8039dd70,
		"MarioUtil::@27": 0x8039dd80,
		"@27": 0x8039dd80,
		"MarioUtil::@28": 0x8039dd94,
		"MarioUtil::@29": 0x8039dda4,
		"@29": 0x8039dda4,
		"MarioUtil::@30": 0x8039ddb4,
		"MarioUtil::@31": 0x8039ddc4,
		"MarioUtil::@32": 0x8039ddd4,
		"MarioUtil::@33": 0x8039dde4,
		"MarioUtil::@34": 0x8039ddf4,
		"MarioUtil::@35": 0x8039de04,
		"MarioUtil::@36": 0x8039de14,
		"MarioUtil::@37": 0x8039de24,
		"MarioUtil::@38": 0x8039de34,
		"MarioUtil::@39": 0x8039de40,
		"MarioUtil::@40": 0x8039de4c,
		"MarioUtil::@66": 0x8039de64,
		"System::@1664": 0x803a1e70,
		"System::@1711": 0x803a1e7c,
		"System::prmarray$2214": 0x803a1e90,
		"prmarray$2214": 0x803a1e90,
		"System::envarray$2215": 0x803a1ea8,
		"envarray$2215": 0x803a1ea8,
		"System::@2200": 0x803a1ee0,
		"System::@2201": 0x803a1f10,
		"System::@2202": 0x803a1f48,
		"System::@2203": 0x803a1f7c,
		"System::@2728": 0x803a1fa0,
		"System::@3708": 0x803a2090,
		"System::@3709": 0x803a20a0,
		"System::@3710": 0x803a20b4,
		"System::@3711": 0x803a20c4,
		"System::@3712": 0x803a20d0,
		"System::@3713": 0x803a20e0,
		"System::@3714": 0x803a20f0,
		"System::@3715": 0x803a20fc,
		"System::@3716": 0x803a2114,
		"System::@3717": 0x803a212c,
		"System::@3718": 0x803a213c,
		"System::@3719": 0x803a2150,
		"System::@3720": 0x803a2164,
		"System::@3721": 0x803a2178,
		"System::@3722": 0x803a218c,
		"System::@3723": 0x803a21a0,
		"System::@3724": 0x803a21b0,
		"System::@3725": 0x803a21c4,
		"System::@3726": 0x803a21e0,
		"System::@3727": 0x803a21ec,
		"System::@3728": 0x803a2200,
		"System::@3729": 0x803a2210,
		"System::@3730": 0x803a2220,
		"System::@3731": 0x803a222c,
		"System::@3732": 0x803a2240,
		"System::@3733": 0x803a2258,
		"System::@3734": 0x803a2268,
		"System::@3735": 0x803a2280,
		"System::@3736": 0x803a2298,
		"System::@3737": 0x803a22b4,
		"System::@3738": 0x803a22c8,
		"System::@3739": 0x803a22e0,
		"System::@3740": 0x803a22f8,
		"System::@3741": 0x803a230c,
		"System::@3742": 0x803a2324,
		"System::@3743": 0x803a2334,
		"System::@3744": 0x803a2344,
		"System::@3745": 0x803a2350,
		"System::@3746": 0x803a235c,
		"System::@3747": 0x803a236c,
		"System::@3748": 0x803a2378,
		"System::@3750": 0x803a238c,
		"System::@3751": 0x803a2398,
		"System::@3752": 0x803a23a8,
		"System::@2396": 0x803a2824,
		"System::@2397": 0x803a2830,
		"System::@2399": 0x803a283c,
		"System::@1701": 0x803a2a74,
		"System::@1784": 0x803a2a88,
		"System::@1785": 0x803a2ab8,
		"System::@1786": 0x803a2af0,
		"System::@1787": 0x803a2b24,
		"System::@2388": 0x803a2b68,
		"System::@2732": 0x803a2b80,
		"System::@2733": 0x803a2b94,
		"System::@2734": 0x803a2ba8,
		"System::@2735": 0x803a2bb8,
		"System::@2736": 0x803a2bc4,
		"System::@2737": 0x803a2bd0,
		"System::@2743": 0x803a2be0,
		"System::@2744": 0x803a2bec,
		"System::@2746": 0x803a2c14,
		"System::@2747": 0x803a2c28,
		"System::@2748": 0x803a2c34,
		"System::@2749": 0x803a2c44,
		"System::@2750": 0x803a2c54,
		"System::@2751": 0x803a2c64,
		"System::@2810": 0x803a2c74,
		"System::@2811": 0x803a2c84,
		"System::@2971": 0x803a2c90,
		"System::@2972": 0x803a2ca0,
		"System::@2973": 0x803a2cb0,
		"System::@2974": 0x803a2cc0,
		"System::@1615": 0x803a2d24,
		"System::@1616": 0x803a2d3c,
		"System::@1617": 0x803a2d50,
		"System::@1620": 0x803a2d7c,
		"System::@1621": 0x803a2d8c,
		"System::@1622": 0x803a2d98,
		"System::@1623": 0x803a2da8,
		"System::@1624": 0x803a2db8,
		"System::@1625": 0x803a2dd8,
		"System::@1627": 0x803a2df8,
		"System::@1628": 0x803a2e18,
		"System::@1629": 0x803a2e38,
		"System::@1630": 0x803a2e4c,
		"System::@1631": 0x803a2e5c,
		"System::@1638": 0x803a2ed8,
		"System::@1639": 0x803a2eec,
		"System::@1640": 0x803a2f04,
		"System::@1641": 0x803a2f1c,
		"System::@1642": 0x803a2f30,
		"System::@2205": 0x803a2f68,
		"System::@2206": 0x803a2f98,
		"System::@2207": 0x803a2fd0,
		"System::@2208": 0x803a3004,
		"System::@2694": 0x803a3028,
		"@unnamed@::cDispExceptionCommand": 0x803a3140,
		"cDispExceptionCommand": 0x803a3140,
		"System::@2117": 0x803a3174,
		"System::@2174": 0x803a31b8,
		"System::@2175": 0x803a31f0,
		"System::@2176": 0x803a3224,
		"System::@4634": 0x803a3324,
		"System::@4635": 0x803a3334,
		"System::@4636": 0x803a3340,
		"System::@4637": 0x803a3350,
		"System::@4638": 0x803a335c,
		"System::@4639": 0x803a3368,
		"System::@4640": 0x803a3380,
		"System::@4641": 0x803a338c,
		"System::@4642": 0x803a33a8,
		"System::@4643": 0x803a33b8,
		"System::@4644": 0x803a33c4,
		"System::@4645": 0x803a33d0,
		"System::@4646": 0x803a33dc,
		"System::@4647": 0x803a33ec,
		"System::@4648": 0x803a3400,
		"System::@4649": 0x803a3414,
		"System::@4650": 0x803a3420,
		"System::@4651": 0x803a3430,
		"System::@4653": 0x803a3440,
		"System::@4654": 0x803a344c,
		"System::@4655": 0x803a3458,
		"System::@4656": 0x803a3464,
		"System::@4657": 0x803a3474,
		"System::@4658": 0x803a3488,
		"System::@4659": 0x803a34a0,
		"System::@4660": 0x803a34b0,
		"System::@4662": 0x803a34d0,
		"System::@4663": 0x803a34e0,
		"System::@4671": 0x803a3544,
		"System::@4672": 0x803a3554,
		"System::@4675": 0x803a356c,
		"System::@4676": 0x803a3578,
		"@4676": 0x803a3578,
		"System::@4677": 0x803a3588,
		"System::@4678": 0x803a3594,
		"System::@4679": 0x803a35a4,
		"@4679": 0x803a35a4,
		"System::@4680": 0x803a35b0,
		"System::@4681": 0x803a35bc,
		"System::@4683": 0x803a35d4,
		"System::@4684": 0x803a35e4,
		"System::@4685": 0x803a35f0,
		"System::@4686": 0x803a3600,
		"System::@4687": 0x803a360c,
		"System::@4688": 0x803a3624,
		"System::@4689": 0x803a3630,
		"System::@4690": 0x803a3640,
		"System::@4691": 0x803a364c,
		"System::@4692": 0x803a365c,
		"System::@4693": 0x803a3668,
		"System::@4694": 0x803a3674,
		"System::@4695": 0x803a3680,
		"System::@4698": 0x803a368c,
		"System::@4699": 0x803a3698,
		"System::@4700": 0x803a36a4,
		"System::@4701": 0x803a36b0,
		"System::@4702": 0x803a36bc,
		"System::@4704": 0x803a36c8,
		"System::@4707": 0x803a3700,
		"System::@4708": 0x803a370c,
		"System::@4709": 0x803a3728,
		"System::@4710": 0x803a3734,
		"@4710": 0x803a3734,
		"System::@4711": 0x803a374c,
		"@4711": 0x803a374c,
		"System::@4713": 0x803a376c,
		"@4713": 0x803a376c,
		"System::@4714": 0x803a3778,
		"@4714": 0x803a3778,
		"System::@4715": 0x803a3790,
		"@4715": 0x803a3790,
		"System::@4716": 0x803a379c,
		"System::@4717": 0x803a37b4,
		"System::@4718": 0x803a37c0,
		"System::@4719": 0x803a37d8,
		"System::@4720": 0x803a37e4,
		"System::@4721": 0x803a37fc,
		"System::@4722": 0x803a380c,
		"System::@4723": 0x803a3830,
		"System::@4724": 0x803a3840,
		"System::@4725": 0x803a3864,
		"System::@4726": 0x803a387c,
		"System::@4727": 0x803a3890,
		"System::@4728": 0x803a38b0,
		"System::@4729": 0x803a38cc,
		"System::@4730": 0x803a38e4,
		"System::@4731": 0x803a38fc,
		"System::@4732": 0x803a3910,
		"System::@4733": 0x803a391c,
		"System::@4734": 0x803a3930,
		"System::@4735": 0x803a3950,
		"System::@4736": 0x803a3968,
		"System::@4737": 0x803a3984,
		"System::@4738": 0x803a399c,
		"System::@4739": 0x803a39bc,
		"System::@4740": 0x803a39d4,
		"System::@4742": 0x803a39e8,
		"System::@4743": 0x803a39fc,
		"System::@4744": 0x803a3a18,
		"System::@4745": 0x803a3a30,
		"System::@4746": 0x803a3a48,
		"System::@4747": 0x803a3a58,
		"System::@4748": 0x803a3a6c,
		"System::@4749": 0x803a3a78,
		"System::@4751": 0x803a3a98,
		"System::@4752": 0x803a3aac,
		"System::@4753": 0x803a3ac0,
		"System::@4754": 0x803a3ad8,
		"System::@4755": 0x803a3aec,
		"System::@4756": 0x803a3afc,
		"System::@4759": 0x803a3b10,
		"System::@4760": 0x803a3b20,
		"System::@4761": 0x803a3b34,
		"System::@4762": 0x803a3b4c,
		"System::@4763": 0x803a3b5c,
		"System::@4764": 0x803a3b70,
		"System::@4765": 0x803a3b8c,
		"System::@4768": 0x803a3bc0,
		"System::@4769": 0x803a3bd0,
		"System::@4770": 0x803a3be4,
		"System::@4771": 0x803a3bf8,
		"System::@4772": 0x803a3c04,
		"System::@4773": 0x803a3c14,
		"System::@4774": 0x803a3c28,
		"System::@4775": 0x803a3c34,
		"System::@4776": 0x803a3c40,
		"System::@4777": 0x803a3c54,
		"System::@4778": 0x803a3c68,
		"System::@4779": 0x803a3c74,
		"System::@4780": 0x803a3c84,
		"System::@4781": 0x803a3c94,
		"System::@4782": 0x803a3ca4,
		"System::@4783": 0x803a3cb0,
		"System::@4784": 0x803a3cc0,
		"System::@4785": 0x803a3ccc,
		"System::@4786": 0x803a3cdc,
		"System::@2838": 0x803a3d80,
		"System::@2842": 0x803a3d8c,
		"System::@2843": 0x803a3d98,
		"System::@2854": 0x803a3da4,
		"System::@2857": 0x803a3dc0,
		"System::@2858": 0x803a3dd0,
		"System::SceneParamsDir": 0x803a3ed0,
		"SceneParamsDir": 0x803a3ed0,
		"System::@1525": 0x803a3eec,
		"System::@2003": 0x803a3fc0,
		"System::@2004": 0x803a3fd4,
		"System::@2005": 0x803a3ff4,
		"System::@2006": 0x803a4000,
		"System::@2573": 0x803a4030,
		"System::@1726": 0x803a431c,
		"@1726": 0x803a431c,
		"System::@1958": 0x803a43cc,
		"System::@1959": 0x803a4400,
		"System::@3507": 0x803a45fc,
		"System::@3508": 0x803a4614,
		"System::@3509": 0x803a4634,
		"System::@3510": 0x803a4644,
		"System::@3515": 0x803a4694,
		"System::@3516": 0x803a46ac,
		"System::@3521": 0x803a473c,
		"System::@3522": 0x803a474c,
		"System::@3523": 0x803a4764,
		"System::@3524": 0x803a4778,
		"System::@3525": 0x803a4784,
		"System::@3526": 0x803a479c,
		"System::@3527": 0x803a47b8,
		"System::@3528": 0x803a47c8,
		"System::@3529": 0x803a47d8,
		"System::@3530": 0x803a47ec,
		"System::@3531": 0x803a4808,
		"System::@3532": 0x803a4818,
		"System::@3533": 0x803a4828,
		"System::@3534": 0x803a4834,
		"System::@3535": 0x803a4844,
		"System::@3536": 0x803a4858,
		"System::@3537": 0x803a4870,
		"System::@3538": 0x803a487c,
		"System::@3539": 0x803a488c,
		"System::@3540": 0x803a4898,
		"System::@3541": 0x803a48a8,
		"System::@3542": 0x803a48bc,
		"System::@3543": 0x803a48d8,
		"System::@3544": 0x803a48ec,
		"System::@3545": 0x803a4908,
		"System::@3546": 0x803a4914,
		"System::@3547": 0x803a4920,
		"System::@3548": 0x803a4934,
		"System::@3549": 0x803a494c,
		"System::@3550": 0x803a495c,
		"System::@3553": 0x803a4970,
		"System::@3554": 0x803a497c,
		"System::@3555": 0x803a4988,
		"System::@3556": 0x803a499c,
		"System::@3922": 0x803a4acc,
		"System::@3924": 0x803a4ad8,
		"System::@3925": 0x803a4aec,
		"System::@3926": 0x803a4b00,
		"System::@3927": 0x803a4b10,
		"System::@3928": 0x803a4b2c,
		"System::@3929": 0x803a4b38,
		"System::@3930": 0x803a4b48,
		"System::@3933": 0x803a4b6c,
		"System::@3934": 0x803a4b80,
		"System::@3935": 0x803a4b9c,
		"System::@3936": 0x803a4bb0,
		"System::@3938": 0x803a4bd8,
		"System::@3940": 0x803a4be4,
		"System::@3941": 0x803a4bf0,
		"System::@3942": 0x803a4bfc,
		"System::@3943": 0x803a4c0c,
		"System::@3944": 0x803a4c20,
		"System::@3945": 0x803a4c3c,
		"System::@3946": 0x803a4c48,
		"System::@3947": 0x803a4c54,
		"System::@3948": 0x803a4c60,
		"System::@3949": 0x803a4c6c,
		"System::@3950": 0x803a4c78,
		"System::@3951": 0x803a4c84,
		"System::@3952": 0x803a4c90,
		"System::@3956": 0x803a4cc0,
		"System::@3957": 0x803a4cd0,
		"System::@3959": 0x803a4cf8,
		"System::@3961": 0x803a4d04,
		"System::@3963": 0x803a4d10,
		"System::@3965": 0x803a4d1c,
		"System::@3967": 0x803a4d30,
		"System::@3968": 0x803a4d40,
		"System::@3969": 0x803a4d54,
		"System::@3970": 0x803a4d68,
		"System::@3971": 0x803a4d78,
		"System::@3972": 0x803a4d98,
		"System::@3973": 0x803a4db0,
		"System::@3974": 0x803a4dcc,
		"System::@3975": 0x803a4de8,
		"System::@3976": 0x803a4e08,
		"System::@3977": 0x803a4e20,
		"System::@3978": 0x803a4e3c,
		"System::@3979": 0x803a4e54,
		"System::@3980": 0x803a4e70,
		"System::@3981": 0x803a4e84,
		"System::@3982": 0x803a4ea0,
		"System::@3983": 0x803a4eac,
		"System::@3984": 0x803a4ebc,
		"System::@3985": 0x803a4ecc,
		"System::@3986": 0x803a4ee8,
		"System::@3987": 0x803a4ef8,
		"System::@3991": 0x803a4f3c,
		"System::@3992": 0x803a4f58,
		"System::@3993": 0x803a4f68,
		"System::@3994": 0x803a4f78,
		"System::@3995": 0x803a4f88,
		"System::@3996": 0x803a4f98,
		"System::@3997": 0x803a4fac,
		"System::@3998": 0x803a4fc8,
		"System::@3999": 0x803a4fd8,
		"System::@4000": 0x803a4fe8,
		"System::@4001": 0x803a5000,
		"System::@4002": 0x803a501c,
		"System::@4003": 0x803a5038,
		"System::@4004": 0x803a5058,
		"System::@4005": 0x803a506c,
		"System::@4006": 0x803a5080,
		"System::@4007": 0x803a5094,
		"System::@4008": 0x803a50ac,
		"System::@4009": 0x803a50bc,
		"System::@4010": 0x803a50c8,
		"System::@4014": 0x803a5118,
		"System::@4015": 0x803a5128,
		"System::@4016": 0x803a5140,
		"System::@4017": 0x803a514c,
		"System::@4018": 0x803a5158,
		"System::@4019": 0x803a5174,
		"System::@4021": 0x803a51a0,
		"System::@4023": 0x803a51b8,
		"System::@4024": 0x803a51c4,
		"System::@4025": 0x803a51d0,
		"System::@4026": 0x803a51e0,
		"System::@4027": 0x803a51f4,
		"System::@4028": 0x803a520c,
		"System::@4029": 0x803a5218,
		"System::@4030": 0x803a5224,
		"System::@4031": 0x803a5238,
		"System::@4032": 0x803a5254,
		"System::@4033": 0x803a5260,
		"System::@4034": 0x803a5270,
		"System::@4035": 0x803a5280,
		"System::@4036": 0x803a5294,
		"System::@4037": 0x803a52a8,
		"System::@4038": 0x803a52c4,
		"System::@4039": 0x803a52d0,
		"System::@4044": 0x803a5300,
		"System::@4045": 0x803a5310,
		"System::@4047": 0x803a5338,
		"System::@4049": 0x803a5350,
		"System::@4050": 0x803a535c,
		"System::@4051": 0x803a5368,
		"System::@4052": 0x803a5378,
		"System::@4054": 0x803a5394,
		"System::@4055": 0x803a53a8,
		"System::@4056": 0x803a53c4,
		"System::@4057": 0x803a53d0,
		"System::@4058": 0x803a53e0,
		"System::@4059": 0x803a53f4,
		"System::@4060": 0x803a5410,
		"System::@4061": 0x803a5420,
		"System::@4066": 0x803a5454,
		"System::@4067": 0x803a5460,
		"System::@4068": 0x803a546c,
		"System::@4069": 0x803a5478,
		"@4069": 0x803a5478,
		"System::@4070": 0x803a5488,
		"System::@4071": 0x803a5494,
		"@4071": 0x803a5494,
		"System::@4072": 0x803a54a0,
		"System::@4073": 0x803a54b4,
		"System::@4074": 0x803a54c8,
		"System::@4075": 0x803a54dc,
		"System::@4077": 0x803a5500,
		"System::@4079": 0x803a551c,
		"System::@4088": 0x803a55a0,
		"System::@4089": 0x803a55b4,
		"System::@4090": 0x803a55d4,
		"System::@4091": 0x803a55e0,
		"System::@4092": 0x803a55f4,
		"System::@4093": 0x803a5610,
		"System::@4094": 0x803a562c,
		"System::@4095": 0x803a5640,
		"System::@4096": 0x803a5650,
		"System::@4097": 0x803a5668,
		"System::@4098": 0x803a5684,
		"System::@4099": 0x803a5698,
		"System::@4100": 0x803a56a8,
		"System::@4101": 0x803a56b8,
		"System::@4102": 0x803a56d0,
		"System::@4103": 0x803a56e0,
		"System::@4105": 0x803a5704,
		"System::@4107": 0x803a5710,
		"System::@4108": 0x803a571c,
		"System::@4109": 0x803a572c,
		"System::@4110": 0x803a5750,
		"System::@4111": 0x803a575c,
		"System::@4112": 0x803a5774,
		"System::@4113": 0x803a5784,
		"System::@4114": 0x803a57a0,
		"System::@4115": 0x803a57ac,
		"System::@4117": 0x803a57cc,
		"@4117": 0x803a57cc,
		"System::@4135": 0x803a586c,
		"System::@4137": 0x803a5884,
		"System::@4138": 0x803a5890,
		"System::@4139": 0x803a58a8,
		"System::@4140": 0x803a58c8,
		"System::@4141": 0x803a58d8,
		"System::@4142": 0x803a58ec,
		"System::@4143": 0x803a58fc,
		"System::@4144": 0x803a5910,
		"System::@4145": 0x803a5928,
		"System::@4146": 0x803a5948,
		"System::@4147": 0x803a5954,
		"System::@4148": 0x803a596c,
		"System::@4150": 0x803a599c,
		"System::@4152": 0x803a59a8,
		"System::@4153": 0x803a59b4,
		"System::@4154": 0x803a59c8,
		"System::@4155": 0x803a59dc,
		"System::@4175": 0x803a5b44,
		"System::@4177": 0x803a5b5c,
		"System::@4179": 0x803a5b78,
		"System::@1723": 0x803a5c3c,
		"System::@1779": 0x803a5c50,
		"System::@1780": 0x803a5c80,
		"System::@1781": 0x803a5cb8,
		"System::@1782": 0x803a5cec,
		"System::@2095": 0x803a5d4c,
		"System::@2096": 0x803a5d58,
		"System::@2097": 0x803a5d64,
		"@2097": 0x803a5d64,
		"System::@2098": 0x803a5d70,
		"System::@2099": 0x803a5d80,
		"System::@2105": 0x803a5dc0,
		"System::@2106": 0x803a5dcc,
		"System::@2107": 0x803a5dd8,
		"System::@1752": 0x803a5dfc,
		"System::@1808": 0x803a5e10,
		"System::@1810": 0x803a5e78,
		"System::@1811": 0x803a5eac,
		"System::@2364": 0x803a5ed0,
		"System::@2366": 0x803a5edc,
		"System::@4994": 0x803a5ee8,
		"System::@4995": 0x803a5ef4,
		"System::@4996": 0x803a5f08,
		"System::@4997": 0x803a5f18,
		"System::@4999": 0x803a5f2c,
		"System::@5001": 0x803a5f38,
		"System::@5002": 0x803a5f48,
		"System::@5003": 0x803a5f54,
		"System::@5004": 0x803a5f60,
		"System::@5005": 0x803a5f74,
		"System::@5006": 0x803a5f80,
		"System::@5007": 0x803a5f90,
		"System::@5009": 0x803a5fb4,
		"System::@5010": 0x803a5fc8,
		"System::@5011": 0x803a5fd8,
		"System::@5012": 0x803a5fe8,
		"System::@5014": 0x803a6010,
		"System::@5016": 0x803a6034,
		"System::@5018": 0x803a6058,
		"System::@5020": 0x803a607c,
		"System::@5021": 0x803a608c,
		"System::@5023": 0x803a60a0,
		"System::@5024": 0x803a60b4,
		"System::@5025": 0x803a60c0,
		"System::@5026": 0x803a60cc,
		"System::@5028": 0x803a60d8,
		"System::@5030": 0x803a60e4,
		"System::@5034": 0x803a6104,
		"System::@5035": 0x803a6118,
		"System::@5036": 0x803a612c,
		"@5036": 0x803a612c,
		"System::@5038": 0x803a6150,
		"System::@5040": 0x803a6180,
		"@5040": 0x803a6180,
		"System::@5041": 0x803a61a4,
		"System::@5042": 0x803a61b4,
		"System::@5047": 0x803a61f4,
		"System::@5048": 0x803a6208,
		"System::@5049": 0x803a6218,
		"System::@5050": 0x803a6224,
		"System::@5054": 0x803a6244,
		"System::@5055": 0x803a6258,
		"System::@5056": 0x803a626c,
		"System::@5062": 0x803a6284,
		"@5062": 0x803a6284,
		"System::@5065": 0x803a62b0,
		"@5065": 0x803a62b0,
		"System::@5067": 0x803a62c0,
		"@5067": 0x803a62c0,
		"System::@5068": 0x803a62cc,
		"@5068": 0x803a62cc,
		"System::@5069": 0x803a62e4,
		"@5069": 0x803a62e4,
		"System::@5070": 0x803a62f0,
		"System::@5071": 0x803a6308,
		"System::@5072": 0x803a6314,
		"System::@5073": 0x803a6324,
		"System::@5076": 0x803a6330,
		"System::@5079": 0x803a633c,
		"@5079": 0x803a633c,
		"System::@5080": 0x803a6354,
		"System::@5081": 0x803a6368,
		"System::@5082": 0x803a6378,
		"@5082": 0x803a6378,
		"System::@5083": 0x803a638c,
		"System::@5084": 0x803a639c,
		"System::@5085": 0x803a63b0,
		"System::@5087": 0x803a63d0,
		"System::@5090": 0x803a63f8,
		"System::@5091": 0x803a640c,
		"System::@5092": 0x803a6420,
		"System::@5093": 0x803a643c,
		"System::@5094": 0x803a6448,
		"System::@5095": 0x803a6458,
		"System::@5096": 0x803a6468,
		"System::@5097": 0x803a6474,
		"System::@5098": 0x803a6484,
		"System::@5099": 0x803a6490,
		"System::@5104": 0x803a64a8,
		"System::@5105": 0x803a64b4,
		"@5105": 0x803a64b4,
		"System::@5106": 0x803a64c0,
		"@5106": 0x803a64c0,
		"System::@5107": 0x803a64cc,
		"@5107": 0x803a64cc,
		"System::@5109": 0x803a64e8,
		"System::@5111": 0x803a6504,
		"System::@5112": 0x803a6510,
		"System::@5113": 0x803a6520,
		"System::@5114": 0x803a6530,
		"System::@5117": 0x803a653c,
		"System::@5118": 0x803a6550,
		"System::@5120": 0x803a656c,
		"System::@5121": 0x803a6578,
		"System::@5123": 0x803a6584,
		"System::@5124": 0x803a6594,
		"System::@5125": 0x803a65ac,
		"System::@5126": 0x803a65bc,
		"System::@5128": 0x803a65e0,
		"System::@5129": 0x803a65f0,
		"System::@5134": 0x803a663c,
		"System::@5135": 0x803a664c,
		"System::@5136": 0x803a6660,
		"System::@5137": 0x803a666c,
		"System::@5138": 0x803a6680,
		"System::@5139": 0x803a668c,
		"System::@5140": 0x803a669c,
		"@5140": 0x803a669c,
		"System::@5142": 0x803a66a8,
		"System::@5143": 0x803a66b8,
		"System::@5144": 0x803a66c4,
		"System::@5145": 0x803a66d4,
		"System::@5146": 0x803a66e4,
		"System::@5148": 0x803a6704,
		"System::@5149": 0x803a6710,
		"System::@5150": 0x803a671c,
		"@5150": 0x803a671c,
		"System::@5151": 0x803a6728,
		"System::@5152": 0x803a673c,
		"System::@5157": 0x803a6788,
		"System::@5158": 0x803a679c,
		"System::@5159": 0x803a67ac,
		"System::@5160": 0x803a67c0,
		"System::@5162": 0x803a67d4,
		"@5162": 0x803a67d4,
		"System::@5163": 0x803a67e0,
		"System::@5164": 0x803a67f0,
		"System::@5165": 0x803a6804,
		"System::@5166": 0x803a6814,
		"System::@5167": 0x803a682c,
		"System::@5168": 0x803a6844,
		"System::@5169": 0x803a6854,
		"@5169": 0x803a6854,
		"System::@5170": 0x803a6860,
		"System::@5171": 0x803a6870,
		"@5171": 0x803a6870,
		"System::@5172": 0x803a6880,
		"System::@5173": 0x803a6894,
		"System::@5174": 0x803a68a4,
		"System::@5175": 0x803a68b4,
		"System::@5177": 0x803a68d8,
		"System::@5179": 0x803a68f0,
		"System::@5180": 0x803a6900,
		"System::@5181": 0x803a6914,
		"System::@5182": 0x803a6924,
		"System::@5183": 0x803a6938,
		"System::@5184": 0x803a6944,
		"System::@5186": 0x803a6960,
		"System::@5187": 0x803a696c,
		"System::@5188": 0x803a6978,
		"System::@5189": 0x803a6988,
		"System::@5193": 0x803a69b8,
		"System::@5195": 0x803a69c4,
		"System::@5196": 0x803a69d8,
		"System::@5197": 0x803a69ec,
		"System::@5198": 0x803a69fc,
		"System::@5199": 0x803a6a08,
		"System::@5200": 0x803a6a18,
		"@5200": 0x803a6a18,
		"System::@5202": 0x803a6a28,
		"System::@5203": 0x803a6a38,
		"System::@5204": 0x803a6a48,
		"System::@5205": 0x803a6a5c,
		"@5205": 0x803a6a5c,
		"System::@5208": 0x803a6a68,
		"System::@5209": 0x803a6a74,
		"System::@5210": 0x803a6a80,
		"System::@5211": 0x803a6a90,
		"@5211": 0x803a6a90,
		"System::@5213": 0x803a6aac,
		"System::@5214": 0x803a6abc,
		"System::@5215": 0x803a6acc,
		"System::@5216": 0x803a6ae0,
		"System::@5217": 0x803a6aec,
		"System::@5218": 0x803a6afc,
		"System::@5219": 0x803a6b08,
		"System::@5220": 0x803a6b18,
		"System::@5222": 0x803a6b34,
		"System::@5224": 0x803a6b44,
		"System::@5225": 0x803a6b50,
		"System::@5226": 0x803a6b60,
		"System::@5227": 0x803a6b6c,
		"System::@5229": 0x803a6b78,
		"System::@5230": 0x803a6b8c,
		"System::@5231": 0x803a6b98,
		"System::@5232": 0x803a6ba8,
		"System::@5233": 0x803a6bb4,
		"System::@5234": 0x803a6bc0,
		"System::@5235": 0x803a6bd4,
		"System::@5236": 0x803a6be0,
		"System::@5238": 0x803a6bec,
		"System::@5239": 0x803a6bf8,
		"System::@5240": 0x803a6c04,
		"System::@5241": 0x803a6c18,
		"System::@5242": 0x803a6c24,
		"System::@5243": 0x803a6c30,
		"System::@5244": 0x803a6c3c,
		"System::@5246": 0x803a6c5c,
		"System::@5248": 0x803a6c80,
		"System::@5249": 0x803a6c94,
		"System::@5250": 0x803a6ca0,
		"System::@5251": 0x803a6cac,
		"System::@5252": 0x803a6cb8,
		"System::@5253": 0x803a6ccc,
		"System::@5254": 0x803a6cdc,
		"System::@5255": 0x803a6ce8,
		"System::@5257": 0x803a6d04,
		"System::@5258": 0x803a6d18,
		"System::@5259": 0x803a6d24,
		"System::@5260": 0x803a6d34,
		"System::@5262": 0x803a6d40,
		"System::@5264": 0x803a6d50,
		"System::@5266": 0x803a6d6c,
		"System::@5267": 0x803a6d78,
		"System::@5268": 0x803a6d88,
		"System::@5270": 0x803a6db0,
		"System::@5271": 0x803a6dc0,
		"System::@5273": 0x803a6dd0,
		"System::@5274": 0x803a6de0,
		"System::@5276": 0x803a6dfc,
		"System::@5277": 0x803a6e08,
		"System::@5278": 0x803a6e18,
		"System::@5279": 0x803a6e24,
		"System::@5280": 0x803a6e34,
		"System::@5282": 0x803a6e40,
		"System::@5283": 0x803a6e50,
		"System::@5288": 0x803a6e88,
		"System::@5289": 0x803a6e98,
		"System::@5290": 0x803a6ea8,
		"System::@5292": 0x803a6eb4,
		"System::@5293": 0x803a6ec0,
		"@5293": 0x803a6ec0,
		"System::@5294": 0x803a6ed0,
		"@5294": 0x803a6ed0,
		"System::@5295": 0x803a6eec,
		"System::@5296": 0x803a6efc,
		"System::@5297": 0x803a6f0c,
		"@5297": 0x803a6f0c,
		"System::@5298": 0x803a6f18,
		"@5298": 0x803a6f18,
		"System::@5301": 0x803a6f34,
		"System::@5304": 0x803a6f40,
		"System::@5306": 0x803a6f58,
		"System::@5307": 0x803a6f64,
		"System::@5308": 0x803a6f70,
		"System::@5309": 0x803a6f7c,
		"System::@5310": 0x803a6f88,
		"System::@5314": 0x803a6fb8,
		"System::@5316": 0x803a6fc4,
		"System::@5318": 0x803a6fdc,
		"System::@5319": 0x803a6fe8,
		"System::@5320": 0x803a6ff8,
		"System::@5322": 0x803a7004,
		"System::@5323": 0x803a7010,
		"System::@5324": 0x803a7028,
		"System::@5325": 0x803a7034,
		"System::@5326": 0x803a7044,
		"System::@5330": 0x803a7054,
		"System::@5331": 0x803a7060,
		"System::@5332": 0x803a706c,
		"System::@5334": 0x803a7078,
		"System::@5335": 0x803a7088,
		"System::@5336": 0x803a7098,
		"System::@5337": 0x803a70ac,
		"System::@5338": 0x803a70bc,
		"System::@5339": 0x803a70cc,
		"System::@5340": 0x803a70e4,
		"System::@5341": 0x803a70f8,
		"System::@5342": 0x803a7108,
		"System::@5343": 0x803a7114,
		"System::@5345": 0x803a7128,
		"@5345": 0x803a7128,
		"System::@5346": 0x803a7134,
		"System::@5347": 0x803a7140,
		"System::@5348": 0x803a7150,
		"System::@5350": 0x803a715c,
		"System::@5351": 0x803a7168,
		"System::@5352": 0x803a7178,
		"System::@2577": 0x803a7380,
		"System::@2578": 0x803a738c,
		"System::@2594": 0x803a744c,
		"System::@2595": 0x803a7458,
		"System::@2596": 0x803a7464,
		"System::@2597": 0x803a7470,
		"System::CardFileName": 0x803a76b0,
		"CardFileName": 0x803a76b0,
		"System::@2155": 0x803a7764,
		"System::@2384": 0x803a7778,
		"System::@3140": 0x803a788c,
		"System::@3141": 0x803a78a0,
		"System::@3142": 0x803a78b4,
		"System::@3143": 0x803a78c8,
		"System::@3144": 0x803a78d8,
		"System::@3145": 0x803a78e8,
		"System::@3146": 0x803a78f8,
		"System::@3147": 0x803a7908,
		"System::@3148": 0x803a7918,
		"System::@3149": 0x803a7928,
		"System::@3150": 0x803a793c,
		"System::@3151": 0x803a7950,
		"System::@3152": 0x803a7964,
		"System::@3153": 0x803a7970,
		"System::@3154": 0x803a7984,
		"System::@3159": 0x803a79e8,
		"System::@3160": 0x803a79fc,
		"System::@3161": 0x803a7a10,
		"System::@3162": 0x803a7a24,
		"System::@3163": 0x803a7a38,
		"System::@3164": 0x803a7a4c,
		"System::@3165": 0x803a7a60,
		"System::@3166": 0x803a7a78,
		"System::@3167": 0x803a7a90,
		"System::@3168": 0x803a7aa4,
		"System::@3169": 0x803a7abc,
		"System::@3170": 0x803a7ad0,
		"System::@3171": 0x803a7ae8,
		"System::@3172": 0x803a7b00,
		"System::@3173": 0x803a7b14,
		"System::@3174": 0x803a7b28,
		"System::@3175": 0x803a7b3c,
		"System::@3176": 0x803a7b54,
		"System::@3177": 0x803a7b6c,
		"System::@3178": 0x803a7b80,
		"System::@3179": 0x803a7b94,
		"System::@3180": 0x803a7ba8,
		"System::@3181": 0x803a7bbc,
		"System::@3182": 0x803a7bd0,
		"System::@3183": 0x803a7be4,
		"System::@3184": 0x803a7bf8,
		"System::@3189": 0x803a7c58,
		"System::@3190": 0x803a7c6c,
		"System::@3191": 0x803a7c80,
		"System::@3192": 0x803a7c94,
		"System::@3193": 0x803a7cac,
		"System::@3194": 0x803a7cc4,
		"System::@3195": 0x803a7cdc,
		"System::@3218": 0x803a7ea0,
		"System::@3219": 0x803a7eb0,
		"System::@3220": 0x803a7ec8,
		"System::@3221": 0x803a7ee0,
		"System::@3222": 0x803a7ef0,
		"System::@3223": 0x803a7f04,
		"System::@3224": 0x803a7f18,
		"System::@3225": 0x803a7f2c,
		"System::@3226": 0x803a7f40,
		"System::@3227": 0x803a7f50,
		"System::@3228": 0x803a7f60,
		"System::@3316": 0x803a83c8,
		"System::@3317": 0x803a83dc,
		"System::@3318": 0x803a83f0,
		"System::@3319": 0x803a8408,
		"System::@3320": 0x803a8420,
		"System::@3321": 0x803a8430,
		"System::@3322": 0x803a8440,
		"System::@3323": 0x803a8450,
		"System::@3324": 0x803a8468,
		"System::@3325": 0x803a8480,
		"System::@3326": 0x803a8498,
		"System::@3327": 0x803a84a8,
		"System::@3328": 0x803a84bc,
		"System::@3329": 0x803a84d0,
		"System::@3330": 0x803a84e4,
		"System::@3331": 0x803a84f8,
		"System::@3332": 0x803a850c,
		"System::@3333": 0x803a8520,
		"System::@3334": 0x803a8534,
		"System::@3335": 0x803a8544,
		"System::@3336": 0x803a855c,
		"System::@3337": 0x803a8570,
		"System::@3338": 0x803a8584,
		"System::@3339": 0x803a8598,
		"System::@3340": 0x803a85a8,
		"System::@3341": 0x803a85bc,
		"System::@3342": 0x803a85d0,
		"System::@3343": 0x803a85e8,
		"System::@3344": 0x803a85fc,
		"System::@3345": 0x803a8614,
		"System::@3346": 0x803a8628,
		"System::@3347": 0x803a863c,
		"System::@3348": 0x803a8650,
		"System::@3349": 0x803a8664,
		"System::@3350": 0x803a8674,
		"System::@3351": 0x803a8688,
		"System::@3352": 0x803a869c,
		"System::@3353": 0x803a86b0,
		"System::@3354": 0x803a86c4,
		"System::@3355": 0x803a86d8,
		"System::@3356": 0x803a86f0,
		"System::@3357": 0x803a8708,
		"System::@3358": 0x803a871c,
		"System::@3359": 0x803a8730,
		"System::@3360": 0x803a8744,
		"System::@3361": 0x803a8758,
		"System::@3362": 0x803a8768,
		"System::@3363": 0x803a877c,
		"System::@3364": 0x803a8790,
		"System::@3365": 0x803a87a0,
		"System::@3366": 0x803a87b0,
		"System::@3367": 0x803a87c4,
		"System::@3368": 0x803a87d4,
		"System::@3369": 0x803a87e8,
		"System::@3370": 0x803a87f8,
		"System::@3371": 0x803a880c,
		"System::@3372": 0x803a8820,
		"System::@3373": 0x803a8838,
		"System::@3374": 0x803a884c,
		"System::@3375": 0x803a8860,
		"System::@3376": 0x803a8870,
		"System::@3377": 0x803a8884,
		"System::@3378": 0x803a8898,
		"System::@3379": 0x803a88ac,
		"System::@3381": 0x803a88d0,
		"System::@3382": 0x803a88e4,
		"System::@3383": 0x803a88f8,
		"System::@3384": 0x803a8908,
		"System::@3385": 0x803a891c,
		"System::@3387": 0x803a8944,
		"System::@3388": 0x803a8958,
		"System::@3389": 0x803a896c,
		"System::@3390": 0x803a8984,
		"System::@1816": 0x803a8dc8,
		"System::@2110": 0x803a8dec,
		"System::@3796": 0x803a90e0,
		"System::@3797": 0x803a90f8,
		"System::@3798": 0x803a9110,
		"System::@3799": 0x803a9128,
		"System::@3800": 0x803a9138,
		"System::@3802": 0x803a9164,
		"System::@3803": 0x803a9174,
		"System::@3805": 0x803a9184,
		"System::@3806": 0x803a9198,
		"System::@3807": 0x803a91a8,
		"System::@3808": 0x803a91bc,
		"System::@3809": 0x803a91cc,
		"System::@1681": 0x803a92c0,
		"System::@1708": 0x803a92ec,
		"System::@1709": 0x803a9304,
		"Strategic::@2836": 0x8039d088,
		"Strategic::@2837": 0x8039d098,
		"Strategic::@1582": 0x8039d0e0,
		"Strategic::@1583": 0x8039d110,
		"Strategic::@1584": 0x8039d148,
		"Strategic::@1585": 0x8039d17c,
		"Strategic::@2148": 0x8039d1f8,
		"Strategic::@1598": 0x8039d228,
		"Strategic::@1599": 0x8039d258,
		"Strategic::@1600": 0x8039d290,
		"Strategic::@1601": 0x8039d2c4,
		"Strategic::@1735": 0x8039d2e8,
		"Strategic::entry$1734": 0x8039d2f4,
		"entry$1734": 0x8039d2f4,
		"Strategic::@1948": 0x8039d310,
		"Strategic::@514": 0x8039d320,
		"@514": 0x8039d320,
		"Strategic::@515": 0x8039d33c,
		"@515": 0x8039d33c,
		"Strategic::@559": 0x8039d360,
		"@559": 0x8039d360,
		"Strategic::@560": 0x8039d384,
		"@560": 0x8039d384,
		"Strategic::@561": 0x8039d3ac,
		"@561": 0x8039d3ac,
		"Strategic::@610": 0x8039d3d0,
		"Strategic::@611": 0x8039d3f4,
		"@611": 0x8039d3f4,
		"Strategic::@612": 0x8039d424,
		"@612": 0x8039d424,
		"Strategic::@654": 0x8039d44c,
		"Strategic::@655": 0x8039d468,
		"Strategic::@725": 0x8039d488,
		"Strategic::@834": 0x8039d4b8,
		"@834": 0x8039d4b8,
		"Strategic::@915": 0x8039d4f0,
		"@915": 0x8039d4f0,
		"Strategic::@916": 0x8039d510,
		"@916": 0x8039d510,
		"Strategic::@917": 0x8039d520,
		"@917": 0x8039d520,
		"Strategic::@918": 0x8039d530,
		"@918": 0x8039d530,
		"Strategic::@919": 0x8039d540,
		"@919": 0x8039d540,
		"Strategic::@920": 0x8039d550,
		"Strategic::@921": 0x8039d560,
		"@921": 0x8039d560,
		"Strategic::@922": 0x8039d574,
		"@922": 0x8039d574,
		"Strategic::@923": 0x8039d58c,
		"@923": 0x8039d58c,
		"Strategic::@924": 0x8039d5a4,
		"@924": 0x8039d5a4,
		"Strategic::@925": 0x8039d5bc,
		"@925": 0x8039d5bc,
		"Strategic::@1000": 0x8039d5f0,
		"@1000": 0x8039d5f0,
		"Strategic::@1071": 0x8039d60c,
		"@1071": 0x8039d60c,
		"Strategic::@1072": 0x8039d628,
		"Strategic::@1078": 0x8039d654,
		"@1078": 0x8039d654,
		"Strategic::@2481": 0x8039d674,
		"Strategic::@2541": 0x8039d694,
		"Strategic::@2620": 0x8039d6bc,
		"Strategic::@1826": 0x8039d6e0,
		"@1826": 0x8039d6e0,
		"Strategic::@2112": 0x8039d70c,
		"Strategic::@2302": 0x8039d720,
		"Strategic::@2303": 0x8039d750,
		"Strategic::@2304": 0x8039d788,
		"Strategic::@2305": 0x8039d7bc,
		"Strategic::@2581": 0x8039d7e0,
		"Player::@1763": 0x8039de84,
		"Player::@1936": 0x8039dfbc,
		"Player::@2446": 0x8039e000,
		"Player::@2447": 0x8039e038,
		"Player::@2448": 0x8039e06c,
		"Player::@2902": 0x8039e1c4,
		"Player::@2903": 0x8039e1d0,
		"Player::@2904": 0x8039e1dc,
		"Player::@2911": 0x8039e218,
		"Player::@2912": 0x8039e224,
		"Player::@2913": 0x8039e230,
		"Player::@2915": 0x8039e24c,
		"Player::@2916": 0x8039e258,
		"Player::@2919": 0x8039e274,
		"Player::@2920": 0x8039e280,
		"Player::@2921": 0x8039e28c,
		"Player::@2922": 0x8039e29c,
		"Player::@2923": 0x8039e2ac,
		"Player::@2924": 0x8039e2b8,
		"Player::@2925": 0x8039e2c8,
		"Player::@2926": 0x8039e2d4,
		"Player::@2928": 0x8039e2f4,
		"Player::@2929": 0x8039e304,
		"Player::@2931": 0x8039e320,
		"Player::@2932": 0x8039e334,
		"Player::@2933": 0x8039e344,
		"Player::@2934": 0x8039e358,
		"Player::@2935": 0x8039e368,
		"Player::@2936": 0x8039e374,
		"Player::@2937": 0x8039e380,
		"Player::@2940": 0x8039e3a0,
		"Player::@2941": 0x8039e3ac,
		"Player::@2944": 0x8039e3d8,
		"Player::@2945": 0x8039e3e8,
		"Player::@2946": 0x8039e3f4,
		"Player::@2950": 0x8039e418,
		"Player::@2960": 0x8039e470,
		"Player::@2961": 0x8039e47c,
		"Player::@2962": 0x8039e488,
		"Player::@5660": 0x8039ea98,
		"Player::@5662": 0x8039eab0,
		"@5662": 0x8039eab0,
		"Player::@5663": 0x8039eabc,
		"@5663": 0x8039eabc,
		"Player::@5665": 0x8039eac8,
		"Player::@5666": 0x8039eae0,
		"Player::@5667": 0x8039eaf8,
		"Player::@5668": 0x8039eb10,
		"Player::@5669": 0x8039eb28,
		"Player::@5670": 0x8039eb40,
		"Player::@5671": 0x8039eb58,
		"@5671": 0x8039eb58,
		"Player::@5672": 0x8039eb70,
		"@5672": 0x8039eb70,
		"Player::@5674": 0x8039eb88,
		"@5674": 0x8039eb88,
		"Player::@5675": 0x8039eba0,
		"@5675": 0x8039eba0,
		"Player::@5676": 0x8039ebc4,
		"Player::@5677": 0x8039ebe0,
		"@5677": 0x8039ebe0,
		"Player::@5678": 0x8039ec0c,
		"@5678": 0x8039ec0c,
		"Player::@5679": 0x8039ec28,
		"Player::cParticleIDs": 0x8039ef0c,
		"cParticleIDs": 0x8039ef0c,
		"Player::warpInEffectIDs": 0x8039ef18,
		"warpInEffectIDs": 0x8039ef18,
		"Player::@1937": 0x8039ef64,
		"Player::@2386": 0x8039f024,
		"Player::@2442": 0x8039f038,
		"Player::@2443": 0x8039f068,
		"Player::@2444": 0x8039f0a0,
		"Player::bodyColor": 0x8039f934,
		"bodyColor": 0x8039f934,
		"Player::@2722": 0x803a004c,
		"Player::@2725": 0x803a006c,
		"Player::@3140": 0x803a0734,
		"Player::@3142": 0x803a0748,
		"Player::@3322": 0x803a09b4,
		"Player::@3324": 0x803a09c0,
		"Player::@3326": 0x803a09cc,
		"Player::@3327": 0x803a09e4,
		"Player::@3328": 0x803a09fc,
		"Player::@3329": 0x803a0a0c,
		"Player::@3330": 0x803a0a1c,
		"Player::@3337": 0x803a0a3c,
		"Player::@3338": 0x803a0a50,
		"Player::@3468": 0x803a0b70,
		"Player::@3469": 0x803a0b80,
		"Player::@3470": 0x803a0b8c,
		"Player::@3472": 0x803a0b9c,
		"Player::@3477": 0x803a0bd4,
		"Player::@3481": 0x803a0c18,
		"Player::@3483": 0x803a0c28,
		"Player::@3559": 0x803a0c88,
		"Player::@3560": 0x803a0c94,
		"Player::@3568": 0x803a0cfc,
		"Player::@3569": 0x803a0d08,
		"Player::@3570": 0x803a0d18,
		"Player::@3572": 0x803a0d2c,
		"Player::@3573": 0x803a0d3c,
		"Player::@3575": 0x803a0d60,
		"Player::@3736": 0x803a0ea0,
		"Player::@3737": 0x803a0eb0,
		"Player::@3739": 0x803a0ec4,
		"Player::@3748": 0x803a0f64,
		"Player::@3752": 0x803a0f98,
		"Player::@3753": 0x803a0fac,
		"Player::@3755": 0x803a0fbc,
		"Player::@3756": 0x803a0fd0,
		"Player::@3761": 0x803a1014,
		"Player::@3762": 0x803a1024,
		"Player::@3764": 0x803a1044,
		"Player::@3765": 0x803a1054,
		"Player::@3768": 0x803a1088,
		"Player::@3971": 0x803a110c,
		"Player::@3973": 0x803a1134,
		"Player::@3975": 0x803a1158,
		"Player::@3976": 0x803a116c,
		"Player::@3977": 0x803a1180,
		"Player::@3978": 0x803a118c,
		"Player::@3979": 0x803a1198,
		"Player::@3980": 0x803a11a8,
		"Player::@3984": 0x803a11d4,
		"Player::@3985": 0x803a11e4,
		"Player::@3986": 0x803a11f4,
		"Player::@3987": 0x803a1204,
		"Player::@3991": 0x803a1234,
		"Player::@3993": 0x803a1258,
		"Player::@3994": 0x803a126c,
		"Player::@3995": 0x803a1280,
		"Player::@3996": 0x803a1290,
		"Player::@3997": 0x803a129c,
		"Player::@3999": 0x803a12a8,
		"Player::@4001": 0x803a12b8,
		"Player::@4002": 0x803a12c8,
		"Player::@4003": 0x803a12d8,
		"Player::@4008": 0x803a1324,
		"Player::@4010": 0x803a1348,
		"Player::@4011": 0x803a1358,
		"Player::@4012": 0x803a1368,
		"Player::@4016": 0x803a13c0,
		"Player::@6516": 0x803a1480,
		"@6516": 0x803a1480,
		"Player::@6517": 0x803a149c,
		"@6517": 0x803a149c,
		"Player::@6518": 0x803a14b8,
		"Player::@6519": 0x803a14d8,
		"Player::@6520": 0x803a1504,
		"Player::@6521": 0x803a1528,
		"Player::@6522": 0x803a1544,
		"Player::@6523": 0x803a1560,
		"Player::@6524": 0x803a1580,
		"Player::@6525": 0x803a15a0,
		"@6525": 0x803a15a0,
		"Player::@6526": 0x803a15c0,
		"@6526": 0x803a15c0,
		"Player::@6527": 0x803a15e0,
		"@6527": 0x803a15e0,
		"Player::@6528": 0x803a15f4,
		"@6528": 0x803a15f4,
		"Player::@6529": 0x803a1608,
		"@6529": 0x803a1608,
		"Player::@6530": 0x803a1624,
		"@6530": 0x803a1624,
		"Player::@6531": 0x803a163c,
		"@6531": 0x803a163c,
		"Player::@6532": 0x803a1654,
		"@6532": 0x803a1654,
		"Player::@6533": 0x803a1674,
		"@6533": 0x803a1674,
		"Player::@6534": 0x803a168c,
		"@6534": 0x803a168c,
		"Player::@6535": 0x803a16ac,
		"@6535": 0x803a16ac,
		"Player::@6536": 0x803a16cc,
		"@6536": 0x803a16cc,
		"Player::@6537": 0x803a16e8,
		"@6537": 0x803a16e8,
		"Player::@6538": 0x803a1700,
		"@6538": 0x803a1700,
		"Player::@6539": 0x803a171c,
		"@6539": 0x803a171c,
		"Player::@6540": 0x803a1734,
		"@6540": 0x803a1734,
		"Player::@6541": 0x803a174c,
		"@6541": 0x803a174c,
		"Player::@6542": 0x803a1764,
		"@6542": 0x803a1764,
		"Player::@6543": 0x803a1778,
		"@6543": 0x803a1778,
		"Player::@6544": 0x803a1794,
		"@6544": 0x803a1794,
		"Player::@6545": 0x803a17ac,
		"@6545": 0x803a17ac,
		"Player::@6546": 0x803a17c8,
		"@6546": 0x803a17c8,
		"Player::@6547": 0x803a17e0,
		"@6547": 0x803a17e0,
		"Player::@6548": 0x803a17f8,
		"Player::@6549": 0x803a1814,
		"Player::@6550": 0x803a1830,
		"Player::@6551": 0x803a184c,
		"@6551": 0x803a184c,
		"Player::@6552": 0x803a1868,
		"Player::@6553": 0x803a1884,
		"Player::@6554": 0x803a18a4,
		"Player::@6555": 0x803a18c0,
		"Player::@6556": 0x803a18dc,
		"@6556": 0x803a18dc,
		"Player::@6557": 0x803a1900,
		"Player::@6558": 0x803a1918,
		"Player::@6559": 0x803a1930,
		"Player::@6560": 0x803a1948,
		"Player::@6561": 0x803a1960,
		"@6561": 0x803a1960,
		"Player::@6562": 0x803a1978,
		"@6562": 0x803a1978,
		"Player::@6563": 0x803a1990,
		"@6563": 0x803a1990,
		"Player::@6564": 0x803a19a8,
		"@6564": 0x803a19a8,
		"Player::@6565": 0x803a19c0,
		"@6565": 0x803a19c0,
		"Player::@6566": 0x803a19d8,
		"@6566": 0x803a19d8,
		"Player::@6567": 0x803a19f0,
		"@6567": 0x803a19f0,
		"Player::@2239": 0x803a1a14,
		"Player::@2297": 0x803a1a90,
		"Player::@2298": 0x803a1ac4,
		"Player::@2665": 0x803a1ae8,
		"Player::@2666": 0x803a1b00,
		"Player::@2667": 0x803a1b18,
		"Player::@2668": 0x803a1b30,
		"Player::@2669": 0x803a1b4c,
		"Player::@2670": 0x803a1b64,
		"Player::@2671": 0x803a1b7c,
		"Player::@2672": 0x803a1b94,
		"Player::@2673": 0x803a1bac,
		"Player::@2674": 0x803a1bc4,
		"Player::@2675": 0x803a1be0,
		"Player::@2676": 0x803a1bf8,
		"Player::@2677": 0x803a1c14,
		"Player::@2678": 0x803a1c30,
		"Player::@2679": 0x803a1c48,
		"Player::@2680": 0x803a1c60,
		"Player::@2681": 0x803a1c78,
		"Player::@3162": 0x803a1c94,
		"Player::@4560": 0x803a1ca0,
		"Player::@4628": 0x803a1cb8,
		"Player::@4630": 0x803a1cf0,
		"Player::@4635": 0x803a1d90,
		"Player::@4636": 0x803a1db4,
		"Player::@4645": 0x803a1dd8,
		"Player::@4646": 0x803a1de4,
		"Player::@4647": 0x803a1df0,
		"Player::@4649": 0x803a1dfc,
		"Player::@4736": 0x803a1e08,
		"Player::@4738": 0x803a1e14,
		"Player::@4741": 0x803a1e20,
		"Player::@4742": 0x803a1e30,
		"Player::@4743": 0x803a1e3c,
		"Player::@4746": 0x803a1e48,
		"Player::@4876": 0x803a1e54,
		"NPC::@2255": 0x80394880,
		"NPC::@2256": 0x803948b0,
		"NPC::@2257": 0x803948e8,
		"NPC::@2258": 0x8039491c,
		"NPC::@2440": 0x80394940,
		"NPC::sIndividualPeachBck$2896": 0x80394950,
		"sIndividualPeachBck$2896": 0x80394950,
		"NPC::sIndividualPeachBtp$2897": 0x80394968,
		"sIndividualPeachBtp$2897": 0x80394968,
		"NPC::sIndividualPeachBck$2904": 0x80394978,
		"sIndividualPeachBck$2904": 0x80394978,
		"NPC::sIndividualPeachBtp$2905": 0x80394988,
		"sIndividualPeachBtp$2905": 0x80394988,
		"NPC::sIndividualSunflowerBck$2906": 0x80394998,
		"sIndividualSunflowerBck$2906": 0x80394998,
		"NPC::sIndividualSunflowerBtp$2907": 0x803949b0,
		"sIndividualSunflowerBtp$2907": 0x803949b0,
		"NPC::@2053": 0x80394a84,
		"NPC::entry$2229": 0x80394c58,
		"entry$2229": 0x80394c58,
		"NPC::@2236": 0x80394cb0,
		"NPC::@2237": 0x80394cc0,
		"NPC::entry$2231": 0x80394cd0,
		"entry$2231": 0x80394cd0,
		"NPC::entry$2335": 0x80394d34,
		"entry$2335": 0x80394d34,
		"NPC::entry$2337": 0x80394d5c,
		"entry$2337": 0x80394d5c,
		"NPC::entry$2339": 0x80394d84,
		"entry$2339": 0x80394d84,
		"NPC::entry$2341": 0x80394dac,
		"entry$2341": 0x80394dac,
		"NPC::entry$2343": 0x80394dd4,
		"entry$2343": 0x80394dd4,
		"NPC::entry$2345": 0x80394dfc,
		"entry$2345": 0x80394dfc,
		"NPC::entry$2347": 0x80394e14,
		"entry$2347": 0x80394e14,
		"NPC::entry$2348": 0x80394e2c,
		"entry$2348": 0x80394e2c,
		"NPC::entry$2349": 0x80394e44,
		"entry$2349": 0x80394e44,
		"NPC::entry$2350": 0x80394e6c,
		"entry$2350": 0x80394e6c,
		"NPC::entry$2352": 0x80394e94,
		"entry$2352": 0x80394e94,
		"NPC::entry$2354": 0x80394ebc,
		"entry$2354": 0x80394ebc,
		"NPC::entry$2356": 0x80394ed4,
		"entry$2356": 0x80394ed4,
		"NPC::entry$2357": 0x80394ef8,
		"entry$2357": 0x80394ef8,
		"NPC::entry$2359": 0x80394f1c,
		"entry$2359": 0x80394f1c,
		"NPC::entry$2361": 0x80394f48,
		"entry$2361": 0x80394f48,
		"NPC::entry$2363": 0x80394f70,
		"entry$2363": 0x80394f70,
		"NPC::entry$2365": 0x80394f98,
		"entry$2365": 0x80394f98,
		"NPC::entry$2367": 0x80394fbc,
		"entry$2367": 0x80394fbc,
		"NPC::entry$2369": 0x80394fe4,
		"entry$2369": 0x80394fe4,
		"NPC::entry$2371": 0x8039500c,
		"entry$2371": 0x8039500c,
		"NPC::@2416": 0x80395024,
		"NPC::@2459": 0x80395034,
		"NPC::@2467": 0x80395044,
		"NPC::@2475": 0x80395054,
		"NPC::@1968": 0x803951d4,
		"NPC::@1969": 0x803951e8,
		"NPC::@1973": 0x80395238,
		"NPC::@1974": 0x8039524c,
		"NPC::@1978": 0x8039529c,
		"NPC::@1979": 0x803952b0,
		"NPC::@1982": 0x803952f8,
		"NPC::@1983": 0x8039530c,
		"NPC::@2160": 0x80395320,
		"NPC::@2162": 0x80395330,
		"NPC::@2164": 0x80395340,
		"NPC::@2166": 0x80395350,
		"NPC::@2168": 0x80395364,
		"NPC::@2170": 0x8039537c,
		"NPC::@2172": 0x80395390,
		"NPC::@2174": 0x803953a4,
		"NPC::@2176": 0x803953b8,
		"NPC::@2178": 0x803953cc,
		"NPC::@2179": 0x803953dc,
		"NPC::@2181": 0x803953ec,
		"NPC::@2183": 0x803953f8,
		"NPC::@2185": 0x80395404,
		"NPC::@2186": 0x80395414,
		"NPC::@2188": 0x80395424,
		"NPC::@2190": 0x80395434,
		"NPC::@2191": 0x80395444,
		"NPC::@2192": 0x80395454,
		"NPC::@2193": 0x80395464,
		"NPC::@2195": 0x80395478,
		"NPC::@2203": 0x803954c0,
		"NPC::@2205": 0x803954d8,
		"NPC::@2209": 0x80395504,
		"NPC::@2228": 0x803955c8,
		"NPC::@2229": 0x803955d8,
		"NPC::@2231": 0x803955f0,
		"NPC::@2334": 0x80395648,
		"NPC::@2335": 0x8039565c,
		"NPC::@2337": 0x80395678,
		"NPC::@2339": 0x8039569c,
		"NPC::@2343": 0x803956e0,
		"NPC::@2345": 0x80395714,
		"NPC::@2357": 0x803957e4,
		"NPC::@2359": 0x803957fc,
		"NPC::@2361": 0x80395828,
		"NPC::@2363": 0x8039583c,
		"NPC::@2365": 0x8039584c,
		"NPC::@2367": 0x8039585c,
		"NPC::@2369": 0x80395888,
		"NPC::@2371": 0x803958b8,
		"NPC::@2373": 0x803958e4,
		"NPC::@2417": 0x80395908,
		"NPC::@2418": 0x8039591c,
		"NPC::@2420": 0x8039592c,
		"NPC::@2421": 0x80395940,
		"NPC::@2422": 0x80395954,
		"NPC::@2423": 0x80395968,
		"NPC::@2424": 0x8039597c,
		"NPC::@2426": 0x803959a4,
		"NPC::@2427": 0x803959b8,
		"NPC::@2431": 0x80395a0c,
		"NPC::@2721": 0x80395c48,
		"NPC::@2722": 0x80395c60,
		"NPC::@2723": 0x80395c78,
		"NPC::@2724": 0x80395c84,
		"NPC::@1530": 0x80395d70,
		"@1530": 0x80395d70,
		"NPC::@1535": 0x80395d80,
		"NPC::@1536": 0x80395da4,
		"NPC::sMonteM_HatAColorBuf0": 0x80395db8,
		"sMonteM_HatAColorBuf0": 0x80395db8,
		"NPC::sMonteM_HatAColorBuf1": 0x80395df0,
		"sMonteM_HatAColorBuf1": 0x80395df0,
		"NPC::@1537": 0x80395e28,
		"NPC::sMonteM_HatAColorChange": 0x80395e34,
		"sMonteM_HatAColorChange": 0x80395e34,
		"NPC::sMonteM_HatABeltColorBuf": 0x80395e44,
		"sMonteM_HatABeltColorBuf": 0x80395e44,
		"NPC::@1538": 0x80395e7c,
		"NPC::sMonteM_HatABeltColorChange": 0x80395e88,
		"sMonteM_HatABeltColorChange": 0x80395e88,
		"NPC::@1540": 0x80395e98,
		"NPC::sMonteM_HatAData": 0x80395ea8,
		"sMonteM_HatAData": 0x80395ea8,
		"NPC::sMonteM_HatBColorBuf": 0x80395ed4,
		"sMonteM_HatBColorBuf": 0x80395ed4,
		"NPC::sMonteM_HatBColorChange": 0x80395eec,
		"sMonteM_HatBColorChange": 0x80395eec,
		"NPC::sMonteM_HatBBeltColorBuf": 0x80395efc,
		"sMonteM_HatBBeltColorBuf": 0x80395efc,
		"NPC::sMonteM_HatBBeltColorChange": 0x80395f14,
		"sMonteM_HatBBeltColorChange": 0x80395f14,
		"NPC::@1541": 0x80395f24,
		"NPC::sMonteM_HatBData": 0x80395f34,
		"sMonteM_HatBData": 0x80395f34,
		"NPC::sMonteM_HatDColorBuf": 0x80395f60,
		"sMonteM_HatDColorBuf": 0x80395f60,
		"NPC::sMonteM_HatDColorChange": 0x80395f70,
		"sMonteM_HatDColorChange": 0x80395f70,
		"NPC::@1542": 0x80395f80,
		"NPC::sMonteM_HatDData": 0x80395f90,
		"sMonteM_HatDData": 0x80395f90,
		"NPC::sMonteM_HatEColorBuf0": 0x80395fbc,
		"sMonteM_HatEColorBuf0": 0x80395fbc,
		"NPC::sMonteM_HatEColorBuf1": 0x80395fcc,
		"sMonteM_HatEColorBuf1": 0x80395fcc,
		"NPC::sMonteM_HatEColorChange": 0x80395fdc,
		"sMonteM_HatEColorChange": 0x80395fdc,
		"NPC::@1543": 0x80395fec,
		"NPC::sMonteM_HatEData": 0x80395ffc,
		"sMonteM_HatEData": 0x80395ffc,
		"NPC::sMonteM_HatFColorBuf0": 0x80396028,
		"sMonteM_HatFColorBuf0": 0x80396028,
		"NPC::sMonteM_HatFColorBuf1": 0x80396038,
		"sMonteM_HatFColorBuf1": 0x80396038,
		"NPC::sMonteM_HatFColorChange": 0x80396048,
		"sMonteM_HatFColorChange": 0x80396048,
		"NPC::@1544": 0x80396058,
		"NPC::sMonteM_HatFData": 0x80396068,
		"sMonteM_HatFData": 0x80396068,
		"NPC::sMonteM_HatGColorBuf0": 0x80396094,
		"sMonteM_HatGColorBuf0": 0x80396094,
		"NPC::sMonteM_HatGColorBuf1": 0x803960bc,
		"sMonteM_HatGColorBuf1": 0x803960bc,
		"NPC::sMonteM_HatGColorChange": 0x803960e4,
		"sMonteM_HatGColorChange": 0x803960e4,
		"NPC::@1545": 0x803960f4,
		"NPC::sMonteM_HatGData": 0x80396104,
		"sMonteM_HatGData": 0x80396104,
		"NPC::sMonteM_MustacheAColorBuf0": 0x80396130,
		"sMonteM_MustacheAColorBuf0": 0x80396130,
		"NPC::@1546": 0x80396150,
		"NPC::sMonteM_MustacheAColorChange": 0x8039615c,
		"sMonteM_MustacheAColorChange": 0x8039615c,
		"NPC::@1547": 0x8039616c,
		"NPC::sMonteM_MustacheAData": 0x8039617c,
		"sMonteM_MustacheAData": 0x8039617c,
		"NPC::@1548": 0x803961a8,
		"NPC::sMonteM_GlassesAData": 0x803961bc,
		"sMonteM_GlassesAData": 0x803961bc,
		"NPC::sMonteM_GlassesBColorBuf0": 0x803961e8,
		"sMonteM_GlassesBColorBuf0": 0x803961e8,
		"NPC::@1549": 0x80396200,
		"NPC::sMonteM_GlassesBColorChange": 0x8039620c,
		"sMonteM_GlassesBColorChange": 0x8039620c,
		"NPC::@1550": 0x8039621c,
		"NPC::sMonteM_GlassesBData": 0x80396230,
		"sMonteM_GlassesBData": 0x80396230,
		"NPC::sMonteM_LapelAColorBuf0": 0x8039625c,
		"sMonteM_LapelAColorBuf0": 0x8039625c,
		"NPC::sMonteM_LapelAColorBuf1": 0x8039626c,
		"sMonteM_LapelAColorBuf1": 0x8039626c,
		"NPC::@1551": 0x8039627c,
		"NPC::sMonteM_LapelAColorChange": 0x80396288,
		"sMonteM_LapelAColorChange": 0x80396288,
		"NPC::@1552": 0x80396298,
		"NPC::@1553": 0x803962a4,
		"NPC::sMonteM_LapelAData": 0x803962b4,
		"sMonteM_LapelAData": 0x803962b4,
		"NPC::@1554": 0x803962e0,
		"NPC::sMonteM_TieBColorChange": 0x803962ec,
		"sMonteM_TieBColorChange": 0x803962ec,
		"NPC::@1555": 0x803962fc,
		"NPC::sMonteM_TieBData": 0x8039630c,
		"sMonteM_TieBData": 0x8039630c,
		"NPC::@1556": 0x80396338,
		"NPC::sMonteM_LuggageData": 0x8039634c,
		"sMonteM_LuggageData": 0x8039634c,
		"NPC::@1557": 0x80396378,
		"NPC::sMonteMF_TubeData": 0x80396388,
		"sMonteMF_TubeData": 0x80396388,
		"NPC::@1558": 0x803963b4,
		"NPC::@1559": 0x803963c0,
		"NPC::sMonteMG_MopData": 0x803963d0,
		"sMonteMG_MopData": 0x803963d0,
		"NPC::@1560": 0x803963fc,
		"NPC::sMonteMH_UkleleData": 0x80396410,
		"sMonteMH_UkleleData": 0x80396410,
		"NPC::sMonteW_FlowerInColorBuf": 0x8039643c,
		"sMonteW_FlowerInColorBuf": 0x8039643c,
		"NPC::@1561": 0x80396454,
		"NPC::sMonteW_FlowerInColorChange": 0x80396460,
		"sMonteW_FlowerInColorChange": 0x80396460,
		"NPC::sMonteW_FlowerOutColorBuf": 0x80396470,
		"sMonteW_FlowerOutColorBuf": 0x80396470,
		"NPC::@1562": 0x80396488,
		"NPC::sMonteW_FlowerOutColorChange": 0x80396494,
		"sMonteW_FlowerOutColorChange": 0x80396494,
		"NPC::@1563": 0x803964a4,
		"NPC::@1564": 0x803964b0,
		"NPC::sMonteW_FlowerData": 0x803964c4,
		"sMonteW_FlowerData": 0x803964c4,
		"NPC::sMonteW_HatAMainColorBuf0": 0x803964f0,
		"sMonteW_HatAMainColorBuf0": 0x803964f0,
		"NPC::sMonteW_HatAMainColorBuf1": 0x80396510,
		"sMonteW_HatAMainColorBuf1": 0x80396510,
		"NPC::sMonteW_HatAMainColorChange": 0x80396530,
		"sMonteW_HatAMainColorChange": 0x80396530,
		"NPC::sMonteW_HatABeltColorBuf": 0x80396540,
		"sMonteW_HatABeltColorBuf": 0x80396540,
		"NPC::sMonteW_HatABeltColorChange": 0x80396560,
		"sMonteW_HatABeltColorChange": 0x80396560,
		"NPC::@1565": 0x80396570,
		"NPC::sMonteW_HatAData": 0x80396580,
		"sMonteW_HatAData": 0x80396580,
		"NPC::sMonteW_GlassBColorBuf": 0x803965ac,
		"sMonteW_GlassBColorBuf": 0x803965ac,
		"NPC::sMonteW_GlassBColorChange": 0x803965c4,
		"sMonteW_GlassBColorChange": 0x803965c4,
		"NPC::@1566": 0x803965d4,
		"NPC::sMonteW_GlassBData": 0x803965e4,
		"sMonteW_GlassBData": 0x803965e4,
		"NPC::@1567": 0x80396610,
		"NPC::sMonteW_ArrowRData": 0x80396624,
		"sMonteW_ArrowRData": 0x80396624,
		"NPC::@1568": 0x80396650,
		"NPC::sMonteW_ArrowLData": 0x80396664,
		"sMonteW_ArrowLData": 0x80396664,
		"NPC::@1569": 0x80396690,
		"NPC::sMonteWC_HatCData": 0x803966a0,
		"sMonteWC_HatCData": 0x803966a0,
		"NPC::@1570": 0x803966cc,
		"NPC::sMonteWC_BraceletRData": 0x803966e0,
		"sMonteWC_BraceletRData": 0x803966e0,
		"NPC::@1571": 0x8039670c,
		"NPC::@1572": 0x80396718,
		"NPC::sMonteWC_BraceletLData": 0x8039672c,
		"sMonteWC_BraceletLData": 0x8039672c,
		"NPC::sMareM_HatAColorBuf0": 0x80396758,
		"sMareM_HatAColorBuf0": 0x80396758,
		"NPC::sMareM_HatAColorBuf1": 0x803967a0,
		"sMareM_HatAColorBuf1": 0x803967a0,
		"NPC::sMareM_HatAColorChange": 0x803967e8,
		"sMareM_HatAColorChange": 0x803967e8,
		"NPC::@1574": 0x803967f8,
		"NPC::sMareM_HatAData": 0x80396808,
		"sMareM_HatAData": 0x80396808,
		"NPC::sMareM_HatBColorBuf0": 0x80396834,
		"sMareM_HatBColorBuf0": 0x80396834,
		"NPC::sMareM_HatBColorBuf1": 0x80396864,
		"sMareM_HatBColorBuf1": 0x80396864,
		"NPC::sMareM_HatBColorChange": 0x80396894,
		"sMareM_HatBColorChange": 0x80396894,
		"NPC::@1575": 0x803968a4,
		"NPC::sMareM_HatBData": 0x803968b4,
		"sMareM_HatBData": 0x803968b4,
		"NPC::sMareM_HatEColorBuf0": 0x803968e0,
		"sMareM_HatEColorBuf0": 0x803968e0,
		"NPC::sMareM_HatEColorBuf1": 0x80396938,
		"sMareM_HatEColorBuf1": 0x80396938,
		"NPC::sMareM_HatEColorChange": 0x80396990,
		"sMareM_HatEColorChange": 0x80396990,
		"NPC::@1576": 0x803969a0,
		"NPC::sMareM_HatEData": 0x803969b0,
		"sMareM_HatEData": 0x803969b0,
		"NPC::sMareM_ShellAColorBuf0": 0x803969dc,
		"sMareM_ShellAColorBuf0": 0x803969dc,
		"NPC::sMareM_ShellAColorBuf1": 0x80396a2c,
		"sMareM_ShellAColorBuf1": 0x80396a2c,
		"NPC::sMareM_ShellAColorChange": 0x80396a7c,
		"sMareM_ShellAColorChange": 0x80396a7c,
		"NPC::@1578": 0x80396a8c,
		"NPC::sMareM_ShellAData": 0x80396aa0,
		"sMareM_ShellAData": 0x80396aa0,
		"NPC::sMareM_ShellBColorBuf0": 0x80396acc,
		"sMareM_ShellBColorBuf0": 0x80396acc,
		"NPC::sMareM_ShellBColorBuf1": 0x80396b1c,
		"sMareM_ShellBColorBuf1": 0x80396b1c,
		"NPC::sMareM_ShellBColorChange": 0x80396b6c,
		"sMareM_ShellBColorChange": 0x80396b6c,
		"NPC::@1579": 0x80396b7c,
		"NPC::sMareM_ShellBData": 0x80396b90,
		"sMareM_ShellBData": 0x80396b90,
		"NPC::sMareM_BivalveBColorBuf0": 0x80396bbc,
		"sMareM_BivalveBColorBuf0": 0x80396bbc,
		"NPC::sMareM_BivalveBColorBuf1": 0x80396bec,
		"sMareM_BivalveBColorBuf1": 0x80396bec,
		"NPC::sMareM_BivalveBColorChange": 0x80396c1c,
		"sMareM_BivalveBColorChange": 0x80396c1c,
		"NPC::@1580": 0x80396c2c,
		"NPC::sMareM_BivalveBData": 0x80396c40,
		"sMareM_BivalveBData": 0x80396c40,
		"NPC::sMareM_GlassColorBuf0": 0x80396c6c,
		"sMareM_GlassColorBuf0": 0x80396c6c,
		"NPC::sMareM_GlassColorBuf1": 0x80396c84,
		"sMareM_GlassColorBuf1": 0x80396c84,
		"NPC::@1581": 0x80396c9c,
		"NPC::sMareM_GlassColorChange": 0x80396ca8,
		"sMareM_GlassColorChange": 0x80396ca8,
		"NPC::@1582": 0x80396cb8,
		"NPC::sMareM_GlassData": 0x80396cc8,
		"sMareM_GlassData": 0x80396cc8,
		"NPC::sMareMB_ElderMat1ColorChange": 0x80396cf4,
		"sMareMB_ElderMat1ColorChange": 0x80396cf4,
		"NPC::sMareMB_ElderMat2ColorChange": 0x80396d04,
		"sMareMB_ElderMat2ColorChange": 0x80396d04,
		"NPC::sMareMB_ElderMat3ColorChange": 0x80396d14,
		"sMareMB_ElderMat3ColorChange": 0x80396d14,
		"NPC::@1585": 0x80396d24,
		"NPC::sMareMB_ElderData": 0x80396d34,
		"sMareMB_ElderData": 0x80396d34,
		"NPC::sMareMB_FishingRodMat1ColorChange": 0x80396d60,
		"sMareMB_FishingRodMat1ColorChange": 0x80396d60,
		"NPC::sMareMB_FishingRodMat2ColorChange": 0x80396d70,
		"sMareMB_FishingRodMat2ColorChange": 0x80396d70,
		"NPC::sMareMB_FishingRodMat3ColorChange": 0x80396d80,
		"sMareMB_FishingRodMat3ColorChange": 0x80396d80,
		"NPC::@1586": 0x80396d90,
		"NPC::sMareMC_HatFColorChange": 0x80396da4,
		"sMareMC_HatFColorChange": 0x80396da4,
		"NPC::@1587": 0x80396db4,
		"NPC::sMareMC_HatFData": 0x80396dc4,
		"sMareMC_HatFData": 0x80396dc4,
		"NPC::sMareMC_BeardColorChange": 0x80396df0,
		"sMareMC_BeardColorChange": 0x80396df0,
		"NPC::@1588": 0x80396e00,
		"NPC::sMareMC_BeardData": 0x80396e14,
		"sMareMC_BeardData": 0x80396e14,
		"NPC::sMareMC_MustacheColorChange": 0x80396e40,
		"sMareMC_MustacheColorChange": 0x80396e40,
		"NPC::@1589": 0x80396e50,
		"NPC::sMareMC_MustacheData": 0x80396e64,
		"sMareMC_MustacheData": 0x80396e64,
		"NPC::sMareMD_PipeColorChange": 0x80396e90,
		"sMareMD_PipeColorChange": 0x80396e90,
		"NPC::@1591": 0x80396ea0,
		"NPC::sMareMD_PipeData": 0x80396eb4,
		"sMareMD_PipeData": 0x80396eb4,
		"NPC::sMareW_PearlAColorBuf0": 0x80396ee0,
		"sMareW_PearlAColorBuf0": 0x80396ee0,
		"NPC::sMareW_PearlAColorBuf1": 0x80396f10,
		"sMareW_PearlAColorBuf1": 0x80396f10,
		"NPC::sMareW_PearlAColorChange": 0x80396f40,
		"sMareW_PearlAColorChange": 0x80396f40,
		"NPC::@1592": 0x80396f50,
		"NPC::sMareW_PearlAData": 0x80396f64,
		"sMareW_PearlAData": 0x80396f64,
		"NPC::sMareW_HatAColorBuf0": 0x80396f90,
		"sMareW_HatAColorBuf0": 0x80396f90,
		"NPC::sMareW_HatAColorBuf1": 0x80396fc0,
		"sMareW_HatAColorBuf1": 0x80396fc0,
		"NPC::sMareW_HatAColorChange": 0x80396ff0,
		"sMareW_HatAColorChange": 0x80396ff0,
		"NPC::@1593": 0x80397000,
		"NPC::sMareW_HatAData": 0x80397010,
		"sMareW_HatAData": 0x80397010,
		"NPC::sMareW_HatDColorBuf0": 0x8039703c,
		"sMareW_HatDColorBuf0": 0x8039703c,
		"NPC::sMareW_HatDColorBuf1": 0x80397094,
		"sMareW_HatDColorBuf1": 0x80397094,
		"NPC::sMareW_HatDColorChange": 0x803970ec,
		"sMareW_HatDColorChange": 0x803970ec,
		"NPC::@1594": 0x803970fc,
		"NPC::sMareW_HatDData": 0x8039710c,
		"sMareW_HatDData": 0x8039710c,
		"NPC::sMareW_ShellAColorBuf0": 0x80397138,
		"sMareW_ShellAColorBuf0": 0x80397138,
		"NPC::sMareW_ShellAColorBuf1": 0x80397168,
		"sMareW_ShellAColorBuf1": 0x80397168,
		"NPC::sMareW_ShellAColorChange": 0x80397198,
		"sMareW_ShellAColorChange": 0x80397198,
		"NPC::@1595": 0x803971a8,
		"NPC::sMareW_ShellAData": 0x803971b8,
		"sMareW_ShellAData": 0x803971b8,
		"NPC::sMareW_ShellBColorBuf0": 0x803971e4,
		"sMareW_ShellBColorBuf0": 0x803971e4,
		"NPC::sMareW_ShellBColorBuf1": 0x8039722c,
		"sMareW_ShellBColorBuf1": 0x8039722c,
		"NPC::sMareW_ShellBColorChange": 0x80397274,
		"sMareW_ShellBColorChange": 0x80397274,
		"NPC::@1596": 0x80397284,
		"NPC::sMareW_ShellBData": 0x80397294,
		"sMareW_ShellBData": 0x80397294,
		"NPC::sMareW_BivalveAColorBuf0": 0x803972c0,
		"sMareW_BivalveAColorBuf0": 0x803972c0,
		"NPC::sMareW_BivalveAColorBuf1": 0x803972f0,
		"sMareW_BivalveAColorBuf1": 0x803972f0,
		"NPC::sMareW_BivalveAColorChange": 0x80397320,
		"sMareW_BivalveAColorChange": 0x80397320,
		"NPC::@1597": 0x80397330,
		"NPC::sMareW_BivalveAData": 0x80397344,
		"sMareW_BivalveAData": 0x80397344,
		"NPC::sMareWB_BabyBodyColorChange": 0x80397370,
		"sMareWB_BabyBodyColorChange": 0x80397370,
		"NPC::@1599": 0x80397380,
		"NPC::sMareWB_BabyHatColorChange": 0x8039738c,
		"sMareWB_BabyHatColorChange": 0x8039738c,
		"NPC::@1600": 0x8039739c,
		"NPC::sMareWB_BabyBedColorChange": 0x803973a8,
		"sMareWB_BabyBedColorChange": 0x803973a8,
		"NPC::@1601": 0x803973b8,
		"NPC::@1602": 0x803973c8,
		"NPC::sKinopio_SunGlassesData": 0x803973e0,
		"sKinopio_SunGlassesData": 0x803973e0,
		"NPC::@1603": 0x8039740c,
		"NPC::@1604": 0x8039741c,
		"NPC::sKinojii_StickData": 0x80397430,
		"sKinojii_StickData": 0x80397430,
		"NPC::@1605": 0x8039745c,
		"NPC::sPeach_HairNormalData": 0x80397474,
		"sPeach_HairNormalData": 0x80397474,
		"NPC::@1606": 0x803974a0,
		"NPC::@1607": 0x803974ac,
		"NPC::sPeach_Hand1LData": 0x803974c0,
		"sPeach_Hand1LData": 0x803974c0,
		"NPC::@1608": 0x803974ec,
		"NPC::@1609": 0x803974f8,
		"NPC::sPeach_Hand1RData": 0x8039750c,
		"sPeach_Hand1RData": 0x8039750c,
		"NPC::@1610": 0x80397538,
		"NPC::sPeach_HairPonytailData": 0x80397550,
		"sPeach_HairPonytailData": 0x80397550,
		"NPC::@1611": 0x8039757c,
		"NPC::sPeach_ParasolData": 0x80397590,
		"sPeach_ParasolData": 0x80397590,
		"NPC::@1612": 0x803975bc,
		"NPC::sPeach_Hand2LData": 0x803975d0,
		"sPeach_Hand2LData": 0x803975d0,
		"NPC::@1613": 0x803975fc,
		"@1613": 0x803975fc,
		"NPC::sPeach_Hand2RData": 0x80397610,
		"sPeach_Hand2RData": 0x80397610,
		"NPC::sRaccoonDog_TubeColorBuf0": 0x8039763c,
		"sRaccoonDog_TubeColorBuf0": 0x8039763c,
		"NPC::sRaccoonDog_TubeColorBuf1": 0x8039764c,
		"sRaccoonDog_TubeColorBuf1": 0x8039764c,
		"NPC::sRaccoonDog_TubeColorChange": 0x8039765c,
		"sRaccoonDog_TubeColorChange": 0x8039765c,
		"NPC::@1615": 0x8039766c,
		"NPC::@1616": 0x80397678,
		"NPC::sRaccoonDog_TubeData": 0x80397684,
		"sRaccoonDog_TubeData": 0x80397684,
		"NPC::sMonteM_BodyColorBuf": 0x803976b0,
		"sMonteM_BodyColorBuf": 0x803976b0,
		"NPC::@1617": 0x80397700,
		"NPC::sMonteM_BodyColor": 0x8039770c,
		"sMonteM_BodyColor": 0x8039770c,
		"NPC::sMonteMA_ClothColorBuf0": 0x8039771c,
		"sMonteMA_ClothColorBuf0": 0x8039771c,
		"NPC::sMonteMA_ClothColorBuf1": 0x80397774,
		"sMonteMA_ClothColorBuf1": 0x80397774,
		"NPC::@1618": 0x803977cc,
		"NPC::sMonteMA_ClothColor": 0x803977d8,
		"sMonteMA_ClothColor": 0x803977d8,
		"NPC::sMonteMB_BodyColorBuf": 0x803977e8,
		"sMonteMB_BodyColorBuf": 0x803977e8,
		"NPC::sMonteMB_BodyColor": 0x80397808,
		"sMonteMB_BodyColor": 0x80397808,
		"NPC::sMonteMB_ClothColorBuf": 0x80397818,
		"sMonteMB_ClothColorBuf": 0x80397818,
		"NPC::sMonteMB_ClothColor": 0x80397848,
		"sMonteMB_ClothColor": 0x80397848,
		"NPC::sMonteMC_ClothColorBuf0": 0x80397858,
		"sMonteMC_ClothColorBuf0": 0x80397858,
		"NPC::sMonteMC_ClothColorBuf1": 0x803978b0,
		"sMonteMC_ClothColorBuf1": 0x803978b0,
		"NPC::sMonteMC_ClothColor": 0x80397908,
		"sMonteMC_ClothColor": 0x80397908,
		"NPC::sMonteMD_ClothColorBuf": 0x80397918,
		"sMonteMD_ClothColorBuf": 0x80397918,
		"NPC::sMonteMD_ClothColor": 0x80397940,
		"sMonteMD_ClothColor": 0x80397940,
		"NPC::sMonteW_ColorBuf": 0x80397950,
		"sMonteW_ColorBuf": 0x80397950,
		"NPC::sMonteW_BodyColor": 0x80397980,
		"sMonteW_BodyColor": 0x80397980,
		"NPC::sMonteWA_ClothColorBuf": 0x80397990,
		"sMonteWA_ClothColorBuf": 0x80397990,
		"NPC::sMonteWA_ClothColor": 0x803979c0,
		"sMonteWA_ClothColor": 0x803979c0,
		"NPC::sMonteWB_ClothColorBuf0": 0x803979d0,
		"sMonteWB_ClothColorBuf0": 0x803979d0,
		"NPC::sMonteWB_ClothColorBuf1": 0x80397a18,
		"sMonteWB_ClothColorBuf1": 0x80397a18,
		"NPC::sMonteWB_ClothColor": 0x80397a60,
		"sMonteWB_ClothColor": 0x80397a60,
		"NPC::sMareM_ColorBuf": 0x80397a70,
		"sMareM_ColorBuf": 0x80397a70,
		"NPC::sMareM_BodyColor": 0x80397aa0,
		"sMareM_BodyColor": 0x80397aa0,
		"NPC::sMareW_ColorBuf": 0x80397ab0,
		"sMareW_ColorBuf": 0x80397ab0,
		"NPC::sMareW_BodyColor": 0x80397ae0,
		"sMareW_BodyColor": 0x80397ae0,
		"NPC::sKinopio_BodyColorData0": 0x80397af0,
		"sKinopio_BodyColorData0": 0x80397af0,
		"NPC::sKinopio_BodyColorData1": 0x80397b18,
		"sKinopio_BodyColorData1": 0x80397b18,
		"NPC::@1619": 0x80397b40,
		"NPC::sKinopio_BodyColor": 0x80397b4c,
		"sKinopio_BodyColor": 0x80397b4c,
		"NPC::sKinopio_ClothColorData0": 0x80397b5c,
		"sKinopio_ClothColorData0": 0x80397b5c,
		"NPC::sKinopio_ClothColorData1": 0x80397b84,
		"sKinopio_ClothColorData1": 0x80397b84,
		"NPC::@1620": 0x80397bac,
		"NPC::sKinopio_ClothColor": 0x80397bb8,
		"sKinopio_ClothColor": 0x80397bb8,
		"NPC::sRaccoonDog_ClothColorBuf0": 0x80397bc8,
		"sRaccoonDog_ClothColorBuf0": 0x80397bc8,
		"NPC::sRaccoonDog_ClothColorBuf1": 0x80397bd8,
		"sRaccoonDog_ClothColorBuf1": 0x80397bd8,
		"NPC::sRaccoonDog_ClothColor": 0x80397be8,
		"sRaccoonDog_ClothColor": 0x80397be8,
		"NPC::sMonteM_InitData": 0x80397bf8,
		"sMonteM_InitData": 0x80397bf8,
		"NPC::sMonteMA_InitData": 0x80397c4c,
		"sMonteMA_InitData": 0x80397c4c,
		"NPC::sMonteMB_InitData": 0x80397ca0,
		"sMonteMB_InitData": 0x80397ca0,
		"NPC::sMonteMC_InitData": 0x80397cf4,
		"sMonteMC_InitData": 0x80397cf4,
		"NPC::sMonteMD_InitData": 0x80397d48,
		"sMonteMD_InitData": 0x80397d48,
		"NPC::sMonteME_InitData": 0x80397d9c,
		"sMonteME_InitData": 0x80397d9c,
		"NPC::sMonteMF_InitData": 0x80397df0,
		"sMonteMF_InitData": 0x80397df0,
		"NPC::sMonteMG_InitData": 0x80397e44,
		"sMonteMG_InitData": 0x80397e44,
		"NPC::sMonteMH_InitData": 0x80397e98,
		"sMonteMH_InitData": 0x80397e98,
		"NPC::sMonteW_InitData": 0x80397eec,
		"sMonteW_InitData": 0x80397eec,
		"NPC::sMonteWA_InitData": 0x80397f40,
		"sMonteWA_InitData": 0x80397f40,
		"NPC::sMonteWB_InitData": 0x80397f94,
		"sMonteWB_InitData": 0x80397f94,
		"NPC::sMonteWC_InitData": 0x80397fe8,
		"sMonteWC_InitData": 0x80397fe8,
		"NPC::sMareM_InitData": 0x8039803c,
		"sMareM_InitData": 0x8039803c,
		"NPC::sMareMB_InitData": 0x80398090,
		"sMareMB_InitData": 0x80398090,
		"NPC::sMareMC_InitData": 0x803980e4,
		"sMareMC_InitData": 0x803980e4,
		"NPC::sMareMD_InitData": 0x80398138,
		"sMareMD_InitData": 0x80398138,
		"NPC::sMareW_InitData": 0x8039818c,
		"sMareW_InitData": 0x8039818c,
		"NPC::sMareWB_InitData": 0x803981e0,
		"sMareWB_InitData": 0x803981e0,
		"NPC::sKinopio_InitData": 0x80398234,
		"sKinopio_InitData": 0x80398234,
		"NPC::sKinojii_InitData": 0x80398288,
		"sKinojii_InitData": 0x80398288,
		"NPC::sPeach_InitData": 0x803982dc,
		"sPeach_InitData": 0x803982dc,
		"NPC::sRaccoonDog_InitData": 0x80398330,
		"sRaccoonDog_InitData": 0x80398330,
		"NPC::sSunflowerL_InitData": 0x80398384,
		"sSunflowerL_InitData": 0x80398384,
		"NPC::sSunflowerS_InitData": 0x803983d8,
		"sSunflowerS_InitData": 0x803983d8,
		"NPC::sBoardNpc_InitData": 0x8039842c,
		"sBoardNpc_InitData": 0x8039842c,
		"TBaseNPC::sMtxEffectInitData$localstatic1$setMtxEffect_": 0x803985f0,
		"sMtxEffectInitData$localstatic1$setMtxEffect_": 0x803985f0,
		"TBaseNPC::sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x803986d0,
		"sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x803986d0,
		"TBaseNPC::sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x803986e0,
		"sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x803986e0,
		"TBaseNPC::sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x80398718,
		"sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x80398718,
		"TBaseNPC::sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x80398730,
		"sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x80398730,
		"TBaseNPC::sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x80398760,
		"sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x80398760,
		"TBaseNPC::sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80398778,
		"sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80398778,
		"TBaseNPC::sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x80398788,
		"sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x80398788,
		"TBaseNPC::sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x80398798,
		"sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x80398798,
		"TBaseNPC::sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x803987a8,
		"sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x803987a8,
		"TBaseNPC::sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x803987b8,
		"sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x803987b8,
		"TBaseNPC::sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x803987c8,
		"sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x803987c8,
		"NPC::@2266": 0x803988b8,
		"NPC::@2275": 0x803988c8,
		"NPC::@2489": 0x803988f0,
		"NPC::@1938": 0x803989f0,
		"NPC::@1939": 0x80398a18,
		"NPC::@1940": 0x80398a40,
		"NPC::@1941": 0x80398a68,
		"NPC::@1942": 0x80398a90,
		"NPC::@1943": 0x80398ab4,
		"NPC::@1944": 0x80398adc,
		"NPC::@1945": 0x80398b04,
		"NPC::@1946": 0x80398b28,
		"NPC::@1947": 0x80398b50,
		"NPC::@1948": 0x80398b78,
		"NPC::@1949": 0x80398ba4,
		"NPC::@1950": 0x80398bcc,
		"NPC::@1951": 0x80398bf0,
		"NPC::@1952": 0x80398c18,
		"NPC::@1953": 0x80398c44,
		"NPC::@1954": 0x80398c70,
		"NPC::@1955": 0x80398c98,
		"NPC::@1956": 0x80398cc0,
		"NPC::@1957": 0x80398ce8,
		"NPC::@1958": 0x80398d10,
		"NPC::@1959": 0x80398d3c,
		"NPC::@1960": 0x80398d68,
		"NPC::@1984": 0x80398fe8,
		"NPC::@1985": 0x8039900c,
		"NPC::@1986": 0x80399034,
		"NPC::@1989": 0x8039905c,
		"NPC::@1990": 0x80399084,
		"NPC::@1991": 0x803990ac,
		"NPC::@1992": 0x803990d4,
		"NPC::@1993": 0x803990fc,
		"NPC::@1994": 0x80399120,
		"NPC::@1995": 0x80399148,
		"NPC::@1996": 0x8039916c,
		"NPC::@1997": 0x80399194,
		"NPC::@1998": 0x803991bc,
		"NPC::@1999": 0x803991e8,
		"NPC::@2000": 0x80399214,
		"NPC::@2001": 0x8039923c,
		"NPC::@2002": 0x80399260,
		"NPC::@2003": 0x80399288,
		"NPC::@2004": 0x803992b4,
		"NPC::@2005": 0x803992e0,
		"NPC::@2006": 0x80399308,
		"NPC::@2007": 0x80399330,
		"NPC::@2008": 0x80399358,
		"NPC::@2009": 0x80399380,
		"NPC::@2010": 0x803993ac,
		"NPC::@2011": 0x803993d4,
		"NPC::@2012": 0x80399400,
		"NPC::@2013": 0x80399428,
		"NPC::@2014": 0x80399458,
		"NPC::@2015": 0x80399488,
		"NPC::@2016": 0x803994b0,
		"NPC::@2017": 0x803994d8,
		"NPC::@2018": 0x80399500,
		"NPC::@2021": 0x80399530,
		"NPC::@2022": 0x80399550,
		"NPC::@2023": 0x80399570,
		"NPC::@2026": 0x80399594,
		"NPC::@2027": 0x803995b8,
		"NPC::@2028": 0x803995dc,
		"NPC::@2029": 0x803995fc,
		"NPC::@2030": 0x80399620,
		"NPC::@2031": 0x80399640,
		"NPC::@2032": 0x80399664,
		"NPC::@2033": 0x80399684,
		"NPC::@2034": 0x803996a8,
		"NPC::@2035": 0x803996cc,
		"NPC::@2036": 0x803996f4,
		"NPC::@2037": 0x80399714,
		"NPC::@2038": 0x80399734,
		"NPC::@2039": 0x80399754,
		"NPC::@2040": 0x80399778,
		"NPC::@2041": 0x8039979c,
		"NPC::@2042": 0x803997c0,
		"NPC::@2043": 0x803997e4,
		"NPC::@2044": 0x80399808,
		"NPC::@2045": 0x8039982c,
		"NPC::@2046": 0x80399854,
		"NPC::@2047": 0x80399878,
		"NPC::@2048": 0x8039989c,
		"NPC::@2049": 0x803998c4,
		"NPC::@2057": 0x80399954,
		"NPC::@2059": 0x80399978,
		"NPC::@2060": 0x8039999c,
		"NPC::@2061": 0x803999c4,
		"NPC::@2062": 0x803999e8,
		"NPC::@2065": 0x80399a0c,
		"NPC::@2066": 0x80399a30,
		"NPC::@2073": 0x80399ae0,
		"NPC::@2074": 0x80399b04,
		"NPC::@2075": 0x80399b24,
		"NPC::@2076": 0x80399b48,
		"NPC::@2077": 0x80399b6c,
		"NPC::@2078": 0x80399b94,
		"NPC::@2079": 0x80399bb4,
		"NPC::@2080": 0x80399bd4,
		"NPC::@2081": 0x80399bf4,
		"NPC::@2083": 0x80399c3c,
		"NPC::@2084": 0x80399c60,
		"NPC::@2085": 0x80399c84,
		"NPC::@2086": 0x80399ca8,
		"NPC::@2087": 0x80399cd0,
		"NPC::@2088": 0x80399cf4,
		"NPC::@2089": 0x80399d18,
		"NPC::@2090": 0x80399d40,
		"NPC::@2091": 0x80399d64,
		"NPC::@2092": 0x80399d88,
		"NPC::@2093": 0x80399dac,
		"NPC::@2098": 0x80399dd0,
		"NPC::@2099": 0x80399df8,
		"NPC::@2100": 0x80399e24,
		"NPC::@2101": 0x80399e50,
		"NPC::@2102": 0x80399e78,
		"NPC::@2113": 0x80399fd8,
		"NPC::@2117": 0x8039a074,
		"NPC::@2120": 0x8039a0a0,
		"NPC::@2121": 0x8039a0c4,
		"NPC::@2122": 0x8039a0ec,
		"NPC::@2123": 0x8039a114,
		"NPC::@2124": 0x8039a13c,
		"NPC::@2125": 0x8039a164,
		"NPC::@2126": 0x8039a188,
		"NPC::@2127": 0x8039a1ac,
		"NPC::@2130": 0x8039a1d0,
		"NPC::@2131": 0x8039a1f8,
		"NPC::@2132": 0x8039a21c,
		"NPC::@2133": 0x8039a244,
		"NPC::@2134": 0x8039a26c,
		"NPC::@2135": 0x8039a290,
		"NPC::@2136": 0x8039a2b8,
		"NPC::@2139": 0x8039a2d8,
		"NPC::@2140": 0x8039a300,
		"NPC::@2141": 0x8039a328,
		"NPC::@2144": 0x8039a350,
		"NPC::@2145": 0x8039a37c,
		"NPC::@2146": 0x8039a3a4,
		"NPC::@2150": 0x8039a3d0,
		"NPC::@2151": 0x8039a3fc,
		"NPC::@2152": 0x8039a428,
		"NPC::@1700": 0x8039a464,
		"NPC::@2153": 0x8039a478,
		"NPC::@2154": 0x8039a4a8,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x8039a548,
		"sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x8039a548,
		"TBaseNPC::sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x8039a564,
		"sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x8039a564,
		"TBaseNPC::sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x8039a570,
		"sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x8039a570,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8039a57c,
		"sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8039a57c,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8039a58c,
		"sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8039a58c,
		"NPC::@2696": 0x8039a59c,
		"NPC::sMonteM_AnmIndex": 0x8039a608,
		"sMonteM_AnmIndex": 0x8039a608,
		"NPC::sMonteME_AnmIndex": 0x8039a7d8,
		"sMonteME_AnmIndex": 0x8039a7d8,
		"NPC::sMonteMF_AnmIndex": 0x8039a9a8,
		"sMonteMF_AnmIndex": 0x8039a9a8,
		"NPC::sMonteMG_AnmIndex": 0x8039ab78,
		"sMonteMG_AnmIndex": 0x8039ab78,
		"NPC::sMonteMH_AnmIndex": 0x8039ad48,
		"sMonteMH_AnmIndex": 0x8039ad48,
		"NPC::sMonteW_AnmIndex": 0x8039af18,
		"sMonteW_AnmIndex": 0x8039af18,
		"NPC::sMonteWC_AnmIndex": 0x8039b0e8,
		"sMonteWC_AnmIndex": 0x8039b0e8,
		"NPC::sMareM_AnmIndex": 0x8039b2b8,
		"sMareM_AnmIndex": 0x8039b2b8,
		"NPC::sMareMA_AnmIndex": 0x8039b488,
		"sMareMA_AnmIndex": 0x8039b488,
		"NPC::sMareMB_AnmIndex": 0x8039b658,
		"sMareMB_AnmIndex": 0x8039b658,
		"NPC::sMareMC_AnmIndex": 0x8039b828,
		"sMareMC_AnmIndex": 0x8039b828,
		"NPC::sMareMD_AnmIndex": 0x8039b9f8,
		"sMareMD_AnmIndex": 0x8039b9f8,
		"NPC::sMareW_AnmIndex": 0x8039bbc8,
		"sMareW_AnmIndex": 0x8039bbc8,
		"NPC::sMareWA_AnmIndex": 0x8039bd98,
		"sMareWA_AnmIndex": 0x8039bd98,
		"NPC::sMareWB_AnmIndex": 0x8039bf68,
		"sMareWB_AnmIndex": 0x8039bf68,
		"NPC::sKinopio_AnmIndex": 0x8039c138,
		"sKinopio_AnmIndex": 0x8039c138,
		"NPC::sKinojii_AnmIndex": 0x8039c308,
		"sKinojii_AnmIndex": 0x8039c308,
		"NPC::sPeach_AnmIndex": 0x8039c4d8,
		"sPeach_AnmIndex": 0x8039c4d8,
		"NPC::sRaccoonDog_AnmIndex": 0x8039c6a8,
		"sRaccoonDog_AnmIndex": 0x8039c6a8,
		"NPC::sSunflowerL_AnmIndex": 0x8039c878,
		"sSunflowerL_AnmIndex": 0x8039c878,
		"NPC::sSunflowerS_AnmIndex": 0x8039ca48,
		"sSunflowerS_AnmIndex": 0x8039ca48,
		"NPC::sMonteMA_IndividualBtp": 0x8039cc18,
		"sMonteMA_IndividualBtp": 0x8039cc18,
		"NPC::sMonteMB_IndividualBtp": 0x8039cc88,
		"sMonteMB_IndividualBtp": 0x8039cc88,
		"NPC::sMonteMC_IndividualBtp": 0x8039ccf8,
		"sMonteMC_IndividualBtp": 0x8039ccf8,
		"NPC::sMonteMD_IndividualBtp": 0x8039cd68,
		"sMonteMD_IndividualBtp": 0x8039cd68,
		"NPC::sMonteWA_IndividualBtp": 0x8039cdd8,
		"sMonteWA_IndividualBtp": 0x8039cdd8,
		"NPC::sMonteWB_IndividualBtp": 0x8039ce48,
		"sMonteWB_IndividualBtp": 0x8039ce48,
		"NPC::sAllNpcInitAnmData$1577": 0x8039ceb8,
		"sAllNpcInitAnmData$1577": 0x8039ceb8,
		"NPC::sBaseActionFlagTable$1938": 0x8039cfa0,
		"sBaseActionFlagTable$1938": 0x8039cfa0,
		"NPC::sBaseActionFlagTable$1941": 0x8039d004,
		"sBaseActionFlagTable$1941": 0x8039d004,
		"NPC::sBaseActionFlagTable$1944": 0x8039d048,
		"sBaseActionFlagTable$1944": 0x8039d048,
		"MSound::@1912": 0x80373e80,
		"MSound::@1501": 0x80373f08,
		"@1501": 0x80373f08,
		"MSound::@2817": 0x80373f28,
		"MSound::@2822": 0x80373f44,
		"MSound::@2826": 0x80373f60,
		"MSound::@2832": 0x80373f74,
		"MSound::@2834": 0x80373f8c,
		"MSound::@2835": 0x80373fa0,
		"MSound::@2836": 0x80373fb8,
		"MSound::@2841": 0x80373fc4,
		"MSound::@2844": 0x80373fd4,
		"MSound::@2846": 0x80373fec,
		"MSound::@2862": 0x80374024,
		"MSound::@2872": 0x8037407c,
		"MSound::@2876": 0x803740a8,
		"MSound::@2882": 0x803740dc,
		"MSound::@2887": 0x8037410c,
		"MSound::@2888": 0x80374130,
		"MSound::@2894": 0x80374190,
		"MSound::@2911": 0x80374220,
		"MSound::@2932": 0x803742a0,
		"MSound::@2934": 0x803742b8,
		"MSound::@3292": 0x803742e8,
		"MSound::@3293": 0x803742f8,
		"MSound::@3294": 0x80374308,
		"MSound::@3295": 0x80374318,
		"MSound::@3296": 0x80374324,
		"MSound::@3297": 0x80374330,
		"MSound::@3298": 0x80374340,
		"MSound::@3299": 0x80374350,
		"MSound::@3300": 0x80374360,
		"MSound::@3301": 0x80374378,
		"MSound::@3302": 0x8037438c,
		"MSound::@3303": 0x8037439c,
		"MSound::@3304": 0x803743bc,
		"MSound::@1994": 0x80374430,
		"MSound::@2024": 0x80374460,
		"MSound::@2026": 0x8037446c,
		"MSound::@2028": 0x8037447c,
		"MSound::@2449": 0x8037448c,
		"MSound::@2450": 0x8037449c,
		"MSound::@2451": 0x803744ac,
		"MSound::@2452": 0x803744bc,
		"MSound::@2453": 0x803744c8,
		"MSound::@2454": 0x803744d4,
		"MSound::@2455": 0x803744e4,
		"MSound::@2456": 0x803744f4,
		"MSound::@2457": 0x80374504,
		"MSound::@2458": 0x8037451c,
		"MSound::@2461": 0x80374560,
		"MSound::@2463": 0x80374588,
		"MSound::@2464": 0x803745a4,
		"MSound::@2465": 0x803745bc,
		"MoveBG::@2192": 0x8038ab3c,
		"MoveBG::no_data_obj_hit_table": 0x8038ab78,
		"no_data_obj_hit_table": 0x8038ab78,
		"MoveBG::no_data_obj_hit_info": 0x8038ab88,
		"no_data_obj_hit_info": 0x8038ab88,
		"MoveBG::@2772": 0x8038abb4,
		"MoveBG::@2774": 0x8038abd8,
		"MoveBG::billboard_dolphin_anim_data": 0x8038abe8,
		"billboard_dolphin_anim_data": 0x8038abe8,
		"MoveBG::billboard_hit_data_table": 0x8038ac24,
		"billboard_hit_data_table": 0x8038ac24,
		"MoveBG::billboard_obj_hit_info": 0x8038ac34,
		"billboard_obj_hit_info": 0x8038ac34,
		"MoveBG::@2776": 0x8038ac58,
		"MoveBG::@2777": 0x8038ac70,
		"MoveBG::billboard_sun_anim_data": 0x8038ac84,
		"billboard_sun_anim_data": 0x8038ac84,
		"MoveBG::billboard_restaurant_anim_data": 0x8038ace8,
		"billboard_restaurant_anim_data": 0x8038ace8,
		"MoveBG::billboard_fish_anim_data": 0x8038ad50,
		"billboard_fish_anim_data": 0x8038ad50,
		"MoveBG::HideObj_hit_data_table": 0x8038ad9c,
		"HideObj_hit_data_table": 0x8038ad9c,
		"MoveBG::HideObj_obj_hit_info": 0x8038adac,
		"HideObj_obj_hit_info": 0x8038adac,
		"MoveBG::WaterHitHideObj_hit_data_table": 0x8038adbc,
		"WaterHitHideObj_hit_data_table": 0x8038adbc,
		"MoveBG::WaterHitHideObj_obj_hit_info": 0x8038adcc,
		"WaterHitHideObj_obj_hit_info": 0x8038adcc,
		"MoveBG::FruitHitHideObj_hit_data_table": 0x8038adec,
		"FruitHitHideObj_hit_data_table": 0x8038adec,
		"MoveBG::FruitHitHideObj_obj_hit_info": 0x8038adfc,
		"FruitHitHideObj_obj_hit_info": 0x8038adfc,
		"MoveBG::HipDropHideObj_hit_data_table": 0x8038ae1c,
		"HipDropHideObj_hit_data_table": 0x8038ae1c,
		"MoveBG::HipDropHideObj_obj_hit_info": 0x8038ae2c,
		"HipDropHideObj_obj_hit_info": 0x8038ae2c,
		"MoveBG::MonteChair_anim_data": 0x8038ae64,
		"MonteChair_anim_data": 0x8038ae64,
		"MoveBG::@2797": 0x8038af20,
		"MoveBG::door_anim_data": 0x8038af40,
		"door_anim_data": 0x8038af40,
		"MoveBG::door_hit_data_table": 0x8038afa4,
		"door_hit_data_table": 0x8038afa4,
		"MoveBG::door_obj_hit_info": 0x8038afb4,
		"door_obj_hit_info": 0x8038afb4,
		"MoveBG::doorHotel_anim_data": 0x8038afd4,
		"doorHotel_anim_data": 0x8038afd4,
		"MoveBG::@2800": 0x8038b038,
		"MoveBG::manhole_anim_data": 0x8038b050,
		"manhole_anim_data": 0x8038b050,
		"MoveBG::manhole_hit_data_table": 0x8038b064,
		"manhole_hit_data_table": 0x8038b064,
		"MoveBG::manhole_obj_hit_info": 0x8038b074,
		"manhole_obj_hit_info": 0x8038b074,
		"MoveBG::manhole_map_collision_data": 0x8038b084,
		"manhole_map_collision_data": 0x8038b084,
		"MoveBG::FruitBasket_anim_data": 0x8038b0a0,
		"FruitBasket_anim_data": 0x8038b0a0,
		"MoveBG::FruitBasket_hit_data_table": 0x8038b0c8,
		"FruitBasket_hit_data_table": 0x8038b0c8,
		"MoveBG::FruitBasket_obj_hit_info": 0x8038b0d8,
		"FruitBasket_obj_hit_info": 0x8038b0d8,
		"MoveBG::@2806": 0x8038b0e8,
		"MoveBG::BasketReverse_anim_data": 0x8038b0f4,
		"BasketReverse_anim_data": 0x8038b0f4,
		"MoveBG::BasketReverse_hit_data_table": 0x8038b108,
		"BasketReverse_hit_data_table": 0x8038b108,
		"MoveBG::BasketReverse_obj_hit_info": 0x8038b118,
		"BasketReverse_obj_hit_info": 0x8038b118,
		"MoveBG::CoconutJuice_hit_data_table": 0x8038b138,
		"CoconutJuice_hit_data_table": 0x8038b138,
		"MoveBG::CoconutJuice_obj_hit_info": 0x8038b148,
		"CoconutJuice_obj_hit_info": 0x8038b148,
		"MoveBG::Pile_hit_data_table": 0x8038b168,
		"Pile_hit_data_table": 0x8038b168,
		"MoveBG::Pile_obj_hit_info": 0x8038b178,
		"Pile_obj_hit_info": 0x8038b178,
		"MoveBG::ChangeStage_hit_data_table": 0x8038b1a8,
		"ChangeStage_hit_data_table": 0x8038b1a8,
		"MoveBG::ChangeStage_obj_hit_info": 0x8038b1b8,
		"ChangeStage_obj_hit_info": 0x8038b1b8,
		"MoveBG::StartDemo_hit_data_table": 0x8038b1ec,
		"StartDemo_hit_data_table": 0x8038b1ec,
		"MoveBG::StartDemo_obj_hit_info": 0x8038b1fc,
		"StartDemo_obj_hit_info": 0x8038b1fc,
		"MoveBG::ChipShine_anim_data": 0x8038b230,
		"ChipShine_anim_data": 0x8038b230,
		"MoveBG::ChipShine_hit_data_table": 0x8038b244,
		"ChipShine_hit_data_table": 0x8038b244,
		"MoveBG::ChipShine_obj_hit_info": 0x8038b254,
		"ChipShine_obj_hit_info": 0x8038b254,
		"MoveBG::KoopaJrSignM_anim_data": 0x8038b284,
		"KoopaJrSignM_anim_data": 0x8038b284,
		"MoveBG::KoopaJrSignM_hit_data_table": 0x8038b298,
		"KoopaJrSignM_hit_data_table": 0x8038b298,
		"MoveBG::KoopaJrSignM_obj_hit_info": 0x8038b2a8,
		"KoopaJrSignM_obj_hit_info": 0x8038b2a8,
		"MoveBG::SignCircle_anim_data": 0x8038b2e4,
		"SignCircle_anim_data": 0x8038b2e4,
		"MoveBG::SignCross_anim_data": 0x8038b314,
		"SignCross_anim_data": 0x8038b314,
		"MoveBG::SignTriangle_anim_data": 0x8038b344,
		"SignTriangle_anim_data": 0x8038b344,
		"MoveBG::ArrowBoardLR_hit_data_table": 0x8038b368,
		"ArrowBoardLR_hit_data_table": 0x8038b368,
		"MoveBG::ArrowBoardLR_obj_hit_info": 0x8038b378,
		"ArrowBoardLR_obj_hit_info": 0x8038b378,
		"MoveBG::ArrowBoardUp_hit_data_table": 0x8038b398,
		"ArrowBoardUp_hit_data_table": 0x8038b398,
		"MoveBG::ArrowBoardUp_obj_hit_info": 0x8038b3a8,
		"ArrowBoardUp_obj_hit_info": 0x8038b3a8,
		"MoveBG::@2826": 0x8038b3b8,
		"MoveBG::ArrowBoardDown_hit_data_table": 0x8038b3c8,
		"ArrowBoardDown_hit_data_table": 0x8038b3c8,
		"MoveBG::ArrowBoardDown_obj_hit_info": 0x8038b3d8,
		"ArrowBoardDown_obj_hit_info": 0x8038b3d8,
		"MoveBG::GeneralHitObj_hit_data_table": 0x8038b438,
		"GeneralHitObj_hit_data_table": 0x8038b438,
		"MoveBG::GeneralHitObj_obj_hit_info": 0x8038b448,
		"GeneralHitObj_obj_hit_info": 0x8038b448,
		"MoveBG::item_hit_data_table": 0x8038b468,
		"item_hit_data_table": 0x8038b468,
		"MoveBG::item_obj_hit_info": 0x8038b478,
		"item_obj_hit_info": 0x8038b478,
		"MoveBG::WaterRecoverObj_hit_data_table": 0x8038b4d4,
		"WaterRecoverObj_hit_data_table": 0x8038b4d4,
		"MoveBG::WaterRecoverObj_obj_hit_info": 0x8038b4e4,
		"WaterRecoverObj_obj_hit_info": 0x8038b4e4,
		"MoveBG::nozzle_item_hit_data_table": 0x8038b53c,
		"nozzle_item_hit_data_table": 0x8038b53c,
		"MoveBG::nozzle_item_obj_hit_info": 0x8038b54c,
		"nozzle_item_obj_hit_info": 0x8038b54c,
		"MoveBG::coin_hit_data_table": 0x8038b584,
		"coin_hit_data_table": 0x8038b584,
		"MoveBG::coin_obj_hit_info": 0x8038b594,
		"coin_obj_hit_info": 0x8038b594,
		"MoveBG::coin_sound_data": 0x8038b5a4,
		"coin_sound_data": 0x8038b5a4,
		"MoveBG::mario_cap_anim_data": 0x8038b61c,
		"mario_cap_anim_data": 0x8038b61c,
		"MoveBG::mario_cap_hit_data_table": 0x8038b630,
		"mario_cap_hit_data_table": 0x8038b630,
		"MoveBG::mario_cap_obj_hit_info": 0x8038b640,
		"mario_cap_obj_hit_info": 0x8038b640,
		"MoveBG::coin_anim_data": 0x8038b668,
		"coin_anim_data": 0x8038b668,
		"MoveBG::@2854": 0x8038b688,
		"MoveBG::eggYoshi_anim_data": 0x8038b6f0,
		"eggYoshi_anim_data": 0x8038b6f0,
		"MoveBG::eggYoshi_hit_data_table": 0x8038b740,
		"eggYoshi_hit_data_table": 0x8038b740,
		"MoveBG::eggYoshi_obj_hit_info": 0x8038b7e0,
		"eggYoshi_obj_hit_info": 0x8038b7e0,
		"MoveBG::NozzleBox_anim_data": 0x8038b854,
		"NozzleBox_anim_data": 0x8038b854,
		"MoveBG::NozzleBox_hit_data_table": 0x8038b8a4,
		"NozzleBox_hit_data_table": 0x8038b8a4,
		"MoveBG::NozzleBox_obj_hit_info": 0x8038b8b4,
		"NozzleBox_obj_hit_info": 0x8038b8b4,
		"MoveBG::mushroom1up_anim_data": 0x8038b8e0,
		"mushroom1up_anim_data": 0x8038b8e0,
		"MoveBG::mushroom1up_hit_data_table": 0x8038b8f4,
		"mushroom1up_hit_data_table": 0x8038b8f4,
		"MoveBG::mushroom1up_obj_hit_info": 0x8038b904,
		"mushroom1up_obj_hit_info": 0x8038b904,
		"MoveBG::@2871": 0x8038b940,
		"MoveBG::jumpbase_anim_data": 0x8038b950,
		"jumpbase_anim_data": 0x8038b950,
		"MoveBG::jumpbase_hit_data_table": 0x8038b964,
		"jumpbase_hit_data_table": 0x8038b964,
		"MoveBG::jumpbase_obj_hit_info": 0x8038b974,
		"jumpbase_obj_hit_info": 0x8038b974,
		"MoveBG::@2872": 0x8038b984,
		"MoveBG::fruit_hit_data_table": 0x8038b990,
		"fruit_hit_data_table": 0x8038b990,
		"MoveBG::fruit_obj_hit_info": 0x8038b9a0,
		"fruit_obj_hit_info": 0x8038b9a0,
		"MoveBG::coconut_hit_data_table": 0x8038b9b0,
		"coconut_hit_data_table": 0x8038b9b0,
		"MoveBG::coconut_obj_hit_info": 0x8038b9c0,
		"coconut_obj_hit_info": 0x8038b9c0,
		"MoveBG::fruit_sound_data": 0x8038b9d0,
		"fruit_sound_data": 0x8038b9d0,
		"MoveBG::@2873": 0x8038b9f8,
		"MoveBG::@2874": 0x8038ba08,
		"MoveBG::papaya_hit_data_table": 0x8038ba14,
		"papaya_hit_data_table": 0x8038ba14,
		"MoveBG::papaya_obj_hit_info": 0x8038ba24,
		"papaya_obj_hit_info": 0x8038ba24,
		"MoveBG::@2875": 0x8038ba34,
		"MoveBG::pine_hit_data_table": 0x8038ba40,
		"pine_hit_data_table": 0x8038ba40,
		"MoveBG::pine_obj_hit_info": 0x8038ba50,
		"pine_obj_hit_info": 0x8038ba50,
		"MoveBG::@2876": 0x8038ba60,
		"MoveBG::@2877": 0x8038ba6c,
		"MoveBG::CoverPine_anim_data": 0x8038ba7c,
		"CoverPine_anim_data": 0x8038ba7c,
		"MoveBG::cover_pine_hit_data_table": 0x8038bb08,
		"cover_pine_hit_data_table": 0x8038bb08,
		"MoveBG::cover_pine_obj_hit_info": 0x8038bb18,
		"cover_pine_obj_hit_info": 0x8038bb18,
		"MoveBG::@2878": 0x8038bb28,
		"MoveBG::durian_hit_data_table": 0x8038bb38,
		"durian_hit_data_table": 0x8038bb38,
		"MoveBG::durian_obj_hit_info": 0x8038bb48,
		"durian_obj_hit_info": 0x8038bb48,
		"MoveBG::durian_sound_data": 0x8038bb58,
		"durian_sound_data": 0x8038bb58,
		"MoveBG::@2879": 0x8038bb80,
		"MoveBG::banana_hit_data_table": 0x8038bb8c,
		"banana_hit_data_table": 0x8038bb8c,
		"MoveBG::banana_obj_hit_info": 0x8038bb9c,
		"banana_obj_hit_info": 0x8038bb9c,
		"MoveBG::@2881": 0x8038bbb8,
		"MoveBG::@2882": 0x8038bbc4,
		"MoveBG::@2883": 0x8038bbd4,
		"MoveBG::fence3x3_anim_data": 0x8038bbe4,
		"fence3x3_anim_data": 0x8038bbe4,
		"MoveBG::@2885": 0x8038bc04,
		"MoveBG::fence_revolve_outer_anim_data": 0x8038bc1c,
		"fence_revolve_outer_anim_data": 0x8038bc1c,
		"MoveBG::@2886": 0x8038bc30,
		"MoveBG::FenceInner_hit_data_table": 0x8038bc40,
		"FenceInner_hit_data_table": 0x8038bc40,
		"MoveBG::FenceInner_obj_hit_info": 0x8038bc50,
		"FenceInner_obj_hit_info": 0x8038bc50,
		"MoveBG::@2887": 0x8038bc60,
		"MoveBG::FenceWaterH_map_collision_data": 0x8038bcb0,
		"FenceWaterH_map_collision_data": 0x8038bcb0,
		"MoveBG::RailFence_anim_data": 0x8038bcd4,
		"RailFence_anim_data": 0x8038bcd4,
		"MoveBG::RailFence_map_collision_data": 0x8038bd10,
		"RailFence_map_collision_data": 0x8038bd10,
		"MoveBG::BambooRailFence_anim_data": 0x8038bd90,
		"BambooRailFence_anim_data": 0x8038bd90,
		"MoveBG::wood_barrel_anim_data": 0x8038be4c,
		"wood_barrel_anim_data": 0x8038be4c,
		"MoveBG::wood_barrel_hit_data_table": 0x8038bed8,
		"wood_barrel_hit_data_table": 0x8038bed8,
		"MoveBG::wood_barrel_obj_hit_info": 0x8038bf08,
		"wood_barrel_obj_hit_info": 0x8038bf08,
		"MoveBG::wood_barrel_map_collision_data": 0x8038bf18,
		"wood_barrel_map_collision_data": 0x8038bf18,
		"MoveBG::wood_barrel_sound_data": 0x8038bf28,
		"wood_barrel_sound_data": 0x8038bf28,
		"MoveBG::barrel_float_hit_data_table": 0x8038bfb4,
		"barrel_float_hit_data_table": 0x8038bfb4,
		"MoveBG::barrel_float_obj_hit_info": 0x8038bfc4,
		"barrel_float_obj_hit_info": 0x8038bfc4,
		"MoveBG::@2914": 0x8038bff8,
		"MoveBG::@2915": 0x8038c014,
		"MoveBG::drum_can_anim_data": 0x8038c024,
		"drum_can_anim_data": 0x8038c024,
		"MoveBG::drum_can_hit_data_table": 0x8038c060,
		"drum_can_hit_data_table": 0x8038c060,
		"MoveBG::drum_can_obj_hit_info": 0x8038c070,
		"drum_can_obj_hit_info": 0x8038c070,
		"MoveBG::drum_can_map_collision_data": 0x8038c09c,
		"drum_can_map_collision_data": 0x8038c09c,
		"MoveBG::@2918": 0x8038c0ac,
		"MoveBG::@2919": 0x8038c0bc,
		"MoveBG::barrel_oil_anim_data": 0x8038c0e4,
		"barrel_oil_anim_data": 0x8038c0e4,
		"MoveBG::barrel_oil_hit_data_table": 0x8038c170,
		"barrel_oil_hit_data_table": 0x8038c170,
		"MoveBG::barrel_oil_obj_hit_info": 0x8038c180,
		"barrel_oil_obj_hit_info": 0x8038c180,
		"MoveBG::@2920": 0x8038c190,
		"MoveBG::@2925": 0x8038c1ec,
		"MoveBG::breakable_block_anim_data": 0x8038c204,
		"breakable_block_anim_data": 0x8038c204,
		"MoveBG::breakable_block_hit_data_table": 0x8038c240,
		"breakable_block_hit_data_table": 0x8038c240,
		"MoveBG::breakable_block_obj_hit_info": 0x8038c250,
		"breakable_block_obj_hit_info": 0x8038c250,
		"MoveBG::supermario_block_obj_hit_info": 0x8038c270,
		"supermario_block_obj_hit_info": 0x8038c270,
		"MoveBG::@2928": 0x8038c294,
		"MoveBG::@2929": 0x8038c2a0,
		"MoveBG::expand_block_hit_data_table": 0x8038c2b0,
		"expand_block_hit_data_table": 0x8038c2b0,
		"MoveBG::expand_block_obj_hit_info": 0x8038c2c0,
		"expand_block_obj_hit_info": 0x8038c2c0,
		"MoveBG::spread_block_hit_data_table": 0x8038c2e0,
		"spread_block_hit_data_table": 0x8038c2e0,
		"MoveBG::spread_block_obj_hit_info": 0x8038c2f0,
		"spread_block_obj_hit_info": 0x8038c2f0,
		"MoveBG::@2931": 0x8038c300,
		"MoveBG::water_roll_block_anim_data": 0x8038c328,
		"water_roll_block_anim_data": 0x8038c328,
		"MoveBG::water_roll_block_obj_hit_info": 0x8038c33c,
		"water_roll_block_obj_hit_info": 0x8038c33c,
		"MoveBG::@2935": 0x8038c370,
		"MoveBG::sand_block_anim_data": 0x8038c37c,
		"sand_block_anim_data": 0x8038c37c,
		"MoveBG::sand_block_hit_data_table": 0x8038c3b8,
		"sand_block_hit_data_table": 0x8038c3b8,
		"MoveBG::sand_block_obj_hit_info": 0x8038c3c8,
		"sand_block_obj_hit_info": 0x8038c3c8,
		"MoveBG::sand_block_map_collision_data": 0x8038c3d8,
		"sand_block_map_collision_data": 0x8038c3d8,
		"MoveBG::@2937": 0x8038c3f4,
		"MoveBG::@2941": 0x8038c44c,
		"MoveBG::skate_block_hit_data_table": 0x8038c46c,
		"skate_block_hit_data_table": 0x8038c46c,
		"MoveBG::skate_block_obj_hit_info": 0x8038c47c,
		"skate_block_obj_hit_info": 0x8038c47c,
		"MoveBG::@2944": 0x8038c498,
		"MoveBG::@2945": 0x8038c4ac,
		"MoveBG::MoveCoin_anim_data": 0x8038c4bc,
		"MoveCoin_anim_data": 0x8038c4bc,
		"MoveBG::@2946": 0x8038c4d0,
		"MoveBG::cluster_block_anim_data": 0x8038c4f0,
		"cluster_block_anim_data": 0x8038c4f0,
		"MoveBG::@2949": 0x8038c514,
		"MoveBG::ice_block_hit_data_table": 0x8038c520,
		"ice_block_hit_data_table": 0x8038c520,
		"MoveBG::ice_block_obj_hit_info": 0x8038c530,
		"ice_block_obj_hit_info": 0x8038c530,
		"MoveBG::@2950": 0x8038c540,
		"MoveBG::@2951": 0x8038c54c,
		"MoveBG::@2952": 0x8038c55c,
		"MoveBG::BrickBlock_anim_data": 0x8038c580,
		"BrickBlock_anim_data": 0x8038c580,
		"MoveBG::@2955": 0x8038c5c8,
		"MoveBG::@2956": 0x8038c5dc,
		"MoveBG::WaterMelonBlock_anim_data": 0x8038c610,
		"WaterMelonBlock_anim_data": 0x8038c610,
		"MoveBG::WoodBlockPole_hit_data_table": 0x8038c668,
		"WoodBlockPole_hit_data_table": 0x8038c668,
		"MoveBG::WoodBlockPole_obj_hit_info": 0x8038c678,
		"WoodBlockPole_obj_hit_info": 0x8038c678,
		"MoveBG::@2963": 0x8038c6d4,
		"MoveBG::@2964": 0x8038c6e8,
		"MoveBG::@2965": 0x8038c6f8,
		"MoveBG::SuperHipDropBlock_anim_data": 0x8038c71c,
		"SuperHipDropBlock_anim_data": 0x8038c71c,
		"MoveBG::@2966": 0x8038c758,
		"MoveBG::@2967": 0x8038c764,
		"MoveBG::tree_sound_data": 0x8038c778,
		"tree_sound_data": 0x8038c778,
		"MoveBG::@2968": 0x8038c7a0,
		"MoveBG::PalmNormal_anim_data": 0x8038c7b0,
		"PalmNormal_anim_data": 0x8038c7b0,
		"MoveBG::palmNormal_hit_data_table": 0x8038c7c4,
		"palmNormal_hit_data_table": 0x8038c7c4,
		"MoveBG::palmNormal_obj_hit_info": 0x8038c7d4,
		"palmNormal_obj_hit_info": 0x8038c7d4,
		"MoveBG::@2969": 0x8038c7e4,
		"MoveBG::palmOugi_hit_data_table": 0x8038c800,
		"palmOugi_hit_data_table": 0x8038c800,
		"MoveBG::palmOugi_obj_hit_info": 0x8038c810,
		"palmOugi_obj_hit_info": 0x8038c810,
		"MoveBG::palmSago_hit_data_table": 0x8038c82c,
		"palmSago_hit_data_table": 0x8038c82c,
		"MoveBG::palmSago_obj_hit_info": 0x8038c83c,
		"palmSago_obj_hit_info": 0x8038c83c,
		"MoveBG::palmNatume_hit_data_table": 0x8038c858,
		"palmNatume_hit_data_table": 0x8038c858,
		"MoveBG::palmNatume_obj_hit_info": 0x8038c868,
		"palmNatume_obj_hit_info": 0x8038c868,
		"MoveBG::PalmLeaf_anim_data": 0x8038c894,
		"PalmLeaf_anim_data": 0x8038c894,
		"MoveBG::palmLeaf_hit_data_table": 0x8038c8a8,
		"palmLeaf_hit_data_table": 0x8038c8a8,
		"MoveBG::palmLeaf_obj_hit_info": 0x8038c8b8,
		"palmLeaf_obj_hit_info": 0x8038c8b8,
		"MoveBG::BananaTree_anim_data": 0x8038c8e4,
		"BananaTree_anim_data": 0x8038c8e4,
		"MoveBG::BananaTree_hit_data_table": 0x8038c8f8,
		"BananaTree_hit_data_table": 0x8038c8f8,
		"MoveBG::BananaTree_obj_hit_info": 0x8038c908,
		"BananaTree_obj_hit_info": 0x8038c908,
		"MoveBG::FruitTree_hit_data_table": 0x8038c924,
		"FruitTree_hit_data_table": 0x8038c924,
		"MoveBG::FruitTree_obj_hit_info": 0x8038c934,
		"FruitTree_obj_hit_info": 0x8038c934,
		"MoveBG::flower_hit_data_table": 0x8038c950,
		"flower_hit_data_table": 0x8038c950,
		"MoveBG::flower_obj_hit_info": 0x8038c960,
		"flower_obj_hit_info": 0x8038c960,
		"MoveBG::flowerOrange_anim_data": 0x8038c9a4,
		"flowerOrange_anim_data": 0x8038c9a4,
		"MoveBG::flowerPink_anim_data": 0x8038c9fc,
		"flowerPink_anim_data": 0x8038c9fc,
		"MoveBG::flowerPurple_anim_data": 0x8038ca58,
		"flowerPurple_anim_data": 0x8038ca58,
		"MoveBG::@2991": 0x8038caa0,
		"MoveBG::flowerRed_anim_data": 0x8038cab0,
		"flowerRed_anim_data": 0x8038cab0,
		"MoveBG::flowerYellow_anim_data": 0x8038cb0c,
		"flowerYellow_anim_data": 0x8038cb0c,
		"MoveBG::flowerSunflower_anim_data": 0x8038cb70,
		"flowerSunflower_anim_data": 0x8038cb70,
		"MoveBG::pole_sound_data": 0x8038cba8,
		"pole_sound_data": 0x8038cba8,
		"MoveBG::telegraph_pole_l_hit_data_table": 0x8038cbd0,
		"telegraph_pole_l_hit_data_table": 0x8038cbd0,
		"MoveBG::telegraph_pole_l_obj_hit_info": 0x8038cbe0,
		"telegraph_pole_l_obj_hit_info": 0x8038cbe0,
		"MoveBG::telegraph_pole_s_hit_data_table": 0x8038cc04,
		"telegraph_pole_s_hit_data_table": 0x8038cc04,
		"MoveBG::telegraph_pole_s_obj_hit_info": 0x8038cc14,
		"telegraph_pole_s_obj_hit_info": 0x8038cc14,
		"MoveBG::dptlight_anim_data": 0x8038cc74,
		"dptlight_anim_data": 0x8038cc74,
		"MoveBG::streetlamp_hit_data_table": 0x8038cd00,
		"streetlamp_hit_data_table": 0x8038cd00,
		"MoveBG::streetlamp_obj_hit_info": 0x8038cd30,
		"streetlamp_obj_hit_info": 0x8038cd30,
		"MoveBG::streetlamp_map_collision_data": 0x8038cd5c,
		"streetlamp_map_collision_data": 0x8038cd5c,
		"MoveBG::PoleNormal_hit_data_table": 0x8038cd6c,
		"PoleNormal_hit_data_table": 0x8038cd6c,
		"MoveBG::PoleNormal_obj_hit_info": 0x8038cd7c,
		"PoleNormal_obj_hit_info": 0x8038cd7c,
		"MoveBG::football_anim_data": 0x8038cda8,
		"football_anim_data": 0x8038cda8,
		"MoveBG::football_hit_data_table": 0x8038cdbc,
		"football_hit_data_table": 0x8038cdbc,
		"MoveBG::football_obj_hit_info": 0x8038cdcc,
		"football_obj_hit_info": 0x8038cdcc,
		"MoveBG::football_sound_data": 0x8038cddc,
		"football_sound_data": 0x8038cddc,
		"MoveBG::football_goal_anim_data": 0x8038ce28,
		"football_goal_anim_data": 0x8038ce28,
		"MoveBG::football_goal_hit_data_table": 0x8038ce3c,
		"football_goal_hit_data_table": 0x8038ce3c,
		"MoveBG::football_goal_obj_hit_info": 0x8038ce4c,
		"football_goal_obj_hit_info": 0x8038ce4c,
		"MoveBG::football_goal_map_collision_data": 0x8038ce7c,
		"football_goal_map_collision_data": 0x8038ce7c,
		"MoveBG::@3013": 0x8038ce9c,
		"MoveBG::@3014": 0x8038cea8,
		"MoveBG::@3015": 0x8038ceb8,
		"MoveBG::@3016": 0x8038cec8,
		"MoveBG::@3017": 0x8038cedc,
		"MoveBG::Watermelon_anim_data": 0x8038cf00,
		"Watermelon_anim_data": 0x8038cf00,
		"MoveBG::watermelon_hit_data_table": 0x8038cfa0,
		"watermelon_hit_data_table": 0x8038cfa0,
		"MoveBG::watermelon_obj_hit_info": 0x8038cfb0,
		"watermelon_obj_hit_info": 0x8038cfb0,
		"MoveBG::watermelon_sound_data": 0x8038cfc0,
		"watermelon_sound_data": 0x8038cfc0,
		"MoveBG::@3018": 0x8038cfe8,
		"MoveBG::WatermelonStatic_anim_data": 0x8038cff4,
		"WatermelonStatic_anim_data": 0x8038cff4,
		"MoveBG::@3019": 0x8038d008,
		"MoveBG::@3020": 0x8038d01c,
		"MoveBG::@3021": 0x8038d028,
		"MoveBG::cloud_anim_data": 0x8038d034,
		"cloud_anim_data": 0x8038d034,
		"MoveBG::cloud_hit_data_table": 0x8038d048,
		"cloud_hit_data_table": 0x8038d048,
		"MoveBG::cloud_obj_hit_info": 0x8038d058,
		"cloud_obj_hit_info": 0x8038d058,
		"MoveBG::normallift_anim_data": 0x8038d078,
		"normallift_anim_data": 0x8038d078,
		"MoveBG::normallift_hit_data_table": 0x8038d08c,
		"normallift_hit_data_table": 0x8038d08c,
		"MoveBG::normallift_obj_hit_info": 0x8038d09c,
		"normallift_obj_hit_info": 0x8038d09c,
		"MoveBG::exrollcube_anim_data": 0x8038d0c8,
		"exrollcube_anim_data": 0x8038d0c8,
		"MoveBG::exrollcube_hit_data_table": 0x8038d0dc,
		"exrollcube_hit_data_table": 0x8038d0dc,
		"MoveBG::exrollcube_obj_hit_info": 0x8038d0ec,
		"exrollcube_obj_hit_info": 0x8038d0ec,
		"MoveBG::exkickboard_anim_data": 0x8038d124,
		"exkickboard_anim_data": 0x8038d124,
		"MoveBG::exkickboard_hit_data_table": 0x8038d138,
		"exkickboard_hit_data_table": 0x8038d138,
		"MoveBG::exkickboard_obj_hit_info": 0x8038d148,
		"exkickboard_obj_hit_info": 0x8038d148,
		"MoveBG::railblockr_anim_data": 0x8038d188,
		"railblockr_anim_data": 0x8038d188,
		"MoveBG::railblocky_anim_data": 0x8038d1b4,
		"railblocky_anim_data": 0x8038d1b4,
		"MoveBG::railblockb_anim_data": 0x8038d1e0,
		"railblockb_anim_data": 0x8038d1e0,
		"MoveBG::railblock_hit_data_table": 0x8038d1f4,
		"railblock_hit_data_table": 0x8038d1f4,
		"MoveBG::railblock_obj_hit_info": 0x8038d204,
		"railblock_obj_hit_info": 0x8038d204,
		"MoveBG::umaibou_anim_data": 0x8038d278,
		"umaibou_anim_data": 0x8038d278,
		"MoveBG::umaibou_hit_data_table": 0x8038d28c,
		"umaibou_hit_data_table": 0x8038d28c,
		"MoveBG::umaibou_obj_hit_info": 0x8038d29c,
		"umaibou_obj_hit_info": 0x8038d29c,
		"MoveBG::kamaboko_anim_data": 0x8038d2bc,
		"kamaboko_anim_data": 0x8038d2bc,
		"MoveBG::kamaboko_hit_data_table": 0x8038d2d0,
		"kamaboko_hit_data_table": 0x8038d2d0,
		"MoveBG::kamaboko_obj_hit_info": 0x8038d2e0,
		"kamaboko_obj_hit_info": 0x8038d2e0,
		"MoveBG::getag_anim_data": 0x8038d30c,
		"getag_anim_data": 0x8038d30c,
		"MoveBG::getao_anim_data": 0x8038d330,
		"getao_anim_data": 0x8038d330,
		"MoveBG::geta_hit_data_table": 0x8038d344,
		"geta_hit_data_table": 0x8038d344,
		"MoveBG::geta_obj_hit_info": 0x8038d354,
		"geta_obj_hit_info": 0x8038d354,
		"MoveBG::uirou_anim_data": 0x8038d370,
		"uirou_anim_data": 0x8038d370,
		"MoveBG::uirou_hit_data_table": 0x8038d384,
		"uirou_hit_data_table": 0x8038d384,
		"MoveBG::uirou_obj_hit_info": 0x8038d394,
		"uirou_obj_hit_info": 0x8038d394,
		"MoveBG::hikidashi_anim_data": 0x8038d3b4,
		"hikidashi_anim_data": 0x8038d3b4,
		"MoveBG::hikidashi_hit_data_table": 0x8038d3c8,
		"hikidashi_hit_data_table": 0x8038d3c8,
		"MoveBG::hikidashi_obj_hit_info": 0x8038d3d8,
		"hikidashi_obj_hit_info": 0x8038d3d8,
		"MoveBG::castella_anim_data": 0x8038d404,
		"castella_anim_data": 0x8038d404,
		"MoveBG::castella_hit_data_table": 0x8038d418,
		"castella_hit_data_table": 0x8038d418,
		"MoveBG::castella_obj_hit_info": 0x8038d428,
		"castella_obj_hit_info": 0x8038d428,
		"MoveBG::yoshiblock_anim_data": 0x8038d454,
		"yoshiblock_anim_data": 0x8038d454,
		"MoveBG::yoshiblock_hit_data_table": 0x8038d468,
		"yoshiblock_hit_data_table": 0x8038d468,
		"MoveBG::yoshiblock_obj_hit_info": 0x8038d478,
		"yoshiblock_obj_hit_info": 0x8038d478,
		"MoveBG::@3057": 0x8038d488,
		"MoveBG::@3058": 0x8038d494,
		"MoveBG::@3062": 0x8038d4dc,
		"MoveBG::@3063": 0x8038d4ec,
		"MoveBG::@3065": 0x8038d508,
		"MoveBG::normalvariant0_hit_data_table": 0x8038d518,
		"normalvariant0_hit_data_table": 0x8038d518,
		"MoveBG::normalvariant0_obj_hit_info": 0x8038d528,
		"normalvariant0_obj_hit_info": 0x8038d528,
		"MoveBG::normalvariant1_hit_data_table": 0x8038d548,
		"normalvariant1_hit_data_table": 0x8038d548,
		"MoveBG::normalvariant1_obj_hit_info": 0x8038d558,
		"normalvariant1_obj_hit_info": 0x8038d558,
		"MoveBG::@3067": 0x8038d568,
		"MoveBG::normalvariant2_hit_data_table": 0x8038d578,
		"normalvariant2_hit_data_table": 0x8038d578,
		"MoveBG::normalvariant2_obj_hit_info": 0x8038d588,
		"normalvariant2_obj_hit_info": 0x8038d588,
		"MoveBG::normalvariant3_hit_data_table": 0x8038d5a8,
		"normalvariant3_hit_data_table": 0x8038d5a8,
		"MoveBG::normalvariant3_obj_hit_info": 0x8038d5b8,
		"normalvariant3_obj_hit_info": 0x8038d5b8,
		"MoveBG::@3069": 0x8038d5c8,
		"MoveBG::normalvariant4_hit_data_table": 0x8038d5d8,
		"normalvariant4_hit_data_table": 0x8038d5d8,
		"MoveBG::normalvariant4_obj_hit_info": 0x8038d5e8,
		"normalvariant4_obj_hit_info": 0x8038d5e8,
		"MoveBG::railvariant0_hit_data_table": 0x8038d608,
		"railvariant0_hit_data_table": 0x8038d608,
		"MoveBG::railvariant0_obj_hit_info": 0x8038d618,
		"railvariant0_obj_hit_info": 0x8038d618,
		"MoveBG::railvariant1_hit_data_table": 0x8038d638,
		"railvariant1_hit_data_table": 0x8038d638,
		"MoveBG::railvariant1_obj_hit_info": 0x8038d648,
		"railvariant1_obj_hit_info": 0x8038d648,
		"MoveBG::@3072": 0x8038d658,
		"MoveBG::railvariant2_hit_data_table": 0x8038d668,
		"railvariant2_hit_data_table": 0x8038d668,
		"MoveBG::railvariant2_obj_hit_info": 0x8038d678,
		"railvariant2_obj_hit_info": 0x8038d678,
		"MoveBG::@3073": 0x8038d688,
		"MoveBG::railvariant3_hit_data_table": 0x8038d698,
		"railvariant3_hit_data_table": 0x8038d698,
		"MoveBG::railvariant3_obj_hit_info": 0x8038d6a8,
		"railvariant3_obj_hit_info": 0x8038d6a8,
		"MoveBG::railvariant4_hit_data_table": 0x8038d6c8,
		"railvariant4_hit_data_table": 0x8038d6c8,
		"MoveBG::railvariant4_obj_hit_info": 0x8038d6d8,
		"railvariant4_obj_hit_info": 0x8038d6d8,
		"MoveBG::rollvariant0_hit_data_table": 0x8038d6f8,
		"rollvariant0_hit_data_table": 0x8038d6f8,
		"MoveBG::rollvariant0_obj_hit_info": 0x8038d708,
		"rollvariant0_obj_hit_info": 0x8038d708,
		"MoveBG::@3076": 0x8038d718,
		"MoveBG::rollvariant1_hit_data_table": 0x8038d728,
		"rollvariant1_hit_data_table": 0x8038d728,
		"MoveBG::rollvariant1_obj_hit_info": 0x8038d738,
		"rollvariant1_obj_hit_info": 0x8038d738,
		"MoveBG::@3077": 0x8038d748,
		"MoveBG::rollvariant2_hit_data_table": 0x8038d758,
		"rollvariant2_hit_data_table": 0x8038d758,
		"MoveBG::rollvariant2_obj_hit_info": 0x8038d768,
		"rollvariant2_obj_hit_info": 0x8038d768,
		"MoveBG::@3078": 0x8038d778,
		"MoveBG::rollvariant3_hit_data_table": 0x8038d788,
		"rollvariant3_hit_data_table": 0x8038d788,
		"MoveBG::rollvariant3_obj_hit_info": 0x8038d798,
		"rollvariant3_obj_hit_info": 0x8038d798,
		"MoveBG::@3079": 0x8038d7a8,
		"MoveBG::rollvariant4_hit_data_table": 0x8038d7b8,
		"rollvariant4_hit_data_table": 0x8038d7b8,
		"MoveBG::rollvariant4_obj_hit_info": 0x8038d7c8,
		"rollvariant4_obj_hit_info": 0x8038d7c8,
		"MoveBG::lamptrapspike_anim_data": 0x8038d7fc,
		"lamptrapspike_anim_data": 0x8038d7fc,
		"MoveBG::lamptrapiron_anim_data": 0x8038d824,
		"lamptrapiron_anim_data": 0x8038d824,
		"MoveBG::lamptrap_hit_data_table": 0x8038d838,
		"lamptrap_hit_data_table": 0x8038d838,
		"MoveBG::lamptrap_obj_hit_info": 0x8038d848,
		"lamptrap_obj_hit_info": 0x8038d848,
		"MoveBG::@3088": 0x8038d89c,
		"MoveBG::WoodBox_anim_data": 0x8038d8c0,
		"WoodBox_anim_data": 0x8038d8c0,
		"MoveBG::WoodBox_sound_data": 0x8038d8fc,
		"WoodBox_sound_data": 0x8038d8fc,
		"MoveBG::AirportPole_hit_data_table": 0x8038d924,
		"AirportPole_hit_data_table": 0x8038d924,
		"MoveBG::AirportPole_obj_hit_info": 0x8038d934,
		"AirportPole_obj_hit_info": 0x8038d934,
		"MoveBG::@3093": 0x8038d950,
		"MoveBG::@3094": 0x8038d95c,
		"MoveBG::ice_car_anim_data": 0x8038d968,
		"ice_car_anim_data": 0x8038d968,
		"MoveBG::ice_car_hit_data_table": 0x8038d9f4,
		"ice_car_hit_data_table": 0x8038d9f4,
		"MoveBG::ice_car_obj_hit_info": 0x8038da04,
		"ice_car_obj_hit_info": 0x8038da04,
		"MoveBG::AirportBuoy_hit_data_table": 0x8038da24,
		"AirportBuoy_hit_data_table": 0x8038da24,
		"MoveBG::AirportBuoy_obj_hit_info": 0x8038da34,
		"AirportBuoy_obj_hit_info": 0x8038da34,
		"MoveBG::dptKing_map_collision_data": 0x8038da50,
		"dptKing_map_collision_data": 0x8038da50,
		"MoveBG::monumentshine_anim_data": 0x8038da88,
		"monumentshine_anim_data": 0x8038da88,
		"MoveBG::monumentshine_hit_data_table": 0x8038da9c,
		"monumentshine_hit_data_table": 0x8038da9c,
		"MoveBG::monumentshine_obj_hit_info": 0x8038daac,
		"monumentshine_obj_hit_info": 0x8038daac,
		"MoveBG::belldolpic_anim_data": 0x8038dadc,
		"belldolpic_anim_data": 0x8038dadc,
		"MoveBG::belldolpic_hit_data_table": 0x8038daf0,
		"belldolpic_hit_data_table": 0x8038daf0,
		"MoveBG::belldolpic_obj_hit_info": 0x8038db00,
		"belldolpic_obj_hit_info": 0x8038db00,
		"MoveBG::DptWeathercock_anim_data": 0x8038db40,
		"DptWeathercock_anim_data": 0x8038db40,
		"MoveBG::DptWeathercock_hit_data_table": 0x8038db54,
		"DptWeathercock_hit_data_table": 0x8038db54,
		"MoveBG::DptWeathercock_obj_hit_info": 0x8038db64,
		"DptWeathercock_obj_hit_info": 0x8038db64,
		"MoveBG::DptMonteFence_hit_data_table": 0x8038db84,
		"DptMonteFence_hit_data_table": 0x8038db84,
		"MoveBG::DptMonteFence_obj_hit_info": 0x8038db94,
		"DptMonteFence_obj_hit_info": 0x8038db94,
		"MoveBG::MapSmoke_hit_data_table": 0x8038dbc4,
		"MapSmoke_hit_data_table": 0x8038dbc4,
		"MoveBG::MapSmoke_obj_hit_info": 0x8038dbd4,
		"MapSmoke_obj_hit_info": 0x8038dbd4,
		"MoveBG::@3112": 0x8038dbf0,
		"MoveBG::MareGate_anim_data": 0x8038dc0c,
		"MareGate_anim_data": 0x8038dc0c,
		"MoveBG::NozzleDoor_anim_data": 0x8038dc48,
		"NozzleDoor_anim_data": 0x8038dc48,
		"MoveBG::NozzleDoor_hit_data_table": 0x8038dc70,
		"NozzleDoor_hit_data_table": 0x8038dc70,
		"MoveBG::NozzleDoor_obj_hit_info": 0x8038dc80,
		"NozzleDoor_obj_hit_info": 0x8038dc80,
		"MoveBG::DokanGate_anim_data": 0x8038dcb8,
		"DokanGate_anim_data": 0x8038dcb8,
		"MoveBG::Crane_hit_data_table": 0x8038dcd8,
		"Crane_hit_data_table": 0x8038dcd8,
		"MoveBG::Crane_obj_hit_info": 0x8038dce8,
		"Crane_obj_hit_info": 0x8038dce8,
		"MoveBG::CraneUpDown_hit_data_table": 0x8038dd18,
		"CraneUpDown_hit_data_table": 0x8038dd18,
		"MoveBG::CraneUpDown_obj_hit_info": 0x8038dd28,
		"CraneUpDown_obj_hit_info": 0x8038dd28,
		"MoveBG::crane_cargo_hit_data_table": 0x8038dd44,
		"crane_cargo_hit_data_table": 0x8038dd44,
		"MoveBG::crane_cargo_obj_hit_info": 0x8038dd54,
		"crane_cargo_obj_hit_info": 0x8038dd54,
		"MoveBG::Submarine_hit_data_table": 0x8038dd84,
		"Submarine_hit_data_table": 0x8038dd84,
		"MoveBG::Submarine_obj_hit_info": 0x8038dd94,
		"Submarine_obj_hit_info": 0x8038dd94,
		"MoveBG::submarine_map_collision_data": 0x8038ddb0,
		"submarine_map_collision_data": 0x8038ddb0,
		"MoveBG::ricco_ship_hit_data_table": 0x8038ddc0,
		"ricco_ship_hit_data_table": 0x8038ddc0,
		"MoveBG::ricco_ship_obj_hit_info": 0x8038ddd0,
		"ricco_ship_obj_hit_info": 0x8038ddd0,
		"MoveBG::ricco_pole_hit_data_table": 0x8038ddec,
		"ricco_pole_hit_data_table": 0x8038ddec,
		"MoveBG::ricco_pole_obj_hit_info": 0x8038ddfc,
		"ricco_pole_obj_hit_info": 0x8038ddfc,
		"MoveBG::riccoLog_hit_data_table": 0x8038de18,
		"riccoLog_hit_data_table": 0x8038de18,
		"MoveBG::riccoLog_obj_hit_info": 0x8038de28,
		"riccoLog_obj_hit_info": 0x8038de28,
		"MoveBG::gesoSurfboard_anim_data": 0x8038de54,
		"gesoSurfboard_anim_data": 0x8038de54,
		"MoveBG::gesoSurfboard_hit_data_table": 0x8038de68,
		"gesoSurfboard_hit_data_table": 0x8038de68,
		"MoveBG::gesoSurfboard_obj_hit_info": 0x8038de78,
		"gesoSurfboard_obj_hit_info": 0x8038de78,
		"MoveBG::riccoWatermill_hit_data_table": 0x8038deac,
		"riccoWatermill_hit_data_table": 0x8038deac,
		"MoveBG::riccoWatermill_obj_hit_info": 0x8038debc,
		"riccoWatermill_obj_hit_info": 0x8038debc,
		"MoveBG::riccoShipLog_hit_data_table": 0x8038dedc,
		"riccoShipLog_hit_data_table": 0x8038dedc,
		"MoveBG::riccoShipLog_obj_hit_info": 0x8038deec,
		"riccoShipLog_obj_hit_info": 0x8038deec,
		"MoveBG::riccoShipDol_hit_data_table": 0x8038df0c,
		"riccoShipDol_hit_data_table": 0x8038df0c,
		"MoveBG::riccoShipDol_obj_hit_info": 0x8038df1c,
		"riccoShipDol_obj_hit_info": 0x8038df1c,
		"MoveBG::riccoYachtL_hit_data_table": 0x8038df3c,
		"riccoYachtL_hit_data_table": 0x8038df3c,
		"MoveBG::riccoYachtL_obj_hit_info": 0x8038df4c,
		"riccoYachtL_obj_hit_info": 0x8038df4c,
		"MoveBG::riccoYachtS_hit_data_table": 0x8038df68,
		"riccoYachtS_hit_data_table": 0x8038df68,
		"MoveBG::riccoYachtS_obj_hit_info": 0x8038df78,
		"riccoYachtS_obj_hit_info": 0x8038df78,
		"MoveBG::riccoBoatL_hit_data_table": 0x8038df94,
		"riccoBoatL_hit_data_table": 0x8038df94,
		"MoveBG::riccoBoatL_obj_hit_info": 0x8038dfa4,
		"riccoBoatL_obj_hit_info": 0x8038dfa4,
		"MoveBG::riccoBoatS_hit_data_table": 0x8038dfc0,
		"riccoBoatS_hit_data_table": 0x8038dfc0,
		"MoveBG::riccoBoatS_obj_hit_info": 0x8038dfd0,
		"riccoBoatS_obj_hit_info": 0x8038dfd0,
		"MoveBG::surfgeso_hit_data_table": 0x8038e0a0,
		"surfgeso_hit_data_table": 0x8038e0a0,
		"MoveBG::surfgeso_obj_hit_info": 0x8038e0b0,
		"surfgeso_obj_hit_info": 0x8038e0b0,
		"MoveBG::surfgeso_anim_data": 0x8038e0d0,
		"surfgeso_anim_data": 0x8038e0d0,
		"MoveBG::@3157": 0x8038e100,
		"MoveBG::windmill_anim_data": 0x8038e120,
		"windmill_anim_data": 0x8038e120,
		"MoveBG::Windmill_hit_data_table": 0x8038e134,
		"Windmill_hit_data_table": 0x8038e134,
		"MoveBG::Windmill_obj_hit_info": 0x8038e144,
		"Windmill_obj_hit_info": 0x8038e144,
		"MoveBG::MiniWindmill_hit_data_table": 0x8038e170,
		"MiniWindmill_hit_data_table": 0x8038e170,
		"MoveBG::MiniWindmill_obj_hit_info": 0x8038e180,
		"MiniWindmill_obj_hit_info": 0x8038e180,
		"MoveBG::@3162": 0x8038e1a0,
		"MoveBG::@3163": 0x8038e1b0,
		"MoveBG::@3164": 0x8038e1c0,
		"MoveBG::lamp_bianco_anim_data": 0x8038e1d0,
		"lamp_bianco_anim_data": 0x8038e1d0,
		"MoveBG::lamp_bianco_hit_data_table": 0x8038e25c,
		"lamp_bianco_hit_data_table": 0x8038e25c,
		"MoveBG::lamp_bianco_obj_hit_info": 0x8038e28c,
		"lamp_bianco_obj_hit_info": 0x8038e28c,
		"MoveBG::@3165": 0x8038e29c,
		"MoveBG::lamp_bianco_map_collision_data": 0x8038e2a8,
		"lamp_bianco_map_collision_data": 0x8038e2a8,
		"MoveBG::WindmillBlock_hit_data_table": 0x8038e2c4,
		"WindmillBlock_hit_data_table": 0x8038e2c4,
		"MoveBG::WindmillBlock_obj_hit_info": 0x8038e2d4,
		"WindmillBlock_obj_hit_info": 0x8038e2d4,
		"MoveBG::PolluterPakkun_hit_data_table": 0x8038e2f8,
		"PolluterPakkun_hit_data_table": 0x8038e2f8,
		"MoveBG::PolluterPakkun_obj_hit_info": 0x8038e308,
		"PolluterPakkun_obj_hit_info": 0x8038e308,
		"MoveBG::@3168": 0x8038e318,
		"MoveBG::@3169": 0x8038e328,
		"MoveBG::BiaBell_anim_data": 0x8038e364,
		"BiaBell_anim_data": 0x8038e364,
		"MoveBG::BiaBell_hit_data_table": 0x8038e3c8,
		"BiaBell_hit_data_table": 0x8038e3c8,
		"MoveBG::BiaBell_obj_hit_info": 0x8038e3d8,
		"BiaBell_obj_hit_info": 0x8038e3d8,
		"MoveBG::watermill00_anim_data": 0x8038e424,
		"watermill00_anim_data": 0x8038e424,
		"MoveBG::BiaWatermill00_hit_data_table": 0x8038e438,
		"BiaWatermill00_hit_data_table": 0x8038e438,
		"MoveBG::BiaWatermill00_obj_hit_info": 0x8038e448,
		"BiaWatermill00_obj_hit_info": 0x8038e448,
		"MoveBG::@3177": 0x8038e458,
		"MoveBG::BiaWatermill01_hit_data_table": 0x8038e468,
		"BiaWatermill01_hit_data_table": 0x8038e468,
		"MoveBG::BiaWatermill01_obj_hit_info": 0x8038e478,
		"BiaWatermill01_obj_hit_info": 0x8038e478,
		"MoveBG::@3178": 0x8038e488,
		"MoveBG::BiaWatermillVertical_hit_data_table": 0x8038e498,
		"BiaWatermillVertical_hit_data_table": 0x8038e498,
		"MoveBG::BiaWatermillVertical_obj_hit_info": 0x8038e4a8,
		"BiaWatermillVertical_obj_hit_info": 0x8038e4a8,
		"MoveBG::@3179": 0x8038e4b8,
		"MoveBG::BiaTurnBridge_hit_data_table": 0x8038e4d0,
		"BiaTurnBridge_hit_data_table": 0x8038e4d0,
		"MoveBG::BiaTurnBridge_obj_hit_info": 0x8038e4e0,
		"BiaTurnBridge_obj_hit_info": 0x8038e4e0,
		"MoveBG::@3180": 0x8038e4f0,
		"MoveBG::LeafBoat_hit_data_table": 0x8038e500,
		"LeafBoat_hit_data_table": 0x8038e500,
		"MoveBG::LeafBoat_obj_hit_info": 0x8038e510,
		"LeafBoat_obj_hit_info": 0x8038e510,
		"MoveBG::LampSeesaw_anim_data": 0x8038e53c,
		"LampSeesaw_anim_data": 0x8038e53c,
		"MoveBG::LampSeesaw_hit_data_table": 0x8038e550,
		"LampSeesaw_hit_data_table": 0x8038e550,
		"MoveBG::LampSeesaw_obj_hit_info": 0x8038e580,
		"LampSeesaw_obj_hit_info": 0x8038e580,
		"MoveBG::SandBird_anim_data": 0x8038e5c4,
		"SandBird_anim_data": 0x8038e5c4,
		"MoveBG::SandBirdBlock_hit_data_table": 0x8038e5e4,
		"SandBirdBlock_hit_data_table": 0x8038e5e4,
		"MoveBG::SandBirdBlock_obj_hit_info": 0x8038e5f4,
		"SandBirdBlock_obj_hit_info": 0x8038e5f4,
		"MoveBG::SandBirdBlock_map_collision_data": 0x8038e614,
		"SandBirdBlock_map_collision_data": 0x8038e614,
		"MoveBG::@3191": 0x8038e634,
		"MoveBG::SkyIsland_anim_data": 0x8038e640,
		"SkyIsland_anim_data": 0x8038e640,
		"MoveBG::@3192": 0x8038e654,
		"MoveBG::SandLeaf_anim_data": 0x8038e6b0,
		"SandLeaf_anim_data": 0x8038e6b0,
		"MoveBG::sand_leaf_hit_data_table": 0x8038e714,
		"sand_leaf_hit_data_table": 0x8038e714,
		"MoveBG::sand_leaf_obj_hit_info": 0x8038e724,
		"sand_leaf_obj_hit_info": 0x8038e724,
		"MoveBG::SandLeafBase00_anim_data": 0x8038e754,
		"SandLeafBase00_anim_data": 0x8038e754,
		"MoveBG::SandLeafBase00_map_collision_data": 0x8038e778,
		"SandLeafBase00_map_collision_data": 0x8038e778,
		"MoveBG::SandLeafBase01_anim_data": 0x8038e79c,
		"SandLeafBase01_anim_data": 0x8038e79c,
		"MoveBG::SandLeafBase01_map_collision_data": 0x8038e7c0,
		"SandLeafBase01_map_collision_data": 0x8038e7c0,
		"MoveBG::SandLeafBase02_anim_data": 0x8038e7e4,
		"SandLeafBase02_anim_data": 0x8038e7e4,
		"MoveBG::SandLeafBase02_map_collision_data": 0x8038e808,
		"SandLeafBase02_map_collision_data": 0x8038e808,
		"MoveBG::SandLeafBase03_anim_data": 0x8038e82c,
		"SandLeafBase03_anim_data": 0x8038e82c,
		"MoveBG::SandLeafBase03_map_collision_data": 0x8038e850,
		"SandLeafBase03_map_collision_data": 0x8038e850,
		"MoveBG::SandBomb_anim_data": 0x8038e8b0,
		"SandBomb_anim_data": 0x8038e8b0,
		"MoveBG::sand_bomb_hit_data_table": 0x8038e93c,
		"sand_bomb_hit_data_table": 0x8038e93c,
		"MoveBG::sand_bomb_obj_hit_info": 0x8038e94c,
		"sand_bomb_obj_hit_info": 0x8038e94c,
		"MoveBG::@3212": 0x8038e95c,
		"MoveBG::mirror_L_hit_data_table": 0x8038e968,
		"mirror_L_hit_data_table": 0x8038e968,
		"MoveBG::mirror_L_obj_hit_info": 0x8038e978,
		"mirror_L_obj_hit_info": 0x8038e978,
		"MoveBG::mirror_L_map_collision_data": 0x8038e988,
		"mirror_L_map_collision_data": 0x8038e988,
		"MoveBG::mirror_M_hit_data_table": 0x8038e998,
		"mirror_M_hit_data_table": 0x8038e998,
		"MoveBG::mirror_M_obj_hit_info": 0x8038e9a8,
		"mirror_M_obj_hit_info": 0x8038e9a8,
		"MoveBG::mirror_M_map_collision_data": 0x8038e9b8,
		"mirror_M_map_collision_data": 0x8038e9b8,
		"MoveBG::mirrorS_hit_data_table": 0x8038e9c8,
		"mirrorS_hit_data_table": 0x8038e9c8,
		"MoveBG::mirrorS_obj_hit_info": 0x8038e9d8,
		"mirrorS_obj_hit_info": 0x8038e9d8,
		"MoveBG::mirrorS_map_collision_data": 0x8038e9e8,
		"mirrorS_map_collision_data": 0x8038e9e8,
		"MoveBG::@3218": 0x8038ea18,
		"MoveBG::SandCastle_anim_data": 0x8038ea28,
		"SandCastle_anim_data": 0x8038ea28,
		"MoveBG::@3219": 0x8038ea78,
		"MoveBG::SandCastle_map_collision_data": 0x8038ea84,
		"SandCastle_map_collision_data": 0x8038ea84,
		"MoveBG::MammaBlockRotate_map_collision_data": 0x8038eaa8,
		"MammaBlockRotate_map_collision_data": 0x8038eaa8,
		"MoveBG::MammaSurfboard_hit_data_table": 0x8038eae8,
		"MammaSurfboard_hit_data_table": 0x8038eae8,
		"MoveBG::MammaSurfboard_obj_hit_info": 0x8038eaf8,
		"MammaSurfboard_obj_hit_info": 0x8038eaf8,
		"MoveBG::@3225": 0x8038eb1c,
		"MoveBG::@3226": 0x8038eb30,
		"MoveBG::@3227": 0x8038eb44,
		"MoveBG::@3228": 0x8038eb58,
		"MoveBG::MammaYacht00_hit_data_table": 0x8038eb6c,
		"MammaYacht00_hit_data_table": 0x8038eb6c,
		"MoveBG::MammaYacht00_obj_hit_info": 0x8038eb7c,
		"MammaYacht00_obj_hit_info": 0x8038eb7c,
		"MoveBG::@3229": 0x8038eb8c,
		"MoveBG::SandBombBase00_anim_data": 0x8038ebe0,
		"SandBombBase00_anim_data": 0x8038ebe0,
		"MoveBG::SandBombBase00_map_collision_data": 0x8038ec18,
		"SandBombBase00_map_collision_data": 0x8038ec18,
		"MoveBG::SandBombBaseMushroom_anim_data": 0x8038ec44,
		"SandBombBaseMushroom_anim_data": 0x8038ec44,
		"MoveBG::SandBombBaseMushroom_map_collision_data": 0x8038ec84,
		"SandBombBaseMushroom_map_collision_data": 0x8038ec84,
		"MoveBG::SandBombBasePyramid_anim_data": 0x8038ecac,
		"SandBombBasePyramid_anim_data": 0x8038ecac,
		"MoveBG::SandBombBasePyramid_map_collision_data": 0x8038ece8,
		"SandBombBasePyramid_map_collision_data": 0x8038ece8,
		"MoveBG::SandBombBaseShit_anim_data": 0x8038ed10,
		"SandBombBaseShit_anim_data": 0x8038ed10,
		"MoveBG::SandBombBaseShit_map_collision_data": 0x8038ed4c,
		"SandBombBaseShit_map_collision_data": 0x8038ed4c,
		"MoveBG::SandBombBaseStar_anim_data": 0x8038ed74,
		"SandBombBaseStar_anim_data": 0x8038ed74,
		"MoveBG::SandBombBaseStar_map_collision_data": 0x8038edb0,
		"SandBombBaseStar_map_collision_data": 0x8038edb0,
		"MoveBG::SandBombBaseTurtle_anim_data": 0x8038edd8,
		"SandBombBaseTurtle_anim_data": 0x8038edd8,
		"MoveBG::SandBombBaseTurtle_map_collision_data": 0x8038ee14,
		"SandBombBaseTurtle_map_collision_data": 0x8038ee14,
		"MoveBG::SandBombBaseFoot_anim_data": 0x8038ee3c,
		"SandBombBaseFoot_anim_data": 0x8038ee3c,
		"MoveBG::SandBombBaseFoot_map_collision_data": 0x8038ee78,
		"SandBombBaseFoot_map_collision_data": 0x8038ee78,
		"MoveBG::SandBombBaseHand_anim_data": 0x8038eea0,
		"SandBombBaseHand_anim_data": 0x8038eea0,
		"MoveBG::SandBombBaseHand_map_collision_data": 0x8038eedc,
		"SandBombBaseHand_map_collision_data": 0x8038eedc,
		"MoveBG::SandBombBaseStairs_anim_data": 0x8038ef04,
		"SandBombBaseStairs_anim_data": 0x8038ef04,
		"MoveBG::SandBombBaseStairs_map_collision_data": 0x8038ef40,
		"SandBombBaseStairs_map_collision_data": 0x8038ef40,
		"MoveBG::GoalWatermelon_hit_data_table": 0x8038ef50,
		"GoalWatermelon_hit_data_table": 0x8038ef50,
		"MoveBG::GoalWatermelon_obj_hit_info": 0x8038ef60,
		"GoalWatermelon_obj_hit_info": 0x8038ef60,
		"MoveBG::TeethOfJuicer_anim_data": 0x8038efa4,
		"TeethOfJuicer_anim_data": 0x8038efa4,
		"MoveBG::TeethOfJuicer_hit_data_table": 0x8038efb8,
		"TeethOfJuicer_hit_data_table": 0x8038efb8,
		"MoveBG::TeethOfJuicer_obj_hit_info": 0x8038efc8,
		"TeethOfJuicer_obj_hit_info": 0x8038efc8,
		"MoveBG::merrygoround_anim_data": 0x8038f004,
		"merrygoround_anim_data": 0x8038f004,
		"MoveBG::merry_hit_data_table": 0x8038f018,
		"merry_hit_data_table": 0x8038f018,
		"MoveBG::merrygoround_obj_hit_info": 0x8038f028,
		"merrygoround_obj_hit_info": 0x8038f028,
		"MoveBG::merry_egg_hit_data_table": 0x8038f038,
		"merry_egg_hit_data_table": 0x8038f038,
		"MoveBG::merry_egg_obj_hit_info": 0x8038f048,
		"merry_egg_obj_hit_info": 0x8038f048,
		"MoveBG::merry_pole_hit_data_table": 0x8038f064,
		"merry_pole_hit_data_table": 0x8038f064,
		"MoveBG::merry_pole_obj_hit_info": 0x8038f074,
		"merry_pole_obj_hit_info": 0x8038f074,
		"MoveBG::FerrisWheel_anim_data": 0x8038f0ac,
		"FerrisWheel_anim_data": 0x8038f0ac,
		"MoveBG::FerrisWheel_hit_data_table": 0x8038f0c0,
		"FerrisWheel_hit_data_table": 0x8038f0c0,
		"MoveBG::FerrisWheel_obj_hit_info": 0x8038f0d0,
		"FerrisWheel_obj_hit_info": 0x8038f0d0,
		"MoveBG::FerrisWheelGondola_hit_data_table": 0x8038f0fc,
		"FerrisWheelGondola_hit_data_table": 0x8038f0fc,
		"MoveBG::FerrisWheelGondola_obj_hit_info": 0x8038f10c,
		"FerrisWheelGondola_obj_hit_info": 0x8038f10c,
		"MoveBG::FerrisLOD_anim_data": 0x8038f138,
		"FerrisLOD_anim_data": 0x8038f138,
		"MoveBG::Viking_hit_data_table": 0x8038f158,
		"Viking_hit_data_table": 0x8038f158,
		"MoveBG::Viking_obj_hit_info": 0x8038f168,
		"Viking_obj_hit_info": 0x8038f168,
		"MoveBG::balloon_koopajr_anim_data": 0x8038f1c8,
		"balloon_koopajr_anim_data": 0x8038f1c8,
		"MoveBG::balloon_koopajr_hit_data_table": 0x8038f204,
		"balloon_koopajr_hit_data_table": 0x8038f204,
		"MoveBG::balloon_koopajr_obj_hit_info": 0x8038f214,
		"balloon_koopajr_obj_hit_info": 0x8038f214,
		"MoveBG::@3276": 0x8038f234,
		"MoveBG::@3277": 0x8038f244,
		"MoveBG::ShellCup_anim_data": 0x8038f250,
		"ShellCup_anim_data": 0x8038f250,
		"MoveBG::@3278": 0x8038f264,
		"MoveBG::ShellCup_hit_data_table": 0x8038f274,
		"ShellCup_hit_data_table": 0x8038f274,
		"MoveBG::ShellCup_obj_hit_info": 0x8038f284,
		"ShellCup_obj_hit_info": 0x8038f284,
		"MoveBG::Gateshell_anim_data": 0x8038f2bc,
		"Gateshell_anim_data": 0x8038f2bc,
		"MoveBG::PinnaHangingBridgeBoard_anim_data": 0x8038f2ec,
		"PinnaHangingBridgeBoard_anim_data": 0x8038f2ec,
		"MoveBG::PinnaHangingBridgeBoard_hit_data_table": 0x8038f300,
		"PinnaHangingBridgeBoard_hit_data_table": 0x8038f300,
		"MoveBG::PinnaHangingBridgeBoard_obj_hit_info": 0x8038f310,
		"PinnaHangingBridgeBoard_obj_hit_info": 0x8038f310,
		"MoveBG::GateManta_anim_data": 0x8038f360,
		"GateManta_anim_data": 0x8038f360,
		"MoveBG::@3289": 0x8038f380,
		"MoveBG::@3290": 0x8038f390,
		"MoveBG::AmiKing_anim_data": 0x8038f3a4,
		"AmiKing_anim_data": 0x8038f3a4,
		"MoveBG::AmiKing_hit_data_table": 0x8038f3b8,
		"AmiKing_hit_data_table": 0x8038f3b8,
		"MoveBG::AmiKing_obj_hit_info": 0x8038f3c8,
		"AmiKing_obj_hit_info": 0x8038f3c8,
		"MoveBG::PinnaCoaster_hit_data_table": 0x8038f3d8,
		"PinnaCoaster_hit_data_table": 0x8038f3d8,
		"MoveBG::PinnaCoaster_obj_hit_info": 0x8038f3e8,
		"PinnaCoaster_obj_hit_info": 0x8038f3e8,
		"MoveBG::roulette_anim_data": 0x8038f410,
		"roulette_anim_data": 0x8038f410,
		"MoveBG::slotdrum_hit_data_table": 0x8038f424,
		"slotdrum_hit_data_table": 0x8038f424,
		"MoveBG::slotdrum_obj_hit_info": 0x8038f434,
		"slotdrum_obj_hit_info": 0x8038f434,
		"MoveBG::telesaslot_hit_data_table": 0x8038f45c,
		"telesaslot_hit_data_table": 0x8038f45c,
		"MoveBG::telesaslot_obj_hit_info": 0x8038f46c,
		"telesaslot_obj_hit_info": 0x8038f46c,
		"MoveBG::@3300": 0x8038f47c,
		"MoveBG::donchou_anim_data": 0x8038f488,
		"donchou_anim_data": 0x8038f488,
		"MoveBG::donchou_hit_data_table": 0x8038f49c,
		"donchou_hit_data_table": 0x8038f49c,
		"MoveBG::donchou_obj_hit_info": 0x8038f4ac,
		"donchou_obj_hit_info": 0x8038f4ac,
		"MoveBG::casino_panel_gate_hit_data_table": 0x8038f4bc,
		"casino_panel_gate_hit_data_table": 0x8038f4bc,
		"MoveBG::casino_panel_gate_obj_hit_info": 0x8038f4cc,
		"casino_panel_gate_obj_hit_info": 0x8038f4cc,
		"MoveBG::bosswall_anim_data": 0x8038f4f8,
		"bosswall_anim_data": 0x8038f4f8,
		"MoveBG::casinoroof_anim_data": 0x8038f540,
		"casinoroof_anim_data": 0x8038f540,
		"MoveBG::GlassBreak_anim_data": 0x8038f584,
		"GlassBreak_anim_data": 0x8038f584,
		"MoveBG::GlassBreak_sound_data": 0x8038f610,
		"GlassBreak_sound_data": 0x8038f610,
		"MoveBG::closet_anim_data": 0x8038f650,
		"closet_anim_data": 0x8038f650,
		"MoveBG::closet_hit_data_table": 0x8038f664,
		"closet_hit_data_table": 0x8038f664,
		"MoveBG::closet_obj_hit_info": 0x8038f674,
		"closet_obj_hit_info": 0x8038f674,
		"MoveBG::ChestRevolve_anim_data": 0x8038f6c8,
		"ChestRevolve_anim_data": 0x8038f6c8,
		"MoveBG::ChestRevolve_map_collision_data": 0x8038f700,
		"ChestRevolve_map_collision_data": 0x8038f700,
		"MoveBG::PosterTeresa_anim_data": 0x8038f734,
		"PosterTeresa_anim_data": 0x8038f734,
		"MoveBG::PictureTeresa_anim_data": 0x8038f77c,
		"PictureTeresa_anim_data": 0x8038f77c,
		"MoveBG::PictureTeresa_hit_data_table": 0x8038f790,
		"PictureTeresa_hit_data_table": 0x8038f790,
		"MoveBG::PictureTeresa_obj_hit_info": 0x8038f7a0,
		"PictureTeresa_obj_hit_info": 0x8038f7a0,
		"MoveBG::PanelBreak_anim_data": 0x8038f7dc,
		"PanelBreak_anim_data": 0x8038f7dc,
		"MoveBG::PanelBreak_sound_data": 0x8038f868,
		"PanelBreak_sound_data": 0x8038f868,
		"MoveBG::PanelRevolve_anim_data": 0x8038f8b4,
		"PanelRevolve_anim_data": 0x8038f8b4,
		"MoveBG::cogwheel_anim_data": 0x8038f92c,
		"cogwheel_anim_data": 0x8038f92c,
		"MoveBG::Cogwheel_hit_data_table": 0x8038f940,
		"Cogwheel_hit_data_table": 0x8038f940,
		"MoveBG::Cogwheel_obj_hit_info": 0x8038f950,
		"Cogwheel_obj_hit_info": 0x8038f950,
		"MoveBG::CogwheelPlate_hit_data_table": 0x8038f97c,
		"CogwheelPlate_hit_data_table": 0x8038f97c,
		"MoveBG::CogwheelPlate_obj_hit_info": 0x8038f98c,
		"CogwheelPlate_obj_hit_info": 0x8038f98c,
		"MoveBG::@3336": 0x8038f99c,
		"MoveBG::CogwheelPot_hit_data_table": 0x8038f9ac,
		"CogwheelPot_hit_data_table": 0x8038f9ac,
		"MoveBG::CogwheelPot_obj_hit_info": 0x8038f9bc,
		"CogwheelPot_obj_hit_info": 0x8038f9bc,
		"MoveBG::@3337": 0x8038f9cc,
		"MoveBG::mare_float_house_hit_data_table": 0x8038f9dc,
		"mare_float_house_hit_data_table": 0x8038f9dc,
		"MoveBG::mare_float_house_obj_hit_info": 0x8038f9ec,
		"mare_float_house_obj_hit_info": 0x8038f9ec,
		"MoveBG::StopRock_hit_data_table": 0x8038f9fc,
		"StopRock_hit_data_table": 0x8038f9fc,
		"MoveBG::StopRock_obj_hit_info": 0x8038fa0c,
		"StopRock_obj_hit_info": 0x8038fa0c,
		"MoveBG::@3339": 0x8038fa1c,
		"MoveBG::ElasticCode_hit_data_table": 0x8038fa28,
		"ElasticCode_hit_data_table": 0x8038fa28,
		"MoveBG::ElasticCode_obj_hit_info": 0x8038fa38,
		"ElasticCode_obj_hit_info": 0x8038fa38,
		"MoveBG::@3340": 0x8038fa48,
		"MoveBG::@3343": 0x8038fa6c,
		"MoveBG::GrowthTree_anim_data": 0x8038fa7c,
		"GrowthTree_anim_data": 0x8038fa7c,
		"MoveBG::GrowthTree_hit_data_table": 0x8038faa4,
		"GrowthTree_hit_data_table": 0x8038faa4,
		"MoveBG::GrowthTree_obj_hit_info": 0x8038fab4,
		"GrowthTree_obj_hit_info": 0x8038fab4,
		"MoveBG::MuddyBoat_anim_data": 0x8038fb0c,
		"MuddyBoat_anim_data": 0x8038fb0c,
		"MoveBG::MuddyBoat_hit_data_table": 0x8038fb48,
		"MuddyBoat_hit_data_table": 0x8038fb48,
		"MoveBG::MuddyBoat_obj_hit_info": 0x8038fb58,
		"MuddyBoat_obj_hit_info": 0x8038fb58,
		"MoveBG::Puncher_anim_data": 0x8038fbbc,
		"Puncher_anim_data": 0x8038fbbc,
		"MoveBG::Puncher_hit_data_table": 0x8038fbe4,
		"Puncher_hit_data_table": 0x8038fbe4,
		"MoveBG::Puncher_obj_hit_info": 0x8038fbf4,
		"Puncher_obj_hit_info": 0x8038fbf4,
		"MoveBG::@3354": 0x8038fc04,
		"MoveBG::@3356": 0x8038fc28,
		"MoveBG::HatoPop_anim_data": 0x8038fc4c,
		"HatoPop_anim_data": 0x8038fc4c,
		"MoveBG::HatoPop_hit_data_table": 0x8038fc74,
		"HatoPop_hit_data_table": 0x8038fc74,
		"MoveBG::HatoPop_obj_hit_info": 0x8038fc84,
		"HatoPop_obj_hit_info": 0x8038fc84,
		"MoveBG::MareWaterJump_hit_data_table": 0x8038fc94,
		"MareWaterJump_hit_data_table": 0x8038fc94,
		"MoveBG::MareWaterJump_obj_hit_info": 0x8038fca4,
		"MareWaterJump_obj_hit_info": 0x8038fca4,
		"MoveBG::@3358": 0x8038fcb4,
		"MoveBG::@3359": 0x8038fcc8,
		"MoveBG::BumpyWall_hit_data_table": 0x8038fcd8,
		"BumpyWall_hit_data_table": 0x8038fcd8,
		"MoveBG::BumpyWall_obj_hit_info": 0x8038fce8,
		"BumpyWall_obj_hit_info": 0x8038fce8,
		"MoveBG::@3360": 0x8038fcf8,
		"MoveBG::ExBottle_hit_data_table": 0x8038fd0c,
		"ExBottle_hit_data_table": 0x8038fd0c,
		"MoveBG::ExBottle_obj_hit_info": 0x8038fd1c,
		"ExBottle_obj_hit_info": 0x8038fd1c,
		"MoveBG::@3362": 0x8038fd38,
		"MoveBG::@3363": 0x8038fd48,
		"MoveBG::CoinFish_anim_data": 0x8038fd54,
		"CoinFish_anim_data": 0x8038fd54,
		"MoveBG::@3365": 0x8038fd74,
		"MoveBG::@3366": 0x8038fd84,
		"MoveBG::MareFall_anim_data": 0x8038fd90,
		"MareFall_anim_data": 0x8038fd90,
		"MoveBG::@3367": 0x8038fda4,
		"MoveBG::MonteRoot_anim_data": 0x8038fdc8,
		"MonteRoot_anim_data": 0x8038fdc8,
		"MoveBG::MonteRoot_hit_data_table": 0x8038fddc,
		"MonteRoot_hit_data_table": 0x8038fddc,
		"MoveBG::MonteRoot_obj_hit_info": 0x8038fdec,
		"MonteRoot_obj_hit_info": 0x8038fdec,
		"MoveBG::@3370": 0x8038fdfc,
		"MoveBG::@3371": 0x8038fe08,
		"MoveBG::@3372": 0x8038fe18,
		"MoveBG::JumpMushroom_anim_data": 0x8038fe2c,
		"JumpMushroom_anim_data": 0x8038fe2c,
		"MoveBG::@3373": 0x8038fe54,
		"MoveBG::@3374": 0x8038fe60,
		"MoveBG::MonteGoalFlag_anim_data": 0x8038fe90,
		"MonteGoalFlag_anim_data": 0x8038fe90,
		"MoveBG::MonteGoalFlag_hit_data_table": 0x8038fea4,
		"MonteGoalFlag_hit_data_table": 0x8038fea4,
		"MoveBG::MonteGoalFlag_obj_hit_info": 0x8038feb4,
		"MonteGoalFlag_obj_hit_info": 0x8038feb4,
		"MoveBG::HangingBridgeBoard_anim_data": 0x8038fee0,
		"HangingBridgeBoard_anim_data": 0x8038fee0,
		"MoveBG::HangingBridgeBoard_hit_data_table": 0x8038fef4,
		"HangingBridgeBoard_hit_data_table": 0x8038fef4,
		"MoveBG::HangingBridgeBoard_obj_hit_info": 0x8038ff04,
		"HangingBridgeBoard_obj_hit_info": 0x8038ff04,
		"MoveBG::SwingBoard_hit_data_table": 0x8038ff38,
		"SwingBoard_hit_data_table": 0x8038ff38,
		"MoveBG::SwingBoard_obj_hit_info": 0x8038ff48,
		"SwingBoard_obj_hit_info": 0x8038ff48,
		"MoveBG::Fluff_anim_data": 0x8038ff70,
		"Fluff_anim_data": 0x8038ff70,
		"MoveBG::Fluff_hit_data_table": 0x8038ff84,
		"Fluff_hit_data_table": 0x8038ff84,
		"MoveBG::Fluff_obj_hit_info": 0x8038ff94,
		"Fluff_obj_hit_info": 0x8038ff94,
		"MoveBG::Bathtub_anim_data": 0x8038ffd0,
		"Bathtub_anim_data": 0x8038ffd0,
		"MoveBG::BathtubStandBreaking_anim_data": 0x80390078,
		"BathtubStandBreaking_anim_data": 0x80390078,
		"MoveBG::ex1_turn_lift_anim_data": 0x803900f8,
		"ex1_turn_lift_anim_data": 0x803900f8,
		"MoveBG::y_turn_lift_anim_data": 0x8039017c,
		"y_turn_lift_anim_data": 0x8039017c,
		"MoveBG::Nail_anim_data": 0x803901e8,
		"Nail_anim_data": 0x803901e8,
		"MoveBG::Nail_hit_data_table": 0x803901fc,
		"Nail_hit_data_table": 0x803901fc,
		"MoveBG::Nail_obj_hit_info": 0x8039020c,
		"Nail_obj_hit_info": 0x8039020c,
		"MoveBG::PachinkoNail_anim_data": 0x8039023c,
		"PachinkoNail_anim_data": 0x8039023c,
		"MoveBG::FileLoadBlockA_anim_data": 0x803902c8,
		"FileLoadBlockA_anim_data": 0x803902c8,
		"MoveBG::FileLoadBlock_hit_data_table": 0x80390304,
		"FileLoadBlock_hit_data_table": 0x80390304,
		"MoveBG::FileLoadBlock_obj_hit_info": 0x80390314,
		"FileLoadBlock_obj_hit_info": 0x80390314,
		"MoveBG::FileLoadBlockB_anim_data": 0x80390360,
		"FileLoadBlockB_anim_data": 0x80390360,
		"MoveBG::FileLoadBlockC_anim_data": 0x803903d8,
		"FileLoadBlockC_anim_data": 0x803903d8,
		"MoveBG::@3728": 0x80390424,
		"MoveBG::@2183": 0x803904a0,
		"MoveBG::@2184": 0x803904d8,
		"MoveBG::@2185": 0x8039050c,
		"MoveBG::@3779": 0x80390700,
		"MoveBG::@3786": 0x80390768,
		"MoveBG::@3806": 0x80390874,
		"MoveBG::@3807": 0x80390890,
		"MoveBG::@3808": 0x8039089c,
		"MoveBG::@3809": 0x803908a8,
		"MoveBG::@3810": 0x803908c4,
		"MoveBG::@4173": 0x80390b98,
		"MoveBG::@4174": 0x80390bb4,
		"MoveBG::@4175": 0x80390bd0,
		"MoveBG::@4176": 0x80390bec,
		"MoveBG::@4177": 0x80390c0c,
		"MoveBG::@4178": 0x80390c28,
		"MoveBG::@4179": 0x80390c48,
		"MoveBG::@2409": 0x803911f0,
		"MoveBG::@2410": 0x80391220,
		"MoveBG::@2411": 0x80391258,
		"MoveBG::@2412": 0x8039128c,
		"MoveBG::@4241": 0x8039156c,
		"MoveBG::@3440": 0x8039197c,
		"MoveBG::@2724": 0x80391a68,
		"MoveBG::@4109": 0x80391c34,
		"MoveBG::@3499": 0x80392010,
		"MoveBG::@3500": 0x80392030,
		"MoveBG::@3501": 0x80392048,
		"MoveBG::@3696": 0x80392154,
		"MoveBG::@2211": 0x80392258,
		"MoveBG::@2212": 0x80392288,
		"MoveBG::@2213": 0x803922c0,
		"MoveBG::@2214": 0x803922f4,
		"MoveBG::@2692": 0x80392324,
		"MoveBG::@2498": 0x8039251c,
		"MoveBG::@2499": 0x80392528,
		"MoveBG::@2500": 0x80392538,
		"MoveBG::@2501": 0x80392548,
		"MoveBG::@2464": 0x80392660,
		"MoveBG::@2467": 0x8039266c,
		"MoveBG::@2468": 0x80392678,
		"@2468": 0x80392678,
		"MoveBG::@2469": 0x80392684,
		"@2469": 0x80392684,
		"MoveBG::@2470": 0x80392690,
		"MoveBG::@2471": 0x8039269c,
		"MoveBG::@2473": 0x803926b8,
		"MoveBG::param_table": 0x803926d8,
		"param_table": 0x803926d8,
		"MoveBG::@2539": 0x803928e8,
		"MoveBG::@2540": 0x8039290c,
		"MoveBG::@2634": 0x80392930,
		"MoveBG::@2639": 0x80392990,
		"MoveBG::@2371": 0x803929d0,
		"MoveBG::@2372": 0x80392a00,
		"MoveBG::@2373": 0x80392a38,
		"MoveBG::@2374": 0x80392a6c,
		"MoveBG::@2600": 0x80392fb8,
		"MoveBG::@2188": 0x80393028,
		"MoveBG::@2520": 0x803930e8,
		"MoveBG::@2522": 0x803930f4,
		"MoveBG::@2397": 0x80393188,
		"MoveBG::@2398": 0x803931b8,
		"MoveBG::@2399": 0x803931f0,
		"MoveBG::@2400": 0x80393224,
		"MoveBG::@2575": 0x80393294,
		"MoveBG::@2576": 0x803932a0,
		"MoveBG::@2577": 0x803932ac,
		"MoveBG::@2578": 0x803932b8,
		"MoveBG::cDirtyFileName": 0x803936d0,
		"MoveBG::cDirtyTexName": 0x803936f4,
		"MoveBG::@3679": 0x80393788,
		"MoveBG::@3680": 0x803937a8,
		"MoveBG::@3715": 0x80393848,
		"MoveBG::@3755": 0x80393870,
		"MoveBG::@3758": 0x803938a8,
		"MoveBG::@2753": 0x803939c8,
		"MoveBG::@2605": 0x80393e50,
		"MoveBG::@2659": 0x80393e94,
		"MoveBG::@2660": 0x80393ea4,
		"MoveBG::@2661": 0x80393ec4,
		"MoveBG::@5966": 0x8039433c,
		"@5966": 0x8039433c,
		"MoveBG::@5967": 0x8039434c,
		"@5967": 0x8039434c,
		"MoveBG::@5968": 0x8039435c,
		"@5968": 0x8039435c,
		"MoveBG::@5969": 0x80394368,
		"@5969": 0x80394368,
		"MoveBG::@5970": 0x80394374,
		"@5970": 0x80394374,
		"MoveBG::@5971": 0x80394380,
		"@5971": 0x80394380,
		"MoveBG::@5972": 0x8039438c,
		"@5972": 0x8039438c,
		"MoveBG::@5973": 0x8039439c,
		"@5973": 0x8039439c,
		"MoveBG::@5976": 0x803943b4,
		"@5976": 0x803943b4,
		"MoveBG::@5977": 0x803943c0,
		"@5977": 0x803943c0,
		"MoveBG::@5978": 0x803943cc,
		"@5978": 0x803943cc,
		"MoveBG::@5991": 0x80394418,
		"MoveBG::@2546": 0x80394470,
		"MoveBG::@2547": 0x803944a0,
		"MoveBG::@2548": 0x803944d8,
		"MoveBG::@2549": 0x8039450c,
		"MoveBG::@2327": 0x80394730,
		"MoveBG::@2328": 0x80394760,
		"MoveBG::@2329": 0x80394798,
		"MoveBG::@2330": 0x803947cc,
		"Map::@2324": 0x80388bf0,
		"Map::@2514": 0x80388ce0,
		"Map::@2516": 0x80388cec,
		"Map::@2972": 0x80388cf8,
		"Map::@3338": 0x80388d08,
		"Map::@3339": 0x80388d24,
		"Map::@3340": 0x80388d34,
		"Map::@3506": 0x80388d44,
		"Map::@3507": 0x80388d5c,
		"Map::@3509": 0x80388d68,
		"Map::@3510": 0x80388d7c,
		"Map::@3511": 0x80388d88,
		"Map::@3512": 0x80388d9c,
		"Map::@3566": 0x80388db8,
		"Map::@3567": 0x80388dd0,
		"Map::@3701": 0x80388ddc,
		"Map::@3702": 0x80388df0,
		"Map::@3703": 0x80388dfc,
		"Map::@3704": 0x80388e20,
		"Map::@3705": 0x80388e44,
		"Map::@3799": 0x80388e60,
		"Map::@3800": 0x80388e74,
		"Map::@3801": 0x80388e9c,
		"Map::@3802": 0x80388ec4,
		"Map::@1526": 0x80388ef4,
		"Map::@1766": 0x80388f08,
		"@1766": 0x80388f08,
		"Map::@1768": 0x80388f14,
		"Map::@2018": 0x80388f20,
		"Map::@2019": 0x80388f30,
		"Map::@2020": 0x80388f40,
		"Map::@2272": 0x80388f88,
		"Map::@2273": 0x80388fb8,
		"Map::@2274": 0x80388ff0,
		"Map::@2275": 0x80389024,
		"Map::@2604": 0x80389048,
		"Map::@3076": 0x80389060,
		"Map::@3151": 0x803890a8,
		"Map::@3154": 0x803890b4,
		"Map::@2513": 0x80389210,
		"Map::@2515": 0x8038921c,
		"Map::@2517": 0x80389228,
		"Map::@2667": 0x80389278,
		"Map::@2502": 0x80389288,
		"Map::@2503": 0x80389298,
		"Map::@2197": 0x80389370,
		"Map::@2198": 0x803893a0,
		"Map::@2199": 0x803893d8,
		"Map::@2200": 0x8038940c,
		"Map::@2882": 0x8038950c,
		"Map::@2883": 0x80389518,
		"Map::@2884": 0x80389530,
		"Map::@2885": 0x80389554,
		"Map::@2886": 0x80389568,
		"Map::@2887": 0x80389574,
		"Map::@2888": 0x80389588,
		"Map::@2889": 0x8038959c,
		"Map::@2890": 0x803895b0,
		"Map::@2891": 0x803895c4,
		"Map::@2892": 0x803895d8,
		"Map::@2893": 0x803895e4,
		"Map::@2894": 0x803895f8,
		"Map::@2895": 0x8038960c,
		"Map::@2896": 0x80389624,
		"Map::@2897": 0x80389630,
		"Map::@2898": 0x8038963c,
		"Map::@2899": 0x80389648,
		"Map::actor_data_table": 0x80389654,
		"actor_data_table": 0x80389654,
		"Map::sound_info": 0x80389e14,
		"sound_info": 0x80389e14,
		"Map::@1937": 0x80389ee4,
		"Map::@2174": 0x80389ef8,
		"Map::@2176": 0x80389f04,
		"Map::@2579": 0x80389f10,
		"Map::@2178": 0x80389f90,
		"Map::@2179": 0x80389fc0,
		"Map::@2180": 0x80389ff8,
		"Map::@2181": 0x8038a02c,
		"Map::@2829": 0x8038a164,
		"Map::@2986": 0x8038a170,
		"Map::@2987": 0x8038a184,
		"Map::@2988": 0x8038a198,
		"Map::@2771": 0x8038a320,
		"Map::@2772": 0x8038a344,
		"Map::@2784": 0x8038a368,
		"Map::@1974": 0x8038a418,
		"Map::@2925": 0x8038a540,
		"Map::@3396": 0x8038a628,
		"Map::@3403": 0x8038a648,
		"Map::@3688": 0x8038a66c,
		"Map::@3699": 0x8038a67c,
		"Map::@3735": 0x8038a68c,
		"Map::@1900": 0x8038a6a8,
		"Map::@1907": 0x8038a6bc,
		"Map::@1996": 0x8038a6c8,
		"Map::@1997": 0x8038a6f8,
		"Map::@1998": 0x8038a730,
		"Map::@1999": 0x8038a764,
		"Map::@3425": 0x8038a7c4,
		"Map::@4208": 0x8038a7e4,
		"Map::@4358": 0x8038a7f0,
		"Map::@4359": 0x8038a808,
		"Map::@4360": 0x8038a820,
		"Map::@4361": 0x8038a838,
		"Map::@4362": 0x8038a854,
		"Map::@4363": 0x8038a874,
		"Map::@4364": 0x8038a894,
		"Map::@4440": 0x8038a8ac,
		"Map::@4441": 0x8038a8bc,
		"@4441": 0x8038a8bc,
		"Map::@4442": 0x8038a8c8,
		"@4442": 0x8038a8c8,
		"Map::@4748": 0x8038a8f0,
		"Map::@4749": 0x8038a8fc,
		"Map::@4752": 0x8038a920,
		"Map::@4755": 0x8038a944,
		"Map::@4758": 0x8038a950,
		"Map::@4762": 0x8038a970,
		"Map::@4764": 0x8038a98c,
		"Map::@4766": 0x8038a998,
		"Map::@4768": 0x8038a9a4,
		"Map::@4832": 0x8038a9b0,
		"Map::@4834": 0x8038a9d0,
		"Map::@4835": 0x8038a9dc,
		"Map::@4837": 0x8038a9f4,
		"Map::@4838": 0x8038aa00,
		"Map::@4844": 0x8038aa30,
		"Map::@4855": 0x8038aa54,
		"Map::@4858": 0x8038aa60,
		"GC2D::@1772": 0x80387780,
		"GC2D::@1953": 0x8038779c,
		"GC2D::@2082": 0x803877b0,
		"GC2D::@2084": 0x803877d0,
		"GC2D::@2086": 0x803877f0,
		"GC2D::scNozzleSoundList": 0x80387830,
		"scNozzleSoundList": 0x80387830,
		"GC2D::@1937": 0x80387a24,
		"GC2D::scTalkSoundList": 0x80387af8,
		"scTalkSoundList": 0x80387af8,
		"GC2D::@2719": 0x80387d14,
		"GC2D::@2722": 0x80387d24,
		"GC2D::@2723": 0x80387d4c,
		"GC2D::@3284": 0x80387f20,
		"GC2D::@3340": 0x80387f3c,
		"GC2D::@3341": 0x80387f58,
		"GC2D::@1991": 0x80387f78,
		"GC2D::@2112": 0x80388084,
		"GC2D::@1705": 0x8038826c,
		"GC2D::@1917": 0x80388280,
		"GC2D::@3484": 0x8038828c,
		"GC2D::@3485": 0x8038829c,
		"GC2D::@3486": 0x803882b0,
		"GC2D::@3487": 0x803882cc,
		"GC2D::@2421": 0x80388334,
		"GC2D::@2422": 0x80388360,
		"GC2D::@3040": 0x8038849c,
		"GC2D::@3041": 0x803884ac,
		"GC2D::@3042": 0x803884b8,
		"GC2D::@3043": 0x803884c8,
		"GC2D::@3044": 0x803884dc,
		"GC2D::@3045": 0x803884ec,
		"GC2D::@3046": 0x803884f8,
		"GC2D::@3047": 0x80388504,
		"GC2D::@3048": 0x80388510,
		"GC2D::@3049": 0x80388524,
		"GC2D::@3050": 0x8038854c,
		"GC2D::@3051": 0x80388574,
		"GC2D::@3052": 0x8038859c,
		"GC2D::@3053": 0x803885c8,
		"GC2D::@3054": 0x803885f0,
		"GC2D::@3055": 0x80388618,
		"GC2D::@3056": 0x80388640,
		"GC2D::@3057": 0x80388668,
		"GC2D::@3058": 0x80388690,
		"GC2D::@3059": 0x803886a4,
		"GC2D::@3060": 0x803886b4,
		"GC2D::@3066": 0x803886c4,
		"GC2D::@3128": 0x803886f8,
		"GC2D::@1752": 0x80388714,
		"GC2D::@2482": 0x80388728,
		"GC2D::@2483": 0x80388740,
		"GC2D::@1942": 0x803887a4,
		"GC2D::@4089": 0x803887b8,
		"GC2D::@4090": 0x803887c4,
		"GC2D::@4091": 0x803887e4,
		"GC2D::@4092": 0x80388804,
		"GC2D::@4093": 0x80388820,
		"GC2D::@4094": 0x80388844,
		"GC2D::@4095": 0x80388868,
		"GC2D::@4096": 0x80388890,
		"GC2D::@4097": 0x803888b8,
		"GC2D::@4098": 0x803888dc,
		"GC2D::@941": 0x803888f8,
		"@941": 0x803888f8,
		"GC2D::@1128": 0x80388910,
		"@1128": 0x80388910,
		"GC2D::@1938": 0x8038898c,
		"@unnamed@::cRumbleAnm": 0x803889a0,
		"cRumbleAnm": 0x803889a0,
		"@unnamed@::cSurMonteAnm": 0x803889f0,
		"cSurMonteAnm": 0x803889f0,
		"@unnamed@::cSurLTSpeakerAnm": 0x80388a30,
		"cSurLTSpeakerAnm": 0x80388a30,
		"@unnamed@::cSurRTSpeakerAnm": 0x80388a58,
		"cSurRTSpeakerAnm": 0x80388a58,
		"@unnamed@::cSurLBSpeakerAnm": 0x80388a80,
		"cSurLBSpeakerAnm": 0x80388a80,
		"@unnamed@::cSurRBSpeakerAnm": 0x80388aa8,
		"cSurRBSpeakerAnm": 0x80388aa8,
		"@unnamed@::cSteMonteAnm": 0x80388ad0,
		"cSteMonteAnm": 0x80388ad0,
		"@unnamed@::cSteLSpeakerAnm": 0x80388b10,
		"cSteLSpeakerAnm": 0x80388b10,
		"@unnamed@::cSteRSpeakerAnm": 0x80388b38,
		"cSteRSpeakerAnm": 0x80388b38,
		"@unnamed@::cMonoMonteAnm": 0x80388b60,
		"cMonoMonteAnm": 0x80388b60,
		"@unnamed@::cMonoSpeakerAnm": 0x80388b70,
		"cMonoSpeakerAnm": 0x80388b70,
		"@unnamed@::cSoundToggleItems": 0x80388b80,
		"cSoundToggleItems": 0x80388b80,
		"GC2D::@1557": 0x80388bb8,
		"GC2D::@1578": 0x80388bcc,
		"GC2D::@1579": 0x80388bd8,
		"Enemy::@4571": 0x803768d0,
		"@4571": 0x803768d0,
		"Enemy::@2141": 0x80376954,
		"Enemy::@2673": 0x80376a28,
		"Enemy::@2685": 0x80376a40,
		"Enemy::@1973": 0x80376d48,
		"Enemy::@1974": 0x80376d78,
		"Enemy::@1975": 0x80376db0,
		"Enemy::@1976": 0x80376de4,
		"Enemy::@2270": 0x80376f48,
		"Enemy::@2272": 0x80376fb4,
		"Enemy::@2281": 0x803770b8,
		"Enemy::@2283": 0x80377124,
		"Enemy::replayLinkMonteMan": 0x8037778c,
		"replayLinkMonteMan": 0x8037778c,
		"Enemy::@6434": 0x80377990,
		"@6434": 0x80377990,
		"Enemy::@6435": 0x8037799c,
		"@6435": 0x8037799c,
		"Enemy::@6437": 0x803779ac,
		"@6437": 0x803779ac,
		"Enemy::@6438": 0x803779b8,
		"@6438": 0x803779b8,
		"Enemy::@6439": 0x803779c4,
		"@6439": 0x803779c4,
		"Enemy::@6440": 0x803779d0,
		"@6440": 0x803779d0,
		"Enemy::@6441": 0x803779dc,
		"@6441": 0x803779dc,
		"Enemy::@6442": 0x803779e8,
		"@6442": 0x803779e8,
		"Enemy::@6444": 0x80377a04,
		"@6444": 0x80377a04,
		"Enemy::@6445": 0x80377a10,
		"@6445": 0x80377a10,
		"Enemy::@6446": 0x80377a20,
		"@6446": 0x80377a20,
		"Enemy::@6448": 0x80377a30,
		"@6448": 0x80377a30,
		"Enemy::@6449": 0x80377a4c,
		"@6449": 0x80377a4c,
		"Enemy::@6450": 0x80377a68,
		"@6450": 0x80377a68,
		"Enemy::@6451": 0x80377a88,
		"@6451": 0x80377a88,
		"Enemy::@6455": 0x80377abc,
		"@6455": 0x80377abc,
		"Enemy::@6456": 0x80377ae0,
		"@6456": 0x80377ae0,
		"Enemy::@6457": 0x80377b04,
		"@6457": 0x80377b04,
		"Enemy::@6458": 0x80377b28,
		"@6458": 0x80377b28,
		"Enemy::@5330": 0x80378080,
		"Enemy::@5331": 0x80378094,
		"Enemy::@5332": 0x803780ac,
		"Enemy::@5333": 0x803780c4,
		"Enemy::@5334": 0x803780d8,
		"Enemy::@5336": 0x80378104,
		"Enemy::@5338": 0x80378114,
		"Enemy::@5340": 0x80378124,
		"Enemy::@1961": 0x80378190,
		"Enemy::@1962": 0x803781c0,
		"Enemy::@1963": 0x803781f8,
		"Enemy::@1964": 0x8037822c,
		"Enemy::@7735": 0x80378724,
		"@7735": 0x80378724,
		"Enemy::@7736": 0x80378730,
		"@7736": 0x80378730,
		"Enemy::@7737": 0x8037873c,
		"@7737": 0x8037873c,
		"Enemy::@7755": 0x8037876c,
		"@7755": 0x8037876c,
		"Enemy::@7788": 0x803787b0,
		"@7788": 0x803787b0,
		"Enemy::@7904": 0x80378828,
		"@7904": 0x80378828,
		"Enemy::@7905": 0x80378838,
		"Enemy::@7906": 0x80378848,
		"@7906": 0x80378848,
		"Enemy::@7907": 0x8037885c,
		"@7907": 0x8037885c,
		"Enemy::@7908": 0x80378870,
		"@7908": 0x80378870,
		"Enemy::@8294": 0x803788f0,
		"@8294": 0x803788f0,
		"Enemy::@8297": 0x80378918,
		"Enemy::@8298": 0x80378928,
		"@8298": 0x80378928,
		"Enemy::@8299": 0x80378934,
		"@8299": 0x80378934,
		"Enemy::@8300": 0x80378948,
		"@8300": 0x80378948,
		"Enemy::@8301": 0x8037895c,
		"@8301": 0x8037895c,
		"Enemy::@8302": 0x80378970,
		"@8302": 0x80378970,
		"Enemy::@8303": 0x80378988,
		"Enemy::@8304": 0x80378994,
		"@8304": 0x80378994,
		"Enemy::@8305": 0x803789a8,
		"@8305": 0x803789a8,
		"Enemy::@8306": 0x803789bc,
		"@8306": 0x803789bc,
		"Enemy::@8307": 0x803789d0,
		"@8307": 0x803789d0,
		"Enemy::@2539": 0x80378ac0,
		"Enemy::@2541": 0x80378acc,
		"Enemy::@5905": 0x80378edc,
		"Enemy::@5906": 0x80378efc,
		"Enemy::@6361": 0x80378f4c,
		"@6361": 0x80378f4c,
		"Enemy::@6363": 0x80378f60,
		"@6363": 0x80378f60,
		"Enemy::@6365": 0x80378f74,
		"Enemy::@6366": 0x80378f88,
		"Enemy::@6368": 0x80378f98,
		"@6368": 0x80378f98,
		"Enemy::@6369": 0x80378fa8,
		"@6369": 0x80378fa8,
		"Enemy::@6370": 0x80378fb8,
		"@6370": 0x80378fb8,
		"Enemy::@6372": 0x80378fc8,
		"@6372": 0x80378fc8,
		"Enemy::@6374": 0x80378fd8,
		"@6374": 0x80378fd8,
		"Enemy::@6375": 0x80378fe8,
		"@6375": 0x80378fe8,
		"Enemy::@6377": 0x80378ff4,
		"@6377": 0x80378ff4,
		"Enemy::@6378": 0x80379004,
		"@6378": 0x80379004,
		"Enemy::@6379": 0x80379014,
		"@6379": 0x80379014,
		"Enemy::@6380": 0x80379028,
		"@6380": 0x80379028,
		"Enemy::@6381": 0x8037903c,
		"@6381": 0x8037903c,
		"Enemy::@6383": 0x80379050,
		"@6383": 0x80379050,
		"Enemy::@6384": 0x80379060,
		"@6384": 0x80379060,
		"Enemy::@6388": 0x80379078,
		"@6388": 0x80379078,
		"Enemy::@6390": 0x80379084,
		"@6390": 0x80379084,
		"Enemy::@6391": 0x80379090,
		"@6391": 0x80379090,
		"Enemy::@6392": 0x803790a0,
		"@6392": 0x803790a0,
		"Enemy::@6397": 0x803790cc,
		"@6397": 0x803790cc,
		"Enemy::@6399": 0x803790dc,
		"@6399": 0x803790dc,
		"Enemy::@6400": 0x803790ec,
		"@6400": 0x803790ec,
		"Enemy::@6401": 0x803790fc,
		"@6401": 0x803790fc,
		"Enemy::@6402": 0x80379110,
		"@6402": 0x80379110,
		"Enemy::@6404": 0x80379120,
		"@6404": 0x80379120,
		"Enemy::@6405": 0x80379134,
		"@6405": 0x80379134,
		"Enemy::@6406": 0x80379148,
		"@6406": 0x80379148,
		"Enemy::@6407": 0x8037915c,
		"@6407": 0x8037915c,
		"Enemy::@6408": 0x80379170,
		"@6408": 0x80379170,
		"Enemy::@6409": 0x80379184,
		"@6409": 0x80379184,
		"Enemy::@2430": 0x80379278,
		"Enemy::@2478": 0x80379378,
		"@2478": 0x80379378,
		"Enemy::@2479": 0x80379384,
		"Enemy::@2480": 0x80379390,
		"Enemy::@2481": 0x8037939c,
		"Enemy::@2482": 0x803793a8,
		"Enemy::@2483": 0x803793b4,
		"Enemy::@2484": 0x803793c0,
		"Enemy::@2121": 0x8037954c,
		"Enemy::nameKuriTevColorData": 0x8037964c,
		"nameKuriTevColorData": 0x8037964c,
		"Enemy::@4531": 0x8037983c,
		"Enemy::@2325": 0x80379884,
		"Enemy::@2565": 0x803798c8,
		"Enemy::@5123": 0x80379b6c,
		"Enemy::@5125": 0x80379b78,
		"Enemy::@5127": 0x80379ba0,
		"Enemy::@2396": 0x80379c20,
		"Enemy::@2398": 0x80379c2c,
		"Enemy::@4947": 0x80379d5c,
		"Enemy::@4961": 0x80379dec,
		"Enemy::@4964": 0x80379e1c,
		"Enemy::@4966": 0x80379e30,
		"Enemy::@4968": 0x80379e40,
		"Enemy::@1604": 0x80379f18,
		"Enemy::@1605": 0x80379f48,
		"Enemy::@1606": 0x80379f80,
		"Enemy::@2252": 0x80379fd8,
		"Enemy::@2253": 0x80379fec,
		"Enemy::@2370": 0x8037a020,
		"Enemy::@2373": 0x8037a0bc,
		"Enemy::@2112": 0x8037a134,
		"Enemy::@3712": 0x8037a3d8,
		"Enemy::@9188": 0x8037a9cc,
		"@9188": 0x8037a9cc,
		"Enemy::@9189": 0x8037a9dc,
		"@9189": 0x8037a9dc,
		"Enemy::@9191": 0x8037a9fc,
		"@9191": 0x8037a9fc,
		"Enemy::@9192": 0x8037aa0c,
		"@9192": 0x8037aa0c,
		"Enemy::@9193": 0x8037aa1c,
		"@9193": 0x8037aa1c,
		"Enemy::@9194": 0x8037aa2c,
		"@9194": 0x8037aa2c,
		"Enemy::@9196": 0x8037aa44,
		"@9196": 0x8037aa44,
		"Enemy::@2346": 0x8037ac0c,
		"Enemy::@5269": 0x8037af28,
		"Enemy::@5271": 0x8037af58,
		"Enemy::cTelesaColor": 0x8037b0f4,
		"cTelesaColor": 0x8037b0f4,
		"Enemy::@5411": 0x8037b3e4,
		"Enemy::@5414": 0x8037b420,
		"Enemy::@5415": 0x8037b438,
		"@5415": 0x8037b438,
		"Enemy::@5417": 0x8037b450,
		"Enemy::@2255": 0x8037b4e0,
		"Enemy::@2256": 0x8037b518,
		"Enemy::@2257": 0x8037b54c,
		"Enemy::@7290": 0x8037b644,
		"@7290": 0x8037b644,
		"Enemy::@7429": 0x8037b6c0,
		"@7429": 0x8037b6c0,
		"Enemy::@8401": 0x8037b6f8,
		"@8401": 0x8037b6f8,
		"Enemy::@9114": 0x8037b76c,
		"@9114": 0x8037b76c,
		"Enemy::@9116": 0x8037b780,
		"@9116": 0x8037b780,
		"Enemy::@9117": 0x8037b790,
		"@9117": 0x8037b790,
		"Enemy::@9118": 0x8037b7a4,
		"@9118": 0x8037b7a4,
		"Enemy::@9120": 0x8037b7c4,
		"@9120": 0x8037b7c4,
		"Enemy::@9122": 0x8037b7d4,
		"@9122": 0x8037b7d4,
		"Enemy::@9124": 0x8037b7e0,
		"@9124": 0x8037b7e0,
		"Enemy::@9125": 0x8037b7ec,
		"@9125": 0x8037b7ec,
		"Enemy::@9126": 0x8037b7f8,
		"@9126": 0x8037b7f8,
		"Enemy::@9127": 0x8037b80c,
		"@9127": 0x8037b80c,
		"Enemy::@9129": 0x8037b834,
		"@9129": 0x8037b834,
		"Enemy::@9131": 0x8037b844,
		"@9131": 0x8037b844,
		"Enemy::@9133": 0x8037b854,
		"@9133": 0x8037b854,
		"Enemy::@9134": 0x8037b868,
		"@9134": 0x8037b868,
		"Enemy::@9135": 0x8037b880,
		"@9135": 0x8037b880,
		"Enemy::@9136": 0x8037b894,
		"@9136": 0x8037b894,
		"Enemy::@9137": 0x8037b8a4,
		"@9137": 0x8037b8a4,
		"Enemy::@9139": 0x8037b8cc,
		"@9139": 0x8037b8cc,
		"Enemy::@9141": 0x8037b8dc,
		"@9141": 0x8037b8dc,
		"Enemy::@9142": 0x8037b8f0,
		"@9142": 0x8037b8f0,
		"Enemy::@9144": 0x8037b918,
		"@9144": 0x8037b918,
		"Enemy::@9146": 0x8037b92c,
		"@9146": 0x8037b92c,
		"Enemy::@9148": 0x8037b954,
		"@9148": 0x8037b954,
		"Enemy::@9150": 0x8037b964,
		"@9150": 0x8037b964,
		"Enemy::@2233": 0x8037b988,
		"Enemy::@2154": 0x8037b9a4,
		"Enemy::@2210": 0x8037b9b8,
		"Enemy::@2211": 0x8037b9e8,
		"Enemy::@2212": 0x8037ba20,
		"Enemy::@2213": 0x8037ba54,
		"Enemy::@3113": 0x8037bd8c,
		"Enemy::@5869": 0x8037c130,
		"Enemy::@5870": 0x8037c158,
		"Enemy::@5871": 0x8037c180,
		"Enemy::@5872": 0x8037c1ac,
		"Enemy::@5873": 0x8037c1d8,
		"Enemy::@7218": 0x8037c23c,
		"@7218": 0x8037c23c,
		"Enemy::@7220": 0x8037c250,
		"@7220": 0x8037c250,
		"Enemy::@7222": 0x8037c264,
		"@7222": 0x8037c264,
		"Enemy::@7223": 0x8037c278,
		"@7223": 0x8037c278,
		"Enemy::@7224": 0x8037c288,
		"@7224": 0x8037c288,
		"Enemy::@8315": 0x8037c314,
		"@8315": 0x8037c314,
		"Enemy::@8316": 0x8037c328,
		"@8316": 0x8037c328,
		"Enemy::@8317": 0x8037c33c,
		"@8317": 0x8037c33c,
		"Enemy::@8318": 0x8037c34c,
		"@8318": 0x8037c34c,
		"Enemy::@8320": 0x8037c374,
		"@8320": 0x8037c374,
		"Enemy::@8322": 0x8037c394,
		"Enemy::@8325": 0x8037c3b8,
		"Enemy::@8327": 0x8037c3c8,
		"Enemy::@8329": 0x8037c3dc,
		"@8329": 0x8037c3dc,
		"Enemy::@8331": 0x8037c3fc,
		"Enemy::@8334": 0x8037c420,
		"Enemy::@8335": 0x8037c434,
		"Enemy::@8336": 0x8037c448,
		"Enemy::@8338": 0x8037c45c,
		"Enemy::@6087": 0x8037d340,
		"@6087": 0x8037d340,
		"Enemy::@6088": 0x8037d358,
		"@6088": 0x8037d358,
		"Enemy::@6089": 0x8037d368,
		"Enemy::@6091": 0x8037d37c,
		"Enemy::@6093": 0x8037d3a4,
		"Enemy::entry$2906": 0x8037d528,
		"entry$2906": 0x8037d528,
		"Enemy::@2110": 0x8037d5b4,
		"Enemy::@7585": 0x8037da64,
		"Enemy::@7586": 0x8037da74,
		"@7586": 0x8037da74,
		"Enemy::@7587": 0x8037da84,
		"@7587": 0x8037da84,
		"Enemy::@7589": 0x8037daa4,
		"@7589": 0x8037daa4,
		"Enemy::@7590": 0x8037dab4,
		"@7590": 0x8037dab4,
		"Enemy::@7593": 0x8037dad4,
		"@7593": 0x8037dad4,
		"Enemy::@7595": 0x8037dae8,
		"@7595": 0x8037dae8,
		"Enemy::@2150": 0x8037def4,
		"Enemy::@4484": 0x8037e5b4,
		"Enemy::@4485": 0x8037e5c8,
		"Enemy::@5050": 0x8037ea04,
		"Enemy::@5053": 0x8037ea24,
		"Enemy::@2315": 0x8037ea44,
		"Enemy::@2554": 0x8037ea58,
		"Enemy::@2555": 0x8037ea88,
		"Enemy::@3934": 0x8037ed00,
		"Enemy::@3936": 0x8037ed34,
		"Enemy::@7630": 0x8037edf0,
		"@7630": 0x8037edf0,
		"Enemy::@7633": 0x8037ee14,
		"@7633": 0x8037ee14,
		"Enemy::@7634": 0x8037ee20,
		"@7634": 0x8037ee20,
		"Enemy::@7635": 0x8037ee2c,
		"@7635": 0x8037ee2c,
		"Enemy::@7636": 0x8037ee38,
		"Enemy::@7637": 0x8037ee44,
		"Enemy::@7638": 0x8037ee50,
		"Enemy::@7639": 0x8037ee5c,
		"Enemy::@7640": 0x8037ee68,
		"Enemy::@7641": 0x8037ee74,
		"Enemy::@7642": 0x8037ee80,
		"Enemy::@7643": 0x8037ee8c,
		"Enemy::@7644": 0x8037ee98,
		"Enemy::@7645": 0x8037eea4,
		"Enemy::@7646": 0x8037eeb0,
		"Enemy::@7647": 0x8037eebc,
		"Enemy::@7648": 0x8037eec8,
		"Enemy::@7649": 0x8037eed4,
		"Enemy::@7650": 0x8037eee0,
		"Enemy::@7651": 0x8037eeec,
		"Enemy::@7652": 0x8037eefc,
		"@7652": 0x8037eefc,
		"Enemy::@7677": 0x8037f29c,
		"@7677": 0x8037f29c,
		"Enemy::@8598": 0x8037f36c,
		"@8598": 0x8037f36c,
		"Enemy::@8599": 0x8037f37c,
		"@8599": 0x8037f37c,
		"Enemy::@8600": 0x8037f38c,
		"@8600": 0x8037f38c,
		"Enemy::@8601": 0x8037f39c,
		"@8601": 0x8037f39c,
		"Enemy::@8602": 0x8037f3b0,
		"@8602": 0x8037f3b0,
		"Enemy::@8603": 0x8037f3c4,
		"@8603": 0x8037f3c4,
		"Enemy::@8604": 0x8037f3d0,
		"@8604": 0x8037f3d0,
		"Enemy::@8605": 0x8037f3e0,
		"@8605": 0x8037f3e0,
		"Enemy::@8606": 0x8037f3f0,
		"@8606": 0x8037f3f0,
		"Enemy::@8607": 0x8037f404,
		"@8607": 0x8037f404,
		"Enemy::@8608": 0x8037f414,
		"@8608": 0x8037f414,
		"Enemy::@8609": 0x8037f424,
		"@8609": 0x8037f424,
		"Enemy::@8610": 0x8037f440,
		"@8610": 0x8037f440,
		"Enemy::@8611": 0x8037f458,
		"@8611": 0x8037f458,
		"Enemy::@8612": 0x8037f468,
		"@8612": 0x8037f468,
		"Enemy::@8613": 0x8037f47c,
		"@8613": 0x8037f47c,
		"Enemy::@8614": 0x8037f490,
		"@8614": 0x8037f490,
		"Enemy::@8615": 0x8037f4a4,
		"@8615": 0x8037f4a4,
		"Enemy::@9058": 0x8037f4e0,
		"@9058": 0x8037f4e0,
		"Enemy::@9060": 0x8037f4fc,
		"@9060": 0x8037f4fc,
		"Enemy::@9061": 0x8037f508,
		"@9061": 0x8037f508,
		"Enemy::@9062": 0x8037f518,
		"@9062": 0x8037f518,
		"Enemy::@5159": 0x8037fb8c,
		"Enemy::@5780": 0x8037fbcc,
		"@5780": 0x8037fbcc,
		"Enemy::@5782": 0x8037fbf8,
		"@5782": 0x8037fbf8,
		"Enemy::@5784": 0x8037fc04,
		"@5784": 0x8037fc04,
		"Enemy::@6156": 0x8037fd88,
		"Enemy::@6158": 0x8037fd94,
		"@6158": 0x8037fd94,
		"Enemy::@6161": 0x8037fdb4,
		"@6161": 0x8037fdb4,
		"Enemy::@6169": 0x8037fe54,
		"Enemy::@7954": 0x80380438,
		"@7954": 0x80380438,
		"Enemy::@7955": 0x80380460,
		"@7955": 0x80380460,
		"Enemy::@8097": 0x8038067c,
		"@8097": 0x8038067c,
		"Enemy::@8102": 0x803806c4,
		"@8102": 0x803806c4,
		"Enemy::@8104": 0x803806ec,
		"@8104": 0x803806ec,
		"Enemy::@8105": 0x80380704,
		"@8105": 0x80380704,
		"Enemy::@8106": 0x8038071c,
		"@8106": 0x8038071c,
		"Enemy::@8107": 0x80380734,
		"@8107": 0x80380734,
		"Enemy::@8109": 0x8038075c,
		"@8109": 0x8038075c,
		"Enemy::@8110": 0x8038076c,
		"@8110": 0x8038076c,
		"Enemy::@8111": 0x80380780,
		"@8111": 0x80380780,
		"Enemy::@8112": 0x80380798,
		"@8112": 0x80380798,
		"Enemy::@2118": 0x80380cd4,
		"Enemy::@2359": 0x80380d50,
		"Enemy::@2701": 0x80380f48,
		"Enemy::@4297": 0x80381120,
		"@4297": 0x80381120,
		"Enemy::@5348": 0x803815cc,
		"Enemy::@5349": 0x803815d8,
		"Enemy::@5350": 0x803815e8,
		"Enemy::@5351": 0x803815f8,
		"Enemy::@5353": 0x8038161c,
		"Enemy::@5354": 0x8038162c,
		"Enemy::@2261": 0x803817dc,
		"Enemy::entry$2260": 0x803817f4,
		"entry$2260": 0x803817f4,
		"Enemy::@1597": 0x80381870,
		"Enemy::@2029": 0x80381930,
		"Enemy::@2031": 0x80381940,
		"Enemy::@2004": 0x80381c08,
		"Enemy::@2005": 0x80381c38,
		"Enemy::@2006": 0x80381c70,
		"Enemy::@2007": 0x80381ca4,
		"Enemy::@2353": 0x80381cd4,
		"Enemy::@2715": 0x80381d48,
		"Enemy::@4364": 0x80381d8c,
		"Enemy::@4365": 0x80381da0,
		"Enemy::@4833": 0x80381db4,
		"Enemy::@4834": 0x80381dc8,
		"Enemy::@2220": 0x80381e28,
		"Enemy::@2221": 0x80381e58,
		"Enemy::@2222": 0x80381e90,
		"Enemy::@2223": 0x80381ec4,
		"Enemy::sBodyBckIndex$2891": 0x80381f50,
		"sBodyBckIndex$2891": 0x80381f50,
		"Enemy::sHeadBckIndex$2906": 0x80381f98,
		"sHeadBckIndex$2906": 0x80381f98,
		"Enemy::sHeadBtpIndex$2907": 0x80381fe0,
		"sHeadBtpIndex$2907": 0x80381fe0,
		"Enemy::sHeadBtkIndex$2908": 0x80382028,
		"sHeadBtkIndex$2908": 0x80382028,
		"Enemy::@1637": 0x803820c0,
		"Enemy::@1639": 0x803820d8,
		"Enemy::@1641": 0x803820ec,
		"Enemy::@1643": 0x80382104,
		"Enemy::@1645": 0x80382118,
		"@1645": 0x80382118,
		"Enemy::@1646": 0x8038212c,
		"@1646": 0x8038212c,
		"Enemy::@1648": 0x8038213c,
		"@1648": 0x8038213c,
		"Enemy::@1650": 0x80382150,
		"Enemy::@1652": 0x80382164,
		"Enemy::@1654": 0x8038217c,
		"@1654": 0x8038217c,
		"Enemy::@1656": 0x80382194,
		"@1656": 0x80382194,
		"Enemy::@1657": 0x803821ac,
		"Enemy::@1658": 0x803821c0,
		"Enemy::@1660": 0x803821d8,
		"Enemy::@1661": 0x803821ec,
		"Enemy::@1662": 0x80382208,
		"Enemy::@1666": 0x80382230,
		"Enemy::@1667": 0x80382244,
		"Enemy::@1669": 0x80382254,
		"Enemy::@1671": 0x80382264,
		"Enemy::@1673": 0x80382284,
		"Enemy::@1674": 0x8038229c,
		"Enemy::@1675": 0x803822b4,
		"Enemy::@1676": 0x803822c8,
		"Enemy::@1677": 0x803822dc,
		"@1677": 0x803822dc,
		"Enemy::@1678": 0x803822f0,
		"@1678": 0x803822f0,
		"Enemy::@1679": 0x80382304,
		"@1679": 0x80382304,
		"Enemy::@1681": 0x8038231c,
		"Enemy::@1682": 0x80382330,
		"Enemy::@1684": 0x80382344,
		"Enemy::@1686": 0x80382358,
		"Enemy::@1687": 0x80382370,
		"Enemy::@1778": 0x80382380,
		"Enemy::@1780": 0x80382390,
		"Enemy::@1786": 0x803823cc,
		"Enemy::@1788": 0x803823e0,
		"@1788": 0x803823e0,
		"Enemy::@1792": 0x80382408,
		"@1792": 0x80382408,
		"Enemy::@1793": 0x8038241c,
		"@1793": 0x8038241c,
		"Enemy::@1802": 0x80382494,
		"Enemy::@1803": 0x803824a8,
		"Enemy::@1805": 0x803824bc,
		"@1805": 0x803824bc,
		"Enemy::@1806": 0x803824d0,
		"Enemy::@1808": 0x803824e0,
		"Enemy::@1810": 0x803824f0,
		"Enemy::@1812": 0x80382504,
		"@1812": 0x80382504,
		"Enemy::@1814": 0x80382518,
		"@1814": 0x80382518,
		"Enemy::@1816": 0x80382530,
		"Enemy::@1818": 0x80382548,
		"Enemy::@1820": 0x80382560,
		"Enemy::@1821": 0x80382578,
		"@1821": 0x80382578,
		"Enemy::@1822": 0x80382590,
		"@1822": 0x80382590,
		"Enemy::@1824": 0x803825a4,
		"@1824": 0x803825a4,
		"Enemy::@1825": 0x803825b8,
		"Enemy::@2560": 0x8038268c,
		"Enemy::@2434": 0x80382d58,
		"@2434": 0x80382d58,
		"Enemy::@2435": 0x80382d88,
		"@2435": 0x80382d88,
		"Enemy::@2436": 0x80382dc0,
		"@2436": 0x80382dc0,
		"Enemy::@2437": 0x80382df4,
		"Enemy::sSnortStepFrames": 0x80382e18,
		"sSnortStepFrames": 0x80382e18,
		"Enemy::entry$2836": 0x803831b8,
		"entry$2836": 0x803831b8,
		"Enemy::@3211": 0x803831e8,
		"Enemy::@2444": 0x80383220,
		"Enemy::zangle$3575": 0x803833a0,
		"zangle$3575": 0x803833a0,
		"Enemy::@2122": 0x8038359c,
		"Enemy::@2363": 0x803835e0,
		"Enemy::@2365": 0x8038364c,
		"Enemy::@1755": 0x80383908,
		"Enemy::@1756": 0x80383938,
		"Enemy::@1757": 0x80383970,
		"Enemy::@1758": 0x803839a4,
		"Enemy::@1941": 0x803839f4,
		"Enemy::@1942": 0x80383a24,
		"Enemy::@1943": 0x80383a54,
		"Enemy::@1948": 0x80383b4c,
		"Enemy::@1949": 0x80383b7c,
		"Enemy::@1950": 0x80383ba8,
		"Enemy::@1951": 0x80383bd4,
		"Enemy::@1952": 0x80383c00,
		"Enemy::@1953": 0x80383c2c,
		"Enemy::@1954": 0x80383c64,
		"Enemy::@1956": 0x80383cc0,
		"Enemy::@2588": 0x80383f28,
		"Enemy::@2589": 0x80383f50,
		"Enemy::@3742": 0x8038408c,
		"Enemy::entry$3295": 0x80384648,
		"entry$3295": 0x80384648,
		"Enemy::@3477": 0x803847a8,
		"Enemy::@2766": 0x8038499c,
		"Enemy::@3287": 0x80384b58,
		"Enemy::@1529": 0x803851ec,
		"@1529": 0x803851ec,
		"Enemy::@1608": 0x80385230,
		"Enemy::@1609": 0x80385268,
		"Enemy::@1610": 0x8038529c,
		"Enemy::@2183": 0x80385310,
		"Enemy::@2184": 0x80385338,
		"Enemy::@2185": 0x8038535c,
		"Enemy::@2186": 0x80385384,
		"Enemy::@2187": 0x803853ac,
		"Enemy::@2188": 0x803853d4,
		"Enemy::@2189": 0x803853fc,
		"Enemy::@2190": 0x80385424,
		"Enemy::@2191": 0x8038544c,
		"Enemy::@2192": 0x80385470,
		"Enemy::@2193": 0x80385494,
		"Enemy::@3773": 0x8038575c,
		"Enemy::@3555": 0x80385bd0,
		"Enemy::@3573": 0x80385c6c,
		"@unnamed@::cDropCoinNumTable": 0x80385f1c,
		"cDropCoinNumTable": 0x80385f1c,
		"Enemy::@3632": 0x80385ff8,
		"Enemy::@4779": 0x803860a4,
		"Enemy::@1586": 0x80386138,
		"Enemy::@1587": 0x80386170,
		"Enemy::@1588": 0x803861a4,
		"Enemy::@2369": 0x803861c8,
		"Enemy::@2389": 0x80386208,
		"@unnamed@::cJointNames": 0x8038625c,
		"cJointNames": 0x8038625c,
		"Enemy::@5696": 0x803867e8,
		"@5696": 0x803867e8,
		"Enemy::@5697": 0x803867f8,
		"@5697": 0x803867f8,
		"Enemy::@5699": 0x8038682c,
		"@5699": 0x8038682c,
		"Enemy::@5703": 0x80386874,
		"@5703": 0x80386874,
		"Enemy::@5706": 0x803868bc,
		"Enemy::@2015": 0x80386c40,
		"Enemy::@2016": 0x80386c70,
		"Enemy::@2017": 0x80386ca8,
		"Enemy::@1525": 0x8038700c,
		"Enemy::@1582": 0x80387020,
		"Enemy::@1583": 0x80387050,
		"Enemy::@1584": 0x80387088,
		"Enemy::@2160": 0x803870e0,
		"Enemy::@2161": 0x803870ec,
		"Enemy::@3369": 0x80387398,
		"Enemy::@3784": 0x803876c4,
		"Enemy::@3790": 0x8038770c,
		"Camera::@1873": 0x803745f8,
		"@1873": 0x803745f8,
		"Camera::@1874": 0x80374628,
		"@1874": 0x80374628,
		"Camera::@1875": 0x80374660,
		"Camera::@1876": 0x80374694,
		"@1876": 0x80374694,
		"Camera::cDirtyFileName": 0x803746b8,
		"Camera::cDirtyTexName": 0x803746dc,
		"Camera::@1901": 0x803749d0,
		"@1901": 0x803749d0,
		"Camera::@1903": 0x803749dc,
		"@1903": 0x803749dc,
		"Camera::@1905": 0x803749ec,
		"@1905": 0x803749ec,
		"Camera::@1912": 0x80374a50,
		"Camera::@1915": 0x80374a7c,
		"@1915": 0x80374a7c,
		"Camera::@1917": 0x80374a94,
		"Camera::@1919": 0x80374aac,
		"@1919": 0x80374aac,
		"Camera::@1921": 0x80374ac4,
		"@1921": 0x80374ac4,
		"Camera::@1941": 0x80374c48,
		"Camera::@1943": 0x80374c60,
		"Camera::@1944": 0x80374c78,
		"Camera::@1946": 0x80374c90,
		"Camera::@1948": 0x80374ca8,
		"Camera::@1957": 0x80374d1c,
		"Camera::@1959": 0x80374d30,
		"Camera::@1961": 0x80374d44,
		"Camera::@1962": 0x80374d58,
		"Camera::@1964": 0x80374d6c,
		"Camera::@1966": 0x80374d7c,
		"Camera::@1967": 0x80374d8c,
		"Camera::@1968": 0x80374da0,
		"Camera::@1969": 0x80374db4,
		"Camera::@1970": 0x80374dc8,
		"Camera::@1971": 0x80374ddc,
		"Camera::@1972": 0x80374df0,
		"Camera::@1973": 0x80374e00,
		"Camera::@1974": 0x80374e10,
		"Camera::@1975": 0x80374e28,
		"Camera::@1976": 0x80374e3c,
		"Camera::@1977": 0x80374e4c,
		"Camera::@1988": 0x80374f14,
		"@1988": 0x80374f14,
		"Camera::@1989": 0x80374f24,
		"Camera::@1994": 0x80374f74,
		"Camera::@1995": 0x80374f84,
		"Camera::@2003": 0x80375020,
		"Camera::@2004": 0x80375034,
		"Camera::@2005": 0x80375044,
		"Camera::@2006": 0x80375054,
		"Camera::@2007": 0x80375064,
		"Camera::@2008": 0x80375074,
		"Camera::@2009": 0x80375084,
		"Camera::@2012": 0x803750b4,
		"Camera::@2013": 0x803750c8,
		"Camera::@2014": 0x803750dc,
		"Camera::@2015": 0x803750ec,
		"Camera::@2016": 0x80375100,
		"Camera::@2017": 0x80375114,
		"Camera::@2021": 0x8037515c,
		"Camera::@2022": 0x8037516c,
		"Camera::@2023": 0x80375184,
		"Camera::@2029": 0x803751f4,
		"Camera::@2030": 0x80375204,
		"Camera::@2031": 0x80375214,
		"Camera::@2032": 0x80375224,
		"Camera::@2033": 0x80375238,
		"Camera::@2034": 0x80375248,
		"Camera::@2035": 0x80375260,
		"Camera::@2036": 0x80375270,
		"Camera::@2037": 0x80375280,
		"Camera::@2038": 0x80375294,
		"Camera::@2119": 0x803752a8,
		"Camera::@2120": 0x803752c4,
		"Camera::@2122": 0x803752d0,
		"Camera::@2123": 0x803752e0,
		"Camera::@2127": 0x80375314,
		"Camera::@2129": 0x80375328,
		"Camera::@2130": 0x80375340,
		"Camera::@2131": 0x80375350,
		"Camera::@2135": 0x80375380,
		"Camera::@2136": 0x80375390,
		"Camera::@2138": 0x803753a0,
		"Camera::@2139": 0x803753b4,
		"Camera::@2141": 0x803753dc,
		"Camera::@2142": 0x803753f0,
		"Camera::@2143": 0x8037540c,
		"Camera::@2144": 0x80375420,
		"Camera::@2146": 0x80375434,
		"Camera::@2147": 0x8037544c,
		"Camera::@2148": 0x80375464,
		"Camera::@2150": 0x8037548c,
		"Camera::@2151": 0x803754a0,
		"Camera::@2152": 0x803754b4,
		"Camera::@2174": 0x803754ec,
		"Camera::@2175": 0x80375504,
		"Camera::@2203": 0x80375584,
		"Camera::@2204": 0x80375590,
		"Camera::@2206": 0x8037559c,
		"Camera::@2207": 0x803755a8,
		"Camera::@2208": 0x803755b4,
		"Camera::@1632": 0x803756f0,
		"Camera::@2078": 0x80375750,
		"Camera::@2079": 0x8037575c,
		"Camera::@2223": 0x80375780,
		"Camera::@2224": 0x8037578c,
		"CPolarSubCamera::sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x80375858,
		"sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x80375858,
		"Camera::@1681": 0x80375948,
		"Camera::@1682": 0x80375974,
		"Camera::@1683": 0x803759a4,
		"Camera::@1684": 0x803759c8,
		"Camera::@1685": 0x803759d8,
		"Camera::@1686": 0x803759e8,
		"Camera::@1687": 0x803759fc,
		"Camera::@1688": 0x80375a2c,
		"Camera::@1689": 0x80375a60,
		"Camera::@1837": 0x80375a88,
		"@1837": 0x80375a88,
		"Camera::@1650": 0x80375ac8,
		"Camera::@1535": 0x80375b10,
		"Camera::@1578": 0x80375f70,
		"Camera::@1579": 0x80375f88,
		"Camera::@1580": 0x80375fa0,
		"Camera::@1581": 0x80375fb8,
		"Camera::@1582": 0x80375fd4,
		"Camera::@1583": 0x80375ff0,
		"Camera::@1584": 0x80376008,
		"Camera::@1585": 0x80376024,
		"Camera::@1586": 0x80376040,
		"Camera::@1587": 0x8037605c,
		"Camera::@1588": 0x80376078,
		"Camera::@1589": 0x80376090,
		"Camera::@1590": 0x803760a8,
		"Camera::@1591": 0x803760c0,
		"Camera::@1592": 0x803760e0,
		"Camera::@1597": 0x80376164,
		"Camera::@1598": 0x80376180,
		"Camera::@1599": 0x80376198,
		"Camera::@1600": 0x803761b0,
		"Camera::@1601": 0x803761c8,
		"Camera::@1602": 0x803761e4,
		"Camera::@1603": 0x803761fc,
		"Camera::@1604": 0x8037621c,
		"Camera::@1605": 0x80376234,
		"Camera::@1606": 0x8037624c,
		"Camera::@1607": 0x80376268,
		"Animal::@2230": 0x80373580,
		"Animal::@2231": 0x8037358c,
		"Animal::@2232": 0x80373598,
		"Animal::@2233": 0x803735a4,
		"@unnamed@::cFishoidMdlNames": 0x803735b0,
		"cFishoidMdlNames": 0x803735b0,
		"Animal::entry$2319": 0x803735c0,
		"entry$2319": 0x803735c0,
		"Animal::@2688": 0x80373608,
		"Animal::@3202": 0x80373618,
		"Animal::@2337": 0x80373648,
		"Animal::@2338": 0x80373678,
		"Animal::@2340": 0x803736e4,
		"Animal::@2543": 0x80373708,
		"Animal::entry$2542": 0x80373718,
		"entry$2542": 0x80373718,
		"Animal::@2573": 0x80373730,
		"Animal::@1562": 0x80373760,
		"Animal::@1563": 0x80373770,
		"Animal::@1565": 0x80373780,
		"Animal::@1567": 0x80373790,
		"Animal::@1569": 0x803737a4,
		"Animal::@1571": 0x803737b8,
		"Animal::@1573": 0x803737c8,
		"Animal::@1575": 0x803737dc,
		"Animal::@1577": 0x803737f0,
		"Animal::@1940": 0x80373814,
		"Animal::@2018": 0x80373828,
		"Animal::@2019": 0x80373858,
		"Animal::@2020": 0x80373890,
		"Animal::@2021": 0x803738c4,
		"Animal::@2904": 0x803738e8,
		"Animal::@2905": 0x80373908,
		"Animal::@2906": 0x80373928,
		"Animal::@2907": 0x80373948,
		"@unnamed@::cRandomAnims": 0x80373968,
		"cRandomAnims": 0x80373968,
		"Animal::@2909": 0x8037397c,
		"@unnamed@::cColorTable": 0x80373988,
		"Animal::entry$3023": 0x803739b8,
		"entry$3023": 0x803739b8,
		"Animal::@3452": 0x803739d0,
		"Animal::@3871": 0x803739e4,
		"Animal::@3928": 0x803739f8,
		"Animal::@3929": 0x80373a04,
		"Animal::@3931": 0x80373a10,
		"Animal::@3932": 0x80373a20,
		"Animal::@3934": 0x80373a30,
		"Animal::@3936": 0x80373a40,
		"Animal::@3938": 0x80373a50,
		"Animal::@3940": 0x80373a60,
		"Animal::@3941": 0x80373a70,
		"Animal::@3942": 0x80373a84,
		"Animal::@3943": 0x80373a98,
		"Animal::@3945": 0x80373aac,
		"Animal::@3947": 0x80373abc,
		"Animal::@3948": 0x80373acc,
		"Animal::@3949": 0x80373adc,
		"Animal::@3950": 0x80373ae8,
		"Animal::@3952": 0x80373af8,
		"Animal::@3953": 0x80373b08,
		"Animal::@1996": 0x80373b38,
		"Animal::@1997": 0x80373b68,
		"Animal::@1998": 0x80373ba0,
		"Animal::@1999": 0x80373bd4,
		"Animal::@2986": 0x80373bf8,
		"Animal::@2987": 0x80373c08,
		"Animal::@2988": 0x80373c18,
		"Animal::entry$2985": 0x80373c2c,
		"Animal::@3447": 0x80373c5c,
		"Animal::@3661": 0x80373c6c,
		"Animal::@3662": 0x80373c80,
		"Animal::@3663": 0x80373c90,
		"Animal::@3665": 0x80373ca0,
		"Animal::@3666": 0x80373cb0,
		"Animal::@3670": 0x80373cbc,
		"Animal::@3672": 0x80373ccc,
		"Animal::@3674": 0x80373cd8,
		"Animal::@3675": 0x80373ce8,
		"Animal::@5081": 0x80373cf8,
		"Animal::@2393": 0x80373de8,
		"Animal::@2394": 0x80373df8,
		"Animal::@2395": 0x80373e08,
		"@unnamed@::cButterflyMdlNames": 0x80373e18,
		"cButterflyMdlNames": 0x80373e18,
		"Animal::entry$2459": 0x80373e24,
		"entry$2459": 0x80373e24,
		"Animal::@2493": 0x80373e54,
		"Animal::@2594": 0x80373e64,
		"Animal::@2711": 0x80373e74,
		"MAnmSoundMario::__vt": 0x803ac450,
		"Camera::@3715": 0x803acbf8,
		"Camera::@3891": 0x803accc4,
		"Enemy::names$3265": 0x803aeef4,
		"names$3265": 0x803aeef4,
		"Enemy::bmdFileNames$3278": 0x803aef08,
		"bmdFileNames$3278": 0x803aef08,
		"Enemy::entry$2959": 0x803af34c,
		"entry$2959": 0x803af34c,
		"Enemy::entry$3041": 0x803afc6c,
		"entry$3041": 0x803afc6c,
		"Enemy::entry$3108": 0x803afc84,
		"entry$3108": 0x803afc84,
		"Enemy::entry$3118": 0x803afc9c,
		"entry$3118": 0x803afc9c,
		"Enemy::entry$3161": 0x803afccc,
		"entry$3161": 0x803afccc,
		"Enemy::entry$2940": 0x803b1778,
		"entry$2940": 0x803b1778,
		"Enemy::@6300": 0x803b29e8,
		"@6300": 0x803b29e8,
		"Enemy::entry$2985": 0x803b32cc,
		"Enemy::entry$3395": 0x803b32e4,
		"entry$3395": 0x803b32e4,
		"Enemy::entry$3029": 0x803b3eb0,
		"entry$3029": 0x803b3eb0,
		"Enemy::table$3022": 0x803b5668,
		"table$3022": 0x803b5668,
		"Enemy::table$3034": 0x803b5698,
		"table$3034": 0x803b5698,
		"Enemy::table$3035": 0x803b56b0,
		"table$3035": 0x803b56b0,
		"Enemy::table$3037": 0x803b56dc,
		"table$3037": 0x803b56dc,
		"Enemy::table$3038": 0x803b56f0,
		"table$3038": 0x803b56f0,
		"Enemy::table$3039": 0x803b5704,
		"table$3039": 0x803b5704,
		"Enemy::table$3040": 0x803b5718,
		"table$3040": 0x803b5718,
		"Enemy::onetimeFilenames$3486": 0x803b577c,
		"onetimeFilenames$3486": 0x803b577c,
		"Enemy::loopFilenames$3500": 0x803b5798,
		"loopFilenames$3500": 0x803b5798,
		"Enemy::graphlist$2864": 0x803b6534,
		"graphlist$2864": 0x803b6534,
		"Enemy::entry$3103": 0x803b6850,
		"entry$3103": 0x803b6850,
		"Enemy::entry$3330": 0x803b6868,
		"entry$3330": 0x803b6868,
		"Enemy::entry$3142": 0x803b7674,
		"entry$3142": 0x803b7674,
		"Enemy::entry$3269": 0x803b799c,
		"entry$3269": 0x803b799c,
		"Enemy::manNameTable$3929": 0x803b79b4,
		"manNameTable$3929": 0x803b79b4,
		"Enemy::sCannonDomPartsJointTable$3045": 0x803b8898,
		"sCannonDomPartsJointTable$3045": 0x803b8898,
		"Enemy::entry$3117": 0x803b8c94,
		"entry$3117": 0x803b8c94,
		"Enemy::sEyePartsJointTable$3526": 0x803b8cb8,
		"sEyePartsJointTable$3526": 0x803b8cb8,
		"Enemy::sToothPartsJointTable$3537": 0x803b8cc8,
		"sToothPartsJointTable$3537": 0x803b8cc8,
		"Enemy::sCollisionJointTable$3569": 0x803b8ce8,
		"sCollisionJointTable$3569": 0x803b8ce8,
		"Enemy::sCollisionFileTable$3573": 0x803b8cf8,
		"sCollisionFileTable$3573": 0x803b8cf8,
		"Enemy::entry$3038": 0x803b984c,
		"entry$3038": 0x803b984c,
		"Enemy::entry$2762": 0x803b9d48,
		"entry$2762": 0x803b9d48,
		"Enemy::entry$2896": 0x803b9d60,
		"entry$2896": 0x803b9d60,
		"Enemy::jIndexTable$3048": 0x803b9d84,
		"jIndexTable$3048": 0x803b9d84,
		"Enemy::entry$3090": 0x803b9d94,
		"entry$3090": 0x803b9d94,
		"Enemy::entry$2822": 0x803bb278,
		"entry$2822": 0x803bb278,
		"Enemy::jntidx$3419": 0x803bbe8c,
		"jntidx$3419": 0x803bbe8c,
		"Enemy::@4439": 0x803bbeec,
		"Enemy::@4829": 0x803bbf18,
		"Enemy::entry$2800": 0x803bc48c,
		"entry$2800": 0x803bc48c,
		"Enemy::entry$2814": 0x803bcb58,
		"entry$2814": 0x803bcb58,
		"Enemy::entry$3228": 0x803beab4,
		"entry$3228": 0x803beab4,
		"Enemy::entry$2932": 0x803bed4c,
		"entry$2932": 0x803bed4c,
		"GC2D::scDolpicNewsDolpic8_Aa1": 0x803c0050,
		"scDolpicNewsDolpic8_Aa1": 0x803c0050,
		"GC2D::scDolpicNewsDolpic8_Aa2": 0x803c0060,
		"scDolpicNewsDolpic8_Aa2": 0x803c0060,
		"GC2D::scDolpicNewsDolpic8_Aa3": 0x803c0074,
		"scDolpicNewsDolpic8_Aa3": 0x803c0074,
		"GC2D::scDolpicNewsDolpic8_Aa4": 0x803c0084,
		"scDolpicNewsDolpic8_Aa4": 0x803c0084,
		"GC2D::scDolpicNewsDolpic8_Ab1": 0x803c0090,
		"scDolpicNewsDolpic8_Ab1": 0x803c0090,
		"GC2D::scDolpicNewsDolpic8_Ab2": 0x803c00a0,
		"scDolpicNewsDolpic8_Ab2": 0x803c00a0,
		"GC2D::scDolpicNewsDolpic8_Ab3": 0x803c00b4,
		"scDolpicNewsDolpic8_Ab3": 0x803c00b4,
		"GC2D::scDolpicNewsDolpic8_Ab4": 0x803c00c4,
		"scDolpicNewsDolpic8_Ab4": 0x803c00c4,
		"GC2D::scDolpicNewsDolpic8_Ac1": 0x803c00d0,
		"scDolpicNewsDolpic8_Ac1": 0x803c00d0,
		"GC2D::scDolpicNewsDolpic8_Ac2": 0x803c00dc,
		"scDolpicNewsDolpic8_Ac2": 0x803c00dc,
		"GC2D::scDolpicNewsDolpic8_Ac3": 0x803c00ec,
		"scDolpicNewsDolpic8_Ac3": 0x803c00ec,
		"GC2D::scDolpicNewsDolpic8_Ba1": 0x803c00f8,
		"scDolpicNewsDolpic8_Ba1": 0x803c00f8,
		"GC2D::scDolpicNewsDolpic8_Ba2": 0x803c010c,
		"scDolpicNewsDolpic8_Ba2": 0x803c010c,
		"GC2D::scDolpicNewsDolpic8_Ba3": 0x803c0124,
		"scDolpicNewsDolpic8_Ba3": 0x803c0124,
		"GC2D::scDolpicNewsDolpic8_Ba4": 0x803c0138,
		"scDolpicNewsDolpic8_Ba4": 0x803c0138,
		"GC2D::scDolpicNewsDolpic8_Bb1": 0x803c0148,
		"scDolpicNewsDolpic8_Bb1": 0x803c0148,
		"GC2D::scDolpicNewsDolpic8_Bb2": 0x803c015c,
		"scDolpicNewsDolpic8_Bb2": 0x803c015c,
		"GC2D::scDolpicNewsDolpic8_Bb3": 0x803c0174,
		"scDolpicNewsDolpic8_Bb3": 0x803c0174,
		"GC2D::scDolpicNewsDolpic8_Bb4": 0x803c0188,
		"scDolpicNewsDolpic8_Bb4": 0x803c0188,
		"GC2D::scDolpicNewsDolpic8_Bc1": 0x803c0198,
		"scDolpicNewsDolpic8_Bc1": 0x803c0198,
		"GC2D::scDolpicNewsDolpic8_Bc2": 0x803c01a8,
		"scDolpicNewsDolpic8_Bc2": 0x803c01a8,
		"GC2D::scDolpicNewsDolpic8_Bc3": 0x803c01bc,
		"scDolpicNewsDolpic8_Bc3": 0x803c01bc,
		"GC2D::scDolpicNewsDolpic8_Bc4": 0x803c01cc,
		"scDolpicNewsDolpic8_Bc4": 0x803c01cc,
		"GC2D::scDolpicNewsDolpic8_Ca1": 0x803c01d8,
		"scDolpicNewsDolpic8_Ca1": 0x803c01d8,
		"GC2D::scDolpicNewsDolpic8_Ca2": 0x803c01e8,
		"scDolpicNewsDolpic8_Ca2": 0x803c01e8,
		"GC2D::scDolpicNewsDolpic8_Ca3": 0x803c01fc,
		"scDolpicNewsDolpic8_Ca3": 0x803c01fc,
		"GC2D::scDolpicNewsDolpic8_Ca4": 0x803c020c,
		"scDolpicNewsDolpic8_Ca4": 0x803c020c,
		"GC2D::scDolpicNewsDolpic8_Cb1": 0x803c0218,
		"scDolpicNewsDolpic8_Cb1": 0x803c0218,
		"GC2D::scDolpicNewsDolpic8_Cb2": 0x803c0228,
		"scDolpicNewsDolpic8_Cb2": 0x803c0228,
		"GC2D::scDolpicNewsDolpic8_Cb3": 0x803c023c,
		"scDolpicNewsDolpic8_Cb3": 0x803c023c,
		"GC2D::scDolpicNewsDolpic8_Cb4": 0x803c024c,
		"scDolpicNewsDolpic8_Cb4": 0x803c024c,
		"GC2D::scDolpicNewsDolpic8_Cc1": 0x803c0258,
		"scDolpicNewsDolpic8_Cc1": 0x803c0258,
		"GC2D::scDolpicNewsDolpic8_Cc2": 0x803c0264,
		"scDolpicNewsDolpic8_Cc2": 0x803c0264,
		"GC2D::scDolpicNewsDolpic8_Cc3": 0x803c0274,
		"scDolpicNewsDolpic8_Cc3": 0x803c0274,
		"GC2D::scDolpicNewsDolpic8_Da1": 0x803c0280,
		"scDolpicNewsDolpic8_Da1": 0x803c0280,
		"GC2D::scDolpicNewsDolpic8_Da2": 0x803c028c,
		"scDolpicNewsDolpic8_Da2": 0x803c028c,
		"GC2D::scDolpicNewsDolpic8_Da3": 0x803c029c,
		"scDolpicNewsDolpic8_Da3": 0x803c029c,
		"GC2D::scDolpicNewsDolpic8_Db1": 0x803c02a8,
		"scDolpicNewsDolpic8_Db1": 0x803c02a8,
		"GC2D::scDolpicNewsDolpic8_Db2": 0x803c02b4,
		"scDolpicNewsDolpic8_Db2": 0x803c02b4,
		"GC2D::scDolpicNewsDolpic8_Db3": 0x803c02c4,
		"scDolpicNewsDolpic8_Db3": 0x803c02c4,
		"GC2D::scDolpicNewsDolpic8_Dc2": 0x803c02d0,
		"scDolpicNewsDolpic8_Dc2": 0x803c02d0,
		"GC2D::@6848": 0x803c0328,
		"@6848": 0x803c0328,
		"GC2D::@7412": 0x803c0354,
		"@7412": 0x803c0354,
		"GC2D::@3872": 0x803c03ec,
		"GC2D::@4236": 0x803c07c4,
		"GC2D::@4583": 0x803c09ec,
		"GC2D::@7279": 0x803c0ac4,
		"@7279": 0x803c0ac4,
		"GC2D::@7721": 0x803c0ae4,
		"@7721": 0x803c0ae4,
		"GC2D::@7718": 0x803c0b0c,
		"@7718": 0x803c0b0c,
		"GC2D::strDispProg": 0x803c1148,
		"strDispProg": 0x803c1148,
		"GC2D::strSetProg": 0x803c117c,
		"strSetProg": 0x803c117c,
		"GC2D::strSetInter": 0x803c11ec,
		"strSetInter": 0x803c11ec,
		"GC2D::@2195": 0x803c1508,
		"GC2D::@2197": 0x803c1514,
		"GC2D::@2199": 0x803c1520,
		"GC2D::@2201": 0x803c152c,
		"GC2D::@2204": 0x803c1538,
		"GC2D::@2206": 0x803c1544,
		"GC2D::@2213": 0x803c1568,
		"GC2D::@2215": 0x803c1574,
		"Map::@3484": 0x803c1b54,
		"MoveBG::item_names$2995": 0x803c8d30,
		"item_names$2995": 0x803c8d30,
		"MoveBG::@4305": 0x803c93e0,
		"MoveBG::@5101": 0x803cefa4,
		"TWatermelonStatic::__vt": 0x803cf150,
		"NPC::sCameraNames$2617": 0x803d9468,
		"sCameraNames$2617": 0x803d9468,
		"Strategic::@3446": 0x803d9db8,
		"Player::@5864": 0x803dd0a0,
		"Player::@5723": 0x803dd168,
		"Player::@6690": 0x803dd190,
		"@6690": 0x803dd190,
		"Player::@6689": 0x803dd1b4,
		"@6689": 0x803dd1b4,
		"Player::param$3386": 0x803dd218,
		"param$3386": 0x803dd218,
		"Player::param$3389": 0x803dd22c,
		"param$3389": 0x803dd22c,
		"Player::param$3392": 0x803dd240,
		"param$3392": 0x803dd240,
		"Player::param$3395": 0x803dd254,
		"param$3395": 0x803dd254,
		"Player::param$3400": 0x803dd268,
		"param$3400": 0x803dd268,
		"Player::param$3403": 0x803dd27c,
		"param$3403": 0x803dd27c,
		"System::@2156": 0x803dee38,
		"System::@2189": 0x803dee64,
		"System::@3617": 0x803defd8,
		"System::@4380": 0x803df02c,
		"System::@2821": 0x803df090,
		"System::movies$2059": 0x803dfa00,
		"movies$2059": 0x803dfa00,
		"TEndingString::__vt": 0x803dfabc,
		"MSStageCubeFadeDouble::__vt": 0x803dfce4,
		"JKRFile::__vt": 0x803dfd70,
		"JKRAramArchive::__vt": 0x803dfd90,
		"JKRAramHeap::__vt": 0x803dfdd8,
		"JKRAram::sMessageBuffer": 0x803dfde8,
		"JKRAram::sMessageQueue": 0x803dfdf8,
		"JKRAram::__vt": 0x803dfe18,
		"JKRArchive::__vt": 0x803dfe28,
		"JKRCompArchive::__vt": 0x803dfe70,
		"JKRDisposer::__vt": 0x803dfeb8,
		"JKRDvdArchive::__vt": 0x803dfec8,
		"JKRDvdFile::__vt": 0x803dff10,
		"JKRExpHeap::__vt": 0x803dff38,
		"JKRArcFinder::__vt": 0x803dff88,
		"JKRFileLoader::__vt": 0x803dff98,
		"JKRHeap::__vt": 0x803dffd8,
		"JKRMemArchive::__vt": 0x803e0028,
		"JKRSolidHeap::__vt": 0x803e0070,
		"JKRStdHeap::__vt": 0x803e00c0,
		"JKRThread::__vt": 0x803e0110,
		"JSURandomOutputStream::__vt": 0x803e0120,
		"JSUOutputStream::__vt": 0x803e0148,
		"JSURandomInputStream::__vt": 0x803e0160,
		"JSUInputStream::__vt": 0x803e0184,
		"JSUMemoryOutputStream::__vt": 0x803e01a0,
		"JSUMemoryInputStream::__vt": 0x803e01c8,
		"JSUFileInputStream::__vt": 0x803e01f0,
		"JUTException::sMessageQueue": 0x803e0218,
		"JUTException::sCpuExpName": 0x803e0238,
		"sCpuExpName": 0x803e0238,
		"JUTException::__vt": 0x803e0278,
		"JUTDirectPrint::sAsciiTable": 0x803e0288,
		"sAsciiTable": 0x803e0288,
		"JUTDirectPrint::sFontData": 0x803e0308,
		"sFontData": 0x803e0308,
		"JUTDirectPrint::sFontData2": 0x803e0408,
		"sFontData2": 0x803e0408,
		"JUTFont::__vt": 0x803e0540,
		"JSystem::channel_mask": 0x803e0578,
		"channel_mask": 0x803e0578,
		"JUTGamePad::__vt": 0x803e0588,
		"J2DPane::__vt": 0x803e0598,
		"J2DPicture::__vt": 0x803e05c8,
		"J2DPrint::__vt": 0x803e0658,
		"J2DSetScreen::__vt": 0x803e06b8,
		"J2DScreen::__vt": 0x803e06ec,
		"J2DTextBox::__vt": 0x803e0720,
		"J2DWindow::__vt": 0x803e0750,
		"J2DWindow::Texture::__vt": 0x803e077c,
		"JSystem::j3dDefaultTransformInfo": 0x803e0788,
		"j3dDefaultTransformInfo": 0x803e0788,
		"JSystem::j3dDefaultMtx": 0x803e07a8,
		"j3dDefaultMtx": 0x803e07a8,
		"JSystem::PSMulUnit01": 0x803e07d8,
		"PSMulUnit01": 0x803e07d8,
		"J3DSkinDeform::__vt": 0x803e07e0,
		"J3DJoint::__vt": 0x803e07f0,
		"J3DMtxCalcMayaAnm::__vt": 0x803e0818,
		"J3DMtxCalcMaya::__vt": 0x803e086c,
		"J3DMtxCalcSoftimage::__vt": 0x803e08b0,
		"J3DMtxCalcBasic::__vt": 0x803e08f4,
		"J3DMtxCalcAnm::__vt": 0x803e0938,
		"J3DPEBlockFull::__vt": 0x803e0968,
		"J3DIndBlockFull::__vt": 0x803e09cc,
		"J3DTevBlock16::__vt": 0x803e0a14,
		"J3DTevBlock4::__vt": 0x803e0ab0,
		"J3DTevBlock2::__vt": 0x803e0b4c,
		"J3DTevBlock1::__vt": 0x803e0be8,
		"J3DTexGenBlockBasic::__vt": 0x803e0c84,
		"J3DColorBlockLightOn::__vt": 0x803e0cd4,
		"J3DColorBlockLightOff::__vt": 0x803e0d38,
		"J3DPEBlockXlu::__vt": 0x803e0d9c,
		"J3DPEBlockTexEdge::__vt": 0x803e0e00,
		"J3DPEBlockOpa::__vt": 0x803e0e64,
		"J3DPEBlock::__vt": 0x803e0ec8,
		"J3DIndBlockNull::__vt": 0x803e0f2c,
		"J3DIndBlock::__vt": 0x803e0f74,
		"J3DTevBlock::__vt": 0x803e0fbc,
		"J3DTexGenBlock::__vt": 0x803e1058,
		"J3DColorBlock::__vt": 0x803e10a8,
		"J3DModel::__vt": 0x803e115c,
		"J3DModelData::__vt": 0x803e1178,
		"J3DNode::__vt": 0x803e1188,
		"JSystem::@952": 0x803e11b0,
		"@952": 0x803e11b0,
		"JSystem::@953": 0x803e11bc,
		"@953": 0x803e11bc,
		"JSystem::@954": 0x803e11c8,
		"@954": 0x803e11c8,
		"J3DShapeMtx::mtxLoadPipeline": 0x803e11e0,
		"mtxLoadPipeline": 0x803e11e0,
		"J3DShapeDraw::__vt": 0x803e1210,
		"J3DShapeMtxMulti::__vt": 0x803e121c,
		"J3DShapeMtxDL::__vt": 0x803e123c,
		"J3DShapeMtx::__vt": 0x803e125c,
		"J3DAnmColorKey::__vt": 0x803e1290,
		"J3DAnmColor::__vt": 0x803e12a0,
		"J3DAnmColorFull::__vt": 0x803e12b0,
		"J3DAnmVtxColorKey::__vt": 0x803e12c0,
		"J3DAnmVtxColor::__vt": 0x803e12d0,
		"J3DAnmVtxColorFull::__vt": 0x803e12e0,
		"J3DAnmClusterKey::__vt": 0x803e12f0,
		"J3DAnmCluster::__vt": 0x803e1300,
		"J3DAnmClusterFull::__vt": 0x803e1310,
		"J3DAnmTransformKey::__vt": 0x803e1320,
		"J3DAnmTransform::__vt": 0x803e1334,
		"J3DAnmTransformFull::__vt": 0x803e1344,
		"J3DAnmBase::__vt": 0x803e1354,
		"J3DModelLoader_v21::__vt": 0x803e1360,
		"J3DModelLoader_v26::__vt": 0x803e1388,
		"J3DTexture::__vt": 0x803e13b0,
		"J3DModelLoader::__vt": 0x803e13bc,
		"J3DAnmKeyLoader_v15::__vt": 0x803e13e8,
		"J3DAnmFullLoader_v15::__vt": 0x803e13f8,
		"J3DAnmLoader::__vt": 0x803e1408,
		"J3DAnmVisibilityFull::__vt": 0x803e1418,
		"J3DAnmTexPattern::__vt": 0x803e1424,
		"J3DAnmTevRegKey::__vt": 0x803e1430,
		"J3DAnmTextureSRTKey::__vt": 0x803e143c,
		"J2DGrafContext::__vt": 0x803e1448,
		"JKRDecomp::sMessageBuffer": 0x803e1470,
		"JKRDecomp::sMessageQueue": 0x803e1480,
		"JKRDecomp::__vt": 0x803e14a0,
		"J2DOrthoGraph::__vt": 0x803e14b0,
		"J3DVertexBuffer::__vt": 0x803e14d8,
		"J3DShapePacket::__vt": 0x803e14e8,
		"J3DMatPacket::__vt": 0x803e1500,
		"J3DDrawPacket::__vt": 0x803e1518,
		"J3DCallBackPacket::__vt": 0x803e1530,
		"J3DPacket::__vt": 0x803e1548,
		"JSystem::j3dDefaultLightInfo": 0x803e15a4,
		"j3dDefaultLightInfo": 0x803e15a4,
		"JSystem::j3dDefaultTexCoordInfo": 0x803e15d8,
		"j3dDefaultTexCoordInfo": 0x803e15d8,
		"JSystem::j3dDefaultTexMtxInfo": 0x803e15f8,
		"j3dDefaultTexMtxInfo": 0x803e15f8,
		"JSystem::j3dDefaultIndTexMtxInfo": 0x803e165c,
		"j3dDefaultIndTexMtxInfo": 0x803e165c,
		"JSystem::j3dDefaultTevStageInfo": 0x803e1678,
		"j3dDefaultTevStageInfo": 0x803e1678,
		"JSystem::j3dDefaultIndTevStageInfo": 0x803e168c,
		"j3dDefaultIndTevStageInfo": 0x803e168c,
		"JSystem::j3dDefaultFogInfo": 0x803e1698,
		"j3dDefaultFogInfo": 0x803e1698,
		"JSystem::j3dDefaultNBTScaleInfo": 0x803e16c4,
		"j3dDefaultNBTScaleInfo": 0x803e16c4,
		"JSystem::@815": 0x803e16e4,
		"@815": 0x803e16e4,
		"JSystem::@816": 0x803e16f0,
		"@816": 0x803e16f0,
		"JSystem::@817": 0x803e16fc,
		"@817": 0x803e16fc,
		"JSystem::@818": 0x803e1708,
		"@818": 0x803e1708,
		"JSystem::@819": 0x803e1714,
		"@819": 0x803e1714,
		"J3DDrawBuffer::sortFuncTable": 0x803e1720,
		"sortFuncTable": 0x803e1720,
		"JSystem::@820": 0x803e1768,
		"@820": 0x803e1768,
		"JSystem::@821": 0x803e1774,
		"@821": 0x803e1774,
		"J3DDrawBuffer::drawFuncTable": 0x803e1780,
		"drawFuncTable": 0x803e1780,
		"J3DMaterialAnm::__vt": 0x803e1798,
		"J3DTexNoAnm::__vt": 0x803e17a8,
		"JKRAramBlock::__vt": 0x803e17b8,
		"JKRAramStream::sMessageBuffer": 0x803e17c8,
		"JKRAramStream::sMessageQueue": 0x803e17d8,
		"JKRAramStream::__vt": 0x803e17f8,
		"JUTResFont::saoAboutEncoding_": 0x803e1808,
		"JUTResFont::__vt": 0x803e1814,
		"JUTRomFont::saoAboutEncoding_": 0x803e1850,
		"JUTRomFont::__vt": 0x803e1868,
		"JSystem::@320": 0x803e18a8,
		"JSystem::c2r$795": 0x803e18fc,
		"c2r$795": 0x803e18fc,
		"JUTConsole::__vt": 0x803e1910,
		"JDrama::TActor::__vt": 0x803e1920,
		"JDrama::TOrthoProj::__vt": 0x803e19c0,
		"JDrama::TLookAtCamera::__vt": 0x803e1a94,
		"JDrama::TPolarCamera::__vt": 0x803e1b88,
		"JDrama::TCamera::__vt": 0x803e1c64,
		"JDrama::TSmplChara::__vt": 0x803e1d28,
		"JDrama::TDirector::__vt": 0x803e1d50,
		"JDrama::TDisplay::__vt": 0x803e1dc0,
		"JDrama::TDrawBufObj::__vt": 0x803e1dd0,
		"JDrama::TDStageDisp::__vt": 0x803e1df8,
		"JDrama::TDStageGroup::__vt": 0x803e1e20,
		"JDrama::TEfbCtrlTex::__vt": 0x803e1e50,
		"JDrama::TEfbCtrlDisp::__vt": 0x803e1e74,
		"JDrama::TEfbCtrl::__vt": 0x803e1e98,
		"JDrama::TFrmGXSet::__vt": 0x803e1ec0,
		"JDrama::TLightMap::__vt": 0x803e1ee8,
		"JDrama::TAmbAry::__vt": 0x803e1f0c,
		"JDrama::TAmbColor::__vt": 0x803e1f30,
		"JDrama::TIdxLight::__vt": 0x803e1f94,
		"JDrama::TLightAry::__vt": 0x803e2030,
		"JDrama::TLight::__vt": 0x803e2054,
		"JDrama::TNameRef::__vt": 0x803e20f0,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::__vt": 0x803e2110,
		"JDrama::TNameRefGen::__vt": 0x803e2130,
		"JDrama::TPlacement::__vt": 0x803e2140,
		"JDrama::TScreen::__vt": 0x803e2168,
		"TCamConnecter::__vt": 0x803e218c,
		"JDrama::TSmJ3DAct::__vt": 0x803e21b0,
		"JDrama::TSmJ3DScn::__vt": 0x803e2250,
		"JDrama::TViewConnecter::__vt": 0x803e2280,
		"JDrama::TViewport::__vt": 0x803e22a8,
		"JALSeModData<JALSeModVolFunk>::__vt": 0x803e22d0,
		"JALSeModData<JALSeModPitFunk>::__vt": 0x803e22e0,
		"JALSeModData<JALSeModEffFunk>::__vt": 0x803e22f0,
		"JALSeModData<JALSeModVolDist>::__vt": 0x803e2300,
		"JALSeModData<JALSeModEffDist>::__vt": 0x803e2310,
		"JALSeModData<JALSeModPitDist>::__vt": 0x803e2320,
		"JALSeModData<JALSeModVolFGrp>::__vt": 0x803e2330,
		"JALSeModData<JALSeModPitFGrp>::__vt": 0x803e2340,
		"JALSeModData<JALSeModEffFGrp>::__vt": 0x803e2350,
		"JALSeModData<JALSeModVolDGrp>::__vt": 0x803e2360,
		"JALSeModData<JALSeModEffDGrp>::__vt": 0x803e2370,
		"JALSeModData<JALSeModPitDGrp>::__vt": 0x803e2380,
		"JALSeModPitDGrp::__vt": 0x803e2390,
		"JALSeModDataGrp<JALSeModPitDGrp>::__vt": 0x803e23a0,
		"JALSeModEffDGrp::__vt": 0x803e23b0,
		"JALSeModDataGrp<JALSeModEffDGrp>::__vt": 0x803e23c0,
		"JALSeModVolDGrp::__vt": 0x803e23d0,
		"JALSeModDataGrp<JALSeModVolDGrp>::__vt": 0x803e23e0,
		"JALSeModEffFGrp::__vt": 0x803e23f0,
		"JALSeModDataGrp<JALSeModEffFGrp>::__vt": 0x803e2400,
		"JALSeModPitFGrp::__vt": 0x803e2410,
		"JALSeModDataGrp<JALSeModPitFGrp>::__vt": 0x803e2420,
		"JALSeModVolFGrp::__vt": 0x803e2430,
		"JALSeModDataGrp<JALSeModVolFGrp>::__vt": 0x803e2440,
		"JALSeModPitDist::__vt": 0x803e2450,
		"JALSeModEffDist::__vt": 0x803e2460,
		"JALSeModVolDist::__vt": 0x803e2470,
		"JALSeModEffFunk::__vt": 0x803e2480,
		"JALSeModPitFunk::__vt": 0x803e2490,
		"JALSeModVolFunk::__vt": 0x803e24a0,
		"JAIAnimeSound::__vt": 0x803e24b0,
		"JSystem::@547": 0x803e24c0,
		"@547": 0x803e24c0,
		"JAIBasic::__vt": 0x803e24e4,
		"JAIConst::dummyZeroVec": 0x803e2520,
		"dummyZeroVec": 0x803e2520,
		"JAIConst::nullInfoData2": 0x803e252c,
		"nullInfoData2": 0x803e252c,
		"JAIConst::sCInfos_0": 0x803e254c,
		"sCInfos_0": 0x803e254c,
		"JAInter::StreamLib::filter_table": 0x803e2570,
		"filter_table": 0x803e2570,
		"JAInter::StreamLib::table4": 0x803e25b0,
		"table4": 0x803e25b0,
		"JAISound::__vt": 0x803e25d0,
		"JASystem::BankMgr::OSC_RELEASE_TABLE": 0x803e2608,
		"OSC_RELEASE_TABLE": 0x803e2608,
		"JASystem::BankMgr::OSC_ENV": 0x803e2614,
		"OSC_ENV": 0x803e2614,
		"JASystem::TBasicBank::__vt": 0x803e2630,
		"JASystem::TBank::__vt": 0x803e2644,
		"JASystem::TBasicInst::__vt": 0x803e2658,
		"JASystem::TInst::__vt": 0x803e2670,
		"JASystem::TWaveHandle::__vt": 0x803e2688,
		"JASystem::TBasicWaveBank::TWaveHandle::__vt": 0x803e269c,
		"JASystem::TBasicWaveBank::TWaveGroup::__vt": 0x803e26b0,
		"JASystem::WaveArcLoader::TObject::__vt": 0x803e26c4,
		"JASystem::TBasicWaveBank::__vt": 0x803e26d8,
		"JASystem::TWaveBank::__vt": 0x803e26ec,
		"JASystem::TInstEffect::__vt": 0x803e2700,
		"JASystem::TDrumSet::__vt": 0x803e2710,
		"JASystem::TInstRand::__vt": 0x803e2728,
		"JASystem::TInstSense::__vt": 0x803e2738,
		"JASystem::TSimpleWaveBank::TWaveHandle::__vt": 0x803e2748,
		"JASystem::TSimpleWaveBank::__vt": 0x803e275c,
		"JASystem::WaveArcLoader::sCurrentDir": 0x803e2790,
		"sCurrentDir": 0x803e2790,
		"JASystem::Driver::calc_sw_table": 0x803e27d0,
		"calc_sw_table": 0x803e27d0,
		"JSystem::@325": 0x803e2844,
		"@325": 0x803e2844,
		"JASystem::Driver::C5BASE_PITCHTABLE": 0x803e2880,
		"C5BASE_PITCHTABLE": 0x803e2880,
		"JASystem::history": 0x803e2fc0,
		"history": 0x803e2fc0,
		"JASystem::DSPInterface::SEND_TABLE": 0x803e2fe8,
		"SEND_TABLE": 0x803e2fe8,
		"JSystem::connect_table$341": 0x803e3000,
		"connect_table$341": 0x803e3000,
		"JASystem::Driver::FORCE_STOP_TABLE": 0x803e3018,
		"FORCE_STOP_TABLE": 0x803e3018,
		"JASystem::Dvd::audioRootPath": 0x803e3028,
		"audioRootPath": 0x803e3028,
		"JASystem::HardStream::rootDir": 0x803e3048,
		"rootDir": 0x803e3048,
		"JSystem::@550": 0x803e3068,
		"@550": 0x803e3068,
		"JASystem::Player::CUTOFF_TO_IIR_TABLE": 0x803e3088,
		"CUTOFF_TO_IIR_TABLE": 0x803e3088,
		"JASystem::Player::s_key_table": 0x803e3488,
		"s_key_table": 0x803e3488,
		"JASystem::Player::sAdsrDef": 0x803e3588,
		"sAdsrDef": 0x803e3588,
		"JASystem::Player::sEnvelopeDef": 0x803e35a0,
		"sEnvelopeDef": 0x803e35a0,
		"JASystem::Player::sVibratoDef": 0x803e35b8,
		"sVibratoDef": 0x803e35b8,
		"JASystem::Player::sTremoroDef": 0x803e35d0,
		"sTremoroDef": 0x803e35d0,
		"JASystem::Player::sAdsTable": 0x803e35e8,
		"sAdsTable": 0x803e35e8,
		"JASystem::Player::sRelTable": 0x803e3600,
		"sRelTable": 0x803e3600,
		"JASystem::Player::sVibTable": 0x803e360c,
		"sVibTable": 0x803e360c,
		"JASystem::Player::sTreTable": 0x803e3630,
		"sTreTable": 0x803e3630,
		"JASystem::TTrack::sOscTable": 0x803e3658,
		"sOscTable": 0x803e3658,
		"JSystem::@982": 0x803e3660,
		"@982": 0x803e3660,
		"JSystem::@1324": 0x803e36d8,
		"@1324": 0x803e36d8,
		"JSystem::@139": 0x803e3738,
		"@139": 0x803e3738,
		"JSystem::@140": 0x803e3744,
		"@140": 0x803e3744,
		"JSystem::@141": 0x803e3750,
		"@141": 0x803e3750,
		"JSystem::@142": 0x803e375c,
		"@142": 0x803e375c,
		"JSystem::@143": 0x803e3768,
		"@143": 0x803e3768,
		"JSystem::@146": 0x803e378c,
		"@146": 0x803e378c,
		"JSystem::@147": 0x803e3798,
		"@147": 0x803e3798,
		"JSystem::@152": 0x803e37d4,
		"JSystem::@153": 0x803e37e0,
		"JSystem::@154": 0x803e37ec,
		"@154": 0x803e37ec,
		"JSystem::@155": 0x803e37f8,
		"@155": 0x803e37f8,
		"JSystem::@156": 0x803e3804,
		"JSystem::@157": 0x803e3810,
		"JSystem::@158": 0x803e381c,
		"JSystem::@159": 0x803e3828,
		"JSystem::@161": 0x803e3840,
		"@161": 0x803e3840,
		"JSystem::@162": 0x803e384c,
		"@162": 0x803e384c,
		"JSystem::@163": 0x803e3858,
		"@163": 0x803e3858,
		"JSystem::@168": 0x803e3894,
		"JSystem::@169": 0x803e38a0,
		"JSystem::@170": 0x803e38ac,
		"JSystem::@171": 0x803e38b8,
		"@171": 0x803e38b8,
		"JSystem::@172": 0x803e38c4,
		"@172": 0x803e38c4,
		"JSystem::@173": 0x803e38d0,
		"@173": 0x803e38d0,
		"JSystem::@174": 0x803e38dc,
		"JSystem::@175": 0x803e38e8,
		"JSystem::@176": 0x803e38f4,
		"@176": 0x803e38f4,
		"JSystem::@180": 0x803e3924,
		"@180": 0x803e3924,
		"JSystem::@181": 0x803e3930,
		"@181": 0x803e3930,
		"JSystem::@182": 0x803e393c,
		"JSystem::@183": 0x803e3948,
		"JSystem::@184": 0x803e3954,
		"@184": 0x803e3954,
		"JSystem::@185": 0x803e3960,
		"@185": 0x803e3960,
		"JASystem::TSeqParser::sCmdPList": 0x803e399c,
		"sCmdPList": 0x803e399c,
		"J3DMaterialTable::__vt": 0x803e3ca0,
		"JSystem::@2833": 0x803e3cb0,
		"JSystem::@3104": 0x803e3ccc,
		"JSystem::@2535": 0x803e3cf8,
		"JPADragField::__vt": 0x803e3d18,
		"JPARandomField::__vt": 0x803e3d30,
		"JPAConvectionField::__vt": 0x803e3d48,
		"JPAVortexField::__vt": 0x803e3d60,
		"JPANewtonField::__vt": 0x803e3d78,
		"JPAMagnetField::__vt": 0x803e3d90,
		"JPAAirField::__vt": 0x803e3da8,
		"JPAGravityField::__vt": 0x803e3dc0,
		"JPABaseField::__vt": 0x803e3dd8,
		"JPAParticle::__vt": 0x803e3df0,
		"JPABaseParticle::__vt": 0x803e3e48,
		"JSystem::@2383": 0x803e3ea0,
		"JSystem::@2382": 0x803e3ecc,
		"JPADrawCalcEmitterVisitor::__vt": 0x803e3ef8,
		"JPADrawCalcParticleVisitor::__vt": 0x803e3f08,
		"JPADrawExecParticleVisitor::__vt": 0x803e3f18,
		"JPADrawExecEmitterVisitor::__vt": 0x803e3f28,
		"JPADrawCalcChildScaleOut::__vt": 0x803e3f38,
		"JPADrawCalcChildAlphaOut::__vt": 0x803e3f48,
		"JPADrawCalcAlphaFlickMultSin::__vt": 0x803e3f58,
		"JPADrawCalcAlphaFlickAddSin::__vt": 0x803e3f68,
		"JPADrawCalcAlphaFlickNrmSin::__vt": 0x803e3f78,
		"JPADrawCalcAlpha::__vt": 0x803e3f88,
		"JPADrawCalcColorCopyFromEmitter::__vt": 0x803e3f98,
		"JPADrawCalcScaleAnmTimingReverseY::__vt": 0x803e3fa8,
		"JPADrawCalcScaleAnmTimingReverseX::__vt": 0x803e3fb8,
		"JPADrawCalcScaleAnmTimingRepeatY::__vt": 0x803e3fc8,
		"JPADrawCalcScaleAnmTimingRepeatX::__vt": 0x803e3fd8,
		"JPADrawCalcScaleAnmTimingNormal::__vt": 0x803e3fe8,
		"JPADrawCalcScaleCopyX2Y::__vt": 0x803e3ff8,
		"JPADrawCalcScaleYBySpeed::__vt": 0x803e4008,
		"JPADrawCalcScaleXBySpeed::__vt": 0x803e4018,
		"JPADrawCalcScaleY::__vt": 0x803e4028,
		"JPADrawCalcScaleX::__vt": 0x803e4038,
		"JPADrawExecCallBack::__vt": 0x803e4048,
		"JPADrawCalcTextureAnmIndexRandom::__vt": 0x803e406c,
		"JPADrawCalcTextureAnmIndexMerge::__vt": 0x803e4090,
		"JPADrawCalcTextureAnmIndexReverse::__vt": 0x803e40b4,
		"JPADrawCalcTextureAnmIndexRepeat::__vt": 0x803e40d8,
		"JPADrawCalcTextureAnmIndexNormal::__vt": 0x803e40fc,
		"JPADrawCalcColorAnmFrameRandom::__vt": 0x803e4120,
		"JPADrawCalcColorAnmFrameMerge::__vt": 0x803e4144,
		"JPADrawCalcColorAnmFrameReverse::__vt": 0x803e4168,
		"JPADrawCalcColorAnmFrameRepeat::__vt": 0x803e418c,
		"JPADrawCalcColorAnmFrameNormal::__vt": 0x803e41b0,
		"JPADrawCalcColorEnv::__vt": 0x803e41d4,
		"JPADrawCalcColorPrm::__vt": 0x803e41f8,
		"JPADrawExecRegisterColorChildPE::__vt": 0x803e421c,
		"JPADrawExecRegisterColorEmitterE::__vt": 0x803e422c,
		"JPADrawExecRegisterColorEmitterP::__vt": 0x803e423c,
		"JPADrawExecRegisterColorEmitterPE::__vt": 0x803e424c,
		"JPADrawExecStripeCross::__vt": 0x803e425c,
		"JPADrawExecStripe::__vt": 0x803e426c,
		"JPADrawExecLine::__vt": 0x803e427c,
		"JPADrawExecPoint::__vt": 0x803e428c,
		"JPADrawExecRotationCross::__vt": 0x803e429c,
		"JPADrawExecRotation::__vt": 0x803e42ac,
		"JPADrawExecDirBillBoard::__vt": 0x803e42bc,
		"JPADrawExecRotDirectionalCross::__vt": 0x803e42cc,
		"JPADrawExecDirectionalCross::__vt": 0x803e42dc,
		"JPADrawExecRotDirectional::__vt": 0x803e42ec,
		"JPADrawExecDirectional::__vt": 0x803e42fc,
		"JPADrawExecRotYBillBoard::__vt": 0x803e430c,
		"JPADrawExecYBillBoard::__vt": 0x803e431c,
		"JPADrawExecRotBillBoard::__vt": 0x803e432c,
		"JPADrawExecBillBoard::__vt": 0x803e433c,
		"JPADrawExecRegisterPrmAEnv::__vt": 0x803e434c,
		"JPADrawExecRegisterPrmCEnv::__vt": 0x803e435c,
		"JPADrawExecRegisterEnvColorAnm::__vt": 0x803e436c,
		"JPADrawExecRegisterPrmAlphaAnm::__vt": 0x803e437c,
		"JPADrawExecRegisterPrmColorAnm::__vt": 0x803e438c,
		"JPADrawExecSetLineWidth::__vt": 0x803e439c,
		"JPADrawExecSetPointSize::__vt": 0x803e43ac,
		"JPADrawExecLoadTexture::__vt": 0x803e43bc,
		"JPADrawExecLoadDefaultTexture::__vt": 0x803e43e0,
		"JPADrawExecSetTexMtx::__vt": 0x803e43f0,
		"JPADrawExecGenIdtMtx::__vt": 0x803e4414,
		"JPADrawExecGenTexMtx0::__vt": 0x803e4424,
		"JPADrawExecGenPrjTexMtx::__vt": 0x803e4434,
		"JPADrawExecGenPrjMtx::__vt": 0x803e4444,
		"JPADrawExecLoadExTex::__vt": 0x803e4454,
		"JPAExTexShape::__vt": 0x803e4468,
		"JPADataBlock::__vt": 0x803e4474,
		"JPAKeyFrameAnime::__vt": 0x803e4480,
		"JPAEmitterLoader::__vt": 0x803e448c,
		"JPAEmitterLoader_v10::__vt": 0x803e4498,
		"JPABaseShape::stBlendMode": 0x803e44a8,
		"stBlendMode": 0x803e44a8,
		"JPABaseShape::stBlendFactor": 0x803e44b8,
		"stBlendFactor": 0x803e44b8,
		"JPABaseShape::stLogicOp": 0x803e44e0,
		"stLogicOp": 0x803e44e0,
		"JPABaseShape::stCompare": 0x803e4520,
		"stCompare": 0x803e4520,
		"JPABaseShape::stAlphaOp": 0x803e4540,
		"stAlphaOp": 0x803e4540,
		"JPABaseShape::__vt": 0x803e4550,
		"JPAExtraShape::__vt": 0x803e4560,
		"JPASweepShape::__vt": 0x803e4570,
		"JPATexture::__vt": 0x803e4580,
		"JStage::TAmbientLight::__vt": 0x803e4590,
		"JStage::TCamera::__vt": 0x803e45c8,
		"JStage::TActor::__vt": 0x803e4650,
		"JStage::TLight::__vt": 0x803e46b8,
		"JStage::TObject::__vt": 0x803e4718,
		"JStage::TSystem::__vt": 0x803e4748,
		"MSL_C.PPCEABI.bare.H::__files": 0x803e6480,
		"__files": 0x803e6480,
		"MSL_C.PPCEABI.bare.H::@1009": 0x803e6558,
		"@1009": 0x803e6558,
		"MSL_C.PPCEABI.bare.H::@1066": 0x803e65dc,
		"@1066": 0x803e65dc,
		"MSL_C.PPCEABI.bare.H::@1186": 0x803e6660,
		"@1186": 0x803e6660,
		"MSL_C.PPCEABI.bare.H::@1185": 0x803e6730,
		"@1185": 0x803e6730,
		"MSL_C.PPCEABI.bare.H::@410": 0x803e6778,
		"@410": 0x803e6778,
		"MSL_C.PPCEABI.bare.H::__float_nan": 0x803e67c0,
		"__float_nan": 0x803e67c0,
		"MSL_C.PPCEABI.bare.H::__float_huge": 0x803e67c4,
		"__float_huge": 0x803e67c4,
		"MSL_C.PPCEABI.bare.H::__four_over_pi_m1": 0x803e67c8,
		"__four_over_pi_m1": 0x803e67c8,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTable": 0x803e67d8,
		"gTRKDispatchTable": 0x803e67d8,
		"TRK_MINNOW_DOLPHIN::@175": 0x803e6860,
		"TRK_MINNOW_DOLPHIN::@214": 0x803e687c,
		"TRK_MINNOW_DOLPHIN::gTRKRestoreFlags": 0x803e6898,
		"gTRKRestoreFlags": 0x803e6898,
		"TRK_MINNOW_DOLPHIN::gTRKExceptionStatus": 0x803e68a4,
		"gTRKExceptionStatus": 0x803e68a4,
		"TRK_MINNOW_DOLPHIN::gTRKStepStatus": 0x803e68b4,
		"gTRKStepStatus": 0x803e68b4,
		"TRK_MINNOW_DOLPHIN::TRK_ISR_OFFSETS": 0x803e68c8,
		"TRK_ISR_OFFSETS": 0x803e68c8,
		"TRK_MINNOW_DOLPHIN::gDBCommTable": 0x803e6908,
		"gDBCommTable": 0x803e6908,
		"db::@7": 0x803e6928,
		"@7": 0x803e6928,
		"os::@84": 0x803e6940,
		"os::@85": 0x803e6960,
		"@85": 0x803e6960,
		"os::@86": 0x803e6978,
		"@86": 0x803e6978,
		"os::@87": 0x803e6984,
		"@87": 0x803e6984,
		"os::@88": 0x803e6990,
		"@88": 0x803e6990,
		"os::@89": 0x803e69a0,
		"@89": 0x803e69a0,
		"os::__OSExceptionLocations": 0x803e6a28,
		"__OSExceptionLocations": 0x803e6a28,
		"os::@130": 0x803e6a64,
		"os::@131": 0x803e6a80,
		"@131": 0x803e6a80,
		"os::@132": 0x803e6ab0,
		"@132": 0x803e6ab0,
		"os::@133": 0x803e6ae0,
		"os::@352": 0x803e6b00,
		"@352": 0x803e6b00,
		"os::@353": 0x803e6b24,
		"@353": 0x803e6b24,
		"os::@354": 0x803e6b5c,
		"os::@355": 0x803e6b84,
		"os::@356": 0x803e6bd4,
		"@356": 0x803e6bd4,
		"os::@357": 0x803e6c14,
		"os::@358": 0x803e6c4c,
		"os::@359": 0x803e6c98,
		"@359": 0x803e6c98,
		"os::@360": 0x803e6ccc,
		"os::@361": 0x803e6d0c,
		"@361": 0x803e6d0c,
		"os::@362": 0x803e6d48,
		"@362": 0x803e6d48,
		"os::@363": 0x803e6d90,
		"os::@364": 0x803e6df0,
		"os::@383": 0x803e6e1c,
		"@383": 0x803e6e1c,
		"os::@384": 0x803e6e30,
		"@384": 0x803e6e30,
		"os::@385": 0x803e6e44,
		"os::@386": 0x803e6e60,
		"os::@387": 0x803e6e74,
		"@387": 0x803e6e74,
		"os::@388": 0x803e6e84,
		"os::DSPInitCode": 0x803e6e98,
		"DSPInitCode": 0x803e6e98,
		"os::@97": 0x803e7088,
		"os::@98": 0x803e70a8,
		"os::@110": 0x803e70c4,
		"os::@111": 0x803e70e0,
		"os::@112": 0x803e70fc,
		"@112": 0x803e70fc,
		"os::@113": 0x803e7114,
		"@113": 0x803e7114,
		"os::@59": 0x803e7148,
		"@59": 0x803e7148,
		"os::@60": 0x803e718c,
		"os::@61": 0x803e71bc,
		"os::@62": 0x803e71ec,
		"@62": 0x803e71ec,
		"os::@63": 0x803e721c,
		"os::@64": 0x803e7230,
		"os::@65": 0x803e7254,
		"@65": 0x803e7254,
		"os::@66": 0x803e7268,
		"os::@67": 0x803e7284,
		"@67": 0x803e7284,
		"os::@68": 0x803e7298,
		"@68": 0x803e7298,
		"os::@70": 0x803e72e0,
		"@70": 0x803e72e0,
		"os::@74": 0x803e72fc,
		"@74": 0x803e72fc,
		"os::@10": 0x803e7320,
		"@10": 0x803e7320,
		"os::@11": 0x803e7338,
		"@11": 0x803e7338,
		"os::@12": 0x803e7360,
		"@12": 0x803e7360,
		"os::@30": 0x803e737c,
		"os::@31": 0x803e739c,
		"os::@33": 0x803e73b4,
		"os::@34": 0x803e73e8,
		"os::@35": 0x803e73f8,
		"os::@36": 0x803e7458,
		"os::@37": 0x803e74a4,
		"os::@38": 0x803e7508,
		"os::@39": 0x803e7568,
		"os::@40": 0x803e7588,
		"os::@41": 0x803e75a8,
		"os::@42": 0x803e75c4,
		"os::@43": 0x803e75fc,
		"@43": 0x803e75fc,
		"os::HankakuToCode": 0x803e7640,
		"HankakuToCode": 0x803e7640,
		"os::Zenkaku2Code": 0x803e77c0,
		"Zenkaku2Code": 0x803e77c0,
		"os::InterruptPrioTable": 0x803e8150,
		"InterruptPrioTable": 0x803e8150,
		"os::ResetFunctionInfo": 0x803e8180,
		"os::YearDays": 0x803e8190,
		"YearDays": 0x803e8190,
		"os::LeapYearDays": 0x803e81c0,
		"LeapYearDays": 0x803e81c0,
		"dvd::@117": 0x803e81f0,
		"dvd::@138": 0x803e82b8,
		"dvd::@237": 0x803e82f0,
		"dvd::@263": 0x803e8324,
		"@263": 0x803e8324,
		"dvd::@269": 0x803e8354,
		"dvd::@309": 0x803e837c,
		"dvd::@340": 0x803e83b8,
		"dvd::@341": 0x803e8420,
		"dvd::@342": 0x803e8478,
		"@342": 0x803e8478,
		"dvd::@373": 0x803e84d4,
		"@373": 0x803e84d4,
		"dvd::@374": 0x803e8538,
		"@374": 0x803e8538,
		"dvd::@375": 0x803e8588,
		"@375": 0x803e8588,
		"dvd::@13": 0x803e85e0,
		"@13": 0x803e85e0,
		"dvd::@14": 0x803e85f8,
		"dvd::@15": 0x803e8604,
		"dvd::@16": 0x803e8620,
		"dvd::@293": 0x803e862c,
		"dvd::@331": 0x803e864c,
		"@331": 0x803e864c,
		"dvd::@835": 0x803e868c,
		"@835": 0x803e868c,
		"dvd::@936": 0x803e86c0,
		"@936": 0x803e86c0,
		"dvd::ErrorTable": 0x803e86f8,
		"ErrorTable": 0x803e86f8,
		"dvd::@36": 0x803e8740,
		"dvd::@37": 0x803e875c,
		"dvd::@38": 0x803e8774,
		"dvd::@39": 0x803e8788,
		"dvd::@42": 0x803e879c,
		"vi::timing": 0x803e87b0,
		"timing": 0x803e87b0,
		"vi::taps": 0x803e88e0,
		"taps": 0x803e88e0,
		"vi::@92": 0x803e8914,
		"vi::@336": 0x803e896c,
		"@336": 0x803e896c,
		"vi::@337": 0x803e8998,
		"@337": 0x803e8998,
		"vi::@338": 0x803e89c4,
		"@338": 0x803e89c4,
		"vi::@339": 0x803e89f0,
		"vi::@340": 0x803e8a1c,
		"vi::@341": 0x803e8a48,
		"pad::ResetFunctionInfo": 0x803e8a78,
		"dsp::@16": 0x803e8a88,
		"dsp::@17": 0x803e8aa8,
		"dsp::@18": 0x803e8ab4,
		"dsp::@264": 0x803e8ac0,
		"@264": 0x803e8ac0,
		"dsp::@265": 0x803e8ae0,
		"@265": 0x803e8ae0,
		"dsp::@266": 0x803e8b10,
		"@266": 0x803e8b10,
		"dsp::@267": 0x803e8b40,
		"@267": 0x803e8b40,
		"dsp::@268": 0x803e8b70,
		"@268": 0x803e8b70,
		"dsp::@269": 0x803e8ba0,
		"dsp::@292": 0x803e8bd0,
		"card::ResetFunctionInfo": 0x803e8c00,
		"card::SectorSizeTable": 0x803e8d80,
		"SectorSizeTable": 0x803e8d80,
		"card::LatencyTable": 0x803e8da0,
		"LatencyTable": 0x803e8da0,
		"gx::@189": 0x803e8e28,
		"gx::@256": 0x803e8e90,
		"gx::@302": 0x803e8ef8,
		"gx::@329": 0x803e8f3c,
		"gx::@393": 0x803e8f80,
		"@393": 0x803e8f80,
		"gx::@499": 0x803e8fc4,
		"@499": 0x803e8fc4,
		"gx::@498": 0x803e8fe0,
		"@498": 0x803e8fe0,
		"gx::GXNtsc480IntDf": 0x803e9038,
		"GXNtsc480IntDf": 0x803e9038,
		"gx::GXNtsc480Int": 0x803e9074,
		"GXNtsc480Int": 0x803e9074,
		"gx::GXMpal480IntDf": 0x803e90b0,
		"GXMpal480IntDf": 0x803e90b0,
		"gx::GXPal528IntDf": 0x803e90ec,
		"GXPal528IntDf": 0x803e90ec,
		"gx::GXEurgb60Hz480IntDf": 0x803e9128,
		"GXEurgb60Hz480IntDf": 0x803e9128,
		"gx::@92": 0x803e9168,
		"gx::@168": 0x803e9350,
		"gx::c2r$71": 0x803e9390,
		"c2r$71": 0x803e9390,
		"gx::p2f$194": 0x803e93b8,
		"p2f$194": 0x803e93b8,
		"gx::@242": 0x803e93d8,
		"@242": 0x803e93d8,
		"gx::@241": 0x803e9434,
		"gd::@121": 0x803e94c8,
		"gd::@207": 0x803e9530,
		"@207": 0x803e9530,
		"gd::c2r$382": 0x803e9578,
		"c2r$382": 0x803e9578,
		"si::Si": 0x803e9588,
		"Si": 0x803e9588,
		"si::Type": 0x803e959c,
		"si::@456": 0x803e95ac,
		"@456": 0x803e95ac,
		"si::@458": 0x803e95b8,
		"@458": 0x803e95b8,
		"si::@459": 0x803e95c8,
		"@459": 0x803e95c8,
		"si::@460": 0x803e95d8,
		"@460": 0x803e95d8,
		"si::@461": 0x803e95e8,
		"si::@462": 0x803e95f4,
		"@462": 0x803e95f4,
		"si::@463": 0x803e9604,
		"si::@464": 0x803e9618,
		"@464": 0x803e9618,
		"si::@465": 0x803e962c,
		"@465": 0x803e962c,
		"si::@466": 0x803e9640,
		"@466": 0x803e9640,
		"si::@467": 0x803e964c,
		"@467": 0x803e964c,
		"si::XYNTSC": 0x803e9658,
		"XYNTSC": 0x803e9658,
		"si::XYPAL": 0x803e9688,
		"XYPAL": 0x803e9688,
		"si::@16": 0x803e96b8,
		"THPPlayer::VolumeTable": 0x803acaf8,
		"VolumeTable": 0x803acaf8,
		"TDLColorTexQuad::__vt": 0x803da5f8,
		"TDLTexQuad::__vt": 0x803da618,
		"TSilhouette::__vt": 0x803da638,
		"TLightWithDBSetManager::__vt": 0x803da660,
		"TIndirectLightWithDBSet::__vt": 0x803da684,
		"TMapObjectLightWithDBSet::__vt": 0x803da6ac,
		"TObjectLightWithDBSet::__vt": 0x803da6d4,
		"TPlayerLightWithDBSet::__vt": 0x803da6fc,
		"TLightWithDBSet::__vt": 0x803da724,
		"TLightDrawBuffer::__vt": 0x803da74c,
		"TLightMario::__vt": 0x803da774,
		"TLightShadow::__vt": 0x803da7a8,
		"TLightCommon::__vt": 0x803da7dc,
		"MarioUtil::@1431": 0x803da810,
		"MarioUtil::@1210": 0x803da828,
		"MarioUtil::atntable": 0x803da838,
		"atntable": 0x803da838,
		"TParamT<JGeometry::TVec3<float><float>>::__vt": 0x803db040,
		"TMtxSwingRZReverseXZ::__vt": 0x803db04c,
		"TParamVec::__vt": 0x803db058,
		"TMtxSwingRZ::__vt": 0x803db064,
		"TMtxTimeLag::__vt": 0x803db070,
		"TMtxEffectBase::__vt": 0x803db07c,
		"TScreenTexture::__vt": 0x803db088,
		"TAfterEffect::__vt": 0x803db0ac,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::vl$localstatic0$makeDL": 0x803db0dc,
		"vl$localstatic0$makeDL": 0x803db0dc,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::fl$localstatic1$makeDL": 0x803db0ec,
		"fl$localstatic1$makeDL": 0x803db0ec,
		"TMBindShadowManager::__vt": 0x803db10c,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::__vt": 0x803db184,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::__vt": 0x803db194,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::__vt": 0x803db1a4,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::__vt": 0x803db1b4,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::__vt": 0x803db1c4,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::__vt": 0x803db1d4,
		"MarioUtil::IdentityMtx": 0x803db210,
		"IdentityMtx": 0x803db210,
		"MarioUtil::rumbleFrame_00": 0x803db240,
		"rumbleFrame_00": 0x803db240,
		"MarioUtil::rumblePower_00": 0x803db26c,
		"rumblePower_00": 0x803db26c,
		"MarioUtil::rumbleFrame_01": 0x803db298,
		"rumbleFrame_01": 0x803db298,
		"MarioUtil::rumblePower_01": 0x803db2f8,
		"rumblePower_01": 0x803db2f8,
		"MarioUtil::rumbleFrame_04": 0x803db358,
		"rumbleFrame_04": 0x803db358,
		"MarioUtil::rumblePower_04": 0x803db374,
		"rumblePower_04": 0x803db374,
		"MarioUtil::rumbleFrame_05": 0x803db390,
		"rumbleFrame_05": 0x803db390,
		"MarioUtil::rumblePower_05": 0x803db3e4,
		"rumblePower_05": 0x803db3e4,
		"MarioUtil::rumbleFrame_06": 0x803db438,
		"rumbleFrame_06": 0x803db438,
		"MarioUtil::rumblePower_06": 0x803db460,
		"rumblePower_06": 0x803db460,
		"MarioUtil::rumbleFrame_07": 0x803db488,
		"rumbleFrame_07": 0x803db488,
		"MarioUtil::rumblePower_07": 0x803db4d8,
		"rumblePower_07": 0x803db4d8,
		"MarioUtil::rumbleFrame_08": 0x803db528,
		"rumbleFrame_08": 0x803db528,
		"MarioUtil::rumblePower_08": 0x803db53c,
		"rumblePower_08": 0x803db53c,
		"MarioUtil::rumbleFrame_09": 0x803db550,
		"rumbleFrame_09": 0x803db550,
		"MarioUtil::rumblePower_09": 0x803db560,
		"rumblePower_09": 0x803db560,
		"MarioUtil::rumbleFrame_19": 0x803db570,
		"rumbleFrame_19": 0x803db570,
		"MarioUtil::rumblePower_19": 0x803db584,
		"rumblePower_19": 0x803db584,
		"MarioUtil::rumbleFrame_23": 0x803db598,
		"rumbleFrame_23": 0x803db598,
		"MarioUtil::rumblePower_23": 0x803db6cc,
		"rumblePower_23": 0x803db6cc,
		"MarioUtil::rumbleFrame_24": 0x803db800,
		"rumbleFrame_24": 0x803db800,
		"MarioUtil::rumblePower_24": 0x803db894,
		"rumblePower_24": 0x803db894,
		"MarioUtil::channelDataTbl": 0x803db928,
		"channelDataTbl": 0x803db928,
		"MarioUtil::_info": 0x803dba58,
		"_info": 0x803dba58,
		"TGDLStatic::__vt": 0x803dbb40,
		"TGDLStatic::TGDLSentinel::__vt": 0x803dbb50,
		"Koga::ToolData::__vt": 0x803dbb60,
		"M3DUtil::@1411": 0x803dbb70,
		"M3UMtxCalcSIAnmBlendQuat::__vt": 0x803dbb7c,
		"M3UModel::__vt": 0x803dbbc0,
		"M3UModelCommon::__vt": 0x803dbbe4,
		"MActorAnmEach<J3DAnmClusterKey>::__vt": 0x803dbbf0,
		"MActorAnmMatEach<J3DAnmTevRegKey>::__vt": 0x803dbc18,
		"MActorAnmEach<J3DAnmTevRegKey>::__vt": 0x803dbc40,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::__vt": 0x803dbc68,
		"MActorAnmEach<J3DAnmTextureSRTKey>::__vt": 0x803dbc90,
		"MActorAnmMatEach<J3DAnmTexPattern>::__vt": 0x803dbcb8,
		"MActorAnmEach<J3DAnmTexPattern>::__vt": 0x803dbce0,
		"MActorAnmMatEach<J3DAnmColorKey>::__vt": 0x803dbd08,
		"MActorAnmEach<J3DAnmColorKey>::__vt": 0x803dbd30,
		"MActorAnmEach<J3DAnmTransformKey>::__vt": 0x803dbd58,
		"MActorAnmBlk::__vt": 0x803dbd80,
		"MActorAnmBrk::__vt": 0x803dbda8,
		"MActorAnmBpk::__vt": 0x803dbdd0,
		"MActorAnmBtk::__vt": 0x803dbdf8,
		"MActorAnmBtp::__vt": 0x803dbe20,
		"MActorAnmBck::__vt": 0x803dbe48,
		"MActorAnmBase::__vt": 0x803dbe70,
		"SDLModel::__vt": 0x803dbea8,
		"SDLMatPacket::__vt": 0x803dbec8,
		"SampleCtrlJoint::__vt": 0x803dbee0,
		"SampleCtrlMaterial::__vt": 0x803dbeec,
		"SampleCtrlShape::__vt": 0x803dbef8,
		"SampleCtrlModelData::__vt": 0x803dbf08,
		"TBaseParam::__vt": 0x803dec50,
		"TMarioParticleManager::__vt": 0x803dec88,
		"TMarioEmitterCallBackBindToSRTMtxPtr::__vt": 0x803decd0,
		"TMarioEmitterCallBackBindToMtxPtr::__vt": 0x803dece4,
		"TMarioEmitterCallBackBindToPosPtr::__vt": 0x803decf8,
		"TEmitterIndirectViewObj::__vt": 0x803ded0c,
		"TEmitterViewObj::__vt": 0x803ded30,
		"JPACallBackBase<JPABaseEmitter*>::__vt": 0x803ded54,
		"TEventWatcher::__vt": 0x803ded68,
		"TSpcTypedInterp<TEventWatcher>::__vt": 0x803ded90,
		"TSpcTypedBinary<TEventWatcher>::__vt": 0x803deda4,
		"TGCLogoDir::__vt": 0x803dee90,
		"TNintendo2D::__vt": 0x803deefc,
		"TGXAlphaUpdate::__vt": 0x803def20,
		"TReInitGX::__vt": 0x803def44,
		"TSMSDrawInit::__vt": 0x803def68,
		"TJ3DSysSetViewMtx::__vt": 0x803def8c,
		"TJ3DSysFlag::__vt": 0x803defb0,
		"TMarDirector::__vt": 0x803df0c8,
		"TMarNameRefGen::__vt": 0x803df138,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::__vt": 0x803df148,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::__vt": 0x803df168,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::__vt": 0x803df188,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::__vt": 0x803df1a8,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::__vt": 0x803df1c8,
		"TCubeManagerFast::__vt": 0x803df1e8,
		"TCubeManagerArea::__vt": 0x803df20c,
		"TCubeManagerMarioIn::__vt": 0x803df230,
		"TMenuDirector::__vt": 0x803df258,
		"TPerformList::__vt": 0x803df2c8,
		"System::SMSAASamplePattern_non": 0x803df318,
		"SMSAASamplePattern_non": 0x803df318,
		"System::SMSAASamplePattern_aa": 0x803df330,
		"SMSAASamplePattern_aa": 0x803df330,
		"System::SMSVFilter_non": 0x803df348,
		"SMSVFilter_non": 0x803df348,
		"System::SMSVFilter_flicker": 0x803df350,
		"SMSVFilter_flicker": 0x803df350,
		"TSnapTimeObj::__vt": 0x803df358,
		"TTalkCursor::__vt": 0x803df380,
		"TAlphaCatch::__vt": 0x803df3a8,
		"TZBufferCatch::__vt": 0x803df3cc,
		"System::@2633": 0x803df3f0,
		"System::@2929": 0x803df424,
		"TMarioGamePad::__vt": 0x803df44c,
		"TScenarioArchiveName::__vt": 0x803df458,
		"TStageEventInfo::__vt": 0x803df478,
		"System::shineStageTable": 0x803df498,
		"shineStageTable": 0x803df498,
		"System::exShineTable": 0x803df4d8,
		"exShineTable": 0x803df4d8,
		"TStagePositionInfo::__vt": 0x803df4f8,
		"TTimeRec::__vt": 0x803df518,
		"TTHPRender::__vt": 0x803df528,
		"TNameKuriLauncherManager::__vt": 0x803df550,
		"THamuKuriLauncherManager::__vt": 0x803df5a4,
		"TCasinoRoulette::__vt": 0x803df5f8,
		"TSirenaGate::__vt": 0x803df760,
		"TMareWManager::__vt": 0x803df8c8,
		"TMareMManager::__vt": 0x803df920,
		"System::titles": 0x803df9a0,
		"titles": 0x803df9a0,
		"System::comments": 0x803df9b4,
		"comments": 0x803df9b4,
		"System::@1818": 0x803df9c8,
		"TMovieDirector::__vt": 0x803dfa50,
		"System::@3810": 0x803dfae0,
		"System::@3898": 0x803dfb08,
		"System::@3897": 0x803dfb30,
		"MSSTageSimpleEnvironment::__vt": 0x803dfca8,
		"MSStageCubeSwitch::__vt": 0x803dfcbc,
		"MSStageCubeFadeMonte::__vt": 0x803dfcd0,
		"MSStageCubeFade::__vt": 0x803dfcf8,
		"MSStageDistFadeMonte::__vt": 0x803dfd0c,
		"MSStageDistFade::__vt": 0x803dfd20,
		"MSStage::__vt": 0x803dfd34,
		"TTargetArrow::__vt": 0x803dfd48,
		"TLiveActor::__vt": 0x803d9cb8,
		"TLiveManager::__vt": 0x803d9f68,
		"TObjManager::__vt": 0x803d9fa8,
		"TObjChara::__vt": 0x803d9ffc,
		"Strategic::@285": 0x803da020,
		"@285": 0x803da020,
		"Strategic::@286": 0x803da02c,
		"@286": 0x803da02c,
		"Strategic::@287": 0x803da038,
		"@287": 0x803da038,
		"Strategic::@288": 0x803da044,
		"Strategic::@289": 0x803da050,
		"Strategic::@290": 0x803da05c,
		"@290": 0x803da05c,
		"Strategic::@291": 0x803da068,
		"@291": 0x803da068,
		"Strategic::@292": 0x803da074,
		"Strategic::@293": 0x803da080,
		"Strategic::@294": 0x803da08c,
		"Strategic::@295": 0x803da098,
		"Strategic::@296": 0x803da0a4,
		"@296": 0x803da0a4,
		"Strategic::@297": 0x803da0b0,
		"Strategic::@298": 0x803da0bc,
		"@298": 0x803da0bc,
		"Strategic::@299": 0x803da0c8,
		"@299": 0x803da0c8,
		"Strategic::@300": 0x803da0d4,
		"@300": 0x803da0d4,
		"Strategic::@301": 0x803da0e0,
		"Strategic::@302": 0x803da0ec,
		"Strategic::@303": 0x803da0f8,
		"Strategic::@304": 0x803da104,
		"Strategic::@305": 0x803da110,
		"Strategic::@306": 0x803da11c,
		"@306": 0x803da11c,
		"Strategic::@307": 0x803da128,
		"@307": 0x803da128,
		"Strategic::@308": 0x803da134,
		"@308": 0x803da134,
		"Strategic::@309": 0x803da140,
		"Strategic::@310": 0x803da14c,
		"@310": 0x803da14c,
		"Strategic::@311": 0x803da158,
		"@311": 0x803da158,
		"Strategic::@312": 0x803da164,
		"@312": 0x803da164,
		"Strategic::@313": 0x803da170,
		"@313": 0x803da170,
		"Strategic::@314": 0x803da17c,
		"@314": 0x803da17c,
		"Strategic::@315": 0x803da188,
		"@315": 0x803da188,
		"Strategic::@316": 0x803da194,
		"@316": 0x803da194,
		"Strategic::@317": 0x803da1a0,
		"@317": 0x803da1a0,
		"Strategic::@318": 0x803da1ac,
		"@318": 0x803da1ac,
		"Strategic::@319": 0x803da1b8,
		"@319": 0x803da1b8,
		"Strategic::@320": 0x803da1c4,
		"Strategic::@321": 0x803da1d0,
		"Strategic::@322": 0x803da1dc,
		"Strategic::@323": 0x803da1e8,
		"Strategic::@324": 0x803da1f4,
		"Strategic::table$284": 0x803da200,
		"table$284": 0x803da200,
		"TSpcInterp::__vt": 0x803da3e0,
		"TSpcStack<TSpcSlice>::__vt": 0x803da3f4,
		"TSpcStack<unsigned_long><unsigned_long>::__vt": 0x803da400,
		"TSpcBinary::__vt": 0x803da40c,
		"TStrategy::__vt": 0x803da420,
		"TIdxGroupObj::__vt": 0x803da444,
		"TQuestionManager::__vt": 0x803da4a0,
		"TSMSSmplChara::__vt": 0x803da4c8,
		"THitActor::__vt": 0x803da4f0,
		"TBinder::__vt": 0x803da598,
		"TSharedParts::__vt": 0x803da5a8,
		"TMirrorActor::__vt": 0x803da5d0,
		"M3UModelMario::__vt": 0x803dbf18,
		"TMarioCap::__vt": 0x803dbf40,
		"Player::marioAnimeFiles": 0x803dbf88,
		"Player::gMarioAnimeData": 0x803dc5c0,
		"gMarioAnimeData": 0x803dc5c0,
		"Player::marioAnimeTexPatternFilenames": 0x803dd040,
		"marioAnimeTexPatternFilenames": 0x803dd040,
		"Player::cParticleFileNames": 0x803dd290,
		"cParticleFileNames": 0x803dd290,
		"TWarpInCallBack::__vt": 0x803dd29c,
		"TBubbleCallBack::__vt": 0x803dd2d4,
		"TSplashManager::__vt": 0x803dd2e8,
		"TYoshiTongue::__vt": 0x803dd310,
		"Player::nozzleBmdData": 0x803dd3f8,
		"nozzleBmdData": 0x803dd3f8,
		"TWaterGun::__vt": 0x803dd4a0,
		"TNozzleDeform::__vt": 0x803dd4d0,
		"TNozzleTrigger::__vt": 0x803dd4f8,
		"TNozzleBase::__vt": 0x803dd520,
		"TMarioEffect::__vt": 0x803dd590,
		"TMario::__vt": 0x803dd660,
		"Player::gModelWaterManagerWaterColor": 0x803dd898,
		"gModelWaterManagerWaterColor": 0x803dd898,
		"Player::prmNames": 0x803dd8a8,
		"prmNames": 0x803dd8a8,
		"Player::gWaterManagerPlaneInfo": 0x803dd8ec,
		"gWaterManagerPlaneInfo": 0x803dd8ec,
		"TModelWaterManager::__vt": 0x803de9ec,
		"TMarioPositionObj::__vt": 0x803deb38,
		"NPC::@3884": 0x803d82f0,
		"NPC::@3883": 0x803d8344,
		"NPC::@3880": 0x803d8394,
		"NPC::@4719": 0x803d83f0,
		"TBaseNPC::__vt": 0x803d8448,
		"NPC::@3445": 0x803d855c,
		"NPC::@3991": 0x803d85b4,
		"NPC::@3990": 0x803d85dc,
		"NPC::@4128": 0x803d8638,
		"NPC::@4190": 0x803d8694,
		"TSunflowerSManager::__vt": 0x803d86f0,
		"NPC::@2899": 0x803d8748,
		"TMareWBaseManager::__vt": 0x803d8780,
		"TMareMBaseManager::__vt": 0x803d87d8,
		"TMonteWBManager::__vt": 0x803d8830,
		"TMonteWAManager::__vt": 0x803d8888,
		"TMonteWManager::__vt": 0x803d88e0,
		"TMonteMEManager::__vt": 0x803d8938,
		"TMonteMDManager::__vt": 0x803d8990,
		"TMonteMCManager::__vt": 0x803d89e8,
		"TMonteMBManager::__vt": 0x803d8a40,
		"TMonteMAManager::__vt": 0x803d8a98,
		"TMonteMManager::__vt": 0x803d8af0,
		"TSunflowerLManager::__vt": 0x803d8b48,
		"TRaccoonDogManager::__vt": 0x803d8ba0,
		"TPeachManager::__vt": 0x803d8bf8,
		"TKinojiiManager::__vt": 0x803d8c50,
		"TKinopioManager::__vt": 0x803d8ca8,
		"TMareWBManager::__vt": 0x803d8d00,
		"TMareWAManager::__vt": 0x803d8d58,
		"TMareMDManager::__vt": 0x803d8db0,
		"TMareMCManager::__vt": 0x803d8e08,
		"TMareMBManager::__vt": 0x803d8e60,
		"TMareMAManager::__vt": 0x803d8eb8,
		"TMonteWCManager::__vt": 0x803d8f10,
		"TMonteMHManager::__vt": 0x803d8f68,
		"TMonteMGManager::__vt": 0x803d8fc0,
		"TMonteMFManager::__vt": 0x803d9018,
		"TMonteWSpecialManager::__vt": 0x803d9070,
		"TMonteMSpecialManager::__vt": 0x803d90c8,
		"TMonteWBaseManager::__vt": 0x803d9120,
		"TMonteMBaseManager::__vt": 0x803d9178,
		"TMareBaseManager::__vt": 0x803d91d0,
		"TNPCManager::__vt": 0x803d9228,
		"TMareJellyFishManager::__vt": 0x803d9280,
		"TBoardNpcManager::__vt": 0x803d92b0,
		"TNerveNPCMareStand::__vt": 0x803d92f0,
		"TNerveNPCBlown::__vt": 0x803d9300,
		"TNerveNPCMad::__vt": 0x803d9310,
		"TNerveNPCThrow::__vt": 0x803d9320,
		"TNerveNPCTalk::__vt": 0x803d9330,
		"TNerveNPCSetPosAfterSinkBottom::__vt": 0x803d9340,
		"TNerveNPCRecoverAfter::__vt": 0x803d9350,
		"TNerveNPCRecoverFromSink::__vt": 0x803d9360,
		"TNerveNPCSink::__vt": 0x803d9370,
		"TNerveNPCWet::__vt": 0x803d9380,
		"TNerveNPCTurnToMario::__vt": 0x803d9390,
		"TNerveNPCWaitMarioApproach::__vt": 0x803d93a0,
		"TNerveNPCWaitContinue::__vt": 0x803d93b0,
		"TNerveNPCGraphWait::__vt": 0x803d93c0,
		"TNerveNPCUTurn::__vt": 0x803d93d0,
		"TNerveNPCGraphWander::__vt": 0x803d93e0,
		"NPC::sSaveFileName$1960": 0x803d93f0,
		"sSaveFileName$1960": 0x803d93f0,
		"NPC::sMareMB_FishingRodData": 0x803d94a8,
		"sMareMB_FishingRodData": 0x803d94a8,
		"NPC::sMareWB_BabyData": 0x803d94d4,
		"sMareWB_BabyData": 0x803d94d4,
		"NPC::sAllNpcInitData$1622": 0x803d9500,
		"sAllNpcInitData$1622": 0x803d9500,
		"NPC::MtxCalcTypeName": 0x803d95a0,
		"NPC::monteMCommon_bastable": 0x803d95b0,
		"monteMCommon_bastable": 0x803d95b0,
		"NPC::monteMCommon_bas_c_table": 0x803d960c,
		"monteMCommon_bas_c_table": 0x803d960c,
		"NPC::monteME_bastable": 0x803d9668,
		"monteME_bastable": 0x803d9668,
		"NPC::monteME_bas_c_table": 0x803d9684,
		"monteME_bas_c_table": 0x803d9684,
		"NPC::monteMF_bastable": 0x803d96a0,
		"monteMF_bastable": 0x803d96a0,
		"NPC::monteMF_bas_c_table": 0x803d96ac,
		"monteMF_bas_c_table": 0x803d96ac,
		"NPC::monteMH_bastable": 0x803d96b8,
		"monteMH_bastable": 0x803d96b8,
		"NPC::monteMH_bas_c_table": 0x803d96c8,
		"monteMH_bas_c_table": 0x803d96c8,
		"NPC::monteWCommon_bastable": 0x803d96d8,
		"monteWCommon_bastable": 0x803d96d8,
		"NPC::monteWCommon_bas_c_table": 0x803d9738,
		"monteWCommon_bas_c_table": 0x803d9738,
		"NPC::monteWC_bastable": 0x803d9798,
		"monteWC_bastable": 0x803d9798,
		"NPC::monteWC_bas_c_table": 0x803d97ac,
		"monteWC_bas_c_table": 0x803d97ac,
		"NPC::mareM_bastable": 0x803d97c0,
		"mareM_bastable": 0x803d97c0,
		"NPC::mareM_bas_c_table": 0x803d9814,
		"mareM_bas_c_table": 0x803d9814,
		"NPC::mareMA_bastable": 0x803d9868,
		"mareMA_bastable": 0x803d9868,
		"NPC::mareMA_bas_c_table": 0x803d987c,
		"mareMA_bas_c_table": 0x803d987c,
		"NPC::mareMB_bastable": 0x803d9890,
		"mareMB_bastable": 0x803d9890,
		"NPC::mareMB_bas_c_table": 0x803d98a8,
		"mareMB_bas_c_table": 0x803d98a8,
		"NPC::mareMC_bastable": 0x803d98c0,
		"mareMC_bastable": 0x803d98c0,
		"NPC::mareMC_bas_c_table": 0x803d98d4,
		"mareMC_bas_c_table": 0x803d98d4,
		"NPC::mareW_bastable": 0x803d98e8,
		"mareW_bastable": 0x803d98e8,
		"NPC::mareW_bas_c_table": 0x803d9938,
		"mareW_bas_c_table": 0x803d9938,
		"NPC::mareWA_bastable": 0x803d9988,
		"mareWA_bastable": 0x803d9988,
		"NPC::mareWA_bas_c_table": 0x803d9998,
		"mareWA_bas_c_table": 0x803d9998,
		"NPC::mareWB_bastable": 0x803d99a8,
		"mareWB_bastable": 0x803d99a8,
		"NPC::mareWB_bas_c_table": 0x803d99c0,
		"mareWB_bas_c_table": 0x803d99c0,
		"NPC::kinopio_bastable": 0x803d99d8,
		"kinopio_bastable": 0x803d99d8,
		"NPC::kinopio_bas_c_table": 0x803d9a3c,
		"kinopio_bas_c_table": 0x803d9a3c,
		"NPC::kinojii_bastable": 0x803d9aa0,
		"kinojii_bastable": 0x803d9aa0,
		"NPC::kinojii_bas_c_table": 0x803d9ae8,
		"kinojii_bas_c_table": 0x803d9ae8,
		"NPC::peach_bastable": 0x803d9b30,
		"peach_bastable": 0x803d9b30,
		"NPC::peach_bas_c_table": 0x803d9b8c,
		"peach_bas_c_table": 0x803d9b8c,
		"NPC::raccoonDog_bastable": 0x803d9be8,
		"raccoonDog_bastable": 0x803d9be8,
		"NPC::raccoonDog_bas_c_table": 0x803d9bf8,
		"raccoonDog_bas_c_table": 0x803d9bf8,
		"NPC::sunflowerL_bastable": 0x803d9c08,
		"sunflowerL_bastable": 0x803d9c08,
		"NPC::sunflowerL_bas_c_table": 0x803d9c1c,
		"sunflowerL_bas_c_table": 0x803d9c1c,
		"NPC::sunflowerS_bastable": 0x803d9c30,
		"sunflowerS_bastable": 0x803d9c30,
		"NPC::sunflowerS_bas_c_table": 0x803d9c44,
		"sunflowerS_bas_c_table": 0x803d9c44,
		"MAnmSoundNPC::__vt": 0x803ac440,
		"MAnmSound::__vt": 0x803ac460,
		"MSSeCallBack::smTrackCategory": 0x803ac470,
		"smTrackCategory": 0x803ac470,
		"MSSeCallBack::smPolifonic": 0x803ac4b0,
		"smPolifonic": 0x803ac4b0,
		"MSound::__vt": 0x803ac4c0,
		"MSound::@2331": 0x803ac550,
		"MSoundSESystem::MSRandPlay::__vt": 0x803ac610,
		"MSound::@2334": 0x803ac61c,
		"MSSetSoundTL<MSSetSoundGrp>::__vt": 0x803ac6a8,
		"MSSetSoundGrp::__vt": 0x803ac6c0,
		"MSoundSESystem::MSRandVol::__vt": 0x803ac6d8,
		"JALListFrameLoop<MSSetSoundGrp>::__vt": 0x803ac6e4,
		"MSSetSoundTL<MSSetSound>::__vt": 0x803ac6f0,
		"MSSetSound::__vt": 0x803ac708,
		"JALListFrameLoop<MSSetSound>::__vt": 0x803ac720,
		"MSHandle::smACosPrm": 0x803ac758,
		"smACosPrm": 0x803ac758,
		"MSHandle::smSeCategory": 0x803ac8ec,
		"smSeCategory": 0x803ac8ec,
		"MSHandle::__vt": 0x803ac9ec,
		"MSBgmXFade::scTiming": 0x803aca68,
		"scTiming": 0x803aca68,
		"MSBgmXFade::scExp": 0x803acab0,
		"scExp": 0x803acab0,
		"TWoodBarrel::__vt": 0x803c28d8,
		"TMapObjBase::__vt": 0x803c2ab8,
		"TMapObjGeneral::mDefaultSound": 0x803c2c58,
		"mDefaultSound": 0x803c2c58,
		"MoveBG::normal_sound_data": 0x803c2c80,
		"normal_sound_data": 0x803c2c80,
		"MoveBG::end_data": 0x803c2ca8,
		"end_data": 0x803c2ca8,
		"MoveBG::no_data": 0x803c2ce4,
		"no_data": 0x803c2ce4,
		"MoveBG::billboard_dolphin_data": 0x803c2d20,
		"billboard_dolphin_data": 0x803c2d20,
		"MoveBG::billboard_sun_data": 0x803c2d5c,
		"billboard_sun_data": 0x803c2d5c,
		"MoveBG::billboard_restaurant_data": 0x803c2d98,
		"billboard_restaurant_data": 0x803c2d98,
		"MoveBG::billboard_fish_data": 0x803c2dd4,
		"billboard_fish_data": 0x803c2dd4,
		"MoveBG::HideObj_data": 0x803c2e10,
		"HideObj_data": 0x803c2e10,
		"MoveBG::WaterHitHideObj_data": 0x803c2e4c,
		"WaterHitHideObj_data": 0x803c2e4c,
		"MoveBG::FruitHitHideObj_data": 0x803c2e88,
		"FruitHitHideObj_data": 0x803c2e88,
		"MoveBG::HipDropHideObj_data": 0x803c2ec4,
		"HipDropHideObj_data": 0x803c2ec4,
		"MoveBG::MonteChair_data": 0x803c2f00,
		"MonteChair_data": 0x803c2f00,
		"MoveBG::door_data": 0x803c2f3c,
		"door_data": 0x803c2f3c,
		"MoveBG::doorHotel_data": 0x803c2f78,
		"doorHotel_data": 0x803c2f78,
		"MoveBG::manhole_data": 0x803c2fb4,
		"manhole_data": 0x803c2fb4,
		"MoveBG::FruitBasket_data": 0x803c2ff0,
		"FruitBasket_data": 0x803c2ff0,
		"MoveBG::BasketReverse_data": 0x803c302c,
		"BasketReverse_data": 0x803c302c,
		"MoveBG::CoconutJuice_data": 0x803c3068,
		"CoconutJuice_data": 0x803c3068,
		"MoveBG::Pile_data": 0x803c30a4,
		"Pile_data": 0x803c30a4,
		"MoveBG::ChangeStage_data": 0x803c30e0,
		"ChangeStage_data": 0x803c30e0,
		"MoveBG::ChangeStageMerrygoround_data": 0x803c311c,
		"ChangeStageMerrygoround_data": 0x803c311c,
		"MoveBG::StartDemo_data": 0x803c3158,
		"StartDemo_data": 0x803c3158,
		"MoveBG::ChipShine_data": 0x803c3194,
		"ChipShine_data": 0x803c3194,
		"MoveBG::KoopaJrSignM_data": 0x803c31d0,
		"KoopaJrSignM_data": 0x803c31d0,
		"MoveBG::StarSign_data": 0x803c320c,
		"StarSign_data": 0x803c320c,
		"MoveBG::SignCircle_data": 0x803c3248,
		"SignCircle_data": 0x803c3248,
		"MoveBG::SignCross_data": 0x803c3284,
		"SignCross_data": 0x803c3284,
		"MoveBG::SignTriangle_data": 0x803c32c0,
		"SignTriangle_data": 0x803c32c0,
		"MoveBG::ArrowBoardLR_data": 0x803c32fc,
		"ArrowBoardLR_data": 0x803c32fc,
		"MoveBG::ArrowBoardUp_data": 0x803c3338,
		"ArrowBoardUp_data": 0x803c3338,
		"MoveBG::ArrowBoardDown_data": 0x803c3374,
		"ArrowBoardDown_data": 0x803c3374,
		"MoveBG::WaterSprayCylinder_data": 0x803c33b0,
		"WaterSprayCylinder_data": 0x803c33b0,
		"MoveBG::WaterSprayBox_data": 0x803c33ec,
		"WaterSprayBox_data": 0x803c33ec,
		"MoveBG::ObjSwitch_data": 0x803c3428,
		"ObjSwitch_data": 0x803c3428,
		"MoveBG::RedCoinSwitch_data": 0x803c3464,
		"RedCoinSwitch_data": 0x803c3464,
		"MoveBG::bucket_data": 0x803c34a0,
		"bucket_data": 0x803c34a0,
		"MoveBG::GeneralHitObj_data": 0x803c34dc,
		"GeneralHitObj_data": 0x803c34dc,
		"MoveBG::bottle_large_data": 0x803c3518,
		"bottle_large_data": 0x803c3518,
		"MoveBG::bottle_short_data": 0x803c3554,
		"bottle_short_data": 0x803c3554,
		"MoveBG::WaterRecoverObj_data": 0x803c3590,
		"WaterRecoverObj_data": 0x803c3590,
		"MoveBG::watergun_item_data": 0x803c35cc,
		"watergun_item_data": 0x803c35cc,
		"MoveBG::nozzle_normal_physical_data": 0x803c3608,
		"nozzle_normal_physical_data": 0x803c3608,
		"MoveBG::nozzle_normal_physical_info": 0x803c363c,
		"nozzle_normal_physical_info": 0x803c363c,
		"MoveBG::nozzle_normal_item_data": 0x803c3648,
		"nozzle_normal_item_data": 0x803c3648,
		"MoveBG::yoshi_whistle_item_data": 0x803c3684,
		"yoshi_whistle_item_data": 0x803c3684,
		"MoveBG::nozzle_rocket_item_data": 0x803c36c0,
		"nozzle_rocket_item_data": 0x803c36c0,
		"MoveBG::nozzle_back_item_data": 0x803c36fc,
		"nozzle_back_item_data": 0x803c36fc,
		"MoveBG::coin_physical_data": 0x803c3738,
		"coin_physical_data": 0x803c3738,
		"MoveBG::coin_physical_info": 0x803c376c,
		"coin_physical_info": 0x803c376c,
		"MoveBG::coin_data": 0x803c3778,
		"coin_data": 0x803c3778,
		"MoveBG::invisible_coin_data": 0x803c37b4,
		"invisible_coin_data": 0x803c37b4,
		"MoveBG::coin_red_data": 0x803c37f0,
		"coin_red_data": 0x803c37f0,
		"MoveBG::coin_blue_data": 0x803c382c,
		"coin_blue_data": 0x803c382c,
		"MoveBG::shine_data": 0x803c3868,
		"shine_data": 0x803c3868,
		"MoveBG::mario_cap_data": 0x803c38a4,
		"mario_cap_data": 0x803c38a4,
		"MoveBG::joint_coin_data": 0x803c38e0,
		"joint_coin_data": 0x803c38e0,
		"MoveBG::eggYoshi_data": 0x803c391c,
		"eggYoshi_data": 0x803c391c,
		"MoveBG::EggYoshi_physical_data": 0x803c3958,
		"EggYoshi_physical_data": 0x803c3958,
		"MoveBG::EggYoshi_physical_info": 0x803c398c,
		"EggYoshi_physical_info": 0x803c398c,
		"MoveBG::eggYoshiEvent_data": 0x803c3998,
		"eggYoshiEvent_data": 0x803c3998,
		"MoveBG::NozzleBox_data": 0x803c39d4,
		"NozzleBox_data": 0x803c39d4,
		"MoveBG::mushroom1up_data": 0x803c3a10,
		"mushroom1up_data": 0x803c3a10,
		"MoveBG::mushroom1upR_data": 0x803c3a4c,
		"mushroom1upR_data": 0x803c3a4c,
		"MoveBG::mushroom1upX_data": 0x803c3a88,
		"mushroom1upX_data": 0x803c3a88,
		"MoveBG::jumpbase_data": 0x803c3ac4,
		"jumpbase_data": 0x803c3ac4,
		"MoveBG::coconut_physical_data": 0x803c3b00,
		"coconut_physical_data": 0x803c3b00,
		"MoveBG::coconut_physical_info": 0x803c3b34,
		"coconut_physical_info": 0x803c3b34,
		"MoveBG::coconut_data": 0x803c3b40,
		"coconut_data": 0x803c3b40,
		"MoveBG::papaya_physical_data": 0x803c3b7c,
		"papaya_physical_data": 0x803c3b7c,
		"MoveBG::papaya_physical_info": 0x803c3bb0,
		"papaya_physical_info": 0x803c3bb0,
		"MoveBG::papaya_data": 0x803c3bbc,
		"papaya_data": 0x803c3bbc,
		"MoveBG::pine_physical_data": 0x803c3bf8,
		"pine_physical_data": 0x803c3bf8,
		"MoveBG::pine_physical_info": 0x803c3c2c,
		"pine_physical_info": 0x803c3c2c,
		"MoveBG::pine_data": 0x803c3c38,
		"pine_data": 0x803c3c38,
		"MoveBG::CoverPine_data": 0x803c3c74,
		"CoverPine_data": 0x803c3c74,
		"MoveBG::durian_physical_data": 0x803c3cb0,
		"durian_physical_data": 0x803c3cb0,
		"MoveBG::durian_physical_info": 0x803c3ce4,
		"durian_physical_info": 0x803c3ce4,
		"MoveBG::durian_data": 0x803c3cf0,
		"durian_data": 0x803c3cf0,
		"MoveBG::banana_physical_data": 0x803c3d2c,
		"banana_physical_data": 0x803c3d2c,
		"MoveBG::banana_physical_info": 0x803c3d60,
		"banana_physical_info": 0x803c3d60,
		"MoveBG::banana_data": 0x803c3d6c,
		"banana_data": 0x803c3d6c,
		"MoveBG::red_pepper_physical_data": 0x803c3da8,
		"red_pepper_physical_data": 0x803c3da8,
		"MoveBG::red_pepper_physical_info": 0x803c3ddc,
		"red_pepper_physical_info": 0x803c3ddc,
		"MoveBG::RedPepper_data": 0x803c3de8,
		"RedPepper_data": 0x803c3de8,
		"MoveBG::fence_normal_data": 0x803c3e24,
		"fence_normal_data": 0x803c3e24,
		"MoveBG::fence3x3_data": 0x803c3e60,
		"fence3x3_data": 0x803c3e60,
		"MoveBG::fence_revolve_data": 0x803c3e9c,
		"fence_revolve_data": 0x803c3e9c,
		"MoveBG::fence_revolve_inner_data": 0x803c3ed8,
		"fence_revolve_inner_data": 0x803c3ed8,
		"MoveBG::fenceInnerGreen_data": 0x803c3f14,
		"fenceInnerGreen_data": 0x803c3f14,
		"MoveBG::FenceWaterV_data": 0x803c3f50,
		"FenceWaterV_data": 0x803c3f50,
		"MoveBG::FenceWaterH_data": 0x803c3f8c,
		"FenceWaterH_data": 0x803c3f8c,
		"MoveBG::RailFence_data": 0x803c3fc8,
		"RailFence_data": 0x803c3fc8,
		"MoveBG::bambooFenceRevolveInner_data": 0x803c4004,
		"bambooFenceRevolveInner_data": 0x803c4004,
		"MoveBG::bambooFenceRevolveOuter_data": 0x803c4040,
		"bambooFenceRevolveOuter_data": 0x803c4040,
		"MoveBG::bambooRailFence_data": 0x803c407c,
		"bambooRailFence_data": 0x803c407c,
		"MoveBG::wood_barrel_physical_data": 0x803c40b8,
		"wood_barrel_physical_data": 0x803c40b8,
		"MoveBG::wood_barrel_physical_info": 0x803c40ec,
		"wood_barrel_physical_info": 0x803c40ec,
		"MoveBG::wood_barrel_hold_data": 0x803c40f8,
		"wood_barrel_hold_data": 0x803c40f8,
		"MoveBG::wood_barrel_data": 0x803c410c,
		"wood_barrel_data": 0x803c410c,
		"MoveBG::wood_barrel_once_data": 0x803c4148,
		"wood_barrel_once_data": 0x803c4148,
		"MoveBG::barrel_float_data": 0x803c4184,
		"barrel_float_data": 0x803c4184,
		"MoveBG::drum_can_data": 0x803c41c0,
		"drum_can_data": 0x803c41c0,
		"MoveBG::barrel_oil_data": 0x803c41fc,
		"barrel_oil_data": 0x803c41fc,
		"MoveBG::breakable_block_data": 0x803c4238,
		"breakable_block_data": 0x803c4238,
		"MoveBG::supermario_block_data": 0x803c4274,
		"supermario_block_data": 0x803c4274,
		"MoveBG::move_block_data": 0x803c42b0,
		"move_block_data": 0x803c42b0,
		"MoveBG::fall_slow_block_data": 0x803c42ec,
		"fall_slow_block_data": 0x803c42ec,
		"MoveBG::expand_block_data": 0x803c4328,
		"expand_block_data": 0x803c4328,
		"MoveBG::spread_block_data": 0x803c4364,
		"spread_block_data": 0x803c4364,
		"MoveBG::water_roll_block_data": 0x803c43a0,
		"water_roll_block_data": 0x803c43a0,
		"MoveBG::sand_block_data": 0x803c43dc,
		"sand_block_data": 0x803c43dc,
		"MoveBG::water_power_lift_data": 0x803c4418,
		"water_power_lift_data": 0x803c4418,
		"MoveBG::water_power_inertial_lift_data": 0x803c4454,
		"water_power_inertial_lift_data": 0x803c4454,
		"MoveBG::water_power_ship_data": 0x803c4490,
		"water_power_ship_data": 0x803c4490,
		"MoveBG::lean_direct_block_data": 0x803c44cc,
		"lean_direct_block_data": 0x803c44cc,
		"MoveBG::lean_indirect_block_data": 0x803c4508,
		"lean_indirect_block_data": 0x803c4508,
		"MoveBG::lean_block_data": 0x803c4544,
		"lean_block_data": 0x803c4544,
		"MoveBG::skate_block_data": 0x803c4580,
		"skate_block_data": 0x803c4580,
		"MoveBG::MoveCoin_data": 0x803c45bc,
		"MoveCoin_data": 0x803c45bc,
		"MoveBG::cluster_block_data": 0x803c45f8,
		"cluster_block_data": 0x803c45f8,
		"MoveBG::NormalBlock_data": 0x803c4634,
		"NormalBlock_data": 0x803c4634,
		"MoveBG::IceBlock_data": 0x803c4670,
		"IceBlock_data": 0x803c4670,
		"MoveBG::BrickBlock_data": 0x803c46ac,
		"BrickBlock_data": 0x803c46ac,
		"MoveBG::WaterMelonBlock_data": 0x803c46e8,
		"WaterMelonBlock_data": 0x803c46e8,
		"MoveBG::TelesaBlock_data": 0x803c4724,
		"TelesaBlock_data": 0x803c4724,
		"MoveBG::WoodBlockPole_data": 0x803c4760,
		"WoodBlockPole_data": 0x803c4760,
		"MoveBG::JuiceBlock_data": 0x803c479c,
		"JuiceBlock_data": 0x803c479c,
		"MoveBG::SuperHipDropBlock_data": 0x803c47d8,
		"SuperHipDropBlock_data": 0x803c47d8,
		"MoveBG::palmNormal_data": 0x803c4814,
		"palmNormal_data": 0x803c4814,
		"MoveBG::palmOugi_data": 0x803c4850,
		"palmOugi_data": 0x803c4850,
		"MoveBG::palmSago_data": 0x803c488c,
		"palmSago_data": 0x803c488c,
		"MoveBG::palmNatume_data": 0x803c48c8,
		"palmNatume_data": 0x803c48c8,
		"MoveBG::palmLeaf_data": 0x803c4904,
		"palmLeaf_data": 0x803c4904,
		"MoveBG::BananaTree_data": 0x803c4940,
		"BananaTree_data": 0x803c4940,
		"MoveBG::FruitTree_data": 0x803c497c,
		"FruitTree_data": 0x803c497c,
		"MoveBG::flower_data": 0x803c49b8,
		"flower_data": 0x803c49b8,
		"MoveBG::flowerOrange_data": 0x803c49f4,
		"flowerOrange_data": 0x803c49f4,
		"MoveBG::flowerPink_data": 0x803c4a30,
		"flowerPink_data": 0x803c4a30,
		"MoveBG::flowerPurple_data": 0x803c4a6c,
		"flowerPurple_data": 0x803c4a6c,
		"MoveBG::flowerRed_data": 0x803c4aa8,
		"flowerRed_data": 0x803c4aa8,
		"MoveBG::flowerYellow_data": 0x803c4ae4,
		"flowerYellow_data": 0x803c4ae4,
		"MoveBG::flowerSunflower_data": 0x803c4b20,
		"flowerSunflower_data": 0x803c4b20,
		"MoveBG::telegraph_pole_l_data": 0x803c4b5c,
		"telegraph_pole_l_data": 0x803c4b5c,
		"MoveBG::telegraph_pole_s_data": 0x803c4b98,
		"telegraph_pole_s_data": 0x803c4b98,
		"MoveBG::streetlamp_data": 0x803c4bd4,
		"streetlamp_data": 0x803c4bd4,
		"MoveBG::PoleNormal_data": 0x803c4c10,
		"PoleNormal_data": 0x803c4c10,
		"MoveBG::football_physical_data": 0x803c4c4c,
		"football_physical_data": 0x803c4c4c,
		"MoveBG::football_physical_info": 0x803c4c80,
		"football_physical_info": 0x803c4c80,
		"MoveBG::football_data": 0x803c4c8c,
		"football_data": 0x803c4c8c,
		"MoveBG::football_goal_data": 0x803c4cc8,
		"football_goal_data": 0x803c4cc8,
		"MoveBG::baloonball_physical_data": 0x803c4d04,
		"baloonball_physical_data": 0x803c4d04,
		"MoveBG::baloonball_physical_info": 0x803c4d38,
		"baloonball_physical_info": 0x803c4d38,
		"MoveBG::baloonball_data": 0x803c4d44,
		"baloonball_data": 0x803c4d44,
		"MoveBG::coconutball_data": 0x803c4d80,
		"coconutball_data": 0x803c4d80,
		"MoveBG::watermelon_physical_data": 0x803c4dbc,
		"watermelon_physical_data": 0x803c4dbc,
		"MoveBG::watermelon_physical_info": 0x803c4df0,
		"watermelon_physical_info": 0x803c4df0,
		"MoveBG::watermelon_data": 0x803c4dfc,
		"watermelon_data": 0x803c4dfc,
		"MoveBG::WatermelonStatic_data": 0x803c4e38,
		"WatermelonStatic_data": 0x803c4e38,
		"MoveBG::cloud_data": 0x803c4e74,
		"cloud_data": 0x803c4e74,
		"MoveBG::normallift_data": 0x803c4eb0,
		"normallift_data": 0x803c4eb0,
		"MoveBG::exrollcube_data": 0x803c4eec,
		"exrollcube_data": 0x803c4eec,
		"MoveBG::exkickboard_data": 0x803c4f28,
		"exkickboard_data": 0x803c4f28,
		"MoveBG::railblockr_data": 0x803c4f64,
		"railblockr_data": 0x803c4f64,
		"MoveBG::railblocky_data": 0x803c4fa0,
		"railblocky_data": 0x803c4fa0,
		"MoveBG::railblockb_data": 0x803c4fdc,
		"railblockb_data": 0x803c4fdc,
		"MoveBG::rollblockr_data": 0x803c5018,
		"rollblockr_data": 0x803c5018,
		"MoveBG::rollblocky_data": 0x803c5054,
		"rollblocky_data": 0x803c5054,
		"MoveBG::rollblockb_data": 0x803c5090,
		"rollblockb_data": 0x803c5090,
		"MoveBG::umaibou_data": 0x803c50cc,
		"umaibou_data": 0x803c50cc,
		"MoveBG::kamaboko_data": 0x803c5108,
		"kamaboko_data": 0x803c5108,
		"MoveBG::getag_data": 0x803c5144,
		"getag_data": 0x803c5144,
		"MoveBG::getao_data": 0x803c5180,
		"getao_data": 0x803c5180,
		"MoveBG::uirou_data": 0x803c51bc,
		"uirou_data": 0x803c51bc,
		"MoveBG::hikidashi_data": 0x803c51f8,
		"hikidashi_data": 0x803c51f8,
		"MoveBG::castella_data": 0x803c5234,
		"castella_data": 0x803c5234,
		"MoveBG::yoshiblock_data": 0x803c5270,
		"yoshiblock_data": 0x803c5270,
		"MoveBG::WoodBlockTriangle_data": 0x803c52ac,
		"WoodBlockTriangle_data": 0x803c52ac,
		"MoveBG::WoodBlockPyramid_data": 0x803c52e8,
		"WoodBlockPyramid_data": 0x803c52e8,
		"MoveBG::WoodBlockLong_data": 0x803c5324,
		"WoodBlockLong_data": 0x803c5324,
		"MoveBG::WoodBlockLarge_data": 0x803c5360,
		"WoodBlockLarge_data": 0x803c5360,
		"MoveBG::WoodBlockCone_data": 0x803c539c,
		"WoodBlockCone_data": 0x803c539c,
		"MoveBG::WoodBlockL_data": 0x803c53d8,
		"WoodBlockL_data": 0x803c53d8,
		"MoveBG::WoodBlockBridge_data": 0x803c5414,
		"WoodBlockBridge_data": 0x803c5414,
		"MoveBG::WoodBlockCube_data": 0x803c5450,
		"WoodBlockCube_data": 0x803c5450,
		"MoveBG::normalvariant0_data": 0x803c548c,
		"normalvariant0_data": 0x803c548c,
		"MoveBG::normalvariant1_data": 0x803c54c8,
		"normalvariant1_data": 0x803c54c8,
		"MoveBG::normalvariant2_data": 0x803c5504,
		"normalvariant2_data": 0x803c5504,
		"MoveBG::normalvariant3_data": 0x803c5540,
		"normalvariant3_data": 0x803c5540,
		"MoveBG::normalvariant4_data": 0x803c557c,
		"normalvariant4_data": 0x803c557c,
		"MoveBG::railvariant0_data": 0x803c55b8,
		"railvariant0_data": 0x803c55b8,
		"MoveBG::railvariant1_data": 0x803c55f4,
		"railvariant1_data": 0x803c55f4,
		"MoveBG::railvariant2_data": 0x803c5630,
		"railvariant2_data": 0x803c5630,
		"MoveBG::railvariant3_data": 0x803c566c,
		"railvariant3_data": 0x803c566c,
		"MoveBG::railvariant4_data": 0x803c56a8,
		"railvariant4_data": 0x803c56a8,
		"MoveBG::rollvariant0_data": 0x803c56e4,
		"rollvariant0_data": 0x803c56e4,
		"MoveBG::rollvariant1_data": 0x803c5720,
		"rollvariant1_data": 0x803c5720,
		"MoveBG::rollvariant2_data": 0x803c575c,
		"rollvariant2_data": 0x803c575c,
		"MoveBG::rollvariant3_data": 0x803c5798,
		"rollvariant3_data": 0x803c5798,
		"MoveBG::rollvariant4_data": 0x803c57d4,
		"rollvariant4_data": 0x803c57d4,
		"MoveBG::lamptrapspike_data": 0x803c5810,
		"lamptrapspike_data": 0x803c5810,
		"MoveBG::lamptrapiron_data": 0x803c584c,
		"lamptrapiron_data": 0x803c584c,
		"MoveBG::airplane_data": 0x803c5888,
		"airplane_data": 0x803c5888,
		"MoveBG::WoodBox_data": 0x803c58c4,
		"WoodBox_data": 0x803c58c4,
		"MoveBG::AirportPole_data": 0x803c5900,
		"AirportPole_data": 0x803c5900,
		"MoveBG::ice_car_data": 0x803c593c,
		"ice_car_data": 0x803c593c,
		"MoveBG::move_ice_car_data": 0x803c5978,
		"move_ice_car_data": 0x803c5978,
		"MoveBG::AirportBuoy_data": 0x803c59b4,
		"AirportBuoy_data": 0x803c59b4,
		"MoveBG::dptCannon_data": 0x803c59f0,
		"dptCannon_data": 0x803c59f0,
		"MoveBG::dptKing_data": 0x803c5a2c,
		"dptKing_data": 0x803c5a2c,
		"MoveBG::KoopaJrSubmarine_data": 0x803c5a68,
		"KoopaJrSubmarine_data": 0x803c5a68,
		"MoveBG::monumentshine_data": 0x803c5aa4,
		"monumentshine_data": 0x803c5aa4,
		"MoveBG::belldolpic_data": 0x803c5ae0,
		"belldolpic_data": 0x803c5ae0,
		"MoveBG::dptWeathercock_data": 0x803c5b1c,
		"dptWeathercock_data": 0x803c5b1c,
		"MoveBG::dptMonteFence_data": 0x803c5b58,
		"dptMonteFence_data": 0x803c5b58,
		"MoveBG::dptCoronaFence_data": 0x803c5b94,
		"dptCoronaFence_data": 0x803c5b94,
		"MoveBG::MapSmoke_data": 0x803c5bd0,
		"MapSmoke_data": 0x803c5bd0,
		"MoveBG::MareGate_data": 0x803c5c0c,
		"MareGate_data": 0x803c5c0c,
		"MoveBG::DemoCannon_data": 0x803c5c48,
		"DemoCannon_data": 0x803c5c48,
		"MoveBG::NozzleDoor_data": 0x803c5c84,
		"NozzleDoor_data": 0x803c5c84,
		"MoveBG::DokanGate_data": 0x803c5cc0,
		"DokanGate_data": 0x803c5cc0,
		"MoveBG::crane_data": 0x803c5cfc,
		"crane_data": 0x803c5cfc,
		"MoveBG::crane90Scene2_data": 0x803c5d38,
		"crane90Scene2_data": 0x803c5d38,
		"MoveBG::crane180Scene1_data": 0x803c5d74,
		"crane180Scene1_data": 0x803c5d74,
		"MoveBG::craneUpDown_data": 0x803c5db0,
		"craneUpDown_data": 0x803c5db0,
		"MoveBG::craneCargoUpDown_data": 0x803c5dec,
		"craneCargoUpDown_data": 0x803c5dec,
		"MoveBG::tank_data": 0x803c5e28,
		"tank_data": 0x803c5e28,
		"MoveBG::container_data": 0x803c5e64,
		"container_data": 0x803c5e64,
		"MoveBG::submarine_data": 0x803c5ea0,
		"submarine_data": 0x803c5ea0,
		"MoveBG::riccoShip_data": 0x803c5edc,
		"riccoShip_data": 0x803c5edc,
		"MoveBG::riccoPole_data": 0x803c5f18,
		"riccoPole_data": 0x803c5f18,
		"MoveBG::riccoLog_data": 0x803c5f54,
		"riccoLog_data": 0x803c5f54,
		"MoveBG::gesoSurfboard_data": 0x803c5f90,
		"gesoSurfboard_data": 0x803c5f90,
		"MoveBG::gesoSurfboardStatic_data": 0x803c5fcc,
		"gesoSurfboardStatic_data": 0x803c5fcc,
		"MoveBG::riccoWatermill_data": 0x803c6008,
		"riccoWatermill_data": 0x803c6008,
		"MoveBG::riccoShipLog_data": 0x803c6044,
		"riccoShipLog_data": 0x803c6044,
		"MoveBG::riccoShipDol_data": 0x803c6080,
		"riccoShipDol_data": 0x803c6080,
		"MoveBG::riccoYachtL_data": 0x803c60bc,
		"riccoYachtL_data": 0x803c60bc,
		"MoveBG::riccoYachtS_data": 0x803c60f8,
		"riccoYachtS_data": 0x803c60f8,
		"MoveBG::riccoBoatL_data": 0x803c6134,
		"riccoBoatL_data": 0x803c6134,
		"MoveBG::riccoBoatS_data": 0x803c6170,
		"riccoBoatS_data": 0x803c6170,
		"MoveBG::riccoBasket_data": 0x803c61ac,
		"riccoBasket_data": 0x803c61ac,
		"MoveBG::riccoGangway_data": 0x803c61e8,
		"riccoGangway_data": 0x803c61e8,
		"MoveBG::riccoShipFish_data": 0x803c6224,
		"riccoShipFish_data": 0x803c6224,
		"MoveBG::riccoShipGeso_data": 0x803c6260,
		"riccoShipGeso_data": 0x803c6260,
		"MoveBG::riccoSwitch_data": 0x803c629c,
		"riccoSwitch_data": 0x803c629c,
		"MoveBG::riccoSwitchShine_data": 0x803c62d8,
		"riccoSwitchShine_data": 0x803c62d8,
		"MoveBG::riccoFenceMaze_data": 0x803c6314,
		"riccoFenceMaze_data": 0x803c6314,
		"MoveBG::riccoStand_data": 0x803c6350,
		"riccoStand_data": 0x803c6350,
		"MoveBG::riccoGrille_data": 0x803c638c,
		"riccoGrille_data": 0x803c638c,
		"MoveBG::riccoArrow_data": 0x803c63c8,
		"riccoArrow_data": 0x803c63c8,
		"MoveBG::riccoStreetStall_data": 0x803c6404,
		"riccoStreetStall_data": 0x803c6404,
		"MoveBG::riccoHericopter_data": 0x803c6440,
		"riccoHericopter_data": 0x803c6440,
		"MoveBG::surfgeso_red_data": 0x803c647c,
		"surfgeso_red_data": 0x803c647c,
		"MoveBG::surfgeso_yellow_data": 0x803c64b8,
		"surfgeso_yellow_data": 0x803c64b8,
		"MoveBG::surfgeso_green_data": 0x803c64f4,
		"surfgeso_green_data": 0x803c64f4,
		"MoveBG::big_windmill_data": 0x803c6530,
		"big_windmill_data": 0x803c6530,
		"MoveBG::windmill_far_data": 0x803c656c,
		"windmill_far_data": 0x803c656c,
		"MoveBG::MiniWindmillL_data": 0x803c65a8,
		"MiniWindmillL_data": 0x803c65a8,
		"MoveBG::MiniWindmillS_data": 0x803c65e4,
		"MiniWindmillS_data": 0x803c65e4,
		"MoveBG::WindmillRoof_data": 0x803c6620,
		"WindmillRoof_data": 0x803c6620,
		"MoveBG::lamp_bianco_data": 0x803c665c,
		"lamp_bianco_data": 0x803c665c,
		"MoveBG::root_pakkun_data": 0x803c6698,
		"root_pakkun_data": 0x803c6698,
		"MoveBG::windmill_block_data": 0x803c66d4,
		"windmill_block_data": 0x803c66d4,
		"MoveBG::PolluterPakkun_data": 0x803c6710,
		"PolluterPakkun_data": 0x803c6710,
		"MoveBG::BiaBell_data": 0x803c674c,
		"BiaBell_data": 0x803c674c,
		"MoveBG::BiaWatermill00_data": 0x803c6788,
		"BiaWatermill00_data": 0x803c6788,
		"MoveBG::BiaWatermill01_data": 0x803c67c4,
		"BiaWatermill01_data": 0x803c67c4,
		"MoveBG::BiaWatermillVertical_data": 0x803c6800,
		"BiaWatermillVertical_data": 0x803c6800,
		"MoveBG::BiaTurnBridge_data": 0x803c683c,
		"BiaTurnBridge_data": 0x803c683c,
		"MoveBG::LeafBoat_data": 0x803c6878,
		"LeafBoat_data": 0x803c6878,
		"MoveBG::LeafBoatRotten_data": 0x803c68b4,
		"LeafBoatRotten_data": 0x803c68b4,
		"MoveBG::LampSeesaw_data": 0x803c68f0,
		"LampSeesaw_data": 0x803c68f0,
		"MoveBG::BiancoDoor_data": 0x803c692c,
		"BiancoDoor_data": 0x803c692c,
		"MoveBG::BiaBridge_data": 0x803c6968,
		"BiaBridge_data": 0x803c6968,
		"MoveBG::SandBird_data": 0x803c69a4,
		"SandBird_data": 0x803c69a4,
		"MoveBG::SandBirdBlock_data": 0x803c69e0,
		"SandBirdBlock_data": 0x803c69e0,
		"MoveBG::SkyIsland_data": 0x803c6a1c,
		"SkyIsland_data": 0x803c6a1c,
		"MoveBG::SandLeaf_data": 0x803c6a58,
		"SandLeaf_data": 0x803c6a58,
		"MoveBG::SandLeafBase00_data": 0x803c6a94,
		"SandLeafBase00_data": 0x803c6a94,
		"MoveBG::SandLeafBase01_data": 0x803c6ad0,
		"SandLeafBase01_data": 0x803c6ad0,
		"MoveBG::SandLeafBase02_data": 0x803c6b0c,
		"SandLeafBase02_data": 0x803c6b0c,
		"MoveBG::SandLeafBase03_data": 0x803c6b48,
		"SandLeafBase03_data": 0x803c6b48,
		"MoveBG::SandBomb_data": 0x803c6b84,
		"SandBomb_data": 0x803c6b84,
		"MoveBG::MirrorL_data": 0x803c6bc0,
		"MirrorL_data": 0x803c6bc0,
		"MoveBG::MirrorM_data": 0x803c6bfc,
		"MirrorM_data": 0x803c6bfc,
		"MoveBG::MirrorS_data": 0x803c6c38,
		"MirrorS_data": 0x803c6c38,
		"MoveBG::SandCastle_data": 0x803c6c74,
		"SandCastle_data": 0x803c6c74,
		"MoveBG::MammaBlockRotate_data": 0x803c6cb0,
		"MammaBlockRotate_data": 0x803c6cb0,
		"MoveBG::SandEgg_data": 0x803c6cec,
		"SandEgg_data": 0x803c6cec,
		"MoveBG::SandEggBroken_data": 0x803c6d28,
		"SandEggBroken_data": 0x803c6d28,
		"MoveBG::ShiningStone_data": 0x803c6d64,
		"ShiningStone_data": 0x803c6d64,
		"MoveBG::MammaSurfboard00_data": 0x803c6da0,
		"MammaSurfboard00_data": 0x803c6da0,
		"MoveBG::MammaSurfboard01_data": 0x803c6ddc,
		"MammaSurfboard01_data": 0x803c6ddc,
		"MoveBG::MammaSurfboard02_data": 0x803c6e18,
		"MammaSurfboard02_data": 0x803c6e18,
		"MoveBG::MammaSurfboard03_data": 0x803c6e54,
		"MammaSurfboard03_data": 0x803c6e54,
		"MoveBG::MammaSurfboardStand_data": 0x803c6e90,
		"MammaSurfboardStand_data": 0x803c6e90,
		"MoveBG::MammaYacht00_data": 0x803c6ecc,
		"MammaYacht00_data": 0x803c6ecc,
		"MoveBG::MammaYacht01_data": 0x803c6f08,
		"MammaYacht01_data": 0x803c6f08,
		"MoveBG::MammaYacht02_data": 0x803c6f44,
		"MammaYacht02_data": 0x803c6f44,
		"MoveBG::SandBombBase00_data": 0x803c6f80,
		"SandBombBase00_data": 0x803c6f80,
		"MoveBG::SandBombBaseMushroom_data": 0x803c6fbc,
		"SandBombBaseMushroom_data": 0x803c6fbc,
		"MoveBG::SandBombBasePyramid_data": 0x803c6ff8,
		"SandBombBasePyramid_data": 0x803c6ff8,
		"MoveBG::SandBombBaseShit_data": 0x803c7034,
		"SandBombBaseShit_data": 0x803c7034,
		"MoveBG::SandBombBaseStar_data": 0x803c7070,
		"SandBombBaseStar_data": 0x803c7070,
		"MoveBG::SandBombBaseTurtle_data": 0x803c70ac,
		"SandBombBaseTurtle_data": 0x803c70ac,
		"MoveBG::SandBombBaseFoot_data": 0x803c70e8,
		"SandBombBaseFoot_data": 0x803c70e8,
		"MoveBG::SandBombBaseHand_data": 0x803c7124,
		"SandBombBaseHand_data": 0x803c7124,
		"MoveBG::SandBombBaseStairs_data": 0x803c7160,
		"SandBombBaseStairs_data": 0x803c7160,
		"MoveBG::coral00_data": 0x803c719c,
		"coral00_data": 0x803c719c,
		"MoveBG::coral01_data": 0x803c71d8,
		"coral01_data": 0x803c71d8,
		"MoveBG::GoalWatermelon_data": 0x803c7214,
		"GoalWatermelon_data": 0x803c7214,
		"MoveBG::TeethOfJuicer_data": 0x803c7250,
		"TeethOfJuicer_data": 0x803c7250,
		"MoveBG::SandEggRepair_data": 0x803c728c,
		"SandEggRepair_data": 0x803c728c,
		"MoveBG::merrygoround_data": 0x803c72c8,
		"merrygoround_data": 0x803c72c8,
		"MoveBG::merry_egg_data": 0x803c7304,
		"merry_egg_data": 0x803c7304,
		"MoveBG::merry_pole_data": 0x803c7340,
		"merry_pole_data": 0x803c7340,
		"MoveBG::FerrisWheel_data": 0x803c737c,
		"FerrisWheel_data": 0x803c737c,
		"MoveBG::gondola_data": 0x803c73b8,
		"gondola_data": 0x803c73b8,
		"MoveBG::FerrisLOD_data": 0x803c73f4,
		"FerrisLOD_data": 0x803c73f4,
		"MoveBG::viking_data": 0x803c7430,
		"viking_data": 0x803c7430,
		"MoveBG::PinnaEntrance_data": 0x803c746c,
		"PinnaEntrance_data": 0x803c746c,
		"MoveBG::PinnaEntranceOpen_data": 0x803c74a8,
		"PinnaEntranceOpen_data": 0x803c74a8,
		"MoveBG::SirenaGate_data": 0x803c74e4,
		"SirenaGate_data": 0x803c74e4,
		"MoveBG::BalloonKoopaJr_data": 0x803c7520,
		"BalloonKoopaJr_data": 0x803c7520,
		"MoveBG::ShellCup_data": 0x803c755c,
		"ShellCup_data": 0x803c755c,
		"MoveBG::Gateshell_data": 0x803c7598,
		"Gateshell_data": 0x803c7598,
		"MoveBG::PinnaHangingBridgeBoard_data": 0x803c75d4,
		"PinnaHangingBridgeBoard_data": 0x803c75d4,
		"MoveBG::GateManta_data": 0x803c7610,
		"GateManta_data": 0x803c7610,
		"MoveBG::PinnaSunFlower_data": 0x803c764c,
		"PinnaSunFlower_data": 0x803c764c,
		"MoveBG::AmiKing_data": 0x803c7688,
		"AmiKing_data": 0x803c7688,
		"MoveBG::PinnaCoaster_data": 0x803c76c4,
		"PinnaCoaster_data": 0x803c76c4,
		"MoveBG::casinoroulette_data": 0x803c7700,
		"casinoroulette_data": 0x803c7700,
		"MoveBG::roulette00_data": 0x803c773c,
		"roulette00_data": 0x803c773c,
		"MoveBG::roulette01_data": 0x803c7778,
		"roulette01_data": 0x803c7778,
		"MoveBG::roulette02_data": 0x803c77b4,
		"roulette02_data": 0x803c77b4,
		"MoveBG::slotdrum_data": 0x803c77f0,
		"slotdrum_data": 0x803c77f0,
		"MoveBG::telesaslot_data": 0x803c782c,
		"telesaslot_data": 0x803c782c,
		"MoveBG::donchou_data": 0x803c7868,
		"donchou_data": 0x803c7868,
		"MoveBG::casino_panel_gate_data": 0x803c78a4,
		"casino_panel_gate_data": 0x803c78a4,
		"MoveBG::SakuCasino_data": 0x803c78e0,
		"SakuCasino_data": 0x803c78e0,
		"MoveBG::SirenabossWall_data": 0x803c791c,
		"SirenabossWall_data": 0x803c791c,
		"MoveBG::SirenaCasinoRoof_data": 0x803c7958,
		"SirenaCasinoRoof_data": 0x803c7958,
		"MoveBG::GlassBreak_data": 0x803c7994,
		"GlassBreak_data": 0x803c7994,
		"MoveBG::Closet_data": 0x803c79d0,
		"Closet_data": 0x803c79d0,
		"MoveBG::ChestRevolve_data": 0x803c7a0c,
		"ChestRevolve_data": 0x803c7a0c,
		"MoveBG::PosterTeresa_data": 0x803c7a48,
		"PosterTeresa_data": 0x803c7a48,
		"MoveBG::PictureTeresa_data": 0x803c7a84,
		"PictureTeresa_data": 0x803c7a84,
		"MoveBG::PanelBreak_data": 0x803c7ac0,
		"PanelBreak_data": 0x803c7ac0,
		"MoveBG::PanelRevolve_data": 0x803c7afc,
		"PanelRevolve_data": 0x803c7afc,
		"MoveBG::SirenaBlockBreak_data": 0x803c7b38,
		"SirenaBlockBreak_data": 0x803c7b38,
		"MoveBG::SirenaShop_data": 0x803c7b74,
		"SirenaShop_data": 0x803c7b74,
		"MoveBG::StainHotel_data": 0x803c7bb0,
		"StainHotel_data": 0x803c7bb0,
		"MoveBG::cogwheel_data": 0x803c7bec,
		"cogwheel_data": 0x803c7bec,
		"MoveBG::CogwheelPlate_data": 0x803c7c28,
		"CogwheelPlate_data": 0x803c7c28,
		"MoveBG::CogwheelPot_data": 0x803c7c64,
		"CogwheelPot_data": 0x803c7c64,
		"MoveBG::mare_float_house_data": 0x803c7ca0,
		"mare_float_house_data": 0x803c7ca0,
		"MoveBG::StopRock_physical_data": 0x803c7cdc,
		"StopRock_physical_data": 0x803c7cdc,
		"MoveBG::StopRock_physical_info": 0x803c7d10,
		"StopRock_physical_info": 0x803c7d10,
		"MoveBG::StopRock_data": 0x803c7d1c,
		"StopRock_data": 0x803c7d1c,
		"MoveBG::ElasticCode_data": 0x803c7d58,
		"ElasticCode_data": 0x803c7d58,
		"MoveBG::GrowthTree_data": 0x803c7d94,
		"GrowthTree_data": 0x803c7d94,
		"MoveBG::WireBellPurple_data": 0x803c7dd0,
		"WireBellPurple_data": 0x803c7dd0,
		"MoveBG::MuddyBoat_data": 0x803c7e0c,
		"MuddyBoat_data": 0x803c7e0c,
		"MoveBG::Puncher_data": 0x803c7e48,
		"Puncher_data": 0x803c7e48,
		"MoveBG::HatoPop_data": 0x803c7e84,
		"HatoPop_data": 0x803c7e84,
		"MoveBG::MareWaterJump_data": 0x803c7ec0,
		"MareWaterJump_data": 0x803c7ec0,
		"MoveBG::BumpyWall_data": 0x803c7efc,
		"BumpyWall_data": 0x803c7efc,
		"MoveBG::ExBottle_data": 0x803c7f38,
		"ExBottle_data": 0x803c7f38,
		"MoveBG::CoinFish_data": 0x803c7f74,
		"CoinFish_data": 0x803c7f74,
		"MoveBG::MareFall_data": 0x803c7fb0,
		"MareFall_data": 0x803c7fb0,
		"MoveBG::MareCork_data": 0x803c7fec,
		"MareCork_data": 0x803c7fec,
		"MoveBG::MonteRoot_data": 0x803c8028,
		"MonteRoot_data": 0x803c8028,
		"MoveBG::JumpMushroom_data": 0x803c8064,
		"JumpMushroom_data": 0x803c8064,
		"MoveBG::MonteGoalFlag_data": 0x803c80a0,
		"MonteGoalFlag_data": 0x803c80a0,
		"MoveBG::HangingBridgeBoard_data": 0x803c80dc,
		"HangingBridgeBoard_data": 0x803c80dc,
		"MoveBG::HangingBridge_data": 0x803c8118,
		"HangingBridge_data": 0x803c8118,
		"MoveBG::SwingBoard_data": 0x803c8154,
		"SwingBoard_data": 0x803c8154,
		"MoveBG::Fluff_data": 0x803c8190,
		"Fluff_data": 0x803c8190,
		"MoveBG::FluffManager_data": 0x803c81cc,
		"FluffManager_data": 0x803c81cc,
		"MoveBG::Bathtub_data": 0x803c8208,
		"Bathtub_data": 0x803c8208,
		"MoveBG::BathtubStand_data": 0x803c8244,
		"BathtubStand_data": 0x803c8244,
		"MoveBG::BathtubStandBreaking_animation": 0x803c8280,
		"BathtubStandBreaking_animation": 0x803c8280,
		"MoveBG::BathtubStandBreaking_data": 0x803c828c,
		"BathtubStandBreaking_data": 0x803c828c,
		"MoveBG::ex1_turn_lift_move_data": 0x803c82c8,
		"ex1_turn_lift_move_data": 0x803c82c8,
		"MoveBG::ex1_turn_lift_data": 0x803c82d4,
		"ex1_turn_lift_data": 0x803c82d4,
		"MoveBG::z_turn_disk_move_data": 0x803c8310,
		"z_turn_disk_move_data": 0x803c8310,
		"MoveBG::z_turn_disk_data": 0x803c831c,
		"z_turn_disk_data": 0x803c831c,
		"MoveBG::y_turn_lift_move_data": 0x803c8358,
		"y_turn_lift_move_data": 0x803c8358,
		"MoveBG::y_turn_lift_data": 0x803c8364,
		"y_turn_lift_data": 0x803c8364,
		"MoveBG::EXskyTumiki_data": 0x803c83a0,
		"EXskyTumiki_data": 0x803c83a0,
		"MoveBG::EXskyWindow_data": 0x803c83dc,
		"EXskyWindow_data": 0x803c83dc,
		"MoveBG::EXskySenro_data": 0x803c8418,
		"EXskySenro_data": 0x803c8418,
		"MoveBG::Nail_data": 0x803c8454,
		"Nail_data": 0x803c8454,
		"MoveBG::PachinkoNail_data": 0x803c8490,
		"PachinkoNail_data": 0x803c8490,
		"MoveBG::FileLoadBlockA_data": 0x803c84cc,
		"FileLoadBlockA_data": 0x803c84cc,
		"MoveBG::FileLoadBlockB_data": 0x803c8508,
		"FileLoadBlockB_data": 0x803c8508,
		"MoveBG::FileLoadBlockC_data": 0x803c8544,
		"FileLoadBlockC_data": 0x803c8544,
		"MoveBG::sObjDataTable": 0x803c8580,
		"sObjDataTable": 0x803c8580,
		"TMapObjGeneral::__vt": 0x803c8b20,
		"TMapObjBaseManager::__vt": 0x803c8d48,
		"TMerryPole::__vt": 0x803c8d88,
		"TMapObjManager::__vt": 0x803c8eec,
		"TMapObjTurn::__vt": 0x803c8f30,
		"TMapObjMessenger::__vt": 0x803c90a4,
		"TShine::mPromiLife": 0x803c9180,
		"mPromiLife": 0x803c9180,
		"TShine::mSenkoRate": 0x803c9190,
		"mSenkoRate": 0x803c9190,
		"TShine::mKiraRate": 0x803c91a0,
		"mKiraRate": 0x803c91a0,
		"TShine::mBowRate": 0x803c91b0,
		"mBowRate": 0x803c91b0,
		"TNozzleBox::__vt": 0x803c91c0,
		"TItemNozzle::__vt": 0x803c942c,
		"TEggYoshi::__vt": 0x803c9610,
		"TShine::__vt": 0x803c97ec,
		"TCoinBlue::__vt": 0x803c99d0,
		"TCoinRed::__vt": 0x803c9bb4,
		"TCoinEmpty::__vt": 0x803c9d98,
		"TFlowerCoin::__vt": 0x803c9f7c,
		"TCoin::__vt": 0x803ca160,
		"TItem::__vt": 0x803ca344,
		"TItemManager::__vt": 0x803ca528,
		"TBasketReverse::__vt": 0x803ca568,
		"TRedCoinSwitch::__vt": 0x803ca6cc,
		"TMapObjSwitch::__vt": 0x803ca830,
		"THideObjInfo::__vt": 0x803ca994,
		"TMapObjWaterSpray::__vt": 0x803caa38,
		"TDamageObj::__vt": 0x803cab9c,
		"TMapObjStartDemo::__vt": 0x803cac40,
		"TMapObjChangeStageHipDrop::__vt": 0x803cada4,
		"TMapObjChangeStage::__vt": 0x803caf08,
		"TMapObjBillboard::__vt": 0x803cb06c,
		"TManhole::__vt": 0x803cb1dc,
		"TDoor::__vt": 0x803cb3b8,
		"TSuperHipDropBlock::__vt": 0x803cb520,
		"TTelesaBlock::__vt": 0x803cb690,
		"TJuiceBlock::__vt": 0x803cb7f4,
		"TBrickBlock::__vt": 0x803cb958,
		"TIceBlock::__vt": 0x803cbac8,
		"TLeanBlock::__vt": 0x803cbc2c,
		"TSandBlock::__vt": 0x803cbd94,
		"TBreakableBlock::__vt": 0x803cbef8,
		"TWoodLog::__vt": 0x803cc0d8,
		"TBellWatermill::__vt": 0x803cc240,
		"TBiancoBell::__vt": 0x803cc3b4,
		"TLampSeesawMain::__vt": 0x803cc518,
		"TLampSeesaw::__vt": 0x803cc680,
		"TLeafBoatRotten::__vt": 0x803cc7e8,
		"TLeafBoat::__vt": 0x803cc94c,
		"TBiancoMiniWindmill::__vt": 0x803ccab0,
		"TBiancoWatermillVertical::__vt": 0x803ccc20,
		"TBiancoWatermill::__vt": 0x803ccd84,
		"TMapObjRootPakkun::__vt": 0x803ccee8,
		"TBigWindmill::__vt": 0x803cd04c,
		"TPictureTelesa::__vt": 0x803cd1b0,
		"TPanelRevolve::__vt": 0x803cd32c,
		"TChestRevolve::__vt": 0x803cd490,
		"TWarpAreaActor::__vt": 0x803cd5f4,
		"TSirenaCasinoRoof::__vt": 0x803cd698,
		"TSirenabossWall::__vt": 0x803cd7fc,
		"TSakuCasino::__vt": 0x803cd960,
		"TCloset::__vt": 0x803cdac4,
		"TDonchou::__vt": 0x803cdc34,
		"TCasinoPanelGate::__vt": 0x803cdd98,
		"TItemSlotDrum::__vt": 0x803cdf08,
		"TSlotDrum::__vt": 0x803ce07c,
		"TRoulette::__vt": 0x803ce1f0,
		"TRouletteSw::__vt": 0x803ce358,
		"TFruitLauncher::__vt": 0x803ce400,
		"TFruitSwitch::__vt": 0x803ce564,
		"TSurfGesoObj::__vt": 0x803ce6c8,
		"TRiccoWatermill::__vt": 0x803ce8ac,
		"TCraneCargo::__vt": 0x803cea10,
		"TCraneUpDown::__vt": 0x803ceb78,
		"TCraneRotY::__vt": 0x803cecdc,
		"TSandEgg::__vt": 0x803cee40,
		"TMammaMirrorMapOperator::__vt": 0x803cefc8,
		"TGoalWatermelon::__vt": 0x803cefec,
		"TSandBird::__vt": 0x803cf2b4,
		"TMammaYacht::__vt": 0x803cf424,
		"TMammaBlockRotate::__vt": 0x803cf588,
		"TShiningStone::__vt": 0x803cf6ec,
		"TLeanMirror::__vt": 0x803cf790,
		"TSandCastle::__vt": 0x803cf8f4,
		"TSandBombBase::__vt": 0x803cfa78,
		"TSandBomb::__vt": 0x803cfbfc,
		"TSandLeafBase::__vt": 0x803cfd60,
		"TSandBase::__vt": 0x803cfecc,
		"TSandLeaf::__vt": 0x803d0038,
		"TPinnaCoaster::__vt": 0x803d01a0,
		"TAmiKing::__vt": 0x803d0304,
		"TWaterRecoverObj::__vt": 0x803d0468,
		"TPinnaEntrance::__vt": 0x803d05cc,
		"TBalloonKoopaJr::__vt": 0x803d0730,
		"TChangeStageMerrygoround::__vt": 0x803d090c,
		"TMerrygoround::__vt": 0x803d0a70,
		"TShellCup::__vt": 0x803d0bd4,
		"TPinnaShell::__vt": 0x803d0d38,
		"TViking::__vt": 0x803d0ddc,
		"THorizontalViking::__vt": 0x803d0f44,
		"TFerrisWheel::__vt": 0x803d10ac,
		"TGateShadow::__vt": 0x803d1210,
		"TMareEventPoint::__vt": 0x803d1238,
		"TMareCork::__vt": 0x803d12dc,
		"TMareFall::__vt": 0x803d1440,
		"TMuddyBoat::__vt": 0x803d15a4,
		"TMapObjPuncher::__vt": 0x803d1708,
		"TWireBell::__vt": 0x803d186c,
		"TMapObjGrowTree::__vt": 0x803d19d0,
		"TMapObjElasticCode::__vt": 0x803d1b34,
		"TCogwheel::__vt": 0x803d1c98,
		"TCogwheelScale::__vt": 0x803d1dfc,
		"TMapObjFlagManager::__vt": 0x803d1f60,
		"TMapObjFlag::__vt": 0x803d1f84,
		"TMapObjWave::__vt": 0x803d2030,
		"TMapObjFloatOnSea::__vt": 0x803d2058,
		"TSandPlane::__vt": 0x803d21c0,
		"TRockPlane::__vt": 0x803d22bc,
		"TMapObjPlane::__vt": 0x803d23b8,
		"TRideCloud::__vt": 0x803d24b8,
		"TBigWatermelon::__vt": 0x803d2628,
		"TCoverFruit::__vt": 0x803d2850,
		"TRandomFruit::__vt": 0x803d29b4,
		"TResetFruit::__vt": 0x803d2ba4,
		"TMapObjBall::__vt": 0x803d2d94,
		"TAirportEventSink::__vt": 0x803d2f88,
		"TAirportSwitch::__vt": 0x803d2fdc,
		"TTurboNozzleDoor::__vt": 0x803d31b8,
		"TDemoCannon::__vt": 0x803d331c,
		"TMareGate::__vt": 0x803d3480,
		"TMapObjSmoke::__vt": 0x803d35e4,
		"TDptMonteFence::__vt": 0x803d3754,
		"TBellDolpic::__vt": 0x803d38b8,
		"TMonumentShine::__vt": 0x803d3a1c,
		"TMapObjRevivalPollution::__vt": 0x803d3b80,
		"TPolluterBase::__vt": 0x803d3ba4,
		"TMapObjGrassManager::__vt": 0x803d3d08,
		"TMapObjGrassGroup::__vt": 0x803d3d2c,
		"TMapObjPoleManager::__vt": 0x803d3dd0,
		"TMapObjWaterFilter::__vt": 0x803d3df8,
		"TMapObjSeaIndirect::__vt": 0x803d3e98,
		"MoveBG::gateMActorNames": 0x803d3f70,
		"gateMActorNames": 0x803d3f70,
		"MoveBG::gateNames$2573": 0x803d3f84,
		"gateNames$2573": 0x803d3f84,
		"TModelGate::__vt": 0x803d3f9c,
		"TRailFence::__vt": 0x803d4128,
		"TFenceWaterH::__vt": 0x803d428c,
		"TFenceWater::__vt": 0x803d43f8,
		"TRevolvingFenceInner::__vt": 0x803d4564,
		"TRevolvingFenceOuter::__vt": 0x803d46c8,
		"TFence::__vt": 0x803d482c,
		"TFileLoadBlock::__vt": 0x803d4990,
		"TMapObjOptionWall::__vt": 0x803d4af4,
		"TWoodBlock::__vt": 0x803d4b98,
		"TRollBlock::__vt": 0x803d4d08,
		"TRailBlock::__vt": 0x803d4e6c,
		"TNormalLift::__vt": 0x803d4fdc,
		"TRailMapObj::__vt": 0x803d514c,
		"TFluffManager::__vt": 0x803d52c0,
		"TFluff::__vt": 0x803d5424,
		"TGoalFlag::__vt": 0x803d5588,
		"TSwingBoard::__vt": 0x803d56ec,
		"THangingBridge::__vt": 0x803d5850,
		"THangingBridgeBoard::__vt": 0x803d5874,
		"TJumpMushroom::__vt": 0x803d59dc,
		"TMapObjMonteRoot::__vt": 0x803d5b40,
		"TMapObjTreeScale::__vt": 0x803d5ca8,
		"TMapObjTree::__vt": 0x803d5e84,
		"TMapObjSteam::__vt": 0x803d6060,
		"TJointCoin::__vt": 0x803d61d0,
		"TMapObjNail::__vt": 0x803d6340,
		"TPool::__vt": 0x803d64b0,
		"TPoolManager::__vt": 0x803d6614,
		"TBathtub::__vt": 0x803d6658,
		"TBathtubGrip::__vt": 0x803d67bc,
		"TBathtubGripPartsHard::__vt": 0x803d6920,
		"TBathtubGripPartsFragile::__vt": 0x803d6a1c,
		"TBathtubGripParts::__vt": 0x803d6b18,
		"TJumpBase::__vt": 0x803d6c18,
		"TMushroom1up::__vt": 0x803d6d7c,
		"TWoodBox::__vt": 0x803d6ee0,
		"TBreakHideObj::__vt": 0x803d7050,
		"THideObjPictureTwin::__vt": 0x803d71c0,
		"TWaterHitPictureHideObj::__vt": 0x803d733c,
		"THipDropHideObj::__vt": 0x803d74b8,
		"TFruitBasketEvent::__vt": 0x803d7628,
		"TFruitBasket::__vt": 0x803d77a0,
		"TFruitHitHideObj::__vt": 0x803d7918,
		"TWaterHitHideObj::__vt": 0x803d7a8c,
		"THideObj::__vt": 0x803d7bfc,
		"THideObjBase::__vt": 0x803d7d6c,
		"TLampTrapIron::__vt": 0x803d7ee0,
		"TLampTrapIronHit::__vt": 0x803d8044,
		"TLampTrapSpike::__vt": 0x803d80e8,
		"TLampTrapSpikeHit::__vt": 0x803d824c,
		"TJointModel::__vt": 0x803c15d0,
		"TJointModelManager::__vt": 0x803c1608,
		"TJointObj::__vt": 0x803c1630,
		"TMap::__vt": 0x803c1658,
		"Map::@3341": 0x803c167c,
		"TBGCheckListWarp::__vt": 0x803c16c0,
		"TBGCheckList::__vt": 0x803c16cc,
		"TMapCollisionWarp::__vt": 0x803c16d8,
		"TMapCollisionMove::__vt": 0x803c16fc,
		"TMapCollisionStatic::__vt": 0x803c1720,
		"TMapCollisionBase::__vt": 0x803c1744,
		"TMapDrawWall::__vt": 0x803c1768,
		"TMapEvent::__vt": 0x803c1790,
		"TMapEventSinkShadowMario::__vt": 0x803c17d0,
		"TMapEventSinkBianco::__vt": 0x803c1824,
		"TMapEventSinkInPollutionReset::__vt": 0x803c1878,
		"TMapEventSinkInPollution::__vt": 0x803c18cc,
		"TMapEventSink::__vt": 0x803c1920,
		"TMirrorMapDrawBuf::__vt": 0x803c1978,
		"TMirrorModelManager::__vt": 0x803c199c,
		"TMirrorModelObj::__vt": 0x803c19c0,
		"TMirrorModel::__vt": 0x803c19dc,
		"TMirrorCamera::__vt": 0x803c19f8,
		"Map::name_table$2428": 0x803c1ac0,
		"name_table$2428": 0x803c1ac0,
		"TMapModel::__vt": 0x803c1ad4,
		"TMapModelManager::__vt": 0x803c1b08,
		"TMapObjSoundGroup::__vt": 0x803c1b30,
		"TMapModelActor::__vt": 0x803c1b70,
		"TMapStaticObj::__vt": 0x803c1c14,
		"TMapWireManager::__vt": 0x803c1cb8,
		"TMapWireActor::__vt": 0x803c1cdc,
		"TPollutionCounterBase::__vt": 0x803c1d90,
		"TPollutionCounterObj::__vt": 0x803c1da4,
		"TPollutionCounterLayer::__vt": 0x803c1db8,
		"Map::mare_name_table$2805": 0x803c1dd0,
		"mare_name_table$2805": 0x803c1dd0,
		"Map::name_table$2816": 0x803c1df8,
		"name_table$2816": 0x803c1df8,
		"TPollutionManager::__vt": 0x803c1e4c,
		"Map::@3043": 0x803c1e74,
		"TPollutionLayerWallMinusX::__vt": 0x803c1e90,
		"TPollutionLayerWallMinusZ::__vt": 0x803c1eec,
		"TPollutionObj::__vt": 0x803c1f48,
		"TShimmer::__vt": 0x803c1f70,
		"TSky::__vt": 0x803c2010,
		"TMapEventSirenaSink::__vt": 0x803c20b0,
		"Map::x_offset_table$2432": 0x803c2110,
		"x_offset_table$2432": 0x803c2110,
		"Map::z_offset_table$2433": 0x803c2138,
		"z_offset_table$2433": 0x803c2138,
		"TPollutionLayer::__vt": 0x803c2160,
		"TPollutionLayerWallBase::__vt": 0x803c21bc,
		"TPollutionLayerWallPlusX::__vt": 0x803c2218,
		"TPollutionLayerWallPlusZ::__vt": 0x803c2274,
		"TPollutionLayerWave::__vt": 0x803c22d0,
		"TPollutionTest::__vt": 0x803c2330,
		"TMarineSnow::__vt": 0x803c2358,
		"TDolpicEventRiccoMammaGate::__vt": 0x803c23f8,
		"TDolpicEventBiancoGate::__vt": 0x803c2438,
		"TMareEventBumpyWall::__vt": 0x803c2478,
		"Map::@3790": 0x803c25dc,
		"TMareEventDepressWall::__vt": 0x803c25fc,
		"TMareEventWallRock::__vt": 0x803c2620,
		"TMareWallRock::__vt": 0x803c2644,
		"TBathWaterManager::fileNames": 0x803c2780,
		"fileNames": 0x803c2780,
		"TBathWaterManager::__vt": 0x803c2788,
		"TBathWater::__vt": 0x803c27ac,
		"TBathWaterMeshRenderer::__vt": 0x803c2850,
		"TBathWaterFlatRenderer::__vt": 0x803c2864,
		"TBathWaterRenderer::__vt": 0x803c2878,
		"TBathWaterPreprocessor::__vt": 0x803c288c,
		"TStickyStainManager::__vt": 0x803c28b0,
		"TFlashPane::__vt": 0x803bff58,
		"TMenuPlane::__vt": 0x803bff7c,
		"TMenuBase::__vt": 0x803bffa0,
		"TSMSFader::__vt": 0x803bffc8,
		"GC2D::scDolpicNewsDolpic5_1": 0x803c0020,
		"scDolpicNewsDolpic5_1": 0x803c0020,
		"GC2D::scDolpicNewsDolpic5_4": 0x803c002c,
		"scDolpicNewsDolpic5_4": 0x803c002c,
		"GC2D::scDolpicNewsDolpic6": 0x803c0038,
		"scDolpicNewsDolpic6": 0x803c0038,
		"GC2D::scDolpicNewsDolpic7": 0x803c0044,
		"scDolpicNewsDolpic7": 0x803c0044,
		"GC2D::scDolpicNewsDolpic9": 0x803c02dc,
		"scDolpicNewsDolpic9": 0x803c02dc,
		"GC2D::scDolpicNewsDolpic10": 0x803c02e8,
		"scDolpicNewsDolpic10": 0x803c02e8,
		"TGCConsole2::__vt": 0x803c0304,
		"TTalk2D2::cColorTable": 0x803c03b0,
		"TTalk2D2::__vt": 0x803c03c8,
		"TPauseMenu2::__vt": 0x803c0550,
		"TSwitchHelpActor::__vt": 0x803c0578,
		"THelpActor::__vt": 0x803c0620,
		"TCardSave::cMessageID": 0x803c06c8,
		"TCardSave::__vt": 0x803c07a0,
		"TCardLoad::cMessageID": 0x803c08f0,
		"TCardLoad::__vt": 0x803c09c8,
		"TConsoleStr::__vt": 0x803c0c78,
		"TSelectMenu::__vt": 0x803c0e58,
		"TSelectGrad::__vt": 0x803c0ec8,
		"TSelectDir::__vt": 0x803c0ef0,
		"TSelectShine::__vt": 0x803c0f88,
		"TSelectShineManager::__vt": 0x803c0f98,
		"TBlendPane::__vt": 0x803c0fc0,
		"TGuide::__vt": 0x803c1048,
		"GC2D::@2657": 0x803c106c,
		"TSunShine::__vt": 0x803c10a0,
		"TSunGlass::__vt": 0x803c10c8,
		"TShineFader::__vt": 0x803c10f0,
		"TProgSelect::__vt": 0x803c1254,
		"GC2D::camLoc$96": 0x803c1278,
		"camLoc$96": 0x803c1278,
		"GC2D::objPt$97": 0x803c1284,
		"objPt$97": 0x803c1284,
		"GC2D::up$98": 0x803c1290,
		"up$98": 0x803c1290,
		"GC2D::handle_table": 0x803c129c,
		"handle_table": 0x803c129c,
		"GC2D::handle_type": 0x803c12d8,
		"handle_type": 0x803c12d8,
		"GC2D::boundtable$262": 0x803c12e8,
		"boundtable$262": 0x803c12e8,
		"GC2D::@943": 0x803c1464,
		"TMovieSubTitle::__vt": 0x803c1488,
		"TOptionSoundUnit::cSoundSettings": 0x803c14d8,
		"cSoundSettings": 0x803c14d8,
		"TOptionSoundUnit::cFlagInfos": 0x803c14f0,
		"cFlagInfos": 0x803c14f0,
		"TMovieRumble::__vt": 0x803c15a8,
		"TConductor::__vt": 0x803ad958,
		"Enemy::entry$2672": 0x803ad980,
		"entry$2672": 0x803ad980,
		"Enemy::entry$2684": 0x803ad998,
		"entry$2684": 0x803ad998,
		"Enemy::entry$2697": 0x803ad9b0,
		"entry$2697": 0x803ad9b0,
		"Enemy::entry$2706": 0x803ad9c8,
		"entry$2706": 0x803ad9c8,
		"TEffectExplosion::__vt": 0x803ad9e0,
		"TEffectModelManager::__vt": 0x803adaf4,
		"TEffectExplosionManager::__vt": 0x803adb48,
		"TEffectColumSand::__vt": 0x803adb9c,
		"TEffectColumSandManager::__vt": 0x803adcb0,
		"TEffectBombColumWater::__vt": 0x803add04,
		"TEffectBombColumWaterManager::__vt": 0x803ade18,
		"TEffectColumWater::__vt": 0x803ade6c,
		"TEffectColumWaterManager::__vt": 0x803adf80,
		"TEffectModel::__vt": 0x803adfd4,
		"TEffectObjManager::__vt": 0x803ae0e8,
		"TEffectObjBase::__vt": 0x803ae10c,
		"TEffectBiancoFunsui::__vt": 0x803ae1c0,
		"TEffectPinnaFunsui::__vt": 0x803ae264,
		"TSimpleEffect::__vt": 0x803ae308,
		"TEMarioManager::__vt": 0x803ae3b0,
		"TEMario::__vt": 0x803ae404,
		"TSpineEnemy::__vt": 0x803ae518,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::__vt": 0x803ae62c,
		"TSpineBase<TLiveActor>::__vt": 0x803ae638,
		"TSolidStack<TPathNode>::__vt": 0x803ae648,
		"TEnemyPolluteModel::__vt": 0x803ae658,
		"TEnemyPolluteModelManager::__vt": 0x803ae680,
		"TEnemyAttachment::__vt": 0x803ae6a8,
		"TEnemyManager::__vt": 0x803ae800,
		"Enemy::marioAnimeFiles": 0x803ae890,
		"Enemy::recordFileNamesDolpic1": 0x803aeec8,
		"recordFileNamesDolpic1": 0x803aeec8,
		"Enemy::recordFileNamesMonteMan": 0x803aeee8,
		"recordFileNamesMonteMan": 0x803aeee8,
		"TEnemyMario::__vt": 0x803aef24,
		"TMtxCalcFootInv::__vt": 0x803af228,
		"Enemy::rikuGesso_bastable": 0x803af2f0,
		"rikuGesso_bastable": 0x803af2f0,
		"TNerveGessoTurn::__vt": 0x803af364,
		"TNerveGessoLand::__vt": 0x803af374,
		"TNerveGessoFindMario::__vt": 0x803af384,
		"TNerveGessoRolling::__vt": 0x803af394,
		"TNerveGessoFall::__vt": 0x803af3a4,
		"TNerveGessoPollute::__vt": 0x803af3b4,
		"TNerveGessoPunch::__vt": 0x803af3c4,
		"TNerveGessoFreeze::__vt": 0x803af3d4,
		"TNerveGessoStay::__vt": 0x803af3e4,
		"TGessoPolluteObj::__vt": 0x803af3f4,
		"TLandGesso::__vt": 0x803af53c,
		"TSurfGesso::__vt": 0x803af6f4,
		"TGesso::__vt": 0x803af8ac,
		"TGessoManager::__vt": 0x803afa64,
		"TGessoPolluteModel::__vt": 0x803afabc,
		"TGessoPolluteModelManager::__vt": 0x803afae4,
		"Enemy::grDummyRail": 0x803afb48,
		"grDummyRail": 0x803afb48,
		"TGraphWeb::__vt": 0x803afc14,
		"Enemy::hanekuri_bastable": 0x803afc20,
		"hanekuri_bastable": 0x803afc20,
		"Enemy::hamukurianm_bastable": 0x803afc30,
		"hamukurianm_bastable": 0x803afc30,
		"TNerveDoroHanePrepareAttack::__vt": 0x803afce4,
		"TNerveDoroHaneHitWater::__vt": 0x803afcf4,
		"TNerveDoroHaneRise::__vt": 0x803afd04,
		"TNerveFireHamuKuriRecover::__vt": 0x803afd14,
		"TNerveDoroHamuKuriRobCap::__vt": 0x803afd24,
		"TNerveHaneHamuKuriMoveOnGraph::__vt": 0x803afd34,
		"TNerveHaneHamuKuriUpWait::__vt": 0x803afd44,
		"TNerveDangoHamuKuriWait::__vt": 0x803afd54,
		"TNerveHamuKuriJitabata::__vt": 0x803afd64,
		"TNerveHamuKuriLand::__vt": 0x803afd74,
		"TNerveHamuKuriWallDie::__vt": 0x803afd84,
		"TNerveHamuKuriBoundFreeze::__vt": 0x803afd94,
		"TNerveHamuKuriGoForSearchActor::__vt": 0x803afda4,
		"TDoroHamuKuri::__vt": 0x803afdb4,
		"TFireHamuKuri::__vt": 0x803aff7c,
		"TBossDangoHamuKuri::__vt": 0x803b0144,
		"TDangoHamuKuri::__vt": 0x803b030c,
		"THaneHamuKuri2::__vt": 0x803b04d4,
		"TDoroHaneKuri::__vt": 0x803b069c,
		"THaneHamuKuri::__vt": 0x803b0864,
		"THamuKuri::__vt": 0x803b0a2c,
		"TDoroHamuKuriManager::__vt": 0x803b0bf4,
		"TDoroHige::__vt": 0x803b0c4c,
		"TFireHamuKuriManager::__vt": 0x803b0c70,
		"TBossDangoHamuKuriManager::__vt": 0x803b0cc8,
		"TDangoHamuKuriManager::__vt": 0x803b0d20,
		"TDoroHaneKuriManager::__vt": 0x803b0d78,
		"THaneHamuKuriManager::__vt": 0x803b0dd0,
		"THamuKuriManager::__vt": 0x803b0e28,
		"THamuKuriLauncher::__vt": 0x803b0e80,
		"Enemy::hinokuri2_bastable": 0x803b0fe8,
		"hinokuri2_bastable": 0x803b0fe8,
		"TNerveHino2WaitAnm::__vt": 0x803b1058,
		"TNerveHino2Freeze::__vt": 0x803b1134,
		"TNerveHino2Stamp::__vt": 0x803b1144,
		"TNerveHino2Die::__vt": 0x803b1154,
		"TNerveHino2Burst::__vt": 0x803b1164,
		"TNerveHino2Squat::__vt": 0x803b1174,
		"TNerveHino2Damage::__vt": 0x803b1184,
		"TNerveHino2Pollute::__vt": 0x803b1194,
		"TNerveHino2PrePol::__vt": 0x803b11a4,
		"TNerveHino2Turn::__vt": 0x803b11b4,
		"TNerveHino2Landing::__vt": 0x803b11c4,
		"TNerveHino2JumpIn::__vt": 0x803b11d4,
		"TNerveHino2Fly::__vt": 0x803b11e4,
		"TNerveHino2GraphWander::__vt": 0x803b11f4,
		"TNerveHino2Appear::__vt": 0x803b1204,
		"THinokuri2::__vt": 0x803b1214,
		"THino2Hit::__vt": 0x803b1328,
		"THino2MtxCalc::__vt": 0x803b13cc,
		"THinokuri2Manager::__vt": 0x803b1420,
		"Enemy::mameGesso_bastable": 0x803b1478,
		"mameGesso_bastable": 0x803b1478,
		"TNerveMameGessoWait::__vt": 0x803b14c4,
		"TNerveMameGessoObject::__vt": 0x803b14d4,
		"TNerveMameGessoThrown::__vt": 0x803b14e4,
		"TNerveMameGessoPickUp::__vt": 0x803b14f4,
		"TNerveMameGessoTrample::__vt": 0x803b1504,
		"TNerveMameGessoJitabata::__vt": 0x803b1514,
		"TNerveMameGessoDamage::__vt": 0x803b1524,
		"TNerveMameGessoGraphJumpWander::__vt": 0x803b1534,
		"TMameGesso::__vt": 0x803b1544,
		"TMameGessoManager::__vt": 0x803b16fc,
		"Enemy::namekuri2_bastable": 0x803b1758,
		"namekuri2_bastable": 0x803b1758,
		"TNerveNKFollowMario::__vt": 0x803b1790,
		"TDiffusionNameKuri::__vt": 0x803b17b0,
		"TNerveNameKuriDrawPollute::__vt": 0x803b1968,
		"TNerveNameKuriDiffuse::__vt": 0x803b1978,
		"TNerveNameKuriExplosion::__vt": 0x803b1988,
		"TNerveNameKuriJumpAttackPrepare::__vt": 0x803b1998,
		"TNerveNameKuriJumpAttack::__vt": 0x803b19a8,
		"TNerveNameKuriLand::__vt": 0x803b19b8,
		"TDiffusionNameKuriManager::__vt": 0x803b19c8,
		"TNameKuri::__vt": 0x803b1a20,
		"TNameIndParCallback::__vt": 0x803b1bd8,
		"TNameKuriManager::__vt": 0x803b1be8,
		"TNameKuriLauncher::__vt": 0x803b1c40,
		"Enemy::pakkun_bastable": 0x803b1d70,
		"pakkun_bastable": 0x803b1d70,
		"TNerveStayPakkunAppear::__vt": 0x803b1db0,
		"TNerveStayPakkunHide::__vt": 0x803b1dc0,
		"TNervePakkunFreeze::__vt": 0x803b1dd0,
		"TNervePakkunShoot::__vt": 0x803b1de0,
		"TNervePakkunHide::__vt": 0x803b1df0,
		"TNervePakkunAppear::__vt": 0x803b1e00,
		"TNervePakkunStay::__vt": 0x803b1e10,
		"TNervePakkunGenerate::__vt": 0x803b1e20,
		"TStayPakkun::__vt": 0x803b1e30,
		"TPakkunSeed::__vt": 0x803b1fe0,
		"TPakkun::__vt": 0x803b2128,
		"TPakkunManager::__vt": 0x803b22d8,
		"TNerveSmallEnemyChange::__vt": 0x803b2348,
		"TNerveSmallEnemyWait::__vt": 0x803b2358,
		"TNerveSmallEnemyHitWaterJump::__vt": 0x803b2368,
		"TNerveSmallEnemyJump::__vt": 0x803b2378,
		"TNerveSmallEnemyFreeze::__vt": 0x803b2388,
		"TNerveSmallEnemyDie::__vt": 0x803b2398,
		"TSmallEnemy::__vt": 0x803b23a8,
		"TSmallEnemyManager::__vt": 0x803b2550,
		"TSpider::__vt": 0x803b25a8,
		"TNerveTypicalGraphWander::__vt": 0x803b25b8,
		"TTypicalManager::__vt": 0x803b25c8,
		"TTypicalEnemy::__vt": 0x803b261c,
		"TWalker::__vt": 0x803b2730,
		"TSolidStack<TBGCheckData_const*>::__vt": 0x803b2740,
		"TNerveWalkerTraceMario::__vt": 0x803b2750,
		"TNerveWalkerEscape::__vt": 0x803b2760,
		"TNerveWalkerPostAttack::__vt": 0x803b2770,
		"TNerveWalkerAttack::__vt": 0x803b2780,
		"TNerveWalkerGraphWander::__vt": 0x803b2790,
		"TNerveWalkerGenerate::__vt": 0x803b27a0,
		"TWalkerEnemy::__vt": 0x803b27b0,
		"Enemy::bgeso_bastable": 0x803b2968,
		"bgeso_bastable": 0x803b2968,
		"TNerveBGRoll::__vt": 0x803b29d8,
		"TNerveBGPolDrop::__vt": 0x803b2a28,
		"TNerveBGPollute::__vt": 0x803b2a38,
		"TNerveBGDie::__vt": 0x803b2a48,
		"TNerveBGTug::__vt": 0x803b2a58,
		"TNerveBGTentacleDamage::__vt": 0x803b2a68,
		"TNerveBGBeakDamage::__vt": 0x803b2a78,
		"TNerveBGEyeDamage::__vt": 0x803b2a88,
		"TNerveBGWait::__vt": 0x803b2a98,
		"TBossGessoManager::__vt": 0x803b2aa8,
		"TBossGesso::__vt": 0x803b2afc,
		"TBGBinder::__vt": 0x803b2c10,
		"TBossGessoMtxCalc::__vt": 0x803b2c20,
		"TBGBodyHit::__vt": 0x803b2c64,
		"TBGEyeHit::__vt": 0x803b2d08,
		"TBGBeakHit::__vt": 0x803b2dac,
		"Enemy::dennoko_bastable": 0x803b2e60,
		"dennoko_bastable": 0x803b2e60,
		"TNerveElecCarapaceReturn::__vt": 0x803b2ec0,
		"TNerveElecCarapaceWait::__vt": 0x803b2ed0,
		"TNerveElecCarapaceMove::__vt": 0x803b2ee0,
		"TNerveElecNokonokoAttack::__vt": 0x803b2ef0,
		"TNerveElecNokonokoRebirth::__vt": 0x803b2f00,
		"TNerveElecNokonokoFreeze::__vt": 0x803b2f10,
		"TNerveElecNokonokoTurn::__vt": 0x803b2f20,
		"TNerveElecNokonokoCollect::__vt": 0x803b2f30,
		"TNerveElecNokonokoShoot::__vt": 0x803b2f40,
		"TElecCarapace::__vt": 0x803b2f50,
		"TElecNokonoko::__vt": 0x803b3098,
		"TElecNokonokoManager::__vt": 0x803b3254,
		"Enemy::telesa_bastable": 0x803b32b0,
		"telesa_bastable": 0x803b32b0,
		"TNerveKageMarioModokiWait::__vt": 0x803b32fc,
		"TKageMarioModoki::__vt": 0x803b3340,
		"TKageMarioModokiManager::__vt": 0x803b34f8,
		"TNerveTelesaTrample::__vt": 0x803b3550,
		"TNerveTelesaAttackMario::__vt": 0x803b3560,
		"TNerveTelesaFreeze::__vt": 0x803b3570,
		"TNerveTelesaDie::__vt": 0x803b3580,
		"TNerveTelesaImitate::__vt": 0x803b3590,
		"TMarioModokiTelesa::__vt": 0x803b35a0,
		"TBoxTelesa::__vt": 0x803b3758,
		"TLoopTelesa::__vt": 0x803b3910,
		"TSeeTelesa::__vt": 0x803b3ac8,
		"TTelesa::__vt": 0x803b3c80,
		"TTelesaManager::__vt": 0x803b3e38,
		"Enemy::fireWanwan_bastable": 0x803b3e90,
		"fireWanwan_bastable": 0x803b3e90,
		"TNerveFireWanwanEscape::__vt": 0x803b3ec8,
		"TNerveFireWanwanFreeze::__vt": 0x803b3ed8,
		"TNerveFireWanwanFly::__vt": 0x803b3ee8,
		"TNerveFireWanwanHungTail::__vt": 0x803b3ef8,
		"TNerveFireWanwanDie::__vt": 0x803b3f08,
		"TNerveFireWanwanRecover::__vt": 0x803b3f18,
		"TNerveFireWanwanRecoverGraph::__vt": 0x803b3f28,
		"TNerveFireWanwanTired::__vt": 0x803b3f38,
		"TNerveFireWanwanAttack::__vt": 0x803b3f48,
		"TNerveFireWanwanFindMario::__vt": 0x803b3f58,
		"TNerveFireWanwanTurn::__vt": 0x803b3f68,
		"TNerveFireWanwanGraphWander::__vt": 0x803b3f78,
		"TFireWanwan::__vt": 0x803b3f88,
		"TFireWanwanTailHit::__vt": 0x803b4130,
		"TFireWanwanManager::__vt": 0x803b41e4,
		"TStageEnemyInfo::__vt": 0x803b4240,
		"TStageEnemyInfoTable::__vt": 0x803b4260,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::__vt": 0x803b4280,
		"TOneShotGenerator::__vt": 0x803b42a0,
		"TGenerator::__vt": 0x803b4344,
		"Enemy::bosspakkun_bastable": 0x803b4368,
		"bosspakkun_bastable": 0x803b4368,
		"TNerveBPCannonL::__vt": 0x803b43e0,
		"TNerveBPWaitL::__vt": 0x803b43f0,
		"TNerveBPBreakSleep::__vt": 0x803b4400,
		"TNerveBPSleep::__vt": 0x803b4410,
		"TNerveBPFall::__vt": 0x803b4420,
		"TNerveBPHover::__vt": 0x803b4430,
		"TNerveBPFlyPivot::__vt": 0x803b4440,
		"TNerveBPFlyCannon::__vt": 0x803b4450,
		"TNerveBPTouchDown::__vt": 0x803b4460,
		"TNerveBPFly::__vt": 0x803b4470,
		"TNerveBPTakeOff::__vt": 0x803b4480,
		"TNerveBPDie::__vt": 0x803b4490,
		"TNerveBPPreDie::__vt": 0x803b44a0,
		"TNerveBPJumpReact::__vt": 0x803b44b0,
		"TNerveBPStompReact::__vt": 0x803b44c0,
		"TNerveBPSwing::__vt": 0x803b44d0,
		"TNerveBPGetUp::__vt": 0x803b44e0,
		"TNerveBPTumbleOut::__vt": 0x803b44f0,
		"TNerveBPTumble::__vt": 0x803b4500,
		"TNerveBPTumbleIn::__vt": 0x803b4510,
		"TNerveBPSwallow::__vt": 0x803b4520,
		"TNerveBPPivot::__vt": 0x803b4530,
		"TNerveBPTornado::__vt": 0x803b4540,
		"TNerveBPVomit::__vt": 0x803b4550,
		"TNerveBPCannon::__vt": 0x803b4560,
		"TNerveBPWait::__vt": 0x803b4570,
		"TBossPakkunManager::__vt": 0x803b4580,
		"TBossPakkun::__vt": 0x803b45d4,
		"TBossPakkunMtxCalc::__vt": 0x803b46e8,
		"TBPNavel::__vt": 0x803b472c,
		"TBPHeadHit::__vt": 0x803b47d0,
		"TBPTornado::__vt": 0x803b4874,
		"TBPVomit::__vt": 0x803b4918,
		"TBPPolDrop::__vt": 0x803b493c,
		"Enemy::pukupuku_bastable": 0x803b49e0,
		"pukupuku_bastable": 0x803b49e0,
		"Enemy::moepuku_bastable": 0x803b4a0c,
		"moepuku_bastable": 0x803b4a0c,
		"TNerveTobiPukuSwimWander::__vt": 0x803b4a38,
		"TNerveTobiPukuReturnLaunch::__vt": 0x803b4a48,
		"TNerveTobiPukuPrepareFly::__vt": 0x803b4a58,
		"TNerveTobiPukuBound::__vt": 0x803b4a68,
		"TNerveTobiPukuLand::__vt": 0x803b4a78,
		"TNerveTobiPukuDie::__vt": 0x803b4a88,
		"TNerveTobiPukuPitiPiti::__vt": 0x803b4a98,
		"TNerveTobiPukuFall::__vt": 0x803b4aa8,
		"TNerveTobiPukuHitWater::__vt": 0x803b4ab8,
		"TNerveTobiPukuAttack::__vt": 0x803b4ac8,
		"TNerveTobiPukuFly::__vt": 0x803b4ad8,
		"TNerveTobiPukuGenerate::__vt": 0x803b4ae8,
		"TMoePuku::__vt": 0x803b4af8,
		"TPukuPuku::__vt": 0x803b4cf8,
		"TTobiPuku::__vt": 0x803b4ef8,
		"TMoePukuLaunchPad::__vt": 0x803b50f8,
		"TTobiPukuLaunchPad::__vt": 0x803b52a4,
		"TMoePukuManager::__vt": 0x803b5450,
		"TTobiPukuManager::__vt": 0x803b54a8,
		"TMoePukuLaunchPadManager::__vt": 0x803b5500,
		"TTobiPukuLaunchPadManager::__vt": 0x803b5558,
		"Enemy::tinkoopa_bastable": 0x803b55e8,
		"tinkoopa_bastable": 0x803b55e8,
		"Enemy::TTinKoopa_jointNameTable": 0x803b562c,
		"TTinKoopa_jointNameTable": 0x803b562c,
		"Enemy::table$3029": 0x803b5680,
		"table$3029": 0x803b5680,
		"Enemy::table$3036": 0x803b56c8,
		"table$3036": 0x803b56c8,
		"Enemy::breastTrackJointNameTable": 0x803b572c,
		"breastTrackJointNameTable": 0x803b572c,
		"Enemy::bellyTrackJointNameTable": 0x803b5744,
		"bellyTrackJointNameTable": 0x803b5744,
		"Enemy::rightArmTrackJointNameTable": 0x803b575c,
		"rightArmTrackJointNameTable": 0x803b575c,
		"Enemy::leftArmTrackJointNameTable": 0x803b576c,
		"leftArmTrackJointNameTable": 0x803b576c,
		"TNerveTinKoopaBreak::__vt": 0x803b57dc,
		"TNerveTinKoopaDamage::__vt": 0x803b584c,
		"TNerveTinKoopaWait::__vt": 0x803b585c,
		"TTinKoopaManager::__vt": 0x803b586c,
		"TTinKoopaMtxCalc::__vt": 0x803b58c0,
		"TTinKoopaPartsBase::__vt": 0x803b5904,
		"TTinKoopaFlame::__vt": 0x803b5a04,
		"TTinKoopa::__vt": 0x803b5aa8,
		"Enemy::clauncher_bastable": 0x803b5bc0,
		"clauncher_bastable": 0x803b5bc0,
		"TCommonLauncherManager::__vt": 0x803b5bd0,
		"TCommonLauncher::__vt": 0x803b5c24,
		"TLauncherManager::__vt": 0x803b5d50,
		"TLauncher::__vt": 0x803b5da4,
		"Enemy::bwanwan_bastable": 0x803b5f08,
		"bwanwan_bastable": 0x803b5f08,
		"TNerveBWFall::__vt": 0x803b5f24,
		"TNerveBWShake::__vt": 0x803b6084,
		"TNerveBWJumpAway::__vt": 0x803b6094,
		"TNerveBWDie::__vt": 0x803b60a4,
		"TNerveBWJumpToBath::__vt": 0x803b60b4,
		"TNerveBWWakeup::__vt": 0x803b60c4,
		"TNerveBWStun::__vt": 0x803b60d4,
		"TNerveBWJump::__vt": 0x803b60e4,
		"TNerveBWBark::__vt": 0x803b60f4,
		"TNerveBWRoll::__vt": 0x803b6104,
		"TNerveBWGraphWander::__vt": 0x803b6114,
		"TBossWanwanManager::__vt": 0x803b6124,
		"TBossWanwan::__vt": 0x803b6178,
		"TBossWanwanMtxCalc::__vt": 0x803b628c,
		"TBWBinder::__vt": 0x803b62d0,
		"TBWHit::__vt": 0x803b62e0,
		"TBWPicket::__vt": 0x803b6384,
		"TBWLeash::__vt": 0x803b6438,
		"TBWLeashNode::__vt": 0x803b645c,
		"Enemy::tyuhana_bastable": 0x803b6500,
		"tyuhana_bastable": 0x803b6500,
		"TNerveChuuHanaWait::__vt": 0x803b654c,
		"TNerveChuuHanaJumpPrepare::__vt": 0x803b655c,
		"TNerveChuuHanaAttack::__vt": 0x803b656c,
		"TNerveChuuHanaObject::__vt": 0x803b657c,
		"TNerveChuuHanaFall2::__vt": 0x803b658c,
		"TNerveChuuHanaFall::__vt": 0x803b659c,
		"TNerveChuuHanaRoll::__vt": 0x803b65ac,
		"TNerveChuuHanaStick::__vt": 0x803b65bc,
		"TNerveChuuHanaKeepBalance::__vt": 0x803b65cc,
		"TNerveChuuHanaForceJumped::__vt": 0x803b65dc,
		"TNerveChuuHanaWalkOnPanel::__vt": 0x803b65ec,
		"TChuuHana::__vt": 0x803b65fc,
		"TChuuHanaAseParCallback::__vt": 0x803b67b4,
		"TChuuHanaManager::__vt": 0x803b67c4,
		"Enemy::igaiga_bastable": 0x803b6820,
		"igaiga_bastable": 0x803b6820,
		"Enemy::gorogoro_bastable": 0x803b6840,
		"gorogoro_bastable": 0x803b6840,
		"TNerveGorogoroDie::__vt": 0x803b6880,
		"TNerveGorogoroRollOnGraph::__vt": 0x803b6890,
		"TGorogoro::__vt": 0x803b68a0,
		"TGorogoroManager::__vt": 0x803b6a70,
		"TGorogoroPolluteModel::__vt": 0x803b6ac8,
		"TGorogoroPolluteModelManager::__vt": 0x803b6af0,
		"TNerveIgaigaShootFromCannon::__vt": 0x803b6b18,
		"TNerveIgaigaWaterHit::__vt": 0x803b6b28,
		"TNerveIgaigaRollOnGraph::__vt": 0x803b6b38,
		"TIgaiga::__vt": 0x803b6b48,
		"TIgaigaManager::__vt": 0x803b6d18,
		"TIgaigaPolluteModel::__vt": 0x803b6d70,
		"TIgaigaPolluteModelManager::__vt": 0x803b6d98,
		"TRollEnemy::__vt": 0x803b6dc0,
		"Enemy::poihana_bastable": 0x803b6f90,
		"poihana_bastable": 0x803b6f90,
		"TNervePoihanaTrapped::__vt": 0x803b6fc8,
		"TNervePoihanaThrow::__vt": 0x803b6fd8,
		"TNervePoihanaFreeze::__vt": 0x803b6fe8,
		"TNervePoihanaSleep::__vt": 0x803b6ff8,
		"TSleepPoiHana::__vt": 0x803b7008,
		"TPoiHanaRed::__vt": 0x803b71c0,
		"TPoiHana::__vt": 0x803b7378,
		"TPoiHanaCollision::__vt": 0x803b7530,
		"TPoiHanaManager::__vt": 0x803b75d4,
		"Enemy::tamaNoko_bastable": 0x803b7630,
		"tamaNoko_bastable": 0x803b7630,
		"TNerveTamaNokoWait::__vt": 0x803b768c,
		"TNerveTamaNokoHitWater::__vt": 0x803b769c,
		"TNerveTamaNokoSink::__vt": 0x803b76ac,
		"TNerveTamaNokoThrown::__vt": 0x803b76bc,
		"TNerveTamaNokoPickUp::__vt": 0x803b76cc,
		"TNerveTamaNokoDown::__vt": 0x803b76dc,
		"TNerveTamaNokoAttack::__vt": 0x803b76ec,
		"TNerveTamaNokoSleep::__vt": 0x803b76fc,
		"TTamaNoko::__vt": 0x803b770c,
		"TTamaNokoManager::__vt": 0x803b78c4,
		"TTamaNokoFlower::__vt": 0x803b791c,
		"Enemy::btelesa_bastable": 0x803b7940,
		"btelesa_bastable": 0x803b7940,
		"TNerveBossTelesaFallDemo::__vt": 0x803b79d8,
		"TBossTelesaKillSmallEnemy::__vt": 0x803b79e8,
		"TNerveBossTelesaFreeze::__vt": 0x803b7a8c,
		"TNerveBossTelesaPrepareSlot::__vt": 0x803b7a9c,
		"TNerveBossTelesaSpitSlotItem::__vt": 0x803b7aac,
		"TNerveBossTelesaSlotStart::__vt": 0x803b7abc,
		"TNerveBossTelesaAppear::__vt": 0x803b7acc,
		"TNerveBossTelesaHideWait::__vt": 0x803b7adc,
		"TNerveBossTelesaHide::__vt": 0x803b7aec,
		"TNerveBossTelesaSpit::__vt": 0x803b7afc,
		"TNerveBossTelesaDie::__vt": 0x803b7b0c,
		"TBossTelesa::__vt": 0x803b7b1c,
		"TTelesaSlot::__vt": 0x803b7c30,
		"TBossTelesaTongue::__vt": 0x803b7f14,
		"TBossTelesaBody::__vt": 0x803b7fb8,
		"TBossTelesaManager::__vt": 0x803b805c,
		"TNerveBubbleSplit::__vt": 0x803b80b0,
		"TNerveBubbleLive::__vt": 0x803b80c0,
		"TBubble::__vt": 0x803b80d0,
		"TBubbleManager::__vt": 0x803b8288,
		"TNerveRHGraphWander::__vt": 0x803b82e0,
		"TRiccoHookManager::__vt": 0x803b82f0,
		"TRiccoHook::__vt": 0x803b8344,
		"THookTake::__vt": 0x803b8458,
		"Enemy::bombhei_bastable": 0x803b8548,
		"bombhei_bastable": 0x803b8548,
		"TNerveBombHeiExplosion::__vt": 0x803b8588,
		"TNerveBombHeiThrown::__vt": 0x803b85d8,
		"TNerveBombHeiPickUp::__vt": 0x803b85e8,
		"TNerveBombHeiWaitExplosion::__vt": 0x803b85f8,
		"TNerveBombHeiWalkExplosion::__vt": 0x803b8608,
		"TNerveBombHeiAttack::__vt": 0x803b8618,
		"TNerveBombHeiGenerate::__vt": 0x803b8628,
		"TBombHei::__vt": 0x803b8638,
		"TBombHeiManager::__vt": 0x803b87f0,
		"Enemy::cannon_bastable": 0x803b8848,
		"cannon_bastable": 0x803b8848,
		"TNerveCannonObject::__vt": 0x803b88a4,
		"TNerveCannonDamageDemo::__vt": 0x803b88b4,
		"TNerveCannonDamage::__vt": 0x803b88c4,
		"TNerveCannonClose::__vt": 0x803b88d4,
		"TNerveCannonForceBombShoot::__vt": 0x803b88e4,
		"TNerveCannonShoot::__vt": 0x803b88f4,
		"TNerveCannonSearch::__vt": 0x803b8904,
		"TNerveCannonOpen::__vt": 0x803b8914,
		"TCannon::__vt": 0x803b8924,
		"TCannonDom::__vt": 0x803b8ad0,
		"TChorobei::__vt": 0x803b8af4,
		"TCannonManager::__vt": 0x803b8b98,
		"Enemy::bosseel_bastable": 0x803b8c28,
		"bosseel_bastable": 0x803b8c28,
		"Enemy::bossEelTears_bastable": 0x803b8c84,
		"bossEelTears_bastable": 0x803b8c84,
		"TNerveBossEelSleepOnBottom::__vt": 0x803b8d08,
		"TNerveBossEelMouthOpenWait::__vt": 0x803b8d7c,
		"TNerveBossEelDie::__vt": 0x803b8d8c,
		"TNerveBossEelEat::__vt": 0x803b8d9c,
		"TNerveBossEelQuickBack::__vt": 0x803b8dac,
		"TNerveBossEelSlowBack::__vt": 0x803b8dbc,
		"TNerveBossEelOutWait::__vt": 0x803b8dcc,
		"TNerveBossEelAppear::__vt": 0x803b8ddc,
		"TNerveBossEelSecondSpin::__vt": 0x803b8dec,
		"TNerveBossEelFirstSpin::__vt": 0x803b8dfc,
		"TNerveBossEelWaitAppear::__vt": 0x803b8e0c,
		"TBossEel::__vt": 0x803b8e1c,
		"TBossEelTearsRecoverCollision::__vt": 0x803b8f30,
		"TBossEelBarrierCollision::__vt": 0x803b8fdc,
		"TBossEelAwaCollision::__vt": 0x803b9088,
		"TBossEelBodyCollision::__vt": 0x803b9134,
		"TBossEelCollision::__vt": 0x803b91e0,
		"TBossEelHeartCoin::__vt": 0x803b928c,
		"TBossEelEye::__vt": 0x803b92b0,
		"TBossEelVortex::__vt": 0x803b92d4,
		"TBossEelTooth::__vt": 0x803b937c,
		"TBossEelManager::__vt": 0x803b9420,
		"TNerveOilBallStay::__vt": 0x803b9474,
		"TOilBall::__vt": 0x803b9484,
		"TNerveBEelTearsSplit::__vt": 0x803b959c,
		"TNerveBEelTearsMarioRecover::__vt": 0x803b95ac,
		"TNerveBEelTearsWaterHit::__vt": 0x803b95bc,
		"TNerveBEelTearsMoveUp::__vt": 0x803b95cc,
		"TNerveBEelTearsGenerate::__vt": 0x803b95dc,
		"TBEelTears::__vt": 0x803b95ec,
		"TBEelTearsManager::__vt": 0x803b9704,
		"TBEelTearsDrop::__vt": 0x803b9758,
		"TNerveKillerExplosion::__vt": 0x803b9870,
		"TKiller::__vt": 0x803b98c0,
		"TKillerManager::__vt": 0x803b9a84,
		"TNerveFlyEnemyChaseFly::__vt": 0x803b9adc,
		"TNerveFlyEnemyNormalFly::__vt": 0x803b9aec,
		"TFlyEnemy::__vt": 0x803b9afc,
		"TBeamManager::__vt": 0x803b9cc0,
		"Enemy::sambo_bastable": 0x803b9ce8,
		"sambo_bastable": 0x803b9ce8,
		"TNerveSamboHeadHitWall::__vt": 0x803b9dac,
		"TNerveSamboHeadRecoverWater::__vt": 0x803b9dbc,
		"TNerveSamboHeadHitWater::__vt": 0x803b9dcc,
		"TNerveSamboHeadHide::__vt": 0x803b9ddc,
		"TNerveSamboHeadAttack::__vt": 0x803b9dec,
		"TNerveSamboHeadAppear::__vt": 0x803b9dfc,
		"TSamboHead::__vt": 0x803b9e0c,
		"TSamboHeadManager::__vt": 0x803b9fc4,
		"TNerveHanaSamboFreeze::__vt": 0x803ba01c,
		"TNerveHanaSamboDie::__vt": 0x803ba02c,
		"TNerveHanaSamboHide::__vt": 0x803ba03c,
		"TNerveHanaSamboAttack::__vt": 0x803ba04c,
		"TNerveHanaSamboWait::__vt": 0x803ba05c,
		"TNerveHanaSamboAppear::__vt": 0x803ba06c,
		"THanaSambo::__vt": 0x803ba07c,
		"THanaSamboHead::__vt": 0x803ba224,
		"THanaSamboManager::__vt": 0x803ba2c8,
		"TSamboFlower::__vt": 0x803ba320,
		"TSamboFlowerManager::__vt": 0x803ba438,
		"TSamboLeaf::__vt": 0x803ba490,
		"Enemy::popo_bastable": 0x803ba4b8,
		"popo_bastable": 0x803ba4b8,
		"TNervePopoThrown::__vt": 0x803ba4f8,
		"TNervePopoWait::__vt": 0x803ba508,
		"TNervePopoExplosion::__vt": 0x803ba518,
		"TNervePopoFly::__vt": 0x803ba528,
		"TNervePopoAttack::__vt": 0x803ba538,
		"TNervePopoPossessedNozzle::__vt": 0x803ba548,
		"TPopo::__vt": 0x803ba558,
		"TPopoCollision::__vt": 0x803ba710,
		"TPopoManager::__vt": 0x803ba7b4,
		"TNerveSBH_Fall::__vt": 0x803ba810,
		"TNerveSBH_SleepContinue::__vt": 0x803ba820,
		"TSleepBossHanachan::__vt": 0x803ba830,
		"TSleepBossHanachanManager::__vt": 0x803ba944,
		"TDemoBossHanachan::__vt": 0x803ba998,
		"TDemoBossHanachanManager::__vt": 0x803baaac,
		"TNerveFruitsBoatBckTrace::__vt": 0x803bab00,
		"TNerveFruitsBoatGraphWander::__vt": 0x803bab10,
		"TFruitsBoatManager::__vt": 0x803bab20,
		"TFruitsBoat::__vt": 0x803bab74,
		"TWaterHitActor::__vt": 0x803bac88,
		"Enemy::sChangeSaveFileName$2712": 0x803bad30,
		"sChangeSaveFileName$2712": 0x803bad30,
		"Enemy::entry$2725": 0x803bad3c,
		"entry$2725": 0x803bad3c,
		"TBossHanachan::__vt": 0x803bad6c,
		"TBossHanachanManager::__vt": 0x803bae80,
		"TNerveBossHanachanDead::__vt": 0x803baed8,
		"TNerveBossHanachanSnort::__vt": 0x803baee8,
		"TNerveBossHanachanDamage::__vt": 0x803baef8,
		"TNerveBossHanachanGetUp::__vt": 0x803baf08,
		"TNerveBossHanachanDown::__vt": 0x803baf18,
		"TNerveBossHanachanTumble::__vt": 0x803baf28,
		"TNerveBossHanachanGraphWander::__vt": 0x803baf38,
		"TBossHanachanPartsHead::__vt": 0x803baf48,
		"TFootHitActor::__vt": 0x803bb090,
		"TBossHanachanPartsBody::__vt": 0x803bb134,
		"Enemy::amiNoko_bastable": 0x803bb238,
		"amiNoko_bastable": 0x803bb238,
		"TNerveAmiNokoFreeze::__vt": 0x803bb290,
		"TNerveAmiNokoDie::__vt": 0x803bb2a0,
		"TNerveAmiNokoTurn::__vt": 0x803bb2b0,
		"TNerveAmiNokoWalkOnFence::__vt": 0x803bb2c0,
		"TAmiNoko::__vt": 0x803bb2d0,
		"TAmiHit::__vt": 0x803bb488,
		"TAmiNokoManager::__vt": 0x803bb52c,
		"Enemy::gatekeeper_bastable": 0x803bb588,
		"gatekeeper_bastable": 0x803bb588,
		"TNerveBGKLaunchName::__vt": 0x803bb5d8,
		"TBGKObstacle::__vt": 0x803bb5e8,
		"TNerveBGKLaunchGoro::__vt": 0x803bb68c,
		"TNerveBGKDive::__vt": 0x803bb69c,
		"TNerveBGKDie::__vt": 0x803bb6ac,
		"TNerveBGKAwakeDamage::__vt": 0x803bb6bc,
		"TNerveBGKSleepDamage::__vt": 0x803bb6cc,
		"TNerveBGKWait2::__vt": 0x803bb6dc,
		"TNerveBGKWait::__vt": 0x803bb6ec,
		"TNerveBGKAppear::__vt": 0x803bb6fc,
		"TNerveBGKSleep::__vt": 0x803bb70c,
		"TBiancoGateKeeper::__vt": 0x803bb71c,
		"TBGKMtxCalc::__vt": 0x803bb830,
		"TBiancoGateKeeperManager::__vt": 0x803bb874,
		"TGateKeeperBase::__vt": 0x803bb8cc,
		"TGKHitObj::__vt": 0x803bb9e0,
		"TEggGenManager::__vt": 0x803bba88,
		"TEggGenerator::__vt": 0x803bbadc,
		"TNerveSealDie::__vt": 0x803bbbf0,
		"TNerveSealWait::__vt": 0x803bbc00,
		"TNerveSealSleep::__vt": 0x803bbc10,
		"TSealManager::__vt": 0x803bbc20,
		"TSeal::__vt": 0x803bbc74,
		"TBGPolDrop::__vt": 0x803bbd88,
		"Enemy::tstatestr": 0x803bbe60,
		"tstatestr": 0x803bbe60,
		"TBGTentacle::__vt": 0x803bbe9c,
		"TBGAttackHit::__vt": 0x803bc0c0,
		"TBGTakeHit::__vt": 0x803bc164,
		"TBGTentacleMtxCalc::__vt": 0x803bc218,
		"TEffectEnemy::__vt": 0x803bc270,
		"TEffectEnemyManager::__vt": 0x803bc428,
		"Enemy::hauntleg_bastable": 0x803bc480,
		"hauntleg_bastable": 0x803bc480,
		"TNerveHauntLegHaunt::__vt": 0x803bc498,
		"THauntLeg::__vt": 0x803bc4a8,
		"THauntedObject::__vt": 0x803bc660,
		"THauntLegManager::__vt": 0x803bc704,
		"TAreaCylinderManager::__vt": 0x803bc760,
		"TAreaCylinder::__vt": 0x803bc784,
		"TNerveWireTrapGoWait::__vt": 0x803bc7a8,
		"TNerveWireTrapWait::__vt": 0x803bc7e8,
		"TNerveWireTrapSearch::__vt": 0x803bc7f8,
		"TNerveWireTrapOnewayMoveEnd::__vt": 0x803bc808,
		"TNerveWireTrapOnewayMove::__vt": 0x803bc818,
		"TNerveWireTrapOnewayMoveStart::__vt": 0x803bc828,
		"TNerveWireTrapReturnMove::__vt": 0x803bc838,
		"TWireTrapManager::__vt": 0x803bc848,
		"TWireTrap::__vt": 0x803bc89c,
		"Enemy::bosshanachan_bastable": 0x803bc9b0,
		"bosshanachan_bastable": 0x803bc9b0,
		"TBossHanachanPartsBase::__vt": 0x803bca48,
		"Enemy::rocket_bastable": 0x803bcb48,
		"rocket_bastable": 0x803bcb48,
		"TNerveRocketWait::__vt": 0x803bcb70,
		"TNerveRocketFly::__vt": 0x803bcb80,
		"TNerveRocketPossessedNozzle::__vt": 0x803bcb90,
		"TRocket::__vt": 0x803bcba0,
		"TRocketManager::__vt": 0x803bcd48,
		"Enemy::Kazekun_bastable": 0x803bcda0,
		"Kazekun_bastable": 0x803bcda0,
		"TNerveKazekunHitWater::__vt": 0x803bcdb4,
		"TNerveKazekunWait::__vt": 0x803bcdc4,
		"TNerveKazekunDisappear::__vt": 0x803bcdd4,
		"TNerveKazekunAttack::__vt": 0x803bcde4,
		"TNerveKazekunPreAttack::__vt": 0x803bcdf4,
		"TNerveKazekunTurn::__vt": 0x803bce04,
		"TNerveKazekunAppear::__vt": 0x803bce14,
		"TNerveKazekunSearch::__vt": 0x803bce24,
		"TKazekunManager::__vt": 0x803bce34,
		"TKazekun::__vt": 0x803bce8c,
		"TBossManta::sFrameRate": 0x803bd038,
		"sFrameRate": 0x803bd038,
		"TBossManta::sScale": 0x803bd050,
		"sScale": 0x803bd050,
		"Enemy::onetimeFilenames$3261": 0x803bd068,
		"onetimeFilenames$3261": 0x803bd068,
		"Enemy::loopFilenames$3273": 0x803bd07c,
		"loopFilenames$3273": 0x803bd07c,
		"TBossMantaManager::__vt": 0x803bd0a4,
		"TBossMantaAdditionalCollision::__vt": 0x803bd0f8,
		"TBossManta::__vt": 0x803bd19c,
		"TNerveMantaAppearDemo::__vt": 0x803bd2b0,
		"TNerveMantaDeath::__vt": 0x803bd2c0,
		"TNerveMantaSpawn::__vt": 0x803bd2d0,
		"TNerveMantaHitWater::__vt": 0x803bd2e0,
		"TNerveMantaMove::__vt": 0x803bd2f0,
		"TWireBinder::__vt": 0x803bd300,
		"TNerveYumboFreeze::__vt": 0x803bd344,
		"TNerveYumboAttack::__vt": 0x803bd354,
		"TNerveYumboAppearing::__vt": 0x803bd364,
		"TNerveYumboHiding::__vt": 0x803bd374,
		"TNerveYumboDancing::__vt": 0x803bd384,
		"TYumbo::__vt": 0x803bd394,
		"TYumboManager::__vt": 0x803bd53c,
		"TYumboSeed::__vt": 0x803bd594,
		"Enemy::TKoopaJr_jointNameTable": 0x803bd650,
		"TKoopaJr_jointNameTable": 0x803bd650,
		"TKoopaJrSubmarineManager::__vt": 0x803bd664,
		"TNerveKoopaJrSubmarineLaunchKiller::__vt": 0x803bd6b8,
		"TNerveKoopaJrSubmarineCannonOpenClose::__vt": 0x803bd6c8,
		"TNerveKoopaJrSubmarineWait::__vt": 0x803bd6d8,
		"TKoopaJrSubmarine::__vt": 0x803bd6e8,
		"TKoopaJrManager::__vt": 0x803bd7fc,
		"TNerveKoopaJrYahoo::__vt": 0x803bd850,
		"TNerveKoopaJrLaunch::__vt": 0x803bd860,
		"TNerveKoopaJrDemo::__vt": 0x803bd870,
		"TNerveKoopaJrDamage::__vt": 0x803bd880,
		"TNerveKoopaJrWait::__vt": 0x803bd890,
		"TKoopaJr::__vt": 0x803bd8a0,
		"TCallbackHitActor::__vt": 0x803bd9b4,
		"Enemy::kumokun_bastable": 0x803bda58,
		"kumokun_bastable": 0x803bda58,
		"Enemy::kumokun_bas_c_table": 0x803bda8c,
		"kumokun_bas_c_table": 0x803bda8c,
		"TNerveKumokunPreFly::__vt": 0x803bdac0,
		"TSolidStack<char_const*>::__vt": 0x803bdad0,
		"TNerveKumokunFly::__vt": 0x803bdadc,
		"TNerveKumokunPostFreeze::__vt": 0x803bdaec,
		"TNerveKumokunFreeze::__vt": 0x803bdafc,
		"TNerveKumokunWait::__vt": 0x803bdb0c,
		"TNerveKumokunSearch::__vt": 0x803bdb1c,
		"TNerveKumokunPostWalk::__vt": 0x803bdb2c,
		"TNerveKumokunWalk::__vt": 0x803bdb3c,
		"TNerveKumokunPreWalk::__vt": 0x803bdb4c,
		"TKumokunManager::__vt": 0x803bdb5c,
		"TKumokun::__vt": 0x803bdbb4,
		"Enemy::koopa_bastable": 0x803bdd60,
		"koopa_bastable": 0x803bdd60,
		"TKoopaManager::__vt": 0x803bdd9c,
		"TNerveKoopaTurnR::__vt": 0x803bde2c,
		"TNerveKoopaTurnL::__vt": 0x803bde3c,
		"TNerveKoopaTurn::__vt": 0x803bde4c,
		"TKoopa::__vt": 0x803bde5c,
		"TKoopaBody::__vt": 0x803bdf70,
		"TKoopaHead::__vt": 0x803be01c,
		"TKoopaHand::__vt": 0x803be0c8,
		"TKoopaFlame::__vt": 0x803be174,
		"TKoopaParts::__vt": 0x803be220,
		"TNerveKoopaGetDown::__vt": 0x803be2cc,
		"TNerveKoopaGetShowered::__vt": 0x803be2dc,
		"TNerveKoopaStagger::__vt": 0x803be2ec,
		"TNerveKoopaProvoke::__vt": 0x803be2fc,
		"TNerveKoopaFlame::__vt": 0x803be30c,
		"TNerveKoopaFall::__vt": 0x803be31c,
		"TNerveKoopaTumble::__vt": 0x803be32c,
		"TNerveKoopaWait::__vt": 0x803be33c,
		"Enemy::tori_bastable": 0x803be350,
		"tori_bastable": 0x803be350,
		"TNerveKukkuRecoverGraph::__vt": 0x803be368,
		"TNerveKukkuPostFall::__vt": 0x803be378,
		"TNerveKukkuFall::__vt": 0x803be388,
		"TNerveKukkuGraphWander::__vt": 0x803be398,
		"TKukku::__vt": 0x803be3a8,
		"TKukkuManager::__vt": 0x803be550,
		"TKukkuBall::__vt": 0x803be5a8,
		"Enemy::amenbo_bastable": 0x803be650,
		"amenbo_bastable": 0x803be650,
		"TNerveAmenboHitWater::__vt": 0x803be66c,
		"TNerveAmenboWalk::__vt": 0x803be67c,
		"TNerveAmenboPreAttack::__vt": 0x803be68c,
		"TNerveAmenboTurn::__vt": 0x803be69c,
		"TNerveAmenboSearch::__vt": 0x803be6ac,
		"TAmenbo::__vt": 0x803be6bc,
		"TAmenboManager::__vt": 0x803be864,
		"Enemy::bathtubpeach_bastable": 0x803be8c0,
		"bathtubpeach_bastable": 0x803be8c0,
		"TBathtubPeachManager::__vt": 0x803be91c,
		"TNervePeachEscape::__vt": 0x803be970,
		"TNervePeachStagger::__vt": 0x803be980,
		"TBathtubPeach::__vt": 0x803be990,
		"Enemy::bathtubkiller_bastable": 0x803beaa8,
		"bathtubkiller_bastable": 0x803beaa8,
		"TBathtubKillerManager::__vt": 0x803bead8,
		"TNerveBathtubKillerExplosion::__vt": 0x803beb30,
		"TNerveBathtubKillerBreak::__vt": 0x803beb40,
		"TNerveBathtubKillerStraight::__vt": 0x803beb50,
		"TNerveBathtubKillerChaseStraight::__vt": 0x803beb60,
		"TNerveBathtubKillerChase::__vt": 0x803beb70,
		"TNerveBathtubKillerWander::__vt": 0x803beb80,
		"TBathtubKiller::__vt": 0x803beb90,
		"TCoasterKillerManager::__vt": 0x803bed70,
		"TNerveCoasterKillerExplosion::__vt": 0x803bedc8,
		"TCoasterKiller::__vt": 0x803bedd8,
		"TNerveCoasterEnemyWander::__vt": 0x803bef9c,
		"TCoasterEnemy::__vt": 0x803befac,
		"TNerveDebuTelesaWait::__vt": 0x803bf170,
		"TDebuTelesaManager::__vt": 0x803bf180,
		"TDebuTelesa::__vt": 0x803bf1d8,
		"Enemy::tabepuku_bastable": 0x803bf380,
		"tabepuku_bastable": 0x803bf380,
		"TNerveTabePukuDrag::__vt": 0x803bf38c,
		"TNerveTabePukuDive::__vt": 0x803bf39c,
		"TNerveTabePukuBite::__vt": 0x803bf3ac,
		"TNerveTabePukuAttack::__vt": 0x803bf3bc,
		"TNerveTabePukuRecoverGraph::__vt": 0x803bf3cc,
		"TNerveTabePukuFound::__vt": 0x803bf3dc,
		"TNerveTabePukuGraphWander::__vt": 0x803bf3ec,
		"TTabePukuManager::__vt": 0x803bf3fc,
		"TTabePuku::__vt": 0x803bf454,
		"TTPHitActor::__vt": 0x803bf5fc,
		"TBathtubBinder::__vt": 0x803bf6a8,
		"TLimitKoopaManager::__vt": 0x803bf6b8,
		"TNerveLimitKoopaTurn::__vt": 0x803bf70c,
		"TLimitKoopa::__vt": 0x803bf71c,
		"TLimitKoopaBody::__vt": 0x803bf830,
		"TLimitKoopaHead::__vt": 0x803bf930,
		"TLimitKoopaHand::__vt": 0x803bfa30,
		"TLimitKoopaFlame::__vt": 0x803bfb30,
		"TLimitKoopaParts::__vt": 0x803bfc30,
		"TNerveLimitKoopaGetDown::__vt": 0x803bfd30,
		"TNerveLimitKoopaGetShowered::__vt": 0x803bfd40,
		"TNerveLimitKoopaStagger::__vt": 0x803bfd50,
		"TNerveLimitKoopaTumble::__vt": 0x803bfd60,
		"TNerveLimitKoopaWait::__vt": 0x803bfd70,
		"TNerveLimitKoopaHipDropStart::__vt": 0x803bfd80,
		"TNerveLimitKoopaHipDropJump::__vt": 0x803bfd90,
		"TLimitKoopaJrManager::__vt": 0x803bfdb0,
		"TNerveLimitKoopaJrYahoo::__vt": 0x803bfe04,
		"TNerveLimitKoopaJrLaunch::__vt": 0x803bfe14,
		"TNerveLimitKoopaJrWait::__vt": 0x803bfe24,
		"TNerveLimitKoopaJrRun::__vt": 0x803bfe34,
		"TLimitKoopaJr::__vt": 0x803bfe44,
		"CPolarSubCamera::__vt": 0x803acde8,
		"Camera::@1790": 0x803acfc8,
		"Camera::sNoticeActorManagerName": 0x803ad0b0,
		"sNoticeActorManagerName": 0x803ad0b0,
		"CPolarSubCamera::sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803ad0c0,
		"sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803ad0c0,
		"TLensFlare::__vt": 0x803ad108,
		"TLensGlow::__vt": 0x803ad130,
		"TSunMgr::__vt": 0x803ad160,
		"TSunModel::__vt": 0x803ad1a0,
		"TCubeManagerBase::__vt": 0x803ad240,
		"TCameraMapTool::__vt": 0x803ad288,
		"TCubeStreamInfo::__vt": 0x803ad2a8,
		"TCubeCameraInfo::__vt": 0x803ad2c8,
		"TCubeGeneralInfo::__vt": 0x803ad2e8,
		"Camera::sAddBckFileNameTable": 0x803ad308,
		"sAddBckFileNameTable": 0x803ad308,
		"CPolarSubCamera::mCamKindNameSaveFile": 0x803ad318,
		"mCamKindNameSaveFile": 0x803ad318,
		"Camera::@1781": 0x803ad43c,
		"TCameraShake::mCamShakeNameSave": 0x803ad8b0,
		"mCamShakeNameSave": 0x803ad8b0,
		"TBoidLeader::__vt": 0x803ab660,
		"TFishoidManager::__vt": 0x803ab6a8,
		"TFishoid::__vt": 0x803ab7d0,
		"TFish::__vt": 0x803ab8e8,
		"TRealoid::__vt": 0x803ab9a0,
		"TRealoidActor::__vt": 0x803abab8,
		"TAnimalBase::__vt": 0x803abb70,
		"TMewManager::__vt": 0x803abc88,
		"TAnimalManagerBase::__vt": 0x803abcdc,
		"TNerveAnimalGraphWander::__vt": 0x803abd60,
		"Animal::bird_bastable": 0x803abd70,
		"bird_bastable": 0x803abd70,
		"TNerveAnimalBirdLanding::__vt": 0x803abd94,
		"TNerveAnimalBirdPreLanding::__vt": 0x803abda4,
		"TNerveAnimalBirdComeback::__vt": 0x803abdb4,
		"TNerveAnimalBirdChangeToCoin::__vt": 0x803abdc4,
		"TNerveAnimalBirdGraphWander::__vt": 0x803abdd4,
		"TNerveAnimalBirdTakeoff::__vt": 0x803abde4,
		"TNerveAnimalBirdWalkOnGround::__vt": 0x803abdf4,
		"TNerveAnimalBirdActionOnGround::__vt": 0x803abe04,
		"TNerveAnimalBirdWaitOnGround::__vt": 0x803abe14,
		"TAnimalBirdManager::__vt": 0x803abe24,
		"TAnimalBird::__vt": 0x803abe78,
		"TNerveBeeHiveReset::__vt": 0x803abf90,
		"TNerveBeeHiveMarioWaterIn::__vt": 0x803abfa0,
		"TNerveBeeHiveAttack::__vt": 0x803abfb0,
		"TNerveBeeHiveBreak::__vt": 0x803abfc0,
		"TNerveBeeHiveFall::__vt": 0x803abfd0,
		"TNerveBeeHiveWait::__vt": 0x803abfe0,
		"TBeeHiveManager::__vt": 0x803abff0,
		"TBeeHive::__vt": 0x803ac044,
		"TBee::__vt": 0x803ac15c,
		"TButterfloidManager::__vt": 0x803ac218,
		"TButterfloid::__vt": 0x803ac26c,
		"TButterfly::__vt": 0x803ac384,
		"main::gpApplication": 0x803e9700,
		"gpApplication": 0x803e9700,
		"MSound::@2063": 0x803e9bb8,
		"MSound::@3781": 0x803e9bc8,
		"MSound::@3782": 0x803e9bd4,
		"MSound::@3783": 0x803e9be0,
		"MSound::@3784": 0x803e9bec,
		"MSound::@3785": 0x803e9bf8,
		"MSound::@3786": 0x803e9c04,
		"MSound::@3787": 0x803e9c10,
		"MSound::@3788": 0x803e9c1c,
		"MSound::@3789": 0x803e9c28,
		"MSound::@3790": 0x803e9c34,
		"MSound::@3791": 0x803e9c40,
		"MSound::@3792": 0x803e9c4c,
		"MSound::@3793": 0x803e9c58,
		"MSound::@3794": 0x803e9c64,
		"MSound::@3795": 0x803e9c70,
		"MSound::@3200": 0x803eab64,
		"MSound::@3201": 0x803eab70,
		"MSound::@3202": 0x803eab7c,
		"MSound::@3203": 0x803eab88,
		"Camera::@3184": 0x803efcb0,
		"Camera::@3185": 0x803efcbc,
		"Camera::@2275": 0x803efe30,
		"Camera::@2276": 0x803efe3c,
		"Camera::@2277": 0x803efe48,
		"Camera::@2278": 0x803efe54,
		"Camera::@2279": 0x803efe60,
		"Camera::@2280": 0x803efe6c,
		"Camera::@2281": 0x803efe78,
		"Camera::@2282": 0x803efe84,
		"Camera::@2283": 0x803efe90,
		"Enemy::@3173": 0x803efff4,
		"Enemy::@6774": 0x803f01c8,
		"@6774": 0x803f01c8,
		"Enemy::@3231": 0x803f028c,
		"Enemy::@3868": 0x803f040c,
		"@3868": 0x803f040c,
		"Enemy::@8476": 0x803f0448,
		"@8476": 0x803f0448,
		"Enemy::@2575": 0x803f0668,
		"Enemy::@2676": 0x803f068c,
		"Enemy::@2728": 0x803f06b0,
		"Enemy::@2755": 0x803f06bc,
		"Enemy::@4067": 0x803f0740,
		"Enemy::@4068": 0x803f074c,
		"Enemy::@4756": 0x803f07b8,
		"Enemy::@4757": 0x803f07c4,
		"Enemy::@3256": 0x803f0984,
		"Enemy::@2617": 0x803f0a88,
		"Enemy::@2628": 0x803f0a94,
		"Enemy::@9293": 0x803f0bf4,
		"@9293": 0x803f0bf4,
		"Enemy::@9294": 0x803f0c00,
		"@9294": 0x803f0c00,
		"Enemy::@9295": 0x803f0c0c,
		"@9295": 0x803f0c0c,
		"Enemy::@9296": 0x803f0c18,
		"@9296": 0x803f0c18,
		"Enemy::@9297": 0x803f0c24,
		"@9297": 0x803f0c24,
		"Enemy::@9298": 0x803f0c30,
		"@9298": 0x803f0c30,
		"Enemy::@9299": 0x803f0c3c,
		"@9299": 0x803f0c3c,
		"Enemy::@9300": 0x803f0c48,
		"@9300": 0x803f0c48,
		"Enemy::@9301": 0x803f0c54,
		"@9301": 0x803f0c54,
		"Enemy::@9302": 0x803f0c60,
		"@9302": 0x803f0c60,
		"Enemy::@9303": 0x803f0c6c,
		"@9303": 0x803f0c6c,
		"Enemy::@9304": 0x803f0c78,
		"@9304": 0x803f0c78,
		"Enemy::@9305": 0x803f0c84,
		"@9305": 0x803f0c84,
		"Enemy::@9306": 0x803f0c90,
		"@9306": 0x803f0c90,
		"Enemy::@9307": 0x803f0c9c,
		"@9307": 0x803f0c9c,
		"Enemy::@5542": 0x803f0e40,
		"@5542": 0x803f0e40,
		"Enemy::@9741": 0x803f0ff4,
		"@9741": 0x803f0ff4,
		"Enemy::@9742": 0x803f1000,
		"@9742": 0x803f1000,
		"Enemy::up$3221": 0x803f1010,
		"up$3221": 0x803f1010,
		"Enemy::up$3267": 0x803f101c,
		"up$3267": 0x803f101c,
		"Enemy::goal$3320": 0x803f1028,
		"goal$3320": 0x803f1028,
		"Enemy::start$3323": 0x803f1034,
		"start$3323": 0x803f1034,
		"Enemy::goal$3327": 0x803f1040,
		"goal$3327": 0x803f1040,
		"Enemy::start$3330": 0x803f104c,
		"start$3330": 0x803f104c,
		"Enemy::s$3577": 0x803f1058,
		"s$3577": 0x803f1058,
		"Enemy::@3720": 0x803f1094,
		"Enemy::@8446": 0x803f1214,
		"@8446": 0x803f1214,
		"Enemy::@8447": 0x803f1220,
		"@8447": 0x803f1220,
		"Enemy::@8448": 0x803f122c,
		"@8448": 0x803f122c,
		"Enemy::@8449": 0x803f1238,
		"@8449": 0x803f1238,
		"Enemy::@8450": 0x803f1244,
		"@8450": 0x803f1244,
		"Enemy::@3201": 0x803f1700,
		"Enemy::@3222": 0x803f1718,
		"Enemy::@5936": 0x803f1754,
		"Enemy::@5937": 0x803f1760,
		"Enemy::@5938": 0x803f176c,
		"Enemy::@5939": 0x803f1778,
		"Enemy::@5940": 0x803f1784,
		"Enemy::@5941": 0x803f1790,
		"@5941": 0x803f1790,
		"Enemy::@5942": 0x803f179c,
		"@5942": 0x803f179c,
		"Enemy::@5943": 0x803f17a8,
		"@5943": 0x803f17a8,
		"Enemy::@5944": 0x803f17b4,
		"@5944": 0x803f17b4,
		"Enemy::@5945": 0x803f17c0,
		"@5945": 0x803f17c0,
		"Enemy::@5946": 0x803f17cc,
		"@5946": 0x803f17cc,
		"Enemy::@5947": 0x803f17d8,
		"@5947": 0x803f17d8,
		"Enemy::@5948": 0x803f17e4,
		"@5948": 0x803f17e4,
		"Enemy::@5949": 0x803f17f0,
		"@5949": 0x803f17f0,
		"Enemy::@5950": 0x803f17fc,
		"@5950": 0x803f17fc,
		"Enemy::@3164": 0x803f1910,
		"Enemy::@4636": 0x803f19b8,
		"Enemy::@5302": 0x803f1a40,
		"Enemy::@5304": 0x803f1a58,
		"Enemy::@5305": 0x803f1a64,
		"Enemy::@5306": 0x803f1a70,
		"Enemy::@4084": 0x803f1b28,
		"Enemy::@4129": 0x803f1b4c,
		"Enemy::@4196": 0x803f1b70,
		"Enemy::@9251": 0x803f1c30,
		"@9251": 0x803f1c30,
		"Enemy::@3080": 0x803f1d30,
		"Enemy::@3090": 0x803f1d3c,
		"Enemy::@6278": 0x803f1eec,
		"@6278": 0x803f1eec,
		"Enemy::@6279": 0x803f1ef8,
		"@6279": 0x803f1ef8,
		"Enemy::@3227": 0x803f1f2c,
		"Enemy::@3801": 0x803f1f74,
		"Enemy::@3814": 0x803f1f80,
		"Enemy::@9454": 0x803f1fec,
		"@9454": 0x803f1fec,
		"Enemy::@9455": 0x803f1ff8,
		"@9455": 0x803f1ff8,
		"Enemy::@9456": 0x803f2004,
		"@9456": 0x803f2004,
		"Enemy::@9457": 0x803f2010,
		"@9457": 0x803f2010,
		"Enemy::@9458": 0x803f201c,
		"@9458": 0x803f201c,
		"Enemy::@9459": 0x803f2028,
		"@9459": 0x803f2028,
		"Enemy::@9460": 0x803f2034,
		"@9460": 0x803f2034,
		"Enemy::@9461": 0x803f2040,
		"@9461": 0x803f2040,
		"Enemy::@9462": 0x803f204c,
		"@9462": 0x803f204c,
		"Enemy::@2775": 0x803f23f0,
		"Enemy::@3707": 0x803f24b0,
		"Enemy::@3079": 0x803f2768,
		"Enemy::@4585": 0x803f27a4,
		"@4585": 0x803f27a4,
		"Enemy::@4587": 0x803f27bc,
		"@4587": 0x803f27bc,
		"Enemy::@4591": 0x803f27ec,
		"Enemy::@4592": 0x803f27f8,
		"Enemy::@4593": 0x803f2804,
		"Enemy::@4594": 0x803f2810,
		"Enemy::@3418": 0x803f2864,
		"Enemy::@5811": 0x803f28a0,
		"Enemy::@5812": 0x803f28ac,
		"@5812": 0x803f28ac,
		"Enemy::@5813": 0x803f28b8,
		"@5813": 0x803f28b8,
		"Enemy::@5814": 0x803f28c4,
		"@5814": 0x803f28c4,
		"Enemy::@5815": 0x803f28d0,
		"@5815": 0x803f28d0,
		"Enemy::@5816": 0x803f28dc,
		"@5816": 0x803f28dc,
		"Enemy::@5817": 0x803f28e8,
		"@5817": 0x803f28e8,
		"Enemy::@5818": 0x803f28f4,
		"@5818": 0x803f28f4,
		"Enemy::@6694": 0x803f2ba0,
		"@6694": 0x803f2ba0,
		"Enemy::@6695": 0x803f2bac,
		"@6695": 0x803f2bac,
		"Enemy::@6696": 0x803f2bb8,
		"@6696": 0x803f2bb8,
		"Enemy::@6697": 0x803f2bc4,
		"@6697": 0x803f2bc4,
		"Enemy::@2686": 0x803f2de8,
		"Enemy::@2723": 0x803f2e18,
		"Enemy::@4174": 0x803f321c,
		"Enemy::@4175": 0x803f3228,
		"Enemy::@4176": 0x803f3234,
		"Enemy::@4182": 0x803f327c,
		"Enemy::@4183": 0x803f3288,
		"Enemy::@4184": 0x803f3294,
		"Enemy::@4185": 0x803f32a0,
		"Enemy::@3322": 0x803f3314,
		"Enemy::@6243": 0x803f3338,
		"@6243": 0x803f3338,
		"Enemy::@6244": 0x803f3344,
		"@6244": 0x803f3344,
		"Enemy::@6245": 0x803f3350,
		"@6245": 0x803f3350,
		"Enemy::@6250": 0x803f338c,
		"@6250": 0x803f338c,
		"Enemy::@2665": 0x803f33e0,
		"Enemy::@2677": 0x803f33ec,
		"Enemy::@2716": 0x803f3410,
		"Enemy::@2756": 0x803f3434,
		"Enemy::@4852": 0x803f3640,
		"Enemy::@4853": 0x803f364c,
		"Enemy::@2532": 0x803f3670,
		"Enemy::@2544": 0x803f367c,
		"Enemy::@2578": 0x803f36a0,
		"Enemy::@3906": 0x803f3928,
		"@3906": 0x803f3928,
		"Enemy::@3907": 0x803f3934,
		"Enemy::@5494": 0x803f3c38,
		"@5494": 0x803f3c38,
		"Enemy::@5495": 0x803f3c44,
		"@5495": 0x803f3c44,
		"Enemy::@3858": 0x803f3d1c,
		"Enemy::@3859": 0x803f3d28,
		"GC2D::@11921": 0x803f3df0,
		"@11921": 0x803f3df0,
		"GC2D::@11922": 0x803f3dfc,
		"@11922": 0x803f3dfc,
		"GC2D::@11923": 0x803f3e08,
		"@11923": 0x803f3e08,
		"GC2D::@11924": 0x803f3e14,
		"@11924": 0x803f3e14,
		"GC2D::@11925": 0x803f3e20,
		"@11925": 0x803f3e20,
		"GC2D::@11926": 0x803f3e2c,
		"@11926": 0x803f3e2c,
		"GC2D::@11927": 0x803f3e38,
		"@11927": 0x803f3e38,
		"GC2D::@11928": 0x803f3e44,
		"@11928": 0x803f3e44,
		"GC2D::@11929": 0x803f3e50,
		"@11929": 0x803f3e50,
		"GC2D::@11930": 0x803f3e5c,
		"@11930": 0x803f3e5c,
		"GC2D::@11931": 0x803f3e68,
		"@11931": 0x803f3e68,
		"GC2D::@11932": 0x803f3e74,
		"@11932": 0x803f3e74,
		"GC2D::@11933": 0x803f3e80,
		"@11933": 0x803f3e80,
		"GC2D::@11934": 0x803f3e8c,
		"@11934": 0x803f3e8c,
		"GC2D::@11935": 0x803f3e98,
		"@11935": 0x803f3e98,
		"GC2D::@4986": 0x803f3ea8,
		"GC2D::@4987": 0x803f3eb4,
		"GC2D::@4988": 0x803f3ec0,
		"GC2D::@4989": 0x803f3ecc,
		"GC2D::@4990": 0x803f3ed8,
		"GC2D::@4991": 0x803f3ee4,
		"GC2D::@4992": 0x803f3ef0,
		"GC2D::@4993": 0x803f3efc,
		"GC2D::@4994": 0x803f3f08,
		"GC2D::@4995": 0x803f3f14,
		"GC2D::@4996": 0x803f3f20,
		"GC2D::@4997": 0x803f3f2c,
		"GC2D::@4998": 0x803f3f38,
		"GC2D::@4999": 0x803f3f44,
		"GC2D::@5000": 0x803f3f50,
		"GC2D::@7149": 0x803f4018,
		"@7149": 0x803f4018,
		"GC2D::@7150": 0x803f4024,
		"@7150": 0x803f4024,
		"GC2D::@7151": 0x803f4030,
		"@7151": 0x803f4030,
		"GC2D::@7152": 0x803f403c,
		"@7152": 0x803f403c,
		"GC2D::@7153": 0x803f4048,
		"@7153": 0x803f4048,
		"GC2D::@7154": 0x803f4054,
		"@7154": 0x803f4054,
		"GC2D::@7155": 0x803f4060,
		"@7155": 0x803f4060,
		"GC2D::@7156": 0x803f406c,
		"@7156": 0x803f406c,
		"GC2D::@7157": 0x803f4078,
		"@7157": 0x803f4078,
		"GC2D::@7158": 0x803f4084,
		"@7158": 0x803f4084,
		"GC2D::@7159": 0x803f4090,
		"@7159": 0x803f4090,
		"GC2D::@7160": 0x803f409c,
		"GC2D::@7161": 0x803f40a8,
		"GC2D::@7162": 0x803f40b4,
		"@7162": 0x803f40b4,
		"GC2D::@7163": 0x803f40c0,
		"@7163": 0x803f40c0,
		"GC2D::@8418": 0x803f40d0,
		"@8418": 0x803f40d0,
		"GC2D::@8419": 0x803f40dc,
		"@8419": 0x803f40dc,
		"GC2D::@8420": 0x803f40e8,
		"@8420": 0x803f40e8,
		"GC2D::@8421": 0x803f40f4,
		"@8421": 0x803f40f4,
		"GC2D::@8422": 0x803f4100,
		"@8422": 0x803f4100,
		"GC2D::@8423": 0x803f410c,
		"@8423": 0x803f410c,
		"GC2D::@8424": 0x803f4118,
		"@8424": 0x803f4118,
		"GC2D::@8425": 0x803f4124,
		"@8425": 0x803f4124,
		"GC2D::@8426": 0x803f4130,
		"@8426": 0x803f4130,
		"GC2D::@8427": 0x803f413c,
		"@8427": 0x803f413c,
		"GC2D::@8428": 0x803f4148,
		"@8428": 0x803f4148,
		"GC2D::@8429": 0x803f4154,
		"@8429": 0x803f4154,
		"GC2D::@8430": 0x803f4160,
		"@8430": 0x803f4160,
		"GC2D::@8431": 0x803f416c,
		"GC2D::@8432": 0x803f4178,
		"GC2D::@2315": 0x803f77d0,
		"GC2D::@2316": 0x803f77dc,
		"GC2D::@2317": 0x803f77e8,
		"Map::@3827": 0x803f7e80,
		"Map::@3828": 0x803f7e8c,
		"Map::@3829": 0x803f7e98,
		"Map::@3830": 0x803f7ea4,
		"Map::@3831": 0x803f7eb0,
		"Map::@2683": 0x803f8148,
		"Map::@3658": 0x803f81a0,
		"Map::@3659": 0x803f81ac,
		"Map::@3660": 0x803f81b8,
		"Map::@3661": 0x803f81c4,
		"Map::@3662": 0x803f81d0,
		"Map::@3663": 0x803f81dc,
		"Map::@3664": 0x803f81e8,
		"Map::@3665": 0x803f81f4,
		"Map::@3666": 0x803f8200,
		"Map::@3667": 0x803f820c,
		"Map::@3672": 0x803f8248,
		"Map::@2937": 0x803f8370,
		"Map::@2800": 0x803f8818,
		"Map::@2801": 0x803f8824,
		"Map::@2802": 0x803f8830,
		"Map::@2804": 0x803f8848,
		"Map::@2805": 0x803f8854,
		"Map::@3117": 0x803f8e04,
		"Map::@3118": 0x803f8e10,
		"Map::@3119": 0x803f8e1c,
		"Map::@3120": 0x803f8e28,
		"Map::@3121": 0x803f8e34,
		"Map::@3122": 0x803f8e40,
		"MoveBG::@4334": 0x803f92a0,
		"MoveBG::@4339": 0x803f92dc,
		"MoveBG::@4340": 0x803f92e8,
		"MoveBG::@4341": 0x803f92f4,
		"MoveBG::@4342": 0x803f9300,
		"MoveBG::@4926": 0x803f9410,
		"MoveBG::@4927": 0x803f941c,
		"MoveBG::@4928": 0x803f9428,
		"MoveBG::@4929": 0x803f9434,
		"MoveBG::@4930": 0x803f9440,
		"MoveBG::@4931": 0x803f944c,
		"MoveBG::@4932": 0x803f9458,
		"MoveBG::@4933": 0x803f9464,
		"MoveBG::@4934": 0x803f9470,
		"MoveBG::@4935": 0x803f947c,
		"MoveBG::@4936": 0x803f9488,
		"MoveBG::@4937": 0x803f9494,
		"MoveBG::@4938": 0x803f94a0,
		"MoveBG::@4939": 0x803f94ac,
		"MoveBG::@4940": 0x803f94b8,
		"MoveBG::@2756": 0x803f94c8,
		"MoveBG::@2757": 0x803f94d4,
		"MoveBG::@2758": 0x803f94e0,
		"MoveBG::@2759": 0x803f94ec,
		"MoveBG::@2761": 0x803f9504,
		"MoveBG::@2763": 0x803f951c,
		"MoveBG::@2764": 0x803f9528,
		"MoveBG::@2765": 0x803f9534,
		"MoveBG::@2766": 0x803f9540,
		"MoveBG::@5315": 0x803f97a8,
		"MoveBG::@5316": 0x803f97b4,
		"MoveBG::@5317": 0x803f97c0,
		"MoveBG::@5318": 0x803f97cc,
		"MoveBG::@5319": 0x803f97d8,
		"MoveBG::@5320": 0x803f97e4,
		"MoveBG::@5321": 0x803f97f0,
		"MoveBG::@5322": 0x803f97fc,
		"MoveBG::@5323": 0x803f9808,
		"MoveBG::@5324": 0x803f9814,
		"MoveBG::@5325": 0x803f9820,
		"MoveBG::@5326": 0x803f982c,
		"MoveBG::@5327": 0x803f9838,
		"MoveBG::@5328": 0x803f9844,
		"MoveBG::@5329": 0x803f9850,
		"MoveBG::@5446": 0x803f9930,
		"MoveBG::@5447": 0x803f993c,
		"MoveBG::@5448": 0x803f9948,
		"MoveBG::@5449": 0x803f9954,
		"MoveBG::@5450": 0x803f9960,
		"MoveBG::@5451": 0x803f996c,
		"MoveBG::@5452": 0x803f9978,
		"MoveBG::@5453": 0x803f9984,
		"MoveBG::@5454": 0x803f9990,
		"MoveBG::@5455": 0x803f999c,
		"MoveBG::@5456": 0x803f99a8,
		"MoveBG::@5457": 0x803f99b4,
		"MoveBG::@5458": 0x803f99c0,
		"MoveBG::@5459": 0x803f99cc,
		"MoveBG::@5460": 0x803f99d8,
		"MoveBG::@5466": 0x803f9fb0,
		"MoveBG::@5467": 0x803f9fbc,
		"MoveBG::@5468": 0x803f9fc8,
		"MoveBG::@5469": 0x803f9fd4,
		"MoveBG::@5470": 0x803f9fe0,
		"MoveBG::@5471": 0x803f9fec,
		"MoveBG::@5472": 0x803f9ff8,
		"MoveBG::@5473": 0x803fa004,
		"MoveBG::@5474": 0x803fa010,
		"MoveBG::@5475": 0x803fa01c,
		"MoveBG::@5476": 0x803fa028,
		"MoveBG::@5477": 0x803fa034,
		"MoveBG::@4518": 0x803fa700,
		"MoveBG::@4519": 0x803fa70c,
		"MoveBG::@4520": 0x803fa718,
		"MoveBG::@4521": 0x803fa724,
		"MoveBG::@4522": 0x803fa730,
		"MoveBG::@4527": 0x803fa76c,
		"MoveBG::@4528": 0x803fa778,
		"MoveBG::@4529": 0x803fa784,
		"MoveBG::yDown$3084": 0x803fa9e0,
		"yDown$3084": 0x803fa9e0,
		"MoveBG::y$3281": 0x803fa9ec,
		"y$3281": 0x803fa9ec,
		"MoveBG::@6023": 0x803fa9f8,
		"MoveBG::@6024": 0x803faa04,
		"MoveBG::@6025": 0x803faa10,
		"MoveBG::@6026": 0x803faa1c,
		"MoveBG::@6027": 0x803faa28,
		"MoveBG::@6028": 0x803faa34,
		"NPC::@2634": 0x803faf2c,
		"NPC::@2635": 0x803faf38,
		"NPC::@2636": 0x803faf44,
		"NPC::@2637": 0x803faf50,
		"NPC::@2638": 0x803faf5c,
		"NPC::@2639": 0x803faf68,
		"Strategic::@2743": 0x803fb260,
		"Strategic::@2744": 0x803fb26c,
		"Strategic::@2745": 0x803fb278,
		"Strategic::@2746": 0x803fb284,
		"Strategic::@2747": 0x803fb290,
		"Player::@2099": 0x803fb420,
		"Player::@2100": 0x803fb42c,
		"Player::@2101": 0x803fb438,
		"Player::@2102": 0x803fb444,
		"Player::@2103": 0x803fb450,
		"Player::@2104": 0x803fb45c,
		"Player::@2105": 0x803fb468,
		"Player::@2106": 0x803fb474,
		"Player::@2107": 0x803fb480,
		"Player::@2515": 0x803fb590,
		"Player::@2516": 0x803fb59c,
		"Player::@2517": 0x803fb5a8,
		"Player::@3712": 0x803fb648,
		"Player::@3713": 0x803fb654,
		"Player::@3714": 0x803fb660,
		"Player::@3715": 0x803fb66c,
		"Player::@3716": 0x803fb678,
		"Player::@3114": 0x803fb700,
		"Player::@3117": 0x803fb724,
		"Player::@3118": 0x803fb730,
		"Player::@3119": 0x803fb73c,
		"Player::@2769": 0x803fb80c,
		"Player::@2770": 0x803fb818,
		"Player::@2771": 0x803fb824,
		"Player::@4086": 0x803fb878,
		"Player::@4087": 0x803fb884,
		"Player::@4088": 0x803fb890,
		"Player::@4089": 0x803fb89c,
		"Player::@4090": 0x803fb8a8,
		"Player::@4091": 0x803fb8b4,
		"Player::@4092": 0x803fb8c0,
		"Player::@2787": 0x803fb978,
		"Player::@2788": 0x803fb984,
		"Player::@2789": 0x803fb990,
		"Player::@3447": 0x803fb9f4,
		"Player::@3448": 0x803fba00,
		"Player::@3449": 0x803fba0c,
		"Player::@3205": 0x803fbaa0,
		"Player::@3207": 0x803fbab8,
		"Player::@2150": 0x803fbbac,
		"Player::@2151": 0x803fbbb8,
		"Player::scale$2683": 0x803fbc10,
		"scale$2683": 0x803fbc10,
		"Player::scale$2734": 0x803fbc1c,
		"scale$2734": 0x803fbc1c,
		"Player::@3602": 0x803fbc4c,
		"Player::@3603": 0x803fbc58,
		"Player::@3605": 0x803fbc70,
		"Player::@3606": 0x803fbc7c,
		"Player::@3607": 0x803fbc88,
		"Player::@6203": 0x803fbf08,
		"@6203": 0x803fbf08,
		"Player::@6204": 0x803fbf14,
		"@6204": 0x803fbf14,
		"Player::@6205": 0x803fbf20,
		"@6205": 0x803fbf20,
		"Player::@6206": 0x803fbf2c,
		"@6206": 0x803fbf2c,
		"Player::@6207": 0x803fbf38,
		"Player::@6208": 0x803fbf44,
		"@6208": 0x803fbf44,
		"Player::@6209": 0x803fbf50,
		"@6209": 0x803fbf50,
		"Player::@6210": 0x803fbf5c,
		"@6210": 0x803fbf5c,
		"Player::@6211": 0x803fbf68,
		"@6211": 0x803fbf68,
		"Player::@6212": 0x803fbf74,
		"@6212": 0x803fbf74,
		"Player::@6213": 0x803fbf80,
		"@6213": 0x803fbf80,
		"Player::@6214": 0x803fbf8c,
		"@6214": 0x803fbf8c,
		"Player::@6215": 0x803fbf98,
		"@6215": 0x803fbf98,
		"Player::@6216": 0x803fbfa4,
		"@6216": 0x803fbfa4,
		"Player::@6217": 0x803fbfb0,
		"@6217": 0x803fbfb0,
		"Player::@6583": 0x803fc1f4,
		"@6583": 0x803fc1f4,
		"Player::@6584": 0x803fc200,
		"@6584": 0x803fc200,
		"Player::@6585": 0x803fc20c,
		"@6585": 0x803fc20c,
		"Player::@3254": 0x803fc500,
		"Player::@3255": 0x803fc50c,
		"Player::@3256": 0x803fc518,
		"System::@7659": 0x803fc628,
		"System::@7660": 0x803fc634,
		"System::@7661": 0x803fc640,
		"System::@7662": 0x803fc64c,
		"System::@7663": 0x803fc658,
		"System::@7664": 0x803fc664,
		"System::@7665": 0x803fc670,
		"System::@7666": 0x803fc67c,
		"System::@7667": 0x803fc688,
		"System::@7668": 0x803fc694,
		"System::@7669": 0x803fc6a0,
		"System::@7670": 0x803fc6ac,
		"System::@7671": 0x803fc6b8,
		"System::@7672": 0x803fc6c4,
		"System::@7673": 0x803fc6d0,
		"System::@2757": 0x803fc920,
		"System::@2758": 0x803fc92c,
		"System::@2759": 0x803fc938,
		"System::@2760": 0x803fc944,
		"System::@2761": 0x803fc950,
		"System::@2762": 0x803fc95c,
		"System::@2763": 0x803fc968,
		"System::@3425": 0x803fca08,
		"System::@3426": 0x803fca14,
		"System::@3427": 0x803fca20,
		"System::@6129": 0x803fca78,
		"System::@6130": 0x803fca84,
		"System::@6131": 0x803fca90,
		"System::@6132": 0x803fca9c,
		"System::@6133": 0x803fcaa8,
		"System::@6134": 0x803fcab4,
		"System::@6135": 0x803fcac0,
		"System::@6136": 0x803fcacc,
		"System::@6137": 0x803fcad8,
		"System::@2649": 0x803fd2d8,
		"System::@2650": 0x803fd2e4,
		"System::@2651": 0x803fd2f0,
		"System::@2652": 0x803fd2fc,
		"System::@3098": 0x803fd320,
		"System::@3099": 0x803fd32c,
		"System::@3105": 0x803fd374,
		"System::@3106": 0x803fd380,
		"System::@4190": 0x803fd4fc,
		"System::@4191": 0x803fd508,
		"System::@4192": 0x803fd514,
		"@4192": 0x803fd514,
		"System::@4193": 0x803fd520,
		"@4193": 0x803fd520,
		"System::@4194": 0x803fd52c,
		"@4194": 0x803fd52c,
		"System::@4195": 0x803fd538,
		"@4195": 0x803fd538,
		"JSystem::@25": 0x803fd588,
		"JSystem::exCallbackObject": 0x803fd598,
		"exCallbackObject": 0x803fd598,
		"JSystem::@301": 0x803fd5b8,
		"JUTAssertion::@unnamed@::sMessageFileLine": 0x803fd5f8,
		"sMessageFileLine": 0x803fd5f8,
		"JUTAssertion::@unnamed@::sMessageString": 0x803fd638,
		"sMessageString": 0x803fd638,
		"JSystem::@1661": 0x803fd698,
		"JSystem::@1662": 0x803fd6a4,
		"JSystem::@1663": 0x803fd6b0,
		"JSystem::@1664": 0x803fd6bc,
		"JSystem::@1665": 0x803fd6c8,
		"JSystem::@1666": 0x803fd6d4,
		"JSystem::@1667": 0x803fd6e0,
		"JSystem::@1668": 0x803fd6ec,
		"JAInter::StreamLib::finfo": 0x803fd728,
		"finfo": 0x803fd728,
		"JAInter::StreamLib::header": 0x803fd764,
		"header": 0x803fd764,
		"JAInter::StreamLib::Filename": 0x803fd784,
		"Filename": 0x803fd784,
		"JSystem::@557": 0x803fd7f8,
		"@557": 0x803fd7f8,
		"JSystem::osc$294": 0x803fd808,
		"osc$294": 0x803fd808,
		"JSystem::@257": 0x803fd820,
		"@257": 0x803fd820,
		"JASystem::WaveArcLoader::sAramHeap": 0x803fd82c,
		"sAramHeap": 0x803fd82c,
		"JASystem::AudioThread::audioproc_mq": 0x803fd858,
		"audioproc_mq": 0x803fd858,
		"JASystem::AudioThread::msgbuf": 0x803fd878,
		"msgbuf": 0x803fd878,
		"JASystem::DSPBuf::dsp_buf": 0x803fd8b8,
		"dsp_buf": 0x803fd8b8,
		"JASystem::Kernel::dac": 0x803fd8c8,
		"dac": 0x803fd8c8,
		"JASystem::Dvd::mq": 0x803fd8d8,
		"mq": 0x803fd8d8,
		"JSystem::finfo$314": 0x803fd8f8,
		"finfo$314": 0x803fd8f8,
		"JSystem::req$315": 0x803fd934,
		"req$315": 0x803fd934,
		"JSystem::finfo$361": 0x803fd9b4,
		"finfo$361": 0x803fd9b4,
		"JSystem::req$362": 0x803fd9f0,
		"req$362": 0x803fd9f0,
		"JSystem::finfo$369": 0x803fda10,
		"finfo$369": 0x803fda10,
		"JSystem::req$370": 0x803fda4c,
		"req$370": 0x803fda4c,
		"JSystem::finfo$393": 0x803fda6c,
		"finfo$393": 0x803fda6c,
		"JSystem::finfo$422": 0x803fdaa8,
		"finfo$422": 0x803fdaa8,
		"JSystem::finfo$426": 0x803fdae4,
		"finfo$426": 0x803fdae4,
		"JASystem::HardStream::strCtrl": 0x803fdb2c,
		"strCtrl": 0x803fdb2c,
		"JSystem::finfo$425": 0x803fdb7c,
		"finfo$425": 0x803fdb7c,
		"JSystem::get_addr_cmd$429": 0x803fdc30,
		"get_addr_cmd$429": 0x803fdc30,
		"JSystem::stop_cmd$430": 0x803fdf30,
		"stop_cmd$430": 0x803fdf30,
		"JSystem::finish_cmd$431": 0x803fdf60,
		"finish_cmd$431": 0x803fdf60,
		"JSystem::@241": 0x803fdf90,
		"JASystem::Kernel::audioAramHeap": 0x803fdf9c,
		"audioAramHeap": 0x803fdf9c,
		"JASystem::Player::oRandom": 0x803fdfb0,
		"oRandom": 0x803fdfb0,
		"JASystem::TrackMgr::sTrackList": 0x803fe038,
		"sTrackList": 0x803fe038,
		"JSystem::JPAEmitterInfoObj": 0x803fe138,
		"JPAEmitterInfoObj": 0x803fe138,
		"JSystem::@1657": 0x803fe2b8,
		"JSystem::@1658": 0x803fe2c4,
		"JSystem::taskwork": 0x80400340,
		"taskwork": 0x80400340,
		"JSystem::sync_stack": 0x804003c0,
		"sync_stack": 0x804003c0,
		"Runtime.PPCEABI.H::fragmentinfo": 0x804003d0,
		"fragmentinfo": 0x804003d0,
		"MSL_C.PPCEABI.bare.H::atexit_funcs": 0x804003e0,
		"atexit_funcs": 0x804003e0,
		"MSL_C.PPCEABI.bare.H::__atexit_funcs": 0x804004e0,
		"__atexit_funcs": 0x804004e0,
		"TRK_MINNOW_DOLPHIN::gTRKEventQueue": 0x804005e0,
		"gTRKEventQueue": 0x804005e0,
		"TRK_MINNOW_DOLPHIN::gTRKBigEndian": 0x80400608,
		"gTRKBigEndian": 0x80400608,
		"TRK_MINNOW_DOLPHIN::gTRKMsgBufs": 0x80400610,
		"gTRKMsgBufs": 0x80400610,
		"TRK_MINNOW_DOLPHIN::gTRKFramingState": 0x80401fc0,
		"gTRKFramingState": 0x80401fc0,
		"TRK_MINNOW_DOLPHIN::gTRKInputPendingPtr": 0x80401fd4,
		"gTRKInputPendingPtr": 0x80401fd4,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTableSize": 0x80401fd8,
		"gTRKDispatchTableSize": 0x80401fd8,
		"TRK_MINNOW_DOLPHIN::gTRKSaveState": 0x80401fe4,
		"gTRKSaveState": 0x80401fe4,
		"TRK_MINNOW_DOLPHIN::TRKvalue128_temp": 0x80402078,
		"TRKvalue128_temp": 0x80402078,
		"TRK_MINNOW_DOLPHIN::gTRKState": 0x80402088,
		"gTRKState": 0x80402088,
		"TRK_MINNOW_DOLPHIN::lc_base": 0x80402560,
		"lc_base": 0x80402560,
		"TRK_MINNOW_DOLPHIN::TRK_mainError": 0x80402568,
		"TRK_mainError": 0x80402568,
		"os::DriveBlock": 0x804025a0,
		"DriveBlock": 0x804025a0,
		"os::__OSErrorTable": 0x804025d0,
		"__OSErrorTable": 0x804025d0,
		"os::RunQueue": 0x80402698,
		"RunQueue": 0x80402698,
		"dvd::CommandList": 0x80403080,
		"CommandList": 0x80403080,
		"dvd::Prev": 0x80403138,
		"Prev": 0x80403138,
		"dvd::Curr": 0x80403144,
		"Curr": 0x80403144,
		"dvd::DummyCommandBlock": 0x804031e0,
		"DummyCommandBlock": 0x804031e0,
		"dvd::WaitingQueue": 0x80403238,
		"WaitingQueue": 0x80403238,
		"dvd::bb2Buf": 0x80403258,
		"bb2Buf": 0x80403258,
		"dvd::block$16": 0x80403298,
		"block$16": 0x80403298,
		"vi::regs": 0x804032c8,
		"regs": 0x804032c8,
		"vi::shdwRegs": 0x80403340,
		"shdwRegs": 0x80403340,
		"vi::HorVer": 0x804033b8,
		"HorVer": 0x804033b8,
		"pad::Type": 0x80403410,
		"pad::Origin": 0x80403420,
		"Origin": 0x80403420,
		"pad::CmdProbeDevice": 0x80403450,
		"CmdProbeDevice": 0x80403450,
		"card::__CARDDiskNone": 0x80403680,
		"__CARDDiskNone": 0x80403680,
		"gx::gxData": 0x804036a0,
		"gxData": 0x804036a0,
		"gx::FifoObj": 0x80403b98,
		"FifoObj": 0x80403b98,
		"gx::vcd": 0x80403c18,
		"vcd": 0x80403c18,
		"gx::vat": 0x80403cf0,
		"vat": 0x80403cf0,
		"si::TypeCallback": 0x80404000,
		"TypeCallback": 0x80404000,
		"si::RDSTHandler": 0x80404040,
		"RDSTHandler": 0x80404040,
		"si::InputBufferValid": 0x80404050,
		"InputBufferValid": 0x80404050,
		"si::InputBuffer": 0x80404060,
		"InputBuffer": 0x80404060,
		"si::InputBufferVcount": 0x80404080,
		"InputBufferVcount": 0x80404080,
		"si::cmdFixDevice$326": 0x80404090,
		"cmdFixDevice$326": 0x80404090,
		"exi::Ecb": 0x804040a0,
		"Ecb": 0x804040a0,
		"thp::__THPLCWork512": 0x80404260,
		"__THPLCWork512": 0x80404260,
		"thp::__THPLCWork640": 0x8040426c,
		"__THPLCWork640": 0x8040426c,
		"thp::__THPMCUBuffer": 0x80404278,
		"__THPMCUBuffer": 0x80404278,
		"THPPlayer::AudioDecodeThreadStack": 0x803eb0f0,
		"AudioDecodeThreadStack": 0x803eb0f0,
		"THPPlayer::FreeAudioBufferQueue": 0x803ec0f0,
		"FreeAudioBufferQueue": 0x803ec0f0,
		"THPPlayer::DecodedAudioBufferQueue": 0x803ec110,
		"DecodedAudioBufferQueue": 0x803ec110,
		"THPPlayer::FreeAudioBufferMessage": 0x803ec130,
		"FreeAudioBufferMessage": 0x803ec130,
		"THPPlayer::DecodedAudioBufferMessage": 0x803ec13c,
		"DecodedAudioBufferMessage": 0x803ec13c,
		"THPPlayer::PrepareReadyQueue": 0x803ec380,
		"PrepareReadyQueue": 0x803ec380,
		"THPPlayer::UsedTextureSetQueue": 0x803ec3a0,
		"UsedTextureSetQueue": 0x803ec3a0,
		"THPPlayer::UsedTextureSetMessage": 0x803ec3c0,
		"UsedTextureSetMessage": 0x803ec3c0,
		"THPPlayer::FreeReadBufferQueue": 0x803ed560,
		"FreeReadBufferQueue": 0x803ed560,
		"THPPlayer::ReadedBufferQueue": 0x803ed580,
		"ReadedBufferQueue": 0x803ed580,
		"THPPlayer::ReadedBufferQueue2": 0x803ed5a0,
		"ReadedBufferQueue2": 0x803ed5a0,
		"THPPlayer::FreeReadBufferMessage": 0x803ed5c0,
		"FreeReadBufferMessage": 0x803ed5c0,
		"THPPlayer::ReadedBufferMessage": 0x803ed5e8,
		"ReadedBufferMessage": 0x803ed5e8,
		"THPPlayer::ReadedBufferMessage2": 0x803ed610,
		"ReadedBufferMessage2": 0x803ed610,
		"THPPlayer::ReadThreadStack": 0x803ed948,
		"ReadThreadStack": 0x803ed948,
		"THPPlayer::VideoDecodeThreadStack": 0x803eec58,
		"VideoDecodeThreadStack": 0x803eec58,
		"THPPlayer::FreeTextureSetQueue": 0x803efc58,
		"FreeTextureSetQueue": 0x803efc58,
		"THPPlayer::DecodedTextureSetQueue": 0x803efc78,
		"DecodedTextureSetQueue": 0x803efc78,
		"THPPlayer::FreeTextureSetMessage": 0x803efc98,
		"FreeTextureSetMessage": 0x803efc98,
		"THPPlayer::DecodedTextureSetMessage": 0x803efca4,
		"DecodedTextureSetMessage": 0x803efca4,
		"MarioUtil::sViewPlane": 0x803fb2a0,
		"sViewPlane": 0x803fb2a0,
		"MarioUtil::@2174": 0x803fb300,
		"MarioUtil::setup1$2173": 0x803fb30c,
		"setup1$2173": 0x803fb30c,
		"MarioUtil::@2178": 0x803fb330,
		"MarioUtil::cylinder$2177": 0x803fb33c,
		"cylinder$2177": 0x803fb33c,
		"MarioUtil::@2192": 0x803fb360,
		"MarioUtil::setup2$2191": 0x803fb36c,
		"setup2$2191": 0x803fb36c,
		"MarioUtil::@2197": 0x803fb390,
		"MarioUtil::setup3$2196": 0x803fb39c,
		"setup3$2196": 0x803fb39c,
		"MarioUtil::@2209": 0x803fb3c0,
		"MarioUtil::setup4$2208": 0x803fb3cc,
		"setup4$2208": 0x803fb3cc,
		"MarioUtil::@2218": 0x803fb3f0,
		"MarioUtil::setup5$2217": 0x803fb3fc,
		"setup5$2217": 0x803fb3fc,
		"System::@2705": 0x803fc6e0,
		"System::@2706": 0x803fc6ec,
		"System::@2707": 0x803fc6f8,
		"System::@2708": 0x803fc704,
		"System::@2709": 0x803fc710,
		"System::@2710": 0x803fc71c,
		"System::@2711": 0x803fc728,
		"System::@2712": 0x803fc734,
		"System::@2713": 0x803fc740,
		"System::@2714": 0x803fc74c,
		"System::@2715": 0x803fc758,
		"System::@2716": 0x803fc764,
		"System::@2717": 0x803fc770,
		"System::@2718": 0x803fc77c,
		"System::@2719": 0x803fc788,
		"System::@2272": 0x803fc7bc,
		"System::@2273": 0x803fc7c8,
		"System::@2274": 0x803fc7d4,
		"System::@2275": 0x803fc7e0,
		"System::@2276": 0x803fc7ec,
		"System::@2277": 0x803fc7f8,
		"System::@2278": 0x803fc804,
		"System::@2279": 0x803fc810,
		"System::@2280": 0x803fc81c,
		"System::@2281": 0x803fc828,
		"System::@2282": 0x803fc834,
		"System::@2283": 0x803fc840,
		"System::@2764": 0x803fc974,
		"System::@2765": 0x803fc980,
		"System::@2766": 0x803fc98c,
		"System::@2767": 0x803fc998,
		"System::@2768": 0x803fc9a4,
		"System::@2769": 0x803fc9b0,
		"System::@3428": 0x803fca2c,
		"System::@3431": 0x803fca50,
		"System::@6138": 0x803fcae4,
		"System::@6139": 0x803fcaf0,
		"System::@6140": 0x803fcafc,
		"System::@6141": 0x803fcb08,
		"@6141": 0x803fcb08,
		"System::@6142": 0x803fcb14,
		"@6142": 0x803fcb14,
		"System::@6143": 0x803fcb20,
		"@6143": 0x803fcb20,
		"System::gParticleFlagLoaded": 0x803fd068,
		"gParticleFlagLoaded": 0x803fd068,
		"System::@2640": 0x803fd26c,
		"System::@2643": 0x803fd290,
		"System::@2644": 0x803fd29c,
		"System::@2645": 0x803fd2a8,
		"System::@2646": 0x803fd2b4,
		"System::@2647": 0x803fd2c0,
		"System::@2648": 0x803fd2cc,
		"Strategic::@3355": 0x803fb130,
		"Strategic::@3356": 0x803fb13c,
		"Strategic::@3357": 0x803fb148,
		"Strategic::@3358": 0x803fb154,
		"Strategic::@3359": 0x803fb160,
		"Strategic::@3364": 0x803fb19c,
		"Strategic::@3365": 0x803fb1a8,
		"Strategic::@3366": 0x803fb1b4,
		"Strategic::@3367": 0x803fb1c0,
		"Strategic::@3368": 0x803fb1cc,
		"Strategic::@3369": 0x803fb1d8,
		"Strategic::@2737": 0x803fb218,
		"Strategic::@2738": 0x803fb224,
		"Strategic::@2739": 0x803fb230,
		"Strategic::@2740": 0x803fb23c,
		"Strategic::@2741": 0x803fb248,
		"Strategic::@2742": 0x803fb254,
		"Player::@2108": 0x803fb48c,
		"Player::@2109": 0x803fb498,
		"Player::@2112": 0x803fb4bc,
		"Player::@2113": 0x803fb4c8,
		"Player::@2524": 0x803fb5fc,
		"Player::@2525": 0x803fb608,
		"Player::@2526": 0x803fb614,
		"Player::@2527": 0x803fb620,
		"Player::@2528": 0x803fb62c,
		"Player::@3120": 0x803fb748,
		"Player::@3121": 0x803fb754,
		"Player::@3122": 0x803fb760,
		"Player::@3123": 0x803fb76c,
		"Player::@3126": 0x803fb790,
		"Player::@3127": 0x803fb79c,
		"Player::@3128": 0x803fb7a8,
		"Player::@2772": 0x803fb830,
		"Player::@2773": 0x803fb83c,
		"Player::@2774": 0x803fb848,
		"Player::@2775": 0x803fb854,
		"Player::@2776": 0x803fb860,
		"Player::@2777": 0x803fb86c,
		"Player::@2790": 0x803fb99c,
		"Player::@2791": 0x803fb9a8,
		"Player::@2792": 0x803fb9b4,
		"Player::@2793": 0x803fb9c0,
		"Player::@3455": 0x803fba54,
		"Player::@3608": 0x803fbc94,
		"Player::@6586": 0x803fc218,
		"@6586": 0x803fc218,
		"Player::@6587": 0x803fc224,
		"@6587": 0x803fc224,
		"Player::@6588": 0x803fc230,
		"@6588": 0x803fc230,
		"Player::@6589": 0x803fc23c,
		"Player::@6590": 0x803fc248,
		"@6590": 0x803fc248,
		"Player::@6591": 0x803fc254,
		"@6591": 0x803fc254,
		"Player::@6592": 0x803fc260,
		"@6592": 0x803fc260,
		"Player::@6593": 0x803fc26c,
		"@6593": 0x803fc26c,
		"Player::@6594": 0x803fc278,
		"@6594": 0x803fc278,
		"Player::@6595": 0x803fc284,
		"@6595": 0x803fc284,
		"Player::@6596": 0x803fc290,
		"@6596": 0x803fc290,
		"Player::@6597": 0x803fc29c,
		"@6597": 0x803fc29c,
		"Player::@2664": 0x803fc2a8,
		"TModelWaterManager::mStaticHitActor": 0x803fc2b4,
		"mStaticHitActor": 0x803fc2b4,
		"Player::wcheck$2854": 0x803fc320,
		"wcheck$2854": 0x803fc320,
		"Player::@4749": 0x803fc34c,
		"Player::@4750": 0x803fc358,
		"Player::@4751": 0x803fc364,
		"Player::@4752": 0x803fc370,
		"Player::@4753": 0x803fc37c,
		"Player::@4754": 0x803fc388,
		"Player::@4755": 0x803fc394,
		"Player::@4756": 0x803fc3a0,
		"Player::@4757": 0x803fc3ac,
		"Player::@4758": 0x803fc3b8,
		"Player::@4759": 0x803fc3c4,
		"Player::@4760": 0x803fc3d0,
		"Player::@4761": 0x803fc3dc,
		"Player::@4762": 0x803fc3e8,
		"Player::@4763": 0x803fc3f4,
		"NPC::@2936": 0x803facd8,
		"NPC::@2937": 0x803face4,
		"NPC::@2938": 0x803facf0,
		"NPC::@2939": 0x803facfc,
		"NPC::@2940": 0x803fad08,
		"NPC::@2941": 0x803fad14,
		"NPC::@2942": 0x803fad20,
		"NPC::@2943": 0x803fad2c,
		"NPC::@2944": 0x803fad38,
		"NPC::@2945": 0x803fad44,
		"NPC::@2946": 0x803fad50,
		"NPC::@2947": 0x803fad5c,
		"NPC::@2948": 0x803fad68,
		"NPC::@2949": 0x803fad74,
		"NPC::@2950": 0x803fad80,
		"NPC::@4339": 0x803fad90,
		"NPC::@4340": 0x803fad9c,
		"NPC::@4341": 0x803fada8,
		"NPC::@4342": 0x803fadb4,
		"NPC::@4343": 0x803fadc0,
		"NPC::@4344": 0x803fadcc,
		"NPC::@4345": 0x803fadd8,
		"NPC::@4346": 0x803fade4,
		"NPC::@4347": 0x803fadf0,
		"NPC::@4348": 0x803fadfc,
		"NPC::@4349": 0x803fae08,
		"NPC::@4350": 0x803fae14,
		"NPC::@4351": 0x803fae20,
		"NPC::@4352": 0x803fae2c,
		"NPC::@4353": 0x803fae38,
		"NPC::@2244": 0x803fae54,
		"NPC::@2252": 0x803fae60,
		"NPC::@2265": 0x803fae6c,
		"NPC::@2304": 0x803fae84,
		"NPC::@2405": 0x803faed8,
		"NPC::@2415": 0x803faee4,
		"NPC::@2437": 0x803faefc,
		"NPC::@2640": 0x803faf74,
		"NPC::@2641": 0x803faf80,
		"NPC::@2642": 0x803faf8c,
		"NPC::@2643": 0x803faf98,
		"NPC::@2644": 0x803fafa4,
		"NPC::@2645": 0x803fafb0,
		"NPC::@3044": 0x803fafc0,
		"NPC::@3045": 0x803fafcc,
		"NPC::@3046": 0x803fafd8,
		"NPC::@3047": 0x803fafe4,
		"NPC::@3048": 0x803faff0,
		"NPC::@3049": 0x803faffc,
		"NPC::@3050": 0x803fb008,
		"NPC::@3051": 0x803fb014,
		"NPC::@3052": 0x803fb020,
		"NPC::@3053": 0x803fb02c,
		"NPC::@3054": 0x803fb038,
		"NPC::@3055": 0x803fb044,
		"NPC::@3056": 0x803fb050,
		"NPC::@3057": 0x803fb05c,
		"NPC::@3058": 0x803fb068,
		"NPC::@2377": 0x803fb078,
		"NPC::@2378": 0x803fb084,
		"NPC::@2379": 0x803fb090,
		"NPC::@2380": 0x803fb09c,
		"NPC::@2381": 0x803fb0a8,
		"NPC::@2382": 0x803fb0b4,
		"NPC::@2383": 0x803fb0c0,
		"NPC::@2384": 0x803fb0cc,
		"NPC::@2386": 0x803fb0e4,
		"NPC::@2387": 0x803fb0f0,
		"NPC::@2388": 0x803fb0fc,
		"NPC::@2389": 0x803fb108,
		"NPC::@2390": 0x803fb114,
		"MSBgm::smBgmInTrack": 0x803e9c80,
		"smBgmInTrack": 0x803e9c80,
		"MSound::@1961": 0x803e9db8,
		"MSound::@1962": 0x803e9dc4,
		"MSound::@1963": 0x803e9dd0,
		"MSound::@1964": 0x803e9ddc,
		"MSound::@1965": 0x803e9de8,
		"MSound::_posByCamera": 0x803e9df8,
		"_posByCamera": 0x803e9df8,
		"MSound::@1969": 0x803eaab0,
		"MSoundSESystem::MSRandVol::smList": 0x803eaabc,
		"MSoundSESystem::MSRandPlay::smList": 0x803eaad4,
		"MSound::@3189": 0x803eaae0,
		"MSound::@3190": 0x803eaaec,
		"MSound::@3191": 0x803eaaf8,
		"MSound::@3192": 0x803eab04,
		"MSound::@3193": 0x803eab10,
		"MSound::@3194": 0x803eab1c,
		"MSound::@3195": 0x803eab28,
		"MSound::@3196": 0x803eab34,
		"MSound::@3197": 0x803eab40,
		"MSound::@3198": 0x803eab4c,
		"MSound::@3199": 0x803eab58,
		"MSSetSound::smSetSound": 0x803eab98,
		"smSetSound": 0x803eab98,
		"MSound::@1932": 0x803eabbc,
		"MSound::@1933": 0x803eabc8,
		"MSound::@1934": 0x803eabd4,
		"MSound::@1935": 0x803eabe0,
		"MSound::@1936": 0x803eabec,
		"MSound::@1937": 0x803eabf8,
		"MSound::@1938": 0x803eac04,
		"MSound::@1939": 0x803eac10,
		"MSound::@1940": 0x803eac1c,
		"MSound::@1941": 0x803eac28,
		"MSound::@1942": 0x803eac34,
		"MSound::@1943": 0x803eac40,
		"MSound::@1944": 0x803eac4c,
		"MSound::@2082": 0x803eac70,
		"MSound::@2083": 0x803eac7c,
		"MSound::@2084": 0x803eac88,
		"MSound::@2085": 0x803eac94,
		"MSound::@2086": 0x803eaca0,
		"MSound::@2087": 0x803eacac,
		"MSound::@2088": 0x803eacb8,
		"MSound::@2089": 0x803eacc4,
		"MSound::@2090": 0x803eacd0,
		"MSound::@2091": 0x803eacdc,
		"MSound::@2092": 0x803eace8,
		"MSound::@2093": 0x803eacf4,
		"MSound::@2094": 0x803ead00,
		"MSound::@2095": 0x803ead0c,
		"MSound::@2096": 0x803ead18,
		"MSound::@1947": 0x803ead40,
		"MSound::@1948": 0x803ead4c,
		"MSound::@1949": 0x803ead58,
		"MSound::@1950": 0x803ead64,
		"MoveBG::@4343": 0x803f930c,
		"MoveBG::@4344": 0x803f9318,
		"MoveBG::@4345": 0x803f9324,
		"MoveBG::@4346": 0x803f9330,
		"MoveBG::@4347": 0x803f933c,
		"MoveBG::@4348": 0x803f9348,
		"MoveBG::@4274": 0x803f9358,
		"MoveBG::@4278": 0x803f9388,
		"MoveBG::@4279": 0x803f9394,
		"MoveBG::@4280": 0x803f93a0,
		"MoveBG::@4281": 0x803f93ac,
		"MoveBG::@4282": 0x803f93b8,
		"MoveBG::@4286": 0x803f93e8,
		"MoveBG::submarineCranePos_forSound": 0x803f9860,
		"submarineCranePos_forSound": 0x803f9860,
		"MoveBG::submarineSetWtPos_forSound": 0x803f986c,
		"submarineSetWtPos_forSound": 0x803f986c,
		"MoveBG::@3531": 0x803f9890,
		"MoveBG::@3532": 0x803f989c,
		"MoveBG::@3533": 0x803f98a8,
		"MoveBG::@3534": 0x803f98b4,
		"MoveBG::@3535": 0x803f98c0,
		"MoveBG::@3540": 0x803f98fc,
		"MoveBG::@3541": 0x803f9908,
		"MoveBG::@3542": 0x803f9914,
		"MoveBG::@4379": 0x803f99e8,
		"MoveBG::@4380": 0x803f99f4,
		"MoveBG::@4381": 0x803f9a00,
		"@4381": 0x803f9a00,
		"MoveBG::@4382": 0x803f9a0c,
		"@4382": 0x803f9a0c,
		"MoveBG::@4383": 0x803f9a18,
		"@4383": 0x803f9a18,
		"MoveBG::@4384": 0x803f9a24,
		"@4384": 0x803f9a24,
		"MoveBG::@4390": 0x803f9a6c,
		"MoveBG::@2483": 0x803f9aa0,
		"MoveBG::@2484": 0x803f9aac,
		"MoveBG::@2485": 0x803f9ab8,
		"MoveBG::fall_upper_pos": 0x803f9b58,
		"fall_upper_pos": 0x803f9b58,
		"MoveBG::@4408": 0x803f9c0c,
		"MoveBG::@2557": 0x803f9d88,
		"MoveBG::@2558": 0x803f9d94,
		"MoveBG::@2562": 0x803f9dc4,
		"MoveBG::@2563": 0x803f9dd0,
		"MoveBG::@2564": 0x803f9ddc,
		"MoveBG::@2565": 0x803f9de8,
		"MoveBG::@2566": 0x803f9df4,
		"MoveBG::@2567": 0x803f9e00,
		"MoveBG::@5478": 0x803fa040,
		"MoveBG::@5479": 0x803fa04c,
		"MoveBG::@5480": 0x803fa058,
		"MoveBG::up$2645": 0x803fa120,
		"up$2645": 0x803fa120,
		"MoveBG::up$2710": 0x803fa12c,
		"up$2710": 0x803fa12c,
		"MoveBG::@2741": 0x803fa220,
		"MoveBG::@2743": 0x803fa238,
		"MoveBG::@2745": 0x803fa250,
		"MoveBG::@2746": 0x803fa25c,
		"MoveBG::@2747": 0x803fa268,
		"MoveBG::@2751": 0x803fa298,
		"TMapObjGrassManager::mDrawVec": 0x803fa2a8,
		"mDrawVec": 0x803fa2a8,
		"MoveBG::@2728": 0x803fa2cc,
		"MoveBG::@2729": 0x803fa2d8,
		"MoveBG::@2731": 0x803fa2f0,
		"MoveBG::@2732": 0x803fa2fc,
		"MoveBG::@2736": 0x803fa32c,
		"MoveBG::@2311": 0x803fa368,
		"MoveBG::@2312": 0x803fa374,
		"MoveBG::@2313": 0x803fa380,
		"MoveBG::@2314": 0x803fa38c,
		"MoveBG::@2315": 0x803fa398,
		"MoveBG::@2316": 0x803fa3a4,
		"MoveBG::@2317": 0x803fa3b0,
		"MoveBG::@2318": 0x803fa3bc,
		"@2318": 0x803fa3bc,
		"MoveBG::@2319": 0x803fa3c8,
		"MoveBG::@2320": 0x803fa3d4,
		"MoveBG::@2321": 0x803fa3e0,
		"MoveBG::@2322": 0x803fa3ec,
		"MoveBG::@2323": 0x803fa3f8,
		"MoveBG::@2324": 0x803fa404,
		"MoveBG::@2325": 0x803fa410,
		"MoveBG::@3437": 0x803fa580,
		"MoveBG::@6029": 0x803faa40,
		"MoveBG::@6030": 0x803faa4c,
		"MoveBG::@6031": 0x803faa58,
		"MoveBG::@6032": 0x803faa64,
		"MoveBG::@6033": 0x803faa70,
		"MoveBG::@6034": 0x803faa7c,
		"MoveBG::@6035": 0x803faa88,
		"MoveBG::@6036": 0x803faa94,
		"MoveBG::@6037": 0x803faaa0,
		"Map::@2345": 0x803f78a0,
		"Map::@2417": 0x803f7940,
		"Map::@2418": 0x803f794c,
		"Map::@2419": 0x803f7958,
		"Map::@2519": 0x803f7968,
		"Map::@2520": 0x803f7974,
		"Map::@2522": 0x803f798c,
		"Map::@2524": 0x803f79a4,
		"Map::@2525": 0x803f79b0,
		"Map::@2526": 0x803f79bc,
		"Map::@2527": 0x803f79c8,
		"Map::pos$2895": 0x803f7a20,
		"pos$2895": 0x803f7a20,
		"Map::@2534": 0x803f7b10,
		"Map::@2535": 0x803f7b1c,
		"Map::@2536": 0x803f7b28,
		"Map::@2540": 0x803f7b58,
		"Map::@2541": 0x803f7b64,
		"Map::@2542": 0x803f7b70,
		"Map::@2543": 0x803f7b7c,
		"Map::@2544": 0x803f7b88,
		"TMapCollisionData::mIllegalCheckData": 0x803f7b98,
		"mIllegalCheckData": 0x803f7b98,
		"Map::@2159": 0x803f7be0,
		"Map::@2160": 0x803f7bec,
		"Map::@2161": 0x803f7bf8,
		"Map::@2162": 0x803f7c04,
		"Map::@2163": 0x803f7c10,
		"Map::@2164": 0x803f7c1c,
		"Map::@2165": 0x803f7c28,
		"Map::@2166": 0x803f7c34,
		"Map::@2171": 0x803f7c70,
		"Map::@2172": 0x803f7c7c,
		"Map::@2173": 0x803f7c88,
		"Map::@2402": 0x803f7c98,
		"Map::@2403": 0x803f7ca4,
		"Map::@2404": 0x803f7cb0,
		"Map::@2701": 0x803f7d5c,
		"Map::@2702": 0x803f7d68,
		"Map::@2708": 0x803f7db0,
		"Map::@2709": 0x803f7dbc,
		"Map::@2710": 0x803f7dc8,
		"Map::@2712": 0x803f7de0,
		"Map::@2713": 0x803f7dec,
		"Map::@2749": 0x803f7efc,
		"Map::@2750": 0x803f7f08,
		"Map::@2751": 0x803f7f14,
		"Map::@2752": 0x803f7f20,
		"Map::@2753": 0x803f7f2c,
		"Map::@2754": 0x803f7f38,
		"Map::@2755": 0x803f7f44,
		"Map::@2756": 0x803f7f50,
		"Map::@2757": 0x803f7f5c,
		"Map::@2758": 0x803f7f68,
		"Map::@3295": 0x803f7f90,
		"Map::@3296": 0x803f7f9c,
		"Map::@3297": 0x803f7fa8,
		"Map::@3298": 0x803f7fb4,
		"Map::@3299": 0x803f7fc0,
		"Map::@3300": 0x803f7fcc,
		"Map::@3301": 0x803f7fd8,
		"Map::@3302": 0x803f7fe4,
		"Map::@3303": 0x803f7ff0,
		"Map::@3304": 0x803f7ffc,
		"Map::@3305": 0x803f8008,
		"Map::@2668": 0x803f8030,
		"Map::@2669": 0x803f803c,
		"Map::@2671": 0x803f8054,
		"Map::@2672": 0x803f8060,
		"Map::@2673": 0x803f806c,
		"Map::@2684": 0x803f8154,
		"Map::@2688": 0x803f8184,
		"Map::@2689": 0x803f8190,
		"Map::@2358": 0x803f8258,
		"Map::@2359": 0x803f8264,
		"Map::@2360": 0x803f8270,
		"Map::@2361": 0x803f827c,
		"Map::@2362": 0x803f8288,
		"Map::@2363": 0x803f8294,
		"Map::@2365": 0x803f82ac,
		"Map::@2366": 0x803f82b8,
		"Map::@2367": 0x803f82c4,
		"Map::@2369": 0x803f82dc,
		"Map::@2370": 0x803f82e8,
		"Map::@2371": 0x803f82f4,
		"Map::@2372": 0x803f8300,
		"Map::@2938": 0x803f837c,
		"Map::@2939": 0x803f8388,
		"Map::@2940": 0x803f8394,
		"Map::@2941": 0x803f83a0,
		"Map::@2942": 0x803f83ac,
		"Map::@2943": 0x803f83b8,
		"Map::@2584": 0x803f83ec,
		"Map::@2586": 0x803f8404,
		"Map::@2588": 0x803f841c,
		"Map::@2589": 0x803f8428,
		"Map::@2590": 0x803f8434,
		"Map::@2591": 0x803f8440,
		"Map::@2592": 0x803f844c,
		"Map::@2593": 0x803f8458,
		"Map::@2594": 0x803f8464,
		"Map::@2615": 0x803f8480,
		"Map::@2616": 0x803f848c,
		"Map::@2617": 0x803f8498,
		"Map::@2621": 0x803f84c8,
		"Map::@2622": 0x803f84d4,
		"Map::@2623": 0x803f84e0,
		"Map::@2624": 0x803f84ec,
		"Map::@2625": 0x803f84f8,
		"Map::@2626": 0x803f8504,
		"Map::@2627": 0x803f8510,
		"Map::@2628": 0x803f851c,
		"Map::@2629": 0x803f8528,
		"Map::@3519": 0x803f8538,
		"Map::@3520": 0x803f8544,
		"Map::@3521": 0x803f8550,
		"Map::@3522": 0x803f855c,
		"Map::@3523": 0x803f8568,
		"Map::@3524": 0x803f8574,
		"Map::@3525": 0x803f8580,
		"Map::@3526": 0x803f858c,
		"Map::@3527": 0x803f8598,
		"Map::@3528": 0x803f85a4,
		"Map::@3529": 0x803f85b0,
		"Map::@3530": 0x803f85bc,
		"Map::@3531": 0x803f85c8,
		"Map::@3532": 0x803f85d4,
		"Map::@3533": 0x803f85e0,
		"Map::@3240": 0x803f85fc,
		"Map::@3241": 0x803f8608,
		"Map::@3242": 0x803f8614,
		"Map::@3243": 0x803f8620,
		"Map::@3244": 0x803f862c,
		"Map::@3245": 0x803f8638,
		"Map::@3246": 0x803f8644,
		"Map::@3247": 0x803f8650,
		"Map::@3248": 0x803f865c,
		"Map::@3249": 0x803f8668,
		"Map::@3250": 0x803f8674,
		"Map::@3251": 0x803f8680,
		"Map::@3252": 0x803f868c,
		"Map::@3253": 0x803f8698,
		"Map::@2743": 0x803f8714,
		"Map::@2374": 0x803f8760,
		"Map::@2379": 0x803f879c,
		"Map::@2380": 0x803f87a8,
		"Map::@2381": 0x803f87b4,
		"Map::@2382": 0x803f87c0,
		"Map::@2383": 0x803f87cc,
		"Map::@2386": 0x803f87f0,
		"Map::@2387": 0x803f87fc,
		"Map::@2388": 0x803f8808,
		"Map::@2867": 0x803f88d0,
		"Map::pos$2426": 0x803f8a40,
		"pos$2426": 0x803f8a40,
		"Map::@3094": 0x803f8ab8,
		"Map::@3095": 0x803f8ac4,
		"Map::@3096": 0x803f8ad0,
		"Map::@3098": 0x803f8ae8,
		"Map::@3099": 0x803f8af4,
		"Map::@3100": 0x803f8b00,
		"Map::@3101": 0x803f8b0c,
		"Map::@2727": 0x803f8b70,
		"Map::@2728": 0x803f8b7c,
		"Map::@2729": 0x803f8b88,
		"Map::@2730": 0x803f8b94,
		"Map::@2731": 0x803f8ba0,
		"Map::@2732": 0x803f8bac,
		"Map::@2733": 0x803f8bb8,
		"Map::@2330": 0x803f8c28,
		"Map::@2658": 0x803f8d40,
		"Map::@2659": 0x803f8d4c,
		"Map::@2660": 0x803f8d58,
		"Map::@2661": 0x803f8d64,
		"Map::@2662": 0x803f8d70,
		"Map::@2663": 0x803f8d7c,
		"Map::@2664": 0x803f8d88,
		"Map::@3109": 0x803f8da4,
		"Map::@3110": 0x803f8db0,
		"Map::@3111": 0x803f8dbc,
		"Map::@3112": 0x803f8dc8,
		"Map::@3113": 0x803f8dd4,
		"Map::@3114": 0x803f8de0,
		"Map::@3115": 0x803f8dec,
		"Map::@3116": 0x803f8df8,
		"Map::@3971": 0x803f8e50,
		"Map::@3972": 0x803f8e5c,
		"Map::@3973": 0x803f8e68,
		"Map::@3974": 0x803f8e74,
		"Map::@3975": 0x803f8e80,
		"Map::@3976": 0x803f8e8c,
		"Map::@3977": 0x803f8e98,
		"Map::@3978": 0x803f8ea4,
		"Map::@3979": 0x803f8eb0,
		"Map::@3980": 0x803f8ebc,
		"Map::@3981": 0x803f8ec8,
		"Map::@3982": 0x803f8ed4,
		"Map::@3983": 0x803f8ee0,
		"Map::@3984": 0x803f8eec,
		"Map::@3985": 0x803f8ef8,
		"Map::@6023": 0x803f8f08,
		"Map::@6024": 0x803f8f14,
		"Map::@6025": 0x803f8f20,
		"Map::@6026": 0x803f8f2c,
		"Map::@6027": 0x803f8f38,
		"Map::@6028": 0x803f8f44,
		"Map::@6029": 0x803f8f50,
		"Map::@6030": 0x803f8f5c,
		"Map::@6031": 0x803f8f68,
		"Map::@6032": 0x803f8f74,
		"Map::@6033": 0x803f8f80,
		"Map::@6034": 0x803f8f8c,
		"Map::@6035": 0x803f8f98,
		"Map::@6036": 0x803f8fa4,
		"Map::@6037": 0x803f8fb0,
		"GC2D::@2410": 0x803f3d74,
		"GC2D::@2411": 0x803f3d80,
		"GC2D::@2412": 0x803f3d8c,
		"GC2D::@2413": 0x803f3d98,
		"GC2D::@2414": 0x803f3da4,
		"GC2D::@3375": 0x803f3f60,
		"GC2D::@3376": 0x803f3f6c,
		"GC2D::@3377": 0x803f3f78,
		"GC2D::@3382": 0x803f3fb4,
		"GC2D::@3383": 0x803f3fc0,
		"GC2D::@3384": 0x803f3fcc,
		"GC2D::@3385": 0x803f3fd8,
		"GC2D::@3386": 0x803f3fe4,
		"GC2D::@3387": 0x803f3ff0,
		"GC2D::@3388": 0x803f3ffc,
		"GC2D::@3389": 0x803f4008,
		"GC2D::@3131": 0x803f4240,
		"GC2D::@3132": 0x803f424c,
		"GC2D::@3133": 0x803f4258,
		"GC2D::@3135": 0x803f4270,
		"GC2D::@3136": 0x803f427c,
		"GC2D::@3137": 0x803f4288,
		"GC2D::@3138": 0x803f4294,
		"GC2D::@3139": 0x803f42a0,
		"GC2D::@3140": 0x803f42ac,
		"GC2D::@3141": 0x803f42b8,
		"GC2D::@3142": 0x803f42c4,
		"GC2D::@3143": 0x803f42d0,
		"GC2D::@3144": 0x803f42dc,
		"GC2D::@3145": 0x803f42e8,
		"TSelectShineManager::cCenter": 0x803f42f8,
		"cCenter": 0x803f42f8,
		"GC2D::@4146": 0x803f43a4,
		"GC2D::@4147": 0x803f43b0,
		"GC2D::hx": 0x803f43c0,
		"hx": 0x803f43c0,
		"GC2D::@2303": 0x803f7740,
		"GC2D::@2304": 0x803f774c,
		"GC2D::@2305": 0x803f7758,
		"GC2D::@2306": 0x803f7764,
		"GC2D::@2307": 0x803f7770,
		"GC2D::@2308": 0x803f777c,
		"GC2D::@2309": 0x803f7788,
		"GC2D::@2310": 0x803f7794,
		"GC2D::@2311": 0x803f77a0,
		"GC2D::@2312": 0x803f77ac,
		"GC2D::@2313": 0x803f77b8,
		"GC2D::@2314": 0x803f77c4,
		"Enemy::@3176": 0x803f0018,
		"Enemy::@3178": 0x803f0030,
		"Enemy::@4335": 0x803f00dc,
		"Enemy::@4336": 0x803f00e8,
		"Enemy::@3909": 0x803f011c,
		"Enemy::@3918": 0x803f0188,
		"Enemy::@8477": 0x803f0454,
		"@8477": 0x803f0454,
		"Enemy::@8478": 0x803f0460,
		"@8478": 0x803f0460,
		"Enemy::@8479": 0x803f046c,
		"@8479": 0x803f046c,
		"Enemy::@8480": 0x803f0478,
		"@8480": 0x803f0478,
		"Enemy::@8481": 0x803f0484,
		"@8481": 0x803f0484,
		"Enemy::@8482": 0x803f0490,
		"@8482": 0x803f0490,
		"Enemy::@8483": 0x803f049c,
		"@8483": 0x803f049c,
		"Enemy::@8484": 0x803f04a8,
		"@8484": 0x803f04a8,
		"Enemy::@8485": 0x803f04b4,
		"@8485": 0x803f04b4,
		"Enemy::@8486": 0x803f04c0,
		"@8486": 0x803f04c0,
		"Enemy::@8487": 0x803f04cc,
		"@8487": 0x803f04cc,
		"Enemy::@8488": 0x803f04d8,
		"@8488": 0x803f04d8,
		"Enemy::@8489": 0x803f04e4,
		"@8489": 0x803f04e4,
		"Enemy::@8490": 0x803f04f0,
		"@8490": 0x803f04f0,
		"Enemy::@6476": 0x803f05b4,
		"@6476": 0x803f05b4,
		"Enemy::@6477": 0x803f05c0,
		"@6477": 0x803f05c0,
		"Enemy::@6480": 0x803f05e4,
		"@6480": 0x803f05e4,
		"Enemy::@6481": 0x803f05f0,
		"@6481": 0x803f05f0,
		"Enemy::@6482": 0x803f05fc,
		"@6482": 0x803f05fc,
		"Enemy::@6485": 0x803f0620,
		"@6485": 0x803f0620,
		"Enemy::@6486": 0x803f062c,
		"@6486": 0x803f062c,
		"Enemy::@6487": 0x803f0638,
		"@6487": 0x803f0638,
		"Enemy::@6488": 0x803f0644,
		"@6488": 0x803f0644,
		"Enemy::@6489": 0x803f0650,
		"@6489": 0x803f0650,
		"Enemy::@6490": 0x803f065c,
		"@6490": 0x803f065c,
		"Enemy::@4766": 0x803f0830,
		"Enemy::@4767": 0x803f083c,
		"Enemy::@4769": 0x803f0854,
		"Enemy::@2167": 0x803f0a78,
		"Enemy::@5543": 0x803f0e4c,
		"@5543": 0x803f0e4c,
		"Enemy::@5544": 0x803f0e58,
		"@5544": 0x803f0e58,
		"Enemy::@5545": 0x803f0e64,
		"@5545": 0x803f0e64,
		"Enemy::@5546": 0x803f0e70,
		"@5546": 0x803f0e70,
		"Enemy::@5552": 0x803f0eb8,
		"@5552": 0x803f0eb8,
		"Enemy::@9728": 0x803f0f58,
		"@9728": 0x803f0f58,
		"Enemy::@9729": 0x803f0f64,
		"@9729": 0x803f0f64,
		"Enemy::@9730": 0x803f0f70,
		"@9730": 0x803f0f70,
		"Enemy::@9731": 0x803f0f7c,
		"@9731": 0x803f0f7c,
		"Enemy::@9732": 0x803f0f88,
		"@9732": 0x803f0f88,
		"Enemy::@9733": 0x803f0f94,
		"@9733": 0x803f0f94,
		"Enemy::@9734": 0x803f0fa0,
		"@9734": 0x803f0fa0,
		"Enemy::@9735": 0x803f0fac,
		"@9735": 0x803f0fac,
		"Enemy::@9736": 0x803f0fb8,
		"@9736": 0x803f0fb8,
		"Enemy::@9737": 0x803f0fc4,
		"@9737": 0x803f0fc4,
		"Enemy::@9738": 0x803f0fd0,
		"@9738": 0x803f0fd0,
		"Enemy::@9739": 0x803f0fdc,
		"@9739": 0x803f0fdc,
		"Enemy::@9740": 0x803f0fe8,
		"@9740": 0x803f0fe8,
		"Enemy::@8436": 0x803f119c,
		"Enemy::@8437": 0x803f11a8,
		"Enemy::@8438": 0x803f11b4,
		"Enemy::@8439": 0x803f11c0,
		"Enemy::@8440": 0x803f11cc,
		"Enemy::@8441": 0x803f11d8,
		"Enemy::@8442": 0x803f11e4,
		"Enemy::@8443": 0x803f11f0,
		"@8443": 0x803f11f0,
		"Enemy::@8444": 0x803f11fc,
		"@8444": 0x803f11fc,
		"Enemy::@8445": 0x803f1208,
		"@8445": 0x803f1208,
		"Enemy::@5229": 0x803f12f8,
		"Enemy::@5235": 0x803f1340,
		"Enemy::@5236": 0x803f134c,
		"Enemy::@5237": 0x803f1358,
		"Enemy::TTinKoopa_jointIndexTable": 0x803f1398,
		"TTinKoopa_jointIndexTable": 0x803f1398,
		"Enemy::BW_BATH_POS": 0x803f1570,
		"BW_BATH_POS": 0x803f1570,
		"Enemy::BW_PICKET_START": 0x803f157c,
		"BW_PICKET_START": 0x803f157c,
		"Enemy::BW_HEAD_START": 0x803f1588,
		"BW_HEAD_START": 0x803f1588,
		"Enemy::@3239": 0x803f1730,
		"Enemy::@4624": 0x803f1928,
		"Enemy::@4625": 0x803f1934,
		"Enemy::@4626": 0x803f1940,
		"Enemy::@4627": 0x803f194c,
		"Enemy::@4628": 0x803f1958,
		"Enemy::@4629": 0x803f1964,
		"Enemy::@4630": 0x803f1970,
		"Enemy::@4631": 0x803f197c,
		"Enemy::@4632": 0x803f1988,
		"Enemy::@4633": 0x803f1994,
		"Enemy::@4634": 0x803f19a0,
		"Enemy::@5309": 0x803f1a94,
		"Enemy::@5310": 0x803f1aa0,
		"Enemy::@5311": 0x803f1aac,
		"Enemy::@5312": 0x803f1ab8,
		"Enemy::@5313": 0x803f1ac4,
		"Enemy::@5314": 0x803f1ad0,
		"Enemy::@9237": 0x803f1b88,
		"@9237": 0x803f1b88,
		"Enemy::@9238": 0x803f1b94,
		"@9238": 0x803f1b94,
		"Enemy::@9239": 0x803f1ba0,
		"@9239": 0x803f1ba0,
		"Enemy::@9240": 0x803f1bac,
		"@9240": 0x803f1bac,
		"Enemy::@9241": 0x803f1bb8,
		"@9241": 0x803f1bb8,
		"Enemy::@9242": 0x803f1bc4,
		"@9242": 0x803f1bc4,
		"Enemy::@9243": 0x803f1bd0,
		"@9243": 0x803f1bd0,
		"Enemy::@9244": 0x803f1bdc,
		"@9244": 0x803f1bdc,
		"Enemy::@9245": 0x803f1be8,
		"@9245": 0x803f1be8,
		"Enemy::@9246": 0x803f1bf4,
		"@9246": 0x803f1bf4,
		"Enemy::@9247": 0x803f1c00,
		"@9247": 0x803f1c00,
		"Enemy::@9248": 0x803f1c0c,
		"@9248": 0x803f1c0c,
		"Enemy::@9249": 0x803f1c18,
		"@9249": 0x803f1c18,
		"Enemy::@9250": 0x803f1c24,
		"@9250": 0x803f1c24,
		"Enemy::@4274": 0x803f1d54,
		"Enemy::@4275": 0x803f1d60,
		"Enemy::@4280": 0x803f1d9c,
		"Enemy::@6269": 0x803f1e80,
		"@6269": 0x803f1e80,
		"Enemy::@6270": 0x803f1e8c,
		"@6270": 0x803f1e8c,
		"Enemy::@6271": 0x803f1e98,
		"@6271": 0x803f1e98,
		"Enemy::@6272": 0x803f1ea4,
		"@6272": 0x803f1ea4,
		"Enemy::@6273": 0x803f1eb0,
		"@6273": 0x803f1eb0,
		"Enemy::@6274": 0x803f1ebc,
		"@6274": 0x803f1ebc,
		"Enemy::@6275": 0x803f1ec8,
		"@6275": 0x803f1ec8,
		"Enemy::@6276": 0x803f1ed4,
		"@6276": 0x803f1ed4,
		"Enemy::@6277": 0x803f1ee0,
		"@6277": 0x803f1ee0,
		"Enemy::@9463": 0x803f2058,
		"@9463": 0x803f2058,
		"Enemy::@9464": 0x803f2064,
		"@9464": 0x803f2064,
		"Enemy::@9465": 0x803f2070,
		"@9465": 0x803f2070,
		"Enemy::@9466": 0x803f207c,
		"@9466": 0x803f207c,
		"Enemy::@9467": 0x803f2088,
		"@9467": 0x803f2088,
		"Enemy::@9468": 0x803f2094,
		"@9468": 0x803f2094,
		"Enemy::@4652": 0x803f210c,
		"Enemy::@4654": 0x803f2124,
		"Enemy::@5453": 0x803f2344,
		"Enemy::@5454": 0x803f2350,
		"Enemy::@5455": 0x803f235c,
		"Enemy::@2265": 0x803f23c0,
		"Enemy::up$2718": 0x803f23d8,
		"up$2718": 0x803f23d8,
		"Enemy::up$2732": 0x803f23e4,
		"up$2732": 0x803f23e4,
		"Enemy::@4906": 0x803f24c0,
		"Enemy::@2400": 0x803f25a8,
		"Enemy::@2409": 0x803f25b4,
		"Enemy::@2647": 0x803f25cc,
		"Enemy::@2648": 0x803f25d8,
		"Enemy::@2649": 0x803f25e4,
		"Enemy::@2650": 0x803f25f0,
		"Enemy::@2651": 0x803f25fc,
		"Enemy::@2652": 0x803f2608,
		"Enemy::@2653": 0x803f2614,
		"Enemy::@3818": 0x803f2698,
		"Enemy::@3819": 0x803f26a4,
		"Enemy::@3820": 0x803f26b0,
		"Enemy::@2732": 0x803f2964,
		"Enemy::@2733": 0x803f2970,
		"Enemy::@2734": 0x803f297c,
		"Enemy::@2735": 0x803f2988,
		"Enemy::@2736": 0x803f2994,
		"Enemy::@2737": 0x803f29a0,
		"Enemy::@2738": 0x803f29ac,
		"Enemy::@2739": 0x803f29b8,
		"Enemy::@2742": 0x803f29dc,
		"Enemy::@3272": 0x803f2a64,
		"Enemy::@3273": 0x803f2a70,
		"Enemy::@6698": 0x803f2bd0,
		"@6698": 0x803f2bd0,
		"Enemy::@6699": 0x803f2bdc,
		"@6699": 0x803f2bdc,
		"Enemy::@6700": 0x803f2be8,
		"@6700": 0x803f2be8,
		"Enemy::@6701": 0x803f2bf4,
		"@6701": 0x803f2bf4,
		"Enemy::@6702": 0x803f2c00,
		"@6702": 0x803f2c00,
		"Enemy::@6703": 0x803f2c0c,
		"@6703": 0x803f2c0c,
		"Enemy::@6704": 0x803f2c18,
		"@6704": 0x803f2c18,
		"Enemy::@6705": 0x803f2c24,
		"Enemy::@6706": 0x803f2c30,
		"Enemy::@6707": 0x803f2c3c,
		"@6707": 0x803f2c3c,
		"Enemy::@6708": 0x803f2c48,
		"@6708": 0x803f2c48,
		"Enemy::@4140": 0x803f2e30,
		"Enemy::@5909": 0x803f3114,
		"Enemy::@5910": 0x803f3120,
		"Enemy::@5911": 0x803f312c,
		"Enemy::@5912": 0x803f3138,
		"Enemy::@5913": 0x803f3144,
		"Enemy::@5914": 0x803f3150,
		"Enemy::@5916": 0x803f3168,
		"Enemy::@5917": 0x803f3174,
		"Enemy::TKoopaJr_jointIndexTable": 0x803f32b8,
		"TKoopaJr_jointIndexTable": 0x803f32b8,
		"Enemy::@4842": 0x803f35c8,
		"Enemy::@4845": 0x803f35ec,
		"Enemy::@4846": 0x803f35f8,
		"Enemy::@4847": 0x803f3604,
		"Enemy::@4850": 0x803f3628,
		"Enemy::@4851": 0x803f3634,
		"Enemy::@4981": 0x803f3aac,
		"Enemy::@5481": 0x803f3b9c,
		"Enemy::@5485": 0x803f3bcc,
		"Enemy::@3846": 0x803f3c8c,
		"Enemy::@3847": 0x803f3c98,
		"Enemy::@3850": 0x803f3cbc,
		"Enemy::@3852": 0x803f3cd4,
		"Camera::@3186": 0x803efcc8,
		"Camera::@3187": 0x803efcd4,
		"Camera::@3188": 0x803efce0,
		"Camera::@3189": 0x803efcec,
		"Camera::@3190": 0x803efcf8,
		"Camera::@3191": 0x803efd04,
		"Camera::@3192": 0x803efd10,
		"Camera::@3193": 0x803efd1c,
		"Camera::@3194": 0x803efd28,
		"Camera::@3195": 0x803efd34,
		"Camera::@3196": 0x803efd40,
		"Camera::@3197": 0x803efd4c,
		"Camera::@3198": 0x803efd58,
		"Camera::CLBConstUpVec": 0x803efd68,
		"CLBConstUpVec": 0x803efd68,
		"Camera::@2254": 0x803efe20,
		"Camera::@2284": 0x803efe9c,
		"Camera::@2285": 0x803efea8,
		"Camera::@2286": 0x803efeb4,
		"@2286": 0x803efeb4,
		"Camera::@2287": 0x803efec0,
		"Camera::@2288": 0x803efecc,
		"@2288": 0x803efecc,
		"Camera::@2289": 0x803efed8,
		"Animal::@2300": 0x803e9750,
		"Animal::@3346": 0x803e9760,
		"Animal::@3348": 0x803e9778,
		"Animal::@3349": 0x803e9784,
		"Animal::@3350": 0x803e9790,
		"Animal::@3351": 0x803e979c,
		"Animal::@3352": 0x803e97a8,
		"Animal::@3353": 0x803e97b4,
		"Animal::@3354": 0x803e97c0,
		"Animal::@3355": 0x803e97cc,
		"Animal::@3356": 0x803e97d8,
		"Animal::@3357": 0x803e97e4,
		"Animal::@3358": 0x803e97f0,
		"Animal::@3359": 0x803e97fc,
		"Animal::@3360": 0x803e9808,
		"Animal::@2617": 0x803e9824,
		"Animal::@2618": 0x803e9830,
		"Animal::@2619": 0x803e983c,
		"Animal::@2620": 0x803e9848,
		"Animal::@2621": 0x803e9854,
		"Animal::@2622": 0x803e9860,
		"Animal::@2623": 0x803e986c,
		"Animal::@2624": 0x803e9878,
		"Animal::@2625": 0x803e9884,
		"Animal::@2626": 0x803e9890,
		"Animal::@2629": 0x803e98b4,
		"Animal::@2630": 0x803e98c0,
		"Animal::@2001": 0x803e98d0,
		"Animal::@3026": 0x803e98e0,
		"Animal::@3041": 0x803e98ec,
		"Animal::@3056": 0x803e98f8,
		"Animal::@3068": 0x803e9904,
		"Animal::@3078": 0x803e9910,
		"Animal::@3097": 0x803e991c,
		"Animal::@3105": 0x803e9928,
		"Animal::@3117": 0x803e9934,
		"Animal::@3129": 0x803e9940,
		"Animal::@4981": 0x803e994c,
		"Animal::@4982": 0x803e9958,
		"Animal::@4983": 0x803e9964,
		"Animal::@4984": 0x803e9970,
		"Animal::@4985": 0x803e997c,
		"Animal::@4986": 0x803e9988,
		"Animal::@4987": 0x803e9994,
		"Animal::@4988": 0x803e99a0,
		"Animal::@4989": 0x803e99ac,
		"Animal::@4990": 0x803e99b8,
		"Animal::@4991": 0x803e99c4,
		"Animal::@4992": 0x803e99d0,
		"Animal::@4994": 0x803e99e8,
		"Animal::@4995": 0x803e99f4,
		"Animal::@2990": 0x803e9a00,
		"Animal::@3004": 0x803e9a0c,
		"Animal::@3014": 0x803e9a18,
		"Animal::@3036": 0x803e9a30,
		"Animal::@3048": 0x803e9a3c,
		"Animal::@5213": 0x803e9a48,
		"Animal::@5214": 0x803e9a54,
		"Animal::@5215": 0x803e9a60,
		"Animal::@5216": 0x803e9a6c,
		"Animal::@5217": 0x803e9a78,
		"Animal::@5218": 0x803e9a84,
		"Animal::@5219": 0x803e9a90,
		"Animal::@5220": 0x803e9a9c,
		"Animal::@5221": 0x803e9aa8,
		"Animal::@5222": 0x803e9ab4,
		"Animal::@5223": 0x803e9ac0,
		"Animal::@5224": 0x803e9acc,
		"Animal::@5225": 0x803e9ad8,
		"Animal::@5226": 0x803e9ae4,
		"Animal::@5227": 0x803e9af0,
		"Animal::@2422": 0x803e9b00,
		"JKRAramHeap::sAramList": 0x80404290,
		"sAramList": 0x80404290,
		"JKRAram::sAramCommandList": 0x8040429c,
		"sAramCommandList": 0x8040429c,
		"JKRDvdFile::sDvdList": 0x804042a8,
		"sDvdList": 0x804042a8,
		"JKRFileLoader::sVolumeList": 0x804042b4,
		"sVolumeList": 0x804042b4,
		"JKRThread::sThreadList": 0x804042c0,
		"sThreadList": 0x804042c0,
		"JUTException::sMapFileList": 0x804042cc,
		"sMapFileList": 0x804042cc,
		"JUTGamePad::mPadList": 0x804042d8,
		"mPadList": 0x804042d8,
		"JUTGamePad::mPadStatus": 0x80404454,
		"mPadStatus": 0x80404454,
		"JUTGamePad::mPadButton": 0x80404484,
		"mPadButton": 0x80404484,
		"JUTGamePad::mPadMStick": 0x80404544,
		"mPadMStick": 0x80404544,
		"JUTGamePad::mPadSStick": 0x80404584,
		"mPadSStick": 0x80404584,
		"J2DPrint::mMutex": 0x804045c4,
		"JSystem::j3dSys": 0x804045dc,
		"j3dSys": 0x804045dc,
		"J3DSys::mCurrentMtx": 0x80404788,
		"mCurrentMtx": 0x80404788,
		"J3DSys::mCurrentS": 0x804047b8,
		"mCurrentS": 0x804047b8,
		"J3DSys::mParentS": 0x804047c4,
		"mParentS": 0x804047c4,
		"J3DSys::sTexCoordScaleTable": 0x804047d0,
		"sTexCoordScaleTable": 0x804047d0,
		"JKRDvdRipper::sDvdAsyncList": 0x80404810,
		"sDvdAsyncList": 0x80404810,
		"JKRDvdAramRipper::sDvdAramAsyncList": 0x8040481c,
		"sDvdAramAsyncList": 0x8040481c,
		"JSystem::j3dTexCoordTable": 0x80404828,
		"j3dTexCoordTable": 0x80404828,
		"JSystem::j3dTevSwapTableTable": 0x80406d50,
		"j3dTevSwapTableTable": 0x80406d50,
		"JSystem::j3dAlphaCmpTable": 0x80407150,
		"j3dAlphaCmpTable": 0x80407150,
		"JSystem::j3dZModeTable": 0x80407450,
		"j3dZModeTable": 0x80407450,
		"JKRAramPiece::sAramPieceCommandList": 0x804074b0,
		"sAramPieceCommandList": 0x804074b0,
		"JKRAramPiece::mMutex": 0x804074d4,
		"JSystem::JAInullCamera": 0x804074ec,
		"JAInullCamera": 0x804074ec,
		"JAIConst::nullActor": 0x804074f8,
		"nullActor": 0x804074f8,
		"JAIConst::camMtx": 0x80407550,
		"camMtx": 0x80407550,
		"JAIConst::camTrans": 0x80407580,
		"camTrans": 0x80407580,
		"JAIConst::camPreTrans": 0x8040758c,
		"camPreTrans": 0x8040758c,
		"JAInter::StreamLib::streamHeap": 0x80407598,
		"streamHeap": 0x80407598,
		"JAISystemInterface::systemPortCmd": 0x804075ac,
		"systemPortCmd": 0x804075ac,
		"JASystem::TTrack::sParser": 0x8040bf20,
		"sParser": 0x8040bf20,
		"JPADraw::vc": 0x8040bf24,
		"vc": 0x8040bf24,
		"JPADraw::cb": 0x8040c110,
		"Camera::cCameraBckNameShineGetInside": 0x8040c1e8,
		"Camera::cCameraBckNameShineGetOutside": 0x8040c1ec,
		"Camera::cCameraBckNameGate": 0x8040c1f0,
		"Camera::cSunVolumeName": 0x8040c218,
		"Camera::cSunsetVolumeName": 0x8040c21c,
		"Enemy::idx$3338": 0x8040c2d0,
		"idx$3338": 0x8040c2d0,
		"Enemy::loopIndirectFilenames$3524": 0x8040c33c,
		"loopIndirectFilenames$3524": 0x8040c33c,
		"Enemy::anmlist$3310": 0x8040c368,
		"anmlist$3310": 0x8040c368,
		"Enemy::graphlist$3316": 0x8040c370,
		"graphlist$3316": 0x8040c370,
		"Enemy::onetimeFilenames$3164": 0x8040c50c,
		"onetimeFilenames$3164": 0x8040c50c,
		"Enemy::@2526": 0x8040c544,
		"Enemy::@2527": 0x8040c548,
		"Enemy::loopFilenames$3194": 0x8040c5e0,
		"loopFilenames$3194": 0x8040c5e0,
		"GC2D::scDolpicNewsDolpic8_Ac4": 0x8040c668,
		"scDolpicNewsDolpic8_Ac4": 0x8040c668,
		"GC2D::scDolpicNewsDolpic8_Cc4": 0x8040c670,
		"scDolpicNewsDolpic8_Cc4": 0x8040c670,
		"GC2D::scDolpicNewsDolpic8_Da4": 0x8040c678,
		"scDolpicNewsDolpic8_Da4": 0x8040c678,
		"GC2D::scDolpicNewsDolpic8_Db4": 0x8040c680,
		"scDolpicNewsDolpic8_Db4": 0x8040c680,
		"GC2D::scDolpicNewsDolpic8_Dc1": 0x8040c688,
		"scDolpicNewsDolpic8_Dc1": 0x8040c688,
		"GC2D::scDolpicNewsDolpic8_Dc3": 0x8040c690,
		"scDolpicNewsDolpic8_Dc3": 0x8040c690,
		"GC2D::strYes": 0x8040c698,
		"strYes": 0x8040c698,
		"GC2D::strNo": 0x8040c69c,
		"strNo": 0x8040c69c,
		"System::sShineViewObjName$3422": 0x8040cbe8,
		"sShineViewObjName$3422": 0x8040cbe8,
		"System::stages$3013": 0x8040cbf0,
		"stages$3013": 0x8040cbf0,
		"JSystem::rootPath$1763": 0x8040cc00,
		"rootPath$1763": 0x8040cc00,
		"JUTException::sMessageBuffer": 0x8040cc08,
		"JUTGamePad::mStickMode": 0x8040cc10,
		"mStickMode": 0x8040cc10,
		"JUTGamePad::C3ButtonReset::sResetPattern": 0x8040cc14,
		"sResetPattern": 0x8040cc14,
		"JSystem::Unit01": 0x8040cc18,
		"JSystem::J3DUnit01": 0x8040cc20,
		"J3DUnit01": 0x8040cc20,
		"JKRDvdRipper::szpBufferSize": 0x8040cc2c,
		"JKRDvdAramRipper::szpBufferSize": 0x8040cc34,
		"JSystem::GXTexMode0Ids": 0x8040cc38,
		"GXTexMode0Ids": 0x8040cc38,
		"JSystem::GXTexMode1Ids": 0x8040cc40,
		"GXTexMode1Ids": 0x8040cc40,
		"JSystem::GXTexImage0Ids": 0x8040cc48,
		"GXTexImage0Ids": 0x8040cc48,
		"JSystem::GXTexImage1Ids": 0x8040cc50,
		"GXTexImage1Ids": 0x8040cc50,
		"JSystem::GXTexImage2Ids": 0x8040cc58,
		"GXTexImage2Ids": 0x8040cc58,
		"JSystem::GXTexImage3Ids": 0x8040cc60,
		"GXTexImage3Ids": 0x8040cc60,
		"JSystem::GXTexTlutIds": 0x8040cc68,
		"GXTexTlutIds": 0x8040cc68,
		"JSystem::GX2HWFiltConv": 0x8040cc70,
		"JSystem::j3dDefaultColInfo": 0x8040cc78,
		"j3dDefaultColInfo": 0x8040cc78,
		"JSystem::j3dDefaultAmbInfo": 0x8040cc7c,
		"j3dDefaultAmbInfo": 0x8040cc7c,
		"JSystem::j3dDefaultTevOrderInfoNull": 0x8040cc84,
		"j3dDefaultTevOrderInfoNull": 0x8040cc84,
		"JSystem::j3dDefaultIndTexOrderNull": 0x8040cc88,
		"j3dDefaultIndTexOrderNull": 0x8040cc88,
		"JSystem::j3dDefaultTevColor": 0x8040cc8c,
		"j3dDefaultTevColor": 0x8040cc8c,
		"JSystem::j3dDefaultIndTexCoordScaleInfo": 0x8040cc94,
		"j3dDefaultIndTexCoordScaleInfo": 0x8040cc94,
		"JSystem::j3dDefaultTevKColor": 0x8040cc98,
		"j3dDefaultTevKColor": 0x8040cc98,
		"JSystem::j3dDefaultTevSwapMode": 0x8040cc9c,
		"j3dDefaultTevSwapMode": 0x8040cc9c,
		"JSystem::j3dDefaultTevSwapModeTable": 0x8040cca0,
		"j3dDefaultTevSwapModeTable": 0x8040cca0,
		"JSystem::j3dDefaultBlendInfo": 0x8040cca4,
		"j3dDefaultBlendInfo": 0x8040cca4,
		"JSystem::j3dDefaultColorChanInfo": 0x8040cca8,
		"j3dDefaultColorChanInfo": 0x8040cca8,
		"JSystem::JRNTexImage1Ids": 0x8040ccc0,
		"JRNTexImage1Ids": 0x8040ccc0,
		"JSystem::JRNTexImage2Ids": 0x8040ccc8,
		"JRNTexImage2Ids": 0x8040ccc8,
		"JALCalc::cEqualCSlope": 0x8040ccd0,
		"cEqualCSlope": 0x8040ccd0,
		"JALCalc::cPlusPSlope": 0x8040ccd4,
		"cPlusPSlope": 0x8040ccd4,
		"JAInter::TAsnData::asnFileName": 0x8040ccd8,
		"asnFileName": 0x8040ccd8,
		"JAInter::StreamLib::LOOP_BLOCKS": 0x8040cce0,
		"LOOP_BLOCKS": 0x8040cce0,
		"JAInter::StreamLib::LOOP_SAMPLESIZE": 0x8040cce4,
		"LOOP_SAMPLESIZE": 0x8040cce4,
		"JAInter::StreamLib::outputmode": 0x8040cce8,
		"outputmode": 0x8040cce8,
		"JAIGlobalParameter::soundSceneMax": 0x8040ccf8,
		"soundSceneMax": 0x8040ccf8,
		"JAIGlobalParameter::seRegistMax": 0x8040ccfc,
		"seRegistMax": 0x8040ccfc,
		"JAIGlobalParameter::seTrackMax": 0x8040cd00,
		"seTrackMax": 0x8040cd00,
		"JAIGlobalParameter::seqTrackMax": 0x8040cd04,
		"seqTrackMax": 0x8040cd04,
		"JAIGlobalParameter::seqPlayTrackMax": 0x8040cd08,
		"seqPlayTrackMax": 0x8040cd08,
		"JAIGlobalParameter::seqControlBufferMax": 0x8040cd0c,
		"seqControlBufferMax": 0x8040cd0c,
		"JAIGlobalParameter::streamControlBufferMax": 0x8040cd10,
		"streamControlBufferMax": 0x8040cd10,
		"JAIGlobalParameter::streamParameterBufferMax": 0x8040cd14,
		"streamParameterBufferMax": 0x8040cd14,
		"JAIGlobalParameter::autoHeapMax": 0x8040cd18,
		"autoHeapMax": 0x8040cd18,
		"JAIGlobalParameter::stayHeapMax": 0x8040cd1c,
		"stayHeapMax": 0x8040cd1c,
		"JAIGlobalParameter::autoHeapRoomSize": 0x8040cd20,
		"autoHeapRoomSize": 0x8040cd20,
		"JAIGlobalParameter::stayHeapSize": 0x8040cd24,
		"stayHeapSize": 0x8040cd24,
		"JAIGlobalParameter::seInfoFileName": 0x8040cd28,
		"seInfoFileName": 0x8040cd28,
		"JAIGlobalParameter::seqInfoFileName": 0x8040cd2c,
		"seqInfoFileName": 0x8040cd2c,
		"JAIGlobalParameter::streamInfoFileName": 0x8040cd30,
		"streamInfoFileName": 0x8040cd30,
		"JAIGlobalParameter::initDataFileName": 0x8040cd34,
		"initDataFileName": 0x8040cd34,
		"JAIGlobalParameter::wavePath": 0x8040cd38,
		"wavePath": 0x8040cd38,
		"JAIGlobalParameter::sequenceArchivesPath": 0x8040cd3c,
		"sequenceArchivesPath": 0x8040cd3c,
		"JAIGlobalParameter::streamPath": 0x8040cd40,
		"streamPath": 0x8040cd40,
		"JAIGlobalParameter::sequenceArchivesFileName": 0x8040cd44,
		"sequenceArchivesFileName": 0x8040cd44,
		"JAIGlobalParameter::inputGainDown": 0x8040cd48,
		"inputGainDown": 0x8040cd48,
		"JAIGlobalParameter::outputGainUp": 0x8040cd4c,
		"outputGainUp": 0x8040cd4c,
		"JAIGlobalParameter::distanceMax": 0x8040cd50,
		"distanceMax": 0x8040cd50,
		"JAIGlobalParameter::maxVolumeDistance": 0x8040cd54,
		"maxVolumeDistance": 0x8040cd54,
		"JAIGlobalParameter::seDolbyCenterValue": 0x8040cd58,
		"seDolbyCenterValue": 0x8040cd58,
		"JAIGlobalParameter::seDolbyFrontDistanceMax": 0x8040cd5c,
		"seDolbyFrontDistanceMax": 0x8040cd5c,
		"JAIGlobalParameter::seDolbyBehindDistanceMax": 0x8040cd60,
		"seDolbyBehindDistanceMax": 0x8040cd60,
		"JAIGlobalParameter::dopplarMoveTime": 0x8040cd64,
		"dopplarMoveTime": 0x8040cd64,
		"JAIGlobalParameter::dummyPositionMax": 0x8040cd68,
		"dummyPositionMax": 0x8040cd68,
		"JAIGlobalParameter::seqMuteMoveSpeedSePlay": 0x8040cd6c,
		"seqMuteMoveSpeedSePlay": 0x8040cd6c,
		"JAIGlobalParameter::audioCameraMax": 0x8040cd70,
		"audioCameraMax": 0x8040cd70,
		"JAIGlobalParameter::systemTrackMax": 0x8040cd74,
		"systemTrackMax": 0x8040cd74,
		"JAIGlobalParameter::systemRootTrackMax": 0x8040cd78,
		"systemRootTrackMax": 0x8040cd78,
		"JAIGlobalParameter::panDistanceMax": 0x8040cd7c,
		"panDistanceMax": 0x8040cd7c,
		"JAIGlobalParameter::panDistance2Max": 0x8040cd80,
		"panDistance2Max": 0x8040cd80,
		"JAIGlobalParameter::panAngleParameter": 0x8040cd84,
		"panAngleParameter": 0x8040cd84,
		"JAIGlobalParameter::panAngleParameter2": 0x8040cd88,
		"panAngleParameter2": 0x8040cd88,
		"JAIGlobalParameter::dopplarParameter": 0x8040cd8c,
		"dopplarParameter": 0x8040cd8c,
		"JAIGlobalParameter::seDistancepitchMax": 0x8040cd94,
		"seDistancepitchMax": 0x8040cd94,
		"JASystem::Driver::DSPQueue::waitMax": 0x8040cd98,
		"waitMax": 0x8040cd98,
		"JASystem::Driver::JAS_SYSTEM_OUTPUT_MODE": 0x8040cda4,
		"JAS_SYSTEM_OUTPUT_MODE": 0x8040cda4,
		"JASystem::Driver::DSP_VOICE_WAITS_MAX": 0x8040cdac,
		"DSP_VOICE_WAITS_MAX": 0x8040cdac,
		"JASystem::TDSPChannel::smnFree": 0x8040cdb0,
		"smnFree": 0x8040cdb0,
		"JASystem::DSP_LIMIT_RATIO": 0x8040cdb4,
		"DSP_LIMIT_RATIO": 0x8040cdb4,
		"JSystem::COMP_BLOCKSAMPLES$234": 0x8040cdbc,
		"COMP_BLOCKSAMPLES$234": 0x8040cdbc,
		"JSystem::COMP_BLOCKBYTES$235": 0x8040cdc4,
		"COMP_BLOCKBYTES$235": 0x8040cdc4,
		"JASystem::Kernel::maxCallbacksUser": 0x8040cdd0,
		"maxCallbacksUser": 0x8040cdd0,
		"JASystem::Dvd::dvdMsgsSize": 0x8040cdd8,
		"dvdMsgsSize": 0x8040cdd8,
		"JASystem::Dvd::dvdBufSize": 0x8040cddc,
		"dvdBufSize": 0x8040cddc,
		"JASystem::Dvd::maxDics": 0x8040cde0,
		"maxDics": 0x8040cde0,
		"JASystem::HardStream::playListMax": 0x8040cde8,
		"playListMax": 0x8040cde8,
		"JASystem::Kernel::gDacRate": 0x8040cdf0,
		"gDacRate": 0x8040cdf0,
		"JASystem::Kernel::gSubFrames": 0x8040cdf4,
		"gSubFrames": 0x8040cdf4,
		"JASystem::Kernel::gFrameSamples": 0x8040cdf8,
		"gFrameSamples": 0x8040cdf8,
		"JASystem::Kernel::gDacSize": 0x8040cdfc,
		"gDacSize": 0x8040cdfc,
		"JASystem::Kernel::audioDramSize": 0x8040ce00,
		"audioDramSize": 0x8040ce00,
		"JASystem::Kernel::audioAramSize": 0x8040ce04,
		"audioAramSize": 0x8040ce04,
		"JASystem::Vload::vlMaxArcs": 0x8040ce08,
		"vlMaxArcs": 0x8040ce08,
		"JASystem::Player::sV0": 0x8040ce10,
		"sV0": 0x8040ce10,
		"JASystem::Player::sV1": 0x8040ce14,
		"sV1": 0x8040ce14,
		"Runtime.PPCEABI.H::fragmentID": 0x8040ce20,
		"fragmentID": 0x8040ce20,
		"MSL_C.PPCEABI.bare.H::@wstringBase0": 0x8040ce28,
		"@wstringBase0": 0x8040ce28,
		"MSL_C.PPCEABI.bare.H::next": 0x8040ce30,
		"MSL_C.PPCEABI.bare.H::K1": 0x8040ce38,
		"K1": 0x8040ce38,
		"MSL_C.PPCEABI.bare.H::K2": 0x8040ce3c,
		"K2": 0x8040ce3c,
		"os::__OSCurrHeap": 0x8040ce40,
		"__OSCurrHeap": 0x8040ce40,
		"os::__OSArenaLo": 0x8040ce48,
		"__OSArenaLo": 0x8040ce48,
		"os::@32": 0x8040ce50,
		"mtx::Unit01": 0x8040ce60,
		"dvd::FirstRead": 0x8040ce68,
		"FirstRead": 0x8040ce68,
		"dvd::@116": 0x8040ce70,
		"dvd::autoInvalidation": 0x8040ce78,
		"autoInvalidation": 0x8040ce78,
		"dvd::@35": 0x8040ce80,
		"dvd::@40": 0x8040ce84,
		"dvd::@41": 0x8040ce88,
		"pad::ClampRegion": 0x8040ce90,
		"ClampRegion": 0x8040ce90,
		"pad::ResettingChan": 0x8040ce98,
		"ResettingChan": 0x8040ce98,
		"pad::XPatchBits": 0x8040ce9c,
		"XPatchBits": 0x8040ce9c,
		"pad::AnalogMode": 0x8040cea0,
		"AnalogMode": 0x8040cea0,
		"pad::Spec": 0x8040cea4,
		"Spec": 0x8040cea4,
		"pad::MakeStatus": 0x8040cea8,
		"MakeStatus": 0x8040cea8,
		"pad::CmdReadOrigin": 0x8040ceac,
		"CmdReadOrigin": 0x8040ceac,
		"pad::CmdCalibrate": 0x8040ceb0,
		"CmdCalibrate": 0x8040ceb0,
		"card::next": 0x8040ceb8,
		"gx::gx": 0x8040cec8,
		"gx::tbl1$215": 0x8040ced0,
		"tbl1$215": 0x8040ced0,
		"gx::tbl2$216": 0x8040ced4,
		"tbl2$216": 0x8040ced4,
		"gx::tbl3$217": 0x8040ced8,
		"tbl3$217": 0x8040ced8,
		"gx::GX2HWFiltConv": 0x8040cee0,
		"gd::cm2hw$400": 0x8040cef0,
		"cm2hw$400": 0x8040cef0,
		"gd::cm2hw$515": 0x8040cef4,
		"cm2hw$515": 0x8040cef4,
		"MarioUtil::className$1930": 0x8040caa8,
		"className$1930": 0x8040caa8,
		"MarioUtil::className$1944": 0x8040cab0,
		"className$1944": 0x8040cab0,
		"TMBindShadowManager::mSquareShadowHeight": 0x8040cab8,
		"mSquareShadowHeight": 0x8040cab8,
		"TMBindShadowManager::mTreeScale": 0x8040cabc,
		"mTreeScale": 0x8040cabc,
		"TMBindShadowManager::mYScalePlus": 0x8040cac0,
		"mYScalePlus": 0x8040cac0,
		"MarioUtil::ColorBlack": 0x8040cac8,
		"ColorBlack": 0x8040cac8,
		"MarioUtil::ColorWhite": 0x8040cacc,
		"ColorWhite": 0x8040cacc,
		"RumbleMgr::mMotorCountLimit": 0x8040cad0,
		"mMotorCountLimit": 0x8040cad0,
		"RumbleMgr::mPowerThreshold": 0x8040cad8,
		"mPowerThreshold": 0x8040cad8,
		"MarioUtil::rumblePoint_00": 0x8040cae0,
		"rumblePoint_00": 0x8040cae0,
		"MarioUtil::rumblePoint_01": 0x8040cae4,
		"rumblePoint_01": 0x8040cae4,
		"MarioUtil::rumblePoint_02": 0x8040cae8,
		"rumblePoint_02": 0x8040cae8,
		"MarioUtil::rumbleFrame_02": 0x8040caec,
		"rumbleFrame_02": 0x8040caec,
		"MarioUtil::rumblePower_02": 0x8040caf4,
		"rumblePower_02": 0x8040caf4,
		"MarioUtil::rumblePoint_03": 0x8040cafc,
		"rumblePoint_03": 0x8040cafc,
		"MarioUtil::rumbleFrame_03": 0x8040cb00,
		"rumbleFrame_03": 0x8040cb00,
		"MarioUtil::rumblePower_03": 0x8040cb08,
		"rumblePower_03": 0x8040cb08,
		"MarioUtil::rumblePoint_04": 0x8040cb10,
		"rumblePoint_04": 0x8040cb10,
		"MarioUtil::rumblePoint_05": 0x8040cb14,
		"rumblePoint_05": 0x8040cb14,
		"MarioUtil::rumblePoint_06": 0x8040cb18,
		"rumblePoint_06": 0x8040cb18,
		"MarioUtil::rumblePoint_07": 0x8040cb1c,
		"rumblePoint_07": 0x8040cb1c,
		"MarioUtil::rumblePoint_08": 0x8040cb20,
		"rumblePoint_08": 0x8040cb20,
		"MarioUtil::rumblePoint_09": 0x8040cb24,
		"rumblePoint_09": 0x8040cb24,
		"MarioUtil::rumblePoint_10": 0x8040cb28,
		"rumblePoint_10": 0x8040cb28,
		"MarioUtil::rumbleFrame_10": 0x8040cb2c,
		"rumbleFrame_10": 0x8040cb2c,
		"MarioUtil::rumblePower_10": 0x8040cb30,
		"rumblePower_10": 0x8040cb30,
		"MarioUtil::rumblePoint_11": 0x8040cb34,
		"rumblePoint_11": 0x8040cb34,
		"MarioUtil::rumbleFrame_11": 0x8040cb38,
		"rumbleFrame_11": 0x8040cb38,
		"MarioUtil::rumblePower_11": 0x8040cb3c,
		"rumblePower_11": 0x8040cb3c,
		"MarioUtil::rumblePoint_12": 0x8040cb40,
		"rumblePoint_12": 0x8040cb40,
		"MarioUtil::rumbleFrame_12": 0x8040cb44,
		"rumbleFrame_12": 0x8040cb44,
		"MarioUtil::rumblePower_12": 0x8040cb48,
		"rumblePower_12": 0x8040cb48,
		"MarioUtil::rumblePoint_13": 0x8040cb4c,
		"rumblePoint_13": 0x8040cb4c,
		"MarioUtil::rumbleFrame_13": 0x8040cb50,
		"rumbleFrame_13": 0x8040cb50,
		"MarioUtil::rumblePower_13": 0x8040cb54,
		"rumblePower_13": 0x8040cb54,
		"MarioUtil::rumblePoint_14": 0x8040cb58,
		"rumblePoint_14": 0x8040cb58,
		"MarioUtil::rumbleFrame_14": 0x8040cb5c,
		"rumbleFrame_14": 0x8040cb5c,
		"MarioUtil::rumblePower_14": 0x8040cb60,
		"rumblePower_14": 0x8040cb60,
		"MarioUtil::rumblePoint_15": 0x8040cb64,
		"rumblePoint_15": 0x8040cb64,
		"MarioUtil::rumbleFrame_15": 0x8040cb68,
		"rumbleFrame_15": 0x8040cb68,
		"MarioUtil::rumblePower_15": 0x8040cb6c,
		"rumblePower_15": 0x8040cb6c,
		"MarioUtil::rumblePoint_16": 0x8040cb70,
		"rumblePoint_16": 0x8040cb70,
		"MarioUtil::rumbleFrame_16": 0x8040cb74,
		"rumbleFrame_16": 0x8040cb74,
		"MarioUtil::rumblePower_16": 0x8040cb78,
		"rumblePower_16": 0x8040cb78,
		"MarioUtil::rumblePoint_17": 0x8040cb7c,
		"rumblePoint_17": 0x8040cb7c,
		"MarioUtil::rumbleFrame_17": 0x8040cb80,
		"rumbleFrame_17": 0x8040cb80,
		"MarioUtil::rumblePower_17": 0x8040cb84,
		"rumblePower_17": 0x8040cb84,
		"MarioUtil::rumblePoint_18": 0x8040cb88,
		"rumblePoint_18": 0x8040cb88,
		"MarioUtil::rumbleFrame_18": 0x8040cb8c,
		"rumbleFrame_18": 0x8040cb8c,
		"MarioUtil::rumblePower_18": 0x8040cb90,
		"rumblePower_18": 0x8040cb90,
		"MarioUtil::rumblePoint_19": 0x8040cb94,
		"rumblePoint_19": 0x8040cb94,
		"MarioUtil::rumblePoint_20": 0x8040cb98,
		"rumblePoint_20": 0x8040cb98,
		"MarioUtil::rumbleFrame_20": 0x8040cb9c,
		"rumbleFrame_20": 0x8040cb9c,
		"MarioUtil::rumblePower_20": 0x8040cba4,
		"rumblePower_20": 0x8040cba4,
		"MarioUtil::rumblePoint_21": 0x8040cbac,
		"rumblePoint_21": 0x8040cbac,
		"MarioUtil::rumbleFrame_21": 0x8040cbb0,
		"rumbleFrame_21": 0x8040cbb0,
		"MarioUtil::rumblePower_21": 0x8040cbb8,
		"rumblePower_21": 0x8040cbb8,
		"MarioUtil::rumblePoint_22": 0x8040cbc0,
		"rumblePoint_22": 0x8040cbc0,
		"MarioUtil::rumbleFrame_22": 0x8040cbc4,
		"rumbleFrame_22": 0x8040cbc4,
		"MarioUtil::rumblePower_22": 0x8040cbcc,
		"rumblePower_22": 0x8040cbcc,
		"MarioUtil::rumblePoint_23": 0x8040cbd4,
		"rumblePoint_23": 0x8040cbd4,
		"MarioUtil::rumblePoint_24": 0x8040cbd8,
		"rumblePoint_24": 0x8040cbd8,
		"MarioUtil::channelNum": 0x8040cbdc,
		"channelNum": 0x8040cbdc,
		"M3DUtil::@1211": 0x8040cbe0,
		"@1211": 0x8040cbe0,
		"System::cTargetArrowBmdFileName": 0x8040cbf8,
		"cTargetArrowBmdFileName": 0x8040cbf8,
		"TLiveActor::mVelocityMinY": 0x8040ca88,
		"mVelocityMinY": 0x8040ca88,
		"NPC::cNpcPartsNameRootJoint": 0x8040ca08,
		"cNpcPartsNameRootJoint": 0x8040ca08,
		"NPC::cDummyPollutionTexName": 0x8040ca10,
		"cDummyPollutionTexName": 0x8040ca10,
		"NPC::cRealPollutionTexName": 0x8040ca14,
		"cRealPollutionTexName": 0x8040ca14,
		"NPC::cMonteMDummyStrawTexName": 0x8040ca18,
		"cMonteMDummyStrawTexName": 0x8040ca18,
		"NPC::cMonteWDummyStrawTexName": 0x8040ca1c,
		"cMonteWDummyStrawTexName": 0x8040ca1c,
		"NPC::cMonteMRealStrawTexName": 0x8040ca20,
		"cMonteMRealStrawTexName": 0x8040ca20,
		"NPC::cMonteWRealStrawTexName": 0x8040ca24,
		"cMonteWRealStrawTexName": 0x8040ca24,
		"NPC::cScreenTexViewObjName": 0x8040ca28,
		"cScreenTexViewObjName": 0x8040ca28,
		"NPC::cJellyFishDummyScreenTexName": 0x8040ca2c,
		"cJellyFishDummyScreenTexName": 0x8040ca2c,
		"NPC::cJellyFishDummyTexName": 0x8040ca30,
		"cJellyFishDummyTexName": 0x8040ca30,
		"NPC::cJellyFishRealTexName": 0x8040ca34,
		"cJellyFishRealTexName": 0x8040ca34,
		"NPC::cMonteMCommonVolumeName": 0x8040ca38,
		"cMonteMCommonVolumeName": 0x8040ca38,
		"NPC::cMonteWCommonVolumeName": 0x8040ca3c,
		"cMonteWCommonVolumeName": 0x8040ca3c,
		"NPC::cMareMCommonVolumeName": 0x8040ca40,
		"cMareMCommonVolumeName": 0x8040ca40,
		"NPC::cMareWCommonVolumeName": 0x8040ca44,
		"cMareWCommonVolumeName": 0x8040ca44,
		"NPC::cMareCommonNormalBmtName": 0x8040ca48,
		"cMareCommonNormalBmtName": 0x8040ca48,
		"NPC::cMareCommonPollutionBmtName": 0x8040ca4c,
		"cMareCommonPollutionBmtName": 0x8040ca4c,
		"NPC::cManiyaParentViewObjName": 0x8040ca50,
		"cManiyaParentViewObjName": 0x8040ca50,
		"NPC::cManiyaChildViewObjName": 0x8040ca54,
		"cManiyaChildViewObjName": 0x8040ca54,
		"NPC::cNotUseFastCubeViewObjName0": 0x8040ca58,
		"cNotUseFastCubeViewObjName0": 0x8040ca58,
		"NPC::cNotUseFastCubeViewObjName1": 0x8040ca5c,
		"cNotUseFastCubeViewObjName1": 0x8040ca5c,
		"NPC::cEyeMaterialName": 0x8040ca60,
		"cEyeMaterialName": 0x8040ca60,
		"NPC::cNeckJointName": 0x8040ca64,
		"cNeckJointName": 0x8040ca64,
		"TBaseNPC::sWaistJointName$localstatic0$setMtxEffect_": 0x8040ca68,
		"sWaistJointName$localstatic0$setMtxEffect_": 0x8040ca68,
		"NPC::cPeachPartsTextureName": 0x8040ca70,
		"cPeachPartsTextureName": 0x8040ca70,
		"NPC::cPeachHostTextureName": 0x8040ca74,
		"cPeachHostTextureName": 0x8040ca74,
		"NPC::monteMG_bastable": 0x8040ca78,
		"monteMG_bastable": 0x8040ca78,
		"NPC::mareMD_bastable": 0x8040ca80,
		"mareMD_bastable": 0x8040ca80,
		"MSBgm::smMainVolume": 0x8040c1c0,
		"smMainVolume": 0x8040c1c0,
		"MSHandle::cPan_MaxAmp": 0x8040c1c8,
		"cPan_MaxAmp": 0x8040c1c8,
		"MSHandle::cPan_CAdjust": 0x8040c1cc,
		"cPan_CAdjust": 0x8040c1cc,
		"MSHandle::cPan_CShift": 0x8040c1d0,
		"cPan_CShift": 0x8040c1d0,
		"MSHandle::cPan_HiSence_Dist": 0x8040c1d4,
		"cPan_HiSence_Dist": 0x8040c1d4,
		"MSHandle::cMS_DistanceMax_Sence": 0x8040c1d8,
		"cMS_DistanceMax_Sence": 0x8040c1d8,
		"MSHandle::cDol_0Rad": 0x8040c1dc,
		"cDol_0Rad": 0x8040c1dc,
		"MSHandle::cDol_HalfRad": 0x8040c1e0,
		"cDol_HalfRad": 0x8040c1e0,
		"MSHandle::cDol_FullRad": 0x8040c1e4,
		"cDol_FullRad": 0x8040c1e4,
		"TWoodBarrel::mWaitAppearTime": 0x8040c758,
		"mWaitAppearTime": 0x8040c758,
		"TWoodBarrel::mBreakTime": 0x8040c75c,
		"mBreakTime": 0x8040c75c,
		"TWoodBarrel::mOilBarrelFlushTime": 0x8040c760,
		"mOilBarrelFlushTime": 0x8040c760,
		"MoveBG::streetlamp_sink_data": 0x8040c768,
		"streetlamp_sink_data": 0x8040c768,
		"MoveBG::lamp_bianco_sink_data": 0x8040c770,
		"lamp_bianco_sink_data": 0x8040c770,
		"TMapObjGeneral::mNormalLivingTime": 0x8040c778,
		"mNormalLivingTime": 0x8040c778,
		"TMapObjGeneral::mNormalFlushTime": 0x8040c77c,
		"mNormalFlushTime": 0x8040c77c,
		"TMapObjGeneral::mNormalFlushInterval": 0x8040c780,
		"mNormalFlushInterval": 0x8040c780,
		"TMapObjGeneral::mNormalWaitToAppearTime": 0x8040c784,
		"mNormalWaitToAppearTime": 0x8040c784,
		"TMapObjGeneral::mNormalAppearingScaleUp": 0x8040c788,
		"mNormalAppearingScaleUp": 0x8040c788,
		"TMapObjGeneral::mNormalThrowSpeedRate": 0x8040c78c,
		"mNormalThrowSpeedRate": 0x8040c78c,
		"TMapObjLibWave::mWaveSpeed": 0x8040c790,
		"mWaveSpeed": 0x8040c790,
		"TItem::mAppearedScaleSpeed": 0x8040c798,
		"mAppearedScaleSpeed": 0x8040c798,
		"TShine::mCircleRateY": 0x8040c79c,
		"mCircleRateY": 0x8040c79c,
		"TShine::mUpSpeed": 0x8040c7a0,
		"mUpSpeed": 0x8040c7a0,
		"TShine::mSpeedDownRate": 0x8040c7a4,
		"TManhole::mDownHeight": 0x8040c7a8,
		"TManhole::mDownSpeed": 0x8040c7ac,
		"mDownSpeed": 0x8040c7ac,
		"TManhole::mVibrationSpeed": 0x8040c7b0,
		"mVibrationSpeed": 0x8040c7b0,
		"TManhole::mVibrationEndHeight": 0x8040c7b4,
		"mVibrationEndHeight": 0x8040c7b4,
		"TManhole::mVibrationDecreaseRate": 0x8040c7b8,
		"mVibrationDecreaseRate": 0x8040c7b8,
		"TSandBlock::mSandScaleUp": 0x8040c7c0,
		"mSandScaleUp": 0x8040c7c0,
		"TSandBlock::mSandScaleDown": 0x8040c7c4,
		"mSandScaleDown": 0x8040c7c4,
		"TSandBlock::mSandScaleMin": 0x8040c7c8,
		"mSandScaleMin": 0x8040c7c8,
		"TSandBlock::mWaitTimeToFall": 0x8040c7cc,
		"mWaitTimeToFall": 0x8040c7cc,
		"TSandBlock::mSandWaitTime": 0x8040c7d0,
		"mSandWaitTime": 0x8040c7d0,
		"TIceBlock::mMeltSpeedWater": 0x8040c7d4,
		"mMeltSpeedWater": 0x8040c7d4,
		"TIceBlock::mMeltSpeedAuto": 0x8040c7d8,
		"mMeltSpeedAuto": 0x8040c7d8,
		"TIceBlock::mAutoMeltScale": 0x8040c7dc,
		"mAutoMeltScale": 0x8040c7dc,
		"MoveBG::sSubZ": 0x8040c7e4,
		"sSubZ": 0x8040c7e4,
		"MoveBG::sSpeed": 0x8040c7e8,
		"sSpeed": 0x8040c7e8,
		"TMapObjRootPakkun::mTremblePower": 0x8040c7ec,
		"mTremblePower": 0x8040c7ec,
		"TMapObjRootPakkun::mTrembleAccel": 0x8040c7f0,
		"mTrembleAccel": 0x8040c7f0,
		"TMapObjRootPakkun::mTrembleBrake": 0x8040c7f4,
		"mTrembleBrake": 0x8040c7f4,
		"TMapObjRootPakkun::mTrembleTime": 0x8040c7f8,
		"mTrembleTime": 0x8040c7f8,
		"TBiancoWatermillVertical::mRotAccel": 0x8040c7fc,
		"TBiancoWatermillVertical::mRotSpeedDownRate": 0x8040c800,
		"mRotSpeedDownRate": 0x8040c800,
		"TBiancoWatermillVertical::mRotSpeedMax": 0x8040c804,
		"TBiancoWatermillVertical::mBridgeRotRate": 0x8040c808,
		"mBridgeRotRate": 0x8040c808,
		"TBiancoMiniWindmill::mRotWaterAccel": 0x8040c80c,
		"mRotWaterAccel": 0x8040c80c,
		"TBiancoMiniWindmill::mFriction": 0x8040c810,
		"mFriction": 0x8040c810,
		"TBiancoMiniWindmill::mRotSpeedMax": 0x8040c814,
		"MoveBG::sMessengerPosZ": 0x8040c818,
		"sMessengerPosZ": 0x8040c818,
		"MoveBG::sMessengerPosY": 0x8040c81c,
		"sMessengerPosY": 0x8040c81c,
		"TLeafBoatRotten::mAlphaDownSpeed": 0x8040c820,
		"mAlphaDownSpeed": 0x8040c820,
		"TLeafBoatRotten::mCollisionRemoveAlpha": 0x8040c824,
		"mCollisionRemoveAlpha": 0x8040c824,
		"TLeafBoatRotten::mRottenColor": 0x8040c828,
		"mRottenColor": 0x8040c828,
		"TCraneRotY::mWaitTime": 0x8040c830,
		"TCraneUpDown::mRotSpeed": 0x8040c834,
		"TCraneUpDown::mWaitTime": 0x8040c838,
		"TRiccoWatermill::mRotAccel": 0x8040c83c,
		"TRiccoWatermill::mRotSpeedMaxUp": 0x8040c840,
		"mRotSpeedMaxUp": 0x8040c840,
		"TRiccoWatermill::mRotSpeedMaxDown": 0x8040c844,
		"mRotSpeedMaxDown": 0x8040c844,
		"TRiccoWatermill::mRotDown": 0x8040c848,
		"mRotDown": 0x8040c848,
		"TRiccoWatermill::mSubmarineMoveRate": 0x8040c84c,
		"mSubmarineMoveRate": 0x8040c84c,
		"TRiccoWatermill::mSubmarineMaxTransY": 0x8040c850,
		"mSubmarineMaxTransY": 0x8040c850,
		"TRiccoWatermill::mSubmarineBottomTransY": 0x8040c854,
		"mSubmarineBottomTransY": 0x8040c854,
		"TRiccoWatermill::mWaitTime": 0x8040c858,
		"TFruitLauncher::mObjSpeedXZ": 0x8040c85c,
		"mObjSpeedXZ": 0x8040c85c,
		"TFruitLauncher::mObjSpeedY": 0x8040c860,
		"mObjSpeedY": 0x8040c860,
		"TFruitLauncher::mFruitLiveTime": 0x8040c864,
		"mFruitLiveTime": 0x8040c864,
		"TSandBase::mWitherTime": 0x8040c868,
		"mWitherTime": 0x8040c868,
		"TSandBase::mScaleMin": 0x8040c86c,
		"TSandBombBase::mFiringFrameSpeed": 0x8040c870,
		"mFiringFrameSpeed": 0x8040c870,
		"TSandBombBase::mFiringFrameDownSpeed": 0x8040c874,
		"mFiringFrameDownSpeed": 0x8040c874,
		"TSandBombBase::mExplodeFrameSpeed": 0x8040c878,
		"mExplodeFrameSpeed": 0x8040c878,
		"TSandBombBase::mMarioJumpRate": 0x8040c87c,
		"mMarioJumpRate": 0x8040c87c,
		"TSandBombBase::mExlodingRumbleTime": 0x8040c880,
		"mExlodingRumbleTime": 0x8040c880,
		"TSandCastle::mCollisionRate": 0x8040c884,
		"mCollisionRate": 0x8040c884,
		"TLeanMirror::mGoTargetTime": 0x8040c888,
		"mGoTargetTime": 0x8040c888,
		"TLeanMirror::mDemoWaitTime": 0x8040c88c,
		"mDemoWaitTime": 0x8040c88c,
		"TLeanMirror::mDemoLightTime": 0x8040c890,
		"mDemoLightTime": 0x8040c890,
		"TMammaBlockRotate::mRotSpeed": 0x8040c894,
		"TMammaBlockRotate::mRotReturnSpeed": 0x8040c898,
		"mRotReturnSpeed": 0x8040c898,
		"TMammaBlockRotate::mRotEnd": 0x8040c89c,
		"mRotEnd": 0x8040c89c,
		"TMammaBlockRotate::mMapGoSpeed": 0x8040c8a0,
		"mMapGoSpeed": 0x8040c8a0,
		"TMammaBlockRotate::mMapBackSpeed": 0x8040c8a4,
		"mMapBackSpeed": 0x8040c8a4,
		"TMammaBlockRotate::mWaitTime": 0x8040c8a8,
		"TShellCup::mOpenRotMax": 0x8040c8b0,
		"mOpenRotMax": 0x8040c8b0,
		"TShellCup::mShellDamageRot": 0x8040c8b4,
		"mShellDamageRot": 0x8040c8b4,
		"TShellCup::mWaterOpenAccel": 0x8040c8b8,
		"mWaterOpenAccel": 0x8040c8b8,
		"TShellCup::mCloseAccel": 0x8040c8bc,
		"mCloseAccel": 0x8040c8bc,
		"TMerrygoround::mRotSpeed": 0x8040c8c0,
		"TCogwheelScale::mWaterLeakSpeed": 0x8040c8c8,
		"mWaterLeakSpeed": 0x8040c8c8,
		"TCogwheel::mRopeWidthX": 0x8040c8d0,
		"TCogwheel::mRopeWidthZ": 0x8040c8d4,
		"TCogwheel::mTexPosRate": 0x8040c8d8,
		"TCogwheel::mMinSpeed": 0x8040c8dc,
		"mMinSpeed": 0x8040c8dc,
		"MoveBG::mGrowStartFrame": 0x8040c8e0,
		"mGrowStartFrame": 0x8040c8e0,
		"MoveBG::mGrowEndFrame": 0x8040c8e4,
		"mGrowEndFrame": 0x8040c8e4,
		"TMapObjFlag::mFlutterSpeed": 0x8040c8e8,
		"mFlutterSpeed": 0x8040c8e8,
		"TMapObjPlane::mHipDropDownRate": 0x8040c8f8,
		"mHipDropDownRate": 0x8040c8f8,
		"TMapObjPlane::mWaterDownRate": 0x8040c8fc,
		"mWaterDownRate": 0x8040c8fc,
		"TMapObjPlane::mTexScale": 0x8040c900,
		"mTexScale": 0x8040c900,
		"TRideCloud::mMoveSpeedDefault": 0x8040c908,
		"mMoveSpeedDefault": 0x8040c908,
		"TRideCloud::mCushionLen": 0x8040c90c,
		"mCushionLen": 0x8040c90c,
		"TRideCloud::mCushionSpeed": 0x8040c910,
		"mCushionSpeed": 0x8040c910,
		"TRideCloud::mScaleSpeed": 0x8040c914,
		"mScaleSpeed": 0x8040c914,
		"TResetFruit::mFruitLivingTime": 0x8040c918,
		"mFruitLivingTime": 0x8040c918,
		"TResetFruit::mScaleUpSpeed": 0x8040c91c,
		"TResetFruit::mBreakingScaleSpeed": 0x8040c920,
		"mBreakingScaleSpeed": 0x8040c920,
		"TResetFruit::mFruitWaitTimeToAppear": 0x8040c924,
		"mFruitWaitTimeToAppear": 0x8040c924,
		"TMapObjGrassManager::mWidth": 0x8040c940,
		"mWidth": 0x8040c940,
		"TMapObjGrassManager::mSwingWidth": 0x8040c944,
		"mSwingWidth": 0x8040c944,
		"TMapObjGrassManager::mSwingSpeed": 0x8040c948,
		"mSwingSpeed": 0x8040c948,
		"TMapObjGrassManager::mDistNear": 0x8040c94c,
		"mDistNear": 0x8040c94c,
		"TMapObjGrassManager::mDistFar": 0x8040c950,
		"mDistFar": 0x8040c950,
		"MoveBG::sGrassAddTime": 0x8040c954,
		"sGrassAddTime": 0x8040c954,
		"TRevolvingFenceInner::mSpeed": 0x8040c968,
		"mSpeed": 0x8040c968,
		"TFenceWater::mWaterAccel": 0x8040c96c,
		"mWaterAccel": 0x8040c96c,
		"TFenceWater::mBackSpeed": 0x8040c970,
		"mBackSpeed": 0x8040c970,
		"TFenceWater::mTurnedWaitTime": 0x8040c974,
		"mTurnedWaitTime": 0x8040c974,
		"TRailFence::mFallHeight": 0x8040c978,
		"mFallHeight": 0x8040c978,
		"TRailFence::mWaitTime": 0x8040c97c,
		"MoveBG::sRumbleTime": 0x8040c980,
		"sRumbleTime": 0x8040c980,
		"THangingBridgeBoard::mMarioAccelY": 0x8040c988,
		"mMarioAccelY": 0x8040c988,
		"THangingBridgeBoard::mMarioHipDropAccelY": 0x8040c98c,
		"mMarioHipDropAccelY": 0x8040c98c,
		"THangingBridgeBoard::mReturnAccelRate": 0x8040c990,
		"THangingBridgeBoard::mSpeedDownRate": 0x8040c994,
		"THangingBridgeBoard::mRopeWidthX": 0x8040c998,
		"THangingBridgeBoard::mRopeWidthZ": 0x8040c99c,
		"THangingBridgeBoard::mTexPosRate": 0x8040c9a0,
		"THangingBridge::mRopeWidthBetweenBoards": 0x8040c9a4,
		"mRopeWidthBetweenBoards": 0x8040c9a4,
		"THangingBridge::mRopeWidthBetweenBoardsY": 0x8040c9a8,
		"mRopeWidthBetweenBoardsY": 0x8040c9a8,
		"THangingBridge::mPointNumBetweenBoards": 0x8040c9ac,
		"mPointNumBetweenBoards": 0x8040c9ac,
		"THangingBridge::mBetweenBoardsTexPosRate": 0x8040c9b0,
		"mBetweenBoardsTexPosRate": 0x8040c9b0,
		"TSwingBoard::mBoardWidth": 0x8040c9b4,
		"mBoardWidth": 0x8040c9b4,
		"TSwingBoard::mRopeWidthX": 0x8040c9b8,
		"TSwingBoard::mRopeWidthZ": 0x8040c9bc,
		"TSwingBoard::mTexPosRate": 0x8040c9c0,
		"TSwingBoard::mReturnAccelRate": 0x8040c9c4,
		"TSwingBoard::mSpeedDownRate": 0x8040c9c8,
		"TFluff::mScaleUpSpeed": 0x8040c9cc,
		"TFluff::mScaleDownSpeed": 0x8040c9d0,
		"mScaleDownSpeed": 0x8040c9d0,
		"TFluffManager::mWindMin": 0x8040c9d4,
		"mWindMin": 0x8040c9d4,
		"TMapObjTree::mBananaTreeJumpPower": 0x8040c9d8,
		"mBananaTreeJumpPower": 0x8040c9d8,
		"TMapObjTreeScale::mScaleSpeedY": 0x8040c9dc,
		"mScaleSpeedY": 0x8040c9dc,
		"TMapObjTreeScale::mStatusChangeScaleY": 0x8040c9e0,
		"mStatusChangeScaleY": 0x8040c9e0,
		"TMapObjTreeScale::mScaleSpeedXZ": 0x8040c9e4,
		"mScaleSpeedXZ": 0x8040c9e4,
		"TMapObjTreeScale::mScaleMin": 0x8040c9e8,
		"MoveBG::sWaitTime": 0x8040c9ec,
		"sWaitTime": 0x8040c9ec,
		"TMapObjNail::mDownHeight": 0x8040c9f0,
		"TLampTrapIron::mHitPointMax": 0x8040ca00,
		"mHitPointMax": 0x8040ca00,
		"TLampTrapIron::mFireTimerMax": 0x8040ca04,
		"mFireTimerMax": 0x8040ca04,
		"TMapEventSink::mCleanedDegree": 0x8040c6c0,
		"Map::table$2575": 0x8040c6c8,
		"table$2575": 0x8040c6c8,
		"TMapWire::mMoveTimerSpeed": 0x8040c6d0,
		"mMoveTimerSpeed": 0x8040c6d0,
		"TMapWire::mDownRateMax": 0x8040c6d4,
		"mDownRateMax": 0x8040c6d4,
		"TMapWire::mEndRate": 0x8040c6d8,
		"mEndRate": 0x8040c6d8,
		"TMapWire::mStretchRate": 0x8040c6dc,
		"mStretchRate": 0x8040c6dc,
		"TMapWire::mHeightRate": 0x8040c6e0,
		"mHeightRate": 0x8040c6e0,
		"TMapWire::mReleaseHeight": 0x8040c6e4,
		"mReleaseHeight": 0x8040c6e4,
		"TMapWire::mFootLength": 0x8040c6e8,
		"mFootLength": 0x8040c6e8,
		"TMapWire::mDrawWidth": 0x8040c6ec,
		"mDrawWidth": 0x8040c6ec,
		"TMapWire::mDrawHeight": 0x8040c6f0,
		"mDrawHeight": 0x8040c6f0,
		"TMapWireActor::mCommonAttackRadius": 0x8040c6f8,
		"mCommonAttackRadius": 0x8040c6f8,
		"TMapWireActor::mCommonAttackHeight": 0x8040c6fc,
		"mCommonAttackHeight": 0x8040c6fc,
		"TPollutionLayer::mAreaMinRate": 0x8040c700,
		"mAreaMinRate": 0x8040c700,
		"TPollutionLayer::mSpreadArea": 0x8040c704,
		"mSpreadArea": 0x8040c704,
		"TPollutionLayer::mSpreadFrequency": 0x8040c708,
		"mSpreadFrequency": 0x8040c708,
		"TPollutionLayer::mFireArea": 0x8040c70c,
		"mFireArea": 0x8040c70c,
		"TPollutionLayer::mFireEffectWaitTime": 0x8040c710,
		"mFireEffectWaitTime": 0x8040c710,
		"TPollutionLayer::mThunderArea": 0x8040c714,
		"mThunderArea": 0x8040c714,
		"TPollutionLayer::mGlassWallArea": 0x8040c718,
		"mGlassWallArea": 0x8040c718,
		"TPollutionLayer::mGlassWallEffectTime": 0x8040c71c,
		"mGlassWallEffectTime": 0x8040c71c,
		"TPollutionManager::mFlushTime": 0x8040c720,
		"mFlushTime": 0x8040c720,
		"TPollutionLayerWave::mInterval": 0x8040c728,
		"mInterval": 0x8040c728,
		"TPollutionLayer::mEffectTime": 0x8040c730,
		"mEffectTime": 0x8040c730,
		"TMareWallRock::mAppearSpeed": 0x8040c738,
		"mAppearSpeed": 0x8040c738,
		"TMareWallRock::mDepressSpeed": 0x8040c73c,
		"TMareWallRock::mCleanedDegree": 0x8040c740,
		"TMareWallRock::mWaitTimeToAppear": 0x8040c744,
		"mWaitTimeToAppear": 0x8040c744,
		"TMareWallRock::mWaitTimeToDepress": 0x8040c748,
		"mWaitTimeToDepress": 0x8040c748,
		"TMareEventDepressWall::mDepressSpeed": 0x8040c74c,
		"TMareEventDepressWall::mRiseSpeed": 0x8040c750,
		"mRiseSpeed": 0x8040c750,
		"TMareEventDepressWall::mWaitTimeToWatch": 0x8040c754,
		"mWaitTimeToWatch": 0x8040c754,
		"GC2D::scDolpicNewsDolpic0": 0x8040c648,
		"scDolpicNewsDolpic0": 0x8040c648,
		"GC2D::scDolpicNewsDolpic1": 0x8040c650,
		"scDolpicNewsDolpic1": 0x8040c650,
		"GC2D::scDolpicNewsDolpic5_2": 0x8040c658,
		"scDolpicNewsDolpic5_2": 0x8040c658,
		"GC2D::scDolpicNewsDolpic5_3": 0x8040c660,
		"scDolpicNewsDolpic5_3": 0x8040c660,
		"GC2D::fbuf": 0x8040c6a0,
		"fbuf": 0x8040c6a0,
		"GC2D::vtable_org": 0x8040c6a4,
		"vtable_org": 0x8040c6a4,
		"GC2D::dec_step": 0x8040c6ac,
		"dec_step": 0x8040c6ac,
		"GC2D::inc_step": 0x8040c6b0,
		"inc_step": 0x8040c6b0,
		"GC2D::fbuf2": 0x8040c6b4,
		"fbuf2": 0x8040c6b4,
		"GC2D::gmover_tex_buffer": 0x8040c6b8,
		"gmover_tex_buffer": 0x8040c6b8,
		"GC2D::mag$259": 0x8040c6bc,
		"mag$259": 0x8040c6bc,
		"TGesso::mBodyRotSpeed": 0x8040c24c,
		"mBodyRotSpeed": 0x8040c24c,
		"TGesso::mPollRange": 0x8040c250,
		"mPollRange": 0x8040c250,
		"TGesso::mThroughHoseiDistY": 0x8040c254,
		"mThroughHoseiDistY": 0x8040c254,
		"THamuKuri::mCapGravityY": 0x8040c258,
		"mCapGravityY": 0x8040c258,
		"THamuKuri::mCapSpeed": 0x8040c25c,
		"mCapSpeed": 0x8040c25c,
		"THamuKuri::mVGenerateGravityY": 0x8040c260,
		"mVGenerateGravityY": 0x8040c260,
		"THamuKuri::mLandAnmFrameNum": 0x8040c264,
		"mLandAnmFrameNum": 0x8040c264,
		"Enemy::mFireHamNoseColorDiff": 0x8040c26c,
		"mFireHamNoseColorDiff": 0x8040c26c,
		"Enemy::mFireHamOtherColorDiff": 0x8040c274,
		"mFireHamOtherColorDiff": 0x8040c274,
		"Enemy::mannameTable$3222": 0x8040c280,
		"mannameTable$3222": 0x8040c280,
		"TMameGesso::mBaseHoseiTransY": 0x8040c290,
		"mBaseHoseiTransY": 0x8040c290,
		"TNameKuriManager::mExplosionSpeed": 0x8040c298,
		"mExplosionSpeed": 0x8040c298,
		"TNameKuriManager::mStopMinScaleFrame": 0x8040c29c,
		"mStopMinScaleFrame": 0x8040c29c,
		"TPakkunManager::mRootExplosionScaleRate": 0x8040c2a0,
		"mRootExplosionScaleRate": 0x8040c2a0,
		"TPakkunManager::mTestFlyAngX": 0x8040c2a4,
		"mTestFlyAngX": 0x8040c2a4,
		"TPakkunManager::mIgnoreHitWaterY": 0x8040c2a8,
		"mIgnoreHitWaterY": 0x8040c2a8,
		"TSmallEnemyManager::mBlockWaitTime": 0x8040c2b0,
		"mBlockWaitTime": 0x8040c2b0,
		"TSmallEnemyManager::mBlockMoveSpeed": 0x8040c2b4,
		"mBlockMoveSpeed": 0x8040c2b4,
		"TSmallEnemyManager::mBlockWaitMoveY": 0x8040c2b8,
		"mBlockWaitMoveY": 0x8040c2b8,
		"TSmallEnemyManager::mChangeBlockTime": 0x8040c2bc,
		"mChangeBlockTime": 0x8040c2bc,
		"TSmallEnemyManager::mBlockXZScale": 0x8040c2c0,
		"mBlockXZScale": 0x8040c2c0,
		"TSmallEnemyManager::mBlockYScale": 0x8040c2c4,
		"mBlockYScale": 0x8040c2c4,
		"TTelesa::mFlyAngMax": 0x8040c2e0,
		"mFlyAngMax": 0x8040c2e0,
		"TTobiPuku::mLandAngle": 0x8040c2f8,
		"mLandAngle": 0x8040c2f8,
		"TTobiPuku::mBoundVelocityY": 0x8040c300,
		"mBoundVelocityY": 0x8040c300,
		"TChuuHana::mCheckOnPanelTimeRoll": 0x8040c340,
		"mCheckOnPanelTimeRoll": 0x8040c340,
		"TChuuHana::mCheckOnPanelTime": 0x8040c344,
		"mCheckOnPanelTime": 0x8040c344,
		"TChuuHana::mSmallMirrorR": 0x8040c350,
		"mSmallMirrorR": 0x8040c350,
		"TChuuHana::mMediumMirrorR": 0x8040c354,
		"mMediumMirrorR": 0x8040c354,
		"TChuuHana::mLargeMirrorR": 0x8040c358,
		"mLargeMirrorR": 0x8040c358,
		"TRollEnemy::mBoundVal": 0x8040c360,
		"mBoundVal": 0x8040c360,
		"TIgaiga::mReachNodeDist": 0x8040c364,
		"mReachNodeDist": 0x8040c364,
		"TTamaNoko::mStopOnAirTimeMax": 0x8040c380,
		"mStopOnAirTimeMax": 0x8040c380,
		"TTamaNoko::mRollOnAirTimeMax": 0x8040c384,
		"mRollOnAirTimeMax": 0x8040c384,
		"TTamaNoko::mRollOnAirAngle": 0x8040c388,
		"mRollOnAirAngle": 0x8040c388,
		"TTamaNoko::mDropVelocityY": 0x8040c38c,
		"mDropVelocityY": 0x8040c38c,
		"TBossTelesa::mEnemyGenRate": 0x8040c390,
		"mEnemyGenRate": 0x8040c390,
		"TBossTelesa::mItemGenRate": 0x8040c394,
		"mItemGenRate": 0x8040c394,
		"TBossTelesa::mBaseHoseiPosY": 0x8040c39c,
		"mBaseHoseiPosY": 0x8040c39c,
		"TBossTelesa::mRouletteUpRate": 0x8040c3a0,
		"mRouletteUpRate": 0x8040c3a0,
		"TBossTelesa::mTelesaGenerateInterval": 0x8040c3a4,
		"mTelesaGenerateInterval": 0x8040c3a4,
		"TBossTelesa::mCameraMoveLimit": 0x8040c3a8,
		"mCameraMoveLimit": 0x8040c3a8,
		"TBossTelesa::mCameraMoveSp": 0x8040c3ac,
		"mCameraMoveSp": 0x8040c3ac,
		"TCannon::mVelocityRate": 0x8040c3bc,
		"mVelocityRate": 0x8040c3bc,
		"TCannon::mSearchRate": 0x8040c3c0,
		"mSearchRate": 0x8040c3c0,
		"TBossEel::mOpenRollSpeed": 0x8040c3c8,
		"mOpenRollSpeed": 0x8040c3c8,
		"TBossEel::mForcePow": 0x8040c3d0,
		"mForcePow": 0x8040c3d0,
		"TFlyEnemy::mTestSp": 0x8040c3dc,
		"mTestSp": 0x8040c3dc,
		"TFlyEnemy::mInvalidTime": 0x8040c3e0,
		"mInvalidTime": 0x8040c3e0,
		"TFlyEnemy::mTestMarioSpMax": 0x8040c3e4,
		"mTestMarioSpMax": 0x8040c3e4,
		"TPopo::mTestAng_x": 0x8040c3f4,
		"TPopo::mTestAng_y": 0x8040c3f8,
		"TPopo::mNozzleOffsetZ": 0x8040c3fc,
		"TPopo::mTestBodyScale": 0x8040c408,
		"mTestBodyScale": 0x8040c408,
		"TPopo::mColOffsetY": 0x8040c410,
		"TPopo::mColMinVal": 0x8040c414,
		"mColMinVal": 0x8040c414,
		"Enemy::sleepBossHanachan_bastable": 0x8040c420,
		"sleepBossHanachan_bastable": 0x8040c420,
		"Enemy::cSandPillarModelName": 0x8040c430,
		"cSandPillarModelName": 0x8040c430,
		"Enemy::cHitPoint1_RailName": 0x8040c434,
		"cHitPoint1_RailName": 0x8040c434,
		"Enemy::cHitPoint2_RailName": 0x8040c438,
		"cHitPoint2_RailName": 0x8040c438,
		"Enemy::cSandTextureName": 0x8040c43c,
		"cSandTextureName": 0x8040c43c,
		"Enemy::cDummyTextureName": 0x8040c440,
		"cDummyTextureName": 0x8040c440,
		"Enemy::cMapCollisionJointName": 0x8040c448,
		"cMapCollisionJointName": 0x8040c448,
		"Enemy::cBodyMapCollisionFileName": 0x8040c44c,
		"cBodyMapCollisionFileName": 0x8040c44c,
		"Enemy::cHeadMapCollisionFileName": 0x8040c450,
		"cHeadMapCollisionFileName": 0x8040c450,
		"Enemy::cLegJointName_L3": 0x8040c454,
		"cLegJointName_L3": 0x8040c454,
		"Enemy::cLegJointName_R3": 0x8040c458,
		"cLegJointName_R3": 0x8040c458,
		"Enemy::cNoseHallJointName_L": 0x8040c45c,
		"cNoseHallJointName_L": 0x8040c45c,
		"Enemy::cNoseHallJointName_R": 0x8040c460,
		"cNoseHallJointName_R": 0x8040c460,
		"Enemy::sFootJointName$2739": 0x8040c464,
		"sFootJointName$2739": 0x8040c464,
		"TRocket::mTestAng_y": 0x8040c478,
		"TRocket::mNozzleOffsetZ": 0x8040c47c,
		"TRocket::mColOffsetY": 0x8040c480,
		"Enemy::koopajrsubmarine_bastable": 0x8040c4a8,
		"koopajrsubmarine_bastable": 0x8040c4a8,
		"Enemy::@2523": 0x8040c538,
		"Enemy::@2524": 0x8040c53c,
		"Enemy::@2525": 0x8040c540,
		"Enemy::DebuTelesa_bastable": 0x8040c5f0,
		"DebuTelesa_bastable": 0x8040c5f0,
		"Camera::cStartCamName": 0x8040c1f4,
		"cStartCamName": 0x8040c1f4,
		"Camera::cStartAfterCamName": 0x8040c1f8,
		"cStartAfterCamName": 0x8040c1f8,
		"Camera::cJetCoasterCam0BckName": 0x8040c1fc,
		"cJetCoasterCam0BckName": 0x8040c1fc,
		"Camera::cJetCoasterCam1BckName": 0x8040c200,
		"cJetCoasterCam1BckName": 0x8040c200,
		"Camera::cJetCoasterDemoBckName": 0x8040c204,
		"cJetCoasterDemoBckName": 0x8040c204,
		"Camera::cStartCamBckFileName": 0x8040c208,
		"cStartCamBckFileName": 0x8040c208,
		"Camera::bossGesoViewObjName": 0x8040c210,
		"bossGesoViewObjName": 0x8040c210,
		"Camera::cSunWarpPointName": 0x8040c220,
		"cSunWarpPointName": 0x8040c220,
		"Camera::cPositionJointName": 0x8040c228,
		"cPositionJointName": 0x8040c228,
		"Camera::cLookatJointName": 0x8040c22c,
		"cLookatJointName": 0x8040c22c,
		"Camera::cCameraBckVolumeName": 0x8040c230,
		"cCameraBckVolumeName": 0x8040c230,
		"Camera::cLoadCamName": 0x8040c238,
		"cLoadCamName": 0x8040c238,
		"TNerveWaitForever<TLiveActor>::instance$localstatic0$theNerve": 0x8040cf04,
		"Enemy::instance$3230": 0x8040d130,
		"instance$3230": 0x8040d130,
		"Enemy::instance$3275": 0x8040d140,
		"instance$3275": 0x8040d140,
		"Enemy::instance$3358": 0x8040d150,
		"instance$3358": 0x8040d150,
		"Enemy::instance$3372": 0x8040d158,
		"instance$3372": 0x8040d158,
		"Enemy::instance$3382": 0x8040d160,
		"instance$3382": 0x8040d160,
		"Enemy::instance$3392": 0x8040d168,
		"instance$3392": 0x8040d168,
		"Enemy::instance$3749": 0x8040d174,
		"instance$3749": 0x8040d174,
		"Enemy::instance$3763": 0x8040d17c,
		"instance$3763": 0x8040d17c,
		"Enemy::instance$3792": 0x8040d18c,
		"instance$3792": 0x8040d18c,
		"Enemy::instance$3836": 0x8040d1a4,
		"instance$3836": 0x8040d1a4,
		"Enemy::instance$3847": 0x8040d1ac,
		"instance$3847": 0x8040d1ac,
		"Enemy::instance$3867": 0x8040d1b4,
		"instance$3867": 0x8040d1b4,
		"Enemy::instance$3881": 0x8040d1bc,
		"instance$3881": 0x8040d1bc,
		"Enemy::instance$3892": 0x8040d1c4,
		"instance$3892": 0x8040d1c4,
		"Enemy::instance$3915": 0x8040d1d4,
		"instance$3915": 0x8040d1d4,
		"Enemy::instance$2574": 0x8040d254,
		"instance$2574": 0x8040d254,
		"Enemy::instance$2632": 0x8040d25c,
		"instance$2632": 0x8040d25c,
		"Enemy::instance$2655": 0x8040d264,
		"instance$2655": 0x8040d264,
		"Enemy::instance$2675": 0x8040d26c,
		"instance$2675": 0x8040d26c,
		"Enemy::instance$2695": 0x8040d274,
		"instance$2695": 0x8040d274,
		"Enemy::instance$2709": 0x8040d27c,
		"instance$2709": 0x8040d27c,
		"Enemy::instance$2727": 0x8040d284,
		"instance$2727": 0x8040d284,
		"Enemy::instance$2754": 0x8040d28c,
		"instance$2754": 0x8040d28c,
		"Enemy::instance$3061": 0x8040d298,
		"instance$3061": 0x8040d298,
		"Enemy::instance$3074": 0x8040d2a0,
		"instance$3074": 0x8040d2a0,
		"Enemy::instance$3150": 0x8040d2b8,
		"instance$3150": 0x8040d2b8,
		"Enemy::instance$3164": 0x8040d2c8,
		"instance$3164": 0x8040d2c8,
		"Enemy::instance$3245": 0x8040d2e4,
		"instance$3245": 0x8040d2e4,
		"Enemy::instance$3288": 0x8040d2ec,
		"instance$3288": 0x8040d2ec,
		"Enemy::instance$3301": 0x8040d2f4,
		"instance$3301": 0x8040d2f4,
		"Enemy::instance$3349": 0x8040d30c,
		"instance$3349": 0x8040d30c,
		"Enemy::instance$3227": 0x8040d31c,
		"instance$3227": 0x8040d31c,
		"Enemy::instance$3255": 0x8040d324,
		"instance$3255": 0x8040d324,
		"Enemy::instance$3297": 0x8040d33c,
		"instance$3297": 0x8040d33c,
		"Enemy::instance$3309": 0x8040d344,
		"instance$3309": 0x8040d344,
		"Enemy::instance$2616": 0x8040d354,
		"instance$2616": 0x8040d354,
		"Enemy::instance$2627": 0x8040d35c,
		"instance$2627": 0x8040d35c,
		"Enemy::instance$2639": 0x8040d364,
		"instance$2639": 0x8040d364,
		"Enemy::instance$2658": 0x8040d36c,
		"instance$2658": 0x8040d36c,
		"Enemy::instance$2669": 0x8040d374,
		"instance$2669": 0x8040d374,
		"Enemy::instance$3721": 0x8040d384,
		"instance$3721": 0x8040d384,
		"Enemy::instance$3739": 0x8040d38c,
		"instance$3739": 0x8040d38c,
		"Enemy::instance$3754": 0x8040d394,
		"instance$3754": 0x8040d394,
		"Enemy::instance$3794": 0x8040d39c,
		"instance$3794": 0x8040d39c,
		"Enemy::instance$3814": 0x8040d3a4,
		"instance$3814": 0x8040d3a4,
		"Enemy::instance$3833": 0x8040d3ac,
		"instance$3833": 0x8040d3ac,
		"Enemy::instance$3896": 0x8040d3bc,
		"instance$3896": 0x8040d3bc,
		"Enemy::instance$3913": 0x8040d3c4,
		"instance$3913": 0x8040d3c4,
		"Enemy::instance$3160": 0x8040d3cc,
		"instance$3160": 0x8040d3cc,
		"Enemy::instance$3264": 0x8040d3ec,
		"instance$3264": 0x8040d3ec,
		"Enemy::instance$3314": 0x8040d40c,
		"instance$3314": 0x8040d40c,
		"Enemy::instance$3299": 0x8040d414,
		"instance$3299": 0x8040d414,
		"Enemy::instance$3325": 0x8040d41c,
		"instance$3325": 0x8040d41c,
		"Enemy::instance$3346": 0x8040d424,
		"instance$3346": 0x8040d424,
		"Enemy::instance$3485": 0x8040d444,
		"instance$3485": 0x8040d444,
		"Enemy::instance$3499": 0x8040d44c,
		"instance$3499": 0x8040d44c,
		"Enemy::instance$3511": 0x8040d454,
		"instance$3511": 0x8040d454,
		"Enemy::instance$3521": 0x8040d45c,
		"instance$3521": 0x8040d45c,
		"Enemy::instance$3534": 0x8040d464,
		"instance$3534": 0x8040d464,
		"Enemy::instance$3549": 0x8040d46c,
		"instance$3549": 0x8040d46c,
		"Enemy::instance$3565": 0x8040d474,
		"instance$3565": 0x8040d474,
		"Enemy::instance$3575": 0x8040d47c,
		"instance$3575": 0x8040d47c,
		"Enemy::instance$3584": 0x8040d484,
		"instance$3584": 0x8040d484,
		"Enemy::instance$3594": 0x8040d48c,
		"instance$3594": 0x8040d48c,
		"Enemy::instance$3609": 0x8040d494,
		"instance$3609": 0x8040d494,
		"Enemy::instance$3620": 0x8040d49c,
		"instance$3620": 0x8040d49c,
		"Enemy::instance$3625": 0x8040d4a8,
		"instance$3625": 0x8040d4a8,
		"Enemy::instance$3665": 0x8040d4b0,
		"instance$3665": 0x8040d4b0,
		"Enemy::instance$3678": 0x8040d4b8,
		"instance$3678": 0x8040d4b8,
		"Enemy::instance$3707": 0x8040d4c0,
		"instance$3707": 0x8040d4c0,
		"Enemy::instance$3719": 0x8040d4c8,
		"instance$3719": 0x8040d4c8,
		"Enemy::instance$3732": 0x8040d4d0,
		"instance$3732": 0x8040d4d0,
		"Enemy::instance$3745": 0x8040d4d8,
		"instance$3745": 0x8040d4d8,
		"Enemy::instance$3759": 0x8040d4e0,
		"instance$3759": 0x8040d4e0,
		"Enemy::instance$3795": 0x8040d4f0,
		"instance$3795": 0x8040d4f0,
		"Enemy::instance$3808": 0x8040d4f8,
		"instance$3808": 0x8040d4f8,
		"Enemy::instance$3834": 0x8040d508,
		"instance$3834": 0x8040d508,
		"Enemy::instance$3871": 0x8040d520,
		"instance$3871": 0x8040d520,
		"Enemy::instance$3918": 0x8040d538,
		"instance$3918": 0x8040d538,
		"Enemy::instance$3930": 0x8040d540,
		"instance$3930": 0x8040d540,
		"Enemy::instance$3940": 0x8040d548,
		"instance$3940": 0x8040d548,
		"Enemy::instance$3954": 0x8040d550,
		"instance$3954": 0x8040d550,
		"Enemy::instance$3991": 0x8040d558,
		"instance$3991": 0x8040d558,
		"Enemy::instance$4009": 0x8040d568,
		"instance$4009": 0x8040d568,
		"Enemy::instance$4025": 0x8040d570,
		"instance$4025": 0x8040d570,
		"Enemy::instance$3115": 0x8040d590,
		"instance$3115": 0x8040d590,
		"Enemy::instance$3130": 0x8040d598,
		"instance$3130": 0x8040d598,
		"Enemy::instance$3155": 0x8040d5a0,
		"instance$3155": 0x8040d5a0,
		"Enemy::instance$3180": 0x8040d5b0,
		"instance$3180": 0x8040d5b0,
		"Enemy::instance$3197": 0x8040d5b8,
		"instance$3197": 0x8040d5b8,
		"Enemy::instance$3248": 0x8040d5c8,
		"instance$3248": 0x8040d5c8,
		"Enemy::instance$3270": 0x8040d5d0,
		"instance$3270": 0x8040d5d0,
		"Enemy::instance$3282": 0x8040d5d8,
		"instance$3282": 0x8040d5d8,
		"Enemy::instance$3531": 0x8040d5e4,
		"instance$3531": 0x8040d5e4,
		"Enemy::instance$3543": 0x8040d5ec,
		"instance$3543": 0x8040d5ec,
		"Enemy::instance$3556": 0x8040d5f4,
		"instance$3556": 0x8040d5f4,
		"Enemy::instance$3479": 0x8040d5fc,
		"instance$3479": 0x8040d5fc,
		"Enemy::instance$3526": 0x8040d604,
		"instance$3526": 0x8040d604,
		"Enemy::instance$3539": 0x8040d60c,
		"instance$3539": 0x8040d60c,
		"Enemy::instance$3553": 0x8040d614,
		"instance$3553": 0x8040d614,
		"Enemy::instance$3564": 0x8040d61c,
		"instance$3564": 0x8040d61c,
		"Enemy::instance$3581": 0x8040d624,
		"instance$3581": 0x8040d624,
		"Enemy::instance$3591": 0x8040d62c,
		"instance$3591": 0x8040d62c,
		"Enemy::instance$3610": 0x8040d634,
		"instance$3610": 0x8040d634,
		"Enemy::instance$3629": 0x8040d63c,
		"instance$3629": 0x8040d63c,
		"Enemy::instance$3643": 0x8040d644,
		"instance$3643": 0x8040d644,
		"Enemy::instance$3653": 0x8040d64c,
		"instance$3653": 0x8040d64c,
		"Enemy::instance$3110": 0x8040d658,
		"instance$3110": 0x8040d658,
		"Enemy::instance$3148": 0x8040d668,
		"instance$3148": 0x8040d668,
		"Enemy::instance$3176": 0x8040d670,
		"instance$3176": 0x8040d670,
		"Enemy::instance$3200": 0x8040d678,
		"instance$3200": 0x8040d678,
		"Enemy::instance$3221": 0x8040d688,
		"instance$3221": 0x8040d688,
		"Enemy::instance$3254": 0x8040d6a0,
		"instance$3254": 0x8040d6a0,
		"Enemy::instance$3267": 0x8040d6a8,
		"instance$3267": 0x8040d6a8,
		"Enemy::instance$3457": 0x8040d6d4,
		"instance$3457": 0x8040d6d4,
		"Enemy::instance$3470": 0x8040d6dc,
		"instance$3470": 0x8040d6dc,
		"Enemy::instance$3137": 0x8040d6ec,
		"instance$3137": 0x8040d6ec,
		"Enemy::instance$3163": 0x8040d6f4,
		"instance$3163": 0x8040d6f4,
		"Enemy::instance$3344": 0x8040d70c,
		"instance$3344": 0x8040d70c,
		"Enemy::instance$3407": 0x8040d714,
		"instance$3407": 0x8040d714,
		"Enemy::instance$3425": 0x8040d71c,
		"instance$3425": 0x8040d71c,
		"Enemy::instance$3439": 0x8040d724,
		"instance$3439": 0x8040d724,
		"Enemy::instance$3449": 0x8040d72c,
		"instance$3449": 0x8040d72c,
		"Enemy::instance$3473": 0x8040d734,
		"instance$3473": 0x8040d734,
		"Enemy::instance$3500": 0x8040d73c,
		"instance$3500": 0x8040d73c,
		"Enemy::instance$3199": 0x8040d744,
		"instance$3199": 0x8040d744,
		"Enemy::instance$4027": 0x8040d754,
		"instance$4027": 0x8040d754,
		"Enemy::instance$4069": 0x8040d75c,
		"instance$4069": 0x8040d75c,
		"Enemy::instance$4083": 0x8040d764,
		"instance$4083": 0x8040d764,
		"Enemy::instance$4093": 0x8040d76c,
		"instance$4093": 0x8040d76c,
		"Enemy::instance$4106": 0x8040d774,
		"instance$4106": 0x8040d774,
		"Enemy::instance$4128": 0x8040d77c,
		"instance$4128": 0x8040d77c,
		"Enemy::instance$4144": 0x8040d784,
		"instance$4144": 0x8040d784,
		"Enemy::instance$4160": 0x8040d78c,
		"instance$4160": 0x8040d78c,
		"Enemy::instance$4195": 0x8040d794,
		"instance$4195": 0x8040d794,
		"Enemy::instance$4206": 0x8040d79c,
		"instance$4206": 0x8040d79c,
		"Enemy::instance$2589": 0x8040d7a4,
		"instance$2589": 0x8040d7a4,
		"Enemy::instance$3010": 0x8040d7ac,
		"instance$3010": 0x8040d7ac,
		"Enemy::instance$3033": 0x8040d7b4,
		"instance$3033": 0x8040d7b4,
		"Enemy::instance$3042": 0x8040d7bc,
		"instance$3042": 0x8040d7bc,
		"Enemy::instance$3055": 0x8040d7c4,
		"Enemy::instance$3079": 0x8040d7cc,
		"instance$3079": 0x8040d7cc,
		"Enemy::instance$3089": 0x8040d7d4,
		"instance$3089": 0x8040d7d4,
		"Enemy::instance$3101": 0x8040d7dc,
		"instance$3101": 0x8040d7dc,
		"Enemy::instance$3283": 0x8040d7e4,
		"instance$3283": 0x8040d7e4,
		"Enemy::instance$3296": 0x8040d7ec,
		"instance$3296": 0x8040d7ec,
		"Enemy::instance$3333": 0x8040d7f4,
		"instance$3333": 0x8040d7f4,
		"Enemy::instance$3366": 0x8040d7fc,
		"instance$3366": 0x8040d7fc,
		"Enemy::instance$3410": 0x8040d80c,
		"instance$3410": 0x8040d80c,
		"Enemy::instance$3462": 0x8040d81c,
		"instance$3462": 0x8040d81c,
		"Enemy::instance$3226": 0x8040d82c,
		"instance$3226": 0x8040d82c,
		"Enemy::instance$3800": 0x8040d85c,
		"instance$3800": 0x8040d85c,
		"Enemy::instance$3813": 0x8040d864,
		"instance$3813": 0x8040d864,
		"Enemy::instance$3826": 0x8040d86c,
		"instance$3826": 0x8040d86c,
		"Enemy::instance$3886": 0x8040d888,
		"instance$3886": 0x8040d888,
		"Enemy::instance$3894": 0x8040d890,
		"instance$3894": 0x8040d890,
		"Enemy::instance$3925": 0x8040d898,
		"instance$3925": 0x8040d898,
		"Enemy::instance$3944": 0x8040d8a0,
		"instance$3944": 0x8040d8a0,
		"Enemy::instance$3971": 0x8040d8a8,
		"instance$3971": 0x8040d8a8,
		"Enemy::instance$2972": 0x8040d8b8,
		"instance$2972": 0x8040d8b8,
		"Enemy::instance$2969": 0x8040d8e4,
		"instance$2969": 0x8040d8e4,
		"Enemy::instance$2983": 0x8040d8ec,
		"instance$2983": 0x8040d8ec,
		"Enemy::instance$3022": 0x8040d8fc,
		"instance$3022": 0x8040d8fc,
		"Enemy::instance$3036": 0x8040d904,
		"instance$3036": 0x8040d904,
		"Enemy::instance$3058": 0x8040d90c,
		"instance$3058": 0x8040d90c,
		"Enemy::instance$3212": 0x8040d924,
		"instance$3212": 0x8040d924,
		"Enemy::instance$3179": 0x8040d94c,
		"instance$3179": 0x8040d94c,
		"Enemy::instance$3196": 0x8040d954,
		"instance$3196": 0x8040d954,
		"Enemy::instance$3250": 0x8040d96c,
		"instance$3250": 0x8040d96c,
		"Enemy::instance$2774": 0x8040d98c,
		"instance$2774": 0x8040d98c,
		"Enemy::instance$2796": 0x8040d994,
		"instance$2796": 0x8040d994,
		"Enemy::instance$2974": 0x8040d9dc,
		"instance$2974": 0x8040d9dc,
		"Enemy::instance$3004": 0x8040d9e4,
		"instance$3004": 0x8040d9e4,
		"Enemy::instance$3078": 0x8040d9f4,
		"instance$3078": 0x8040d9f4,
		"Enemy::instance$3403": 0x8040da1c,
		"instance$3403": 0x8040da1c,
		"Enemy::instance$3417": 0x8040da24,
		"instance$3417": 0x8040da24,
		"Enemy::instance$3430": 0x8040da2c,
		"instance$3430": 0x8040da2c,
		"Enemy::instance$3458": 0x8040da34,
		"instance$3458": 0x8040da34,
		"Enemy::instance$3472": 0x8040da3c,
		"instance$3472": 0x8040da3c,
		"Enemy::instance$3486": 0x8040da44,
		"instance$3486": 0x8040da44,
		"Enemy::instance$2859": 0x8040da68,
		"instance$2859": 0x8040da68,
		"Enemy::instance$2685": 0x8040da7c,
		"instance$2685": 0x8040da7c,
		"Enemy::instance$2704": 0x8040da8c,
		"instance$2704": 0x8040da8c,
		"Enemy::instance$2712": 0x8040da94,
		"instance$2712": 0x8040da94,
		"Enemy::instance$2722": 0x8040da9c,
		"instance$2722": 0x8040da9c,
		"Enemy::instance$2730": 0x8040daa4,
		"instance$2730": 0x8040daa4,
		"Enemy::instance$2890": 0x8040dab4,
		"instance$2890": 0x8040dab4,
		"Enemy::instance$2842": 0x8040dacc,
		"instance$2842": 0x8040dacc,
		"Enemy::instance$2854": 0x8040dad4,
		"instance$2854": 0x8040dad4,
		"Enemy::instance$2864": 0x8040dadc,
		"instance$2864": 0x8040dadc,
		"Enemy::instance$2876": 0x8040dae4,
		"instance$2876": 0x8040dae4,
		"Enemy::instance$2889": 0x8040daec,
		"instance$2889": 0x8040daec,
		"Enemy::instance$2911": 0x8040dafc,
		"instance$2911": 0x8040dafc,
		"Enemy::instance$2879": 0x8040db4c,
		"instance$2879": 0x8040db4c,
		"Enemy::instance$2891": 0x8040db54,
		"instance$2891": 0x8040db54,
		"Enemy::instance$3111": 0x8040db74,
		"instance$3111": 0x8040db74,
		"Enemy::instance$3131": 0x8040db84,
		"instance$3131": 0x8040db84,
		"Enemy::instance$3149": 0x8040db94,
		"instance$3149": 0x8040db94,
		"Enemy::instance$3321": 0x8040dba4,
		"instance$3321": 0x8040dba4,
		"Enemy::instance$2664": 0x8040dbb4,
		"instance$2664": 0x8040dbb4,
		"Enemy::instance$2676": 0x8040dbbc,
		"instance$2676": 0x8040dbbc,
		"Enemy::instance$2688": 0x8040dbc4,
		"instance$2688": 0x8040dbc4,
		"Enemy::instance$2698": 0x8040dbcc,
		"instance$2698": 0x8040dbcc,
		"Enemy::instance$2715": 0x8040dbd4,
		"instance$2715": 0x8040dbd4,
		"Enemy::instance$2745": 0x8040dbe4,
		"instance$2745": 0x8040dbe4,
		"Enemy::instance$2755": 0x8040dbec,
		"instance$2755": 0x8040dbec,
		"Enemy::instance$2766": 0x8040dbf4,
		"instance$2766": 0x8040dbf4,
		"Enemy::bathtub$3042": 0x8040dc48,
		"bathtub$3042": 0x8040dc48,
		"Enemy::bathtub$3102": 0x8040dc50,
		"bathtub$3102": 0x8040dc50,
		"Enemy::instance$3102": 0x8040dc5c,
		"instance$3102": 0x8040dc5c,
		"Enemy::instance$3144": 0x8040dc6c,
		"instance$3144": 0x8040dc6c,
		"Enemy::instance$2531": 0x8040dc7c,
		"instance$2531": 0x8040dc7c,
		"Enemy::instance$2543": 0x8040dc84,
		"instance$2543": 0x8040dc84,
		"Enemy::instance$2557": 0x8040dc8c,
		"instance$2557": 0x8040dc8c,
		"Enemy::instance$2567": 0x8040dc94,
		"instance$2567": 0x8040dc94,
		"Enemy::instance$2577": 0x8040dc9c,
		"instance$2577": 0x8040dc9c,
		"Enemy::instance$3132": 0x8040dcbc,
		"instance$3132": 0x8040dcbc,
		"Enemy::instance$2851": 0x8040dcf4,
		"instance$2851": 0x8040dcf4,
		"Enemy::instance$2897": 0x8040dd10,
		"instance$2897": 0x8040dd10,
		"Enemy::instance$2923": 0x8040dd20,
		"instance$2923": 0x8040dd20,
		"Enemy::instance$2929": 0x8040dd28,
		"instance$2929": 0x8040dd28,
		"Enemy::instance$2939": 0x8040dd30,
		"instance$2939": 0x8040dd30,
		"Enemy::instance$3013": 0x8040dd7c,
		"Enemy::instance$3027": 0x8040dd84,
		"instance$3027": 0x8040dd84,
		"Enemy::instance$3037": 0x8040dd8c,
		"instance$3037": 0x8040dd8c,
		"MoveBG::total_use_size$2279": 0x8040df44,
		"total_use_size$2279": 0x8040df44,
		"NPC::sViewObjName$2623": 0x8040e054,
		"sViewObjName$2623": 0x8040e054,
		"MSStageCubeFade::smInstance": 0x8040e218,
		"MSStageCubeFadeDouble::smInstance": 0x8040e21c,
		"JKRArchive::sCurrentDirID": 0x8040e228,
		"sCurrentDirID": 0x8040e228,
		"JKRAram::sAramObject": 0x8040e230,
		"sAramObject": 0x8040e230,
		"JSystem::srcAddress": 0x8040e254,
		"srcAddress": 0x8040e254,
		"JSystem::whatdo": 0x8040e268,
		"whatdo": 0x8040e268,
		"JSystem::whatdo2": 0x8040e26c,
		"whatdo2": 0x8040e26c,
		"JSystem::DBfoundSize": 0x8040e270,
		"DBfoundSize": 0x8040e270,
		"JSystem::DBfoundOffset": 0x8040e274,
		"DBfoundOffset": 0x8040e274,
		"JSystem::DBfoundBlock": 0x8040e278,
		"DBfoundBlock": 0x8040e278,
		"JSystem::DBnewFreeBlock": 0x8040e27c,
		"DBnewFreeBlock": 0x8040e27c,
		"JSystem::DBnewUsedBlock": 0x8040e280,
		"DBnewUsedBlock": 0x8040e280,
		"JKRFileLoader::sCurrentVolume": 0x8040e288,
		"sCurrentVolume": 0x8040e288,
		"JKRHeap::sSystemHeap": 0x8040e290,
		"sSystemHeap": 0x8040e290,
		"JKRHeap::sCurrentHeap": 0x8040e294,
		"JKRHeap::sRootHeap": 0x8040e298,
		"sRootHeap": 0x8040e298,
		"JKRHeap::mErrorHandler": 0x8040e29c,
		"mErrorHandler": 0x8040e29c,
		"JKRHeap::mCodeStart": 0x8040e2a0,
		"mCodeStart": 0x8040e2a0,
		"JKRHeap::mCodeEnd": 0x8040e2a4,
		"mCodeEnd": 0x8040e2a4,
		"JKRHeap::mUserRamStart": 0x8040e2a8,
		"mUserRamStart": 0x8040e2a8,
		"JKRHeap::mUserRamEnd": 0x8040e2ac,
		"mUserRamEnd": 0x8040e2ac,
		"JKRHeap::mMemorySize": 0x8040e2b0,
		"mMemorySize": 0x8040e2b0,
		"JUTException::sErrorManager": 0x8040e2b8,
		"sErrorManager": 0x8040e2b8,
		"JUTException::sPreUserCallback": 0x8040e2bc,
		"sPreUserCallback": 0x8040e2bc,
		"JUTException::sPostUserCallback": 0x8040e2c0,
		"sPostUserCallback": 0x8040e2c0,
		"JUTException::sConsoleBuffer": 0x8040e2c4,
		"sConsoleBuffer": 0x8040e2c4,
		"JUTException::sConsoleBufferSize": 0x8040e2c8,
		"sConsoleBufferSize": 0x8040e2c8,
		"JUTException::sConsole": 0x8040e2cc,
		"sConsole": 0x8040e2cc,
		"JUTException::msr": 0x8040e2d0,
		"msr": 0x8040e2d0,
		"JUTException::fpscr": 0x8040e2d4,
		"fpscr": 0x8040e2d4,
		"JUTDirectPrint::sDirectPrint": 0x8040e2d8,
		"sDirectPrint": 0x8040e2d8,
		"JUTGamePad::mPadAssign": 0x8040e2e4,
		"mPadAssign": 0x8040e2e4,
		"JUTGamePad::mSuppressPadReset": 0x8040e2e8,
		"mSuppressPadReset": 0x8040e2e8,
		"JUTGamePad::sAnalogMode": 0x8040e2ec,
		"sAnalogMode": 0x8040e2ec,
		"JUTGamePad::CRumble::mStatus": 0x8040e2f0,
		"mStatus": 0x8040e2f0,
		"JUTGamePad::CRumble::mEnable": 0x8040e2f4,
		"mEnable": 0x8040e2f4,
		"JUTGamePad::C3ButtonReset::sCallback": 0x8040e2f8,
		"sCallback": 0x8040e2f8,
		"JUTGamePad::C3ButtonReset::sCallbackArg": 0x8040e2fc,
		"sCallbackArg": 0x8040e2fc,
		"JUTGamePad::C3ButtonReset::sResetOccurredPort": 0x8040e30c,
		"sResetOccurredPort": 0x8040e30c,
		"JSystem::jmaSinShift": 0x8040e314,
		"jmaSinShift": 0x8040e314,
		"JSystem::jmaSinTable": 0x8040e318,
		"jmaSinTable": 0x8040e318,
		"JSystem::jmaCosTable": 0x8040e31c,
		"jmaCosTable": 0x8040e31c,
		"J2DPrint::mStrBuff": 0x8040e320,
		"mStrBuff": 0x8040e320,
		"J2DPrint::mStrBuffSize": 0x8040e328,
		"mStrBuffSize": 0x8040e328,
		"J3DShapeMtx::currentPipeline": 0x8040e330,
		"currentPipeline": 0x8040e330,
		"JSystem::j3dDefaultViewNo": 0x8040e338,
		"j3dDefaultViewNo": 0x8040e338,
		"JSystem::dmaBuf": 0x8040e384,
		"dmaBuf": 0x8040e384,
		"JSystem::dmaEnd": 0x8040e388,
		"dmaEnd": 0x8040e388,
		"JSystem::dmaCurrent": 0x8040e38c,
		"dmaCurrent": 0x8040e38c,
		"JKRDecomp::sDecompObject": 0x8040e3b0,
		"sDecompObject": 0x8040e3b0,
		"J3DDrawPacket::sInterruptFlag": 0x8040e3b8,
		"sInterruptFlag": 0x8040e3b8,
		"J3DDrawBuffer::entryNum": 0x8040e3c0,
		"entryNum": 0x8040e3c0,
		"JKRAramStream::sAramStreamObject": 0x8040e3c8,
		"sAramStreamObject": 0x8040e3c8,
		"JKRAramStream::transBuffer": 0x8040e3cc,
		"transBuffer": 0x8040e3cc,
		"JKRAramStream::transSize": 0x8040e3d0,
		"transSize": 0x8040e3d0,
		"JKRAramStream::transHeap": 0x8040e3d4,
		"transHeap": 0x8040e3d4,
		"JUTAssertion::@unnamed@::sMessageLife": 0x8040e3d8,
		"sMessageLife": 0x8040e3d8,
		"JUTVideo::sManager": 0x8040e3e0,
		"JUTRomFont::spAboutEncoding_": 0x8040e3e8,
		"spAboutEncoding_": 0x8040e3e8,
		"JUTRomFont::spFontHeader_": 0x8040e3ec,
		"spFontHeader_": 0x8040e3ec,
		"JUTRomFont::suFontHeaderRefered_": 0x8040e3f0,
		"suFontHeaderRefered_": 0x8040e3f0,
		"JUTConsoleManager::sManager": 0x8040e3f8,
		"JSystem::sReportConsole": 0x8040e3fc,
		"sReportConsole": 0x8040e3fc,
		"JSystem::sWarningConsole": 0x8040e400,
		"sWarningConsole": 0x8040e400,
		"JDrama::TNameRefGen::instance": 0x8040e408,
		"instance": 0x8040e408,
		"JADHioNode::smCurrentHeap": 0x8040e410,
		"smCurrentHeap": 0x8040e410,
		"JSystem::oRandom$356": 0x8040e41c,
		"oRandom$356": 0x8040e41c,
		"JALSystem::spFManager": 0x8040e420,
		"spFManager": 0x8040e420,
		"JAInter::TAsnData::asnData": 0x8040e428,
		"asnData": 0x8040e428,
		"JAIBasic::basic": 0x8040e430,
		"basic": 0x8040e430,
		"JSystem::_dinfo$1264": 0x8040e434,
		"_dinfo$1264": 0x8040e434,
		"JSystem::_info$1317": 0x8040e438,
		"_info$1317": 0x8040e438,
		"JAIConst::random": 0x8040e440,
		"random": 0x8040e440,
		"JAInter::TDebugHeap::currentHeap": 0x8040e448,
		"currentHeap": 0x8040e448,
		"JAInter::StreamLib::adpcm_remain": 0x8040e450,
		"adpcm_remain": 0x8040e450,
		"JAInter::StreamLib::adpcm_loadpoint": 0x8040e454,
		"adpcm_loadpoint": 0x8040e454,
		"JAInter::StreamLib::loadsize": 0x8040e458,
		"loadsize": 0x8040e458,
		"JAInter::StreamLib::adpcm_buffer": 0x8040e45c,
		"adpcm_buffer": 0x8040e45c,
		"JAInter::StreamLib::loop_buffer": 0x8040e460,
		"loop_buffer": 0x8040e460,
		"JAInter::StreamLib::store_buffer": 0x8040e464,
		"store_buffer": 0x8040e464,
		"JAInter::StreamLib::assign_ch": 0x8040e468,
		"assign_ch": 0x8040e468,
		"JAInter::StreamLib::playside": 0x8040e470,
		"playside": 0x8040e470,
		"JAInter::StreamLib::playback_samples": 0x8040e474,
		"playback_samples": 0x8040e474,
		"JAInter::StreamLib::loadup_samples": 0x8040e478,
		"loadup_samples": 0x8040e478,
		"JAInter::StreamLib::adpcmbuf_state": 0x8040e47c,
		"adpcmbuf_state": 0x8040e47c,
		"JAInter::StreamLib::movieframe": 0x8040e480,
		"movieframe": 0x8040e480,
		"JAInter::StreamLib::outvolume": 0x8040e48c,
		"outvolume": 0x8040e48c,
		"JAInter::StreamLib::outpitch": 0x8040e490,
		"outpitch": 0x8040e490,
		"JAInter::StreamLib::outpan": 0x8040e494,
		"outpan": 0x8040e494,
		"JAInter::StreamLib::stackvolume": 0x8040e498,
		"stackvolume": 0x8040e498,
		"JAInter::StreamLib::stackpitch": 0x8040e49c,
		"stackpitch": 0x8040e49c,
		"JAInter::StreamLib::stackpan": 0x8040e4a0,
		"stackpan": 0x8040e4a0,
		"JAInter::StreamLib::loop_start_flag": 0x8040e4a8,
		"loop_start_flag": 0x8040e4a8,
		"JAInter::StreamLib::outpause": 0x8040e4ac,
		"outpause": 0x8040e4ac,
		"JAInter::StreamLib::playmode": 0x8040e4b0,
		"playmode": 0x8040e4b0,
		"JAInter::StreamLib::shift_sample": 0x8040e4b4,
		"shift_sample": 0x8040e4b4,
		"JAInter::StreamLib::extra_sample": 0x8040e4b8,
		"extra_sample": 0x8040e4b8,
		"JAInter::StreamLib::DvdLoadFlag": 0x8040e4bc,
		"DvdLoadFlag": 0x8040e4bc,
		"JAInter::StreamLib::startInitFlag": 0x8040e4c0,
		"startInitFlag": 0x8040e4c0,
		"JAInter::StreamLib::Mode": 0x8040e4c4,
		"Mode": 0x8040e4c4,
		"JAInter::StreamLib::Head": 0x8040e4c8,
		"Head": 0x8040e4c8,
		"JSystem::before$612": 0x8040e4d0,
		"before$612": 0x8040e4d0,
		"JSystem::oldstat$823": 0x8040e4e0,
		"oldstat$823": 0x8040e4e0,
		"JSystem::old_dspside$839": 0x8040e4e8,
		"old_dspside$839": 0x8040e4e8,
		"JAIGlobalParameter::interfaceHeapSize": 0x8040e4f4,
		"interfaceHeapSize": 0x8040e4f4,
		"JAIGlobalParameter::audioResPath": 0x8040e4f8,
		"audioResPath": 0x8040e4f8,
		"JAIGlobalParameter::minDistanceVolume": 0x8040e4fc,
		"minDistanceVolume": 0x8040e4fc,
		"JAISound::interPointer": 0x8040e500,
		"interPointer": 0x8040e500,
		"JASystem::TBank::sCurrentHeap": 0x8040e508,
		"JASystem::BankMgr::sTableSize": 0x8040e510,
		"JASystem::BankMgr::sBankArray": 0x8040e514,
		"sBankArray": 0x8040e514,
		"JASystem::BankMgr::sVir2PhyTable": 0x8040e518,
		"sVir2PhyTable": 0x8040e518,
		"JASystem::BNKParser::sUsedHeapSize": 0x8040e520,
		"JSystem::oscp$295": 0x8040e528,
		"oscp$295": 0x8040e528,
		"JSystem::oRandom$331": 0x8040e534,
		"oRandom$331": 0x8040e534,
		"JASystem::TWaveBank::sCurrentHeap": 0x8040e538,
		"JASystem::WaveBankMgr::sTableSize": 0x8040e540,
		"JASystem::WaveBankMgr::sWaveBank": 0x8040e544,
		"sWaveBank": 0x8040e544,
		"JASystem::WSParser::sUsedHeapSize": 0x8040e548,
		"JASystem::AudioThread::isDSPBoot": 0x8040e550,
		"isDSPBoot": 0x8040e550,
		"JASystem::AudioThread::audioproc_mq_init": 0x8040e554,
		"audioproc_mq_init": 0x8040e554,
		"JASystem::AudioThread::intcount": 0x8040e558,
		"intcount": 0x8040e558,
		"JASystem::AudioThread::priority_set": 0x8040e55c,
		"priority_set": 0x8040e55c,
		"JASystem::AudioThread::jac_pri": 0x8040e560,
		"jac_pri": 0x8040e560,
		"JASystem::AudioThread::dvd_pri": 0x8040e564,
		"dvd_pri": 0x8040e564,
		"JSystem::first$120": 0x8040e568,
		"first$120": 0x8040e568,
		"JASystem::Driver::DSPQueue::waitp": 0x8040e570,
		"waitp": 0x8040e570,
		"JASystem::Driver::DSPQueue::waittime": 0x8040e574,
		"waittime": 0x8040e574,
		"JASystem::Driver::DSPQueue::cur_waits": 0x8040e578,
		"cur_waits": 0x8040e578,
		"JASystem::Driver::DSPQueue::cur_top": 0x8040e57c,
		"cur_top": 0x8040e57c,
		"JASystem::Driver::DSPQueue::cur_tail": 0x8040e580,
		"cur_tail": 0x8040e580,
		"JASystem::ChGlobal::GLOBAL_CHANNEL": 0x8040e588,
		"GLOBAL_CHANNEL": 0x8040e588,
		"JASystem::ChGlobal::CHANNEL": 0x8040e58c,
		"CHANNEL": 0x8040e58c,
		"JASystem::ChGlobal::OSCILLATOR": 0x8040e590,
		"OSCILLATOR": 0x8040e590,
		"JASystem::DSPBuf::dac_sync_counter": 0x8040e59c,
		"dac_sync_counter": 0x8040e59c,
		"JASystem::TDSPChannel::DSPCH": 0x8040e5a0,
		"DSPCH": 0x8040e5a0,
		"JASystem::TDSPChannel::smnUse": 0x8040e5a4,
		"smnUse": 0x8040e5a4,
		"JSystem::first$144": 0x8040e5a8,
		"first$144": 0x8040e5a8,
		"JASystem::old_time": 0x8040e5b0,
		"old_time": 0x8040e5b0,
		"JASystem::DSPInterface::CH_BUF": 0x8040e5b8,
		"CH_BUF": 0x8040e5b8,
		"JASystem::DSPInterface::FX_BUF": 0x8040e5bc,
		"FX_BUF": 0x8040e5bc,
		"JASystem::Kernel::JASUniversalDacCounter": 0x8040e5c0,
		"JASUniversalDacCounter": 0x8040e5c0,
		"JASystem::Kernel::lastRspMadep": 0x8040e5c4,
		"lastRspMadep": 0x8040e5c4,
		"JASystem::Kernel::useRspMadep": 0x8040e5c8,
		"useRspMadep": 0x8040e5c8,
		"JASystem::Kernel::vframeWorkRunning": 0x8040e5cc,
		"vframeWorkRunning": 0x8040e5cc,
		"JASystem::Kernel::dacCallbackFunc": 0x8040e5d0,
		"dacCallbackFunc": 0x8040e5d0,
		"JASystem::Kernel::JASVframeCounter": 0x8040e5d4,
		"JASVframeCounter": 0x8040e5d4,
		"JASystem::Kernel::extMixCallback": 0x8040e5d8,
		"extMixCallback": 0x8040e5d8,
		"JSystem::dacp$140": 0x8040e5e0,
		"dacp$140": 0x8040e5e0,
		"JASystem::Calc::JASC_SINTABLE": 0x8040e5e8,
		"JASC_SINTABLE": 0x8040e5e8,
		"JASystem::Calc::JASC_DOL2TABLE": 0x8040e5ec,
		"JASC_DOL2TABLE": 0x8040e5ec,
		"JASystem::Kernel::callList": 0x8040e5f0,
		"callList": 0x8040e5f0,
		"JSystem::cmd_once": 0x8040e5f8,
		"cmd_once": 0x8040e5f8,
		"JSystem::cmd_stay": 0x8040e600,
		"cmd_stay": 0x8040e600,
		"JASystem::Dvd::mqInit": 0x8040e608,
		"mqInit": 0x8040e608,
		"JASystem::Dvd::buffersize": 0x8040e60c,
		"buffersize": 0x8040e60c,
		"JASystem::Dvd::buffers": 0x8040e610,
		"buffers": 0x8040e610,
		"JASystem::Dvd::nextBufferSize": 0x8040e614,
		"nextBufferSize": 0x8040e614,
		"JASystem::Dvd::nextBufferTop": 0x8040e618,
		"nextBufferTop": 0x8040e618,
		"JASystem::Dvd::nextBuffers": 0x8040e61c,
		"nextBuffers": 0x8040e61c,
		"JASystem::Dvd::audioDvdBuffer": 0x8040e620,
		"audioDvdBuffer": 0x8040e620,
		"JASystem::Dvd::bufferLoad": 0x8040e628,
		"bufferLoad": 0x8040e628,
		"JASystem::Dvd::bufferFull": 0x8040e62c,
		"bufferFull": 0x8040e62c,
		"JASystem::Dvd::callStackArray": 0x8040e630,
		"callStackArray": 0x8040e630,
		"JASystem::Dvd::msgBuf": 0x8040e634,
		"msgBuf": 0x8040e634,
		"JASystem::Dvd::curQ": 0x8040e638,
		"curQ": 0x8040e638,
		"JASystem::Dvd::dvdtSleep": 0x8040e63c,
		"dvdtSleep": 0x8040e63c,
		"JASystem::Dvd::dvdThreadPauseFlag": 0x8040e644,
		"dvdThreadPauseFlag": 0x8040e644,
		"JASystem::Dvd::errorCallback": 0x8040e648,
		"errorCallback": 0x8040e648,
		"JASystem::Dvd::dvdFileDics": 0x8040e64c,
		"dvdFileDics": 0x8040e64c,
		"JASystem::Dvd::dvdFile": 0x8040e650,
		"dvdFile": 0x8040e650,
		"JASystem::Dvd::dvdEntryNum": 0x8040e654,
		"dvdEntryNum": 0x8040e654,
		"JSystem::arq_index$316": 0x8040e658,
		"arq_index$316": 0x8040e658,
		"JASystem::HardStream::streamFiles": 0x8040e664,
		"streamFiles": 0x8040e664,
		"JASystem::HardStream::playList": 0x8040e668,
		"playList": 0x8040e668,
		"JSystem::cur_finfo$426": 0x8040e66c,
		"cur_finfo$426": 0x8040e66c,
		"JSystem::last_frame$577": 0x8040e674,
		"last_frame$577": 0x8040e674,
		"JASystem::Kernel::global_id": 0x8040e680,
		"global_id": 0x8040e680,
		"JASystem::Kernel::gOutputRate": 0x8040e688,
		"gOutputRate": 0x8040e688,
		"JASystem::Kernel::gAiSetting": 0x8040e68c,
		"gAiSetting": 0x8040e68c,
		"JSystem::JASDram": 0x8040e690,
		"JASDram": 0x8040e690,
		"JASystem::Kernel::JASAramDmaBufferTop": 0x8040e694,
		"JASAramDmaBufferTop": 0x8040e694,
		"JASystem::Kernel::audioAramTop": 0x8040e698,
		"audioAramTop": 0x8040e698,
		"JASystem::Kernel::CARD_SECURITY_BUFFER": 0x8040e69c,
		"CARD_SECURITY_BUFFER": 0x8040e69c,
		"JASystem::Vload::vlDirName": 0x8040e6a0,
		"vlDirName": 0x8040e6a0,
		"JASystem::Vload::vlArcName": 0x8040e6a4,
		"vlArcName": 0x8040e6a4,
		"JASystem::Vload::vlArc": 0x8040e6a8,
		"vlArc": 0x8040e6a8,
		"JASystem::Vload::vlCurrentArcs": 0x8040e6ac,
		"vlCurrentArcs": 0x8040e6ac,
		"JASystem::TTrack::sCallBackFunc": 0x8040e6b4,
		"sCallBackFunc": 0x8040e6b4,
		"JASystem::TrackMgr::sTrackPool": 0x8040e6b8,
		"sTrackPool": 0x8040e6b8,
		"JASystem::TrackMgr::sSeqOuter": 0x8040e6bc,
		"sSeqOuter": 0x8040e6bc,
		"JASystem::TrackMgr::sRootTrack": 0x8040e6c0,
		"sRootTrack": 0x8040e6c0,
		"JASystem::TrackMgr::sFreeSeqpQueue": 0x8040e6c4,
		"sFreeSeqpQueue": 0x8040e6c4,
		"JASystem::TrackMgr::sRootSeqCount": 0x8040e6c8,
		"sRootSeqCount": 0x8040e6c8,
		"JASystem::TrackMgr::sTrackCount": 0x8040e6cc,
		"sTrackCount": 0x8040e6cc,
		"JASystem::TrackMgr::sTLists": 0x8040e6d0,
		"sTLists": 0x8040e6d0,
		"JASystem::TrackMgr::seqRemain": 0x8040e6d4,
		"seqRemain": 0x8040e6d4,
		"JASystem::TrackMgr::getP": 0x8040e6d8,
		"getP": 0x8040e6d8,
		"JASystem::TrackMgr::backP": 0x8040e6dc,
		"backP": 0x8040e6dc,
		"JSystem::FieldRand": 0x8040e6e0,
		"FieldRand": 0x8040e6e0,
		"JPADrawContext::pcb": 0x8040e6e8,
		"pcb": 0x8040e6e8,
		"JSystem::flag": 0x8040e6f0,
		"flag": 0x8040e6f0,
		"JSystem::taskreadp": 0x8040e6f8,
		"taskreadp": 0x8040e6f8,
		"JSystem::taskwritep": 0x8040e6fc,
		"taskwritep": 0x8040e6fc,
		"JSystem::__DSP_tmp_task": 0x8040e700,
		"__DSP_tmp_task": 0x8040e700,
		"JSystem::AUDIO_UPDATE_REQUEST": 0x8040e70c,
		"AUDIO_UPDATE_REQUEST": 0x8040e70c,
		"JSystem::DSP_prior_task": 0x8040e710,
		"DSP_prior_task": 0x8040e710,
		"Runtime.PPCEABI.H::__global_destructor_chain": 0x8040e718,
		"__global_destructor_chain": 0x8040e718,
		"MSL_C.PPCEABI.bare.H::__aborting": 0x8040e720,
		"__aborting": 0x8040e720,
		"MSL_C.PPCEABI.bare.H::atexit_curr_func": 0x8040e724,
		"atexit_curr_func": 0x8040e724,
		"MSL_C.PPCEABI.bare.H::__atexit_curr_func": 0x8040e728,
		"__atexit_curr_func": 0x8040e728,
		"MSL_C.PPCEABI.bare.H::__stdio_exit": 0x8040e72c,
		"__stdio_exit": 0x8040e72c,
		"MSL_C.PPCEABI.bare.H::__console_exit": 0x8040e730,
		"__console_exit": 0x8040e730,
		"MSL_C.PPCEABI.bare.H::errno": 0x8040e738,
		"errno": 0x8040e738,
		"MSL_C.PPCEABI.bare.H::initialized$16": 0x8040e740,
		"initialized$16": 0x8040e740,
		"db::__DBInterface": 0x8040e748,
		"__DBInterface": 0x8040e748,
		"db::DBVerbose": 0x8040e74c,
		"DBVerbose": 0x8040e74c,
		"os::BootInfo": 0x8040e750,
		"os::BI2DebugFlag": 0x8040e754,
		"BI2DebugFlag": 0x8040e754,
		"os::BI2DebugFlagHolder": 0x8040e758,
		"BI2DebugFlagHolder": 0x8040e758,
		"os::__OSIsGcam": 0x8040e75c,
		"__OSIsGcam": 0x8040e75c,
		"os::AreWeInitialized": 0x8040e760,
		"AreWeInitialized": 0x8040e760,
		"os::OSExceptionTable": 0x8040e764,
		"OSExceptionTable": 0x8040e764,
		"os::__OSSavedRegionEnd": 0x8040e768,
		"__OSSavedRegionEnd": 0x8040e768,
		"os::__OSSavedRegionStart": 0x8040e76c,
		"__OSSavedRegionStart": 0x8040e76c,
		"os::__OSInIPL": 0x8040e770,
		"__OSInIPL": 0x8040e770,
		"os::AlarmQueue": 0x8040e780,
		"AlarmQueue": 0x8040e780,
		"os::HeapArray": 0x8040e788,
		"HeapArray": 0x8040e788,
		"os::NumHeaps": 0x8040e78c,
		"NumHeaps": 0x8040e78c,
		"os::ArenaStart": 0x8040e790,
		"ArenaStart": 0x8040e790,
		"os::ArenaEnd": 0x8040e794,
		"ArenaEnd": 0x8040e794,
		"os::__OSArenaHi": 0x8040e798,
		"__OSArenaHi": 0x8040e798,
		"os::FontData": 0x8040e7a0,
		"FontData": 0x8040e7a0,
		"os::SheetImage": 0x8040e7a4,
		"SheetImage": 0x8040e7a4,
		"os::WidthTable": 0x8040e7a8,
		"WidthTable": 0x8040e7a8,
		"os::CharsInSheet": 0x8040e7ac,
		"CharsInSheet": 0x8040e7ac,
		"os::InterruptHandlerTable": 0x8040e7b0,
		"InterruptHandlerTable": 0x8040e7b0,
		"os::__OSLastInterruptSrr0": 0x8040e7b4,
		"__OSLastInterruptSrr0": 0x8040e7b4,
		"os::SaveStart": 0x8040e7c8,
		"SaveStart": 0x8040e7c8,
		"os::SaveEnd": 0x8040e7cc,
		"SaveEnd": 0x8040e7cc,
		"os::Prepared": 0x8040e7d0,
		"Prepared": 0x8040e7d0,
		"os::ResetFunctionQueue": 0x8040e7d8,
		"ResetFunctionQueue": 0x8040e7d8,
		"os::ResetCallback": 0x8040e7e0,
		"ResetCallback": 0x8040e7e0,
		"os::Down": 0x8040e7e4,
		"Down": 0x8040e7e4,
		"os::LastState": 0x8040e7e8,
		"os::RunQueueBits": 0x8040e800,
		"RunQueueBits": 0x8040e800,
		"os::RunQueueHint": 0x8040e804,
		"RunQueueHint": 0x8040e804,
		"os::Reschedule": 0x8040e808,
		"Reschedule": 0x8040e808,
		"dvd::StopAtNextInt": 0x8040e810,
		"StopAtNextInt": 0x8040e810,
		"dvd::LastLength": 0x8040e814,
		"LastLength": 0x8040e814,
		"dvd::Callback": 0x8040e818,
		"dvd::ResetCoverCallback": 0x8040e81c,
		"ResetCoverCallback": 0x8040e81c,
		"dvd::ResetOccurred": 0x8040e828,
		"ResetOccurred": 0x8040e828,
		"dvd::WaitingCoverClose": 0x8040e82c,
		"WaitingCoverClose": 0x8040e82c,
		"dvd::Breaking": 0x8040e830,
		"Breaking": 0x8040e830,
		"dvd::WorkAroundType": 0x8040e834,
		"WorkAroundType": 0x8040e834,
		"dvd::WorkAroundSeekLocation": 0x8040e838,
		"WorkAroundSeekLocation": 0x8040e838,
		"dvd::LastCommandWasRead": 0x8040e850,
		"LastCommandWasRead": 0x8040e850,
		"dvd::NextCommandNumber": 0x8040e854,
		"NextCommandNumber": 0x8040e854,
		"dvd::BootInfo": 0x8040e858,
		"dvd::FstStart": 0x8040e85c,
		"FstStart": 0x8040e85c,
		"dvd::FstStringStart": 0x8040e860,
		"FstStringStart": 0x8040e860,
		"dvd::MaxEntryNum": 0x8040e864,
		"MaxEntryNum": 0x8040e864,
		"dvd::currentDirectory": 0x8040e868,
		"currentDirectory": 0x8040e868,
		"dvd::__DVDLongFileNameFlag": 0x8040e86c,
		"__DVDLongFileNameFlag": 0x8040e86c,
		"dvd::__DVDThreadQueue": 0x8040e870,
		"__DVDThreadQueue": 0x8040e870,
		"dvd::executing": 0x8040e878,
		"executing": 0x8040e878,
		"dvd::currID": 0x8040e87c,
		"currID": 0x8040e87c,
		"dvd::bootInfo": 0x8040e880,
		"bootInfo": 0x8040e880,
		"dvd::PauseFlag": 0x8040e884,
		"PauseFlag": 0x8040e884,
		"dvd::PausingFlag": 0x8040e888,
		"PausingFlag": 0x8040e888,
		"dvd::AutoFinishing": 0x8040e88c,
		"AutoFinishing": 0x8040e88c,
		"dvd::FatalErrorFlag": 0x8040e890,
		"FatalErrorFlag": 0x8040e890,
		"dvd::CurrCommand": 0x8040e894,
		"CurrCommand": 0x8040e894,
		"dvd::Canceling": 0x8040e898,
		"Canceling": 0x8040e898,
		"dvd::CancelCallback": 0x8040e89c,
		"CancelCallback": 0x8040e89c,
		"dvd::ResumeFromHere": 0x8040e8a0,
		"ResumeFromHere": 0x8040e8a0,
		"dvd::CancelLastError": 0x8040e8a4,
		"CancelLastError": 0x8040e8a4,
		"dvd::LastError": 0x8040e8a8,
		"LastError": 0x8040e8a8,
		"dvd::NumInternalRetry": 0x8040e8ac,
		"NumInternalRetry": 0x8040e8ac,
		"dvd::ResetRequired": 0x8040e8b0,
		"ResetRequired": 0x8040e8b0,
		"dvd::FirstTimeInBootrom": 0x8040e8b4,
		"FirstTimeInBootrom": 0x8040e8b4,
		"dvd::DVDInitialized": 0x8040e8b8,
		"DVDInitialized": 0x8040e8b8,
		"dvd::LastState": 0x8040e8bc,
		"dvd::status": 0x8040e8c0,
		"status": 0x8040e8c0,
		"dvd::bb2": 0x8040e8c4,
		"bb2": 0x8040e8c4,
		"dvd::idTmp": 0x8040e8c8,
		"idTmp": 0x8040e8c8,
		"vi::retraceCount": 0x8040e8d0,
		"retraceCount": 0x8040e8d0,
		"vi::flushFlag": 0x8040e8d4,
		"flushFlag": 0x8040e8d4,
		"vi::retraceQueue": 0x8040e8d8,
		"retraceQueue": 0x8040e8d8,
		"vi::PreCB": 0x8040e8e0,
		"PreCB": 0x8040e8e0,
		"vi::PostCB": 0x8040e8e4,
		"PostCB": 0x8040e8e4,
		"vi::encoderType": 0x8040e8e8,
		"encoderType": 0x8040e8e8,
		"vi::changeMode": 0x8040e8f0,
		"vi::shdwChangeMode": 0x8040e900,
		"shdwChangeMode": 0x8040e900,
		"vi::CurrTiming": 0x8040e910,
		"CurrTiming": 0x8040e910,
		"vi::CurrTvMode": 0x8040e914,
		"CurrTvMode": 0x8040e914,
		"vi::FBSet": 0x8040e918,
		"FBSet": 0x8040e918,
		"vi::message$332": 0x8040e91c,
		"message$332": 0x8040e91c,
		"pad::Initialized": 0x8040e920,
		"pad::EnabledBits": 0x8040e924,
		"EnabledBits": 0x8040e924,
		"pad::ResettingBits": 0x8040e928,
		"ResettingBits": 0x8040e928,
		"pad::RecalibrateBits": 0x8040e92c,
		"RecalibrateBits": 0x8040e92c,
		"pad::WaitingBits": 0x8040e930,
		"WaitingBits": 0x8040e930,
		"pad::CheckingBits": 0x8040e934,
		"CheckingBits": 0x8040e934,
		"pad::PendingBits": 0x8040e938,
		"PendingBits": 0x8040e938,
		"pad::SamplingCallback": 0x8040e93c,
		"SamplingCallback": 0x8040e93c,
		"pad::recalibrated$396": 0x8040e940,
		"recalibrated$396": 0x8040e940,
		"pad::__PADSpec": 0x8040e944,
		"__PADSpec": 0x8040e944,
		"ai::__AIS_Callback": 0x8040e948,
		"__AIS_Callback": 0x8040e948,
		"ai::__AID_Callback": 0x8040e94c,
		"__AID_Callback": 0x8040e94c,
		"ai::__CallbackStack": 0x8040e950,
		"__CallbackStack": 0x8040e950,
		"ai::__OldStack": 0x8040e954,
		"__OldStack": 0x8040e954,
		"ai::__AI_init_flag": 0x8040e958,
		"__AI_init_flag": 0x8040e958,
		"ar::__AR_Callback": 0x8040e988,
		"__AR_Callback": 0x8040e988,
		"ar::__AR_Size": 0x8040e98c,
		"__AR_Size": 0x8040e98c,
		"ar::__AR_InternalSize": 0x8040e990,
		"__AR_InternalSize": 0x8040e990,
		"ar::__AR_ExpansionSize": 0x8040e994,
		"__AR_ExpansionSize": 0x8040e994,
		"ar::__AR_StackPointer": 0x8040e998,
		"__AR_StackPointer": 0x8040e998,
		"ar::__AR_FreeBlocks": 0x8040e99c,
		"__AR_FreeBlocks": 0x8040e99c,
		"ar::__AR_BlockLength": 0x8040e9a0,
		"__AR_BlockLength": 0x8040e9a0,
		"ar::__AR_init_flag": 0x8040e9a4,
		"__AR_init_flag": 0x8040e9a4,
		"ar::__ARQRequestQueueHi": 0x8040e9a8,
		"__ARQRequestQueueHi": 0x8040e9a8,
		"ar::__ARQRequestTailHi": 0x8040e9ac,
		"__ARQRequestTailHi": 0x8040e9ac,
		"ar::__ARQRequestQueueLo": 0x8040e9b0,
		"__ARQRequestQueueLo": 0x8040e9b0,
		"ar::__ARQRequestTailLo": 0x8040e9b4,
		"__ARQRequestTailLo": 0x8040e9b4,
		"ar::__ARQRequestPendingHi": 0x8040e9b8,
		"__ARQRequestPendingHi": 0x8040e9b8,
		"ar::__ARQRequestPendingLo": 0x8040e9bc,
		"__ARQRequestPendingLo": 0x8040e9bc,
		"ar::__ARQCallbackHi": 0x8040e9c0,
		"__ARQCallbackHi": 0x8040e9c0,
		"ar::__ARQCallbackLo": 0x8040e9c4,
		"__ARQCallbackLo": 0x8040e9c4,
		"ar::__ARQChunkSize": 0x8040e9c8,
		"__ARQChunkSize": 0x8040e9c8,
		"ar::__ARQ_init_flag": 0x8040e9cc,
		"__ARQ_init_flag": 0x8040e9cc,
		"dsp::__DSP_init_flag": 0x8040e9d0,
		"__DSP_init_flag": 0x8040e9d0,
		"dsp::__DSP_last_task": 0x8040e9d8,
		"__DSP_last_task": 0x8040e9d8,
		"dsp::__DSP_first_task": 0x8040e9dc,
		"__DSP_first_task": 0x8040e9dc,
		"dsp::__DSP_curr_task": 0x8040e9e0,
		"__DSP_curr_task": 0x8040e9e0,
		"gx::__piReg": 0x8040e9e8,
		"__piReg": 0x8040e9e8,
		"gx::__cpReg": 0x8040e9ec,
		"__cpReg": 0x8040e9ec,
		"gx::__peReg": 0x8040e9f0,
		"__peReg": 0x8040e9f0,
		"gx::__memReg": 0x8040e9f4,
		"__memReg": 0x8040e9f4,
		"gx::CPUFifo": 0x8040e9f8,
		"CPUFifo": 0x8040e9f8,
		"gx::GPFifo": 0x8040e9fc,
		"GPFifo": 0x8040e9fc,
		"gx::__GXCurrentThread": 0x8040ea00,
		"__GXCurrentThread": 0x8040ea00,
		"gx::GXOverflowSuspendInProgress": 0x8040ea08,
		"GXOverflowSuspendInProgress": 0x8040ea08,
		"gx::BreakPointCB": 0x8040ea0c,
		"BreakPointCB": 0x8040ea0c,
		"gx::__GXOverflowCount": 0x8040ea10,
		"__GXOverflowCount": 0x8040ea10,
		"gx::__GXCurrentBP": 0x8040ea14,
		"__GXCurrentBP": 0x8040ea14,
		"gx::TokenCB": 0x8040ea18,
		"TokenCB": 0x8040ea18,
		"gx::DrawDoneCB": 0x8040ea1c,
		"DrawDoneCB": 0x8040ea1c,
		"gx::FinishQueue": 0x8040ea24,
		"FinishQueue": 0x8040ea24,
		"OdemuExi2::MTRCallback": 0x8040ea30,
		"MTRCallback": 0x8040ea30,
		"OdemuExi2::DBGCallback": 0x8040ea34,
		"DBGCallback": 0x8040ea34,
		"OdemuExi2::SendMailData": 0x8040ea38,
		"SendMailData": 0x8040ea38,
		"OdemuExi2::RecvDataLeng": 0x8040ea3c,
		"RecvDataLeng": 0x8040ea3c,
		"OdemuExi2::pEXIInputFlag": 0x8040ea40,
		"pEXIInputFlag": 0x8040ea40,
		"gd::__GDCurrentDL": 0x8040ea48,
		"__GDCurrentDL": 0x8040ea48,
		"gd::overflowcb": 0x8040ea4c,
		"overflowcb": 0x8040ea4c,
		"si::cmdTypeAndStatus$77": 0x8040ea50,
		"cmdTypeAndStatus$77": 0x8040ea50,
		"si::cmdTypeAndStatus$371": 0x8040ea54,
		"cmdTypeAndStatus$371": 0x8040ea54,
		"si::__PADFixBits": 0x8040ea58,
		"__PADFixBits": 0x8040ea58,
		"si::SamplingRate": 0x8040ea60,
		"SamplingRate": 0x8040ea60,
		"exi::Chan": 0x8040ea68,
		"Chan": 0x8040ea68,
		"exi::Dev": 0x8040ea6c,
		"Dev": 0x8040ea6c,
		"exi::Enabled": 0x8040ea70,
		"Enabled": 0x8040ea70,
		"exi::BarnacleEnabled": 0x8040ea74,
		"BarnacleEnabled": 0x8040ea74,
		"thp::__THPHuffmanBits": 0x8040eb24,
		"__THPHuffmanBits": 0x8040eb24,
		"thp::__THPHuffmanSizeTab": 0x8040eb28,
		"__THPHuffmanSizeTab": 0x8040eb28,
		"thp::__THPHuffmanCodeTab": 0x8040eb2c,
		"__THPHuffmanCodeTab": 0x8040eb2c,
		"thp::__THPOldGQR5": 0x8040eb84,
		"__THPOldGQR5": 0x8040eb84,
		"thp::__THPOldGQR6": 0x8040eb88,
		"__THPOldGQR6": 0x8040eb88,
		"thp::__THPWorkArea": 0x8040eb8c,
		"__THPWorkArea": 0x8040eb8c,
		"thp::__THPInfo": 0x8040eb90,
		"__THPInfo": 0x8040eb90,
		"thp::__THPInitFlag": 0x8040eb94,
		"__THPInitFlag": 0x8040eb94,
		"THPPlayer::AudioDecodeThreadCreated": 0x8040d078,
		"AudioDecodeThreadCreated": 0x8040d078,
		"THPPlayer::Initialized": 0x8040d080,
		"THPPlayer::PrepareReadyMessage": 0x8040d084,
		"PrepareReadyMessage": 0x8040d084,
		"THPPlayer::OldVIPostCallback": 0x8040d088,
		"OldVIPostCallback": 0x8040d088,
		"THPPlayer::SoundBufferIndex": 0x8040d08c,
		"SoundBufferIndex": 0x8040d08c,
		"THPPlayer::LastAudioBuffer": 0x8040d090,
		"LastAudioBuffer": 0x8040d090,
		"THPPlayer::CurAudioBuffer": 0x8040d094,
		"CurAudioBuffer": 0x8040d094,
		"THPPlayer::ReadThreadCreated": 0x8040d098,
		"ReadThreadCreated": 0x8040d098,
		"THPPlayer::VideoDecodeThreadCreated": 0x8040d0a0,
		"VideoDecodeThreadCreated": 0x8040d0a0,
		"THPPlayer::First": 0x8040d0a4,
		"First": 0x8040d0a4,
		"MarioUtil::gpSilhouetteManager": 0x8040e090,
		"gpSilhouetteManager": 0x8040e090,
		"MarioUtil::sKeepViewClipFovy": 0x8040e094,
		"sKeepViewClipFovy": 0x8040e094,
		"MarioUtil::sKeepViewClipAspect": 0x8040e098,
		"sKeepViewClipAspect": 0x8040e098,
		"MarioUtil::sKeepViewClipNear": 0x8040e09c,
		"sKeepViewClipNear": 0x8040e09c,
		"MarioUtil::sKeepViewClipFar": 0x8040e0a0,
		"sKeepViewClipFar": 0x8040e0a0,
		"TLightCommon::mAmbAry": 0x8040e0a8,
		"mAmbAry": 0x8040e0a8,
		"TLightCommon::mLightAry": 0x8040e0ac,
		"mLightAry": 0x8040e0ac,
		"TLightCommon::mLightPos": 0x8040e0b0,
		"mLightPos": 0x8040e0b0,
		"MarioUtil::gpLightManager": 0x8040e0b4,
		"gpLightManager": 0x8040e0b4,
		"MarioUtil::gpAfterEffect": 0x8040e0b8,
		"gpAfterEffect": 0x8040e0b8,
		"MarioUtil::gpScreenTexture": 0x8040e0bc,
		"gpScreenTexture": 0x8040e0bc,
		"MarioUtil::gpBindShadowManager": 0x8040e0c0,
		"gpBindShadowManager": 0x8040e0c0,
		"TMBindShadowManager::mJoinDist": 0x8040e0c4,
		"mJoinDist": 0x8040e0c4,
		"MarioUtil::SMSRumbleMgr": 0x8040e0d0,
		"SMSRumbleMgr": 0x8040e0d0,
		"MarioUtil::currentTGDLStatic": 0x8040e0d8,
		"currentTGDLStatic": 0x8040e0d8,
		"System::gpMarioParticleManager": 0x8040e150,
		"gpMarioParticleManager": 0x8040e150,
		"System::emitterCallBackBindToPosPtr": 0x8040e154,
		"emitterCallBackBindToPosPtr": 0x8040e154,
		"System::emitterCallBackBindToMtxPtr": 0x8040e158,
		"emitterCallBackBindToMtxPtr": 0x8040e158,
		"System::emitterCallBackBindToSRTMtxPtr": 0x8040e15c,
		"emitterCallBackBindToSRTMtxPtr": 0x8040e15c,
		"TFlagManager::smInstance": 0x8040e160,
		"System::gpSceneCmnDat": 0x8040e168,
		"gpSceneCmnDat": 0x8040e168,
		"System::gpSceneCmnDatSize": 0x8040e16c,
		"gpSceneCmnDatSize": 0x8040e16c,
		"TParams::mArc": 0x8040e170,
		"mArc": 0x8040e170,
		"TParams::mSceneArc": 0x8040e174,
		"mSceneArc": 0x8040e174,
		"System::gpMarDirector": 0x8040e178,
		"gpMarDirector": 0x8040e178,
		"System::gpMSound": 0x8040e17c,
		"gpMSound": 0x8040e17c,
		"System::gpSetupThreadStack": 0x8040e180,
		"gpSetupThreadStack": 0x8040e180,
		"System::gpCardManager": 0x8040e184,
		"gpCardManager": 0x8040e184,
		"System::gpSystemFont": 0x8040e188,
		"gpSystemFont": 0x8040e188,
		"System::gpRomFont": 0x8040e18c,
		"gpRomFont": 0x8040e18c,
		"System::sGameInit": 0x8040e190,
		"sGameInit": 0x8040e190,
		"System::arcBufNLogo": 0x8040e194,
		"arcBufNLogo": 0x8040e194,
		"System::arcBufMario": 0x8040e198,
		"arcBufMario": 0x8040e198,
		"System::arcBufCmn": 0x8040e19c,
		"arcBufCmn": 0x8040e19c,
		"System::bufStageArcBin": 0x8040e1a0,
		"bufStageArcBin": 0x8040e1a0,
		"System::spGameHeapBlock": 0x8040e1a4,
		"spGameHeapBlock": 0x8040e1a4,
		"System::gArBkConsole": 0x8040e1a8,
		"gArBkConsole": 0x8040e1a8,
		"System::gArBkGuide": 0x8040e1b0,
		"gArBkGuide": 0x8040e1b0,
		"TMarioGamePad::mResetFlag": 0x8040e1b8,
		"mResetFlag": 0x8040e1b8,
		"System::gpPositionHolder": 0x8040e1c0,
		"gpPositionHolder": 0x8040e1c0,
		"TTimeRec::_instance": 0x8040e1c8,
		"_instance": 0x8040e1c8,
		"TDrawSyncManager::smInstance": 0x8040e1d0,
		"System::sDetach": 0x8040e1d8,
		"sDetach": 0x8040e1d8,
		"System::gpResourceManager": 0x8040e1e0,
		"gpResourceManager": 0x8040e1e0,
		"System::gpEmitterManager4D2": 0x8040e1e4,
		"gpEmitterManager4D2": 0x8040e1e4,
		"MSMainProc::MSStageInfo::msStg": 0x8040e1e8,
		"msStg": 0x8040e1e8,
		"MSMainProc::MSStageInfo::demoBgm": 0x8040e1ec,
		"demoBgm": 0x8040e1ec,
		"MSMainProc::MSStageInfo::stageBgm": 0x8040e1f0,
		"stageBgm": 0x8040e1f0,
		"MSMainProc::MSStageInfo::stageBgmSilent": 0x8040e1f4,
		"stageBgmSilent": 0x8040e1f4,
		"MSMainProc::MSStageInfo::switchBgm": 0x8040e200,
		"switchBgm": 0x8040e200,
		"MSMainProc::MSStageInfo::switchBgm2": 0x8040e204,
		"switchBgm2": 0x8040e204,
		"MSMainProc::MSStageInfo::cubeFadeRatio": 0x8040e208,
		"cubeFadeRatio": 0x8040e208,
		"MSStage::smMSStage": 0x8040e214,
		"smMSStage": 0x8040e214,
		"System::gpTargetArrow": 0x8040e220,
		"gpTargetArrow": 0x8040e220,
		"Strategic::gpObjHitCheck": 0x8040e070,
		"gpObjHitCheck": 0x8040e070,
		"Strategic::gpStrategy": 0x8040e080,
		"gpStrategy": 0x8040e080,
		"Strategic::gpQuestionManager": 0x8040e088,
		"gpQuestionManager": 0x8040e088,
		"Player::gpMarioForCallBack": 0x8040e0e0,
		"gpMarioForCallBack": 0x8040e0e0,
		"Player::gpMarioOriginal": 0x8040e0e8,
		"gpMarioOriginal": 0x8040e0e8,
		"Player::bubbleCallBack": 0x8040e0f4,
		"bubbleCallBack": 0x8040e0f4,
		"Player::warpInCallBack": 0x8040e0fc,
		"warpInCallBack": 0x8040e0fc,
		"Player::gpSplashManager": 0x8040e100,
		"gpSplashManager": 0x8040e100,
		"Player::gpMarioAddress": 0x8040e108,
		"gpMarioAddress": 0x8040e108,
		"Player::gpMarioPos": 0x8040e10c,
		"gpMarioPos": 0x8040e10c,
		"Player::gpMarioAngleX": 0x8040e110,
		"gpMarioAngleX": 0x8040e110,
		"Player::gpMarioAngleY": 0x8040e114,
		"gpMarioAngleY": 0x8040e114,
		"Player::gpMarioAngleZ": 0x8040e118,
		"gpMarioAngleZ": 0x8040e118,
		"Player::gpMarioSpeedX": 0x8040e11c,
		"gpMarioSpeedX": 0x8040e11c,
		"Player::gpMarioSpeedY": 0x8040e120,
		"gpMarioSpeedY": 0x8040e120,
		"Player::gpMarioSpeedZ": 0x8040e124,
		"gpMarioSpeedZ": 0x8040e124,
		"Player::gpMarioLightID": 0x8040e128,
		"gpMarioLightID": 0x8040e128,
		"Player::gpMarioFlag": 0x8040e12c,
		"gpMarioFlag": 0x8040e12c,
		"Player::gpMarioThrowPower": 0x8040e130,
		"gpMarioThrowPower": 0x8040e130,
		"Player::gpMarioGroundPlane": 0x8040e134,
		"gpMarioGroundPlane": 0x8040e134,
		"Player::gpModelWaterManager": 0x8040e138,
		"gpModelWaterManager": 0x8040e138,
		"Player::sphere_glist_p": 0x8040e140,
		"sphere_glist_p": 0x8040e140,
		"Player::sphere_pos_t": 0x8040e144,
		"sphere_pos_t": 0x8040e144,
		"TBaseNPC::mPtrSaveNormal": 0x8040dfa0,
		"mPtrSaveNormal": 0x8040dfa0,
		"NPC::gpCurrentNpc": 0x8040dfa8,
		"gpCurrentNpc": 0x8040dfa8,
		"TMonteMBaseManager::mStaticCommonKeeper": 0x8040dfb0,
		"TMonteWBaseManager::mStaticCommonKeeper": 0x8040dfb4,
		"TMareMBaseManager::mStaticCommonKeeper": 0x8040dfb8,
		"TMareWBaseManager::mStaticCommonKeeper": 0x8040dfbc,
		"TMareBaseManager::mStaticBmtNormal": 0x8040dfc0,
		"mStaticBmtNormal": 0x8040dfc0,
		"TMareBaseManager::mStaticBmtPollution": 0x8040dfc4,
		"mStaticBmtPollution": 0x8040dfc4,
		"NPC::gpMareJellyFishManager": 0x8040dfc8,
		"gpMareJellyFishManager": 0x8040dfc8,
		"NPC::instance$2212": 0x8040dfd4,
		"instance$2212": 0x8040dfd4,
		"NPC::instance$2243": 0x8040dfdc,
		"instance$2243": 0x8040dfdc,
		"NPC::instance$2251": 0x8040dfe4,
		"instance$2251": 0x8040dfe4,
		"NPC::instance$2264": 0x8040dfec,
		"NPC::instance$2275": 0x8040dff4,
		"instance$2275": 0x8040dff4,
		"NPC::instance$2303": 0x8040dffc,
		"instance$2303": 0x8040dffc,
		"NPC::instance$2349": 0x8040e004,
		"instance$2349": 0x8040e004,
		"NPC::instance$2359": 0x8040e00c,
		"NPC::instance$2365": 0x8040e014,
		"instance$2365": 0x8040e014,
		"NPC::instance$2373": 0x8040e01c,
		"instance$2373": 0x8040e01c,
		"NPC::instance$2384": 0x8040e024,
		"instance$2384": 0x8040e024,
		"NPC::instance$2390": 0x8040e02c,
		"instance$2390": 0x8040e02c,
		"NPC::instance$2404": 0x8040e034,
		"instance$2404": 0x8040e034,
		"NPC::instance$2414": 0x8040e03c,
		"instance$2414": 0x8040e03c,
		"NPC::instance$2424": 0x8040e044,
		"instance$2424": 0x8040e044,
		"NPC::instance$2436": 0x8040e04c,
		"instance$2436": 0x8040e04c,
		"TNpcEvent::mDownSunflowerNum": 0x8040e050,
		"mDownSunflowerNum": 0x8040e050,
		"TBaseNPC::sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x8040e060,
		"sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x8040e060,
		"TNpcTrample::msAmpDecrease": 0x8040e068,
		"msAmpDecrease": 0x8040e068,
		"MSound::MSGMSound": 0x8040d05c,
		"MSGMSound": 0x8040d05c,
		"MSound::MSGBasic": 0x8040d060,
		"MSGBasic": 0x8040d060,
		"MSoundSESystem::MSoundSE::mObj": 0x8040d068,
		"mObj": 0x8040d068,
		"MSoundSESystem::SeInfo::smSeSetting": 0x8040d06c,
		"smSeSetting": 0x8040d06c,
		"MoveBG::gpMapObjManager": 0x8040df08,
		"gpMapObjManager": 0x8040df08,
		"MoveBG::gpItemManager": 0x8040df10,
		"gpItemManager": 0x8040df10,
		"MoveBG::gpMapObjSwitch": 0x8040df18,
		"gpMapObjSwitch": 0x8040df18,
		"MoveBG::sAngleAdd": 0x8040df20,
		"sAngleAdd": 0x8040df20,
		"MoveBG::gpCurObject": 0x8040df28,
		"gpCurObject": 0x8040df28,
		"TRiccoWatermill::mSubmarineSurfaceTransY": 0x8040df30,
		"mSubmarineSurfaceTransY": 0x8040df30,
		"MoveBG::switchSnd": 0x8040df38,
		"switchSnd": 0x8040df38,
		"MoveBG::gpMapObjFlagManager": 0x8040df40,
		"gpMapObjFlagManager": 0x8040df40,
		"MoveBG::sColor": 0x8040df50,
		"sColor": 0x8040df50,
		"MoveBG::gpMapObjWave": 0x8040df54,
		"gpMapObjWave": 0x8040df54,
		"MoveBG::timer$2477": 0x8040df58,
		"timer$2477": 0x8040df58,
		"TMapObjGrassManager::mColorUpper": 0x8040df68,
		"TMapObjGrassManager::mColorLower": 0x8040df6c,
		"TMapObjGrassManager::mColorFar": 0x8040df70,
		"mColorFar": 0x8040df70,
		"TMapObjGrassManager::mDrawVecS16": 0x8040df74,
		"mDrawVecS16": 0x8040df74,
		"MoveBG::gpMapObjGrassManager": 0x8040df7c,
		"gpMapObjGrassManager": 0x8040df7c,
		"MoveBG::gpMapObjPoleManager": 0x8040df80,
		"gpMapObjPoleManager": 0x8040df80,
		"THangingBridge::mRopeHeight": 0x8040df88,
		"mRopeHeight": 0x8040df88,
		"MoveBG::gpPoolManager": 0x8040df90,
		"gpPoolManager": 0x8040df90,
		"Map::gpMap": 0x8040de98,
		"gpMap": 0x8040de98,
		"Map::gpMapCollisionData": 0x8040dea0,
		"gpMapCollisionData": 0x8040dea0,
		"Map::gpMirrorModelManager": 0x8040dea8,
		"gpMirrorModelManager": 0x8040dea8,
		"TMapStaticObj::mEffectCoronaScale": 0x8040deb0,
		"mEffectCoronaScale": 0x8040deb0,
		"Map::gpMapWireManager": 0x8040deb8,
		"gpMapWireManager": 0x8040deb8,
		"TMapWireManager::mUpperSurface": 0x8040debc,
		"mUpperSurface": 0x8040debc,
		"TMapWireManager::mLowerSurface": 0x8040dec0,
		"mLowerSurface": 0x8040dec0,
		"Map::counter$2576": 0x8040dec8,
		"counter$2576": 0x8040dec8,
		"Map::gpPollution": 0x8040ded0,
		"gpPollution": 0x8040ded0,
		"Map::effect_counter$2421": 0x8040ded8,
		"effect_counter$2421": 0x8040ded8,
		"Map::now_pos_no$2429": 0x8040dee0,
		"now_pos_no$2429": 0x8040dee0,
		"Map::counter_x$2434": 0x8040dee8,
		"counter_x$2434": 0x8040dee8,
		"Map::counter_z$2437": 0x8040def0,
		"counter_z$2437": 0x8040def0,
		"Map::effect_timer$2449": 0x8040def8,
		"effect_timer$2449": 0x8040def8,
		"Map::delta$2349": 0x8040df00,
		"delta$2349": 0x8040df00,
		"TGCConsole2::cDownTopPoint": 0x8040dd90,
		"cDownTopPoint": 0x8040dd90,
		"TGCConsole2::cDownMidPoint": 0x8040dd98,
		"cDownMidPoint": 0x8040dd98,
		"TGCConsole2::cDownBotPoint": 0x8040dda0,
		"cDownBotPoint": 0x8040dda0,
		"TGCConsole2::cUpTopPoint": 0x8040dda8,
		"cUpTopPoint": 0x8040dda8,
		"TGCConsole2::cUpMidPoint": 0x8040ddb0,
		"cUpMidPoint": 0x8040ddb0,
		"TGCConsole2::cUpBotPoint": 0x8040ddb8,
		"cUpBotPoint": 0x8040ddb8,
		"TGCConsole2::cCoinTopPoint": 0x8040ddc0,
		"cCoinTopPoint": 0x8040ddc0,
		"TGCConsole2::cCoinMidPoint": 0x8040ddc8,
		"cCoinMidPoint": 0x8040ddc8,
		"TGCConsole2::cCoinBotPoint": 0x8040ddd0,
		"cCoinBotPoint": 0x8040ddd0,
		"GC2D::gpTalk2D": 0x8040ddd8,
		"gpTalk2D": 0x8040ddd8,
		"GC2D::gpCardLoad": 0x8040dde0,
		"gpCardLoad": 0x8040dde0,
		"TConsoleStr::cShineGetRight1": 0x8040dde8,
		"cShineGetRight1": 0x8040dde8,
		"TConsoleStr::cShineGetLeft1": 0x8040ddf0,
		"cShineGetLeft1": 0x8040ddf0,
		"TConsoleStr::cShineGetRight2": 0x8040ddf8,
		"cShineGetRight2": 0x8040ddf8,
		"TConsoleStr::cShineGetLeft2": 0x8040de00,
		"cShineGetLeft2": 0x8040de00,
		"TConsoleStr::cShineGetRight3": 0x8040de08,
		"cShineGetRight3": 0x8040de08,
		"TConsoleStr::cShineGetLeft3": 0x8040de10,
		"cShineGetLeft3": 0x8040de10,
		"GC2D::vtable": 0x8040de24,
		"vtable": 0x8040de24,
		"GC2D::r$181": 0x8040de2c,
		"r$181": 0x8040de2c,
		"GC2D::p1$182": 0x8040de30,
		"p1$182": 0x8040de30,
		"GC2D::p2$183": 0x8040de34,
		"p2$183": 0x8040de34,
		"GC2D::p3$184": 0x8040de38,
		"p3$184": 0x8040de38,
		"GC2D::boke$188": 0x8040de44,
		"boke$188": 0x8040de44,
		"GC2D::rot$260": 0x8040de48,
		"rot$260": 0x8040de48,
		"GC2D::fade$261": 0x8040de4c,
		"fade$261": 0x8040de4c,
		"GC2D::boundstate$263": 0x8040de50,
		"boundstate$263": 0x8040de50,
		"GC2D::boundtimer$264": 0x8040de54,
		"boundtimer$264": 0x8040de54,
		"GC2D::bounddelta$265": 0x8040de58,
		"bounddelta$265": 0x8040de58,
		"GC2D::hxs_logo_resetflag": 0x8040de60,
		"hxs_logo_resetflag": 0x8040de60,
		"GC2D::hxs_logodraw_resetflag": 0x8040de64,
		"hxs_logodraw_resetflag": 0x8040de64,
		"GC2D::dp$320": 0x8040de68,
		"dp$320": 0x8040de68,
		"GC2D::bx$321": 0x8040de6c,
		"bx$321": 0x8040de6c,
		"GC2D::by$322": 0x8040de70,
		"by$322": 0x8040de70,
		"GC2D::count$323": 0x8040de74,
		"count$323": 0x8040de74,
		"GC2D::r$393": 0x8040de78,
		"r$393": 0x8040de78,
		"GC2D::r$416": 0x8040de7c,
		"r$416": 0x8040de7c,
		"GC2D::r$432": 0x8040de80,
		"r$432": 0x8040de80,
		"GC2D::thin$469": 0x8040de84,
		"thin$469": 0x8040de84,
		"GC2D::rstep$470": 0x8040de88,
		"rstep$470": 0x8040de88,
		"GC2D::thin_d$471": 0x8040de8c,
		"thin_d$471": 0x8040de8c,
		"GC2D::rstep_d$472": 0x8040de90,
		"rstep_d$472": 0x8040de90,
		"Enemy::gpConductor": 0x8040d110,
		"gpConductor": 0x8040d110,
		"Enemy::gpEffectObjManager": 0x8040d118,
		"gpEffectObjManager": 0x8040d118,
		"Enemy::gpCurGesso": 0x8040d120,
		"gpCurGesso": 0x8040d120,
		"Enemy::gpCurHinokuri": 0x8040d1d8,
		"gpCurHinokuri": 0x8040d1d8,
		"Enemy::instance$3385": 0x8040d1e0,
		"instance$3385": 0x8040d1e0,
		"Enemy::instance$3434": 0x8040d1f0,
		"instance$3434": 0x8040d1f0,
		"Enemy::instance$3450": 0x8040d1f8,
		"instance$3450": 0x8040d1f8,
		"Enemy::instance$3461": 0x8040d200,
		"instance$3461": 0x8040d200,
		"Enemy::instance$3474": 0x8040d208,
		"instance$3474": 0x8040d208,
		"Enemy::instance$3493": 0x8040d210,
		"instance$3493": 0x8040d210,
		"Enemy::instance$3510": 0x8040d218,
		"instance$3510": 0x8040d218,
		"Enemy::instance$3540": 0x8040d220,
		"instance$3540": 0x8040d220,
		"Enemy::instance$3569": 0x8040d228,
		"instance$3569": 0x8040d228,
		"Enemy::instance$3583": 0x8040d230,
		"instance$3583": 0x8040d230,
		"Enemy::instance$3593": 0x8040d238,
		"instance$3593": 0x8040d238,
		"Enemy::instance$3605": 0x8040d240,
		"instance$3605": 0x8040d240,
		"Enemy::instance$3623": 0x8040d248,
		"instance$3623": 0x8040d248,
		"Enemy::gpCurNameKuri": 0x8040d290,
		"gpCurNameKuri": 0x8040d290,
		"Enemy::gpCurPakkun": 0x8040d2d0,
		"gpCurPakkun": 0x8040d2d0,
		"Enemy::gpCurPakkunSeed": 0x8040d2d4,
		"gpCurPakkunSeed": 0x8040d2d4,
		"Enemy::instance$2166": 0x8040d34c,
		"instance$2166": 0x8040d34c,
		"Enemy::instance$3999": 0x8040d560,
		"instance$3999": 0x8040d560,
		"Enemy::gpCurTobiPuku": 0x8040d578,
		"gpCurTobiPuku": 0x8040d578,
		"Enemy::gpCurChuuHana": 0x8040d650,
		"gpCurChuuHana": 0x8040d650,
		"Enemy::instance$3238": 0x8040d698,
		"instance$3238": 0x8040d698,
		"Enemy::gpCurRollEnemy": 0x8040d6b0,
		"gpCurRollEnemy": 0x8040d6b0,
		"TRollEnemy::mTransYOffset": 0x8040d6b4,
		"mTransYOffset": 0x8040d6b4,
		"Enemy::testHeight": 0x8040d870,
		"testHeight": 0x8040d870,
		"Enemy::gpCurKiller": 0x8040d8b0,
		"gpCurKiller": 0x8040d8b0,
		"Enemy::gpBeamManager": 0x8040d8d0,
		"gpBeamManager": 0x8040d8d0,
		"Enemy::gpCurSamboHead": 0x8040d8dc,
		"gpCurSamboHead": 0x8040d8dc,
		"Enemy::gpCurPopo": 0x8040d940,
		"gpCurPopo": 0x8040d940,
		"TPopo::mTestAng_z": 0x8040d944,
		"Enemy::instance$2264": 0x8040d97c,
		"Enemy::instance$2270": 0x8040d984,
		"instance$2270": 0x8040d984,
		"Enemy::sCommonSaveFileName$2709": 0x8040d998,
		"sCommonSaveFileName$2709": 0x8040d998,
		"Enemy::instance$2359": 0x8040d9a4,
		"Enemy::instance$2371": 0x8040d9ac,
		"instance$2371": 0x8040d9ac,
		"Enemy::instance$2383": 0x8040d9b4,
		"instance$2383": 0x8040d9b4,
		"Enemy::instance$2391": 0x8040d9bc,
		"instance$2391": 0x8040d9bc,
		"Enemy::instance$2399": 0x8040d9c4,
		"instance$2399": 0x8040d9c4,
		"Enemy::instance$2408": 0x8040d9cc,
		"instance$2408": 0x8040d9cc,
		"Enemy::instance$2423": 0x8040d9d4,
		"instance$2423": 0x8040d9d4,
		"Enemy::instance$2838": 0x8040da4c,
		"instance$2838": 0x8040da4c,
		"Enemy::instance$2856": 0x8040da54,
		"instance$2856": 0x8040da54,
		"Enemy::gpCurHauntLeg": 0x8040da60,
		"gpCurHauntLeg": 0x8040da60,
		"TRocket::mTestAng_x": 0x8040daa8,
		"TRocket::mTestAng_z": 0x8040daac,
		"Enemy::instance$2918": 0x8040db0c,
		"instance$2918": 0x8040db0c,
		"Enemy::instance$2924": 0x8040db14,
		"instance$2924": 0x8040db14,
		"Enemy::instance$2930": 0x8040db1c,
		"instance$2930": 0x8040db1c,
		"Enemy::instance$2936": 0x8040db24,
		"instance$2936": 0x8040db24,
		"Enemy::instance$2942": 0x8040db2c,
		"instance$2942": 0x8040db2c,
		"TBossManta::sCenterJointIndex": 0x8040db30,
		"sCenterJointIndex": 0x8040db30,
		"TBossManta::sBodyJointIndex": 0x8040db34,
		"sBodyJointIndex": 0x8040db34,
		"TBossManta::sRwingJointIndex": 0x8040db38,
		"sRwingJointIndex": 0x8040db38,
		"TBossManta::sLwingJointIndex": 0x8040db3c,
		"sLwingJointIndex": 0x8040db3c,
		"Enemy::sDefeatSE$3156": 0x8040db44,
		"sDefeatSE$3156": 0x8040db44,
		"TNerveKoopaTurnR::nerve$localstatic0$theNerve": 0x8040dbfc,
		"TNerveKoopaTurnL::nerve$localstatic0$theNerve": 0x8040dc04,
		"TNerveKoopaTumble::nerve$localstatic0$theNerve": 0x8040dc0c,
		"TNerveKoopaProvoke::nerve$localstatic0$theNerve": 0x8040dc14,
		"TNerveKoopaWait::nerve$localstatic0$theNerve": 0x8040dc1c,
		"TNerveKoopaFlame::nerve$localstatic0$theNerve": 0x8040dc24,
		"TNerveKoopaGetDown::nerve$localstatic0$theNerve": 0x8040dc2c,
		"TNerveKoopaStagger::nerve$localstatic0$theNerve": 0x8040dc34,
		"TNerveKoopaFall::nerve$localstatic0$theNerve": 0x8040dc3c,
		"TNerveKoopaGetShowered::nerve$localstatic0$theNerve": 0x8040dc44,
		"TNervePeachStagger::nerve$localstatic0$theNerve": 0x8040dca4,
		"TNervePeachEscape::nerve$localstatic0$theNerve": 0x8040dcac,
		"@unnamed@::cAngleMax": 0x8040dcf8,
		"cAngleMax": 0x8040dcf8,
		"TNerveLimitKoopaHipDropJump::nerve$localstatic0$theNerve": 0x8040dd3c,
		"TNerveLimitKoopaHipDropStart::nerve$localstatic0$theNerve": 0x8040dd44,
		"TNerveLimitKoopaTumble::nerve$localstatic0$theNerve": 0x8040dd4c,
		"TNerveLimitKoopaWait::nerve$localstatic0$theNerve": 0x8040dd54,
		"TNerveLimitKoopaGetDown::nerve$localstatic0$theNerve": 0x8040dd5c,
		"TNerveLimitKoopaStagger::nerve$localstatic0$theNerve": 0x8040dd64,
		"TNerveLimitKoopaGetShowered::nerve$localstatic0$theNerve": 0x8040dd6c,
		"Camera::gpCamera": 0x8040d0a8,
		"gpCamera": 0x8040d0a8,
		"Camera::gpCameraMario": 0x8040d0b0,
		"gpCameraMario": 0x8040d0b0,
		"Camera::gpCameraShake": 0x8040d0b8,
		"gpCameraShake": 0x8040d0b8,
		"Camera::gpSunMgr": 0x8040d0c0,
		"gpSunMgr": 0x8040d0c0,
		"Camera::gpSunModel": 0x8040d0c8,
		"gpSunModel": 0x8040d0c8,
		"Camera::gpCubeCamera": 0x8040d0d0,
		"gpCubeCamera": 0x8040d0d0,
		"Camera::gpCubeMirror": 0x8040d0d4,
		"gpCubeMirror": 0x8040d0d4,
		"Camera::gpCubeWire": 0x8040d0d8,
		"gpCubeWire": 0x8040d0d8,
		"Camera::gpCubeStream": 0x8040d0dc,
		"gpCubeStream": 0x8040d0dc,
		"Camera::gpCubeShadow": 0x8040d0e0,
		"gpCubeShadow": 0x8040d0e0,
		"Camera::gpCubeArea": 0x8040d0e4,
		"gpCubeArea": 0x8040d0e4,
		"Camera::gpCubeFastA": 0x8040d0e8,
		"gpCubeFastA": 0x8040d0e8,
		"Camera::gpCubeFastB": 0x8040d0ec,
		"gpCubeFastB": 0x8040d0ec,
		"Camera::gpCubeFastC": 0x8040d0f0,
		"gpCubeFastC": 0x8040d0f0,
		"Camera::gpCubeSoundChange": 0x8040d0f4,
		"gpCubeSoundChange": 0x8040d0f4,
		"Camera::gpCubeSoundEffect": 0x8040d0f8,
		"gpCubeSoundEffect": 0x8040d0f8,
		"Camera::gpCamMapToolTable": 0x8040d100,
		"gpCamMapToolTable": 0x8040d100,
		"Camera::gpCameraOption": 0x8040d108,
		"gpCameraOption": 0x8040d108,
		"Animal::instance$2000": 0x8040cfd4,
		"instance$2000": 0x8040cfd4,
		"Animal::instance$3025": 0x8040cfdc,
		"Animal::instance$3040": 0x8040cfe4,
		"instance$3040": 0x8040cfe4,
		"Animal::instance$3055": 0x8040cfec,
		"Animal::instance$3067": 0x8040cff4,
		"instance$3067": 0x8040cff4,
		"Animal::instance$3077": 0x8040cffc,
		"instance$3077": 0x8040cffc,
		"Animal::instance$3096": 0x8040d004,
		"instance$3096": 0x8040d004,
		"Animal::instance$3104": 0x8040d00c,
		"instance$3104": 0x8040d00c,
		"Animal::instance$3116": 0x8040d014,
		"instance$3116": 0x8040d014,
		"Animal::instance$3128": 0x8040d01c,
		"@unnamed@::cAngleLimit": 0x8040d020,
		"cAngleLimit": 0x8040d020,
		"Animal::instance$2989": 0x8040d028,
		"instance$2989": 0x8040d028,
		"Animal::instance$3003": 0x8040d030,
		"instance$3003": 0x8040d030,
		"Animal::instance$3013": 0x8040d038,
		"Animal::instance$3023": 0x8040d040,
		"instance$3023": 0x8040d040,
		"Animal::instance$3035": 0x8040d048,
		"Animal::instance$3047": 0x8040d050,
		"instance$3047": 0x8040d050,
		"Animal::@2185": 0x8040ece0,
		"Animal::@2186": 0x8040ece4,
		"Animal::@2198": 0x8040ece8,
		"Animal::@2204": 0x8040ecec,
		"MSound::@1986": 0x8040ee74,
		"MSound::@1987": 0x8040ee78,
		"MSound::@2470": 0x8040ee98,
		"MSound::@2528": 0x8040ee9c,
		"MSound::@2602": 0x8040eea0,
		"MSound::@2603": 0x8040eea4,
		"MSound::@2622": 0x8040eeb0,
		"MSound::@2623": 0x8040eeb4,
		"MSound::@2984": 0x8040eed8,
		"MSound::@2985": 0x8040eedc,
		"MSound::@2986": 0x8040eee0,
		"MSound::@3109": 0x8040eee4,
		"MSound::@3450": 0x8040eee8,
		"MSound::@3451": 0x8040eeec,
		"MSound::@3456": 0x8040eef0,
		"MSound::@2940": 0x8040f084,
		"MSound::@2941": 0x8040f088,
		"MSound::@2942": 0x8040f08c,
		"MSound::@2943": 0x8040f090,
		"MSound::@3170": 0x8040f0a0,
		"Camera::@2334": 0x8040f220,
		"Camera::@3713": 0x8040f228,
		"Camera::@3714": 0x8040f22c,
		"Camera::@2641": 0x8040f240,
		"Camera::@2642": 0x8040f244,
		"Camera::@2661": 0x8040f248,
		"Camera::@2662": 0x8040f24c,
		"Camera::@2663": 0x8040f250,
		"Camera::@2750": 0x8040f268,
		"Camera::@2751": 0x8040f26c,
		"Camera::@2752": 0x8040f270,
		"Camera::@3265": 0x8040f280,
		"Camera::@3266": 0x8040f284,
		"Camera::@3267": 0x8040f288,
		"Camera::@3268": 0x8040f28c,
		"Camera::@3269": 0x8040f290,
		"Camera::@3270": 0x8040f294,
		"Camera::@3369": 0x8040f2a0,
		"Camera::@3726": 0x8040f2a4,
		"Camera::@3727": 0x8040f2ac,
		"Camera::@3825": 0x8040f2b0,
		"Camera::@2182": 0x8040f340,
		"Camera::@2071": 0x8040f358,
		"Camera::@2072": 0x8040f35c,
		"Camera::@2073": 0x8040f360,
		"Camera::@2200": 0x8040f370,
		"Camera::@2201": 0x8040f374,
		"Camera::@2319": 0x8040f378,
		"Camera::@2320": 0x8040f37c,
		"Camera::@2321": 0x8040f380,
		"Camera::@2322": 0x8040f384,
		"Camera::@2323": 0x8040f388,
		"Camera::@2324": 0x8040f38c,
		"Camera::@2352": 0x8040f5e0,
		"Camera::@2353": 0x8040f5e4,
		"Camera::@2354": 0x8040f5e8,
		"Camera::@2355": 0x8040f5ec,
		"Camera::@2702": 0x8040f5f0,
		"Camera::@2703": 0x8040f5f4,
		"Camera::@2704": 0x8040f5f8,
		"Camera::@2705": 0x8040f5fc,
		"Camera::@2706": 0x8040f600,
		"Camera::@2707": 0x8040f604,
		"Camera::@2708": 0x8040f608,
		"Camera::@1830": 0x8040f678,
		"@1830": 0x8040f678,
		"Camera::@1831": 0x8040f67c,
		"Camera::@1832": 0x8040f680,
		"Enemy::@2778": 0x8040f7a8,
		"Enemy::@2779": 0x8040f7b0,
		"Enemy::@2780": 0x8040f7b8,
		"Enemy::@2785": 0x8040f7c0,
		"Enemy::@2786": 0x8040f7c8,
		"Enemy::@3203": 0x8040fa7c,
		"Enemy::@4103": 0x8040faa0,
		"Enemy::@4104": 0x8040faa4,
		"Enemy::@4106": 0x8040faac,
		"Enemy::@4406": 0x8040faf8,
		"Enemy::@5108": 0x8040fb18,
		"Enemy::@5109": 0x8040fb1c,
		"Enemy::@5192": 0x8040fb20,
		"Enemy::@5504": 0x8040fb28,
		"@5504": 0x8040fb28,
		"Enemy::@5908": 0x8040fb44,
		"Enemy::@6426": 0x8040fb50,
		"@6426": 0x8040fb50,
		"Enemy::@3680": 0x8040fbf0,
		"Enemy::@3681": 0x8040fbf4,
		"Enemy::@4082": 0x8040fc2c,
		"Enemy::@4548": 0x8040fc50,
		"Enemy::@4549": 0x8040fc54,
		"Enemy::@4808": 0x8040fc5c,
		"@4808": 0x8040fc5c,
		"Enemy::@5215": 0x8040fc64,
		"Enemy::@5343": 0x8040fc74,
		"Enemy::@4792": 0x8040fd3c,
		"Enemy::@6518": 0x8040fd6c,
		"Enemy::@6519": 0x8040fd70,
		"Enemy::@6520": 0x8040fd74,
		"Enemy::@7348": 0x8040fd7c,
		"@7348": 0x8040fd7c,
		"Enemy::@3646": 0x8040feb8,
		"Enemy::@3648": 0x8040febc,
		"Enemy::@4257": 0x8040fee8,
		"Enemy::@3443": 0x8040fef8,
		"Enemy::@3444": 0x8040fefc,
		"Enemy::@4054": 0x8040ff20,
		"Enemy::@4221": 0x8040ff44,
		"Enemy::@4444": 0x8040ff58,
		"@4444": 0x8040ff58,
		"Enemy::@4499": 0x8040ff68,
		"Enemy::@4033": 0x8040fff8,
		"Enemy::@4035": 0x80410000,
		"Enemy::@4558": 0x80410014,
		"Enemy::idxarray$3431": 0x804100e8,
		"idxarray$3431": 0x804100e8,
		"Enemy::idxarray$3453": 0x804100f0,
		"idxarray$3453": 0x804100f0,
		"Enemy::idxarray$3500": 0x804100f8,
		"idxarray$3500": 0x804100f8,
		"Enemy::idxarray$3520": 0x80410100,
		"idxarray$3520": 0x80410100,
		"Enemy::@4704": 0x80410128,
		"Enemy::@4706": 0x8041012c,
		"Enemy::@4707": 0x80410130,
		"Enemy::@4708": 0x80410134,
		"Enemy::@6056": 0x8041016c,
		"@6056": 0x8041016c,
		"Enemy::@6299": 0x80410170,
		"@6299": 0x80410170,
		"Enemy::@6321": 0x80410174,
		"@6321": 0x80410174,
		"Enemy::@6322": 0x80410178,
		"@6322": 0x80410178,
		"Enemy::@6323": 0x8041017c,
		"@6323": 0x8041017c,
		"Enemy::@6589": 0x80410180,
		"Enemy::@7131": 0x80410184,
		"@7131": 0x80410184,
		"Enemy::@7132": 0x80410188,
		"@7132": 0x80410188,
		"Enemy::@7133": 0x8041018c,
		"@7133": 0x8041018c,
		"Enemy::@7192": 0x80410190,
		"@7192": 0x80410190,
		"Enemy::@7193": 0x80410194,
		"@7193": 0x80410194,
		"Enemy::@7822": 0x8041019c,
		"@7822": 0x8041019c,
		"Enemy::@7863": 0x804101a0,
		"@7863": 0x804101a0,
		"Enemy::@7864": 0x804101a4,
		"@7864": 0x804101a4,
		"Enemy::@7865": 0x804101a8,
		"@7865": 0x804101a8,
		"Enemy::@8145": 0x804101ac,
		"@8145": 0x804101ac,
		"Enemy::@8146": 0x804101b0,
		"@8146": 0x804101b0,
		"Enemy::@8147": 0x804101b8,
		"@8147": 0x804101b8,
		"Enemy::@8149": 0x804101bc,
		"@8149": 0x804101bc,
		"Enemy::@8360": 0x804101c0,
		"Enemy::@8735": 0x804101c4,
		"@8735": 0x804101c4,
		"Enemy::@9038": 0x804101c8,
		"@9038": 0x804101c8,
		"Enemy::@9197": 0x804101cc,
		"@9197": 0x804101cc,
		"Enemy::@9200": 0x804101d0,
		"@9200": 0x804101d0,
		"Enemy::@9202": 0x804101d4,
		"@9202": 0x804101d4,
		"Enemy::@9205": 0x804101d8,
		"@9205": 0x804101d8,
		"Enemy::@9207": 0x804101dc,
		"@9207": 0x804101dc,
		"Enemy::@9210": 0x804101e0,
		"@9210": 0x804101e0,
		"Enemy::@9212": 0x804101e4,
		"@9212": 0x804101e4,
		"Enemy::@9218": 0x804101e8,
		"@9218": 0x804101e8,
		"Enemy::@9222": 0x804101ec,
		"@9222": 0x804101ec,
		"Enemy::@9227": 0x804101f0,
		"@9227": 0x804101f0,
		"Enemy::@4122": 0x80410234,
		"Enemy::@4123": 0x80410238,
		"Enemy::@4435": 0x8041025c,
		"Enemy::@4741": 0x80410264,
		"Enemy::@5172": 0x80410270,
		"Enemy::@4390": 0x804102c8,
		"Enemy::@4391": 0x804102cc,
		"Enemy::@4537": 0x804102d8,
		"Enemy::@4538": 0x804102dc,
		"@4538": 0x804102dc,
		"Enemy::@5296": 0x80410314,
		"Enemy::@5076": 0x80410388,
		"Enemy::@5183": 0x8041038c,
		"Enemy::@5386": 0x804103a0,
		"@5386": 0x804103a0,
		"Enemy::@5387": 0x804103a4,
		"@5387": 0x804103a4,
		"Enemy::@6628": 0x804103c4,
		"@6628": 0x804103c4,
		"Enemy::@6948": 0x804103c8,
		"@6948": 0x804103c8,
		"Enemy::@7610": 0x804103e0,
		"@7610": 0x804103e0,
		"Enemy::@7611": 0x804103e4,
		"@7611": 0x804103e4,
		"Enemy::@7688": 0x804103e8,
		"@7688": 0x804103e8,
		"Enemy::@7689": 0x804103ec,
		"@7689": 0x804103ec,
		"Enemy::@7893": 0x804103f4,
		"@7893": 0x804103f4,
		"Enemy::@7894": 0x804103f8,
		"@7894": 0x804103f8,
		"Enemy::@8404": 0x804103fc,
		"@8404": 0x804103fc,
		"Enemy::@8768": 0x80410400,
		"Enemy::@9151": 0x80410424,
		"@9151": 0x80410424,
		"Enemy::@9482": 0x80410428,
		"@9482": 0x80410428,
		"Enemy::@9483": 0x8041042c,
		"@9483": 0x8041042c,
		"Enemy::@4339": 0x80410464,
		"Enemy::@5038": 0x80410484,
		"Enemy::@5039": 0x80410488,
		"Enemy::@5390": 0x8041048c,
		"@5390": 0x8041048c,
		"Enemy::@5392": 0x80410494,
		"@5392": 0x80410494,
		"Enemy::@5393": 0x80410498,
		"@5393": 0x80410498,
		"Enemy::@5394": 0x8041049c,
		"@5394": 0x8041049c,
		"Enemy::@5788": 0x804104ac,
		"@5788": 0x804104ac,
		"Enemy::@5789": 0x804104b0,
		"@5789": 0x804104b0,
		"Enemy::@5790": 0x804104b4,
		"@5790": 0x804104b4,
		"Enemy::@6199": 0x804104bc,
		"@6199": 0x804104bc,
		"Enemy::@6929": 0x804104d0,
		"@6929": 0x804104d0,
		"Enemy::@6930": 0x804104d4,
		"@6930": 0x804104d4,
		"Enemy::@6931": 0x804104d8,
		"@6931": 0x804104d8,
		"Enemy::@6932": 0x804104dc,
		"@6932": 0x804104dc,
		"Enemy::@6933": 0x804104e0,
		"@6933": 0x804104e0,
		"Enemy::@7230": 0x804104f8,
		"@7230": 0x804104f8,
		"Enemy::@7408": 0x804104fc,
		"@7408": 0x804104fc,
		"Enemy::@7471": 0x8041050c,
		"@7471": 0x8041050c,
		"Enemy::@7472": 0x80410510,
		"@7472": 0x80410510,
		"Enemy::@7473": 0x80410514,
		"Enemy::@7474": 0x80410518,
		"@7474": 0x80410518,
		"Enemy::@7475": 0x8041051c,
		"@7475": 0x8041051c,
		"Enemy::@7997": 0x80410528,
		"@7997": 0x80410528,
		"Enemy::@7998": 0x8041052c,
		"@7998": 0x8041052c,
		"Enemy::@8342": 0x80410544,
		"@8342": 0x80410544,
		"Enemy::@3407": 0x80410568,
		"Enemy::@4901": 0x804105d0,
		"Enemy::@4992": 0x804105d8,
		"Enemy::@4830": 0x8041065c,
		"Enemy::@5660": 0x80410678,
		"Enemy::@5661": 0x8041067c,
		"Enemy::@6085": 0x80410690,
		"@6085": 0x80410690,
		"Enemy::@6602": 0x8041078c,
		"@6602": 0x8041078c,
		"Enemy::@6603": 0x80410790,
		"@6603": 0x80410790,
		"Enemy::@6604": 0x80410794,
		"@6604": 0x80410794,
		"Enemy::@6605": 0x80410798,
		"@6605": 0x80410798,
		"Enemy::@6606": 0x8041079c,
		"@6606": 0x8041079c,
		"Enemy::@6843": 0x804107a0,
		"Enemy::@6844": 0x804107a4,
		"Enemy::@6845": 0x804107a8,
		"Enemy::@7168": 0x804107ac,
		"@7168": 0x804107ac,
		"Enemy::@7169": 0x804107b0,
		"@7169": 0x804107b0,
		"Enemy::@7302": 0x804107b4,
		"@7302": 0x804107b4,
		"Enemy::@7303": 0x804107b8,
		"@7303": 0x804107b8,
		"Enemy::@7304": 0x804107bc,
		"@7304": 0x804107bc,
		"Enemy::@7305": 0x804107c4,
		"@7305": 0x804107c4,
		"Enemy::@7385": 0x804107c8,
		"@7385": 0x804107c8,
		"Enemy::@7505": 0x804107cc,
		"@7505": 0x804107cc,
		"Enemy::@7506": 0x804107d0,
		"@7506": 0x804107d0,
		"Enemy::@7507": 0x804107d4,
		"@7507": 0x804107d4,
		"Enemy::@7508": 0x804107d8,
		"@7508": 0x804107d8,
		"Enemy::@7509": 0x804107dc,
		"@7509": 0x804107dc,
		"Enemy::@7510": 0x804107e0,
		"@7510": 0x804107e0,
		"Enemy::@7780": 0x804107f4,
		"@7780": 0x804107f4,
		"Enemy::@7781": 0x804107f8,
		"@7781": 0x804107f8,
		"Enemy::@7782": 0x804107fc,
		"@7782": 0x804107fc,
		"Enemy::@7783": 0x80410800,
		"@7783": 0x80410800,
		"Enemy::@7784": 0x80410804,
		"@7784": 0x80410804,
		"Enemy::@7785": 0x80410808,
		"@7785": 0x80410808,
		"Enemy::@7786": 0x8041080c,
		"@7786": 0x8041080c,
		"Enemy::@4404": 0x80410878,
		"Enemy::@4752": 0x80410880,
		"Enemy::@5579": 0x804108a4,
		"@5579": 0x804108a4,
		"Enemy::@5580": 0x804108a8,
		"@5580": 0x804108a8,
		"Enemy::@5619": 0x804108ac,
		"@5619": 0x804108ac,
		"Enemy::@3684": 0x804108d0,
		"Enemy::@3685": 0x804108d4,
		"@3685": 0x804108d4,
		"Enemy::@4858": 0x80410934,
		"Enemy::@5177": 0x80410948,
		"Enemy::@5179": 0x80410950,
		"Enemy::@5201": 0x80410958,
		"Enemy::@5202": 0x8041095c,
		"Enemy::@3871": 0x804109c4,
		"Enemy::@4486": 0x804109e0,
		"Enemy::@4353": 0x80410a74,
		"Enemy::@6148": 0x80410ae0,
		"Enemy::@6149": 0x80410ae4,
		"Enemy::@6150": 0x80410ae8,
		"Enemy::@6225": 0x80410aec,
		"@6225": 0x80410aec,
		"Enemy::@6297": 0x80410b0c,
		"@6297": 0x80410b0c,
		"Enemy::@6814": 0x80410b10,
		"@6814": 0x80410b10,
		"Enemy::@6815": 0x80410b14,
		"@6815": 0x80410b14,
		"Enemy::@7194": 0x80410b1c,
		"@7194": 0x80410b1c,
		"Enemy::@7195": 0x80410b20,
		"@7195": 0x80410b20,
		"Enemy::@8019": 0x80410b30,
		"@8019": 0x80410b30,
		"Enemy::@8020": 0x80410b34,
		"@8020": 0x80410b34,
		"Enemy::@8054": 0x80410b50,
		"@8054": 0x80410b50,
		"Enemy::@8181": 0x80410b54,
		"@8181": 0x80410b54,
		"Enemy::@8345": 0x80410b58,
		"@8345": 0x80410b58,
		"Enemy::@8749": 0x80410b5c,
		"@8749": 0x80410b5c,
		"Enemy::@8796": 0x80410b64,
		"@8796": 0x80410b64,
		"Enemy::@8849": 0x80410b70,
		"@8849": 0x80410b70,
		"Enemy::@9019": 0x80410b74,
		"@9019": 0x80410b74,
		"Enemy::@2747": 0x80410b94,
		"Enemy::@2749": 0x80410b98,
		"Enemy::@3838": 0x80410c3c,
		"Enemy::@5103": 0x80410ca8,
		"Enemy::@5104": 0x80410cac,
		"Enemy::@5246": 0x80410d88,
		"Enemy::@5247": 0x80410d8c,
		"Enemy::@5248": 0x80410d90,
		"Enemy::@5249": 0x80410d94,
		"Enemy::@6127": 0x80410dc8,
		"Enemy::@6840": 0x80410ddc,
		"Enemy::@6887": 0x80410de0,
		"Enemy::@6888": 0x80410de4,
		"Enemy::@6899": 0x80410de8,
		"Enemy::@6901": 0x80410dec,
		"Enemy::@6903": 0x80410df0,
		"Enemy::@6904": 0x80410df4,
		"Enemy::@7020": 0x80410df8,
		"@7020": 0x80410df8,
		"Enemy::@7021": 0x80410dfc,
		"@7021": 0x80410dfc,
		"Enemy::@7125": 0x80410e00,
		"@7125": 0x80410e00,
		"Enemy::@7321": 0x80410e04,
		"@7321": 0x80410e04,
		"Enemy::@7446": 0x80410e0c,
		"@7446": 0x80410e0c,
		"Enemy::@7447": 0x80410e10,
		"@7447": 0x80410e10,
		"Enemy::@7448": 0x80410e14,
		"@7448": 0x80410e14,
		"Enemy::@8976": 0x80410e58,
		"@8976": 0x80410e58,
		"Enemy::@8977": 0x80410e5c,
		"@8977": 0x80410e5c,
		"Enemy::@8978": 0x80410e60,
		"@8978": 0x80410e60,
		"Enemy::@8979": 0x80410e64,
		"@8979": 0x80410e64,
		"Enemy::@3807": 0x80410ee0,
		"Enemy::@4210": 0x80410f18,
		"Enemy::@3335": 0x80410f54,
		"Enemy::@4494": 0x80410fbc,
		"Enemy::@5369": 0x80410fd4,
		"@5369": 0x80410fd4,
		"Enemy::@5533": 0x80410fe0,
		"@5533": 0x80410fe0,
		"Enemy::@5893": 0x80410ffc,
		"Enemy::@3323": 0x80411000,
		"Enemy::@4009": 0x8041103c,
		"Enemy::@4241": 0x80411048,
		"Enemy::@4242": 0x8041104c,
		"Enemy::@5091": 0x80411088,
		"Enemy::@5092": 0x8041108c,
		"Enemy::@5154": 0x80411090,
		"Enemy::@3319": 0x8041111c,
		"Enemy::@3320": 0x80411120,
		"Enemy::@3778": 0x8041138c,
		"Enemy::@4163": 0x80411398,
		"Enemy::@4362": 0x804113a0,
		"Enemy::@4431": 0x804113a8,
		"Enemy::@3640": 0x804113b0,
		"Enemy::@3641": 0x804113b4,
		"Enemy::@4563": 0x804113d0,
		"Enemy::@2300": 0x8041147c,
		"Enemy::@2301": 0x80411480,
		"Enemy::@2302": 0x80411484,
		"Enemy::@2303": 0x80411488,
		"Enemy::@3802": 0x804114d0,
		"Enemy::@4089": 0x80411514,
		"Enemy::@4223": 0x80411534,
		"Enemy::@4226": 0x80411540,
		"Enemy::@4437": 0x80411544,
		"Enemy::@4438": 0x80411548,
		"Enemy::@4719": 0x8041154c,
		"Enemy::@4720": 0x80411550,
		"Enemy::@4723": 0x8041155c,
		"Enemy::@4724": 0x80411560,
		"Enemy::@4727": 0x8041156c,
		"Enemy::@5439": 0x80411594,
		"@5439": 0x80411594,
		"Enemy::@5442": 0x804115a0,
		"@5442": 0x804115a0,
		"Enemy::@5979": 0x804115a4,
		"Enemy::@6548": 0x804115a8,
		"Enemy::@6549": 0x804115ac,
		"Enemy::@6550": 0x804115b0,
		"Enemy::@6642": 0x804115c0,
		"@6642": 0x804115c0,
		"Enemy::@3217": 0x80411608,
		"Enemy::@3218": 0x8041160c,
		"Enemy::@3526": 0x804116d4,
		"Enemy::@4457": 0x80411744,
		"@4457": 0x80411744,
		"Enemy::@4685": 0x8041174c,
		"Enemy::@3883": 0x804118c4,
		"Enemy::@3884": 0x804118c8,
		"Enemy::@3831": 0x8041190c,
		"Enemy::@4559": 0x80411928,
		"Enemy::@4560": 0x8041192c,
		"Enemy::@4561": 0x80411930,
		"Enemy::@4562": 0x80411934,
		"Enemy::@6036": 0x80411960,
		"Enemy::@6041": 0x80411964,
		"Enemy::@6042": 0x80411968,
		"Enemy::@6043": 0x8041196c,
		"Enemy::@6044": 0x80411970,
		"@6044": 0x80411970,
		"Enemy::@6057": 0x804119d8,
		"@6057": 0x804119d8,
		"Enemy::@4352": 0x80411a90,
		"Enemy::@5368": 0x80411ae8,
		"Enemy::@3638": 0x80411b34,
		"Enemy::@4495": 0x80411b5c,
		"Enemy::@4611": 0x80411b6c,
		"Enemy::@3413": 0x80411be0,
		"Enemy::@3957": 0x80411c90,
		"Enemy::@4718": 0x80411c98,
		"Enemy::@5691": 0x80411cbc,
		"Enemy::@5693": 0x80411cc0,
		"Enemy::@5695": 0x80411cc4,
		"@5695": 0x80411cc4,
		"Enemy::@3956": 0x80411dac,
		"Enemy::@4797": 0x80411db8,
		"Enemy::@3395": 0x80411e3c,
		"Enemy::@3416": 0x80411e40,
		"Enemy::@4321": 0x80411e64,
		"Enemy::@4351": 0x80411e70,
		"Enemy::@4599": 0x80411e7c,
		"@4599": 0x80411e7c,
		"GC2D::@3499": 0x80411f10,
		"GC2D::@3527": 0x80411f14,
		"GC2D::@3581": 0x80411f18,
		"GC2D::@6831": 0x80411f2c,
		"@6831": 0x80411f2c,
		"GC2D::@6832": 0x80411f30,
		"@6832": 0x80411f30,
		"GC2D::@6833": 0x80411f34,
		"@6833": 0x80411f34,
		"GC2D::@6834": 0x80411f38,
		"@6834": 0x80411f38,
		"GC2D::@6835": 0x80411f3c,
		"@6835": 0x80411f3c,
		"GC2D::@6836": 0x80411f40,
		"@6836": 0x80411f40,
		"GC2D::@6837": 0x80411f44,
		"@6837": 0x80411f44,
		"GC2D::@6838": 0x80411f48,
		"@6838": 0x80411f48,
		"GC2D::@6839": 0x80411f4c,
		"@6839": 0x80411f4c,
		"GC2D::@6840": 0x80411f50,
		"GC2D::@6841": 0x80411f54,
		"@6841": 0x80411f54,
		"GC2D::@6842": 0x80411f58,
		"@6842": 0x80411f58,
		"GC2D::@6843": 0x80411f5c,
		"GC2D::@6846": 0x80411f60,
		"@6846": 0x80411f60,
		"GC2D::@6996": 0x80411f78,
		"@6996": 0x80411f78,
		"GC2D::@7078": 0x80411f7c,
		"@7078": 0x80411f7c,
		"GC2D::@7079": 0x80411f80,
		"@7079": 0x80411f80,
		"GC2D::@8971": 0x80411f90,
		"@8971": 0x80411f90,
		"GC2D::@8972": 0x80411f94,
		"@8972": 0x80411f94,
		"GC2D::@9453": 0x80411f98,
		"@9453": 0x80411f98,
		"GC2D::@9776": 0x80411f9c,
		"@9776": 0x80411f9c,
		"GC2D::@11627": 0x80411fa0,
		"@11627": 0x80411fa0,
		"GC2D::@11628": 0x80411fa4,
		"@11628": 0x80411fa4,
		"GC2D::@11629": 0x80411fa8,
		"@11629": 0x80411fa8,
		"GC2D::@11846": 0x80411fac,
		"@11846": 0x80411fac,
		"GC2D::@11914": 0x80411fb4,
		"@11914": 0x80411fb4,
		"GC2D::@3357": 0x80411fcc,
		"GC2D::@3358": 0x80411fd0,
		"GC2D::@3542": 0x80411fe0,
		"GC2D::@3544": 0x80411ff0,
		"GC2D::@3545": 0x80411ff4,
		"GC2D::@3546": 0x80411ff8,
		"GC2D::@3551": 0x80411ffc,
		"GC2D::@3710": 0x80412000,
		"GC2D::@3871": 0x80412004,
		"GC2D::@4349": 0x80412008,
		"GC2D::@4522": 0x8041200c,
		"GC2D::@4523": 0x80412010,
		"GC2D::@4524": 0x80412014,
		"GC2D::@4525": 0x80412018,
		"GC2D::@4526": 0x8041201c,
		"GC2D::@4527": 0x80412020,
		"GC2D::@4528": 0x80412024,
		"GC2D::@4529": 0x80412028,
		"GC2D::@4917": 0x80412038,
		"GC2D::@4918": 0x8041203c,
		"GC2D::@4949": 0x80412040,
		"GC2D::@4983": 0x80412048,
		"GC2D::@4233": 0x80412150,
		"GC2D::@4234": 0x80412154,
		"GC2D::@4235": 0x80412158,
		"GC2D::@4275": 0x80412170,
		"GC2D::@5958": 0x80412174,
		"GC2D::@5959": 0x80412178,
		"GC2D::@5960": 0x8041217c,
		"GC2D::@5961": 0x80412180,
		"GC2D::@5962": 0x80412184,
		"GC2D::@5963": 0x80412188,
		"GC2D::@7094": 0x8041218c,
		"@7094": 0x8041218c,
		"GC2D::@7096": 0x80412194,
		"@7096": 0x80412194,
		"GC2D::@4580": 0x804121fc,
		"GC2D::@4581": 0x80412200,
		"GC2D::@4582": 0x80412204,
		"GC2D::@5182": 0x80412210,
		"GC2D::@5183": 0x80412214,
		"GC2D::@5184": 0x80412218,
		"GC2D::@5185": 0x8041221c,
		"GC2D::@5186": 0x80412220,
		"GC2D::@5187": 0x80412224,
		"GC2D::@5515": 0x80412228,
		"@5515": 0x80412228,
		"GC2D::@7273": 0x80412238,
		"@7273": 0x80412238,
		"GC2D::@7274": 0x8041223c,
		"@7274": 0x8041223c,
		"GC2D::@7275": 0x80412240,
		"@7275": 0x80412240,
		"GC2D::@7276": 0x80412244,
		"@7276": 0x80412244,
		"GC2D::@7277": 0x80412248,
		"@7277": 0x80412248,
		"GC2D::@7278": 0x8041224c,
		"@7278": 0x8041224c,
		"GC2D::@7712": 0x80412250,
		"@7712": 0x80412250,
		"GC2D::@7713": 0x80412254,
		"@7713": 0x80412254,
		"GC2D::@7714": 0x80412258,
		"@7714": 0x80412258,
		"GC2D::@7715": 0x8041225c,
		"@7715": 0x8041225c,
		"GC2D::@7716": 0x80412260,
		"@7716": 0x80412260,
		"GC2D::@7717": 0x80412264,
		"@7717": 0x80412264,
		"GC2D::@8321": 0x80412268,
		"GC2D::@8327": 0x80412270,
		"GC2D::@8367": 0x80412274,
		"@8367": 0x80412274,
		"GC2D::@3631": 0x80412380,
		"GC2D::@3632": 0x80412384,
		"GC2D::@3633": 0x80412388,
		"GC2D::@3634": 0x8041238c,
		"GC2D::@3635": 0x80412390,
		"GC2D::@3636": 0x80412394,
		"GC2D::@3637": 0x80412398,
		"GC2D::@3957": 0x804123b0,
		"GC2D::@3961": 0x804123b4,
		"GC2D::@3962": 0x804123b8,
		"GC2D::@4077": 0x804123bc,
		"GC2D::@4078": 0x804123c0,
		"GC2D::@4079": 0x804123c4,
		"GC2D::@4080": 0x804123c8,
		"@unnamed@::cSubtitleToggleItems": 0x804126d0,
		"cSubtitleToggleItems": 0x804126d0,
		"GC2D::@2518": 0x804126d8,
		"GC2D::@2519": 0x804126dc,
		"GC2D::@2520": 0x804126e0,
		"GC2D::@2521": 0x804126e4,
		"GC2D::@2780": 0x804126e8,
		"GC2D::@2781": 0x804126ec,
		"GC2D::@2782": 0x804126f0,
		"GC2D::@2971": 0x80412700,
		"GC2D::@2972": 0x80412704,
		"GC2D::@2973": 0x80412708,
		"GC2D::@3795": 0x80412718,
		"Map::@3225": 0x804127d8,
		"Map::@3226": 0x804127dc,
		"Map::@3227": 0x804127e0,
		"Map::@3228": 0x804127e4,
		"Map::@3229": 0x804127e8,
		"Map::@3623": 0x804127f0,
		"Map::@2631": 0x80412888,
		"Map::@2635": 0x804128a8,
		"Map::@2637": 0x804128b8,
		"Map::@2638": 0x804128c0,
		"Map::@2769": 0x8041291c,
		"Map::@2953": 0x80412928,
		"Map::@2954": 0x8041292c,
		"Map::@2955": 0x80412930,
		"Map::@2956": 0x80412934,
		"Map::@3021": 0x8041294c,
		"Map::@3189": 0x80412954,
		"Map::@3329": 0x80412958,
		"Map::@3480": 0x80412960,
		"Map::@3481": 0x80412964,
		"Map::@2794": 0x80412a58,
		"Map::@2549": 0x80412a9c,
		"Map::@2717": 0x80412aa0,
		"Map::@3059": 0x80412b30,
		"Map::@3069": 0x80412b34,
		"Map::@3070": 0x80412b3c,
		"MoveBG::@3476": 0x80413f1c,
		"MoveBG::@3935": 0x80413f48,
		"MoveBG::@3448": 0x80413fd8,
		"MoveBG::@3638": 0x80413fec,
		"MoveBG::@3881": 0x80414008,
		"MoveBG::@3882": 0x8041400c,
		"MoveBG::@3892": 0x80414010,
		"MoveBG::@4100": 0x8041403c,
		"MoveBG::@4302": 0x80414040,
		"MoveBG::@4303": 0x80414044,
		"MoveBG::@4468": 0x80414048,
		"MoveBG::@4469": 0x8041404c,
		"MoveBG::@4470": 0x80414050,
		"MoveBG::@2627": 0x80414058,
		"MoveBG::@2628": 0x8041405c,
		"MoveBG::@2629": 0x80414060,
		"MoveBG::@2656": 0x80414064,
		"MoveBG::@2657": 0x8041406c,
		"MoveBG::@3609": 0x804140d0,
		"MoveBG::@3660": 0x80414180,
		"MoveBG::@3661": 0x80414184,
		"MoveBG::@3662": 0x80414188,
		"MoveBG::@3836": 0x80414198,
		"MoveBG::@3837": 0x8041419c,
		"MoveBG::@3838": 0x804141a0,
		"MoveBG::@3839": 0x804141a4,
		"@3839": 0x804141a4,
		"MoveBG::@4030": 0x804141b0,
		"MoveBG::@4031": 0x804141b4,
		"MoveBG::@4084": 0x804141b8,
		"MoveBG::@4240": 0x804141c4,
		"MoveBG::@3671": 0x804141f4,
		"MoveBG::@3672": 0x804141f8,
		"MoveBG::@3673": 0x804141fc,
		"MoveBG::@3741": 0x80414200,
		"MoveBG::@3895": 0x8041421c,
		"MoveBG::@3896": 0x80414220,
		"MoveBG::@4055": 0x80414238,
		"MoveBG::@4066": 0x80414248,
		"MoveBG::@4067": 0x8041424c,
		"MoveBG::@4289": 0x8041425c,
		"MoveBG::@4436": 0x80414270,
		"MoveBG::@4437": 0x80414274,
		"MoveBG::@4625": 0x80414278,
		"MoveBG::@4626": 0x8041427c,
		"MoveBG::@4627": 0x80414280,
		"MoveBG::@4628": 0x80414284,
		"MoveBG::@4630": 0x8041428c,
		"MoveBG::@4818": 0x80414294,
		"MoveBG::@4819": 0x80414298,
		"MoveBG::@4820": 0x8041429c,
		"@4820": 0x8041429c,
		"MoveBG::@4831": 0x804142a0,
		"MoveBG::@4876": 0x804142a8,
		"MoveBG::@4877": 0x804142ac,
		"MoveBG::@5056": 0x804142b0,
		"MoveBG::@5057": 0x804142b4,
		"MoveBG::@5219": 0x804142b8,
		"MoveBG::@5220": 0x804142bc,
		"MoveBG::@5224": 0x804142c8,
		"MoveBG::@3468": 0x80414338,
		"MoveBG::@3653": 0x80414360,
		"MoveBG::@4245": 0x804143a8,
		"MoveBG::@4246": 0x804143ac,
		"MoveBG::@4247": 0x804143b0,
		"MoveBG::@4248": 0x804143b4,
		"MoveBG::@4249": 0x804143b8,
		"MoveBG::@4250": 0x804143bc,
		"MoveBG::@4251": 0x804143c0,
		"MoveBG::@4252": 0x804143c4,
		"MoveBG::@4253": 0x804143c8,
		"MoveBG::@4779": 0x804143f8,
		"MoveBG::@4780": 0x804143fc,
		"MoveBG::@4781": 0x80414400,
		"MoveBG::@4782": 0x80414404,
		"MoveBG::@4801": 0x80414408,
		"@4801": 0x80414408,
		"MoveBG::@4993": 0x8041441c,
		"MoveBG::@4994": 0x80414420,
		"MoveBG::@4996": 0x80414424,
		"MoveBG::@5184": 0x80414434,
		"MoveBG::@5185": 0x80414438,
		"MoveBG::@5249": 0x8041443c,
		"MoveBG::@5250": 0x80414440,
		"MoveBG::@5256": 0x80414444,
		"MoveBG::@5365": 0x80414448,
		"MoveBG::@4026": 0x804144e0,
		"MoveBG::@4082": 0x804144f8,
		"MoveBG::@4202": 0x80414504,
		"MoveBG::@4312": 0x80414514,
		"MoveBG::@3725": 0x804145ac,
		"MoveBG::@3891": 0x804145c0,
		"MoveBG::@3998": 0x804145c4,
		"MoveBG::@3999": 0x804145c8,
		"MoveBG::@4126": 0x804145d0,
		"MoveBG::@4129": 0x804145d4,
		"MoveBG::@4130": 0x804145dc,
		"MoveBG::@4131": 0x804145e0,
		"MoveBG::@4132": 0x804145e4,
		"MoveBG::@4270": 0x80414608,
		"MoveBG::@2395": 0x80414624,
		"MoveBG::@2593": 0x8041463c,
		"MoveBG::@2594": 0x80414640,
		"MoveBG::@2595": 0x80414644,
		"MoveBG::@2597": 0x8041464c,
		"MoveBG::@2598": 0x80414650,
		"MoveBG::@3593": 0x804147b8,
		"MoveBG::@3613": 0x804147bc,
		"MoveBG::@3965": 0x804147d4,
		"MoveBG::@4226": 0x804147d8,
		"MoveBG::@4360": 0x804147dc,
		"MoveBG::@4735": 0x80414800,
		"MoveBG::@4736": 0x80414804,
		"MoveBG::@4737": 0x80414808,
		"MoveBG::@4738": 0x8041480c,
		"MoveBG::@4739": 0x80414810,
		"MoveBG::@4740": 0x80414814,
		"MoveBG::@4741": 0x80414818,
		"MoveBG::@4742": 0x8041481c,
		"MoveBG::@4743": 0x80414820,
		"MoveBG::@4744": 0x80414824,
		"MoveBG::@5124": 0x8041482c,
		"MoveBG::@2696": 0x80414a04,
		"MoveBG::@2718": 0x80414a08,
		"MoveBG::@3447": 0x80414ab0,
		"MoveBG::@3724": 0x80414acc,
		"MoveBG::@3936": 0x80414ad0,
		"MoveBG::@3937": 0x80414ad4,
		"MoveBG::@3938": 0x80414ad8,
		"MoveBG::@3939": 0x80414adc,
		"MoveBG::@3940": 0x80414ae0,
		"MoveBG::@3556": 0x80414bf8,
		"MoveBG::@4465": 0x80414c9c,
		"@4465": 0x80414c9c,
		"MoveBG::@4651": 0x80414ca0,
		"MoveBG::@4652": 0x80414ca4,
		"MoveBG::@4653": 0x80414ca8,
		"MoveBG::@4655": 0x80414cb0,
		"MoveBG::@4656": 0x80414cb4,
		"MoveBG::@5239": 0x80414cc8,
		"MoveBG::@5240": 0x80414ccc,
		"MoveBG::@5342": 0x80414cd0,
		"MoveBG::@3739": 0x80414dc0,
		"NPC::@2672": 0x80414fb8,
		"NPC::@2673": 0x80414fc0,
		"NPC::@2676": 0x80414fc4,
		"NPC::@2812": 0x80414fc8,
		"Strategic::@2878": 0x804152bc,
		"Strategic::@3180": 0x804152c8,
		"M3DUtil::@3225": 0x80415648,
		"M3DUtil::@3566": 0x8041564c,
		"Player::@2179": 0x804156f8,
		"Player::@3234": 0x80415720,
		"Player::@2269": 0x80415778,
		"Player::@2270": 0x8041577c,
		"Player::@2271": 0x80415780,
		"Player::@2476": 0x80415784,
		"Player::@3638": 0x80415a78,
		"Player::@3650": 0x80415a80,
		"Player::@3960": 0x80415a8c,
		"Player::@3961": 0x80415a90,
		"Player::@4321": 0x80415a94,
		"Player::@4322": 0x80415a98,
		"Player::@4323": 0x80415a9c,
		"Player::@4324": 0x80415aa0,
		"Player::@4938": 0x80415ab8,
		"Player::@4939": 0x80415abc,
		"Player::@4940": 0x80415ac0,
		"Player::@4941": 0x80415ac4,
		"Player::@4942": 0x80415ac8,
		"Player::@5652": 0x80415acc,
		"Player::@5734": 0x80415ae4,
		"Player::@5735": 0x80415ae8,
		"Player::@6339": 0x80415aec,
		"@6339": 0x80415aec,
		"Player::@6340": 0x80415af0,
		"@6340": 0x80415af0,
		"Player::@6341": 0x80415af4,
		"@6341": 0x80415af4,
		"Player::@6666": 0x80415af8,
		"Player::@3367": 0x80415b1c,
		"Player::@3592": 0x80415b38,
		"Player::@3593": 0x80415b3c,
		"Player::@3594": 0x80415b40,
		"Player::@3595": 0x80415b44,
		"Player::@3905": 0x80415b48,
		"Player::@3941": 0x80415b4c,
		"Player::@3942": 0x80415b50,
		"Player::@3943": 0x80415b54,
		"Player::@3944": 0x80415b58,
		"Player::@3945": 0x80415b5c,
		"Player::@4059": 0x80415b70,
		"Player::@4060": 0x80415b74,
		"Player::@4180": 0x80415b78,
		"Player::@4597": 0x80415b88,
		"Player::@3063": 0x80415ba0,
		"Player::@4207": 0x80415ba8,
		"Player::@4208": 0x80415bac,
		"Player::@4209": 0x80415bb0,
		"Player::@4512": 0x80415bec,
		"Player::@5125": 0x80415c04,
		"Player::@5126": 0x80415c08,
		"Player::@5151": 0x80415c0c,
		"Player::@5152": 0x80415c10,
		"Player::@5285": 0x80415c14,
		"Player::@5286": 0x80415c18,
		"Player::@5287": 0x80415c1c,
		"Player::@5706": 0x80415c20,
		"Player::@5708": 0x80415c28,
		"Player::@5709": 0x80415c2c,
		"Player::@5710": 0x80415c30,
		"Player::@5808": 0x80415c34,
		"@5808": 0x80415c34,
		"Player::@5809": 0x80415c38,
		"@5809": 0x80415c38,
		"Player::@5810": 0x80415c3c,
		"@5810": 0x80415c3c,
		"Player::@5811": 0x80415c40,
		"Player::@6169": 0x80415c44,
		"Player::@6170": 0x80415c48,
		"Player::@6171": 0x80415c4c,
		"Player::@6172": 0x80415c50,
		"Player::@6173": 0x80415c54,
		"Player::@7138": 0x80415c58,
		"@7138": 0x80415c58,
		"Player::@7139": 0x80415c5c,
		"Player::@7299": 0x80415c60,
		"@7299": 0x80415c60,
		"Player::@7578": 0x80415c64,
		"Player::@7579": 0x80415c68,
		"Player::@7580": 0x80415c6c,
		"Player::@7581": 0x80415c70,
		"Player::@7582": 0x80415c74,
		"Player::@7583": 0x80415c78,
		"Player::@7584": 0x80415c7c,
		"Player::@7585": 0x80415c80,
		"Player::@8023": 0x80415c84,
		"Player::@8056": 0x80415c88,
		"@8056": 0x80415c88,
		"Player::@3030": 0x80415cb8,
		"Player::@3031": 0x80415cbc,
		"Player::@3032": 0x80415cc0,
		"Player::@3033": 0x80415cc4,
		"Player::@3843": 0x80415d30,
		"Player::@3844": 0x80415d34,
		"Player::@3845": 0x80415d38,
		"Player::@3900": 0x80415d3c,
		"Player::@3901": 0x80415d40,
		"Player::@3957": 0x80415d50,
		"Player::@4123": 0x80415d70,
		"Player::@4124": 0x80415d74,
		"Player::@4125": 0x80415d78,
		"Player::@4164": 0x80415d7c,
		"Player::@4242": 0x80415d80,
		"Player::@4521": 0x80415d88,
		"Player::@4522": 0x80415d8c,
		"Player::@4544": 0x80415d94,
		"Player::@4545": 0x80415d98,
		"Player::@4686": 0x80415d9c,
		"Player::@4778": 0x80415da4,
		"Player::@4944": 0x80415da8,
		"Player::@4945": 0x80415dac,
		"Player::@4946": 0x80415db0,
		"Player::@3391": 0x80415db8,
		"Player::@3392": 0x80415dbc,
		"Player::@3393": 0x80415dc0,
		"Player::@3394": 0x80415dc4,
		"Player::@3395": 0x80415dc8,
		"Player::@3396": 0x80415dcc,
		"Player::@3397": 0x80415dd0,
		"Player::@3398": 0x80415dd4,
		"Player::@3631": 0x80415dec,
		"Player::@3632": 0x80415df0,
		"Player::@3633": 0x80415df4,
		"Player::@3634": 0x80415df8,
		"Player::@4049": 0x80415e08,
		"Player::@4050": 0x80415e0c,
		"Player::@4051": 0x80415e10,
		"Player::@4200": 0x80415e14,
		"Player::@4576": 0x80415e18,
		"Player::@4577": 0x80415e1c,
		"Player::@4952": 0x80415e28,
		"Player::@5119": 0x80415e40,
		"Player::@5149": 0x80415e44,
		"Player::@5223": 0x80415e48,
		"Player::@5224": 0x80415e4c,
		"Player::@5225": 0x80415e50,
		"Player::@5226": 0x80415e54,
		"Player::@5227": 0x80415e58,
		"Player::@5321": 0x80415e5c,
		"Player::@5322": 0x80415e60,
		"Player::@5323": 0x80415e64,
		"Player::@5324": 0x80415e68,
		"Player::@2222": 0x80415e70,
		"Player::@2223": 0x80415e74,
		"Player::@3057": 0x80415ea4,
		"Player::@3058": 0x80415ea8,
		"Player::@3059": 0x80415eac,
		"Player::@3061": 0x80415eb4,
		"Player::@3062": 0x80415eb8,
		"Player::@3159": 0x80415ec0,
		"Player::@3353": 0x80415ee0,
		"Player::@3438": 0x80415f08,
		"Player::@1969": 0x80415f10,
		"Player::@2005": 0x80415f14,
		"Player::@2087": 0x80415f18,
		"Player::@2630": 0x80415f48,
		"Player::@3274": 0x80415f88,
		"Player::@3275": 0x80415f8c,
		"Player::@3948": 0x80415fbc,
		"Player::@4662": 0x80415fe0,
		"Player::@5099": 0x80415fec,
		"Player::@6090": 0x80415ff0,
		"Player::@6091": 0x80415ff8,
		"Player::@6093": 0x80416000,
		"Player::@6095": 0x80416004,
		"Player::@6098": 0x80416008,
		"Player::@6100": 0x80416010,
		"Player::@6109": 0x80416014,
		"@6109": 0x80416014,
		"Player::@6111": 0x80416018,
		"@6111": 0x80416018,
		"Player::@6119": 0x8041601c,
		"@6119": 0x8041601c,
		"Player::@6125": 0x80416024,
		"@6125": 0x80416024,
		"Player::@6127": 0x80416028,
		"Player::@6130": 0x8041602c,
		"Player::@6132": 0x80416030,
		"Player::@6134": 0x80416034,
		"Player::@6139": 0x8041603c,
		"Player::@3296": 0x80416040,
		"Player::@3846": 0x80416050,
		"Player::@3847": 0x80416054,
		"Player::@3848": 0x80416058,
		"Player::@3849": 0x8041605c,
		"Player::@3859": 0x80416070,
		"Player::@4110": 0x80416074,
		"Player::@4955": 0x80416078,
		"Player::@4966": 0x80416088,
		"Player::@4967": 0x8041608c,
		"Player::@4968": 0x80416090,
		"Player::@4969": 0x80416094,
		"Player::@4971": 0x8041609c,
		"Player::@4972": 0x804160a0,
		"Player::@4973": 0x804160a4,
		"Player::@4974": 0x804160a8,
		"Player::@4977": 0x804160ac,
		"Player::@2010": 0x80416100,
		"Player::@2509": 0x80416108,
		"Player::@2510": 0x8041610c,
		"Player::@2511": 0x80416110,
		"Player::@2512": 0x80416118,
		"Player::@2513": 0x8041611c,
		"Player::@2514": 0x80416124,
		"Player::@2551": 0x8041612c,
		"Player::@2553": 0x80416130,
		"Player::@2580": 0x80416138,
		"Player::@2583": 0x80416140,
		"Player::@2585": 0x80416148,
		"Player::@2586": 0x8041614c,
		"Player::@2587": 0x80416154,
		"Player::@2606": 0x80416158,
		"Player::@2608": 0x80416160,
		"Player::@2610": 0x80416164,
		"Player::@2612": 0x80416168,
		"Player::@2614": 0x8041616c,
		"Player::@2627": 0x80416170,
		"Player::@2702": 0x80416188,
		"Player::@2703": 0x8041618c,
		"Player::@2704": 0x80416194,
		"Player::@2705": 0x80416198,
		"Player::@2706": 0x804161a0,
		"Player::@2707": 0x804161a4,
		"Player::@2708": 0x804161ac,
		"Player::@2709": 0x804161b0,
		"Player::@3237": 0x80416250,
		"Player::@3240": 0x80416254,
		"Player::@3360": 0x80416268,
		"Player::@3552": 0x80416290,
		"Player::@3557": 0x80416298,
		"Player::@3778": 0x804162cc,
		"Player::@3963": 0x804162d8,
		"Player::@3965": 0x804162e0,
		"Player::@4126": 0x80416300,
		"Player::@6706": 0x80416328,
		"Player::@4212": 0x804164b0,
		"Player::@4213": 0x804164b4,
		"Player::@4217": 0x804164c4,
		"Player::@4218": 0x804164c8,
		"Player::@4219": 0x804164cc,
		"Player::@4220": 0x804164d0,
		"Player::@4263": 0x804164e0,
		"@4263": 0x804164e0,
		"System::@3855": 0x80416520,
		"System::@3856": 0x80416524,
		"System::@3857": 0x80416528,
		"System::@3858": 0x8041652c,
		"System::@3909": 0x804165b0,
		"System::@3910": 0x804165b4,
		"System::@3912": 0x804165b8,
		"System::@4379": 0x804165d0,
		"System::@3062": 0x804165e8,
		"System::@3476": 0x80416818,
		"System::@4212": 0x80416950,
		"System::@4213": 0x80416954,
		"System::@2529": 0x80416b38,
		"System::@2530": 0x80416b3c,
		"System::@2531": 0x80416b40,
		"System::@2940": 0x80416b4c,
		"System::@2947": 0x80416b54,
		"System::@2796": 0x80416ba0,
		"System::@3008": 0x80416bb8,
		"System::@3449": 0x80416bc8,
		"System::@3450": 0x80416bcc,
		"System::@3643": 0x80416bd0,
		"System::@3644": 0x80416bd4,
		"System::@3645": 0x80416bd8,
		"System::@3646": 0x80416bdc,
		"JSystem::@722": 0x80416bf8,
		"@722": 0x80416bf8,
		"JSystem::@724": 0x80416c00,
		"@724": 0x80416c00,
		"JSystem::@728": 0x80416c10,
		"@728": 0x80416c10,
		"JSystem::@730": 0x80416c18,
		"@730": 0x80416c18,
		"JSystem::@1783": 0x80416c28,
		"JSystem::@370": 0x80416c30,
		"@370": 0x80416c30,
		"JSystem::@1565": 0x80416c60,
		"JSystem::@1629": 0x80416c64,
		"JSystem::@1630": 0x80416c68,
		"JSystem::@1756": 0x80416c6c,
		"JSystem::@2094": 0x80416c70,
		"JSystem::@2216": 0x80416c78,
		"JSystem::@192": 0x80416c80,
		"JSystem::@604": 0x80416c88,
		"JSystem::@609": 0x80416c98,
		"JSystem::@639": 0x80416cb0,
		"JSystem::@640": 0x80416cb4,
		"JSystem::@669": 0x80416cc0,
		"JSystem::@670": 0x80416cc4,
		"@670": 0x80416cc4,
		"JSystem::@671": 0x80416cc8,
		"@671": 0x80416cc8,
		"JSystem::@672": 0x80416ccc,
		"@672": 0x80416ccc,
		"JSystem::@135": 0x80416cd0,
		"@135": 0x80416cd0,
		"JSystem::@543": 0x80416d28,
		"@543": 0x80416d28,
		"JSystem::@297": 0x80416d38,
		"JSystem::@920": 0x80416d50,
		"JSystem::@1014": 0x80416d54,
		"@1014": 0x80416d54,
		"JSystem::@52": 0x80416d58,
		"JSystem::@276": 0x80416d68,
		"@276": 0x80416d68,
		"JSystem::@403": 0x80416d6c,
		"@403": 0x80416d6c,
		"JSystem::@1321": 0x80416d88,
		"@1321": 0x80416d88,
		"JSystem::@1322": 0x80416d8c,
		"@1322": 0x80416d8c,
		"JSystem::@1329": 0x80416d98,
		"@1329": 0x80416d98,
		"JSystem::@871": 0x80416da0,
		"@871": 0x80416da0,
		"JSystem::@872": 0x80416da4,
		"@872": 0x80416da4,
		"JSystem::@912": 0x80416da8,
		"@912": 0x80416da8,
		"JSystem::@1084": 0x80416db0,
		"@1084": 0x80416db0,
		"JSystem::@1099": 0x80416db4,
		"JSystem::@1259": 0x80416dbc,
		"@1259": 0x80416dbc,
		"JSystem::@1260": 0x80416dc0,
		"@1260": 0x80416dc0,
		"JSystem::@1261": 0x80416dc4,
		"@1261": 0x80416dc4,
		"JSystem::@1262": 0x80416dc8,
		"@1262": 0x80416dc8,
		"JSystem::@1077": 0x80416de8,
		"@1077": 0x80416de8,
		"JSystem::@1258": 0x80416dec,
		"@1258": 0x80416dec,
		"JSystem::@330": 0x80416df0,
		"@330": 0x80416df0,
		"JSystem::@2218": 0x80416dfc,
		"JSystem::@2219": 0x80416e00,
		"JSystem::@2221": 0x80416e04,
		"JSystem::@2222": 0x80416e0c,
		"JSystem::@2223": 0x80416e10,
		"JSystem::@2225": 0x80416e14,
		"JSystem::@2226": 0x80416e1c,
		"JSystem::@2227": 0x80416e20,
		"JSystem::@2456": 0x80416e24,
		"JSystem::@1460": 0x80416e28,
		"@1460": 0x80416e28,
		"JSystem::@2249": 0x80416e2c,
		"JSystem::@994": 0x80416e40,
		"@994": 0x80416e40,
		"JSystem::@956": 0x80416e4c,
		"@956": 0x80416e4c,
		"JSystem::@1073": 0x80416e50,
		"JSystem::@1500": 0x80416e68,
		"@1500": 0x80416e68,
		"JSystem::@1288": 0x80416e78,
		"@1288": 0x80416e78,
		"JSystem::@1345": 0x80416e7c,
		"@1345": 0x80416e7c,
		"JSystem::@1425": 0x80416e80,
		"@1425": 0x80416e80,
		"JSystem::@1443": 0x80416e88,
		"@1443": 0x80416e88,
		"JSystem::@1126": 0x80416e90,
		"@1126": 0x80416e90,
		"JSystem::@123": 0x80416ea8,
		"JSystem::@124": 0x80416eac,
		"@124": 0x80416eac,
		"JSystem::@926": 0x80416ec8,
		"@926": 0x80416ec8,
		"JSystem::@927": 0x80416ecc,
		"@927": 0x80416ecc,
		"JSystem::@978": 0x80416ed0,
		"@978": 0x80416ed0,
		"JSystem::@979": 0x80416ed4,
		"@979": 0x80416ed4,
		"JSystem::@824": 0x80416ee0,
		"@824": 0x80416ee0,
		"JSystem::@825": 0x80416ee4,
		"@825": 0x80416ee4,
		"JSystem::@360": 0x80416ef0,
		"JSystem::@100": 0x80416f00,
		"JSystem::@111": 0x80416f08,
		"JSystem::@335": 0x80416f10,
		"@335": 0x80416f10,
		"JSystem::@295": 0x80416f2c,
		"JSystem::@385": 0x80416f38,
		"JSystem::@386": 0x80416f3c,
		"JSystem::@388": 0x80416f48,
		"JSystem::@390": 0x80416f58,
		"@390": 0x80416f58,
		"JSystem::@697": 0x80416f68,
		"@697": 0x80416f68,
		"JSystem::@2338": 0x80416f88,
		"JSystem::@878": 0x80416f94,
		"@878": 0x80416f94,
		"JSystem::@879": 0x80416f98,
		"@879": 0x80416f98,
		"JSystem::@633": 0x80416fa8,
		"@633": 0x80416fa8,
		"JSystem::@634": 0x80416fac,
		"JSystem::@1466": 0x80416fb0,
		"@1466": 0x80416fb0,
		"JSystem::@1467": 0x80416fb4,
		"@1467": 0x80416fb4,
		"JSystem::@1469": 0x80416fb8,
		"@1469": 0x80416fb8,
		"JSystem::@1470": 0x80416fbc,
		"@1470": 0x80416fbc,
		"JSystem::@1471": 0x80416fc0,
		"@1471": 0x80416fc0,
		"JSystem::@1472": 0x80416fc4,
		"@1472": 0x80416fc4,
		"JSystem::@1477": 0x80416fc8,
		"@1477": 0x80416fc8,
		"JSystem::@1478": 0x80416fd0,
		"@1478": 0x80416fd0,
		"JSystem::@1479": 0x80416fd8,
		"@1479": 0x80416fd8,
		"JSystem::@48": 0x80416fe8,
		"@48": 0x80416fe8,
		"JSystem::@244": 0x80417008,
		"@244": 0x80417008,
		"JSystem::@354": 0x80417010,
		"JSystem::@355": 0x80417014,
		"JSystem::@544": 0x80417028,
		"@544": 0x80417028,
		"JSystem::@461": 0x80417030,
		"JSystem::@622": 0x80417034,
		"@622": 0x80417034,
		"JSystem::@623": 0x80417038,
		"@623": 0x80417038,
		"JSystem::@624": 0x8041703c,
		"@624": 0x8041703c,
		"JSystem::@413": 0x80417058,
		"@413": 0x80417058,
		"JSystem::@694": 0x80417060,
		"JSystem::@695": 0x80417064,
		"JSystem::@696": 0x80417068,
		"@696": 0x80417068,
		"JSystem::@1287": 0x8041706c,
		"@1287": 0x8041706c,
		"JSystem::@494": 0x80417078,
		"@494": 0x80417078,
		"JSystem::@495": 0x8041707c,
		"@495": 0x8041707c,
		"JSystem::@496": 0x80417080,
		"@496": 0x80417080,
		"JSystem::@551": 0x8041708c,
		"@551": 0x8041708c,
		"JSystem::@587": 0x80417098,
		"@587": 0x80417098,
		"JSystem::@588": 0x8041709c,
		"@588": 0x8041709c,
		"JSystem::@589": 0x804170a0,
		"@589": 0x804170a0,
		"JSystem::@590": 0x804170a4,
		"@590": 0x804170a4,
		"JSystem::@762": 0x804170c8,
		"JSystem::@763": 0x804170cc,
		"JSystem::@934": 0x804170d8,
		"@934": 0x804170d8,
		"JSystem::@935": 0x804170dc,
		"@935": 0x804170dc,
		"JSystem::@826": 0x804170e4,
		"@826": 0x804170e4,
		"JSystem::@829": 0x804170f8,
		"@829": 0x804170f8,
		"JSystem::@830": 0x804170fc,
		"@830": 0x804170fc,
		"JSystem::@932": 0x80417108,
		"@932": 0x80417108,
		"JSystem::@504": 0x80417118,
		"@504": 0x80417118,
		"JSystem::@989": 0x80417120,
		"@989": 0x80417120,
		"JSystem::@534": 0x80417138,
		"@534": 0x80417138,
		"JSystem::@535": 0x80417140,
		"@535": 0x80417140,
		"JSystem::@536": 0x80417148,
		"@536": 0x80417148,
		"JSystem::@434": 0x80417158,
		"@434": 0x80417158,
		"JSystem::@602": 0x8041715c,
		"JSystem::@680": 0x80417180,
		"@680": 0x80417180,
		"JSystem::@681": 0x80417184,
		"@681": 0x80417184,
		"JSystem::@943": 0x80417188,
		"JSystem::@944": 0x8041718c,
		"@944": 0x8041718c,
		"JSystem::@1207": 0x80417194,
		"@1207": 0x80417194,
		"JSystem::@1242": 0x80417198,
		"@1242": 0x80417198,
		"JSystem::@1373": 0x8041719c,
		"@1373": 0x8041719c,
		"JSystem::@509": 0x804171a0,
		"@509": 0x804171a0,
		"JSystem::@339": 0x804171a8,
		"JSystem::@340": 0x804171ac,
		"JSystem::@418": 0x804171b0,
		"@418": 0x804171b0,
		"JSystem::@419": 0x804171b4,
		"@419": 0x804171b4,
		"JSystem::@435": 0x804171c0,
		"JSystem::@568": 0x804171e8,
		"@568": 0x804171e8,
		"JSystem::@328": 0x804171f8,
		"@328": 0x804171f8,
		"JSystem::@345": 0x80417200,
		"@345": 0x80417200,
		"JSystem::@346": 0x80417204,
		"@346": 0x80417204,
		"JSystem::@252": 0x80417210,
		"@252": 0x80417210,
		"JSystem::@253": 0x80417214,
		"@253": 0x80417214,
		"JSystem::@274": 0x80417240,
		"@274": 0x80417240,
		"JSystem::@836": 0x8041724c,
		"@836": 0x8041724c,
		"JSystem::@120": 0x80417260,
		"@120": 0x80417260,
		"JSystem::@204": 0x80417270,
		"@204": 0x80417270,
		"JSystem::@231": 0x80417274,
		"@231": 0x80417274,
		"JSystem::@260": 0x80417278,
		"JSystem::@261": 0x8041727c,
		"JSystem::@332": 0x80417290,
		"@332": 0x80417290,
		"JSystem::@334": 0x804172a0,
		"@334": 0x804172a0,
		"JSystem::@236": 0x804172a8,
		"@236": 0x804172a8,
		"JSystem::@525": 0x804172b8,
		"@525": 0x804172b8,
		"JSystem::@526": 0x804172bc,
		"@526": 0x804172bc,
		"JSystem::@527": 0x804172c0,
		"@527": 0x804172c0,
		"JSystem::@528": 0x804172c4,
		"@528": 0x804172c4,
		"JSystem::@621": 0x804172dc,
		"@621": 0x804172dc,
		"JSystem::@754": 0x804172e8,
		"JSystem::@129": 0x80417308,
		"@129": 0x80417308,
		"JSystem::@642": 0x80417330,
		"JSystem::@797": 0x80417338,
		"JSystem::@948": 0x80417340,
		"@948": 0x80417340,
		"JSystem::@949": 0x80417344,
		"@949": 0x80417344,
		"JSystem::@950": 0x80417348,
		"@950": 0x80417348,
		"JSystem::@981": 0x80417358,
		"@981": 0x80417358,
		"JSystem::@1217": 0x80417360,
		"@1217": 0x80417360,
		"JSystem::@1326": 0x80417364,
		"@1326": 0x80417364,
		"JSystem::@1344": 0x8041736c,
		"@1344": 0x8041736c,
		"JSystem::@363": 0x80417370,
		"JSystem::@377": 0x80417378,
		"@377": 0x80417378,
		"JSystem::@411": 0x80417398,
		"@411": 0x80417398,
		"JSystem::@1706": 0x804173b0,
		"JSystem::@1707": 0x804173b4,
		"JSystem::@2032": 0x804173d0,
		"JSystem::@2829": 0x804173d4,
		"JSystem::@2830": 0x804173d8,
		"JSystem::@2840": 0x804173e8,
		"JSystem::@1786": 0x804173f0,
		"JSystem::@1787": 0x804173f4,
		"JSystem::@1673": 0x80417400,
		"JSystem::@1877": 0x80417404,
		"@1877": 0x80417404,
		"JSystem::@1955": 0x80417408,
		"JSystem::@1956": 0x8041740c,
		"JSystem::@1957": 0x80417410,
		"JSystem::@2076": 0x80417414,
		"JSystem::@1639": 0x8041741c,
		"JSystem::@1681": 0x8041742c,
		"JSystem::@1682": 0x80417430,
		"JSystem::@1683": 0x80417434,
		"JSystem::@1675": 0x80417450,
		"JSystem::@1689": 0x80417454,
		"JSystem::@1820": 0x80417458,
		"JSystem::@1659": 0x80417460,
		"JSystem::@1860": 0x80417464,
		"JSystem::@2759": 0x80417488,
		"JSystem::@2760": 0x8041748c,
		"JSystem::@2761": 0x80417490,
		"JSystem::@2762": 0x80417494,
		"JSystem::@3307": 0x80417498,
		"JSystem::@1743": 0x804174a8,
		"@1743": 0x804174a8,
		"JSystem::@1744": 0x804174ac,
		"@1744": 0x804174ac,
		"JSystem::@1745": 0x804174b0,
		"@1745": 0x804174b0,
		"JSystem::@2374": 0x804174c8,
		"JSystem::@2375": 0x804174cc,
		"JSystem::@2378": 0x804174d0,
		"JSystem::@2379": 0x804174d4,
		"JSystem::@2380": 0x804174d8,
		"JSystem::@2538": 0x804174dc,
		"JSystem::@2542": 0x804174e0,
		"JSystem::@4485": 0x804174e4,
		"JSystem::@4568": 0x804174e8,
		"@4568": 0x804174e8,
		"JSystem::@1505": 0x804174f0,
		"JSystem::@1506": 0x804174f4,
		"@1506": 0x804174f4,
		"JSystem::@1570": 0x80417508,
		"JSystem::@1571": 0x8041750c,
		"JSystem::@1509": 0x80417510,
		"@1509": 0x80417510,
		"JSystem::@1510": 0x80417514,
		"@1510": 0x80417514,
		"JSystem::@1511": 0x80417518,
		"@1511": 0x80417518,
		"JSystem::@126": 0x80417538,
		"JSystem::@118": 0x80417540,
		"@118": 0x80417540,
		"JSystem::@71": 0x80417548,
		"MSL_C.PPCEABI.bare.H::@156": 0x80417608,
		"MSL_C.PPCEABI.bare.H::@157": 0x8041760c,
		"MSL_C.PPCEABI.bare.H::@158": 0x80417610,
		"MSL_C.PPCEABI.bare.H::@159": 0x80417614,
		"MSL_C.PPCEABI.bare.H::@168": 0x80417618,
		"MSL_C.PPCEABI.bare.H::@169": 0x8041761c,
		"MSL_C.PPCEABI.bare.H::@170": 0x80417620,
		"MSL_C.PPCEABI.bare.H::@188": 0x80417624,
		"MSL_C.PPCEABI.bare.H::@106": 0x80417628,
		"@106": 0x80417628,
		"MSL_C.PPCEABI.bare.H::@107": 0x8041762c,
		"@107": 0x8041762c,
		"MSL_C.PPCEABI.bare.H::@108": 0x80417630,
		"@108": 0x80417630,
		"MSL_C.PPCEABI.bare.H::__log2e_m1$localstatic0$__log2f__Ff": 0x80417640,
		"__log2e_m1$localstatic0$__log2f__Ff": 0x80417640,
		"MSL_C.PPCEABI.bare.H::@93": 0x80417648,
		"MSL_C.PPCEABI.bare.H::_inf": 0x80417650,
		"_inf": 0x80417650,
		"MSL_C.PPCEABI.bare.H::_nan": 0x80417654,
		"_nan": 0x80417654,
		"MSL_C.PPCEABI.bare.H::@246": 0x80417658,
		"@246": 0x80417658,
		"MSL_C.PPCEABI.bare.H::@247": 0x8041765c,
		"@247": 0x8041765c,
		"MSL_C.PPCEABI.bare.H::@248": 0x80417660,
		"@248": 0x80417660,
		"MSL_C.PPCEABI.bare.H::@249": 0x80417664,
		"@249": 0x80417664,
		"MSL_C.PPCEABI.bare.H::@250": 0x80417668,
		"@250": 0x80417668,
		"MSL_C.PPCEABI.bare.H::@251": 0x8041766c,
		"@251": 0x8041766c,
		"MSL_C.PPCEABI.bare.H::@259": 0x80417678,
		"MSL_C.PPCEABI.bare.H::@260": 0x8041767c,
		"MSL_C.PPCEABI.bare.H::@261": 0x80417680,
		"MSL_C.PPCEABI.bare.H::@262": 0x80417684,
		"os::@153": 0x80417688,
		"mtx::@94": 0x80417690,
		"mtx::@95": 0x80417694,
		"mtx::@193": 0x80417698,
		"mtx::@214": 0x8041769c,
		"mtx::@217": 0x804176a0,
		"@217": 0x804176a0,
		"mtx::@218": 0x804176a4,
		"@218": 0x804176a4,
		"mtx::@97": 0x804176a8,
		"mtx::@98": 0x804176ac,
		"mtx::@99": 0x804176b0,
		"mtx::@100": 0x804176b4,
		"mtx::@103": 0x804176b8,
		"@103": 0x804176b8,
		"mtx::@104": 0x804176bc,
		"@104": 0x804176bc,
		"mtx::@116": 0x804176c0,
		"mtx::@117": 0x804176c4,
		"gx::@122": 0x804176cc,
		"@122": 0x804176cc,
		"gx::@123": 0x804176d0,
		"gx::@177": 0x804176d4,
		"gx::@178": 0x804176d8,
		"gx::@179": 0x804176dc,
		"gx::@83": 0x804176e8,
		"gx::@127": 0x804176fc,
		"gx::@148": 0x80417700,
		"gx::@167": 0x80417718,
		"gx::@164": 0x80417720,
		"gx::@192": 0x80417730,
		"gx::@193": 0x80417734,
		"gx::@194": 0x80417738,
		"@194": 0x80417738,
		"gx::@195": 0x8041773c,
		"@195": 0x8041773c,
		"gx::@196": 0x80417740,
		"@196": 0x80417740,
		"gx::@197": 0x80417744,
		"gx::@45": 0x80417748,
		"@45": 0x80417748,
		"gx::@125": 0x80417750,
		"@125": 0x80417750,
		"gx::@126": 0x80417754,
		"gx::@130": 0x80417770,
		"gx::@357": 0x80417784,
		"gx::@358": 0x80417788,
		"gx::@360": 0x8041778c,
		"gx::@405": 0x804177a0,
		"@405": 0x804177a0,
		"gx::@493": 0x804177a4,
		"@493": 0x804177a4,
		"gx::@14": 0x804177a8,
		"gx::@15": 0x804177ac,
		"gx::@16": 0x804177b0,
		"gx::@63": 0x804177c0,
		"gx::@64": 0x804177c4,
		"thp::@665": 0x804177d0,
		"@665": 0x804177d0,
		"thp::@666": 0x804177d4,
		"@666": 0x804177d4,
		"thp::@667": 0x804177d8,
		"@667": 0x804177d8,
		"thp::@668": 0x804177dc,
		"@668": 0x804177dc,
		"thp::@669": 0x804177e0,
		"THPPlayer::@22": 0x8040f1a8,
		"THPPlayer::@25": 0x8040f1b0,
		"THPPlayer::@28": 0x8040f1b4,
		"THPPlayer::@31": 0x8040f1b8,
		"THPPlayer::@55": 0x8040f1bc,
		"@55": 0x8040f1bc,
		"THPPlayer::@71": 0x8040f1c0,
		"THPPlayer::@72": 0x8040f1c4,
		"@72": 0x8040f1c4,
		"THPPlayer::@479": 0x8040f1d8,
		"@479": 0x8040f1d8,
		"THPPlayer::@791": 0x8040f1dc,
		"@791": 0x8040f1dc,
		"THPPlayer::@792": 0x8040f1e0,
		"@792": 0x8040f1e0,
		"MarioUtil::@1997": 0x80415380,
		"MarioUtil::@1999": 0x80415384,
		"MarioUtil::@2009": 0x80415388,
		"MarioUtil::@2452": 0x80415398,
		"MarioUtil::@2453": 0x8041539c,
		"MarioUtil::@2472": 0x804153a0,
		"MarioUtil::@2473": 0x804153a4,
		"MarioUtil::@2948": 0x804153a8,
		"MarioUtil::@3041": 0x804153ac,
		"MarioUtil::@3042": 0x804153b0,
		"MarioUtil::@3043": 0x804153b4,
		"MarioUtil::@3044": 0x804153b8,
		"MarioUtil::@3357": 0x804153bc,
		"MarioUtil::@3505": 0x804153c0,
		"MarioUtil::@3506": 0x804153c4,
		"MarioUtil::@3507": 0x804153c8,
		"MarioUtil::@3555": 0x804153cc,
		"MarioUtil::@3556": 0x804153d0,
		"MarioUtil::@3557": 0x804153d4,
		"MarioUtil::@3558": 0x804153d8,
		"MarioUtil::@3560": 0x804153dc,
		"MarioUtil::@3561": 0x804153e0,
		"MarioUtil::@3565": 0x804153e4,
		"MarioUtil::@3566": 0x804153e8,
		"MarioUtil::@2043": 0x804153f8,
		"MarioUtil::@2044": 0x804153fc,
		"MarioUtil::@2045": 0x80415400,
		"MarioUtil::@2046": 0x80415404,
		"MarioUtil::@2228": 0x8041540c,
		"MarioUtil::@2229": 0x80415410,
		"MarioUtil::@2230": 0x80415414,
		"MarioUtil::@2231": 0x80415418,
		"MarioUtil::@2665": 0x80415420,
		"MarioUtil::@2666": 0x80415428,
		"MarioUtil::@2667": 0x8041542c,
		"MarioUtil::@2844": 0x80415430,
		"MarioUtil::@1608": 0x80415438,
		"MarioUtil::@1627": 0x80415448,
		"MarioUtil::@1638": 0x8041544c,
		"MarioUtil::@1639": 0x80415450,
		"MarioUtil::@1673": 0x80415454,
		"MarioUtil::@1674": 0x80415458,
		"MarioUtil::@1675": 0x8041545c,
		"MarioUtil::@1676": 0x80415460,
		"MarioUtil::@1797": 0x80415464,
		"MarioUtil::@1798": 0x80415468,
		"MarioUtil::@1884": 0x80415480,
		"@1884": 0x80415480,
		"MarioUtil::@2093": 0x80415488,
		"MarioUtil::@2094": 0x8041548c,
		"MarioUtil::@2123": 0x80415490,
		"MarioUtil::@2124": 0x80415494,
		"MarioUtil::@2156": 0x80415498,
		"MarioUtil::@2194": 0x804154a0,
		"MarioUtil::@2550": 0x804154b8,
		"MarioUtil::@2551": 0x804154c0,
		"MarioUtil::@2552": 0x804154c4,
		"MarioUtil::@2553": 0x804154c8,
		"MarioUtil::@2554": 0x804154cc,
		"MarioUtil::@2555": 0x804154d4,
		"MarioUtil::@1629": 0x804154f0,
		"MarioUtil::@1630": 0x804154f4,
		"MarioUtil::@1631": 0x804154f8,
		"MarioUtil::@1802": 0x80415504,
		"MarioUtil::@1803": 0x80415508,
		"MarioUtil::@1833": 0x80415518,
		"MarioUtil::@1834": 0x8041551c,
		"@1834": 0x8041551c,
		"MarioUtil::@2235": 0x80415520,
		"MarioUtil::@2297": 0x80415524,
		"MarioUtil::@2312": 0x80415528,
		"MarioUtil::@2315": 0x8041552c,
		"MarioUtil::@2743": 0x80415534,
		"MarioUtil::@2744": 0x80415538,
		"MarioUtil::@2745": 0x8041553c,
		"MarioUtil::@2746": 0x80415540,
		"MarioUtil::@2747": 0x80415544,
		"MarioUtil::@2748": 0x80415548,
		"MarioUtil::@2749": 0x8041554c,
		"MarioUtil::@2750": 0x80415550,
		"MarioUtil::@2751": 0x80415554,
		"MarioUtil::@2752": 0x80415558,
		"MarioUtil::@2753": 0x8041555c,
		"MarioUtil::@2754": 0x80415560,
		"MarioUtil::@2857": 0x80415564,
		"MarioUtil::@2858": 0x80415568,
		"MarioUtil::@2859": 0x8041556c,
		"MarioUtil::@2976": 0x80415570,
		"MarioUtil::@2977": 0x80415574,
		"MarioUtil::@2978": 0x80415578,
		"MarioUtil::@4014": 0x8041557c,
		"MarioUtil::@4158": 0x80415580,
		"MarioUtil::@4159": 0x80415584,
		"MarioUtil::@4634": 0x80415588,
		"MarioUtil::@4756": 0x8041558c,
		"MarioUtil::@4757": 0x80415590,
		"MarioUtil::@4758": 0x80415594,
		"MarioUtil::@4759": 0x80415598,
		"MarioUtil::@4869": 0x8041559c,
		"MarioUtil::@5163": 0x804155a8,
		"MarioUtil::@5164": 0x804155ac,
		"MarioUtil::@51": 0x804155b0,
		"@51": 0x804155b0,
		"MarioUtil::@52": 0x804155b4,
		"MarioUtil::@53": 0x804155b8,
		"@53": 0x804155b8,
		"MarioUtil::@1799": 0x804155c0,
		"MarioUtil::@2233": 0x804155d4,
		"MarioUtil::@1767": 0x804155e0,
		"MarioUtil::@1790": 0x804155e4,
		"MarioUtil::@1841": 0x804155e8,
		"MarioUtil::@2244": 0x804155ec,
		"MarioUtil::@2245": 0x804155f0,
		"MarioUtil::sFogOffColor$1583": 0x804155f8,
		"sFogOffColor$1583": 0x804155f8,
		"MarioUtil::@2280": 0x80415610,
		"MarioUtil::@2282": 0x80415620,
		"MarioUtil::@1941": 0x80415630,
		"MarioUtil::@1942": 0x80415634,
		"M3DUtil::@1572": 0x80415638,
		"M3DUtil::@1573": 0x8041563c,
		"M3DUtil::@1716": 0x80415640,
		"@1716": 0x80415640,
		"M3DUtil::@1875": 0x80415658,
		"M3DUtil::@1908": 0x80415660,
		"M3DUtil::@1909": 0x80415664,
		"M3DUtil::@2660": 0x80415670,
		"M3DUtil::@2663": 0x80415678,
		"M3DUtil::@2666": 0x80415680,
		"M3DUtil::@2669": 0x80415688,
		"M3DUtil::@2672": 0x80415690,
		"M3DUtil::@2019": 0x80415698,
		"M3DUtil::@2020": 0x804156a0,
		"M3DUtil::@2021": 0x804156a4,
		"M3DUtil::@2022": 0x804156ac,
		"M3DUtil::@2023": 0x804156b4,
		"M3DUtil::@2024": 0x804156bc,
		"M3DUtil::@2025": 0x804156c4,
		"M3DUtil::@2161": 0x804156cc,
		"M3DUtil::@2162": 0x804156d4,
		"M3DUtil::@2163": 0x804156d8,
		"M3DUtil::@1661": 0x804156e0,
		"M3DUtil::@1694": 0x804156e4,
		"System::@2802": 0x80416500,
		"System::@2803": 0x80416504,
		"System::@2171": 0x80416560,
		"System::@2172": 0x80416564,
		"System::@2316": 0x80416578,
		"System::@2317": 0x8041657c,
		"System::@1731": 0x80416590,
		"@1731": 0x80416590,
		"System::@2398": 0x80416598,
		"System::@2389": 0x804165f0,
		"System::@2731": 0x804165f8,
		"System::@2738": 0x80416600,
		"System::@2739": 0x80416604,
		"System::@2740": 0x80416608,
		"System::@2741": 0x8041660c,
		"System::@2742": 0x80416610,
		"System::@2753": 0x80416618,
		"System::@2754": 0x8041661c,
		"System::@2975": 0x80416638,
		"System::@1626": 0x80416640,
		"System::@4673": 0x80416698,
		"System::@2844": 0x804166ec,
		"System::@2850": 0x8041671c,
		"System::@2851": 0x80416724,
		"System::@2852": 0x8041672c,
		"System::@2853": 0x80416734,
		"System::@1607": 0x80416768,
		"System::@2481": 0x80416780,
		"System::@2485": 0x80416784,
		"System::@1806": 0x804167e0,
		"System::@1807": 0x804167e4,
		"System::@2115": 0x804167e8,
		"System::@2116": 0x804167ec,
		"System::@2121": 0x804167f8,
		"System::@2122": 0x804167fc,
		"System::@1902": 0x80416800,
		"System::@1665": 0x80416808,
		"System::@3960": 0x80416874,
		"System::@3962": 0x8041687c,
		"System::@3964": 0x80416884,
		"System::@4118": 0x804168d0,
		"System::@2093": 0x80416968,
		"System::@2094": 0x8041696c,
		"System::@5046": 0x804169b4,
		"System::@5060": 0x804169e0,
		"System::@5102": 0x80416a14,
		"System::@5207": 0x80416a68,
		"@5207": 0x80416a68,
		"System::@5328": 0x80416ae8,
		"System::@5333": 0x80416af8,
		"System::@3804": 0x80416b88,
		"Strategic::@2838": 0x80415248,
		"Strategic::@2872": 0x8041524c,
		"Strategic::@2873": 0x80415250,
		"Strategic::@2935": 0x80415254,
		"Strategic::@3064": 0x80415258,
		"Strategic::@3163": 0x8041525c,
		"Strategic::@3282": 0x80415260,
		"Strategic::@3344": 0x80415264,
		"Strategic::@3345": 0x80415268,
		"Strategic::@3346": 0x8041526c,
		"Strategic::@3347": 0x80415270,
		"Strategic::@2101": 0x804152d0,
		"Strategic::@2103": 0x804152d4,
		"Strategic::@2104": 0x804152d8,
		"Strategic::@2277": 0x804152e0,
		"Strategic::@1841": 0x804152e8,
		"Strategic::@1947": 0x804152f0,
		"Strategic::@1662": 0x804152f8,
		"Strategic::@2285": 0x80415308,
		"Strategic::@2409": 0x8041530c,
		"Strategic::@2532": 0x80415310,
		"Strategic::@2533": 0x80415318,
		"Strategic::@2534": 0x80415320,
		"Strategic::@2535": 0x80415328,
		"Strategic::@2536": 0x80415330,
		"Strategic::@2537": 0x80415338,
		"Strategic::@2538": 0x80415340,
		"Strategic::@2539": 0x80415344,
		"Strategic::@2540": 0x8041534c,
		"Strategic::@2829": 0x80415354,
		"Strategic::@2830": 0x80415358,
		"Strategic::@2831": 0x8041535c,
		"Strategic::@1772": 0x80415360,
		"Strategic::@1825": 0x80415364,
		"Strategic::@1540": 0x80415368,
		"Strategic::@1618": 0x80415370,
		"Strategic::@1619": 0x80415374,
		"Strategic::@1660": 0x80415378,
		"Player::@2856": 0x804158b4,
		"Player::@2857": 0x804158bc,
		"Player::@2859": 0x804158cc,
		"Player::@2860": 0x804158d4,
		"Player::@2861": 0x804158dc,
		"Player::@2865": 0x804158fc,
		"Player::@2866": 0x80415904,
		"Player::@2867": 0x8041590c,
		"Player::@2958": 0x804159f8,
		"Player::@3647": 0x80415a7c,
		"Player::@3070": 0x80415ebc,
		"Player::@2710": 0x804161b8,
		"Player::@2712": 0x804161bc,
		"Player::@2714": 0x804161c0,
		"Player::@2717": 0x804161c4,
		"Player::@2718": 0x804161cc,
		"Player::@2719": 0x804161d0,
		"Player::@3571": 0x804162a4,
		"Player::@3749": 0x804162b8,
		"Player::@3998": 0x804162ec,
		"Player::@6572": 0x80416314,
		"@6572": 0x80416314,
		"Player::@6573": 0x80416318,
		"@6573": 0x80416318,
		"Player::@2699": 0x80416330,
		"Player::@3018": 0x80416338,
		"Player::@3035": 0x8041633c,
		"Player::@3049": 0x80416344,
		"Player::@3680": 0x80416384,
		"Player::@3825": 0x80416394,
		"Player::@3865": 0x804163a8,
		"@3865": 0x804163a8,
		"Player::@4343": 0x804163ac,
		"Player::@4344": 0x804163b0,
		"Player::@4345": 0x804163b4,
		"Player::@4346": 0x804163b8,
		"Player::@4347": 0x804163bc,
		"Player::@4502": 0x804163c0,
		"Player::@4503": 0x804163c4,
		"Player::@4561": 0x804163cc,
		"Player::@4562": 0x804163d0,
		"Player::@4563": 0x804163d4,
		"Player::@4623": 0x804163d8,
		"Player::@4624": 0x804163dc,
		"Player::@4625": 0x804163e0,
		"Player::@4637": 0x804163ec,
		"Player::@4638": 0x804163f0,
		"Player::@4639": 0x804163f4,
		"Player::@4640": 0x804163f8,
		"Player::@4641": 0x804163fc,
		"Player::@4642": 0x80416400,
		"Player::@4643": 0x80416404,
		"Player::@4644": 0x80416408,
		"Player::@4648": 0x8041640c,
		"Player::@4650": 0x80416410,
		"Player::@4651": 0x80416414,
		"Player::@4652": 0x8041641c,
		"Player::@4653": 0x80416420,
		"Player::@4654": 0x80416424,
		"Player::@4731": 0x80416428,
		"Player::@4732": 0x80416430,
		"Player::@4733": 0x80416438,
		"Player::@4734": 0x80416440,
		"Player::@4735": 0x80416448,
		"Player::@4737": 0x8041644c,
		"Player::@4739": 0x80416454,
		"Player::@4740": 0x8041645c,
		"Player::@4744": 0x80416460,
		"Player::@4745": 0x80416468,
		"NPC::@3245": 0x80414df8,
		"NPC::@3246": 0x80414dfc,
		"NPC::@3247": 0x80414e00,
		"NPC::@3361": 0x80414e10,
		"NPC::@3362": 0x80414e14,
		"NPC::@3363": 0x80414e18,
		"NPC::@3365": 0x80414e20,
		"NPC::@3366": 0x80414e24,
		"NPC::@3472": 0x80414e28,
		"NPC::@3878": 0x80414e2c,
		"NPC::@3879": 0x80414e30,
		"NPC::@4245": 0x80414e34,
		"NPC::@4246": 0x80414e38,
		"NPC::@4247": 0x80414e3c,
		"NPC::@4250": 0x80414e50,
		"NPC::@4778": 0x80414e54,
		"NPC::@3704": 0x80414e5c,
		"NPC::@3705": 0x80414e60,
		"NPC::@3706": 0x80414e64,
		"NPC::@3707": 0x80414e68,
		"NPC::@3935": 0x80414e80,
		"NPC::@3936": 0x80414e84,
		"NPC::@3989": 0x80414e88,
		"NPC::@4213": 0x80414e8c,
		"NPC::@2536": 0x80414ebc,
		"NPC::@2804": 0x80414ec0,
		"NPC::@2805": 0x80414ec4,
		"NPC::@2860": 0x80414ec8,
		"NPC::@2898": 0x80414ed0,
		"NPC::@2934": 0x80414ed4,
		"NPC::@2857": 0x80414f00,
		"NPC::@3036": 0x80414f04,
		"NPC::@3037": 0x80414f08,
		"NPC::@2161": 0x80414f10,
		"NPC::@2163": 0x80414f14,
		"NPC::@2165": 0x80414f18,
		"NPC::@2167": 0x80414f1c,
		"NPC::@2169": 0x80414f20,
		"NPC::@2171": 0x80414f24,
		"NPC::@2173": 0x80414f28,
		"NPC::@2175": 0x80414f2c,
		"NPC::@2177": 0x80414f30,
		"NPC::@2180": 0x80414f34,
		"NPC::@2182": 0x80414f38,
		"NPC::@2184": 0x80414f3c,
		"NPC::@2187": 0x80414f40,
		"NPC::@2189": 0x80414f44,
		"NPC::@2194": 0x80414f48,
		"NPC::@2196": 0x80414f4c,
		"NPC::@2204": 0x80414f5c,
		"NPC::@2206": 0x80414f60,
		"NPC::@2208": 0x80414f64,
		"NPC::@2341": 0x80414f90,
		"NPC::@2356": 0x80414f98,
		"NPC::@2375": 0x80414fac,
		"NPC::@2419": 0x80414fb0,
		"NPC::sPeach_TakenMiddle": 0x80414fd0,
		"sPeach_TakenMiddle": 0x80414fd0,
		"NPC::@1539": 0x80414fd8,
		"NPC::sMonteM_TieBColorBuf0": 0x80414fe0,
		"sMonteM_TieBColorBuf0": 0x80414fe0,
		"NPC::sMonteM_TieBColorBuf1": 0x80414fe8,
		"sMonteM_TieBColorBuf1": 0x80414fe8,
		"NPC::@1573": 0x80414ff0,
		"NPC::@1577": 0x80414ff8,
		"NPC::sMareMB_ElderMat1ColorBuf0": 0x80415000,
		"sMareMB_ElderMat1ColorBuf0": 0x80415000,
		"NPC::sMareMB_ElderMat1ColorBuf1": 0x80415008,
		"sMareMB_ElderMat1ColorBuf1": 0x80415008,
		"NPC::sMareMB_ElderMat2ColorBuf0": 0x80415010,
		"sMareMB_ElderMat2ColorBuf0": 0x80415010,
		"NPC::sMareMB_ElderMat2ColorBuf1": 0x80415018,
		"sMareMB_ElderMat2ColorBuf1": 0x80415018,
		"NPC::@1583": 0x80415020,
		"NPC::sMareMB_ElderMat3ColorBuf0": 0x80415028,
		"sMareMB_ElderMat3ColorBuf0": 0x80415028,
		"NPC::sMareMB_ElderMat3ColorBuf1": 0x80415030,
		"sMareMB_ElderMat3ColorBuf1": 0x80415030,
		"NPC::@1584": 0x80415038,
		"NPC::sMareMB_FishingRodMat1ColorBuf0": 0x80415040,
		"sMareMB_FishingRodMat1ColorBuf0": 0x80415040,
		"NPC::sMareMB_FishingRodMat1ColorBuf1": 0x80415048,
		"sMareMB_FishingRodMat1ColorBuf1": 0x80415048,
		"NPC::sMareMB_FishingRodMat2ColorBuf0": 0x80415050,
		"sMareMB_FishingRodMat2ColorBuf0": 0x80415050,
		"NPC::sMareMB_FishingRodMat2ColorBuf1": 0x80415058,
		"sMareMB_FishingRodMat2ColorBuf1": 0x80415058,
		"NPC::sMareMB_FishingRodMat3ColorBuf0": 0x80415060,
		"sMareMB_FishingRodMat3ColorBuf0": 0x80415060,
		"NPC::sMareMB_FishingRodMat3ColorBuf1": 0x80415068,
		"sMareMB_FishingRodMat3ColorBuf1": 0x80415068,
		"NPC::sMareMC_HatFColorBuf0": 0x80415070,
		"sMareMC_HatFColorBuf0": 0x80415070,
		"NPC::sMareMC_HatFColorBuf1": 0x80415078,
		"sMareMC_HatFColorBuf1": 0x80415078,
		"NPC::sMareMC_BeardColorBuf0": 0x80415080,
		"sMareMC_BeardColorBuf0": 0x80415080,
		"NPC::sMareMC_BeardColorBuf1": 0x80415088,
		"sMareMC_BeardColorBuf1": 0x80415088,
		"NPC::sMareMC_MustacheColorBuf0": 0x80415090,
		"sMareMC_MustacheColorBuf0": 0x80415090,
		"NPC::sMareMC_MustacheColorBuf1": 0x80415098,
		"sMareMC_MustacheColorBuf1": 0x80415098,
		"NPC::sMareMD_PipeColorBuf0": 0x804150a0,
		"sMareMD_PipeColorBuf0": 0x804150a0,
		"NPC::sMareMD_PipeColorBuf1": 0x804150a8,
		"sMareMD_PipeColorBuf1": 0x804150a8,
		"NPC::@1590": 0x804150b0,
		"NPC::sMareWB_BabyBodyColorBuf0": 0x804150b8,
		"sMareWB_BabyBodyColorBuf0": 0x804150b8,
		"NPC::@1598": 0x804150c0,
		"NPC::sMareWB_BabyHatColorBuf0": 0x804150c8,
		"sMareWB_BabyHatColorBuf0": 0x804150c8,
		"NPC::sMareWB_BabyHatColorBuf1": 0x804150d0,
		"sMareWB_BabyHatColorBuf1": 0x804150d0,
		"NPC::sMareWB_BabyBedColorBuf0": 0x804150d8,
		"sMareWB_BabyBedColorBuf0": 0x804150d8,
		"NPC::sMareWB_BabyBedColorBuf1": 0x804150e0,
		"sMareWB_BabyBedColorBuf1": 0x804150e0,
		"NPC::@1614": 0x804150e8,
		"@1614": 0x804150e8,
		"NPC::@1621": 0x804150f0,
		"TBaseNPC::sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x80415100,
		"sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x80415100,
		"NPC::@2532": 0x80415108,
		"NPC::@2533": 0x8041510c,
		"NPC::@2534": 0x80415110,
		"NPC::@2754": 0x80415128,
		"NPC::@2755": 0x8041512c,
		"NPC::@2756": 0x80415130,
		"NPC::@1832": 0x80415138,
		"NPC::@1833": 0x8041513c,
		"NPC::@3189": 0x80415158,
		"NPC::@3190": 0x8041515c,
		"NPC::@3191": 0x80415160,
		"NPC::@3387": 0x80415168,
		"NPC::@3388": 0x8041516c,
		"NPC::@3467": 0x80415178,
		"NPC::@3468": 0x8041517c,
		"NPC::@3776": 0x80415180,
		"NPC::@1682": 0x80415188,
		"NPC::@1683": 0x8041518c,
		"NPC::@1684": 0x80415190,
		"NPC::@1685": 0x80415194,
		"NPC::@1686": 0x80415198,
		"NPC::@2611": 0x804151b0,
		"NPC::@2612": 0x804151b4,
		"NPC::@2613": 0x804151b8,
		"NPC::@2614": 0x804151bc,
		"NPC::@2615": 0x804151c0,
		"NPC::@2695": 0x804151c4,
		"NPC::@2499": 0x804151e0,
		"NPC::@2500": 0x804151e4,
		"NPC::@2501": 0x804151e8,
		"NPC::@2319": 0x80415228,
		"NPC::@2320": 0x8041522c,
		"NPC::@2321": 0x80415230,
		"NPC::@2322": 0x80415234,
		"MSound::@1983": 0x8040ee68,
		"MSound::@1984": 0x8040ee6c,
		"MSound::@1985": 0x8040ee70,
		"MSound::@2263": 0x8040ef00,
		"MSound::@2264": 0x8040ef04,
		"MSound::@2265": 0x8040ef08,
		"MSound::@2486": 0x8040ef18,
		"MSound::@2543": 0x8040ef1c,
		"MSound::@2544": 0x8040ef20,
		"MSound::@2545": 0x8040ef24,
		"MSound::@2575": 0x8040ef28,
		"MSound::@2576": 0x8040ef2c,
		"MSound::@2577": 0x8040ef30,
		"MSound::@2818": 0x8040ef40,
		"MSound::@2819": 0x8040ef44,
		"MSound::@2820": 0x8040ef48,
		"MSound::@2821": 0x8040ef4c,
		"MSound::@2823": 0x8040ef50,
		"MSound::@2824": 0x8040ef54,
		"MSound::@2825": 0x8040ef58,
		"MSound::@2827": 0x8040ef5c,
		"MSound::@2828": 0x8040ef60,
		"MSound::@2829": 0x8040ef64,
		"MSound::@2830": 0x8040ef68,
		"MSound::@2831": 0x8040ef6c,
		"MSound::@2833": 0x8040ef70,
		"MSound::@2837": 0x8040ef74,
		"MSound::@2838": 0x8040ef78,
		"MSound::@2839": 0x8040ef7c,
		"MSound::@2840": 0x8040ef80,
		"MSound::@2842": 0x8040ef84,
		"MSound::@2843": 0x8040ef88,
		"MSound::@2845": 0x8040ef8c,
		"MSound::@2847": 0x8040ef90,
		"MSound::@2848": 0x8040ef94,
		"MSound::@2849": 0x8040ef98,
		"MSound::@2850": 0x8040ef9c,
		"MSound::@2859": 0x8040efbc,
		"MSound::@2860": 0x8040efc0,
		"MSound::@2874": 0x8040efe4,
		"MSound::@2878": 0x8040efe8,
		"MSound::@2884": 0x8040eff8,
		"MSound::@2890": 0x8040f000,
		"MSound::@2895": 0x8040f008,
		"MSound::@2902": 0x8040f018,
		"MSound::@2907": 0x8040f024,
		"MSound::@2909": 0x8040f02c,
		"MSound::@2910": 0x8040f030,
		"MSound::@2912": 0x8040f034,
		"MSound::@2915": 0x8040f03c,
		"MSound::@2919": 0x8040f044,
		"MSound::@2920": 0x8040f048,
		"MSound::@2923": 0x8040f050,
		"MSound::@2924": 0x8040f054,
		"MSound::@2925": 0x8040f058,
		"MSound::@2927": 0x8040f05c,
		"MSound::@2929": 0x8040f064,
		"MSound::@2931": 0x8040f06c,
		"MSound::@2933": 0x8040f070,
		"MSound::@2935": 0x8040f074,
		"MSound::@2937": 0x8040f078,
		"MSound::@2939": 0x8040f07c,
		"MSound::@1995": 0x8040f0a8,
		"MSound::@1996": 0x8040f0ac,
		"MSound::@1997": 0x8040f0b0,
		"MSound::@1998": 0x8040f0b4,
		"MSound::@1999": 0x8040f0b8,
		"MSound::@2000": 0x8040f0bc,
		"MSound::@2001": 0x8040f0c0,
		"MSound::@2020": 0x8040f104,
		"MSound::@2021": 0x8040f108,
		"MSound::@2022": 0x8040f10c,
		"MSound::@2023": 0x8040f114,
		"MSound::@2025": 0x8040f11c,
		"MSound::@2027": 0x8040f120,
		"MSound::@2029": 0x8040f124,
		"MSound::@2030": 0x8040f128,
		"MSound::@2031": 0x8040f12c,
		"MSound::@2036": 0x8040f160,
		"MSound::@2080": 0x8040f180,
		"MSound::@2039": 0x8040f198,
		"MSound::@2040": 0x8040f19c,
		"MSound::@2041": 0x8040f1a0,
		"MoveBG::no_data_anim_info": 0x80412d90,
		"no_data_anim_info": 0x80412d90,
		"MoveBG::normal_sound_info": 0x80412d98,
		"normal_sound_info": 0x80412d98,
		"MoveBG::billboard_dolphin_anim_info": 0x80412da8,
		"billboard_dolphin_anim_info": 0x80412da8,
		"MoveBG::billboard_sun_anim_info": 0x80412db0,
		"billboard_sun_anim_info": 0x80412db0,
		"MoveBG::billboard_restaurant_anim_info": 0x80412db8,
		"billboard_restaurant_anim_info": 0x80412db8,
		"MoveBG::billboard_fish_anim_info": 0x80412dc0,
		"billboard_fish_anim_info": 0x80412dc0,
		"MoveBG::MonteChair_anim_info": 0x80412dd0,
		"MonteChair_anim_info": 0x80412dd0,
		"MoveBG::@2798": 0x80412dd8,
		"MoveBG::doorHotel_anim_info": 0x80412de0,
		"doorHotel_anim_info": 0x80412de0,
		"MoveBG::@2802": 0x80412de8,
		"MoveBG::manhole_anim_info": 0x80412df0,
		"manhole_anim_info": 0x80412df0,
		"MoveBG::manhole_map_collision_info": 0x80412df8,
		"manhole_map_collision_info": 0x80412df8,
		"MoveBG::@2804": 0x80412e00,
		"MoveBG::FruitBasket_anim_info": 0x80412e08,
		"FruitBasket_anim_info": 0x80412e08,
		"MoveBG::@2805": 0x80412e10,
		"MoveBG::FruitBasket_map_collision_data": 0x80412e18,
		"FruitBasket_map_collision_data": 0x80412e18,
		"MoveBG::FruitBasket_map_collision_info": 0x80412e20,
		"FruitBasket_map_collision_info": 0x80412e20,
		"MoveBG::BasketReverse_anim_info": 0x80412e28,
		"BasketReverse_anim_info": 0x80412e28,
		"MoveBG::BasketReverse_map_collision_data": 0x80412e30,
		"BasketReverse_map_collision_data": 0x80412e30,
		"MoveBG::BasketReverse_map_collision_info": 0x80412e38,
		"BasketReverse_map_collision_info": 0x80412e38,
		"MoveBG::Pile_map_collision_data": 0x80412e48,
		"Pile_map_collision_data": 0x80412e48,
		"MoveBG::Pile_map_collision_info": 0x80412e50,
		"Pile_map_collision_info": 0x80412e50,
		"MoveBG::ChipShine_anim_info": 0x80412e58,
		"ChipShine_anim_info": 0x80412e58,
		"MoveBG::KoopaJrSignM_anim_info": 0x80412e60,
		"KoopaJrSignM_anim_info": 0x80412e60,
		"MoveBG::SignCircle_anim_info": 0x80412e68,
		"SignCircle_anim_info": 0x80412e68,
		"MoveBG::SignCross_anim_info": 0x80412e70,
		"SignCross_anim_info": 0x80412e70,
		"MoveBG::SignTriangle_anim_info": 0x80412e78,
		"SignTriangle_anim_info": 0x80412e78,
		"MoveBG::ObjSwitch_map_collision_data": 0x80412e80,
		"ObjSwitch_map_collision_data": 0x80412e80,
		"MoveBG::ObjSwitch_map_collision_info": 0x80412e88,
		"ObjSwitch_map_collision_info": 0x80412e88,
		"MoveBG::RedCoinSwitch_map_collision_data": 0x80412e90,
		"RedCoinSwitch_map_collision_data": 0x80412e90,
		"MoveBG::RedCoinSwitch_map_collision_info": 0x80412e98,
		"RedCoinSwitch_map_collision_info": 0x80412e98,
		"MoveBG::coin_sound_info": 0x80412ea8,
		"coin_sound_info": 0x80412ea8,
		"MoveBG::mario_cap_anim_info": 0x80412ec0,
		"mario_cap_anim_info": 0x80412ec0,
		"MoveBG::coin_anim_info": 0x80412ec8,
		"coin_anim_info": 0x80412ec8,
		"MoveBG::eggYoshi_anim_info": 0x80412ed0,
		"eggYoshi_anim_info": 0x80412ed0,
		"MoveBG::NozzleBox_anim_info": 0x80412ed8,
		"NozzleBox_anim_info": 0x80412ed8,
		"MoveBG::mushroom1up_anim_info": 0x80412ee0,
		"mushroom1up_anim_info": 0x80412ee0,
		"MoveBG::jumpbase_anim_info": 0x80412ee8,
		"jumpbase_anim_info": 0x80412ee8,
		"MoveBG::jumpbase_map_collision_data": 0x80412ef0,
		"jumpbase_map_collision_data": 0x80412ef0,
		"MoveBG::jumpbase_map_collision_info": 0x80412ef8,
		"jumpbase_map_collision_info": 0x80412ef8,
		"MoveBG::fruit_sound_info": 0x80412f00,
		"fruit_sound_info": 0x80412f00,
		"MoveBG::CoverPine_anim_info": 0x80412f08,
		"CoverPine_anim_info": 0x80412f08,
		"MoveBG::durian_sound_info": 0x80412f10,
		"durian_sound_info": 0x80412f10,
		"MoveBG::fence3x3_anim_info": 0x80412f18,
		"fence3x3_anim_info": 0x80412f18,
		"MoveBG::fence_revolve_outer_anim_info": 0x80412f20,
		"fence_revolve_outer_anim_info": 0x80412f20,
		"MoveBG::FenceWaterV_map_collision_data": 0x80412f28,
		"FenceWaterV_map_collision_data": 0x80412f28,
		"MoveBG::FenceWaterV_map_collision_info": 0x80412f30,
		"FenceWaterV_map_collision_info": 0x80412f30,
		"MoveBG::FenceWaterH_map_collision_info": 0x80412f38,
		"FenceWaterH_map_collision_info": 0x80412f38,
		"MoveBG::RailFence_anim_info": 0x80412f40,
		"RailFence_anim_info": 0x80412f40,
		"MoveBG::RailFence_map_collision_info": 0x80412f48,
		"RailFence_map_collision_info": 0x80412f48,
		"MoveBG::BambooRailFence_anim_info": 0x80412f50,
		"BambooRailFence_anim_info": 0x80412f50,
		"MoveBG::wood_barrel_anim_info": 0x80412f58,
		"wood_barrel_anim_info": 0x80412f58,
		"MoveBG::wood_barrel_map_collision_info": 0x80412f68,
		"wood_barrel_map_collision_info": 0x80412f68,
		"MoveBG::wood_barrel_sound_info": 0x80412f70,
		"wood_barrel_sound_info": 0x80412f70,
		"MoveBG::wood_barrel_sink_data": 0x80412f78,
		"wood_barrel_sink_data": 0x80412f78,
		"MoveBG::barrel_float_map_collision_data": 0x80412f80,
		"barrel_float_map_collision_data": 0x80412f80,
		"MoveBG::barrel_float_map_collision_info": 0x80412f88,
		"barrel_float_map_collision_info": 0x80412f88,
		"MoveBG::drum_can_anim_info": 0x80412f90,
		"drum_can_anim_info": 0x80412f90,
		"MoveBG::drum_can_map_collision_info": 0x80412f98,
		"drum_can_map_collision_info": 0x80412f98,
		"MoveBG::barrel_oil_anim_info": 0x80412fa0,
		"barrel_oil_anim_info": 0x80412fa0,
		"MoveBG::warp_block_map_collision_data": 0x80412fa8,
		"warp_block_map_collision_data": 0x80412fa8,
		"MoveBG::warp_block_map_collision_info": 0x80412fb0,
		"warp_block_map_collision_info": 0x80412fb0,
		"MoveBG::move_block_map_collision_data": 0x80412fb8,
		"move_block_map_collision_data": 0x80412fb8,
		"MoveBG::move_block_map_collision_info": 0x80412fc0,
		"move_block_map_collision_info": 0x80412fc0,
		"MoveBG::move_block_center_map_collision_data": 0x80412fc8,
		"move_block_center_map_collision_data": 0x80412fc8,
		"MoveBG::move_block_center_map_collision_info": 0x80412fd0,
		"move_block_center_map_collision_info": 0x80412fd0,
		"MoveBG::breakable_block_anim_info": 0x80412fd8,
		"breakable_block_anim_info": 0x80412fd8,
		"MoveBG::breakable_block_map_collision_data": 0x80412fe0,
		"breakable_block_map_collision_data": 0x80412fe0,
		"MoveBG::breakable_block_map_collision_info": 0x80412fe8,
		"breakable_block_map_collision_info": 0x80412fe8,
		"MoveBG::water_roll_block_anim_info": 0x80412ff0,
		"water_roll_block_anim_info": 0x80412ff0,
		"MoveBG::water_roll_block_map_collision_data": 0x80412ff8,
		"water_roll_block_map_collision_data": 0x80412ff8,
		"MoveBG::water_roll_block_map_collision_info": 0x80413000,
		"water_roll_block_map_collision_info": 0x80413000,
		"MoveBG::sand_block_anim_info": 0x80413008,
		"sand_block_anim_info": 0x80413008,
		"MoveBG::sand_block_map_collision_info": 0x80413010,
		"sand_block_map_collision_info": 0x80413010,
		"MoveBG::MoveCoin_anim_info": 0x80413018,
		"MoveCoin_anim_info": 0x80413018,
		"MoveBG::cluster_block_anim_info": 0x80413020,
		"cluster_block_anim_info": 0x80413020,
		"MoveBG::NormalBlock_map_collision_data": 0x80413028,
		"NormalBlock_map_collision_data": 0x80413028,
		"MoveBG::NormalBlock_map_collision_info": 0x80413030,
		"NormalBlock_map_collision_info": 0x80413030,
		"MoveBG::IceBlock_map_collision_data": 0x80413038,
		"IceBlock_map_collision_data": 0x80413038,
		"MoveBG::IceBlock_map_collision_info": 0x80413040,
		"IceBlock_map_collision_info": 0x80413040,
		"MoveBG::BrickBlock_anim_info": 0x80413048,
		"BrickBlock_anim_info": 0x80413048,
		"MoveBG::BrickBlock_map_collision_data": 0x80413050,
		"BrickBlock_map_collision_data": 0x80413050,
		"MoveBG::BrickBlock_map_collision_info": 0x80413058,
		"BrickBlock_map_collision_info": 0x80413058,
		"MoveBG::WaterMelonBlock_anim_info": 0x80413060,
		"WaterMelonBlock_anim_info": 0x80413060,
		"MoveBG::WaterMelonBlock_map_collision_data": 0x80413068,
		"WaterMelonBlock_map_collision_data": 0x80413068,
		"MoveBG::WaterMelonBlock_map_collision_info": 0x80413070,
		"WaterMelonBlock_map_collision_info": 0x80413070,
		"MoveBG::TelesaBlock_map_collision_data": 0x80413078,
		"TelesaBlock_map_collision_data": 0x80413078,
		"MoveBG::TelesaBlock_map_collision_info": 0x80413080,
		"TelesaBlock_map_collision_info": 0x80413080,
		"MoveBG::JuiceBlock_map_collision_data": 0x80413088,
		"JuiceBlock_map_collision_data": 0x80413088,
		"MoveBG::JuiceBlock_map_collision_info": 0x80413090,
		"JuiceBlock_map_collision_info": 0x80413090,
		"MoveBG::SuperHipDropBlock_anim_info": 0x80413098,
		"SuperHipDropBlock_anim_info": 0x80413098,
		"MoveBG::SuperHipDropBlock_map_collision_data": 0x804130a0,
		"SuperHipDropBlock_map_collision_data": 0x804130a0,
		"MoveBG::SuperHipDropBlock_map_collision_info": 0x804130a8,
		"SuperHipDropBlock_map_collision_info": 0x804130a8,
		"MoveBG::PalmNormal_anim_info": 0x804130b0,
		"PalmNormal_anim_info": 0x804130b0,
		"MoveBG::PalmNormalTree_map_collision_data": 0x804130b8,
		"PalmNormalTree_map_collision_data": 0x804130b8,
		"MoveBG::PalmNormalTree_map_collision_info": 0x804130c0,
		"PalmNormalTree_map_collision_info": 0x804130c0,
		"MoveBG::PalmOugiTree_map_collision_data": 0x804130c8,
		"PalmOugiTree_map_collision_data": 0x804130c8,
		"MoveBG::PalmOugiTree_map_collision_info": 0x804130d0,
		"PalmOugiTree_map_collision_info": 0x804130d0,
		"MoveBG::PalmSagoTree_map_collision_data": 0x804130d8,
		"PalmSagoTree_map_collision_data": 0x804130d8,
		"MoveBG::PalmSagoTree_map_collision_info": 0x804130e0,
		"PalmSagoTree_map_collision_info": 0x804130e0,
		"MoveBG::PalmNatumeTree_map_collision_data": 0x804130e8,
		"PalmNatumeTree_map_collision_data": 0x804130e8,
		"MoveBG::PalmNatumeTree_map_collision_info": 0x804130f0,
		"PalmNatumeTree_map_collision_info": 0x804130f0,
		"MoveBG::PalmLeaf_anim_info": 0x804130f8,
		"PalmLeaf_anim_info": 0x804130f8,
		"MoveBG::PalmLeafTree_map_collision_data": 0x80413100,
		"PalmLeafTree_map_collision_data": 0x80413100,
		"MoveBG::PalmLeafTree_map_collision_info": 0x80413108,
		"PalmLeafTree_map_collision_info": 0x80413108,
		"MoveBG::BananaTree_anim_info": 0x80413110,
		"BananaTree_anim_info": 0x80413110,
		"MoveBG::BananaTree_map_collision_data": 0x80413118,
		"BananaTree_map_collision_data": 0x80413118,
		"MoveBG::BananaTree_map_collision_info": 0x80413120,
		"BananaTree_map_collision_info": 0x80413120,
		"MoveBG::FruitTree_map_collision_data": 0x80413128,
		"FruitTree_map_collision_data": 0x80413128,
		"MoveBG::FruitTree_map_collision_info": 0x80413130,
		"FruitTree_map_collision_info": 0x80413130,
		"MoveBG::flowerOrange_anim_info": 0x80413140,
		"flowerOrange_anim_info": 0x80413140,
		"MoveBG::flowerPink_anim_info": 0x80413148,
		"flowerPink_anim_info": 0x80413148,
		"MoveBG::flowerPurple_anim_info": 0x80413150,
		"flowerPurple_anim_info": 0x80413150,
		"MoveBG::flowerRed_anim_info": 0x80413158,
		"flowerRed_anim_info": 0x80413158,
		"MoveBG::flowerYellow_anim_info": 0x80413160,
		"flowerYellow_anim_info": 0x80413160,
		"MoveBG::flowerSunflower_anim_info": 0x80413168,
		"flowerSunflower_anim_info": 0x80413168,
		"MoveBG::pole_sound_info": 0x80413170,
		"pole_sound_info": 0x80413170,
		"MoveBG::dptlight_anim_info": 0x80413178,
		"dptlight_anim_info": 0x80413178,
		"MoveBG::streetlamp_map_collision_info": 0x80413180,
		"streetlamp_map_collision_info": 0x80413180,
		"MoveBG::football_anim_info": 0x80413188,
		"football_anim_info": 0x80413188,
		"MoveBG::football_sound_info": 0x80413190,
		"football_sound_info": 0x80413190,
		"MoveBG::football_goal_anim_info": 0x80413198,
		"football_goal_anim_info": 0x80413198,
		"MoveBG::football_goal_map_collision_info": 0x804131a0,
		"football_goal_map_collision_info": 0x804131a0,
		"MoveBG::Watermelon_anim_info": 0x804131a8,
		"Watermelon_anim_info": 0x804131a8,
		"MoveBG::watermelon_sound_info": 0x804131b0,
		"watermelon_sound_info": 0x804131b0,
		"MoveBG::WatermelonStatic_anim_info": 0x804131b8,
		"WatermelonStatic_anim_info": 0x804131b8,
		"MoveBG::cloud_anim_info": 0x804131c0,
		"cloud_anim_info": 0x804131c0,
		"MoveBG::cloud_map_collision_data": 0x804131d0,
		"cloud_map_collision_data": 0x804131d0,
		"MoveBG::cloud_map_collision_info": 0x804131d8,
		"cloud_map_collision_info": 0x804131d8,
		"MoveBG::normallift_anim_info": 0x804131e0,
		"normallift_anim_info": 0x804131e0,
		"MoveBG::normallift_map_collision_data": 0x804131e8,
		"normallift_map_collision_data": 0x804131e8,
		"MoveBG::normallift_map_collision_info": 0x804131f0,
		"normallift_map_collision_info": 0x804131f0,
		"MoveBG::exrollcube_anim_info": 0x804131f8,
		"exrollcube_anim_info": 0x804131f8,
		"MoveBG::exrollcube_map_collision_data": 0x80413200,
		"exrollcube_map_collision_data": 0x80413200,
		"MoveBG::exrollcube_map_collision_info": 0x80413208,
		"exrollcube_map_collision_info": 0x80413208,
		"MoveBG::exkickboard_anim_info": 0x80413210,
		"exkickboard_anim_info": 0x80413210,
		"MoveBG::exkickboard_map_collision_data": 0x80413218,
		"exkickboard_map_collision_data": 0x80413218,
		"MoveBG::exkickboard_map_collision_info": 0x80413220,
		"exkickboard_map_collision_info": 0x80413220,
		"MoveBG::railblockr_anim_info": 0x80413228,
		"railblockr_anim_info": 0x80413228,
		"MoveBG::railblocky_anim_info": 0x80413230,
		"railblocky_anim_info": 0x80413230,
		"MoveBG::railblockb_anim_info": 0x80413238,
		"railblockb_anim_info": 0x80413238,
		"MoveBG::railblock_map_collision_data": 0x80413240,
		"railblock_map_collision_data": 0x80413240,
		"MoveBG::railblock_map_collision_info": 0x80413248,
		"railblock_map_collision_info": 0x80413248,
		"MoveBG::umaibou_anim_info": 0x80413250,
		"umaibou_anim_info": 0x80413250,
		"MoveBG::umaibou_map_collision_data": 0x80413260,
		"umaibou_map_collision_data": 0x80413260,
		"MoveBG::umaibou_map_collision_info": 0x80413268,
		"umaibou_map_collision_info": 0x80413268,
		"MoveBG::kamaboko_anim_info": 0x80413270,
		"kamaboko_anim_info": 0x80413270,
		"MoveBG::kamaboko_map_collision_data": 0x80413278,
		"kamaboko_map_collision_data": 0x80413278,
		"MoveBG::kamaboko_map_collision_info": 0x80413280,
		"kamaboko_map_collision_info": 0x80413280,
		"MoveBG::getag_anim_info": 0x80413288,
		"getag_anim_info": 0x80413288,
		"MoveBG::getao_anim_info": 0x80413290,
		"getao_anim_info": 0x80413290,
		"MoveBG::geta_map_collision_data": 0x804132a0,
		"geta_map_collision_data": 0x804132a0,
		"MoveBG::geta_map_collision_info": 0x804132a8,
		"geta_map_collision_info": 0x804132a8,
		"MoveBG::uirou_anim_info": 0x804132c0,
		"uirou_anim_info": 0x804132c0,
		"MoveBG::uirou_map_collision_data": 0x804132d0,
		"uirou_map_collision_data": 0x804132d0,
		"MoveBG::uirou_map_collision_info": 0x804132d8,
		"uirou_map_collision_info": 0x804132d8,
		"MoveBG::hikidashi_anim_info": 0x804132e0,
		"hikidashi_anim_info": 0x804132e0,
		"MoveBG::hikidashi_map_collision_data": 0x804132e8,
		"hikidashi_map_collision_data": 0x804132e8,
		"MoveBG::hikidashi_map_collision_info": 0x804132f0,
		"hikidashi_map_collision_info": 0x804132f0,
		"MoveBG::castella_anim_info": 0x804132f8,
		"castella_anim_info": 0x804132f8,
		"MoveBG::castella_map_collision_data": 0x80413300,
		"castella_map_collision_data": 0x80413300,
		"MoveBG::castella_map_collision_info": 0x80413308,
		"castella_map_collision_info": 0x80413308,
		"MoveBG::yoshiblock_anim_info": 0x80413310,
		"yoshiblock_anim_info": 0x80413310,
		"MoveBG::yoshiblock_map_collision_data": 0x80413318,
		"yoshiblock_map_collision_data": 0x80413318,
		"MoveBG::yoshiblock_map_collision_info": 0x80413320,
		"yoshiblock_map_collision_info": 0x80413320,
		"MoveBG::WoodBlockTriangle_map_collision_data": 0x80413328,
		"WoodBlockTriangle_map_collision_data": 0x80413328,
		"MoveBG::WoodBlockTriangle_map_collision_info": 0x80413330,
		"WoodBlockTriangle_map_collision_info": 0x80413330,
		"MoveBG::WoodBlockPyramid_map_collision_data": 0x80413338,
		"WoodBlockPyramid_map_collision_data": 0x80413338,
		"MoveBG::WoodBlockPyramid_map_collision_info": 0x80413340,
		"WoodBlockPyramid_map_collision_info": 0x80413340,
		"MoveBG::WoodBlockLong_map_collision_data": 0x80413348,
		"WoodBlockLong_map_collision_data": 0x80413348,
		"MoveBG::WoodBlockLong_map_collision_info": 0x80413350,
		"WoodBlockLong_map_collision_info": 0x80413350,
		"MoveBG::WoodBlockLarge_map_collision_data": 0x80413358,
		"WoodBlockLarge_map_collision_data": 0x80413358,
		"MoveBG::WoodBlockLarge_map_collision_info": 0x80413360,
		"WoodBlockLarge_map_collision_info": 0x80413360,
		"MoveBG::WoodBlockCone_map_collision_data": 0x80413368,
		"WoodBlockCone_map_collision_data": 0x80413368,
		"MoveBG::WoodBlockCone_map_collision_info": 0x80413370,
		"WoodBlockCone_map_collision_info": 0x80413370,
		"MoveBG::WoodBlockL_map_collision_data": 0x80413378,
		"WoodBlockL_map_collision_data": 0x80413378,
		"MoveBG::WoodBlockL_map_collision_info": 0x80413380,
		"WoodBlockL_map_collision_info": 0x80413380,
		"MoveBG::WoodBlockBridge_map_collision_data": 0x80413388,
		"WoodBlockBridge_map_collision_data": 0x80413388,
		"MoveBG::WoodBlockBridge_map_collision_info": 0x80413390,
		"WoodBlockBridge_map_collision_info": 0x80413390,
		"MoveBG::WoodBlockCube_map_collision_data": 0x80413398,
		"WoodBlockCube_map_collision_data": 0x80413398,
		"MoveBG::WoodBlockCube_map_collision_info": 0x804133a0,
		"WoodBlockCube_map_collision_info": 0x804133a0,
		"MoveBG::normalvariant0_map_collision_data": 0x804133a8,
		"normalvariant0_map_collision_data": 0x804133a8,
		"MoveBG::normalvariant0_map_collision_info": 0x804133b0,
		"normalvariant0_map_collision_info": 0x804133b0,
		"MoveBG::normalvariant1_map_collision_data": 0x804133b8,
		"normalvariant1_map_collision_data": 0x804133b8,
		"MoveBG::normalvariant1_map_collision_info": 0x804133c0,
		"normalvariant1_map_collision_info": 0x804133c0,
		"MoveBG::normalvariant2_map_collision_data": 0x804133c8,
		"normalvariant2_map_collision_data": 0x804133c8,
		"MoveBG::normalvariant2_map_collision_info": 0x804133d0,
		"normalvariant2_map_collision_info": 0x804133d0,
		"MoveBG::normalvariant3_map_collision_data": 0x804133d8,
		"normalvariant3_map_collision_data": 0x804133d8,
		"MoveBG::normalvariant3_map_collision_info": 0x804133e0,
		"normalvariant3_map_collision_info": 0x804133e0,
		"MoveBG::normalvariant4_map_collision_data": 0x804133e8,
		"normalvariant4_map_collision_data": 0x804133e8,
		"MoveBG::normalvariant4_map_collision_info": 0x804133f0,
		"normalvariant4_map_collision_info": 0x804133f0,
		"MoveBG::railvariant0_map_collision_data": 0x804133f8,
		"railvariant0_map_collision_data": 0x804133f8,
		"MoveBG::railvariant0_map_collision_info": 0x80413400,
		"railvariant0_map_collision_info": 0x80413400,
		"MoveBG::railvariant1_map_collision_data": 0x80413408,
		"railvariant1_map_collision_data": 0x80413408,
		"MoveBG::railvariant1_map_collision_info": 0x80413410,
		"railvariant1_map_collision_info": 0x80413410,
		"MoveBG::railvariant2_map_collision_data": 0x80413418,
		"railvariant2_map_collision_data": 0x80413418,
		"MoveBG::railvariant2_map_collision_info": 0x80413420,
		"railvariant2_map_collision_info": 0x80413420,
		"MoveBG::railvariant3_map_collision_data": 0x80413428,
		"railvariant3_map_collision_data": 0x80413428,
		"MoveBG::railvariant3_map_collision_info": 0x80413430,
		"railvariant3_map_collision_info": 0x80413430,
		"MoveBG::railvariant4_map_collision_data": 0x80413438,
		"railvariant4_map_collision_data": 0x80413438,
		"MoveBG::railvariant4_map_collision_info": 0x80413440,
		"railvariant4_map_collision_info": 0x80413440,
		"MoveBG::rollvariant0_map_collision_data": 0x80413448,
		"rollvariant0_map_collision_data": 0x80413448,
		"MoveBG::rollvariant0_map_collision_info": 0x80413450,
		"rollvariant0_map_collision_info": 0x80413450,
		"MoveBG::rollvariant1_map_collision_data": 0x80413458,
		"rollvariant1_map_collision_data": 0x80413458,
		"MoveBG::rollvariant1_map_collision_info": 0x80413460,
		"rollvariant1_map_collision_info": 0x80413460,
		"MoveBG::rollvariant2_map_collision_data": 0x80413468,
		"rollvariant2_map_collision_data": 0x80413468,
		"MoveBG::rollvariant2_map_collision_info": 0x80413470,
		"rollvariant2_map_collision_info": 0x80413470,
		"MoveBG::rollvariant3_map_collision_data": 0x80413478,
		"rollvariant3_map_collision_data": 0x80413478,
		"MoveBG::rollvariant3_map_collision_info": 0x80413480,
		"rollvariant3_map_collision_info": 0x80413480,
		"MoveBG::rollvariant4_map_collision_data": 0x80413488,
		"rollvariant4_map_collision_data": 0x80413488,
		"MoveBG::rollvariant4_map_collision_info": 0x80413490,
		"rollvariant4_map_collision_info": 0x80413490,
		"MoveBG::lamptrapspike_anim_info": 0x80413498,
		"lamptrapspike_anim_info": 0x80413498,
		"MoveBG::lamptrapiron_anim_info": 0x804134a0,
		"lamptrapiron_anim_info": 0x804134a0,
		"MoveBG::lamptrap_map_collision_data": 0x804134a8,
		"lamptrap_map_collision_data": 0x804134a8,
		"MoveBG::lamptrap_map_collision_info": 0x804134b0,
		"lamptrap_map_collision_info": 0x804134b0,
		"MoveBG::airplane_map_collision_data": 0x804134b8,
		"airplane_map_collision_data": 0x804134b8,
		"MoveBG::airplane_map_collision_info": 0x804134c0,
		"airplane_map_collision_info": 0x804134c0,
		"MoveBG::WoodBox_anim_info": 0x804134c8,
		"WoodBox_anim_info": 0x804134c8,
		"MoveBG::WoodBoxNozzle_map_collision_data": 0x804134d8,
		"WoodBoxNozzle_map_collision_data": 0x804134d8,
		"MoveBG::WoodBoxNozzle_map_collision_info": 0x804134e0,
		"WoodBoxNozzle_map_collision_info": 0x804134e0,
		"MoveBG::ice_car_anim_info": 0x804134f0,
		"ice_car_anim_info": 0x804134f0,
		"MoveBG::ice_car_map_collision_data": 0x80413500,
		"ice_car_map_collision_data": 0x80413500,
		"MoveBG::ice_car_map_collision_info": 0x80413508,
		"ice_car_map_collision_info": 0x80413508,
		"MoveBG::move_ice_car_map_collision_data": 0x80413518,
		"move_ice_car_map_collision_data": 0x80413518,
		"MoveBG::move_ice_car_map_collision_info": 0x80413520,
		"move_ice_car_map_collision_info": 0x80413520,
		"MoveBG::@3098": 0x80413528,
		"MoveBG::AirportBuoy_map_collision_data": 0x80413530,
		"AirportBuoy_map_collision_data": 0x80413530,
		"MoveBG::AirportBuoy_map_collision_info": 0x80413538,
		"AirportBuoy_map_collision_info": 0x80413538,
		"MoveBG::dptKing_map_collision_info": 0x80413548,
		"dptKing_map_collision_info": 0x80413548,
		"MoveBG::KoopaJrSubmarine_map_collision_data": 0x80413550,
		"KoopaJrSubmarine_map_collision_data": 0x80413550,
		"MoveBG::KoopaJrSubmarine_map_collision_info": 0x80413558,
		"KoopaJrSubmarine_map_collision_info": 0x80413558,
		"MoveBG::monumentshine_anim_info": 0x80413560,
		"monumentshine_anim_info": 0x80413560,
		"MoveBG::belldolpic_anim_info": 0x80413568,
		"belldolpic_anim_info": 0x80413568,
		"MoveBG::DptWeathercock_anim_info": 0x80413570,
		"DptWeathercock_anim_info": 0x80413570,
		"MoveBG::DptMonteFence_map_collision_data": 0x80413578,
		"DptMonteFence_map_collision_data": 0x80413578,
		"MoveBG::DptMonteFence_map_collision_info": 0x80413580,
		"DptMonteFence_map_collision_info": 0x80413580,
		"MoveBG::DptCoronaFence_map_collision_data": 0x80413588,
		"DptCoronaFence_map_collision_data": 0x80413588,
		"MoveBG::DptCoronaFence_map_collision_info": 0x80413590,
		"DptCoronaFence_map_collision_info": 0x80413590,
		"MoveBG::MareGate_anim_info": 0x80413598,
		"MareGate_anim_info": 0x80413598,
		"MoveBG::NozzleDoor_anim_info": 0x804135a0,
		"NozzleDoor_anim_info": 0x804135a0,
		"MoveBG::NozzleDoor_map_collision_data": 0x804135a8,
		"NozzleDoor_map_collision_data": 0x804135a8,
		"MoveBG::NozzleDoor_map_collision_info": 0x804135b0,
		"NozzleDoor_map_collision_info": 0x804135b0,
		"MoveBG::DokanGate_anim_info": 0x804135b8,
		"DokanGate_anim_info": 0x804135b8,
		"MoveBG::@3121": 0x804135c0,
		"MoveBG::crane_map_collision_data": 0x804135c8,
		"crane_map_collision_data": 0x804135c8,
		"MoveBG::crane_map_collision_info": 0x804135d0,
		"crane_map_collision_info": 0x804135d0,
		"MoveBG::crane90Scene2_map_collision_data": 0x804135d8,
		"crane90Scene2_map_collision_data": 0x804135d8,
		"MoveBG::crane90Scene2_map_collision_info": 0x804135e0,
		"crane90Scene2_map_collision_info": 0x804135e0,
		"MoveBG::crane180Scene1_map_collision_data": 0x804135e8,
		"crane180Scene1_map_collision_data": 0x804135e8,
		"MoveBG::crane180Scene1_map_collision_info": 0x804135f0,
		"crane180Scene1_map_collision_info": 0x804135f0,
		"MoveBG::crane_updown_map_collision_data": 0x804135f8,
		"crane_updown_map_collision_data": 0x804135f8,
		"MoveBG::crane_updown_map_collision_info": 0x80413600,
		"crane_updown_map_collision_info": 0x80413600,
		"MoveBG::crane_cargo_map_collision_data": 0x80413608,
		"crane_cargo_map_collision_data": 0x80413608,
		"MoveBG::crane_cargo_map_collision_info": 0x80413610,
		"crane_cargo_map_collision_info": 0x80413610,
		"MoveBG::tank_map_collision_data": 0x80413620,
		"tank_map_collision_data": 0x80413620,
		"MoveBG::tank_map_collision_info": 0x80413628,
		"tank_map_collision_info": 0x80413628,
		"MoveBG::container_map_collision_data": 0x80413630,
		"container_map_collision_data": 0x80413630,
		"MoveBG::container_map_collision_info": 0x80413638,
		"container_map_collision_info": 0x80413638,
		"MoveBG::submarine_map_collision_info": 0x80413640,
		"submarine_map_collision_info": 0x80413640,
		"MoveBG::riccoShip_map_collision_data": 0x80413648,
		"riccoShip_map_collision_data": 0x80413648,
		"MoveBG::riccoShip_map_collision_info": 0x80413650,
		"riccoShip_map_collision_info": 0x80413650,
		"MoveBG::riccoLog_map_collision_data": 0x80413658,
		"riccoLog_map_collision_data": 0x80413658,
		"MoveBG::riccoLog_map_collision_info": 0x80413660,
		"riccoLog_map_collision_info": 0x80413660,
		"MoveBG::gesoSurfboard_anim_info": 0x80413668,
		"gesoSurfboard_anim_info": 0x80413668,
		"MoveBG::riccoShipLog_map_collision_data": 0x80413670,
		"riccoShipLog_map_collision_data": 0x80413670,
		"MoveBG::riccoShipLog_map_collision_info": 0x80413678,
		"riccoShipLog_map_collision_info": 0x80413678,
		"MoveBG::riccoShipDol_map_collision_data": 0x80413680,
		"riccoShipDol_map_collision_data": 0x80413680,
		"MoveBG::riccoShipDol_map_collision_info": 0x80413688,
		"riccoShipDol_map_collision_info": 0x80413688,
		"MoveBG::riccoYachtL_map_collision_data": 0x80413690,
		"riccoYachtL_map_collision_data": 0x80413690,
		"MoveBG::riccoYachtL_map_collision_info": 0x80413698,
		"riccoYachtL_map_collision_info": 0x80413698,
		"MoveBG::riccoYachtS_map_collision_data": 0x804136a0,
		"riccoYachtS_map_collision_data": 0x804136a0,
		"MoveBG::riccoYachtS_map_collision_info": 0x804136a8,
		"riccoYachtS_map_collision_info": 0x804136a8,
		"MoveBG::riccoBoatL_map_collision_data": 0x804136b0,
		"riccoBoatL_map_collision_data": 0x804136b0,
		"MoveBG::riccoBoatL_map_collision_info": 0x804136b8,
		"riccoBoatL_map_collision_info": 0x804136b8,
		"MoveBG::riccoBoatS_map_collision_data": 0x804136c0,
		"riccoBoatS_map_collision_data": 0x804136c0,
		"MoveBG::riccoBoatS_map_collision_info": 0x804136c8,
		"riccoBoatS_map_collision_info": 0x804136c8,
		"MoveBG::riccoBasket_map_collision_data": 0x804136d0,
		"riccoBasket_map_collision_data": 0x804136d0,
		"MoveBG::riccoBasket_map_collision_info": 0x804136d8,
		"riccoBasket_map_collision_info": 0x804136d8,
		"MoveBG::riccoGangway_map_collision_data": 0x804136e0,
		"riccoGangway_map_collision_data": 0x804136e0,
		"MoveBG::riccoGangway_map_collision_info": 0x804136e8,
		"riccoGangway_map_collision_info": 0x804136e8,
		"MoveBG::riccoShipFish_map_collision_data": 0x804136f0,
		"riccoShipFish_map_collision_data": 0x804136f0,
		"MoveBG::riccoShipFish_map_collision_info": 0x804136f8,
		"riccoShipFish_map_collision_info": 0x804136f8,
		"MoveBG::riccoShipGeso_map_collision_data": 0x80413700,
		"riccoShipGeso_map_collision_data": 0x80413700,
		"MoveBG::riccoShipGeso_map_collision_info": 0x80413708,
		"riccoShipGeso_map_collision_info": 0x80413708,
		"MoveBG::riccoSwitch_map_collision_data": 0x80413710,
		"riccoSwitch_map_collision_data": 0x80413710,
		"MoveBG::riccoSwitch_map_collision_info": 0x80413718,
		"riccoSwitch_map_collision_info": 0x80413718,
		"MoveBG::riccoFenceMaze_map_collision_data": 0x80413720,
		"riccoFenceMaze_map_collision_data": 0x80413720,
		"MoveBG::riccoFenceMaze_map_collision_info": 0x80413728,
		"riccoFenceMaze_map_collision_info": 0x80413728,
		"MoveBG::riccoStand_map_collision_data": 0x80413730,
		"riccoStand_map_collision_data": 0x80413730,
		"MoveBG::riccoStand_map_collision_info": 0x80413738,
		"riccoStand_map_collision_info": 0x80413738,
		"MoveBG::riccoGrille_map_collision_data": 0x80413740,
		"riccoGrille_map_collision_data": 0x80413740,
		"MoveBG::riccoGrille_map_collision_info": 0x80413748,
		"riccoGrille_map_collision_info": 0x80413748,
		"MoveBG::riccoArrow_map_collision_data": 0x80413750,
		"riccoArrow_map_collision_data": 0x80413750,
		"MoveBG::riccoArrow_map_collision_info": 0x80413758,
		"riccoArrow_map_collision_info": 0x80413758,
		"MoveBG::riccoStreetStall_map_collision_data": 0x80413760,
		"riccoStreetStall_map_collision_data": 0x80413760,
		"MoveBG::riccoStreetStall_map_collision_info": 0x80413768,
		"riccoStreetStall_map_collision_info": 0x80413768,
		"MoveBG::riccoHericopter_map_collision_data": 0x80413770,
		"riccoHericopter_map_collision_data": 0x80413770,
		"MoveBG::riccoHericopter_map_collision_info": 0x80413778,
		"riccoHericopter_map_collision_info": 0x80413778,
		"MoveBG::windmill_anim_info": 0x80413780,
		"windmill_anim_info": 0x80413780,
		"MoveBG::windmill_map_collision_data": 0x80413788,
		"windmill_map_collision_data": 0x80413788,
		"MoveBG::windmill_map_collision_info": 0x80413790,
		"windmill_map_collision_info": 0x80413790,
		"MoveBG::MiniWindmillL_map_collision_data": 0x80413798,
		"MiniWindmillL_map_collision_data": 0x80413798,
		"MoveBG::MiniWindmillL_map_collision_info": 0x804137a0,
		"MiniWindmillL_map_collision_info": 0x804137a0,
		"MoveBG::MiniWindmillS_map_collision_data": 0x804137a8,
		"MiniWindmillS_map_collision_data": 0x804137a8,
		"MoveBG::MiniWindmillS_map_collision_info": 0x804137b0,
		"MiniWindmillS_map_collision_info": 0x804137b0,
		"MoveBG::windmill_roof_map_collision_data": 0x804137b8,
		"windmill_roof_map_collision_data": 0x804137b8,
		"MoveBG::windmill_roof_map_collision_info": 0x804137c0,
		"windmill_roof_map_collision_info": 0x804137c0,
		"MoveBG::lamp_bianco_anim_info": 0x804137c8,
		"lamp_bianco_anim_info": 0x804137c8,
		"MoveBG::lamp_bianco_map_collision_info": 0x804137d0,
		"lamp_bianco_map_collision_info": 0x804137d0,
		"MoveBG::RootPakkun_map_collision_data": 0x804137d8,
		"RootPakkun_map_collision_data": 0x804137d8,
		"MoveBG::RootPakkun_map_collision_info": 0x804137e0,
		"RootPakkun_map_collision_info": 0x804137e0,
		"MoveBG::windmill_block_map_collision_data": 0x804137e8,
		"windmill_block_map_collision_data": 0x804137e8,
		"MoveBG::windmill_block_map_collision_info": 0x804137f0,
		"windmill_block_map_collision_info": 0x804137f0,
		"MoveBG::BiaBell_anim_info": 0x804137f8,
		"BiaBell_anim_info": 0x804137f8,
		"MoveBG::watermill00_anim_info": 0x80413808,
		"watermill00_anim_info": 0x80413808,
		"MoveBG::BiaWatermill01_map_collision_data": 0x80413810,
		"BiaWatermill01_map_collision_data": 0x80413810,
		"MoveBG::BiaWatermill01_map_collision_info": 0x80413818,
		"BiaWatermill01_map_collision_info": 0x80413818,
		"MoveBG::BiaWatermillVertical_map_collision_data": 0x80413820,
		"BiaWatermillVertical_map_collision_data": 0x80413820,
		"MoveBG::BiaWatermillVertical_map_collision_info": 0x80413828,
		"BiaWatermillVertical_map_collision_info": 0x80413828,
		"MoveBG::BiaTurnBridge_map_collision_data": 0x80413830,
		"BiaTurnBridge_map_collision_data": 0x80413830,
		"MoveBG::BiaTurnBridge_map_collision_info": 0x80413838,
		"BiaTurnBridge_map_collision_info": 0x80413838,
		"MoveBG::LeafBoat_map_collision_data": 0x80413840,
		"LeafBoat_map_collision_data": 0x80413840,
		"MoveBG::LeafBoat_map_collision_info": 0x80413848,
		"LeafBoat_map_collision_info": 0x80413848,
		"MoveBG::LampSeesaw_anim_info": 0x80413850,
		"LampSeesaw_anim_info": 0x80413850,
		"MoveBG::LampSeesaw_map_collision_data": 0x80413858,
		"LampSeesaw_map_collision_data": 0x80413858,
		"MoveBG::LampSeesaw_map_collision_info": 0x80413860,
		"LampSeesaw_map_collision_info": 0x80413860,
		"MoveBG::BiancoDoor_map_collision_data": 0x80413870,
		"BiancoDoor_map_collision_data": 0x80413870,
		"MoveBG::BiancoDoor_map_collision_info": 0x80413878,
		"BiancoDoor_map_collision_info": 0x80413878,
		"MoveBG::BiaBridge_map_collision_data": 0x80413880,
		"BiaBridge_map_collision_data": 0x80413880,
		"MoveBG::BiaBridge_map_collision_info": 0x80413888,
		"BiaBridge_map_collision_info": 0x80413888,
		"MoveBG::SandBird_anim_info": 0x80413890,
		"SandBird_anim_info": 0x80413890,
		"MoveBG::SandBirdBlock_map_collision_info": 0x80413898,
		"SandBirdBlock_map_collision_info": 0x80413898,
		"MoveBG::SkyIsland_anim_info": 0x804138a0,
		"SkyIsland_anim_info": 0x804138a0,
		"MoveBG::SkyIsland_map_collision_data": 0x804138a8,
		"SkyIsland_map_collision_data": 0x804138a8,
		"MoveBG::SkyIsland_map_collision_info": 0x804138b0,
		"SkyIsland_map_collision_info": 0x804138b0,
		"MoveBG::SandLeaf_anim_info": 0x804138b8,
		"SandLeaf_anim_info": 0x804138b8,
		"MoveBG::SandLeafBase00_anim_info": 0x804138c0,
		"SandLeafBase00_anim_info": 0x804138c0,
		"MoveBG::SandLeafBase00_map_collision_info": 0x804138c8,
		"SandLeafBase00_map_collision_info": 0x804138c8,
		"MoveBG::SandLeafBase01_anim_info": 0x804138d0,
		"SandLeafBase01_anim_info": 0x804138d0,
		"MoveBG::SandLeafBase01_map_collision_info": 0x804138d8,
		"SandLeafBase01_map_collision_info": 0x804138d8,
		"MoveBG::SandLeafBase02_anim_info": 0x804138e0,
		"SandLeafBase02_anim_info": 0x804138e0,
		"MoveBG::SandLeafBase02_map_collision_info": 0x804138e8,
		"SandLeafBase02_map_collision_info": 0x804138e8,
		"MoveBG::SandLeafBase03_anim_info": 0x804138f0,
		"SandLeafBase03_anim_info": 0x804138f0,
		"MoveBG::SandLeafBase03_map_collision_info": 0x804138f8,
		"SandLeafBase03_map_collision_info": 0x804138f8,
		"MoveBG::SandBomb_anim_info": 0x80413900,
		"SandBomb_anim_info": 0x80413900,
		"MoveBG::mirror_L_map_collision_info": 0x80413910,
		"mirror_L_map_collision_info": 0x80413910,
		"MoveBG::mirror_M_map_collision_info": 0x80413920,
		"mirror_M_map_collision_info": 0x80413920,
		"MoveBG::mirrorS_map_collision_info": 0x80413930,
		"mirrorS_map_collision_info": 0x80413930,
		"MoveBG::SandCastle_anim_info": 0x80413938,
		"SandCastle_anim_info": 0x80413938,
		"MoveBG::SandCastle_map_collision_info": 0x80413940,
		"SandCastle_map_collision_info": 0x80413940,
		"MoveBG::MammaBlockRotate_map_collision_info": 0x80413948,
		"MammaBlockRotate_map_collision_info": 0x80413948,
		"MoveBG::SandEgg_map_collision_data": 0x80413950,
		"SandEgg_map_collision_data": 0x80413950,
		"MoveBG::SandEgg_map_collision_info": 0x80413958,
		"SandEgg_map_collision_info": 0x80413958,
		"MoveBG::SandEggBroken_map_collision_data": 0x80413960,
		"SandEggBroken_map_collision_data": 0x80413960,
		"MoveBG::SandEggBroken_map_collision_info": 0x80413968,
		"SandEggBroken_map_collision_info": 0x80413968,
		"MoveBG::MammaSurfboardStand_map_collision_data": 0x80413970,
		"MammaSurfboardStand_map_collision_data": 0x80413970,
		"MoveBG::MammaSurfboardStand_map_collision_info": 0x80413978,
		"MammaSurfboardStand_map_collision_info": 0x80413978,
		"MoveBG::MammaYacht00_map_collision_data": 0x80413980,
		"MammaYacht00_map_collision_data": 0x80413980,
		"MoveBG::MammaYacht00_map_collision_info": 0x80413988,
		"MammaYacht00_map_collision_info": 0x80413988,
		"MoveBG::MammaYacht01_map_collision_data": 0x80413990,
		"MammaYacht01_map_collision_data": 0x80413990,
		"MoveBG::MammaYacht01_map_collision_info": 0x80413998,
		"MammaYacht01_map_collision_info": 0x80413998,
		"MoveBG::MammaYacht02_map_collision_data": 0x804139a0,
		"MammaYacht02_map_collision_data": 0x804139a0,
		"MoveBG::MammaYacht02_map_collision_info": 0x804139a8,
		"MammaYacht02_map_collision_info": 0x804139a8,
		"MoveBG::SandBombBase00_anim_info": 0x804139b0,
		"SandBombBase00_anim_info": 0x804139b0,
		"MoveBG::SandBombBase00_map_collision_info": 0x804139b8,
		"SandBombBase00_map_collision_info": 0x804139b8,
		"MoveBG::SandBombBaseMushroom_anim_info": 0x804139c0,
		"SandBombBaseMushroom_anim_info": 0x804139c0,
		"MoveBG::SandBombBaseMushroom_map_collision_info": 0x804139c8,
		"SandBombBaseMushroom_map_collision_info": 0x804139c8,
		"MoveBG::SandBombBasePyramid_anim_info": 0x804139d0,
		"SandBombBasePyramid_anim_info": 0x804139d0,
		"MoveBG::SandBombBasePyramid_map_collision_info": 0x804139d8,
		"SandBombBasePyramid_map_collision_info": 0x804139d8,
		"MoveBG::SandBombBaseShit_anim_info": 0x804139e0,
		"SandBombBaseShit_anim_info": 0x804139e0,
		"MoveBG::SandBombBaseShit_map_collision_info": 0x804139e8,
		"SandBombBaseShit_map_collision_info": 0x804139e8,
		"MoveBG::SandBombBaseStar_anim_info": 0x804139f0,
		"SandBombBaseStar_anim_info": 0x804139f0,
		"MoveBG::SandBombBaseStar_map_collision_info": 0x804139f8,
		"SandBombBaseStar_map_collision_info": 0x804139f8,
		"MoveBG::SandBombBaseTurtle_anim_info": 0x80413a00,
		"SandBombBaseTurtle_anim_info": 0x80413a00,
		"MoveBG::SandBombBaseTurtle_map_collision_info": 0x80413a08,
		"SandBombBaseTurtle_map_collision_info": 0x80413a08,
		"MoveBG::SandBombBaseFoot_anim_info": 0x80413a10,
		"SandBombBaseFoot_anim_info": 0x80413a10,
		"MoveBG::SandBombBaseFoot_map_collision_info": 0x80413a18,
		"SandBombBaseFoot_map_collision_info": 0x80413a18,
		"MoveBG::SandBombBaseHand_anim_info": 0x80413a20,
		"SandBombBaseHand_anim_info": 0x80413a20,
		"MoveBG::SandBombBaseHand_map_collision_info": 0x80413a28,
		"SandBombBaseHand_map_collision_info": 0x80413a28,
		"MoveBG::SandBombBaseStairs_anim_info": 0x80413a30,
		"SandBombBaseStairs_anim_info": 0x80413a30,
		"MoveBG::SandBombBaseStairs_map_collision_info": 0x80413a38,
		"SandBombBaseStairs_map_collision_info": 0x80413a38,
		"MoveBG::TeethOfJuicer_anim_info": 0x80413a50,
		"TeethOfJuicer_anim_info": 0x80413a50,
		"MoveBG::SandEggRepair_map_collision_data": 0x80413a58,
		"SandEggRepair_map_collision_data": 0x80413a58,
		"MoveBG::SandEggRepair_map_collision_info": 0x80413a60,
		"SandEggRepair_map_collision_info": 0x80413a60,
		"MoveBG::merrygoround_anim_info": 0x80413a70,
		"merrygoround_anim_info": 0x80413a70,
		"MoveBG::merrygoround_map_collision_data": 0x80413a78,
		"merrygoround_map_collision_data": 0x80413a78,
		"MoveBG::merrygoround_map_collision_info": 0x80413a80,
		"merrygoround_map_collision_info": 0x80413a80,
		"MoveBG::merry_egg_map_collision_data": 0x80413a88,
		"merry_egg_map_collision_data": 0x80413a88,
		"MoveBG::merry_egg_map_collision_info": 0x80413a90,
		"merry_egg_map_collision_info": 0x80413a90,
		"MoveBG::FerrisWheel_anim_info": 0x80413a98,
		"FerrisWheel_anim_info": 0x80413a98,
		"MoveBG::gondola_map_collision_data": 0x80413aa0,
		"gondola_map_collision_data": 0x80413aa0,
		"MoveBG::gondola_map_collision_info": 0x80413aa8,
		"gondola_map_collision_info": 0x80413aa8,
		"MoveBG::FerrisLOD_anim_info": 0x80413ab0,
		"FerrisLOD_anim_info": 0x80413ab0,
		"MoveBG::viking_map_collision_data": 0x80413ac0,
		"viking_map_collision_data": 0x80413ac0,
		"MoveBG::viking_map_collision_info": 0x80413ac8,
		"viking_map_collision_info": 0x80413ac8,
		"MoveBG::PinnaEntrance_map_collision_data": 0x80413ad0,
		"PinnaEntrance_map_collision_data": 0x80413ad0,
		"MoveBG::PinnaEntrance_map_collision_info": 0x80413ad8,
		"PinnaEntrance_map_collision_info": 0x80413ad8,
		"MoveBG::PinnaEntranceOpen_map_collision_data": 0x80413ae0,
		"PinnaEntranceOpen_map_collision_data": 0x80413ae0,
		"MoveBG::PinnaEntranceOpen_map_collision_info": 0x80413ae8,
		"PinnaEntranceOpen_map_collision_info": 0x80413ae8,
		"MoveBG::SirenaGate_map_collision_data": 0x80413af0,
		"SirenaGate_map_collision_data": 0x80413af0,
		"MoveBG::SirenaGate_map_collision_info": 0x80413af8,
		"SirenaGate_map_collision_info": 0x80413af8,
		"MoveBG::balloon_koopajr_anim_info": 0x80413b00,
		"balloon_koopajr_anim_info": 0x80413b00,
		"MoveBG::ShellCup_anim_info": 0x80413b08,
		"ShellCup_anim_info": 0x80413b08,
		"MoveBG::ShellCup_map_collision_data": 0x80413b10,
		"ShellCup_map_collision_data": 0x80413b10,
		"MoveBG::ShellCup_map_collision_info": 0x80413b18,
		"ShellCup_map_collision_info": 0x80413b18,
		"MoveBG::Gateshell_anim_info": 0x80413b20,
		"Gateshell_anim_info": 0x80413b20,
		"MoveBG::Gateshell_map_collision_data": 0x80413b28,
		"Gateshell_map_collision_data": 0x80413b28,
		"MoveBG::Gateshell_map_collision_info": 0x80413b30,
		"Gateshell_map_collision_info": 0x80413b30,
		"MoveBG::PinnaHangingBridgeBoard_anim_info": 0x80413b38,
		"PinnaHangingBridgeBoard_anim_info": 0x80413b38,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_data": 0x80413b40,
		"PinnaHangingBridgeBoard_map_collision_data": 0x80413b40,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_info": 0x80413b48,
		"PinnaHangingBridgeBoard_map_collision_info": 0x80413b48,
		"MoveBG::GateManta_anim_info": 0x80413b50,
		"GateManta_anim_info": 0x80413b50,
		"MoveBG::AmiKing_anim_info": 0x80413b58,
		"AmiKing_anim_info": 0x80413b58,
		"MoveBG::@3291": 0x80413b60,
		"MoveBG::casinoroulette_map_collision_data": 0x80413b70,
		"casinoroulette_map_collision_data": 0x80413b70,
		"MoveBG::casinoroulette_map_collision_info": 0x80413b78,
		"casinoroulette_map_collision_info": 0x80413b78,
		"MoveBG::@3295": 0x80413b80,
		"MoveBG::roulette_anim_info": 0x80413b88,
		"roulette_anim_info": 0x80413b88,
		"MoveBG::roulette00_map_collision_data": 0x80413b90,
		"roulette00_map_collision_data": 0x80413b90,
		"MoveBG::roulette00_map_collision_info": 0x80413b98,
		"roulette00_map_collision_info": 0x80413b98,
		"MoveBG::roulette01_map_collision_data": 0x80413ba8,
		"roulette01_map_collision_data": 0x80413ba8,
		"MoveBG::roulette01_map_collision_info": 0x80413bb0,
		"roulette01_map_collision_info": 0x80413bb0,
		"MoveBG::roulette02_map_collision_data": 0x80413bc0,
		"roulette02_map_collision_data": 0x80413bc0,
		"MoveBG::roulette02_map_collision_info": 0x80413bc8,
		"roulette02_map_collision_info": 0x80413bc8,
		"MoveBG::pazul_map_collision_data": 0x80413be8,
		"pazul_map_collision_data": 0x80413be8,
		"MoveBG::pazul_map_collision_info": 0x80413bf0,
		"pazul_map_collision_info": 0x80413bf0,
		"MoveBG::bosswall_anim_info": 0x80413bf8,
		"bosswall_anim_info": 0x80413bf8,
		"MoveBG::casinoroof_anim_info": 0x80413c00,
		"casinoroof_anim_info": 0x80413c00,
		"MoveBG::GlassBreak_anim_info": 0x80413c08,
		"GlassBreak_anim_info": 0x80413c08,
		"MoveBG::GlassBreak_map_collision_data": 0x80413c10,
		"GlassBreak_map_collision_data": 0x80413c10,
		"MoveBG::GlassBreak_map_collision_info": 0x80413c18,
		"GlassBreak_map_collision_info": 0x80413c18,
		"MoveBG::GlassBreak_sound_info": 0x80413c20,
		"GlassBreak_sound_info": 0x80413c20,
		"MoveBG::closet_anim_info": 0x80413c28,
		"closet_anim_info": 0x80413c28,
		"MoveBG::ChestRevolve_anim_info": 0x80413c38,
		"ChestRevolve_anim_info": 0x80413c38,
		"MoveBG::ChestRevolve_map_collision_info": 0x80413c40,
		"ChestRevolve_map_collision_info": 0x80413c40,
		"MoveBG::PosterTeresa_map_collision_data": 0x80413c48,
		"PosterTeresa_map_collision_data": 0x80413c48,
		"MoveBG::PosterTeresa_map_collision_info": 0x80413c50,
		"PosterTeresa_map_collision_info": 0x80413c50,
		"MoveBG::PictureTeresa_map_collision_data": 0x80413c58,
		"PictureTeresa_map_collision_data": 0x80413c58,
		"MoveBG::PictureTeresa_map_collision_info": 0x80413c60,
		"PictureTeresa_map_collision_info": 0x80413c60,
		"MoveBG::PanelBreak_anim_info": 0x80413c68,
		"PanelBreak_anim_info": 0x80413c68,
		"MoveBG::PanelBreak_map_collision_data": 0x80413c70,
		"PanelBreak_map_collision_data": 0x80413c70,
		"MoveBG::PanelBreak_map_collision_info": 0x80413c78,
		"PanelBreak_map_collision_info": 0x80413c78,
		"MoveBG::PanelBreak_sound_info": 0x80413c80,
		"PanelBreak_sound_info": 0x80413c80,
		"MoveBG::PanelRevolve_anim_info": 0x80413c88,
		"PanelRevolve_anim_info": 0x80413c88,
		"MoveBG::PanelRevolve_map_collision_data": 0x80413c90,
		"PanelRevolve_map_collision_data": 0x80413c90,
		"MoveBG::PanelRevolve_map_collision_info": 0x80413c98,
		"PanelRevolve_map_collision_info": 0x80413c98,
		"MoveBG::SirenaShop_map_collision_data": 0x80413ca0,
		"SirenaShop_map_collision_data": 0x80413ca0,
		"MoveBG::SirenaShop_map_collision_info": 0x80413ca8,
		"SirenaShop_map_collision_info": 0x80413ca8,
		"MoveBG::cogwheel_anim_info": 0x80413cb0,
		"cogwheel_anim_info": 0x80413cb0,
		"MoveBG::cogwheel_map_collision_data": 0x80413cb8,
		"cogwheel_map_collision_data": 0x80413cb8,
		"MoveBG::cogwheel_map_collision_info": 0x80413cc0,
		"cogwheel_map_collision_info": 0x80413cc0,
		"MoveBG::CogwheelPlate_map_collision_data": 0x80413cc8,
		"CogwheelPlate_map_collision_data": 0x80413cc8,
		"MoveBG::CogwheelPlate_map_collision_info": 0x80413cd0,
		"CogwheelPlate_map_collision_info": 0x80413cd0,
		"MoveBG::CogwheelPot_map_collision_data": 0x80413cd8,
		"CogwheelPot_map_collision_data": 0x80413cd8,
		"MoveBG::CogwheelPot_map_collision_info": 0x80413ce0,
		"CogwheelPot_map_collision_info": 0x80413ce0,
		"MoveBG::@3338": 0x80413ce8,
		"MoveBG::mare_float_house_map_collision_data": 0x80413cf0,
		"mare_float_house_map_collision_data": 0x80413cf0,
		"MoveBG::mare_float_house_map_collision_info": 0x80413cf8,
		"mare_float_house_map_collision_info": 0x80413cf8,
		"MoveBG::StopRock_map_collision_data": 0x80413d00,
		"StopRock_map_collision_data": 0x80413d00,
		"MoveBG::StopRock_map_collision_info": 0x80413d08,
		"StopRock_map_collision_info": 0x80413d08,
		"MoveBG::GrowthTree_anim_info": 0x80413d10,
		"GrowthTree_anim_info": 0x80413d10,
		"MoveBG::@3344": 0x80413d18,
		"MoveBG::GrowthTree_map_collision_data": 0x80413d20,
		"GrowthTree_map_collision_data": 0x80413d20,
		"MoveBG::GrowthTree_map_collision_info": 0x80413d28,
		"GrowthTree_map_collision_info": 0x80413d28,
		"MoveBG::MuddyBoat_anim_info": 0x80413d30,
		"MuddyBoat_anim_info": 0x80413d30,
		"MoveBG::MuddyBoat_map_collision_data": 0x80413d38,
		"MuddyBoat_map_collision_data": 0x80413d38,
		"MoveBG::MuddyBoat_map_collision_info": 0x80413d40,
		"MuddyBoat_map_collision_info": 0x80413d40,
		"MoveBG::Puncher_anim_info": 0x80413d48,
		"Puncher_anim_info": 0x80413d48,
		"MoveBG::HatoPop_anim_info": 0x80413d58,
		"HatoPop_anim_info": 0x80413d58,
		"MoveBG::@3357": 0x80413d60,
		"MoveBG::MareWaterJump_map_collision_data": 0x80413d68,
		"MareWaterJump_map_collision_data": 0x80413d68,
		"MoveBG::MareWaterJump_map_collision_info": 0x80413d70,
		"MareWaterJump_map_collision_info": 0x80413d70,
		"MoveBG::CoinFish_anim_info": 0x80413d78,
		"CoinFish_anim_info": 0x80413d78,
		"MoveBG::MareFall_anim_info": 0x80413d80,
		"MareFall_anim_info": 0x80413d80,
		"MoveBG::MareCork_map_collision_data": 0x80413d88,
		"MareCork_map_collision_data": 0x80413d88,
		"MoveBG::MareCork_map_collision_info": 0x80413d90,
		"MareCork_map_collision_info": 0x80413d90,
		"MoveBG::MonteRoot_anim_info": 0x80413d98,
		"MonteRoot_anim_info": 0x80413d98,
		"MoveBG::JumpMushroom_anim_info": 0x80413da0,
		"JumpMushroom_anim_info": 0x80413da0,
		"MoveBG::JumpMushroom_map_collision_data": 0x80413da8,
		"JumpMushroom_map_collision_data": 0x80413da8,
		"MoveBG::JumpMushroom_map_collision_info": 0x80413db0,
		"JumpMushroom_map_collision_info": 0x80413db0,
		"MoveBG::MonteGoalFlag_anim_info": 0x80413db8,
		"MonteGoalFlag_anim_info": 0x80413db8,
		"MoveBG::HangingBridgeBoard_anim_info": 0x80413dc0,
		"HangingBridgeBoard_anim_info": 0x80413dc0,
		"MoveBG::HangingBridgeBoard_map_collision_data": 0x80413dd0,
		"HangingBridgeBoard_map_collision_data": 0x80413dd0,
		"MoveBG::HangingBridgeBoard_map_collision_info": 0x80413dd8,
		"HangingBridgeBoard_map_collision_info": 0x80413dd8,
		"MoveBG::SwingBoard_map_collision_data": 0x80413de0,
		"SwingBoard_map_collision_data": 0x80413de0,
		"MoveBG::SwingBoard_map_collision_info": 0x80413de8,
		"SwingBoard_map_collision_info": 0x80413de8,
		"MoveBG::Fluff_anim_info": 0x80413df0,
		"Fluff_anim_info": 0x80413df0,
		"MoveBG::Bathtub_anim_info": 0x80413e00,
		"Bathtub_anim_info": 0x80413e00,
		"MoveBG::BathtubStandBreaking_anim_info": 0x80413e18,
		"BathtubStandBreaking_anim_info": 0x80413e18,
		"MoveBG::ex1_turn_lift_anim_info": 0x80413e20,
		"ex1_turn_lift_anim_info": 0x80413e20,
		"MoveBG::ex1_turn_lift_map_collision_data": 0x80413e28,
		"ex1_turn_lift_map_collision_data": 0x80413e28,
		"MoveBG::ex1_turn_lift_map_collision_info": 0x80413e30,
		"ex1_turn_lift_map_collision_info": 0x80413e30,
		"MoveBG::z_turn_disk_map_collision_data": 0x80413e38,
		"z_turn_disk_map_collision_data": 0x80413e38,
		"MoveBG::z_turn_disk_map_collision_info": 0x80413e40,
		"z_turn_disk_map_collision_info": 0x80413e40,
		"MoveBG::y_turn_lift_anim_info": 0x80413e48,
		"y_turn_lift_anim_info": 0x80413e48,
		"MoveBG::y_turn_lift_map_collision_data": 0x80413e50,
		"y_turn_lift_map_collision_data": 0x80413e50,
		"MoveBG::y_turn_lift_map_collision_info": 0x80413e58,
		"y_turn_lift_map_collision_info": 0x80413e58,
		"MoveBG::Nail_anim_info": 0x80413e60,
		"Nail_anim_info": 0x80413e60,
		"MoveBG::Nail_map_collision_data": 0x80413e70,
		"Nail_map_collision_data": 0x80413e70,
		"MoveBG::Nail_map_collision_info": 0x80413e78,
		"Nail_map_collision_info": 0x80413e78,
		"MoveBG::PachinkoNail_anim_info": 0x80413e80,
		"PachinkoNail_anim_info": 0x80413e80,
		"MoveBG::PachinkoNail_map_collision_data": 0x80413e88,
		"PachinkoNail_map_collision_data": 0x80413e88,
		"MoveBG::PachinkoNail_map_collision_info": 0x80413e90,
		"PachinkoNail_map_collision_info": 0x80413e90,
		"MoveBG::FileLoadBlock_map_collision_data": 0x80413e98,
		"FileLoadBlock_map_collision_data": 0x80413e98,
		"MoveBG::FileLoadBlock_map_collision_info": 0x80413ea0,
		"FileLoadBlock_map_collision_info": 0x80413ea0,
		"MoveBG::FileLoadBlockA_anim_info": 0x80413ea8,
		"FileLoadBlockA_anim_info": 0x80413ea8,
		"MoveBG::FileLoadBlockB_anim_info": 0x80413eb0,
		"FileLoadBlockB_anim_info": 0x80413eb0,
		"MoveBG::FileLoadBlockC_anim_info": 0x80413eb8,
		"FileLoadBlockC_anim_info": 0x80413eb8,
		"MoveBG::@3910": 0x80413ec4,
		"MoveBG::@3969": 0x80413ecc,
		"MoveBG::@4008": 0x80413ed0,
		"MoveBG::@3676": 0x80413f08,
		"MoveBG::@3727": 0x80413f0c,
		"MoveBG::@3738": 0x80413f10,
		"MoveBG::@3651": 0x80413fa0,
		"MoveBG::@4224": 0x80413fb0,
		"MoveBG::@4629": 0x80414288,
		"MoveBG::@3439": 0x80414324,
		"MoveBG::@3654": 0x80414328,
		"MoveBG::@3655": 0x8041432c,
		"MoveBG::@3656": 0x80414330,
		"MoveBG::@3657": 0x80414334,
		"MoveBG::@3503": 0x8041446c,
		"MoveBG::@3504": 0x80414470,
		"MoveBG::@3545": 0x80414478,
		"MoveBG::@3694": 0x80414490,
		"MoveBG::@4024": 0x804144d8,
		"MoveBG::@4025": 0x804144dc,
		"MoveBG::@4077": 0x804144e4,
		"MoveBG::@4078": 0x804144e8,
		"MoveBG::@4079": 0x804144ec,
		"MoveBG::@4080": 0x804144f0,
		"MoveBG::@4081": 0x804144f4,
		"MoveBG::@4205": 0x80414508,
		"MoveBG::@4133": 0x804145e8,
		"MoveBG::@4136": 0x804145f4,
		"MoveBG::@4137": 0x804145f8,
		"MoveBG::@4138": 0x804145fc,
		"MoveBG::@4139": 0x80414600,
		"MoveBG::@2393": 0x8041461c,
		"MoveBG::@2394": 0x80414620,
		"MoveBG::@2646": 0x80414670,
		"MoveBG::@2647": 0x80414674,
		"MoveBG::@2648": 0x80414678,
		"MoveBG::@2676": 0x80414698,
		"MoveBG::@2677": 0x8041469c,
		"MoveBG::@2681": 0x804146a8,
		"MoveBG::@2682": 0x804146ac,
		"MoveBG::@2687": 0x804146c0,
		"MoveBG::@2689": 0x804146c8,
		"MoveBG::@2465": 0x804146f8,
		"MoveBG::@2466": 0x80414700,
		"@2466": 0x80414700,
		"MoveBG::@2512": 0x80414708,
		"MoveBG::@2633": 0x8041471c,
		"MoveBG::@2705": 0x80414734,
		"MoveBG::@3689": 0x804147c0,
		"MoveBG::@4727": 0x804147e0,
		"MoveBG::@4728": 0x804147e4,
		"MoveBG::@4729": 0x804147e8,
		"MoveBG::@4730": 0x804147ec,
		"MoveBG::@4731": 0x804147f0,
		"MoveBG::@4732": 0x804147f4,
		"MoveBG::@4733": 0x804147f8,
		"MoveBG::@4734": 0x804147fc,
		"MoveBG::@2453": 0x804148b8,
		"MoveBG::@2620": 0x804148c4,
		"MoveBG::@2621": 0x804148c8,
		"MoveBG::@2622": 0x804148cc,
		"MoveBG::@2623": 0x804148d0,
		"MoveBG::@2186": 0x804148e0,
		"MoveBG::@2263": 0x804148e4,
		"MoveBG::@2279": 0x804148e8,
		"MoveBG::@2303": 0x804148ec,
		"MoveBG::@2574": 0x804148f8,
		"MoveBG::@3681": 0x804149d4,
		"MoveBG::@3682": 0x804149d8,
		"@3682": 0x804149d8,
		"MoveBG::@2671": 0x80414a00,
		"MoveBG::@3442": 0x80414a9c,
		"MoveBG::@3443": 0x80414aa0,
		"MoveBG::@3444": 0x80414aa4,
		"MoveBG::@3445": 0x80414aa8,
		"MoveBG::@3446": 0x80414aac,
		"MoveBG::@2668": 0x80414ba0,
		"MoveBG::@2697": 0x80414bac,
		"MoveBG::@2702": 0x80414bbc,
		"MoveBG::@2713": 0x80414bd4,
		"MoveBG::@5980": 0x80414ce4,
		"@5980": 0x80414ce4,
		"MoveBG::@5988": 0x80414d00,
		"Map::@3002": 0x80412730,
		"Map::@3209": 0x80412734,
		"Map::@3210": 0x80412738,
		"Map::@3211": 0x8041273c,
		"Map::@3508": 0x80412740,
		"Map::@2050": 0x80412748,
		"Map::@2904": 0x80412750,
		"Map::@2905": 0x80412754,
		"Map::@2906": 0x80412758,
		"Map::@3158": 0x80412768,
		"Map::@3159": 0x8041276c,
		"Map::@3160": 0x80412770,
		"Map::@3161": 0x80412774,
		"Map::@3196": 0x80412778,
		"Map::@3255": 0x8041277c,
		"Map::@3256": 0x80412780,
		"Map::@3279": 0x80412784,
		"Map::@2183": 0x80412788,
		"Map::@2184": 0x8041278c,
		"Map::@2185": 0x80412790,
		"Map::@2221": 0x80412794,
		"Map::@1871": 0x804127a0,
		"Map::@2017": 0x804127a4,
		"Map::@1838": 0x804127b0,
		"@1838": 0x804127b0,
		"Map::@1839": 0x804127b4,
		"Map::@1840": 0x804127b8,
		"Map::@1841": 0x804127c0,
		"Map::@3152": 0x804127d0,
		"Map::@3153": 0x804127d4,
		"Map::@2976": 0x80412800,
		"Map::@2088": 0x80412808,
		"Map::@2089": 0x8041280c,
		"Map::@2207": 0x80412818,
		"Map::@2841": 0x80412838,
		"Map::@3181": 0x80412848,
		"Map::@3182": 0x8041284c,
		"Map::@3183": 0x80412850,
		"Map::@2429": 0x80412858,
		"Map::@2430": 0x8041285c,
		"Map::@2431": 0x80412864,
		"Map::@2432": 0x8041286c,
		"Map::@2505": 0x80412874,
		"Map::@2506": 0x80412878,
		"Map::@2640": 0x804128d0,
		"Map::@2643": 0x804128e8,
		"Map::@2644": 0x804128f0,
		"Map::@2645": 0x804128f8,
		"Map::@2646": 0x80412900,
		"Map::@2648": 0x80412910,
		"Map::@2569": 0x8041296c,
		"Map::@2570": 0x80412970,
		"Map::@2572": 0x80412978,
		"Map::@2573": 0x8041297c,
		"Map::@2574": 0x80412980,
		"Map::@2575": 0x80412984,
		"Map::@2577": 0x8041298c,
		"Map::@2578": 0x80412990,
		"Map::@2547": 0x804129e4,
		"Map::@2610": 0x804129f4,
		"Map::@2863": 0x80412a08,
		"Map::@2958": 0x80412a0c,
		"Map::@3188": 0x80412a18,
		"Map::@2849": 0x80412a20,
		"Map::@2850": 0x80412a24,
		"Map::@2851": 0x80412a28,
		"Map::@2852": 0x80412a2c,
		"Map::@2390": 0x80412a38,
		"Map::@2392": 0x80412a3c,
		"Map::@2396": 0x80412a40,
		"Map::@2460": 0x80412a44,
		"Map::@2788": 0x80412a68,
		"Map::@2790": 0x80412a70,
		"Map::@2865": 0x80412a7c,
		"Map::@2866": 0x80412a80,
		"Map::@2785": 0x80412a8c,
		"Map::@2352": 0x80412abc,
		"Map::@2353": 0x80412ac0,
		"Map::@1992": 0x80412ad8,
		"Map::@1993": 0x80412adc,
		"Map::@2926": 0x80412b04,
		"Map::@2927": 0x80412b08,
		"Map::@2928": 0x80412b0c,
		"Map::@3135": 0x80412b4c,
		"Map::@3136": 0x80412b50,
		"Map::@3169": 0x80412b54,
		"Map::@3258": 0x80412b58,
		"Map::@3272": 0x80412b60,
		"Map::@3290": 0x80412b68,
		"Map::@3291": 0x80412b70,
		"Map::@3292": 0x80412b74,
		"Map::@3397": 0x80412b80,
		"Map::@3400": 0x80412b98,
		"Map::@3401": 0x80412b9c,
		"Map::@3402": 0x80412ba0,
		"Map::@3700": 0x80412ba4,
		"Map::@3760": 0x80412ba8,
		"Map::@3761": 0x80412bac,
		"Map::@3762": 0x80412bb0,
		"Map::@3763": 0x80412bb4,
		"Map::@3764": 0x80412bb8,
		"Map::@3765": 0x80412bbc,
		"Map::@3766": 0x80412bc0,
		"Map::@3767": 0x80412bc4,
		"Map::@3768": 0x80412bc8,
		"Map::@3769": 0x80412bcc,
		"Map::@3770": 0x80412bd0,
		"Map::@3771": 0x80412bd4,
		"Map::@3772": 0x80412bd8,
		"Map::@3773": 0x80412bdc,
		"Map::@3774": 0x80412be0,
		"Map::@3775": 0x80412be4,
		"Map::@3776": 0x80412be8,
		"Map::@3777": 0x80412bec,
		"Map::@3778": 0x80412bf0,
		"Map::@3779": 0x80412bf4,
		"Map::@3780": 0x80412bf8,
		"Map::@3781": 0x80412bfc,
		"Map::@3782": 0x80412c00,
		"Map::@3783": 0x80412c04,
		"Map::@3784": 0x80412c08,
		"Map::@3785": 0x80412c0c,
		"Map::@3786": 0x80412c10,
		"Map::@3787": 0x80412c14,
		"Map::@3788": 0x80412c18,
		"Map::@3789": 0x80412c1c,
		"Map::@2566": 0x80412c2c,
		"Map::@2567": 0x80412c30,
		"Map::@2724": 0x80412c3c,
		"Map::@3413": 0x80412c40,
		"Map::@3414": 0x80412c44,
		"Map::@3419": 0x80412c58,
		"Map::@3420": 0x80412c5c,
		"Map::@3421": 0x80412c60,
		"Map::@3422": 0x80412c64,
		"Map::@3424": 0x80412c6c,
		"Map::@3455": 0x80412c78,
		"Map::@3843": 0x80412c90,
		"Map::@3844": 0x80412c94,
		"Map::@3845": 0x80412c98,
		"Map::@3846": 0x80412c9c,
		"Map::@4483": 0x80412ca0,
		"Map::@4630": 0x80412cb0,
		"Map::@4740": 0x80412cb4,
		"Map::@4741": 0x80412cbc,
		"Map::@4759": 0x80412d04,
		"Map::@4765": 0x80412d14,
		"Map::@4767": 0x80412d18,
		"Map::@4769": 0x80412d1c,
		"Map::@4842": 0x80412d24,
		"Map::@4846": 0x80412d28,
		"Map::@4847": 0x80412d30,
		"Map::@4848": 0x80412d34,
		"Map::@4851": 0x80412d40,
		"Map::@4853": 0x80412d4c,
		"Map::@4854": 0x80412d54,
		"Map::@4856": 0x80412d58,
		"Map::@4857": 0x80412d60,
		"Map::@5833": 0x80412d64,
		"GC2D::@1644": 0x80411ec8,
		"GC2D::@2120": 0x80411ef8,
		"GC2D::@2375": 0x80411f00,
		"TGCConsole2::height$localstatic0$drawWater": 0x80411f1c,
		"height$localstatic0$drawWater": 0x80411f1c,
		"TGCConsole2::topDiff$localstatic1$drawWater": 0x80411f24,
		"topDiff$localstatic1$drawWater": 0x80411f24,
		"GC2D::@2720": 0x80411fb8,
		"GC2D::@2721": 0x80411fc0,
		"GC2D::@1549": 0x80412050,
		"GC2D::@1550": 0x80412054,
		"GC2D::@1551": 0x80412058,
		"GC2D::@1552": 0x8041205c,
		"GC2D::@1553": 0x80412060,
		"GC2D::@2665": 0x804120ac,
		"GC2D::@2666": 0x804120b0,
		"GC2D::@2667": 0x804120b4,
		"GC2D::@2668": 0x804120b8,
		"GC2D::@2669": 0x804120bc,
		"GC2D::@2670": 0x804120c0,
		"GC2D::@2671": 0x804120c4,
		"GC2D::@2672": 0x804120c8,
		"GC2D::@2673": 0x804120cc,
		"GC2D::@2674": 0x804120d0,
		"GC2D::@3154": 0x80412104,
		"GC2D::@3155": 0x80412108,
		"GC2D::@3156": 0x8041210c,
		"GC2D::@3216": 0x80412110,
		"GC2D::@3217": 0x80412114,
		"GC2D::@3218": 0x80412118,
		"GC2D::@3219": 0x8041211c,
		"GC2D::@3220": 0x80412120,
		"GC2D::@3221": 0x80412124,
		"GC2D::@3222": 0x80412128,
		"GC2D::@3223": 0x8041212c,
		"GC2D::@3224": 0x80412130,
		"GC2D::@3225": 0x80412134,
		"GC2D::@3342": 0x80412140,
		"GC2D::@3343": 0x80412144,
		"GC2D::@1995": 0x80412148,
		"GC2D::@1996": 0x8041214c,
		"GC2D::@2222": 0x804122b4,
		"GC2D::@2224": 0x804122bc,
		"GC2D::@2533": 0x804122d0,
		"GC2D::@2875": 0x804122d4,
		"GC2D::@2876": 0x804122d8,
		"GC2D::@2877": 0x804122dc,
		"GC2D::@3483": 0x804122f8,
		"GC2D::@3488": 0x80412300,
		"GC2D::@3489": 0x80412304,
		"GC2D::@3491": 0x80412308,
		"GC2D::@2809": 0x8041236c,
		"GC2D::@2878": 0x80412370,
		"GC2D::@2879": 0x80412374,
		"GC2D::@2392": 0x804123d0,
		"GC2D::@2393": 0x804123d4,
		"GC2D::@2394": 0x804123d8,
		"GC2D::@3119": 0x80412414,
		"GC2D::@1912": 0x80412420,
		"GC2D::@1913": 0x80412424,
		"GC2D::@2032": 0x8041242c,
		"GC2D::@2033": 0x80412430,
		"GC2D::@2034": 0x80412434,
		"GC2D::@2035": 0x80412438,
		"GC2D::@2036": 0x8041243c,
		"GC2D::@2037": 0x80412440,
		"GC2D::@2220": 0x8041245c,
		"GC2D::@2488": 0x8041246c,
		"GC2D::@2489": 0x80412470,
		"GC2D::@2490": 0x80412474,
		"GC2D::@2514": 0x80412478,
		"GC2D::@2515": 0x8041247c,
		"GC2D::@1505": 0x80412480,
		"GC2D::@1507": 0x80412484,
		"@1507": 0x80412484,
		"GC2D::@2653": 0x804124e4,
		"GC2D::@2654": 0x804124ec,
		"GC2D::@2655": 0x804124f0,
		"GC2D::@2656": 0x804124f4,
		"GC2D::@2756": 0x80412500,
		"GC2D::@2757": 0x80412504,
		"GC2D::@2758": 0x80412508,
		"GC2D::@2858": 0x8041250c,
		"GC2D::@2859": 0x80412510,
		"GC2D::@2954": 0x80412514,
		"GC2D::@2955": 0x80412518,
		"GC2D::@2956": 0x8041251c,
		"GC2D::@3620": 0x80412520,
		"GC2D::@3621": 0x80412524,
		"GC2D::@3622": 0x80412528,
		"GC2D::@3623": 0x8041252c,
		"GC2D::@3624": 0x80412530,
		"GC2D::@3814": 0x80412534,
		"GC2D::@1844": 0x80412540,
		"@1844": 0x80412540,
		"GC2D::@1684": 0x80412560,
		"GC2D::@114": 0x80412570,
		"GC2D::@256": 0x80412574,
		"GC2D::@292": 0x80412578,
		"GC2D::@295": 0x8041257c,
		"GC2D::@599": 0x80412580,
		"@599": 0x80412580,
		"GC2D::@600": 0x80412584,
		"@600": 0x80412584,
		"GC2D::@601": 0x80412588,
		"@601": 0x80412588,
		"GC2D::@602": 0x8041258c,
		"GC2D::@603": 0x80412590,
		"@603": 0x80412590,
		"GC2D::@604": 0x80412594,
		"GC2D::@605": 0x80412598,
		"@605": 0x80412598,
		"GC2D::@606": 0x8041259c,
		"GC2D::@607": 0x804125a0,
		"GC2D::@608": 0x804125a4,
		"@608": 0x804125a4,
		"GC2D::@609": 0x804125a8,
		"GC2D::@610": 0x804125ac,
		"GC2D::@650": 0x804125b8,
		"@650": 0x804125b8,
		"GC2D::@651": 0x804125bc,
		"@651": 0x804125bc,
		"GC2D::@652": 0x804125c0,
		"@652": 0x804125c0,
		"GC2D::@653": 0x804125c4,
		"@653": 0x804125c4,
		"GC2D::@654": 0x804125c8,
		"GC2D::@655": 0x804125cc,
		"GC2D::@656": 0x804125d0,
		"@656": 0x804125d0,
		"GC2D::@657": 0x804125d4,
		"@657": 0x804125d4,
		"GC2D::@753": 0x804125f0,
		"GC2D::@754": 0x804125f4,
		"GC2D::@755": 0x804125f8,
		"@755": 0x804125f8,
		"GC2D::@756": 0x804125fc,
		"@756": 0x804125fc,
		"GC2D::@757": 0x80412600,
		"@757": 0x80412600,
		"GC2D::@758": 0x80412604,
		"@758": 0x80412604,
		"GC2D::@759": 0x80412608,
		"@759": 0x80412608,
		"GC2D::@760": 0x8041260c,
		"@760": 0x8041260c,
		"GC2D::@761": 0x80412610,
		"@761": 0x80412610,
		"GC2D::@762": 0x80412614,
		"GC2D::@763": 0x80412618,
		"GC2D::@764": 0x8041261c,
		"@764": 0x8041261c,
		"GC2D::@765": 0x80412620,
		"@765": 0x80412620,
		"GC2D::@766": 0x80412624,
		"@766": 0x80412624,
		"GC2D::@853": 0x80412628,
		"@853": 0x80412628,
		"GC2D::@942": 0x8041262c,
		"@942": 0x8041262c,
		"GC2D::@964": 0x80412630,
		"@964": 0x80412630,
		"GC2D::@996": 0x80412634,
		"@996": 0x80412634,
		"GC2D::@997": 0x80412638,
		"@997": 0x80412638,
		"GC2D::@998": 0x8041263c,
		"@998": 0x8041263c,
		"GC2D::@1037": 0x80412640,
		"@1037": 0x80412640,
		"GC2D::@1072": 0x80412650,
		"GC2D::@1073": 0x80412654,
		"GC2D::@1074": 0x80412658,
		"@1074": 0x80412658,
		"GC2D::@1075": 0x8041265c,
		"@1075": 0x8041265c,
		"GC2D::@1129": 0x80412660,
		"@1129": 0x80412660,
		"GC2D::@1130": 0x80412664,
		"@1130": 0x80412664,
		"GC2D::@1131": 0x80412668,
		"@1131": 0x80412668,
		"GC2D::@1132": 0x8041266c,
		"@1132": 0x8041266c,
		"GC2D::@1133": 0x80412670,
		"@1133": 0x80412670,
		"GC2D::@1134": 0x80412674,
		"@1134": 0x80412674,
		"GC2D::@1276": 0x80412678,
		"@1276": 0x80412678,
		"GC2D::@1620": 0x8041267c,
		"GC2D::@1621": 0x80412680,
		"GC2D::@1622": 0x80412684,
		"GC2D::@1623": 0x80412688,
		"GC2D::@1626": 0x80412694,
		"GC2D::@1627": 0x80412698,
		"GC2D::@1628": 0x8041269c,
		"GC2D::@1764": 0x804126a0,
		"@1764": 0x804126a0,
		"GC2D::@1865": 0x804126a4,
		"@unnamed@::cLongHeightMovieIdList": 0x804126a8,
		"cLongHeightMovieIdList": 0x804126a8,
		"@unnamed@::cStopRumbleAnm": 0x804126c0,
		"cStopRumbleAnm": 0x804126c0,
		"@unnamed@::cRumbleToggleItems": 0x804126c8,
		"cRumbleToggleItems": 0x804126c8,
		"GC2D::@1558": 0x80412720,
		"GC2D::@1580": 0x80412728,
		"Enemy::@4578": 0x8040f6b8,
		"Enemy::@2718": 0x8040f6c0,
		"Enemy::@2800": 0x8040f830,
		"Enemy::@2802": 0x8040f840,
		"Enemy::@2824": 0x8040f8c4,
		"Enemy::@2849": 0x8040f97c,
		"Enemy::@2856": 0x8040f9b4,
		"Enemy::@3205": 0x8040fa84,
		"Enemy::@2168": 0x8040fb8c,
		"Enemy::@2169": 0x8040fb90,
		"Enemy::@2170": 0x8040fb94,
		"Enemy::@2172": 0x8040fb9c,
		"Enemy::@2173": 0x8040fba0,
		"Enemy::@2174": 0x8040fba4,
		"Enemy::@2176": 0x8040fbac,
		"Enemy::@3678": 0x8040fbe8,
		"@3678": 0x8040fbe8,
		"Enemy::@5337": 0x8040fc6c,
		"Enemy::mFireHamNoseColorStart": 0x8040fcb8,
		"mFireHamNoseColorStart": 0x8040fcb8,
		"Enemy::mFireHamNoseColorEnd": 0x8040fcc0,
		"mFireHamNoseColorEnd": 0x8040fcc0,
		"Enemy::mFireHamOtherColorStart": 0x8040fcc8,
		"mFireHamOtherColorStart": 0x8040fcc8,
		"Enemy::mFireHamOtherColorEnd": 0x8040fcd0,
		"mFireHamOtherColorEnd": 0x8040fcd0,
		"Enemy::@6521": 0x8040fd78,
		"Enemy::@4408": 0x8040fd9c,
		"Enemy::@5072": 0x8040fdc8,
		"Enemy::@5073": 0x8040fdcc,
		"Enemy::@5188": 0x8040fde0,
		"Enemy::@5189": 0x8040fde4,
		"Enemy::@6362": 0x8040fdfc,
		"@6362": 0x8040fdfc,
		"Enemy::@6364": 0x8040fe00,
		"Enemy::@6367": 0x8040fe04,
		"@6367": 0x8040fe04,
		"Enemy::@6371": 0x8040fe08,
		"@6371": 0x8040fe08,
		"Enemy::@6373": 0x8040fe0c,
		"@6373": 0x8040fe0c,
		"Enemy::@6376": 0x8040fe10,
		"@6376": 0x8040fe10,
		"Enemy::@6382": 0x8040fe14,
		"@6382": 0x8040fe14,
		"Enemy::@6389": 0x8040fe20,
		"@6389": 0x8040fe20,
		"Enemy::@6393": 0x8040fe24,
		"@6393": 0x8040fe24,
		"Enemy::@6398": 0x8040fe2c,
		"@6398": 0x8040fe2c,
		"Enemy::@6403": 0x8040fe30,
		"@6403": 0x8040fe30,
		"Enemy::@6410": 0x8040fe34,
		"@6410": 0x8040fe34,
		"Enemy::@2402": 0x80410048,
		"Enemy::@2403": 0x8041004c,
		"Enemy::@2404": 0x80410050,
		"Enemy::@1602": 0x8041005c,
		"Enemy::@1603": 0x80410060,
		"Enemy::@1630": 0x80410064,
		"Enemy::@2245": 0x8041007c,
		"Enemy::@4121": 0x80410230,
		"Enemy::@4317": 0x80410240,
		"@4317": 0x80410240,
		"Enemy::cTelesaColorStart": 0x80410280,
		"cTelesaColorStart": 0x80410280,
		"@unnamed@::cBodyColorOnFire": 0x80410320,
		"cBodyColorOnFire": 0x80410320,
		"@unnamed@::cBodyColorOnCool": 0x80410328,
		"cBodyColorOnCool": 0x80410328,
		"@unnamed@::cBodyColorOnSilver": 0x80410330,
		"cBodyColorOnSilver": 0x80410330,
		"Enemy::@5383": 0x80410394,
		"@5383": 0x80410394,
		"Enemy::@5385": 0x8041039c,
		"@5385": 0x8041039c,
		"Enemy::@7892": 0x804103f0,
		"@7892": 0x804103f0,
		"Enemy::@9121": 0x80410408,
		"@9121": 0x80410408,
		"Enemy::@9130": 0x80410410,
		"@9130": 0x80410410,
		"Enemy::@9149": 0x80410420,
		"@9149": 0x80410420,
		"Enemy::@1696": 0x80410430,
		"@1696": 0x80410430,
		"Enemy::@2231": 0x80410448,
		"Enemy::@2232": 0x8041044c,
		"Enemy::@2299": 0x80410450,
		"Enemy::@7468": 0x80410500,
		"@7468": 0x80410500,
		"Enemy::@7469": 0x80410504,
		"@7469": 0x80410504,
		"Enemy::@7470": 0x80410508,
		"@7470": 0x80410508,
		"Enemy::@8328": 0x80410538,
		"Enemy::@8337": 0x80410540,
		"Enemy::@3406": 0x80410564,
		"Enemy::@5924": 0x80410ab8,
		"@5924": 0x80410ab8,
		"Enemy::@5926": 0x80410ac0,
		"@5926": 0x80410ac0,
		"Enemy::@5928": 0x80410ac8,
		"@5928": 0x80410ac8,
		"Enemy::@5929": 0x80410acc,
		"@5929": 0x80410acc,
		"Enemy::@5930": 0x80410ad0,
		"@5930": 0x80410ad0,
		"Enemy::@6816": 0x80410b18,
		"@6816": 0x80410b18,
		"Enemy::@8021": 0x80410b38,
		"@8021": 0x80410b38,
		"Enemy::@8022": 0x80410b3c,
		"@8022": 0x80410b3c,
		"Enemy::@8023": 0x80410b40,
		"Enemy::@8024": 0x80410b44,
		"@8024": 0x80410b44,
		"Enemy::@8025": 0x80410b48,
		"@8025": 0x80410b48,
		"Enemy::@8026": 0x80410b4c,
		"@8026": 0x80410b4c,
		"Enemy::@8750": 0x80410b60,
		"@8750": 0x80410b60,
		"Enemy::@4926": 0x80410c80,
		"Enemy::@4927": 0x80410c84,
		"Enemy::@4930": 0x80410c90,
		"Enemy::@6157": 0x80410cfc,
		"Enemy::@6170": 0x80410d08,
		"Enemy::@4678": 0x80410d70,
		"Enemy::@4204": 0x80410f00,
		"Enemy::@4206": 0x80410f08,
		"Enemy::@4208": 0x80410f10,
		"Enemy::@4209": 0x80410f14,
		"Enemy::@2022": 0x80410f38,
		"Enemy::@2023": 0x80410f3c,
		"Enemy::@2024": 0x80410f40,
		"Enemy::@2025": 0x80410f44,
		"Enemy::@4239": 0x80411040,
		"Enemy::@4240": 0x80411044,
		"Enemy::@2030": 0x804110c4,
		"Enemy::@2032": 0x804110c8,
		"Enemy::@2082": 0x80411148,
		"Enemy::@2083": 0x8041114c,
		"Enemy::@2084": 0x80411150,
		"Enemy::@2085": 0x80411154,
		"Enemy::@2086": 0x80411158,
		"Enemy::@2087": 0x8041115c,
		"Enemy::@2088": 0x80411160,
		"Enemy::@4374": 0x804111f0,
		"@4374": 0x804111f0,
		"Enemy::@4377": 0x804111fc,
		"Enemy::@4378": 0x80411200,
		"Enemy::@4379": 0x80411204,
		"Enemy::@4832": 0x80411220,
		"Enemy::@4835": 0x80411224,
		"Enemy::@4836": 0x80411228,
		"Enemy::@2474": 0x80411248,
		"Enemy::@1638": 0x804112c0,
		"Enemy::@1640": 0x804112c4,
		"Enemy::@1642": 0x804112c8,
		"Enemy::@1644": 0x804112cc,
		"Enemy::@1647": 0x804112d0,
		"@1647": 0x804112d0,
		"Enemy::@1649": 0x804112d4,
		"@1649": 0x804112d4,
		"Enemy::@1651": 0x804112d8,
		"@1651": 0x804112d8,
		"Enemy::@1653": 0x804112dc,
		"Enemy::@1655": 0x804112e0,
		"Enemy::@1659": 0x804112e4,
		"Enemy::@1663": 0x804112e8,
		"Enemy::@1665": 0x804112ec,
		"Enemy::@1668": 0x804112f0,
		"Enemy::@1670": 0x804112f4,
		"Enemy::@1680": 0x804112f8,
		"Enemy::@1683": 0x804112fc,
		"Enemy::@1685": 0x80411300,
		"Enemy::@1688": 0x80411304,
		"Enemy::@1779": 0x80411308,
		"Enemy::@1781": 0x8041130c,
		"Enemy::@1787": 0x80411318,
		"Enemy::@1789": 0x8041131c,
		"@1789": 0x8041131c,
		"Enemy::@1791": 0x80411320,
		"@1791": 0x80411320,
		"Enemy::@1794": 0x80411324,
		"@1794": 0x80411324,
		"Enemy::@1796": 0x80411328,
		"@1796": 0x80411328,
		"Enemy::@1804": 0x80411330,
		"@1804": 0x80411330,
		"Enemy::@1807": 0x80411334,
		"Enemy::@1809": 0x80411338,
		"Enemy::@1811": 0x8041133c,
		"Enemy::@1813": 0x80411340,
		"@1813": 0x80411340,
		"Enemy::@1815": 0x80411344,
		"@1815": 0x80411344,
		"Enemy::@1817": 0x80411348,
		"@1817": 0x80411348,
		"Enemy::@1819": 0x8041134c,
		"Enemy::@1823": 0x80411350,
		"@1823": 0x80411350,
		"Enemy::sEmitSandFrameFoot": 0x80411438,
		"sEmitSandFrameFoot": 0x80411438,
		"Enemy::@4729": 0x80411574,
		"Enemy::@2137": 0x80411630,
		"Enemy::@2138": 0x80411634,
		"Enemy::@2149": 0x80411640,
		"@unnamed@::cRedColor": 0x80411650,
		"cRedColor": 0x80411650,
		"@unnamed@::cBlueColor": 0x80411658,
		"cBlueColor": 0x80411658,
		"Enemy::@3864": 0x804117bc,
		"@3864": 0x804117bc,
		"Enemy::@4199": 0x804117e0,
		"Enemy::@5252": 0x80411824,
		"Enemy::@5253": 0x80411828,
		"Enemy::@5506": 0x80411830,
		"@5506": 0x80411830,
		"Enemy::@5507": 0x80411834,
		"@5507": 0x80411834,
		"Enemy::@1966": 0x80411850,
		"Enemy::@2039": 0x80411854,
		"Enemy::@2040": 0x80411858,
		"Enemy::@2119": 0x8041185c,
		"Enemy::@2152": 0x80411860,
		"Enemy::@3774": 0x804119b0,
		"Enemy::@6421": 0x804119e0,
		"@6421": 0x804119e0,
		"Enemy::@6422": 0x804119e4,
		"@6422": 0x804119e4,
		"Enemy::@6423": 0x804119e8,
		"@6423": 0x804119e8,
		"Enemy::@3636": 0x80411b30,
		"Enemy::@3600": 0x80411d94,
		"Enemy::@2126": 0x80411dd4,
		"Enemy::@2127": 0x80411dd8,
		"Enemy::@2128": 0x80411ddc,
		"Enemy::@2129": 0x80411de0,
		"Enemy::@2130": 0x80411de4,
		"Enemy::@2131": 0x80411de8,
		"Enemy::@4598": 0x80411e78,
		"Enemy::@3787": 0x80411eb0,
		"Enemy::@3789": 0x80411eb4,
		"Enemy::@3794": 0x80411ebc,
		"Camera::@2112": 0x8040f1f4,
		"Camera::@2113": 0x8040f1f8,
		"Camera::@2304": 0x8040f200,
		"Camera::@2305": 0x8040f204,
		"Camera::@2306": 0x8040f208,
		"Camera::@2307": 0x8040f20c,
		"Camera::@2308": 0x8040f210,
		"Camera::@2309": 0x8040f214,
		"Camera::@1717": 0x8040f238,
		"@1717": 0x8040f238,
		"Camera::@1655": 0x8040f2c0,
		"Camera::@1663": 0x8040f2d0,
		"Camera::@1659": 0x8040f2e0,
		"Camera::@1660": 0x8040f2e4,
		"Camera::@2403": 0x8040f324,
		"Camera::@2404": 0x8040f328,
		"Camera::@1896": 0x8040f3a0,
		"@1896": 0x8040f3a0,
		"Camera::@1900": 0x8040f3a8,
		"Camera::@1902": 0x8040f3ac,
		"Camera::@1904": 0x8040f3b0,
		"Camera::@1914": 0x8040f3bc,
		"@1914": 0x8040f3bc,
		"Camera::@1916": 0x8040f3c0,
		"@1916": 0x8040f3c0,
		"Camera::@1918": 0x8040f3c4,
		"@1918": 0x8040f3c4,
		"Camera::@1920": 0x8040f3c8,
		"@1920": 0x8040f3c8,
		"Camera::@1938": 0x8040f3cc,
		"Camera::@1940": 0x8040f3d0,
		"Camera::@1942": 0x8040f3d4,
		"Camera::@1945": 0x8040f3d8,
		"Camera::@1947": 0x8040f3dc,
		"Camera::@1958": 0x8040f3f0,
		"Camera::@1960": 0x8040f3f4,
		"Camera::@1963": 0x8040f3f8,
		"Camera::@1965": 0x8040f3fc,
		"Camera::@2121": 0x8040f400,
		"Camera::@2126": 0x8040f404,
		"Camera::@2128": 0x8040f408,
		"Camera::@2132": 0x8040f40c,
		"Camera::@2134": 0x8040f410,
		"Camera::@2137": 0x8040f414,
		"Camera::@2145": 0x8040f418,
		"Camera::@2205": 0x8040f41c,
		"Camera::@1807": 0x8040f438,
		"Camera::@1808": 0x8040f43c,
		"Camera::@1810": 0x8040f444,
		"Camera::@1811": 0x8040f448,
		"Camera::@2158": 0x8040f4f8,
		"Camera::@2159": 0x8040f4fc,
		"Camera::@2160": 0x8040f500,
		"Camera::@1864": 0x8040f51c,
		"@1864": 0x8040f51c,
		"Camera::@1865": 0x8040f520,
		"Camera::@1887": 0x8040f530,
		"@1887": 0x8040f530,
		"Camera::@2042": 0x8040f558,
		"Camera::@2043": 0x8040f55c,
		"Camera::@2044": 0x8040f560,
		"Camera::@2045": 0x8040f564,
		"Camera::@1778": 0x8040f570,
		"Camera::@1652": 0x8040f598,
		"Camera::@1653": 0x8040f59c,
		"Camera::@1758": 0x8040f5b0,
		"Camera::@1759": 0x8040f5b4,
		"@1759": 0x8040f5b4,
		"Camera::@1762": 0x8040f5c8,
		"@1762": 0x8040f5c8,
		"Camera::@1763": 0x8040f5cc,
		"Camera::@1705": 0x8040f614,
		"Camera::@1706": 0x8040f618,
		"Camera::@1707": 0x8040f61c,
		"Camera::@1710": 0x8040f628,
		"Camera::@1765": 0x8040f62c,
		"@1765": 0x8040f62c,
		"Camera::@1768": 0x8040f674,
		"Animal::@2190": 0x8040eba0,
		"Animal::@2191": 0x8040eba4,
		"Animal::@2192": 0x8040eba8,
		"Animal::@2193": 0x8040ebac,
		"Animal::@2194": 0x8040ebb0,
		"Animal::@2195": 0x8040ebb4,
		"Animal::@2196": 0x8040ebb8,
		"Animal::@2202": 0x8040ebc8,
		"Animal::@2203": 0x8040ebcc,
		"Animal::@2289": 0x8040ebd0,
		"Animal::@2290": 0x8040ebd4,
		"Animal::@2526": 0x8040ebd8,
		"Animal::@2527": 0x8040ebdc,
		"Animal::@2528": 0x8040ebe0,
		"Animal::@2529": 0x8040ebe4,
		"Animal::@2530": 0x8040ebe8,
		"Animal::@2531": 0x8040ebec,
		"Animal::@2532": 0x8040ebf0,
		"Animal::@2533": 0x8040ebf4,
		"Animal::@2577": 0x8040ebf8,
		"Animal::@2578": 0x8040ebfc,
		"Animal::@2580": 0x8040ec04,
		"Animal::@2362": 0x8040ec10,
		"Animal::@2450": 0x8040ec14,
		"Animal::@2451": 0x8040ec18,
		"Animal::@2452": 0x8040ec1c,
		"Animal::@2453": 0x8040ec20,
		"Animal::@2454": 0x8040ec24,
		"Animal::@2455": 0x8040ec28,
		"Animal::@2456": 0x8040ec2c,
		"Animal::@2457": 0x8040ec30,
		"Animal::@2689": 0x8040ec3c,
		"Animal::@2601": 0x8040ec44,
		"Animal::@2605": 0x8040ec48,
		"Animal::@2606": 0x8040ec4c,
		"Animal::@2760": 0x8040ec50,
		"Animal::@2761": 0x8040ec54,
		"Animal::@2762": 0x8040ec58,
		"Animal::@2763": 0x8040ec5c,
		"Animal::@2764": 0x8040ec60,
		"Animal::@2765": 0x8040ec64,
		"Animal::@2766": 0x8040ec68,
		"Animal::@2767": 0x8040ec6c,
		"Animal::@2768": 0x8040ec70,
		"Animal::@2929": 0x8040ec74,
		"Animal::@3022": 0x8040ec78,
		"Animal::@3023": 0x8040ec7c,
		"Animal::@3201": 0x8040ec90,
		"Animal::@3267": 0x8040ec94,
		"Animal::@3268": 0x8040ec98,
		"Animal::@3269": 0x8040ec9c,
		"Animal::@2600": 0x8040eca0,
		"Animal::@2613": 0x8040eca4,
		"Animal::@1564": 0x8040eca8,
		"Animal::@1566": 0x8040ecac,
		"Animal::@1568": 0x8040ecb0,
		"Animal::@1570": 0x8040ecb4,
		"Animal::@1572": 0x8040ecb8,
		"Animal::@1574": 0x8040ecbc,
		"Animal::@1576": 0x8040ecc0,
		"Animal::@1578": 0x8040ecc4,
		"Animal::@2158": 0x8040ecc8,
		"Animal::@2159": 0x8040eccc,
		"Animal::@2160": 0x8040ecd0,
		"Animal::@3220": 0x8040ecf4,
		"Animal::@3221": 0x8040ecf8,
		"Animal::@3303": 0x8040ed08,
		"Animal::@3407": 0x8040ed0c,
		"Animal::@3411": 0x8040ed10,
		"Animal::@3412": 0x8040ed14,
		"Animal::@3453": 0x8040ed18,
		"Animal::@3544": 0x8040ed1c,
		"Animal::@3545": 0x8040ed20,
		"Animal::@3691": 0x8040ed24,
		"Animal::@3692": 0x8040ed28,
		"Animal::@3773": 0x8040ed2c,
		"Animal::@3930": 0x8040ed30,
		"Animal::@3933": 0x8040ed34,
		"Animal::@3935": 0x8040ed38,
		"Animal::@3937": 0x8040ed3c,
		"Animal::@3939": 0x8040ed40,
		"Animal::@3944": 0x8040ed44,
		"Animal::@3946": 0x8040ed48,
		"Animal::@3951": 0x8040ed4c,
		"Animal::@3954": 0x8040ed50,
		"Animal::@4172": 0x8040ed54,
		"Animal::@4173": 0x8040ed58,
		"Animal::@4755": 0x8040ed5c,
		"Animal::@4897": 0x8040ed60,
		"Animal::@4898": 0x8040ed68,
		"Animal::@4921": 0x8040ed6c,
		"Animal::@4922": 0x8040ed70,
		"Animal::@4923": 0x8040ed74,
		"Animal::@3087": 0x8040ed78,
		"Animal::@3088": 0x8040ed7c,
		"Animal::@3089": 0x8040ed80,
		"Animal::@3203": 0x8040ed84,
		"Animal::@3204": 0x8040ed88,
		"Animal::@3205": 0x8040ed8c,
		"Animal::@3206": 0x8040ed90,
		"Animal::@3207": 0x8040ed94,
		"Animal::@3208": 0x8040ed98,
		"Animal::@3448": 0x8040eda0,
		"Animal::@3664": 0x8040eda4,
		"Animal::@3667": 0x8040eda8,
		"Animal::@3668": 0x8040edac,
		"Animal::@3669": 0x8040edb4,
		"Animal::@3671": 0x8040edb8,
		"Animal::@3673": 0x8040edbc,
		"Animal::@3676": 0x8040edc0,
		"Animal::@3852": 0x8040edd0,
		"Animal::@3853": 0x8040edd4,
		"Animal::@3854": 0x8040edd8,
		"Animal::@3855": 0x8040eddc,
		"Animal::@4245": 0x8040ede0,
		"Animal::@4246": 0x8040ede4,
		"Animal::@4332": 0x8040ede8,
		"Animal::@4452": 0x8040edec,
		"Animal::@4453": 0x8040edf0,
		"@4453": 0x8040edf0,
		"Animal::@4454": 0x8040edf4,
		"Animal::@4455": 0x8040edf8,
		"Animal::@4456": 0x8040edfc,
		"Animal::@4641": 0x8040ee00,
		"Animal::@4642": 0x8040ee04,
		"Animal::@4709": 0x8040ee0c,
		"Animal::@4869": 0x8040ee10,
		"Animal::@4870": 0x8040ee14,
		"Animal::@5080": 0x8040ee1c,
		"Animal::@5340": 0x8040ee20,
		"Animal::@2489": 0x8040ee28,
		"Animal::@2490": 0x8040ee2c,
		"Animal::@2491": 0x8040ee30,
		"Animal::@2492": 0x8040ee38,
		"Animal::@2586": 0x8040ee3c,
		"Animal::@2587": 0x8040ee40,
		"Animal::@2588": 0x8040ee44,
		"Animal::@2589": 0x8040ee48,
		"Animal::@2590": 0x8040ee4c,
		"Animal::@2591": 0x8040ee50,
		"Animal::@2592": 0x8040ee54,
		"Animal::@2593": 0x8040ee58,
		"Animal::@2710": 0x8040ee60,
	},
	"GMSP01": {
		"Runtime.PPCEABI.H::memset": 0x80003100,
		"memset": 0x80003100,
		"Runtime.PPCEABI.H::__fill_mem": 0x80003130,
		"__fill_mem": 0x80003130,
		"Runtime.PPCEABI.H::memcpy": 0x800031f4,
		"memcpy": 0x800031f4,
		"TRK_MINNOW_DOLPHIN::TRK_memcpy": 0x80003244,
		"TRK_memcpy": 0x80003244,
		"TRK_MINNOW_DOLPHIN::TRK_memset": 0x80003268,
		"TRK_memset": 0x80003268,
		"TRK_MINNOW_DOLPHIN::__TRK_reset": 0x800051cc,
		"__TRK_reset": 0x800051cc,
		"os::__check_pad3": 0x800051ec,
		"__check_pad3": 0x800051ec,
		"os::__start": 0x8000522c,
		"os::__init_registers": 0x80005364,
		"__init_registers": 0x80005364,
		"os::__init_data": 0x80005380,
		"__init_data": 0x80005380,
		"os::__init_hardware": 0x80005440,
		"__init_hardware": 0x80005440,
		"os::__flush_cache": 0x80005460,
		"__flush_cache": 0x80005460,
		"Runtime.PPCEABI.H::@152": 0x80005540,
		"Runtime.PPCEABI.H::@157": 0x80005548,
		"Runtime.PPCEABI.H::@174": 0x80005550,
		"Runtime.PPCEABI.H::@182": 0x80005568,
		"Runtime.PPCEABI.H::@201": 0x80005570,
		"@201": 0x80005570,
		"Runtime.PPCEABI.H::@153": 0x800055a0,
		"Runtime.PPCEABI.H::@158": 0x800055ac,
		"Runtime.PPCEABI.H::@175": 0x800055b8,
		"Runtime.PPCEABI.H::@183": 0x800055c4,
		"Runtime.PPCEABI.H::@202": 0x800055d0,
		"@202": 0x800055d0,
		"main::main": 0x80005600,
		"main::__sinit_main_cpp": 0x80005644,
		"__sinit_main_cpp": 0x80005644,
		"Animal::CLBChaseGeneralConstantSpecifySpeed": 0x8000945c,
		"Animal::CLBPalFrame": 0x8000ab94,
		"Animal::CLBRoundf": 0x8000abec,
		"Animal::SMS_EasyEmitParticle": 0x8000e400,
		"MAnmSoundMario::startAnimSound": 0x80012cdc,
		"MSound::getDistPowFromCamera": 0x80015224,
		"getDistPowFromCamera": 0x80015224,
		"Camera::CLBRoundf": 0x800211a4,
		"Camera::CLBChaseGeneralConstantSpecifySpeed": 0x800263d4,
		"Camera::CLBChaseConstantSpecifyFrame": 0x80026f3c,
		"Camera::CLBSquared": 0x80029e0c,
		"Camera::JMASCos": 0x8002d7f4,
		"Camera::JMASSin": 0x8002d810,
		"Camera::__ct__Q26JDrama10TFlagT<Us>FUs": 0x8002f894,
		"Enemy::SpcTrace": 0x8003d98c,
		"Enemy::MsPerpendicFootToLineR": 0x800a2f74,
		"Enemy::__sinit_riccohook_cpp": 0x800c1770,
		"__sinit_riccohook_cpp": 0x800c1770,
		"TBombHeiManager::clipEnemies": 0x800c429c,
		"TAmiNoko::emitEffects": 0x800f07f8,
		"TAmiNoko::calcDirection": 0x800f0a38,
		"calcDirection": 0x800f0a38,
		"TGCConsole2::countBlueCoin": 0x8013c200,
		"countBlueCoin": 0x8013c200,
		"TGCConsole2::countShine": 0x8013c690,
		"countShine": 0x8013c690,
		"TGCConsole2::checkDolpic8": 0x8013d458,
		"checkDolpic8": 0x8013d458,
		"TGCConsole2::startDisappearTank": 0x801415b4,
		"startDisappearTank": 0x801415b4,
		"TCardSave::setMessageC": 0x80156c74,
		"setMessageC": 0x80156c74,
		"TCardLoad::resizeBox": 0x801610bc,
		"resizeBox": 0x801610bc,
		"TCardLoad::setupTitleScreen": 0x801638b4,
		"setupTitleScreen": 0x801638b4,
		"TCardLoad::changeLanguage": 0x80163bb8,
		"changeLanguage": 0x80163bb8,
		"TCardLoad::loadLangTexture": 0x80163ddc,
		"loadLangTexture": 0x80163ddc,
		"TCardLoad::resetScoreScreenObjects": 0x80164194,
		"resetScoreScreenObjects": 0x80164194,
		"TGuide::startMoveCursor2": 0x80171314,
		"startMoveCursor2": 0x80171314,
		"TProgSelect::setLang": 0x80173dc0,
		"setLang": 0x80173dc0,
		"TOptionControl::checkInput": 0x80179fe8,
		"checkInput": 0x80179fe8,
		"GC2D::SMSGetMSound": 0x8017a5f0,
		"SMSGetMSound": 0x8017a5f0,
		"@unnamed@::ArrayWrapper<unsigned_long><unsigned_long>::begin": 0x8017a5f8,
		"TOptionControl::changeTopMessage": 0x8017a600,
		"changeTopMessage": 0x8017a600,
		"TOptionSoundUnit::changeTexture": 0x8017c4ec,
		"TOptionLanguageUnit::setInfluencedAlphaRecursive": 0x8017d2f0,
		"TOptionLanguageUnit::setState": 0x8017d3dc,
		"TOptionLanguageUnit::update": 0x8017d700,
		"TOptionLanguageUnit::changeTexture": 0x8017d984,
		"TOptionLanguageUnit::replaceTexture": 0x8017dc34,
		"TOptionLanguageUnit::TOptionLanguageUnit": 0x8017dcf4,
		"TOptionSubtitleUnit::setInfluencedAlphaRecursive": 0x8017e01c,
		"TOptionSubtitleUnit::setState": 0x8017e108,
		"TOptionSubtitleUnit::update": 0x8017e42c,
		"TOptionSubtitleUnit::changeTexture": 0x8017e6b0,
		"TOptionSubtitleUnit::TOptionSubtitleUnit": 0x8017e9c8,
		"TOptionRumbleUnit::changeTexture": 0x8017f3ac,
		"TPaneScalingControl::update": 0x8017fd64,
		"TArrowControl::replaceTexture": 0x8017fef0,
		"@unnamed@::loadTexture": 0x8017ffa8,
		"loadTexture": 0x8017ffa8,
		"TItemNozzle::calcRootMatrix": 0x801b399c,
		"TJuiceBlock::touchActor": 0x801bb158,
		"TWatermelonStatic::touchWater": 0x801c7880,
		"TAmiKing::calc": 0x801cc22c,
		"System::evStartMontemanFanfare": 0x802816d0,
		"evStartMontemanFanfare": 0x802816d0,
		"System::evStartMontemanBGM": 0x8028176c,
		"evStartMontemanBGM": 0x8028176c,
		"System::SMSSetupGCLogoRenderMode": 0x8029d21c,
		"SMSSetupGCLogoRenderMode": 0x8029d21c,
		"System::load2DResource2Aram": 0x8029f18c,
		"load2DResource2Aram": 0x8029f18c,
		"System::SMSGetRealVSyncTimesPerSec": 0x8029fcf4,
		"SMSGetRealVSyncTimesPerSec": 0x8029fcf4,
		"TMarDirector::thpInit": 0x802ab4dc,
		"thpInit": 0x802ab4dc,
		"TEndingString::perform": 0x802af0ac,
		"TEndingString::TEndingString": 0x802af1ec,
		"TEndingString::~TEndingString": 0x802af2d4,
		"MSStageCubeFadeDouble::proc": 0x802b23c4,
		"MSStageCubeFade::setBgmVolumeForce": 0x802b275c,
		"setBgmVolumeForce": 0x802b275c,
		"MSMainProc::getGateKeeperBGMStopFlag": 0x802b44c8,
		"getGateKeeperBGMStopFlag": 0x802b44c8,
		"MSMainProc::setGateKeeperBGMPlayFlag": 0x802b4510,
		"setGateKeeperBGMPlayFlag": 0x802b4510,
		"JKRArchive::~JKRArchive": 0x802b4a80,
		"JKRArchive::findDirectory": 0x802b4ae4,
		"findDirectory": 0x802b4ae4,
		"JKRArchive::findTypeResource": 0x802b4ca4,
		"findTypeResource": 0x802b4ca4,
		"JKRArchive::findFsResource": 0x802b4d9c,
		"findFsResource": 0x802b4d9c,
		"JKRArchive::findIdxResource": 0x802b4ea0,
		"findIdxResource": 0x802b4ea0,
		"JKRArchive::findNameResource": 0x802b4ec8,
		"findNameResource": 0x802b4ec8,
		"JKRArchive::findPtrResource": 0x802b4f88,
		"findPtrResource": 0x802b4f88,
		"JKRAramArchive::JKRAramArchive": 0x802b512c,
		"JKRAramArchive::~JKRAramArchive": 0x802b51d8,
		"JKRFile::~JKRFile": 0x802b530c,
		"JKRAramArchive::open": 0x802b5370,
		"JKRAramHeap::JKRAramHeap": 0x802b5948,
		"JKRAramHeap::~JKRAramHeap": 0x802b5a2c,
		"JKRAramHeap::alloc": 0x802b5ad4,
		"JKRAramHeap::allocFromHead": 0x802b5b54,
		"JKRAramHeap::allocFromTail": 0x802b5be0,
		"JKRAramHeap::freeAll": 0x802b5c58,
		"JSystem::__sinit_JKRAramHeap_cpp": 0x802b5d1c,
		"__sinit_JKRAramHeap_cpp": 0x802b5d1c,
		"JSUList<JKRAramBlock>::~JSUList": 0x802b5d68,
		"JKRAram::create": 0x802b5dc0,
		"JKRAram::JKRAram": 0x802b5e50,
		"JKRAram::~JKRAram": 0x802b5f7c,
		"JKRAram::run": 0x802b600c,
		"JKRAram::mainRamToAram": 0x802b6074,
		"mainRamToAram": 0x802b6074,
		"JSystem::JKRDecompressFromAramToMainRam": 0x802b66e8,
		"JKRDecompressFromAramToMainRam": 0x802b66e8,
		"JSystem::__sinit_JKRAram_cpp": 0x802b6c08,
		"__sinit_JKRAram_cpp": 0x802b6c08,
		"JSUList<JKRAMCommand>::~JSUList": 0x802b6c54,
		"JKRArchive::check_mount_already": 0x802b6cac,
		"check_mount_already": 0x802b6cac,
		"JKRArchive::mount": 0x802b6d00,
		"mount": 0x802b6d00,
		"JKRArchive::becomeCurrent": 0x802b6ec4,
		"becomeCurrent": 0x802b6ec4,
		"JKRArchive::getDirEntry": 0x802b6f54,
		"getDirEntry": 0x802b6f54,
		"JKRArchive::getGlbResource": 0x802b6fcc,
		"JKRArchive::removeResourceAll": 0x802b72e8,
		"JKRArchive::removeResource": 0x802b7380,
		"JKRArchive::detachResource": 0x802b73e0,
		"detachResource": 0x802b73e0,
		"JKRArchive::getResSize": 0x802b741c,
		"JKRArchive::countFile": 0x802b7450,
		"countFile": 0x802b7450,
		"JKRArchive::getFirstFile": 0x802b74b0,
		"getFirstFile": 0x802b74b0,
		"JKRCompArchive::JKRCompArchive": 0x802b7558,
		"JKRCompArchive::~JKRCompArchive": 0x802b7600,
		"JKRCompArchive::open": 0x802b7734,
		"JKRCompArchive::removeResourceAll": 0x802b7f70,
		"JKRCompArchive::removeResource": 0x802b8014,
		"JKRDisposer::JKRDisposer": 0x802b8088,
		"JKRDisposer::~JKRDisposer": 0x802b8100,
		"JKRDvdArchive::JKRDvdArchive": 0x802b8184,
		"JKRDvdArchive::~JKRDvdArchive": 0x802b822c,
		"JKRDvdArchive::open": 0x802b8334,
		"JKRDvdFile::~JKRDvdFile": 0x802b8ba8,
		"JKRDvdFile::initiate": 0x802b8c48,
		"JKRDvdFile::close": 0x802b8da4,
		"close": 0x802b8da4,
		"JKRDvdFile::readData": 0x802b8e20,
		"JKRDvdFile::writeData": 0x802b8ee8,
		"JKRDvdFile::sync": 0x802b8ef0,
		"JKRDvdFile::doneProcess": 0x802b8f44,
		"doneProcess": 0x802b8f44,
		"JKRDvdFile::getFileSize": 0x802b8f74,
		"getFileSize": 0x802b8f74,
		"JSystem::__sinit_JKRDvdFile_cpp": 0x802b8f7c,
		"__sinit_JKRDvdFile_cpp": 0x802b8f7c,
		"JSUList<JKRDvdFile>::~JSUList": 0x802b8fc8,
		"JKRExpHeap::createRoot": 0x802b9020,
		"createRoot": 0x802b9020,
		"JKRExpHeap::destroy": 0x802b9228,
		"destroy": 0x802b9228,
		"JKRExpHeap::JKRExpHeap": 0x802b92b8,
		"JKRExpHeap::~JKRExpHeap": 0x802b935c,
		"JKRExpHeap::changeGroupID": 0x802b93c8,
		"JKRExpHeap::alloc": 0x802b9420,
		"JKRExpHeap::free": 0x802b9ba8,
		"JKRExpHeap::freeAll": 0x802b9c1c,
		"JKRExpHeap::freeTail": 0x802b9c98,
		"JKRExpHeap::resize": 0x802b9d28,
		"JKRExpHeap::getSize": 0x802b9ee8,
		"JKRExpHeap::getFreeSize": 0x802b9f70,
		"JKRExpHeap::getTotalFreeSize": 0x802b9fdc,
		"JKRExpHeap::getUsedSize": 0x802ba040,
		"getUsedSize": 0x802ba040,
		"JKRExpHeap::check": 0x802ba0bc,
		"JKRExpHeap::appendUsedList": 0x802ba2a0,
		"appendUsedList": 0x802ba2a0,
		"JKRExpHeap::setFreeBlock": 0x802ba338,
		"setFreeBlock": 0x802ba338,
		"JKRExpHeap::removeFreeBlock": 0x802ba384,
		"removeFreeBlock": 0x802ba384,
		"JKRExpHeap::recycleFreeBlock": 0x802ba3b8,
		"recycleFreeBlock": 0x802ba3b8,
		"JKRExpHeap::joinTwoBlocks": 0x802ba5a0,
		"joinTwoBlocks": 0x802ba5a0,
		"JKRExpHeap::dump": 0x802ba6a8,
		"JKRExpHeap::dump_sort": 0x802ba870,
		"JKRExpHeap::CMemBlock::initiate": 0x802baa68,
		"JKRExpHeap::CMemBlock::allocFore": 0x802baa88,
		"allocFore": 0x802baa88,
		"JKRExpHeap::CMemBlock::allocBack": 0x802baacc,
		"allocBack": 0x802baacc,
		"JKRExpHeap::CMemBlock::free": 0x802bab24,
		"JKRExpHeap::CMemBlock::getHeapBlock": 0x802bab84,
		"getHeapBlock": 0x802bab84,
		"JKRExpHeap::state_register": 0x802baba0,
		"JKRExpHeap::state_compare": 0x802bac64,
		"JKRExpHeap::getCurrentGroupId": 0x802bac94,
		"JKRExpHeap::getHeapType": 0x802bac9c,
		"JKRArcFinder::JKRArcFinder": 0x802baca8,
		"JKRArcFinder::findNextFile": 0x802bad44,
		"findNextFile": 0x802bad44,
		"JKRArcFinder::~JKRArcFinder": 0x802badfc,
		"JKRFileLoader::JKRFileLoader": 0x802bae58,
		"JKRFileLoader::~JKRFileLoader": 0x802baeb8,
		"JKRFileLoader::unmount": 0x802baf44,
		"JKRFileLoader::getVolume": 0x802baf94,
		"getVolume": 0x802baf94,
		"JKRFileLoader::changeDirectory": 0x802bb000,
		"changeDirectory": 0x802bb000,
		"JKRFileLoader::getResSize": 0x802bb128,
		"JKRFileLoader::findVolume": 0x802bb1b8,
		"findVolume": 0x802bb1b8,
		"JKRFileLoader::findFirstFile": 0x802bb244,
		"findFirstFile": 0x802bb244,
		"JKRFileLoader::fetchVolumeName": 0x802bb30c,
		"fetchVolumeName": 0x802bb30c,
		"JSystem::__sinit_JKRFileLoader_cpp": 0x802bb3f4,
		"__sinit_JKRFileLoader_cpp": 0x802bb3f4,
		"JSUList<JKRFileLoader>::~JSUList": 0x802bb440,
		"JKRHeap::JKRHeap": 0x802bb498,
		"JKRHeap::~JKRHeap": 0x802bb5b8,
		"JKRHeap::initArena": 0x802bb6d0,
		"initArena": 0x802bb6d0,
		"JKRHeap::becomeSystemHeap": 0x802bb7b4,
		"becomeSystemHeap": 0x802bb7b4,
		"JKRHeap::becomeCurrentHeap": 0x802bb7c4,
		"becomeCurrentHeap": 0x802bb7c4,
		"JKRHeap::alloc": 0x802bb7d4,
		"JKRHeap::free": 0x802bb84c,
		"JKRHeap::freeAll": 0x802bb8a4,
		"JKRHeap::findFromRoot": 0x802bb8f4,
		"findFromRoot": 0x802bb8f4,
		"JKRHeap::find": 0x802bb930,
		"find": 0x802bb930,
		"JKRHeap::dispose_subroutine": 0x802bba3c,
		"dispose_subroutine": 0x802bba3c,
		"JKRHeap::copyMemory": 0x802bbb78,
		"copyMemory": 0x802bbb78,
		"JSystem::JKRDefaultMemoryErrorRoutine": 0x802bbc04,
		"JKRDefaultMemoryErrorRoutine": 0x802bbc04,
		"JSystem::operator_delete": 0x802bbe38,
		"operator_delete": 0x802bbe38,
		"JSystem::operator_delete[]": 0x802bbe9c,
		"operator_delete[]": 0x802bbe9c,
		"JKRHeap::state_register": 0x802bbf00,
		"JKRHeap::state_compare": 0x802bbf04,
		"JKRHeap::state_dump": 0x802bbf1c,
		"state_dump": 0x802bbf1c,
		"JKRHeap::dump_sort": 0x802bbf20,
		"JKRHeap::changeGroupID": 0x802bbf28,
		"JKRHeap::getCurrentGroupId": 0x802bbf30,
		"JKRMemArchive::~JKRMemArchive": 0x802bc0d8,
		"JKRMemArchive::mountFixed": 0x802bc180,
		"mountFixed": 0x802bc180,
		"JKRMemArchive::unmountFixed": 0x802bc290,
		"unmountFixed": 0x802bc290,
		"JKRMemArchive::removeResourceAll": 0x802bc5fc,
		"JKRMemArchive::removeResource": 0x802bc64c,
		"JKRMemArchive::fetchResource_subroutine": 0x802bc688,
		"JKRSolidHeap::create": 0x802bc760,
		"JKRSolidHeap::JKRSolidHeap": 0x802bc7e0,
		"JKRSolidHeap::~JKRSolidHeap": 0x802bc83c,
		"JKRSolidHeap::alloc": 0x802bc8a8,
		"JKRSolidHeap::allocFromHead": 0x802bc958,
		"JKRSolidHeap::allocFromTail": 0x802bca3c,
		"JKRSolidHeap::free": 0x802bcb10,
		"JKRSolidHeap::freeAll": 0x802bcb3c,
		"JKRSolidHeap::freeTail": 0x802bcb9c,
		"JKRSolidHeap::resize": 0x802bcc28,
		"JKRSolidHeap::getSize": 0x802bcc58,
		"JKRSolidHeap::check": 0x802bcc88,
		"JKRSolidHeap::dump": 0x802bcd18,
		"JKRSolidHeap::state_register": 0x802bce38,
		"JKRSolidHeap::getTotalFreeSize": 0x802bcea0,
		"JKRSolidHeap::getFreeSize": 0x802bcecc,
		"JKRSolidHeap::state_compare": 0x802bced4,
		"JKRSolidHeap::getHeapType": 0x802bcf04,
		"JKRStdHeap::create": 0x802bcf10,
		"JKRStdHeap::JKRStdHeap": 0x802bcf90,
		"JKRStdHeap::~JKRStdHeap": 0x802bcfe4,
		"JKRStdHeap::alloc": 0x802bd060,
		"JKRStdHeap::free": 0x802bd110,
		"JKRStdHeap::freeAll": 0x802bd158,
		"JKRStdHeap::freeTail": 0x802bd1ac,
		"JKRStdHeap::resize": 0x802bd1d4,
		"JKRStdHeap::getFreeSize": 0x802bd204,
		"JKRStdHeap::state_register": 0x802bd230,
		"JKRStdHeap::state_compare": 0x802bd244,
		"JKRStdHeap::getSize": 0x802bd274,
		"JKRStdHeap::getTotalFreeSize": 0x802bd298,
		"JKRStdHeap::getHeapType": 0x802bd2c4,
		"JKRStdHeap::check": 0x802bd2d0,
		"JKRStdHeap::dump": 0x802bd300,
		"JKRThread::JKRThread": 0x802bd344,
		"JKRThread::~JKRThread": 0x802bd474,
		"JKRThread::start": 0x802bd54c,
		"JKRThread::run": 0x802bd578,
		"JSystem::__sinit_JKRThread_cpp": 0x802bd580,
		"__sinit_JKRThread_cpp": 0x802bd580,
		"JSUList<JKRThread>::~JSUList": 0x802bd5cc,
		"JSUOutputStream::~JSUOutputStream": 0x802bd624,
		"JSUOutputStream::write": 0x802bd680,
		"JSUOutputStream::skip": 0x802bd6d8,
		"JSURandomOutputStream::seek": 0x802bd764,
		"JSUInputStream::~JSUInputStream": 0x802bd7a8,
		"JSUInputStream::read": 0x802bd804,
		"JSUInputStream::skip": 0x802bda50,
		"JSURandomInputStream::align": 0x802bdad8,
		"align": 0x802bdad8,
		"JSURandomInputStream::skip": 0x802bdb68,
		"JSURandomInputStream::peek": 0x802bdbc4,
		"peek": 0x802bdbc4,
		"JSURandomInputStream::seek": 0x802bdc80,
		"JSUPtrLink::JSUPtrLink": 0x802bdcc4,
		"JSUPtrLink::~JSUPtrLink": 0x802bdcdc,
		"JSUPtrList::~JSUPtrList": 0x802bdd78,
		"JSUPtrList::initiate": 0x802bdde0,
		"JSUPtrList::append": 0x802bddf4,
		"JSUPtrList::prepend": 0x802bdeb0,
		"prepend": 0x802bdeb0,
		"JSUPtrList::insert": 0x802bdf6c,
		"JSUPtrList::remove": 0x802be148,
		"JSUMemoryInputStream::setBuffer": 0x802be1f8,
		"JSUMemoryInputStream::readData": 0x802be20c,
		"JSUMemoryInputStream::seekPos": 0x802be284,
		"JSUMemoryOutputStream::setBuffer": 0x802be300,
		"JSUMemoryOutputStream::writeData": 0x802be314,
		"JSUMemoryOutputStream::seekPos": 0x802be388,
		"JSUMemoryOutputStream::getLength": 0x802be404,
		"JSUMemoryOutputStream::getPosition": 0x802be40c,
		"JSUFileInputStream::JSUFileInputStream": 0x802be414,
		"JSUFileInputStream::readData": 0x802be458,
		"JSUFileInputStream::seekPos": 0x802be52c,
		"JSUFileInputStream::~JSUFileInputStream": 0x802be614,
		"JSUFileInputStream::getLength": 0x802be688,
		"JSUFileInputStream::getPosition": 0x802be6b8,
		"JUTException::create": 0x802be6c0,
		"JUTException::run": 0x802be724,
		"JUTException::JUTException": 0x802be7e4,
		"JUTException::errorHandler": 0x802be8c4,
		"errorHandler": 0x802be8c4,
		"JUTException::showFloat": 0x802be9b4,
		"showFloat": 0x802be9b4,
		"JSystem::__fpclassifyf": 0x802bedfc,
		"__fpclassifyf": 0x802bedfc,
		"JUTException::searchPartialModule": 0x802bee64,
		"searchPartialModule": 0x802bee64,
		"JSystem::search_name_part": 0x802bef24,
		"search_name_part": 0x802bef24,
		"JUTException::showStack": 0x802bef9c,
		"showStack": 0x802bef9c,
		"JUTException::showGPR": 0x802bf09c,
		"showGPR": 0x802bf09c,
		"JUTException::showMapInfo_subroutine": 0x802bf15c,
		"showMapInfo_subroutine": 0x802bf15c,
		"JUTException::showGPRMap": 0x802bf2bc,
		"showGPRMap": 0x802bf2bc,
		"JUTException::readPad": 0x802bf3ac,
		"readPad": 0x802bf3ac,
		"JUTException::printContext": 0x802bf598,
		"printContext": 0x802bf598,
		"JUTException::waitTime": 0x802bfa3c,
		"waitTime": 0x802bfa3c,
		"JUTException::createFB": 0x802bfac8,
		"createFB": 0x802bfac8,
		"JUTException::getFpscr": 0x802bfb90,
		"getFpscr": 0x802bfb90,
		"JUTException::setPreUserCallback": 0x802bfbb8,
		"setPreUserCallback": 0x802bfbb8,
		"JUTException::appendMapFile": 0x802bfbc8,
		"appendMapFile": 0x802bfbc8,
		"JUTException::queryMapAddress": 0x802bfc5c,
		"queryMapAddress": 0x802bfc5c,
		"JUTException::queryMapAddress_single": 0x802bfd54,
		"queryMapAddress_single": 0x802bfd54,
		"JUTException::createConsole": 0x802c00a0,
		"createConsole": 0x802c00a0,
		"JUTExternalFB::JUTExternalFB": 0x802c0180,
		"JUTException::~JUTException": 0x802c01a0,
		"JSystem::__sinit_JUTException_cpp": 0x802c0204,
		"__sinit_JUTException_cpp": 0x802c0204,
		"JSUList<JUTException::JUTExMapFile>::~JSUList": 0x802c0254,
		"JUTDirectPrint::start": 0x802c02ac,
		"JUTDirectPrint::JUTDirectPrint": 0x802c02fc,
		"JUTDirectPrint::erase": 0x802c0338,
		"JUTDirectPrint::drawChar": 0x802c042c,
		"drawChar": 0x802c042c,
		"JUTDirectPrint::changeFrameBuffer": 0x802c062c,
		"changeFrameBuffer": 0x802c062c,
		"JUTDirectPrint::drawString": 0x802c0660,
		"drawString": 0x802c0660,
		"JUTDirectPrint::drawString_f": 0x802c068c,
		"drawString_f": 0x802c068c,
		"JUTFont::JUTFont": 0x802c0814,
		"JUTFont::initiate": 0x802c0880,
		"JUTFont::setCharColor": 0x802c0884,
		"setCharColor": 0x802c0884,
		"JUTFont::setGradColor": 0x802c08a8,
		"setGradColor": 0x802c08a8,
		"JUTFont::drawString_size_scale": 0x802c08cc,
		"drawString_size_scale": 0x802c08cc,
		"JUTFont::~JUTFont": 0x802c09bc,
		"JUTFont::setGX": 0x802c0a08,
		"JUTGamePad::JUTGamePad": 0x802c0a34,
		"JUTGamePad::~JUTGamePad": 0x802c0b10,
		"JUTGamePad::initList": 0x802c0bbc,
		"initList": 0x802c0bbc,
		"JUTGamePad::init": 0x802c0bf8,
		"JUTGamePad::read": 0x802c0c30,
		"JUTGamePad::assign": 0x802c0f54,
		"assign": 0x802c0f54,
		"JUTGamePad::update": 0x802c1004,
		"JUTGamePad::checkResetSwitch": 0x802c11ec,
		"checkResetSwitch": 0x802c11ec,
		"JUTGamePad::clearForReset": 0x802c126c,
		"clearForReset": 0x802c126c,
		"JUTGamePad::CButton::clear": 0x802c1298,
		"JUTGamePad::CButton::update": 0x802c12d4,
		"JUTGamePad::CStick::clear": 0x802c1464,
		"JUTGamePad::CStick::update": 0x802c1480,
		"JUTGamePad::CStick::getButton": 0x802c161c,
		"getButton": 0x802c161c,
		"JUTGamePad::CRumble::clear": 0x802c16c8,
		"JUTGamePad::CRumble::stopMotor": 0x802c1734,
		"stopMotor": 0x802c1734,
		"JUTGamePad::CRumble::stopMotorHard": 0x802c1794,
		"stopMotorHard": 0x802c1794,
		"JUTGamePad::CRumble::update": 0x802c17f4,
		"JUTGamePad::CRumble::setEnable": 0x802c19c0,
		"setEnable": 0x802c19c0,
		"JUTGamePad::CButton::setRepeat": 0x802c1ac4,
		"setRepeat": 0x802c1ac4,
		"JUTGamePad::setButtonRepeat": 0x802c1ae0,
		"setButtonRepeat": 0x802c1ae0,
		"JUTGamePad::recalibrate": 0x802c1b2c,
		"recalibrate": 0x802c1b2c,
		"JUTGamePadRecord::read": 0x802c1be8,
		"JUTGamePadRecord::write": 0x802c1c94,
		"JUTGamePadRecord::streamDataToPadStatus": 0x802c1d50,
		"streamDataToPadStatus": 0x802c1d50,
		"JUTGamePadRecord::padStatusToStreamData": 0x802c1de8,
		"padStatusToStreamData": 0x802c1de8,
		"JSystem::__sinit_JUTGamePad_cpp": 0x802c1e80,
		"__sinit_JUTGamePad_cpp": 0x802c1e80,
		"JUTGamePad::CStick::CStick": 0x802c1f74,
		"JUTGamePad::CButton::CButton": 0x802c1f90,
		"JSUList<JUTGamePad>::~JSUList": 0x802c1fcc,
		"JUTNameTab::JUTNameTab": 0x802c2024,
		"JUTNameTab::getIndex": 0x802c2048,
		"JUTNameTab::getName": 0x802c20e4,
		"getName": 0x802c20e4,
		"JUTNameTab::calcKeyCode": 0x802c2114,
		"JUTPalette::storeTLUT": 0x802c2144,
		"storeTLUT": 0x802c2144,
		"JUTPalette::JUTPalette": 0x802c21dc,
		"JUTPalette::load": 0x802c222c,
		"JUTRect::set": 0x802c2274,
		"JUTRect::copy": 0x802c2288,
		"JUTRect::add": 0x802c22ac,
		"JUTRect::intersect": 0x802c22e0,
		"intersect": 0x802c22e0,
		"JUTRect::move": 0x802c2360,
		"JUTRect::resize": 0x802c239c,
		"JUTRect::reform": 0x802c23b8,
		"reform": 0x802c23b8,
		"JUTRect::normalize": 0x802c23ec,
		"JUTRect::isEmpty": 0x802c2420,
		"isEmpty": 0x802c2420,
		"JUTTexture::JUTTexture": 0x802c2580,
		"JUTTexture::~JUTTexture": 0x802c2664,
		"JUTTexture::storeTIMG": 0x802c26d4,
		"storeTIMG": 0x802c26d4,
		"JUTTexture::attachPalette": 0x802c285c,
		"attachPalette": 0x802c285c,
		"JUTTexture::load": 0x802c2ad0,
		"JSystem::JMANewSinTable": 0x802c2b20,
		"JMANewSinTable": 0x802c2b20,
		"JSystem::JMAEulerToQuat": 0x802c2ce0,
		"JMAEulerToQuat": 0x802c2ce0,
		"JSystem::JMAQuatLerp": 0x802c2d98,
		"JMAQuatLerp": 0x802c2d98,
		"JSystem::JMAHermiteInterpolation": 0x802c2e3c,
		"JMAHermiteInterpolation": 0x802c2e3c,
		"J2DPane::~J2DPane": 0x802c3688,
		"J2DPane::draw": 0x802c3768,
		"J2DGrafContext::~J2DGrafContext": 0x802c3b64,
		"J2DPane::clip": 0x802c3bb0,
		"clip": 0x802c3bb0,
		"J2DPane::search": 0x802c3bfc,
		"J2DPane::makeMatrix": 0x802c3c90,
		"makeMatrix": 0x802c3c90,
		"J2DPane::setCullBack": 0x802c3dfc,
		"setCullBack": 0x802c3dfc,
		"J2DPane::setBasePosition": 0x802c3ee8,
		"setBasePosition": 0x802c3ee8,
		"J2DPane::setConnectParent": 0x802c3fb0,
		"J2DPicture::J2DPicture": 0x802c3fc4,
		"J2DPicture::~J2DPicture": 0x802c4450,
		"J2DPicture::insert": 0x802c451c,
		"J2DPicture::remove": 0x802c4648,
		"J2DPicture::changeTexture": 0x802c4734,
		"J2DPicture::drawFullSet": 0x802c48cc,
		"drawFullSet": 0x802c48cc,
		"J2DPicture::draw": 0x802c4f88,
		"J2DPicture::drawTexCoord": 0x802c5380,
		"drawTexCoord": 0x802c5380,
		"J2DPicture::setTevMode": 0x802c5578,
		"J2DPicture::swap": 0x802c59cc,
		"swap": 0x802c59cc,
		"J2DPicture::setBlendKonstColor": 0x802c59e0,
		"setBlendKonstColor": 0x802c59e0,
		"J2DPicture::setBlendKonstAlpha": 0x802c5b18,
		"setBlendKonstAlpha": 0x802c5b18,
		"JSystem::J2DPrint_print_alpha_va": 0x802c5c50,
		"J2DPrint_print_alpha_va": 0x802c5c50,
		"J2DPrint::~J2DPrint": 0x802c5e04,
		"J2DPrint::initiate": 0x802c5e50,
		"J2DPrint::private_initiate": 0x802c5ed8,
		"private_initiate": 0x802c5ed8,
		"J2DPrint::setBuffer": 0x802c6060,
		"J2DPrint::setFontSize": 0x802c60cc,
		"setFontSize": 0x802c60cc,
		"J2DPrint::locate": 0x802c612c,
		"locate": 0x802c612c,
		"J2DPrint::getSize": 0x802c6328,
		"J2DPrint::getWidth": 0x802c643c,
		"J2DPrint::printReturn": 0x802c6548,
		"printReturn": 0x802c6548,
		"J2DPrint::parse": 0x802c67a4,
		"parse": 0x802c67a4,
		"J2DPrint::doCtrlCode": 0x802c6fe4,
		"doCtrlCode": 0x802c6fe4,
		"J2DPrint::doEscapeCode": 0x802c7158,
		"doEscapeCode": 0x802c7158,
		"J2DPrint::initchar": 0x802c7740,
		"initchar": 0x802c7740,
		"J2DPrint::getNumber": 0x802c7784,
		"getNumber": 0x802c7784,
		"J2DScreen::~J2DScreen": 0x802c788c,
		"J2DScreen::makeHiearachyPanes": 0x802c78f0,
		"makeHiearachyPanes": 0x802c78f0,
		"J2DScreen::stop": 0x802c7f14,
		"J2DScreen::draw": 0x802c7f50,
		"J2DScreen::search": 0x802c81f8,
		"J2DSetScreen::J2DSetScreen": 0x802c8228,
		"J2DScreen::drawSelf": 0x802c8370,
		"J2DSetScreen::~J2DSetScreen": 0x802c8428,
		"J2DTextBox::initiate": 0x802c8a8c,
		"J2DTextBox::~J2DTextBox": 0x802c8bbc,
		"J2DTextBox::setFont": 0x802c8c60,
		"setFont": 0x802c8c60,
		"J2DTextBox::draw": 0x802c8cd0,
		"J2DTextBox::getStringPtr": 0x802c8e08,
		"getStringPtr": 0x802c8e08,
		"J2DTextBox::setString": 0x802c8e10,
		"setString": 0x802c8e10,
		"J2DTextBox::setConnectParent": 0x802c8ee0,
		"J2DTextBox::resize": 0x802c90bc,
		"J2DWindow::J2DWindow": 0x802c916c,
		"J2DWindow::~J2DWindow": 0x802c9908,
		"J2DWindow::Texture::~Texture": 0x802c9a30,
		"J2DWindow::draw_private": 0x802c9a94,
		"draw_private": 0x802c9a94,
		"J2DWindow::resize": 0x802c9f50,
		"J2DWindow::drawContents": 0x802ca130,
		"drawContents": 0x802ca130,
		"J2DWindow::Texture::drawContentsTexture": 0x802ca5e4,
		"drawContentsTexture": 0x802ca5e4,
		"J2DWindow::Texture::setTevMode": 0x802ca7cc,
		"JSystem::J3DCalcZValue": 0x802cab9c,
		"J3DCalcZValue": 0x802cab9c,
		"JSystem::J3DPSCalcInverseTranspose": 0x802cabd4,
		"J3DPSCalcInverseTranspose": 0x802cabd4,
		"JSystem::J3DGetTextureMtx": 0x802cae08,
		"J3DGetTextureMtx": 0x802cae08,
		"JSystem::J3DGetTextureMtxOld": 0x802caee0,
		"J3DGetTextureMtxOld": 0x802caee0,
		"JSystem::J3DGetTextureMtxMaya": 0x802cafb8,
		"J3DGetTextureMtxMaya": 0x802cafb8,
		"JSystem::J3DGetTextureMtxMayaOld": 0x802cb108,
		"J3DGetTextureMtxMayaOld": 0x802cb108,
		"JSystem::J3DScaleNrmMtx33": 0x802cb258,
		"J3DScaleNrmMtx33": 0x802cb258,
		"JSystem::J3DMtxProjConcat": 0x802cb2ac,
		"J3DMtxProjConcat": 0x802cb2ac,
		"JSystem::J3DPSMtx33Copy": 0x802cb3d0,
		"J3DPSMtx33Copy": 0x802cb3d0,
		"JSystem::J3DPSMtx33CopyFrom34": 0x802cb3fc,
		"J3DPSMtx33CopyFrom34": 0x802cb3fc,
		"JSystem::J3DPSMtxArrayCopy": 0x802cb430,
		"J3DPSMtxArrayCopy": 0x802cb430,
		"JSystem::J3DMTXConcatArrayIndexedSrc": 0x802cb474,
		"J3DMTXConcatArrayIndexedSrc": 0x802cb474,
		"JSystem::J3DPSMtxArrayConcat": 0x802cb5ac,
		"J3DPSMtxArrayConcat": 0x802cb5ac,
		"J3DDeformData::deform": 0x802cb688,
		"J3DDeformData::setAnm": 0x802cb770,
		"J3DAnmCluster::getWeight": 0x802cb918,
		"J3DDeformer::normalize": 0x802cc070,
		"J3DDeformer::normalizeWeight": 0x802cc120,
		"normalizeWeight": 0x802cc120,
		"J3DSkinDeform::J3DSkinDeform": 0x802cc17c,
		"J3DSkinDeform::initMtxIndexArray": 0x802cc1a4,
		"initMtxIndexArray": 0x802cc1a4,
		"J3DSkinDeform::calcNrmMtx": 0x802cc580,
		"J3DSkinDeform::deform": 0x802cc6ac,
		"J3DAnmVtxColor::getColor": 0x802ccb50,
		"J3DSkinDeform::~J3DSkinDeform": 0x802ccb54,
		"J3DMtxCalcBasic::J3DMtxCalcBasic": 0x802ccc8c,
		"J3DNode::updateOut": 0x802cce90,
		"J3DNode::updateIn": 0x802cce94,
		"J3DNode::calcOut": 0x802cd054,
		"J3DNode::calcIn": 0x802cd058,
		"J3DNode::entryIn": 0x802cd0d8,
		"JSystem::J3DNewMtxCalcAnm": 0x802cd7fc,
		"J3DNewMtxCalcAnm": 0x802cd7fc,
		"J3DMtxCalcMaya::~J3DMtxCalcMaya": 0x802cda6c,
		"J3DJoint::initialize": 0x802cdafc,
		"J3DJoint::addMesh": 0x802cdbf0,
		"addMesh": 0x802cdbf0,
		"J3DJoint::updateIn": 0x802cdc10,
		"J3DJoint::updateOut": 0x802cde48,
		"J3DJoint::calcIn": 0x802cde6c,
		"J3DJoint::calcOut": 0x802cdeec,
		"J3DJoint::entryIn": 0x802cdf10,
		"J3DJoint::getType": 0x802ce0e8,
		"J3DJoint::~J3DJoint": 0x802ce0f4,
		"J3DNode::init": 0x802ce158,
		"J3DColorBlockLightOff::initialize": 0x802ce598,
		"J3DColorBlockLightOn::initialize": 0x802ce604,
		"J3DTevBlock2::initialize": 0x802ce6d8,
		"J3DTevBlock4::initialize": 0x802ce810,
		"J3DTevBlock16::initialize": 0x802ce998,
		"J3DMaterial::createColorBlock": 0x802cecbc,
		"createColorBlock": 0x802cecbc,
		"J3DColorChan::J3DColorChan": 0x802cee00,
		"JSystem::calcColorChanID": 0x802cee64,
		"calcColorChanID": 0x802cee64,
		"J3DGXColor::J3DGXColor": 0x802cefe0,
		"J3DColorBlock::~J3DColorBlock": 0x802cefe4,
		"J3DMaterial::createTexGenBlock": 0x802cf030,
		"createTexGenBlock": 0x802cf030,
		"J3DTexCoord::J3DTexCoord": 0x802cf100,
		"J3DTexGenBlock::~J3DTexGenBlock": 0x802cf120,
		"J3DMaterial::createTevBlock": 0x802cf16c,
		"createTevBlock": 0x802cf16c,
		"J3DTevSwapModeTable::J3DTevSwapModeTable": 0x802cf51c,
		"J3DGXColorS10::J3DGXColorS10": 0x802cf528,
		"J3DIndTevStage::J3DIndTevStage": 0x802cf52c,
		"J3DTevStage::J3DTevStage": 0x802cf57c,
		"J3DTevOrder::J3DTevOrder": 0x802cf6b0,
		"J3DTevBlock::~J3DTevBlock": 0x802cf6d0,
		"J3DMaterial::createIndBlock": 0x802cf71c,
		"createIndBlock": 0x802cf71c,
		"J3DIndTexCoordScale::~J3DIndTexCoordScale": 0x802cf814,
		"J3DIndTexCoordScale::J3DIndTexCoordScale": 0x802cf854,
		"J3DIndTexMtx::~J3DIndTexMtx": 0x802cf86c,
		"J3DIndTexMtx::J3DIndTexMtx": 0x802cf8ac,
		"J3DIndTexOrder::J3DIndTexOrder": 0x802cf8ec,
		"J3DIndBlock::~J3DIndBlock": 0x802cf904,
		"J3DMaterial::createPEBlock": 0x802cf950,
		"createPEBlock": 0x802cf950,
		"J3DPEBlock::~J3DPEBlock": 0x802cfa98,
		"J3DMaterial::initialize": 0x802cfae4,
		"J3DMaterial::addShape": 0x802cfb34,
		"addShape": 0x802cfb34,
		"J3DColorBlockLightOff::countDLSize": 0x802cfb3c,
		"J3DColorBlockLightOn::countDLSize": 0x802cfb44,
		"J3DTexGenBlockBasic::countDLSize": 0x802cfb4c,
		"J3DTevBlock1::countDLSize": 0x802cfb54,
		"J3DTevBlock2::countDLSize": 0x802cfb5c,
		"J3DTevBlock4::countDLSize": 0x802cfb64,
		"J3DTevBlock16::countDLSize": 0x802cfb6c,
		"J3DIndBlockFull::countDLSize": 0x802cfb74,
		"J3DPEBlockOpa::countDLSize": 0x802cfb7c,
		"J3DPEBlockTexEdge::countDLSize": 0x802cfb84,
		"J3DPEBlockXlu::countDLSize": 0x802cfb8c,
		"J3DPEBlockFull::countDLSize": 0x802cfb94,
		"J3DMaterial::countDLSize": 0x802cfb9c,
		"J3DColorBlockLightOff::load": 0x802cfc50,
		"J3DColorBlockLightOn::load": 0x802cfd48,
		"J3DTexGenBlockBasic::load": 0x802cfea4,
		"J3DTexGenBlockBasic::patch": 0x802cff5c,
		"patch": 0x802cff5c,
		"J3DTevBlock1::load": 0x802cfffc,
		"J3DTevBlock2::load": 0x802d01e8,
		"J3DTevBlock4::load": 0x802d06ec,
		"J3DTevBlock16::load": 0x802d0c24,
		"J3DIndBlockFull::load": 0x802d115c,
		"J3DPEBlockOpa::load": 0x802d134c,
		"J3DPEBlockTexEdge::load": 0x802d14c4,
		"J3DPEBlockXlu::load": 0x802d1638,
		"J3DPEBlockFull::load": 0x802d17b0,
		"JSystem::J3DGDWrite_u32": 0x802d18e8,
		"J3DGDWrite_u32": 0x802d18e8,
		"JSystem::__GDWrite": 0x802d1948,
		"__GDWrite": 0x802d1948,
		"JSystem::GDOverflowCheck": 0x802d1960,
		"J3DColorBlockLightOff::reset": 0x802d1998,
		"J3DColorBlockLightOn::reset": 0x802d1a6c,
		"J3DLightInfo::operator_=": 0x802d1c2c,
		"J3DTexGenBlockBasic::reset": 0x802d1cb0,
		"J3DTevBlock1::reset": 0x802d1e1c,
		"J3DTevBlock2::reset": 0x802d1f44,
		"J3DTevBlock4::reset": 0x802d22ac,
		"J3DTevBlock16::reset": 0x802d286c,
		"J3DIndBlockFull::reset": 0x802d2b18,
		"J3DIndTexMtxInfo::operator_=": 0x802d2c3c,
		"J3DPEBlockFull::reset": 0x802d2c78,
		"J3DPEBlock::getZCompLoc": 0x802d2ff0,
		"J3DPEBlock::getBlend": 0x802d2ff8,
		"J3DPEBlock::getAlphaComp": 0x802d3000,
		"J3DFogInfo::operator_=": 0x802d3008,
		"J3DMaterial::makeDisplayList": 0x802d30d0,
		"makeDisplayList": 0x802d30d0,
		"J3DMaterial::load": 0x802d3234,
		"J3DMaterial::safeMakeDisplayList": 0x802d32b8,
		"safeMakeDisplayList": 0x802d32b8,
		"J3DTexGenBlockBasic::calc": 0x802d341c,
		"J3DMaterial::calc": 0x802d36ac,
		"J3DMaterial::setCurrentMtx": 0x802d36dc,
		"setCurrentMtx": 0x802d36dc,
		"J3DMaterial::copy": 0x802d3808,
		"J3DPEBlock::reset": 0x802d38c8,
		"J3DIndBlock::reset": 0x802d38cc,
		"J3DTevBlock::reset": 0x802d38d0,
		"J3DTexGenBlock::reset": 0x802d38d4,
		"J3DColorBlock::reset": 0x802d38d8,
		"J3DMaterial::change": 0x802d38dc,
		"change": 0x802d38dc,
		"J3DMaterial::newSharedDisplayList": 0x802d3914,
		"newSharedDisplayList": 0x802d3914,
		"J3DPEBlockFull::getType": 0x802d398c,
		"J3DPEBlockFull::setFog": 0x802d3998,
		"J3DPEBlockFull::replaceFog": 0x802d39a0,
		"J3DPEBlockFull::getFog": 0x802d39b0,
		"J3DPEBlockFull::getAlphaComp": 0x802d39f0,
		"J3DPEBlockFull::getBlend": 0x802d3a40,
		"J3DPEBlockFull::getZMode": 0x802d3a60,
		"J3DPEBlockFull::getZCompLoc": 0x802d3a7c,
		"J3DPEBlockFull::getDither": 0x802d3a98,
		"J3DPEBlockFull::~J3DPEBlockFull": 0x802d3aa0,
		"J3DIndBlockFull::getType": 0x802d3afc,
		"J3DIndBlockFull::setIndTexStageNum": 0x802d3b08,
		"J3DIndBlockFull::getIndTexStageNum": 0x802d3b10,
		"J3DIndBlockFull::getIndTexOrder": 0x802d3b50,
		"J3DIndBlockFull::getIndTexMtx": 0x802d3bc4,
		"J3DIndBlockFull::getIndTexCoordScale": 0x802d3c10,
		"J3DIndBlockFull::~J3DIndBlockFull": 0x802d3c24,
		"J3DTevBlock16::getType": 0x802d3cc0,
		"J3DTevBlock16::getTexNo": 0x802d3cf0,
		"J3DTevBlock16::getTevOrder": 0x802d3d48,
		"J3DTevBlock16::getTevColor": 0x802d3d94,
		"J3DTevBlock16::getTevKColor": 0x802d3dd0,
		"J3DTevBlock16::getTevKColorSel": 0x802d3e00,
		"J3DTevBlock16::getTevKAlphaSel": 0x802d3e28,
		"J3DTevBlock16::getTevStageNum": 0x802d3e48,
		"J3DTevBlock16::getTevStage": 0x802d3ec8,
		"J3DTevBlock16::getTevSwapModeTable": 0x802d3f6c,
		"J3DTevBlock16::getIndTevStage": 0x802d4024,
		"J3DTevBlock16::~J3DTevBlock16": 0x802d4038,
		"J3DTevBlock4::getType": 0x802d4094,
		"J3DTevBlock4::getTexNo": 0x802d40c4,
		"J3DTevBlock4::getTevOrder": 0x802d411c,
		"J3DTevBlock4::getTevColor": 0x802d4168,
		"J3DTevBlock4::getTevKColor": 0x802d41a4,
		"J3DTevBlock4::getTevKColorSel": 0x802d41d4,
		"J3DTevBlock4::getTevKAlphaSel": 0x802d41fc,
		"J3DTevBlock4::getTevStageNum": 0x802d421c,
		"J3DTevBlock4::getTevStage": 0x802d429c,
		"J3DTevBlock4::getTevSwapModeTable": 0x802d4340,
		"J3DTevBlock4::getIndTevStage": 0x802d43f8,
		"J3DTevBlock4::~J3DTevBlock4": 0x802d440c,
		"J3DTevBlock2::getType": 0x802d4468,
		"J3DTevBlock2::getTexNo": 0x802d4498,
		"J3DTevBlock2::getTevOrder": 0x802d44f0,
		"J3DTevBlock2::getTevColor": 0x802d453c,
		"J3DTevBlock2::getTevKColor": 0x802d4578,
		"J3DTevBlock2::getTevKColorSel": 0x802d45a8,
		"J3DTevBlock2::getTevKAlphaSel": 0x802d45d0,
		"J3DTevBlock2::getTevStageNum": 0x802d45f0,
		"J3DTevBlock2::getTevStage": 0x802d4670,
		"J3DTevBlock2::getTevSwapModeTable": 0x802d4714,
		"J3DTevBlock2::getIndTevStage": 0x802d47cc,
		"J3DTevBlock2::~J3DTevBlock2": 0x802d47e0,
		"J3DTevBlock1::getType": 0x802d483c,
		"J3DTevBlock1::getTexNo": 0x802d486c,
		"J3DTevBlock1::getTevOrder": 0x802d48c4,
		"J3DTevBlock1::getTevColor": 0x802d48e0,
		"J3DTevBlock1::getTevKColor": 0x802d48f0,
		"J3DTevBlock1::getTevKColorSel": 0x802d4900,
		"J3DTevBlock1::getTevKAlphaSel": 0x802d4910,
		"J3DTevBlock1::getTevStageNum": 0x802d4920,
		"J3DTevBlock1::getTevStage": 0x802d49a0,
		"J3DTevBlock1::getTevSwapModeTable": 0x802d49c4,
		"J3DTevBlock1::getIndTevStage": 0x802d4a74,
		"J3DTevBlock1::~J3DTevBlock1": 0x802d4a88,
		"J3DTexGenBlockBasic::getType": 0x802d4ae4,
		"J3DTexGenBlockBasic::getTexGenNum": 0x802d4b04,
		"getTexGenNum": 0x802d4b04,
		"J3DTexGenBlockBasic::setTexCoord": 0x802d4b0c,
		"setTexCoord": 0x802d4b0c,
		"J3DTexGenBlockBasic::getTexCoord": 0x802d4b30,
		"getTexCoord": 0x802d4b30,
		"J3DTexGenBlockBasic::setTexMtx": 0x802d4b44,
		"setTexMtx": 0x802d4b44,
		"J3DTexGenBlockBasic::replaceTexMtx": 0x802d4b54,
		"replaceTexMtx": 0x802d4b54,
		"J3DTexGenBlockBasic::getTexMtx": 0x802d4b68,
		"getTexMtx": 0x802d4b68,
		"J3DTexGenBlockBasic::getNBTScale": 0x802d4bc0,
		"getNBTScale": 0x802d4bc0,
		"J3DTexGenBlockBasic::~J3DTexGenBlockBasic": 0x802d4bc8,
		"J3DColorBlockLightOn::getType": 0x802d4c24,
		"J3DColorBlockLightOn::getMatColor": 0x802d4c58,
		"J3DColorBlockLightOn::getAmbColor": 0x802d4c94,
		"J3DColorBlockLightOn::getColorChanNum": 0x802d4cbc,
		"J3DColorBlockLightOn::getColorChan": 0x802d4cec,
		"J3DColorBlockLightOn::setLight": 0x802d4d00,
		"J3DColorBlockLightOn::replaceLight": 0x802d4d10,
		"J3DColorBlockLightOn::getLight": 0x802d4d24,
		"J3DColorBlockLightOn::getCullMode": 0x802d4d48,
		"J3DColorBlockLightOn::~J3DColorBlockLightOn": 0x802d4d50,
		"J3DColorBlockLightOff::getType": 0x802d4dac,
		"J3DColorBlockLightOff::getMatColor": 0x802d4de0,
		"J3DColorBlockLightOff::getAmbColor": 0x802d4dfc,
		"J3DColorBlockLightOff::getColorChanNum": 0x802d4e18,
		"J3DColorBlockLightOff::getColorChan": 0x802d4e48,
		"J3DColorBlockLightOff::setLight": 0x802d4e5c,
		"J3DColorBlockLightOff::replaceLight": 0x802d4e60,
		"J3DColorBlockLightOff::getLight": 0x802d4e68,
		"J3DColorBlockLightOff::getCullMode": 0x802d4e84,
		"J3DColorBlockLightOff::~J3DColorBlockLightOff": 0x802d4e8c,
		"J3DPEBlockXlu::getType": 0x802d4ee8,
		"J3DPEBlockXlu::~J3DPEBlockXlu": 0x802d4ef4,
		"J3DPEBlock::setFog": 0x802d4f50,
		"J3DPEBlock::replaceFog": 0x802d4f54,
		"J3DPEBlock::getDither": 0x802d4f84,
		"J3DPEBlockTexEdge::getType": 0x802d4f8c,
		"J3DPEBlockTexEdge::~J3DPEBlockTexEdge": 0x802d4f98,
		"J3DPEBlockOpa::getType": 0x802d4ff4,
		"J3DPEBlockOpa::~J3DPEBlockOpa": 0x802d5000,
		"J3DIndBlockNull::reset": 0x802d505c,
		"J3DIndBlockNull::countDLSize": 0x802d5060,
		"J3DIndBlockNull::getType": 0x802d5068,
		"J3DIndBlockNull::setIndTexStageNum": 0x802d5074,
		"J3DIndBlockNull::getIndTexStageNum": 0x802d5078,
		"J3DIndBlockNull::getIndTexOrder": 0x802d5088,
		"J3DIndBlockNull::getIndTexMtx": 0x802d5098,
		"J3DIndBlockNull::getIndTexCoordScale": 0x802d50a8,
		"J3DIndBlockNull::~J3DIndBlockNull": 0x802d50b0,
		"J3DIndBlockNull::load": 0x802d510c,
		"J3DModelData::clear": 0x802d5110,
		"J3DModelData::J3DModelData": 0x802d5184,
		"J3DModelData::~J3DModelData": 0x802d51d8,
		"J3DModelData::makeHierarchy": 0x802d5248,
		"J3DNode::getType": 0x802d53f4,
		"J3DModelData::isDeformableVertexFormat": 0x802d5400,
		"isDeformableVertexFormat": 0x802d5400,
		"J3DModelData::setMaterialTable": 0x802d5484,
		"setMaterialTable": 0x802d5484,
		"J3DModelData::entryMatColorAnimator": 0x802d553c,
		"entryMatColorAnimator": 0x802d553c,
		"J3DModelData::entryTexMtxAnimator": 0x802d55f0,
		"entryTexMtxAnimator": 0x802d55f0,
		"J3DModelData::entryTevRegAnimator": 0x802d57c4,
		"entryTevRegAnimator": 0x802d57c4,
		"J3DModelData::removeMatColorAnimator": 0x802d5930,
		"removeMatColorAnimator": 0x802d5930,
		"J3DModelData::removeTexNoAnimator": 0x802d59a8,
		"removeTexNoAnimator": 0x802d59a8,
		"J3DModelData::removeTexMtxAnimator": 0x802d5a3c,
		"removeTexMtxAnimator": 0x802d5a3c,
		"J3DModelData::removeTevRegAnimator": 0x802d5ae0,
		"removeTevRegAnimator": 0x802d5ae0,
		"J3DModelData::setMatColorAnimator": 0x802d5bfc,
		"setMatColorAnimator": 0x802d5bfc,
		"J3DModelData::setTexNoAnimator": 0x802d5c7c,
		"setTexNoAnimator": 0x802d5c7c,
		"J3DModelData::setTexMtxAnimator": 0x802d5d24,
		"setTexMtxAnimator": 0x802d5d24,
		"J3DModelData::setTevRegAnimator": 0x802d5e5c,
		"setTevRegAnimator": 0x802d5e5c,
		"J3DModel::~J3DModel": 0x802d6048,
		"J3DModel::initialize": 0x802d6094,
		"J3DModel::entryModelData": 0x802d6138,
		"entryModelData": 0x802d6138,
		"J3DModel::lock": 0x802d6618,
		"lock": 0x802d6618,
		"J3DModel::unlock": 0x802d6748,
		"unlock": 0x802d6748,
		"J3DModel::makeDL": 0x802d6878,
		"J3DModel::setSkinDeform": 0x802d6910,
		"setSkinDeform": 0x802d6910,
		"J3DModel::calcWeightEnvelopeMtx": 0x802d698c,
		"calcWeightEnvelopeMtx": 0x802d698c,
		"J3DModel::update": 0x802d6b68,
		"J3DModel::calc": 0x802d6d6c,
		"J3DModel::entry": 0x802d6f70,
		"J3DModel::viewCalc": 0x802d7060,
		"J3DModel::calcNrmMtx": 0x802d7298,
		"J3DModel::calcBumpMtx": 0x802d73f0,
		"calcBumpMtx": 0x802d73f0,
		"J3DModel::calcBBoard": 0x802d74e4,
		"calcBBoard": 0x802d74e4,
		"J3DModel::prepareShapePackets": 0x802d79ec,
		"prepareShapePackets": 0x802d79ec,
		"J3DNode::J3DNode": 0x802d7bb0,
		"J3DNode::~J3DNode": 0x802d7bd4,
		"J3DNode::appendChild": 0x802d7c20,
		"appendChild": 0x802d7c20,
		"J3DShapeMtx::loadMtxIndx_PNGP": 0x802d7c54,
		"loadMtxIndx_PNGP": 0x802d7c54,
		"J3DShapeMtx::loadMtxIndx_PCPU": 0x802d7cb0,
		"loadMtxIndx_PCPU": 0x802d7cb0,
		"J3DShapeMtx::loadMtxIndx_NCPU": 0x802d7d10,
		"loadMtxIndx_NCPU": 0x802d7d10,
		"J3DShapeMtx::loadMtxIndx_PNCPU": 0x802d7d5c,
		"loadMtxIndx_PNCPU": 0x802d7d5c,
		"J3DShapeMtx::load": 0x802d7dac,
		"J3DShapeMtx::calcNBTScale": 0x802d7e08,
		"J3DShapeMtx::~J3DShapeMtx": 0x802d7e70,
		"J3DShapeMtxDL::load": 0x802d7ebc,
		"J3DShapeMtxMulti::load": 0x802d7ee4,
		"J3DShapeMtxMulti::calcNBTScale": 0x802d7f8c,
		"J3DShapeDraw::J3DShapeDraw": 0x802d8018,
		"J3DShapeDraw::draw": 0x802d8030,
		"J3DShape::initialize": 0x802d805c,
		"J3DShape::calcNBTScale": 0x802d80c8,
		"J3DShape::countBumpMtxNum": 0x802d8140,
		"countBumpMtxNum": 0x802d8140,
		"J3DShape::makeVtxArrayCmd": 0x802d81bc,
		"makeVtxArrayCmd": 0x802d81bc,
		"J3DShape::makeVcdVatCmd": 0x802d8454,
		"makeVcdVatCmd": 0x802d8454,
		"J3DShape::loadVtxArray": 0x802d84c8,
		"loadVtxArray": 0x802d84c8,
		"J3DShape::draw": 0x802d8538,
		"J3DShapeDraw::~J3DShapeDraw": 0x802d86a0,
		"J3DShapeMtxMulti::~J3DShapeMtxMulti": 0x802d86ec,
		"J3DShapeMtxMulti::getType": 0x802d8748,
		"J3DShapeMtxMulti::getUseMtxNum": 0x802d8754,
		"J3DShapeMtxMulti::getUseMtxIndex": 0x802d875c,
		"J3DShapeMtxDL::~J3DShapeMtxDL": 0x802d876c,
		"J3DShapeMtxDL::calcNBTScale": 0x802d87c8,
		"J3DShapeMtx::getType": 0x802d87cc,
		"JSystem::__sinit_J3DShape_cpp": 0x802d87d8,
		"__sinit_J3DShape_cpp": 0x802d87d8,
		"J3DSys::J3DSys": 0x802d8844,
		"J3DSys::loadPosMtxIndx": 0x802d8960,
		"loadPosMtxIndx": 0x802d8960,
		"J3DSys::loadNrmMtxIndx": 0x802d8988,
		"loadNrmMtxIndx": 0x802d8988,
		"J3DSys::setTexCacheRegion": 0x802d89b0,
		"setTexCacheRegion": 0x802d89b0,
		"J3DSys::drawInit": 0x802d8b70,
		"drawInit": 0x802d8b70,
		"J3DSys::reinitTexture": 0x802d923c,
		"reinitTexture": 0x802d923c,
		"JSystem::__sinit_J3DSys_cpp": 0x802d92e0,
		"__sinit_J3DSys_cpp": 0x802d92e0,
		"J3DFrameCtrl::init": 0x802d9308,
		"J3DFrameCtrl::checkPass": 0x802d9338,
		"checkPass": 0x802d9338,
		"J3DFrameCtrl::update": 0x802d98d8,
		"J3DAnmBase::~J3DAnmBase": 0x802d9d50,
		"J3DAnmTransformFull::getTransform": 0x802d9d9c,
		"JSystem::J3DHermiteInterpolationS": 0x802da490,
		"J3DHermiteInterpolationS": 0x802da490,
		"JSystem::J3DGetKeyFrameInterpolationS": 0x802da4e4,
		"J3DGetKeyFrameInterpolationS": 0x802da4e4,
		"J3DAnmTransformKey::calcTransform": 0x802da714,
		"J3DAnmTextureSRTKey::calcTransform": 0x802dac00,
		"J3DAnmClusterFull::getWeight": 0x802daec4,
		"J3DAnmClusterKey::getWeight": 0x802daf9c,
		"J3DAnmVtxColorFull::getColor": 0x802db020,
		"J3DAnmVtxColorKey::getColor": 0x802db378,
		"J3DAnmColor::searchUpdateMaterialID": 0x802db6d4,
		"J3DAnmColorFull::getColor": 0x802db764,
		"J3DAnmColorKey::getColor": 0x802dbab4,
		"J3DAnmTexPattern::getTexNo": 0x802dbe00,
		"J3DAnmTexPattern::searchUpdateMaterialID": 0x802dbeec,
		"J3DAnmTextureSRTKey::searchUpdateMaterialID": 0x802dbf7c,
		"J3DAnmTevRegKey::getTevColorReg": 0x802dc0a0,
		"getTevColorReg": 0x802dc0a0,
		"J3DAnmTevRegKey::getTevKonstReg": 0x802dc3ec,
		"getTevKonstReg": 0x802dc3ec,
		"J3DAnmTevRegKey::searchUpdateMaterialID": 0x802dc738,
		"J3DAnmColorKey::~J3DAnmColorKey": 0x802dc82c,
		"J3DAnmColor::getColor": 0x802dc898,
		"J3DAnmColor::~J3DAnmColor": 0x802dc89c,
		"J3DAnmColorFull::~J3DAnmColorFull": 0x802dc8f8,
		"J3DAnmVtxColorKey::~J3DAnmVtxColorKey": 0x802dc964,
		"J3DAnmVtxColor::~J3DAnmVtxColor": 0x802dc9d0,
		"J3DAnmVtxColorFull::~J3DAnmVtxColorFull": 0x802dca2c,
		"J3DAnmClusterKey::~J3DAnmClusterKey": 0x802dca98,
		"J3DAnmCluster::~J3DAnmCluster": 0x802dcb04,
		"J3DAnmClusterFull::~J3DAnmClusterFull": 0x802dcb60,
		"J3DAnmTransformKey::~J3DAnmTransformKey": 0x802dcbcc,
		"J3DAnmTransform::~J3DAnmTransform": 0x802dcc38,
		"J3DAnmTransformFull::~J3DAnmTransformFull": 0x802dcc94,
		"J3DJointFactory::J3DJointFactory": 0x802dd1c8,
		"J3DJointFactory::create": 0x802dd220,
		"J3DMaterialFactory::J3DMaterialFactory": 0x802dd3f4,
		"J3DMaterialFactory::countUniqueMaterials": 0x802dd628,
		"J3DMaterialFactory::countStages": 0x802dd664,
		"J3DMaterialFactory::create": 0x802dd748,
		"J3DMaterialFactory::newMatColor": 0x802de06c,
		"J3DMaterialFactory::newColorChanNum": 0x802de0fc,
		"J3DMaterialFactory::newColorChan": 0x802de134,
		"J3DMaterialFactory::newAmbColor": 0x802de1fc,
		"newAmbColor": 0x802de1fc,
		"J3DMaterialFactory::newTexGenNum": 0x802de28c,
		"J3DMaterialFactory::newTexCoord": 0x802de2c4,
		"J3DMaterialFactory::newTexMtx": 0x802de338,
		"J3DMaterialFactory::newCullMode": 0x802de3cc,
		"J3DMaterialFactory::newTexNo": 0x802de40c,
		"J3DMaterialFactory::newTevOrder": 0x802de454,
		"J3DMaterialFactory::newTevColor": 0x802de4c8,
		"J3DMaterialFactory::newTevKColor": 0x802de560,
		"J3DMaterialFactory::newTevStageNum": 0x802de5f0,
		"J3DMaterialFactory::newTevStage": 0x802de628,
		"J3DMaterialFactory::newTevSwapModeTable": 0x802de894,
		"J3DMaterialFactory::newIndTexStageNum": 0x802de930,
		"newIndTexStageNum": 0x802de930,
		"J3DMaterialFactory::newIndTexOrder": 0x802de958,
		"newIndTexOrder": 0x802de958,
		"J3DMaterialFactory::newIndTexMtx": 0x802de9b8,
		"newIndTexMtx": 0x802de9b8,
		"J3DMaterialFactory::newIndTevStage": 0x802dea80,
		"newIndTevStage": 0x802dea80,
		"J3DMaterialFactory::newIndTexCoordScale": 0x802deb64,
		"newIndTexCoordScale": 0x802deb64,
		"J3DMaterialFactory::newFog": 0x802debc4,
		"J3DMaterialFactory::newAlphaComp": 0x802dec50,
		"J3DMaterialFactory::newBlend": 0x802decd0,
		"J3DMaterialFactory::newZMode": 0x802ded4c,
		"J3DMaterialFactory::newZCompLoc": 0x802dedb0,
		"J3DMaterialFactory::newDither": 0x802dede8,
		"J3DMaterialFactory::newNBTScale": 0x802dee20,
		"J3DModelLoaderDataBase::load": 0x802df0a8,
		"J3DModelLoader_v26::~J3DModelLoader_v26": 0x802df1cc,
		"J3DModelLoader_v21::~J3DModelLoader_v21": 0x802df228,
		"J3DModelLoader::~J3DModelLoader": 0x802df284,
		"J3DModelLoaderDataBase::loadMaterialTable": 0x802df2d0,
		"J3DModelLoader::load": 0x802df3f0,
		"J3DModelLoader::readMaterial_v21": 0x802df614,
		"J3DModelLoader::readMaterial": 0x802df618,
		"J3DModelLoader::loadMaterialTable": 0x802df61c,
		"J3DModelLoader::readMaterialTable_v21": 0x802df760,
		"J3DModelLoader::readMaterialTable": 0x802df764,
		"J3DModelLoader::setupBBoardInfo": 0x802df768,
		"setupBBoardInfo": 0x802df768,
		"J3DModelLoader::readInformation": 0x802df8b4,
		"readInformation": 0x802df8b4,
		"J3DModelLoader::readVertex": 0x802dfa78,
		"readVertex": 0x802dfa78,
		"J3DModelLoader::readEnvelop": 0x802dfc74,
		"readEnvelop": 0x802dfc74,
		"J3DModelLoader::readDraw": 0x802dfd04,
		"readDraw": 0x802dfd04,
		"J3DModelLoader::readJoint": 0x802dfd98,
		"readJoint": 0x802dfd98,
		"J3DModelLoader_v26::readMaterial": 0x802dfe88,
		"J3DMaterial::~J3DMaterial": 0x802e00e0,
		"J3DMaterial::J3DMaterial": 0x802e0120,
		"J3DModelLoader_v21::readMaterial_v21": 0x802e0150,
		"J3DModelLoader::readShape": 0x802e03a8,
		"readShape": 0x802e03a8,
		"J3DModelLoader::readTexture": 0x802e04f0,
		"readTexture": 0x802e04f0,
		"J3DModelLoader_v26::readMaterialTable": 0x802e05a8,
		"J3DModelLoader_v21::readMaterialTable_v21": 0x802e06ec,
		"J3DModelLoader::readTextureTable": 0x802e0830,
		"readTextureTable": 0x802e0830,
		"J3DTexture::~J3DTexture": 0x802e08e8,
		"J3DShapeFactory::J3DShapeFactory": 0x802e09c4,
		"J3DShapeFactory::create": 0x802e0a74,
		"J3DShapeFactory::newShapeMtx": 0x802e0c2c,
		"newShapeMtx": 0x802e0c2c,
		"J3DShapeFactory::newShapeDraw": 0x802e0d20,
		"newShapeDraw": 0x802e0d20,
		"J3DShapeFactory::allocVcdVatCmdBuffer": 0x802e0db4,
		"allocVcdVatCmdBuffer": 0x802e0db4,
		"J3DAnmLoaderDataBase::load": 0x802e0e4c,
		"J3DAnmVtxColor::J3DAnmVtxColor": 0x802e154c,
		"J3DAnmColor::J3DAnmColor": 0x802e15a4,
		"J3DAnmFullLoader_v15::J3DAnmFullLoader_v15": 0x802e1608,
		"J3DAnmLoader::~J3DAnmLoader": 0x802e1624,
		"J3DAnmFullLoader_v15::~J3DAnmFullLoader_v15": 0x802e1670,
		"J3DAnmKeyLoader_v15::J3DAnmKeyLoader_v15": 0x802e16cc,
		"J3DAnmKeyLoader_v15::~J3DAnmKeyLoader_v15": 0x802e16e8,
		"J3DAnmFullLoader_v15::load": 0x802e1744,
		"J3DAnmFullLoader_v15::readAnmTransform": 0x802e1870,
		"J3DAnmFullLoader_v15::readAnmColor": 0x802e1904,
		"J3DAnmFullLoader_v15::readAnmTexPattern": 0x802e19ec,
		"readAnmTexPattern": 0x802e19ec,
		"J3DAnmFullLoader_v15::readAnmVisibility": 0x802e1aac,
		"readAnmVisibility": 0x802e1aac,
		"J3DAnmFullLoader_v15::readAnmCluster": 0x802e1b28,
		"J3DAnmFullLoader_v15::readAnmVtxColor": 0x802e1b94,
		"J3DAnmKeyLoader_v15::load": 0x802e1d0c,
		"J3DAnmKeyLoader_v15::readAnmTransform": 0x802e1e38,
		"J3DAnmKeyLoader_v15::readAnmTextureSRT": 0x802e1ed4,
		"readAnmTextureSRT": 0x802e1ed4,
		"J3DAnmKeyLoader_v15::readAnmColor": 0x802e20d0,
		"J3DAnmKeyLoader_v15::readAnmCluster": 0x802e21d8,
		"J3DAnmKeyLoader_v15::readAnmTevReg": 0x802e2244,
		"readAnmTevReg": 0x802e2244,
		"J3DAnmKeyLoader_v15::readAnmVtxColor": 0x802e2400,
		"J3DAnmVisibilityFull::~J3DAnmVisibilityFull": 0x802e2578,
		"J3DAnmTexPattern::~J3DAnmTexPattern": 0x802e25dc,
		"J3DAnmTevRegKey::~J3DAnmTevRegKey": 0x802e2640,
		"J3DAnmTextureSRTKey::~J3DAnmTextureSRTKey": 0x802e26a4,
		"JGadget::TList_pointer_void::TList_pointer_void": 0x802e2840,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::erase": 0x802e2860,
		"JGadget::TList_pointer_void::~TList_pointer_void": 0x802e28cc,
		"JGadget::TList_pointer_void::insert": 0x802e29a8,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::CreateNode_": 0x802e2a30,
		"CreateNode_": 0x802e2a30,
		"JSystem::JKRDecompressFromDVD": 0x802e2fe8,
		"JKRDecompressFromDVD": 0x802e2fe8,
		"JKRDvdRipper::isErrorRetry": 0x802e355c,
		"isErrorRetry": 0x802e355c,
		"JSystem::__sinit_JKRDvdRipper_cpp": 0x802e3564,
		"__sinit_JKRDvdRipper_cpp": 0x802e3564,
		"JSUList<JKRDMCommand>::~JSUList": 0x802e35b0,
		"J2DGrafContext::setPort": 0x802e3798,
		"J2DGrafContext::setup2D": 0x802e3864,
		"setup2D": 0x802e3864,
		"J2DGrafContext::setScissor": 0x802e3a10,
		"setScissor": 0x802e3a10,
		"J2DGrafContext::scissor": 0x802e3ac8,
		"scissor": 0x802e3ac8,
		"J2DGrafContext::setColor": 0x802e3b30,
		"J2DGrafContext::setLineWidth": 0x802e3bec,
		"setLineWidth": 0x802e3bec,
		"J2DGrafContext::fillBox": 0x802e3c18,
		"fillBox": 0x802e3c18,
		"J2DGrafContext::setLookat": 0x802e3d44,
		"JKRDvdAramRipper::loadToAram_Async": 0x802e3eec,
		"loadToAram_Async": 0x802e3eec,
		"JKRDvdAramRipper::callCommand_Async": 0x802e3f98,
		"callCommand_Async": 0x802e3f98,
		"JKRDvdAramRipper::syncAram": 0x802e42c4,
		"syncAram": 0x802e42c4,
		"JKRADCommand::JKRADCommand": 0x802e4394,
		"JKRADCommand::~JKRADCommand": 0x802e43d0,
		"JSystem::JKRDecompressFromDVDToAram": 0x802e445c,
		"JKRDecompressFromDVDToAram": 0x802e445c,
		"JSystem::dmaBufferFlush": 0x802e49bc,
		"dmaBufferFlush": 0x802e49bc,
		"JSystem::__sinit_JKRDvdAramRipper_cpp": 0x802e4a24,
		"__sinit_JKRDvdAramRipper_cpp": 0x802e4a24,
		"JSUList<JKRADCommand>::~JSUList": 0x802e4a70,
		"JKRDecomp::create": 0x802e4ac8,
		"JKRDecomp::JKRDecomp": 0x802e4b24,
		"JKRDecomp::~JKRDecomp": 0x802e4b7c,
		"JKRDecomp::run": 0x802e4be0,
		"JKRDecomp::sendCommand": 0x802e4ca0,
		"JKRDecomp::orderSync": 0x802e4cd0,
		"JKRDecomp::decode": 0x802e4d78,
		"decode": 0x802e4d78,
		"JKRDecomp::decodeSZP": 0x802e4e04,
		"decodeSZP": 0x802e4e04,
		"JKRDecomp::decodeSZS": 0x802e4fb0,
		"decodeSZS": 0x802e4fb0,
		"JKRDecomp::checkCompressed": 0x802e5094,
		"checkCompressed": 0x802e5094,
		"JKRDecompCommand::JKRDecompCommand": 0x802e50e4,
		"JKRDecompCommand::~JKRDecompCommand": 0x802e5134,
		"J2DOrthoGraph::setPort": 0x802e5328,
		"J2DOrthoGraph::setLookat": 0x802e53e0,
		"J2DOrthoGraph::scissorBounds": 0x802e541c,
		"scissorBounds": 0x802e541c,
		"J3DVertexData::J3DVertexData": 0x802e57bc,
		"J3DVertexData::~J3DVertexData": 0x802e5808,
		"J3DVertexBuffer::J3DVertexBuffer": 0x802e5848,
		"J3DVertexBuffer::~J3DVertexBuffer": 0x802e58b4,
		"J3DVertexBuffer::copyTransformedVtxArray": 0x802e5900,
		"copyTransformedVtxArray": 0x802e5900,
		"J3DDrawMtxData::J3DDrawMtxData": 0x802e59d0,
		"J3DDrawMtxData::~J3DDrawMtxData": 0x802e59e4,
		"J3DDisplayListObj::newDisplayList": 0x802e5a24,
		"newDisplayList": 0x802e5a24,
		"J3DDisplayListObj::callDL": 0x802e5a80,
		"callDL": 0x802e5a80,
		"J3DPacket::isSame": 0x802e5aac,
		"J3DPacket::entry": 0x802e5ab4,
		"J3DPacket::addChildPacket": 0x802e5abc,
		"addChildPacket": 0x802e5abc,
		"J3DCallBackPacket::draw": 0x802e5adc,
		"J3DPacket::draw": 0x802e5b6c,
		"J3DPacket::~J3DPacket": 0x802e5b70,
		"J3DDrawPacket::~J3DDrawPacket": 0x802e5bbc,
		"J3DDrawPacket::draw": 0x802e5c18,
		"J3DDrawPacket::beginDL": 0x802e5c44,
		"beginDL": 0x802e5c44,
		"J3DDrawPacket::endDL": 0x802e5ca4,
		"endDL": 0x802e5ca4,
		"J3DMatPacket::J3DMatPacket": 0x802e5d00,
		"J3DMatPacket::~J3DMatPacket": 0x802e5d54,
		"J3DMatPacket::addShapePacket": 0x802e5dc0,
		"addShapePacket": 0x802e5dc0,
		"J3DMatPacket::draw": 0x802e5de0,
		"J3DShapePacket::J3DShapePacket": 0x802e5e80,
		"J3DCallBackPacket::~J3DCallBackPacket": 0x802e5ee4,
		"J3DShapePacket::~J3DShapePacket": 0x802e5f40,
		"J3DShapePacket::draw": 0x802e5fac,
		"J3DMatPacket::isSame": 0x802e6070,
		"JSystem::J3DLoadArrayBasePtr": 0x802e6094,
		"J3DLoadArrayBasePtr": 0x802e6094,
		"JSystem::J3DSetVtxAttrFmtv": 0x802e60c8,
		"J3DSetVtxAttrFmtv": 0x802e60c8,
		"JSystem::loadCullMode": 0x802e6654,
		"loadCullMode": 0x802e6654,
		"J3DLightObj::load": 0x802e6658,
		"J3DTexMtx::calc": 0x802e66ec,
		"J3DTexMtx::load": 0x802e6b7c,
		"JSystem::loadTexNo": 0x802e6bac,
		"loadTexNo": 0x802e6bac,
		"JSystem::loadDither": 0x802e6ef4,
		"loadDither": 0x802e6ef4,
		"JSystem::loadNBTScale": 0x802e6ef8,
		"loadNBTScale": 0x802e6ef8,
		"JSystem::makeTexCoordTable": 0x802e6f2c,
		"makeTexCoordTable": 0x802e6f2c,
		"JSystem::makeAlphaCmpTable": 0x802e7118,
		"makeAlphaCmpTable": 0x802e7118,
		"JSystem::makeZModeTable": 0x802e74c0,
		"makeZModeTable": 0x802e74c0,
		"JSystem::makeTevSwapTable": 0x802e75f8,
		"makeTevSwapTable": 0x802e75f8,
		"J3DDrawBuffer::J3DDrawBuffer": 0x802e776c,
		"J3DDrawBuffer::frameInit": 0x802e7814,
		"frameInit": 0x802e7814,
		"J3DDrawBuffer::entryMatSort": 0x802e784c,
		"entryMatSort": 0x802e784c,
		"J3DDrawBuffer::entryMatAnmSort": 0x802e79a4,
		"entryMatAnmSort": 0x802e79a4,
		"J3DDrawBuffer::entryZSort": 0x802e7a64,
		"entryZSort": 0x802e7a64,
		"J3DDrawBuffer::entryModelSort": 0x802e7b64,
		"entryModelSort": 0x802e7b64,
		"J3DDrawBuffer::entryInvalidSort": 0x802e7bb4,
		"entryInvalidSort": 0x802e7bb4,
		"J3DDrawBuffer::entryNonSort": 0x802e7c08,
		"entryNonSort": 0x802e7c08,
		"J3DDrawBuffer::entryImm": 0x802e7c3c,
		"entryImm": 0x802e7c3c,
		"J3DDrawBuffer::draw": 0x802e7c5c,
		"J3DDrawBuffer::drawHead": 0x802e7cb0,
		"drawHead": 0x802e7cb0,
		"J3DDrawBuffer::drawTail": 0x802e7d3c,
		"drawTail": 0x802e7d3c,
		"JSystem::__sinit_J3DDrawBuffer_cpp": 0x802e7dc8,
		"__sinit_J3DDrawBuffer_cpp": 0x802e7dc8,
		"J3DTexNoAnm::calc": 0x802e7e94,
		"J3DMaterialAnm::initialize": 0x802e7ec4,
		"J3DMaterialAnm::calc": 0x802e7f34,
		"J3DMaterialAnm::~J3DMaterialAnm": 0x802e8128,
		"JGadget::TVector_pointer_void::TVector_pointer_void": 0x802e8174,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::DestroyElement_": 0x802e81a0,
		"std::__copy<void*,1,0>::copy": 0x802e81b4,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::InsertRaw": 0x802e8270,
		"JGadget::TVector_pointer_void::~TVector_pointer_void": 0x802e8564,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::erase": 0x802e85cc,
		"JGadget::TVector_pointer_void::insert": 0x802e8634,
		"JGadget::TVector_pointer_void::reserve": 0x802e86ac,
		"reserve": 0x802e86ac,
		"JKRAramBlock::JKRAramBlock": 0x802e8784,
		"JKRAramBlock::~JKRAramBlock": 0x802e87f0,
		"JKRAramBlock::allocHead": 0x802e88ac,
		"allocHead": 0x802e88ac,
		"JKRAramBlock::allocTail": 0x802e8948,
		"allocTail": 0x802e8948,
		"JKRAramPiece::sendCommand": 0x802e89ec,
		"JKRAramPiece::orderAsync": 0x802e8a0c,
		"orderAsync": 0x802e8a0c,
		"JKRAramPiece::orderSync": 0x802e8b60,
		"JKRAramPiece::startDMA": 0x802e8c10,
		"startDMA": 0x802e8c10,
		"JKRAramPiece::doneDMA": 0x802e8c88,
		"doneDMA": 0x802e8c88,
		"JKRAMCommand::JKRAMCommand": 0x802e8d30,
		"JKRAMCommand::~JKRAMCommand": 0x802e8da4,
		"JSystem::__sinit_JKRAramPiece_cpp": 0x802e8e4c,
		"__sinit_JKRAramPiece_cpp": 0x802e8e4c,
		"JKRAramStream::create": 0x802e8e98,
		"JKRAramStream::JKRAramStream": 0x802e8f04,
		"JKRAramStream::~JKRAramStream": 0x802e8f5c,
		"JKRAramStream::run": 0x802e8fc0,
		"JKRAramStream::readFromAram": 0x802e9028,
		"readFromAram": 0x802e9028,
		"JKRAramStream::writeToAram": 0x802e9030,
		"writeToAram": 0x802e9030,
		"JKRAramStream::write_StreamToAram_Async": 0x802e9200,
		"write_StreamToAram_Async": 0x802e9200,
		"JKRAramStream::sync": 0x802e92bc,
		"JKRAramStream::setTransBuffer": 0x802e9350,
		"setTransBuffer": 0x802e9350,
		"JKRAramStreamCommand::JKRAramStreamCommand": 0x802e93a4,
		"JUTAssertion::flushMessage": 0x802e93b0,
		"flushMessage": 0x802e93b0,
		"JUTFont::isLeadByte_1Byte": 0x802e9448,
		"isLeadByte_1Byte": 0x802e9448,
		"JUTFont::isLeadByte_2Byte": 0x802e9450,
		"isLeadByte_2Byte": 0x802e9450,
		"JUTFont::isLeadByte_ShiftJIS": 0x802e9458,
		"isLeadByte_ShiftJIS": 0x802e9458,
		"JUTResFont::JUTResFont": 0x802e94a8,
		"JUTResFont::~JUTResFont": 0x802e9524,
		"JUTResFont::initiate": 0x802e95c0,
		"JUTResFont::protected_initiate": 0x802e964c,
		"protected_initiate": 0x802e964c,
		"JUTResFont::countBlock": 0x802e96fc,
		"countBlock": 0x802e96fc,
		"JUTResFont::setBlock": 0x802e97f4,
		"setBlock": 0x802e97f4,
		"JUTResFont::drawChar_scale": 0x802e9ca8,
		"JUTResFont::getDescent": 0x802ea0b8,
		"JUTResFont::getHeight": 0x802ea0c4,
		"JUTResFont::getAscent": 0x802ea120,
		"JUTResFont::loadFont": 0x802ea12c,
		"loadFont": 0x802ea12c,
		"JUTResFont::getWidthEntry": 0x802ea22c,
		"JUTResFont::isLeadByte": 0x802ea2c8,
		"JUTResFont::getFontCode": 0x802ea2f8,
		"getFontCode": 0x802ea2f8,
		"JUTResFont::getFontType": 0x802ea478,
		"JUTResFont::loadImage": 0x802ea484,
		"JUTResFont::convertSjis": 0x802ea5f8,
		"convertSjis": 0x802ea5f8,
		"JUTResFont::getLeading": 0x802ea628,
		"JUTRomFont::JUTRomFont": 0x802ea634,
		"JUTRomFont::initiate": 0x802ea690,
		"JUTRomFont::~JUTRomFont": 0x802ea6d4,
		"JUTRomFont::loadImage": 0x802ea770,
		"JUTRomFont::setGX": 0x802ea844,
		"JUTRomFont::drawChar_scale": 0x802ea91c,
		"JUTRomFont::getDescent": 0x802ead70,
		"JUTRomFont::getAscent": 0x802ead7c,
		"JUTRomFont::getHeight": 0x802ead88,
		"JUTRomFont::getWidth": 0x802eade4,
		"JUTRomFont::getWidthEntry": 0x802eadf0,
		"JUTRomFont::isLeadByte": 0x802eae58,
		"JUTRomFont::getLeading": 0x802eae88,
		"JUTRomFont::getResFont": 0x802eae94,
		"getResFont": 0x802eae94,
		"JUTRomFont::getFontType": 0x802eae9c,
		"JSystem::J3DGDLoadTexMtxImm": 0x802eaea8,
		"J3DGDLoadTexMtxImm": 0x802eaea8,
		"JSystem::J3DGDSetChanAmbColor": 0x802eb550,
		"J3DGDSetChanAmbColor": 0x802eb550,
		"JSystem::J3DGDSetChanMatColor": 0x802eb694,
		"J3DGDSetChanMatColor": 0x802eb694,
		"JSystem::J3DGDSetChanCtrl": 0x802eb7d8,
		"J3DGDSetChanCtrl": 0x802eb7d8,
		"JSystem::J3DGDSetTexCoordGen": 0x802eba44,
		"J3DGDSetTexCoordGen": 0x802eba44,
		"JSystem::J3DGDSetFog": 0x802ebdac,
		"J3DGDSetFog": 0x802ebdac,
		"JSystem::J3DGDSetTexCoordScale2": 0x802ec128,
		"J3DGDSetTexCoordScale2": 0x802ec128,
		"JSystem::J3DGDSetTexImgAttr": 0x802ec324,
		"J3DGDSetTexImgAttr": 0x802ec324,
		"JSystem::J3DGDSetTexImgPtr": 0x802ec408,
		"J3DGDSetTexImgPtr": 0x802ec408,
		"JSystem::J3DGDSetTexTlut": 0x802ec4d4,
		"J3DGDSetTexTlut": 0x802ec4d4,
		"JSystem::J3DGDLoadTlut": 0x802ec5a8,
		"J3DGDLoadTlut": 0x802ec5a8,
		"JSystem::J3DGDSetTevKColor": 0x802ec960,
		"J3DGDSetTevKColor": 0x802ec960,
		"JSystem::JRNLoadCurrentMtx": 0x802ecac8,
		"JRNLoadCurrentMtx": 0x802ecac8,
		"JSystem::JRNSetTevIndirect": 0x802ecb60,
		"JRNSetTevIndirect": 0x802ecb60,
		"JSystem::JRNSetIndTexMtx": 0x802ecc88,
		"JRNSetIndTexMtx": 0x802ecc88,
		"JSystem::JRNSetIndTexCoordScale": 0x802ecf60,
		"JRNSetIndTexCoordScale": 0x802ecf60,
		"JSystem::JRNSetIndTexOrder": 0x802ed050,
		"JRNSetIndTexOrder": 0x802ed050,
		"JSystem::JRNLoadTexCached": 0x802ed264,
		"JRNLoadTexCached": 0x802ed264,
		"JSystem::JRNISetTevOrder": 0x802ed2e4,
		"JRNISetTevOrder": 0x802ed2e4,
		"JSystem::JRNISetTevColorS10": 0x802ed454,
		"JRNISetTevColorS10": 0x802ed454,
		"JSystem::JRNISetFogRangeAdj": 0x802ed688,
		"JRNISetFogRangeAdj": 0x802ed688,
		"JUTConsole::create": 0x802ed834,
		"JUTConsole::JUTConsole": 0x802ed8cc,
		"JUTConsole::~JUTConsole": 0x802ed9d0,
		"JUTConsole::getLineFromObjectSize": 0x802eda40,
		"getLineFromObjectSize": 0x802eda40,
		"JUTConsole::clear": 0x802eda50,
		"JUTConsole::doDraw": 0x802edaac,
		"doDraw": 0x802edaac,
		"JUTConsole::print_f": 0x802edf50,
		"print_f": 0x802edf50,
		"JUTConsole::print": 0x802edfd0,
		"JSystem::JUTConsole_print_f_va_": 0x802ee1e0,
		"JUTConsole_print_f_va_": 0x802ee1e0,
		"JUTConsole::scroll": 0x802ee228,
		"scroll": 0x802ee228,
		"JUTConsole::getUsedLine": 0x802ee304,
		"getUsedLine": 0x802ee304,
		"JUTConsole::getLineOffset": 0x802ee328,
		"getLineOffset": 0x802ee328,
		"JUTConsoleManager::JUTConsoleManager": 0x802ee34c,
		"JUTConsoleManager::createManager": 0x802ee374,
		"createManager": 0x802ee374,
		"JUTConsoleManager::appendConsole": 0x802ee3bc,
		"appendConsole": 0x802ee3bc,
		"JUTConsoleManager::removeConsole": 0x802ee458,
		"removeConsole": 0x802ee458,
		"JGadget::TNodeLinkList::end": 0x802ee530,
		"JGadget::TLinkList<10JUTConsole,-24>::iterator::iterator": 0x802ee53c,
		"JUTConsoleManager::drawDirect": 0x802ee548,
		"drawDirect": 0x802ee548,
		"JUTConsoleManager::setDirectConsole": 0x802ee5c8,
		"setDirectConsole": 0x802ee5c8,
		"JGadget::TLinkListNode::getNext": 0x802ee778,
		"getNext": 0x802ee778,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getValue": 0x802ee780,
		"Element_getValue": 0x802ee780,
		"JGadget::TNodeLinkList::iterator::operator_->": 0x802ee788,
		"operator_->": 0x802ee788,
		"JGadget::TLinkListNode::getPrev": 0x802ee790,
		"getPrev": 0x802ee790,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getNode": 0x802ee798,
		"JSystem::JUTSetReportConsole": 0x802ee7a0,
		"JUTSetReportConsole": 0x802ee7a0,
		"JSystem::JUTGetReportConsole": 0x802ee7a8,
		"JUTGetReportConsole": 0x802ee7a8,
		"JSystem::JUTSetWarningConsole": 0x802ee7b0,
		"JUTSetWarningConsole": 0x802ee7b0,
		"JSystem::JUTGetWarningConsole": 0x802ee7b8,
		"JUTGetWarningConsole": 0x802ee7b8,
		"JSystem::JUTReportConsole_f": 0x802ee7c0,
		"JUTReportConsole_f": 0x802ee7c0,
		"JSystem::JUTReportConsole": 0x802ee884,
		"JUTReportConsole": 0x802ee884,
		"JSystem::JUTWarningConsole_f": 0x802ee8b0,
		"JUTWarningConsole_f": 0x802ee8b0,
		"JSystem::JUTWarningConsole": 0x802ee974,
		"JUTWarningConsole": 0x802ee974,
		"JUTDirectFile::JUTDirectFile": 0x802ee9a0,
		"JUTDirectFile::~JUTDirectFile": 0x802ee9c4,
		"JUTDirectFile::fopen": 0x802eea0c,
		"fopen": 0x802eea0c,
		"JUTDirectFile::fclose": 0x802eeab0,
		"fclose": 0x802eeab0,
		"JUTDirectFile::fgets": 0x802eeb0c,
		"fgets": 0x802eeb0c,
		"JGadget::TNodeLinkList::Insert": 0x802eed44,
		"JGadget::TNodeLinkList::Erase": 0x802eed70,
		"Erase": 0x802eed70,
		"JGadget::TNodeLinkList::Remove": 0x802eed94,
		"Remove": 0x802eed94,
		"JGadget::TNodeLinkList::Remove_if": 0x802eede4,
		"Remove_if": 0x802eede4,
		"JGadget::TSingleNodeLinkList::~TSingleNodeLinkList": 0x802eef04,
		"JGadget::TSingleNodeLinkList::Insert": 0x802eef44,
		"JDrama::TActor::load": 0x802eef78,
		"JDrama::TActor::perform": 0x802ef0cc,
		"JDrama::TPolarCamera::load": 0x802ef328,
		"JDrama::TPolarCamera::perform": 0x802ef390,
		"JDrama::TLookAtCamera::perform": 0x802ef7fc,
		"JDrama::TOrthoProj::load": 0x802ef974,
		"JDrama::TOrthoProj::perform": 0x802ef9ec,
		"JDrama::TSmplChara::load": 0x802efcc4,
		"JDrama::TSmplChara::~TSmplChara": 0x802efd18,
		"JDrama::TSmplChara::getRes": 0x802efdac,
		"JDrama::TSmplChara::mountArc": 0x802efddc,
		"mountArc": 0x802efddc,
		"JDrama::TDirector::searchF": 0x802efe1c,
		"JDrama::TDirector::direct": 0x802efed0,
		"JDrama::TDisplay::TDisplay": 0x802f0054,
		"JDrama::TDisplay::startRendering": 0x802f0180,
		"startRendering": 0x802f0180,
		"JDrama::TDisplay::endRendering": 0x802f0278,
		"endRendering": 0x802f0278,
		"JDrama::TDrawBufObj::load": 0x802f043c,
		"JDrama::TDrawBufObj::perform": 0x802f04b4,
		"JDrama::TDStageDisp::TDStageDisp": 0x802f0558,
		"JDrama::TViewConnecter::~TViewConnecter": 0x802f06b4,
		"JDrama::TDStageDisp::getEfbCtrlDisp": 0x802f0728,
		"getEfbCtrlDisp": 0x802f0728,
		"JDrama::TDStageDisp::~TDStageDisp": 0x802f0730,
		"JDrama::TDStageGroup::perform": 0x802f07b4,
		"JDrama::TDStageGroup::~TDStageGroup": 0x802f0848,
		"JDrama::TEfbCtrl::perform": 0x802f091c,
		"JDrama::TEfbCtrl::setSrcRect": 0x802f09f4,
		"setSrcRect": 0x802f09f4,
		"JDrama::TEfbCtrlDisp::perform": 0x802f0aac,
		"JDrama::TEfbCtrlTex::TEfbCtrlTex": 0x802f0c04,
		"JDrama::TEfbCtrlTex::setTexAttb": 0x802f0ce8,
		"setTexAttb": 0x802f0ce8,
		"JDrama::TEfbCtrlTex::perform": 0x802f0d54,
		"JDrama::TEfbCtrlTex::~TEfbCtrlTex": 0x802f0f4c,
		"JDrama::TEfbCtrlDisp::~TEfbCtrlDisp": 0x802f0fd0,
		"JDrama::DecidePixelFmt": 0x802f1054,
		"DecidePixelFmt": 0x802f1054,
		"JDrama::IssueGXSetCopyFilter": 0x802f11fc,
		"IssueGXSetCopyFilter": 0x802f11fc,
		"JDrama::IssueGXSetCopyClear": 0x802f124c,
		"IssueGXSetCopyClear": 0x802f124c,
		"JDrama::IssueGXCopyDisp": 0x802f1324,
		"IssueGXCopyDisp": 0x802f1324,
		"JDrama::TFrmGXSet::perform": 0x802f14b8,
		"JDrama::TGraphics::setViewport": 0x802f16dc,
		"setViewport": 0x802f16dc,
		"JDrama::TLight::load": 0x802f1860,
		"JDrama::TLight::perform": 0x802f18c4,
		"JDrama::TLight::correct": 0x802f191c,
		"correct": 0x802f191c,
		"JDrama::TLightAry::load": 0x802f1a20,
		"JDrama::TLightAry::searchF": 0x802f1b18,
		"JDrama::TLightAry::setLightNum": 0x802f1ba8,
		"setLightNum": 0x802f1ba8,
		"JDrama::TIdxLight::TIdxLight": 0x802f1cf4,
		"JDrama::TLightAry::perform": 0x802f1ebc,
		"JDrama::TAmbColor::load": 0x802f1f5c,
		"JDrama::TAmbColor::perform": 0x802f1fac,
		"JDrama::TAmbAry::load": 0x802f2008,
		"JDrama::TAmbAry::searchF": 0x802f2100,
		"JDrama::TAmbAry::setAmbNum": 0x802f2190,
		"setAmbNum": 0x802f2190,
		"JDrama::TAmbColor::TAmbColor": 0x802f2288,
		"JDrama::TLightMap::load": 0x802f232c,
		"JDrama::TLightMap::TLightInfo::TLightInfo": 0x802f2420,
		"JDrama::TLightMap::perform": 0x802f2430,
		"JDrama::TLightMap::~TLightMap": 0x802f24c8,
		"JDrama::TAmbAry::~TAmbAry": 0x802f253c,
		"JDrama::TAmbAry::perform": 0x802f25b0,
		"JDrama::TLightAry::~TLightAry": 0x802f25b4,
		"JDrama::TNameRef::calcKeyCode": 0x802f2680,
		"JDrama::TNameRef::genObject": 0x802f2740,
		"genObject": 0x802f2740,
		"JDrama::TNameRef::~TNameRef": 0x802f27f0,
		"JDrama::TNameRef::load": 0x802f2844,
		"JDrama::TNameRef::save": 0x802f289c,
		"JDrama::TNameRef::loadAfter": 0x802f28a0,
		"JDrama::TNameRef::searchF": 0x802f28a4,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadSuper": 0x802f2914,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfterSuper": 0x802f2934,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::searchF": 0x802f2954,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::loadAfter": 0x802f2a3c,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::load": 0x802f2ae8,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::perform": 0x802f2c24,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::searchF": 0x802f2ce0,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfter": 0x802f2dc8,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::load": 0x802f2e80,
		"JDrama::TNameRefGen::load": 0x802f2fc8,
		"JDrama::TNameRefGen::getNameRef": 0x802f30b4,
		"JDrama::TLight::TLight": 0x802f36fc,
		"JDrama::TCamera::TCamera": 0x802f3804,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::~TNameRefPtrListT": 0x802f38d0,
		"~TNameRefPtrListT": 0x802f38d0,
		"JDrama::TPlacement::load": 0x802f3948,
		"JDrama::IsEqualRenderModeVIParams": 0x802f39b0,
		"IsEqualRenderModeVIParams": 0x802f39b0,
		"JDrama::IsRenderModeHalfAspectRatio": 0x802f3ad0,
		"IsRenderModeHalfAspectRatio": 0x802f3ad0,
		"JDrama::GetRenderModeYScale": 0x802f3aec,
		"GetRenderModeYScale": 0x802f3aec,
		"JDrama::CalcRenderModeXFBHeight": 0x802f3b90,
		"CalcRenderModeXFBHeight": 0x802f3b90,
		"JDrama::CalcRenderModeVIXOrigin": 0x802f3c70,
		"CalcRenderModeVIXOrigin": 0x802f3c70,
		"JDrama::CalcRenderModeVIYOrigin": 0x802f3cbc,
		"CalcRenderModeVIYOrigin": 0x802f3cbc,
		"JDrama::CopyRenderModeSamplePattern": 0x802f3d08,
		"CopyRenderModeSamplePattern": 0x802f3d08,
		"JDrama::CopyRenderModeVFilter": 0x802f3d30,
		"CopyRenderModeVFilter": 0x802f3d30,
		"TCamConnecter::perform": 0x802f3de8,
		"JDrama::TScreen::TScreen": 0x802f3e84,
		"JDrama::TScreen::assignCamera": 0x802f3f5c,
		"assignCamera": 0x802f3f5c,
		"JDrama::TScreen::assignViewObj": 0x802f3f68,
		"assignViewObj": 0x802f3f68,
		"JDrama::TScreen::~TScreen": 0x802f3f74,
		"TCamConnecter::~TCamConnecter": 0x802f3ff8,
		"JDrama::TSmJ3DAct::load": 0x802f407c,
		"JDrama::TSmJ3DAct::perform": 0x802f4180,
		"JDrama::TSmJ3DScn::TSmJ3DScn": 0x802f46c0,
		"JDrama::TSmJ3DScn::perform": 0x802f47c4,
		"JDrama::TSmJ3DScn::loadSuper": 0x802f48d8,
		"JDrama::TSmJ3DScn::~TSmJ3DScn": 0x802f498c,
		"JDrama::TVideo::TVideo": 0x802f4a28,
		"JDrama::TVideo::setNextXFB": 0x802f4b1c,
		"setNextXFB": 0x802f4b1c,
		"JDrama::TVideo::waitForRetrace": 0x802f4b24,
		"waitForRetrace": 0x802f4b24,
		"JDrama::TViewConnecter::TViewConnecter": 0x802f4cec,
		"JDrama::TViewConnecter::perform": 0x802f4d88,
		"JDrama::TViewObj::testPerform": 0x802f4e24,
		"testPerform": 0x802f4e24,
		"JDrama::TViewport::TViewport": 0x802f4e8c,
		"JDrama::TViewport::perform": 0x802f4f1c,
		"JDrama::TViewport::load": 0x802f4fcc,
		"JDrama::TViewport::~TViewport": 0x802f5044,
		"JALCalc::linearTransform": 0x802f50b8,
		"linearTransform": 0x802f50b8,
		"JALCalc::getParamByExp": 0x802f512c,
		"getParamByExp": 0x802f512c,
		"JALCalc::getRandom": 0x802f5280,
		"getRandom": 0x802f5280,
		"JALCalc::getRandom_0_1": 0x802f5314,
		"getRandom_0_1": 0x802f5314,
		"JALCalc::getDist": 0x802f5388,
		"getDist": 0x802f5388,
		"JALCalc::getDistPow": 0x802f5400,
		"getDistPow": 0x802f5400,
		"JALSystem::init": 0x802f54d4,
		"JALSystem::gateCheckFunc": 0x802f5514,
		"gateCheckFunc": 0x802f5514,
		"JALSystem::processModFunc": 0x802f5688,
		"processModFunc": 0x802f5688,
		"JALSystem::processModDistVolume": 0x802f5888,
		"processModDistVolume": 0x802f5888,
		"JALSystem::append": 0x802f5934,
		"JSUList<JALSeModDataGrpMemb>::JSUList": 0x802f5f00,
		"JALSystem::appendGrpMember": 0x802f5f30,
		"appendGrpMember": 0x802f5f30,
		"JALSystem::TFlagManager::TFlagManager": 0x802f6200,
		"JALSystem::TFlagManager::addUseFlag": 0x802f6348,
		"addUseFlag": 0x802f6348,
		"JALSystem::TFlagManager::isRegistered": 0x802f6364,
		"isRegistered": 0x802f6364,
		"JALSeModDataGrp<JALSeModVolDGrp>::calcGrp": 0x802f6390,
		"JALSeModDataGrp<JALSeModEffFGrp>::calcGrp": 0x802f63f4,
		"JALSeModDataGrp<JALSeModEffFGrp>::gateCheckGrp": 0x802f6458,
		"JALSeModDataGrp<JALSeModPitFGrp>::gateCheckGrp": 0x802f64a8,
		"JALSeModDataGrp<JALSeModVolFGrp>::calcGrp": 0x802f64f8,
		"JALSeModDataGrp<JALSeModVolFGrp>::gateCheckGrp": 0x802f655c,
		"JALSeModData<JALSeModEffDGrp>::calcDyna": 0x802f65ac,
		"JALSeModData<JALSeModEffDGrp>::gateCheckDyna": 0x802f65e4,
		"JALSeModData<JALSeModPitDGrp>::calcDyna": 0x802f6678,
		"JALSeModData<JALSeModPitDGrp>::gateCheckDyna": 0x802f66b0,
		"JALSeModData<JALSeModVolDGrp>::calcDyna": 0x802f6744,
		"JALSeModData<JALSeModVolDGrp>::gateCheckDyna": 0x802f677c,
		"JALSeModData<JALSeModEffFGrp>::calcDyna": 0x802f6810,
		"JALSeModData<JALSeModEffFGrp>::gateCheckDyna": 0x802f6848,
		"JALSeModData<JALSeModPitFGrp>::gateCheckDyna": 0x802f68dc,
		"JALSeModData<JALSeModVolFGrp>::calcDyna": 0x802f6970,
		"JALSeModData<JALSeModVolFGrp>::gateCheckDyna": 0x802f69a8,
		"JALSeModData<JALSeModEffDist>::calcDyna": 0x802f6a3c,
		"JALSeModData<JALSeModEffDist>::gateCheckDyna": 0x802f6a74,
		"JALSeModData<JALSeModPitDist>::calcDyna": 0x802f6b08,
		"JALSeModData<JALSeModPitDist>::gateCheckDyna": 0x802f6b40,
		"JALSeModData<JALSeModVolDist>::calc": 0x802f6bd4,
		"JALSeModData<JALSeModVolDist>::calcDyna": 0x802f6c38,
		"JALSeModData<JALSeModVolDist>::gateCheckDyna": 0x802f6c70,
		"JALSeModData<JALSeModEffFunk>::calc": 0x802f6d04,
		"JALSeModData<JALSeModEffFunk>::calcDyna": 0x802f6d68,
		"JALSeModData<JALSeModEffFunk>::gateCheck": 0x802f6da0,
		"JALSeModData<JALSeModEffFunk>::gateCheckDyna": 0x802f6df0,
		"JALSeModData<JALSeModPitFunk>::calc": 0x802f6e84,
		"JALSeModData<JALSeModPitFunk>::calcDyna": 0x802f6ee8,
		"JALSeModData<JALSeModPitFunk>::gateCheck": 0x802f6f20,
		"JALSeModData<JALSeModPitFunk>::gateCheckDyna": 0x802f6f70,
		"JALSeModData<JALSeModVolFunk>::gateCheck": 0x802f7004,
		"JALSeModData<JALSeModVolFunk>::gateCheckDyna": 0x802f7054,
		"JALListS<JALSeModPitFunk,unsigned_long><JALSeModPitFunk,unsigned_long>::search": 0x802f70e8,
		"JALListS<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::search": 0x802f711c,
		"JALListS<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::search": 0x802f7150,
		"JALListS<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::search": 0x802f7184,
		"JALListS<JALSeModPitFGrp,unsigned_long><JALSeModPitFGrp,unsigned_long>::search": 0x802f71b8,
		"JALListS<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::search": 0x802f71ec,
		"JALListS<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::search": 0x802f7220,
		"JALListS<JALSeModPitDGrp,unsigned_long><JALSeModPitDGrp,unsigned_long>::search": 0x802f7254,
		"JALListS<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::search": 0x802f7288,
		"JALLinkD<JALSeModDataGrpMemb,unsigned_long><JALSeModDataGrpMemb,unsigned_long>::JALLinkD": 0x802f72bc,
		"JALLinkD": 0x802f72bc,
		"JALSeModData<JALSeModVolFunk>::JALSeModData": 0x802f732c,
		"JALSeModData<JALSeModPitFunk>::JALSeModData": 0x802f73b8,
		"JALSeModData<JALSeModEffFunk>::JALSeModData": 0x802f7444,
		"JALSeModData<JALSeModVolDist>::JALSeModData": 0x802f74d0,
		"JALSeModData<JALSeModPitDist>::JALSeModData": 0x802f755c,
		"JALSeModData<JALSeModEffDist>::JALSeModData": 0x802f75e8,
		"JALSeModData<JALSeModVolFGrp>::JALSeModData": 0x802f7674,
		"JALSeModData<JALSeModPitFGrp>::JALSeModData": 0x802f7700,
		"JALSeModData<JALSeModEffFGrp>::JALSeModData": 0x802f778c,
		"JALSeModData<JALSeModVolDGrp>::JALSeModData": 0x802f7818,
		"JALSeModData<JALSeModPitDGrp>::JALSeModData": 0x802f78a4,
		"JALSeModData<JALSeModEffDGrp>::JALSeModData": 0x802f7930,
		"JALListGrp<JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802f79bc,
		"JALListGrp<JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802f7a18,
		"JALListGrp<JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802f7a74,
		"JALListHioNode<JALSeModVolFunk,unsigned_long><JALSeModVolFunk,unsigned_long>::JALListHioNode": 0x802f7ad0,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x802f7b24,
		"__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x802f7b24,
		"JALListHioNode<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::JALListHioNode": 0x802f7b78,
		"JALListHioNode<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::JALListHioNode": 0x802f7bcc,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x802f7c20,
		"__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x802f7c20,
		"JALListHioNode<JALSeModEffDist,unsigned_long><JALSeModEffDist,unsigned_long>::JALListHioNode": 0x802f7c74,
		"JALListHioNode<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::JALListHioNode": 0x802f7cc8,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x802f7d1c,
		"__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x802f7d1c,
		"JALListHioNode<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::JALListHioNode": 0x802f7d70,
		"JALListHioNode<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::JALListHioNode": 0x802f7dc4,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x802f7e18,
		"__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x802f7e18,
		"JALListHioNode<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::JALListHioNode": 0x802f7e6c,
		"JSystem::__sinit_JALModSe_cpp": 0x802f7ec0,
		"__sinit_JALModSe_cpp": 0x802f7ec0,
		"JAIAnimeSound::JAIAnimeSound": 0x802f812c,
		"JAIAnimeSound::initActorAnimSound": 0x802f81a0,
		"initActorAnimSound": 0x802f81a0,
		"JAIAnimeSound::setAnimSoundVec": 0x802f82f4,
		"setAnimSoundVec": 0x802f82f4,
		"JAIAnimeSound::setAnimSoundActor": 0x802f832c,
		"setAnimSoundActor": 0x802f832c,
		"JAIAnimeSound::playActorAnimSound": 0x802f8780,
		"playActorAnimSound": 0x802f8780,
		"JAIAnimeSound::startAnimSound": 0x802f8994,
		"JAIAnimeSound::setSpeedModifySound": 0x802f89c8,
		"JAIAnimeSound::stop": 0x802f8b08,
		"JAIBasic::JAIBasic": 0x802f8b70,
		"JAIBasic::initInterfaceMain": 0x802f8c48,
		"initInterfaceMain": 0x802f8c48,
		"JAIBasic::setCameraInfo": 0x802f8e74,
		"JAIBasic::initStream": 0x802f8ea8,
		"initStream": 0x802f8ea8,
		"JAIBasic::setRegisterTrackCallback": 0x802f8ee0,
		"JAIBasic::initReadFile": 0x802f8f08,
		"initReadFile": 0x802f8f08,
		"JAIBasic::checkInitListFile": 0x802f8fd4,
		"checkInitListFile": 0x802f8fd4,
		"JAIBasic::checkInitDataFile": 0x802f90c0,
		"checkInitDataFile": 0x802f90c0,
		"JAIBasic::checkInitDataOnMemory": 0x802f9130,
		"checkInitDataOnMemory": 0x802f9130,
		"JAIBasic::transInitDataFile": 0x802f9564,
		"transInitDataFile": 0x802f9564,
		"JAIBasic::initBankWave": 0x802f9650,
		"initBankWave": 0x802f9650,
		"JAIBasic::setWaveScene": 0x802f9824,
		"setWaveScene": 0x802f9824,
		"JAIBasic::setSceneSetFinishCallback": 0x802f98d4,
		"setSceneSetFinishCallback": 0x802f98d4,
		"JAIBasic::finishSceneSet": 0x802f9920,
		"finishSceneSet": 0x802f9920,
		"JAIBasic::loadSceneWave": 0x802f9940,
		"loadSceneWave": 0x802f9940,
		"JAIBasic::checkSceneWaveOnMemory": 0x802f99e0,
		"checkSceneWaveOnMemory": 0x802f99e0,
		"JAIBasic::loadGroupWave": 0x802f9a14,
		"JAIBasic::initNullData": 0x802f9a98,
		"initNullData": 0x802f9a98,
		"JAIBasic::initDriver": 0x802f9bb8,
		"initDriver": 0x802f9bb8,
		"JAIBasic::initInterface": 0x802f9c30,
		"initInterface": 0x802f9c30,
		"JAIBasic::initAllocParameter": 0x802f9c54,
		"initAllocParameter": 0x802f9c54,
		"JAIBasic::initSeqsLoadArea": 0x802f9d18,
		"initSeqsLoadArea": 0x802f9d18,
		"JAIBasic::setInitFileLoadSwitch": 0x802f9da4,
		"setInitFileLoadSwitch": 0x802f9da4,
		"JAIBasic::startFrameInterfaceWork": 0x802f9dac,
		"startFrameInterfaceWork": 0x802f9dac,
		"JAIBasic::processFrameWork": 0x802f9dcc,
		"processFrameWork": 0x802f9dcc,
		"JAIBasic::checkStream": 0x802f9f34,
		"checkStream": 0x802f9f34,
		"JAIBasic::checkDummyPositionBuffer": 0x802f9f78,
		"checkDummyPositionBuffer": 0x802f9f78,
		"JAIBasic::startSoundActor": 0x802fa010,
		"JAIBasic::startSoundActorReturnHandle": 0x802fa0a4,
		"startSoundActorReturnHandle": 0x802fa0a4,
		"JAIBasic::startSoundDirectID": 0x802fa154,
		"startSoundDirectID": 0x802fa154,
		"JAIBasic::startSoundIndirectID": 0x802fa1c4,
		"startSoundIndirectID": 0x802fa1c4,
		"JAIBasic::startSoundBasic": 0x802fa23c,
		"startSoundBasic": 0x802fa23c,
		"JAIBasic::stopSoundHandle": 0x802fa3b4,
		"stopSoundHandle": 0x802fa3b4,
		"JAIBasic::changeIDToCategory": 0x802fa5a4,
		"changeIDToCategory": 0x802fa5a4,
		"JAIBasic::stopAllSe": 0x802fa5ac,
		"stopAllSe": 0x802fa5ac,
		"JAIBasic::getControllerHandle": 0x802fa614,
		"getControllerHandle": 0x802fa614,
		"JAIBasic::releaseControllerHandle": 0x802fa66c,
		"releaseControllerHandle": 0x802fa66c,
		"JAIBasic::getStreamParameter": 0x802fa6e4,
		"JAIBasic::releaseStreamParameterPointer": 0x802fa744,
		"releaseStreamParameterPointer": 0x802fa744,
		"JAIBasic::getSeqParametermeterPointer": 0x802fa7bc,
		"getSeqParametermeterPointer": 0x802fa7bc,
		"JAIBasic::releaseSeqParameterPointer": 0x802fa81c,
		"releaseSeqParameterPointer": 0x802fa81c,
		"JAIBasic::getSeParametermeterPointer": 0x802fa894,
		"getSeParametermeterPointer": 0x802fa894,
		"JAIBasic::releaseSeParameterPointer": 0x802fa924,
		"releaseSeParameterPointer": 0x802fa924,
		"JAIBasic::releaseDummyVecPointer": 0x802fa9a4,
		"releaseDummyVecPointer": 0x802fa9a4,
		"JAIBasic::getMapInfoFxline": 0x802faa1c,
		"getMapInfoFxline": 0x802faa1c,
		"JAIBasic::getMapInfoGround": 0x802faa34,
		"JAIBasic::getMapInfoFxParameter": 0x802faa4c,
		"getMapInfoFxParameter": 0x802faa4c,
		"JAIBasic::getInfoPointerFromID": 0x802faa64,
		"getInfoPointerFromID": 0x802faa64,
		"JAIBasic::getInfoFormat": 0x802faadc,
		"getInfoFormat": 0x802faadc,
		"JAIBasic::setSeCategoryVolume": 0x802fab34,
		"setSeCategoryVolume": 0x802fab34,
		"JAIBasic::setParameterSeqSync": 0x802fab70,
		"JAIBasic::getSoundInfoFromID": 0x802fad40,
		"getSoundInfoFromID": 0x802fad40,
		"JAIBasic::getSeqTrackNumber": 0x802fad6c,
		"getSeqTrackNumber": 0x802fad6c,
		"JAIBasic::getSoundPrioity": 0x802fad74,
		"getSoundPrioity": 0x802fad74,
		"JAIBasic::getSoundSwBit": 0x802fad7c,
		"getSoundSwBit": 0x802fad7c,
		"JAIBasic::setSeExtParameter": 0x802fad84,
		"JAIBasic::routeToTrack": 0x802faf30,
		"routeToTrack": 0x802faf30,
		"JAIBasic::initHeap": 0x802faf70,
		"initHeap": 0x802faf70,
		"JAIBasic::allocHeap": 0x802fafb8,
		"allocHeap": 0x802fafb8,
		"JAIBasic::makeSound": 0x802fb000,
		"JAIBasic::loadDVDFile": 0x802fb094,
		"loadDVDFile": 0x802fb094,
		"JAIBasic::loadTmpDVDFile": 0x802fb118,
		"loadTmpDVDFile": 0x802fb118,
		"JAIBasic::deleteTmpDVDFile": 0x802fb190,
		"deleteTmpDVDFile": 0x802fb190,
		"JAIBasic::loadArcSeqData": 0x802fb1cc,
		"loadArcSeqData": 0x802fb1cc,
		"JSystem::__sinit_JAIBasic_cpp": 0x802fb33c,
		"__sinit_JAIBasic_cpp": 0x802fb33c,
		"JSystem::__sinit_JAIConst_cpp": 0x802fb36c,
		"__sinit_JAIConst_cpp": 0x802fb36c,
		"JAIData::init": 0x802fb3b0,
		"JAIData::initLinkBuffer": 0x802fb3d4,
		"initLinkBuffer": 0x802fb3d4,
		"JAIData::initSeqParaLinkBuffer": 0x802fb52c,
		"initSeqParaLinkBuffer": 0x802fb52c,
		"JAIData::initSeqParameter": 0x802fb638,
		"initSeqParameter": 0x802fb638,
		"JAIData::initSePara": 0x802fb888,
		"initSePara": 0x802fb888,
		"JAIData::initStreamParaLinkBuffer": 0x802fb9e8,
		"initStreamParaLinkBuffer": 0x802fb9e8,
		"JAIData::initStreamParameter": 0x802fbaf4,
		"initStreamParameter": 0x802fbaf4,
		"JAIData::initSeqTrackInfoParameter": 0x802fbb50,
		"initSeqTrackInfoParameter": 0x802fbb50,
		"JAIData::initStreamUpdateParameter": 0x802fbc34,
		"initStreamUpdateParameter": 0x802fbc34,
		"JAIData::setSeMovePara": 0x802fbc84,
		"setSeMovePara": 0x802fbc84,
		"JAIData::moveParameter": 0x802fbce8,
		"moveParameter": 0x802fbce8,
		"JAIData::checkOnMemory": 0x802fbd30,
		"checkOnMemory": 0x802fbd30,
		"JAIData::checkUsefulAutoHeapPosition": 0x802fbdf8,
		"checkUsefulAutoHeapPosition": 0x802fbdf8,
		"JAIData::getFreeAutoHeapPointer": 0x802fbea8,
		"getFreeAutoHeapPointer": 0x802fbea8,
		"JAIData::releaseAutoHeapPointer": 0x802fbef4,
		"releaseAutoHeapPointer": 0x802fbef4,
		"JAIData::getFreeStayHeapPointer": 0x802fbf18,
		"getFreeStayHeapPointer": 0x802fbf18,
		"JAIData::setAutoHeapLoadedFlag": 0x802fbfd0,
		"setAutoHeapLoadedFlag": 0x802fbfd0,
		"JAIData::getInfoPointer": 0x802fbfe4,
		"getInfoPointer": 0x802fbfe4,
		"JAIData::initData": 0x802fc13c,
		"JAIData::initInfoDataWork": 0x802fc9ac,
		"initInfoDataWork": 0x802fc9ac,
		"JAIEntry::checkSoundHandle": 0x802fcacc,
		"checkSoundHandle": 0x802fcacc,
		"JAIEntry::initSoundParameter": 0x802fcb88,
		"initSoundParameter": 0x802fcb88,
		"JAISeEntry::storeBuffer": 0x802fcc2c,
		"JAISeqEntry::storeBuffer": 0x802fcfa8,
		"JAIStreamEntry::storeBuffer": 0x802fd294,
		"JAIBasic::checkNextFrameSe": 0x802fd394,
		"checkNextFrameSe": 0x802fd394,
		"JAIBasic::sendPlayingSeCommand": 0x802fdae8,
		"sendPlayingSeCommand": 0x802fdae8,
		"JAIBasic::setSeqMuteFromSeStart": 0x802fe06c,
		"setSeqMuteFromSeStart": 0x802fe06c,
		"JAIBasic::checkSeMovePara": 0x802fe14c,
		"checkSeMovePara": 0x802fe14c,
		"JAIBasic::sendSeAllParameter": 0x802fe278,
		"sendSeAllParameter": 0x802fe278,
		"JAIBasic::releaseSeRegist": 0x802fe884,
		"releaseSeRegist": 0x802fe884,
		"JAIBasic::stopSeq": 0x802fea68,
		"JAIBasic::checkEntriedSeq": 0x802febac,
		"checkEntriedSeq": 0x802febac,
		"JAIBasic::checkPlayingSeqTrack": 0x802fef38,
		"checkPlayingSeqTrack": 0x802fef38,
		"JAIBasic::checkPlayingSeq": 0x802ffdd4,
		"checkPlayingSeq": 0x802ffdd4,
		"JAIBasic::checkStoppedSeq": 0x802ffedc,
		"checkStoppedSeq": 0x802ffedc,
		"JAIBasic::checkStartedSeq": 0x802fffa8,
		"checkStartedSeq": 0x802fffa8,
		"JAIBasic::checkFadeoutSeq": 0x80300060,
		"checkFadeoutSeq": 0x80300060,
		"JAIBasic::checkReadSeq": 0x8030013c,
		"checkReadSeq": 0x8030013c,
		"JAIBasic::checkSeqWave": 0x80300308,
		"checkSeqWave": 0x80300308,
		"JAIBasic::checkDvdLoadArc": 0x80300420,
		"checkDvdLoadArc": 0x80300420,
		"JAIBasic::checkEntriedStream": 0x803004fc,
		"checkEntriedStream": 0x803004fc,
		"JAIBasic::checkWaitStream": 0x803005c8,
		"checkWaitStream": 0x803005c8,
		"JAIBasic::checkRequestStream": 0x803006b0,
		"checkRequestStream": 0x803006b0,
		"JAIBasic::checkPlayingStream": 0x80300748,
		"checkPlayingStream": 0x80300748,
		"JAInter::StreamLib::Play_DirectPCM": 0x80300b78,
		"Play_DirectPCM": 0x80300b78,
		"JAInter::StreamLib::init": 0x80300c94,
		"JAInter::StreamLib::allocBuffer": 0x80300cf4,
		"allocBuffer": 0x80300cf4,
		"JAInter::StreamLib::getNeedBufferSize": 0x80300e1c,
		"getNeedBufferSize": 0x80300e1c,
		"JAInter::StreamLib::__DecodePCM": 0x80300ea8,
		"__DecodePCM": 0x80300ea8,
		"JAInter::StreamLib::__DecodeADPCM": 0x80301008,
		"__DecodeADPCM": 0x80301008,
		"JAInter::StreamLib::__LoadFin": 0x803014dc,
		"__LoadFin": 0x803014dc,
		"JAInter::StreamLib::LoadADPCM": 0x803014fc,
		"LoadADPCM": 0x803014fc,
		"JAInter::StreamLib::setVolume": 0x80301610,
		"JAInter::StreamLib::setPitch": 0x80301620,
		"JAInter::StreamLib::setPan": 0x80301630,
		"JAInter::StreamLib::stop": 0x80301640,
		"JAInter::StreamLib::setPauseFlag": 0x80301650,
		"JAInter::StreamLib::clearPauseFlag": 0x80301664,
		"clearPauseFlag": 0x80301664,
		"JAInter::StreamLib::setPrepareFlag": 0x8030167c,
		"setPrepareFlag": 0x8030167c,
		"JAInter::StreamLib::setOutputMode": 0x80301684,
		"JAInter::StreamLib::getPlayingFlag": 0x8030168c,
		"getPlayingFlag": 0x8030168c,
		"JAInter::StreamLib::start": 0x80301694,
		"JAInter::StreamLib::__start": 0x8030170c,
		"JAInter::StreamLib::callBack": 0x80301a58,
		"callBack": 0x80301a58,
		"JSystem::__sinit_JAIGFrameStream_cpp": 0x8030232c,
		"__sinit_JAIGFrameStream_cpp": 0x8030232c,
		"JASystem::Kernel::TSolidHeap::~TSolidHeap": 0x80302368,
		"JAIGlobalParameter::setParamInitDataPointer": 0x803023a8,
		"setParamInitDataPointer": 0x803023a8,
		"JAIGlobalParameter::setParamSeqPlayTrackMax": 0x803023c0,
		"setParamSeqPlayTrackMax": 0x803023c0,
		"JAIGlobalParameter::setParamSeqControlBufferMax": 0x803023d0,
		"setParamSeqControlBufferMax": 0x803023d0,
		"JAIGlobalParameter::setParamAutoHeapMax": 0x803023d8,
		"setParamAutoHeapMax": 0x803023d8,
		"JAIGlobalParameter::setParamStayHeapMax": 0x803023e0,
		"setParamStayHeapMax": 0x803023e0,
		"JAIGlobalParameter::setParamInputGainDown": 0x803023e8,
		"setParamInputGainDown": 0x803023e8,
		"JAIGlobalParameter::setParamOutputGainUp": 0x803023f0,
		"setParamOutputGainUp": 0x803023f0,
		"JAIGlobalParameter::setParamDistanceMax": 0x803023f8,
		"setParamDistanceMax": 0x803023f8,
		"JAIGlobalParameter::setParamMaxVolumeDistance": 0x80302400,
		"setParamMaxVolumeDistance": 0x80302400,
		"JAIGlobalParameter::setParamMinDistanceVolume": 0x80302408,
		"setParamMinDistanceVolume": 0x80302408,
		"JAIGlobalParameter::setParamStreamInsideBufferCut": 0x80302410,
		"setParamStreamInsideBufferCut": 0x80302410,
		"JAIGlobalParameter::setParamAutoHeapRoomSize": 0x80302424,
		"setParamAutoHeapRoomSize": 0x80302424,
		"JAIGlobalParameter::setParamStayHeapSize": 0x8030242c,
		"setParamStayHeapSize": 0x8030242c,
		"JAIGlobalParameter::setParamInitDataFileName": 0x80302434,
		"setParamInitDataFileName": 0x80302434,
		"JAIGlobalParameter::setParamWavePath": 0x8030243c,
		"setParamWavePath": 0x8030243c,
		"JAIGlobalParameter::setParamSequenceArchivesPath": 0x80302444,
		"setParamSequenceArchivesPath": 0x80302444,
		"JAIGlobalParameter::setParamStreamPath": 0x8030244c,
		"setParamStreamPath": 0x8030244c,
		"JAIGlobalParameter::setParamSystemTrackMax": 0x80302454,
		"setParamSystemTrackMax": 0x80302454,
		"JAIGlobalParameter::setParamSystemRootTrackMax": 0x8030245c,
		"setParamSystemRootTrackMax": 0x8030245c,
		"JAIGlobalParameter::setParamSoundOutputMode": 0x80302464,
		"setParamSoundOutputMode": 0x80302464,
		"JAIGlobalParameter::getParamSeCategoryMax": 0x803024f0,
		"getParamSeCategoryMax": 0x803024f0,
		"JAIGlobalParameter::getParamSeqTrackMax": 0x80302500,
		"getParamSeqTrackMax": 0x80302500,
		"JAIGlobalParameter::getParamOutputGainUp": 0x80302508,
		"getParamOutputGainUp": 0x80302508,
		"JAIGlobalParameter::getParamMaxVolumeDistance": 0x80302510,
		"getParamMaxVolumeDistance": 0x80302510,
		"JAISound::JAISound": 0x80302518,
		"JAISound::initMoveParameter": 0x80302540,
		"initMoveParameter": 0x80302540,
		"JAISound::getSeCategoryNumber": 0x803025f0,
		"getSeCategoryNumber": 0x803025f0,
		"JAISound::getSwBit": 0x8030261c,
		"getSwBit": 0x8030261c,
		"JAISound::checkSwBit": 0x80302648,
		"checkSwBit": 0x80302648,
		"JAISound::getInfoPriority": 0x80302684,
		"getInfoPriority": 0x80302684,
		"JAISound::clearMainSoundPPointer": 0x803026b0,
		"clearMainSoundPPointer": 0x803026b0,
		"JAISound::release": 0x803026c8,
		"JAISound::stop": 0x803026dc,
		"JAISound::setVolume": 0x8030270c,
		"JAISound::setPan": 0x80302794,
		"JAISound::setPitch": 0x8030281c,
		"JAISound::setFxmix": 0x803028a4,
		"setFxmix": 0x803028a4,
		"JAISound::setDolby": 0x8030291c,
		"JAISound::setTempoProportion": 0x80302994,
		"setTempoProportion": 0x80302994,
		"JAISound::setPortData": 0x803029ec,
		"setPortData": 0x803029ec,
		"JAISound::setDistanceVolumeCommon": 0x80302a50,
		"JAISound::setDistancePanCommon": 0x80302ba4,
		"setDistancePanCommon": 0x80302ba4,
		"JAISound::setPositionDopplarCommon": 0x80302cf8,
		"setPositionDopplarCommon": 0x80302cf8,
		"JAISound::setSeqInterVolume": 0x80302ed4,
		"setSeqInterVolume": 0x80302ed4,
		"JAISound::setSeqInterPan": 0x80302fd4,
		"setSeqInterPan": 0x80302fd4,
		"JAISound::setSeqInterPitch": 0x803030d4,
		"setSeqInterPitch": 0x803030d4,
		"JAISound::setSeqInterFxmix": 0x803031d4,
		"setSeqInterFxmix": 0x803031d4,
		"JAISound::setSeqInterDolby": 0x803032d4,
		"setSeqInterDolby": 0x803032d4,
		"JAISound::setSeqTempoProportion": 0x80303410,
		"setSeqTempoProportion": 0x80303410,
		"JAISound::setSeqPortData": 0x803034c0,
		"setSeqPortData": 0x803034c0,
		"JAISound::setWaveReadMode": 0x8030362c,
		"setWaveReadMode": 0x8030362c,
		"JAISound::setTrackInterruptSwitch": 0x803036cc,
		"setTrackInterruptSwitch": 0x803036cc,
		"JAISound::setTrackPortData": 0x80303770,
		"setTrackPortData": 0x80303770,
		"JAISound::setSeInterVolume": 0x80303890,
		"setSeInterVolume": 0x80303890,
		"JAISound::setSeInterPan": 0x80303a58,
		"setSeInterPan": 0x80303a58,
		"JAISound::setSeInterFxmix": 0x80303c20,
		"setSeInterFxmix": 0x80303c20,
		"JAISound::setSeInterDolby": 0x80303de8,
		"setSeInterDolby": 0x80303de8,
		"JAISound::setSeInterPitch": 0x80303fb0,
		"setSeInterPitch": 0x80303fb0,
		"JAISound::setSePortData": 0x8030416c,
		"setSePortData": 0x8030416c,
		"JAISound::setSeDistanceParameters": 0x803042ec,
		"JAISound::setSeDistanceVolume": 0x80304460,
		"JAISound::setSeDistancePan": 0x80304560,
		"JAISound::setSeDistancePitch": 0x80304628,
		"JAISound::setSePositionDopplar": 0x80304820,
		"setSePositionDopplar": 0x80304820,
		"JAISound::setSeDistanceFxmix": 0x8030491c,
		"setSeDistanceFxmix": 0x8030491c,
		"JAISound::setSeDistanceFir": 0x80304a10,
		"setSeDistanceFir": 0x80304a10,
		"JAISound::setSeDistanceDolby": 0x80304a14,
		"JAISound::setStreamInterVolume": 0x80304ae0,
		"setStreamInterVolume": 0x80304ae0,
		"JAISound::setStreamInterPitch": 0x80304be0,
		"setStreamInterPitch": 0x80304be0,
		"JAISound::setStreamInterPan": 0x80304ce0,
		"setStreamInterPan": 0x80304ce0,
		"JAISound::setPauseMode": 0x80304de0,
		"setPauseMode": 0x80304de0,
		"JAISound::getSeqInterVolume": 0x80305190,
		"getSeqInterVolume": 0x80305190,
		"JAISound::getStreamInterVolume": 0x803051e4,
		"getStreamInterVolume": 0x803051e4,
		"JAISound::getSeqParameter": 0x80305274,
		"getSeqParameter": 0x80305274,
		"JAISound::getSeParameter": 0x8030527c,
		"getSeParameter": 0x8030527c,
		"JAISound::getStreamParameter": 0x80305284,
		"JAISound::getTrackPortRoute": 0x8030528c,
		"getTrackPortRoute": 0x8030528c,
		"JAISystemInterface::checkFileExsistence": 0x803052c8,
		"checkFileExsistence": 0x803052c8,
		"JAISystemInterface::checkSeqActiveFlag": 0x8030530c,
		"checkSeqActiveFlag": 0x8030530c,
		"JAISystemInterface::trackToSeqp": 0x80305414,
		"trackToSeqp": 0x80305414,
		"JAISystemInterface::setSeqPortargsF32": 0x803054a4,
		"setSeqPortargsF32": 0x803054a4,
		"JAISystemInterface::setSeqPortargsU32": 0x803054c0,
		"setSeqPortargsU32": 0x803054c0,
		"JAISystemInterface::rootInit": 0x803054dc,
		"rootInit": 0x803054dc,
		"JAISystemInterface::trackInit": 0x80305554,
		"trackInit": 0x80305554,
		"JAISystemInterface::outerInit": 0x80305644,
		"outerInit": 0x80305644,
		"JAISystemInterface::setSePortParameter": 0x80305834,
		"setSePortParameter": 0x80305834,
		"JAISystemInterface::setSeqData": 0x80305988,
		"JAISystemInterface::startSeq": 0x80305a08,
		"JAISystemInterface::stopSeq": 0x80305a60,
		"JAISystemInterface::writePortApp": 0x80305aa8,
		"JAISystemInterface::readPortApp": 0x80305b00,
		"JSystem::__sinit_JAISystemInterface_cpp": 0x80305b58,
		"__sinit_JAISystemInterface_cpp": 0x80305b58,
		"JASystem::Kernel::TPortCmd::~TPortCmd": 0x80305b94,
		"JASystem::TBank::getCurrentHeap": 0x80305bd4,
		"JASystem::BankMgr::init": 0x80305be8,
		"JASystem::BankMgr::registBankBNK": 0x80305d04,
		"registBankBNK": 0x80305d04,
		"JASystem::BankMgr::getPhysicalNumber": 0x80305d6c,
		"getPhysicalNumber": 0x80305d6c,
		"JASystem::BankMgr::setVir2PhyTable": 0x80305d7c,
		"setVir2PhyTable": 0x80305d7c,
		"JASystem::BankMgr::assignWaveBank": 0x80305d98,
		"assignWaveBank": 0x80305d98,
		"JASystem::BankMgr::noteOn": 0x80305e0c,
		"JASystem::BankMgr::noteOnOsc": 0x8030621c,
		"noteOnOsc": 0x8030621c,
		"JASystem::BankMgr::gateOn": 0x80306374,
		"JASystem::TBasicBank::TBasicBank": 0x8030643c,
		"JASystem::TBank::~TBank": 0x80306468,
		"JASystem::TBasicBank::~TBasicBank": 0x803064b4,
		"JASystem::TBasicBank::setInstCount": 0x80306528,
		"setInstCount": 0x80306528,
		"JASystem::TBasicBank::setInst": 0x8030658c,
		"setInst": 0x8030658c,
		"JASystem::TBasicBank::getInst": 0x8030659c,
		"getInst": 0x8030659c,
		"JASystem::TBasicBank::getType": 0x803065c0,
		"JASystem::TBasicInst::TBasicInst": 0x803065cc,
		"JASystem::TInst::~TInst": 0x80306610,
		"JASystem::TBasicInst::~TBasicInst": 0x8030665c,
		"JASystem::TBasicInst::getParam": 0x803066e8,
		"JASystem::TBasicInst::getKeymapIndex": 0x803068c4,
		"getKeymapIndex": 0x803068c4,
		"JASystem::TBasicInst::setKeyRegionCount": 0x803068cc,
		"setKeyRegionCount": 0x803068cc,
		"JASystem::TBasicInst::TKeymap::TKeymap": 0x80306954,
		"JASystem::TBasicInst::setEffectCount": 0x8030696c,
		"JASystem::TBasicInst::setEffect": 0x803069e4,
		"JASystem::TBasicInst::setOscCount": 0x803069f4,
		"setOscCount": 0x803069f4,
		"JASystem::TBasicInst::setOsc": 0x80306a6c,
		"setOsc": 0x80306a6c,
		"JASystem::TBasicInst::getKeyRegion": 0x80306a7c,
		"getKeyRegion": 0x80306a7c,
		"JASystem::TBasicInst::TKeymap::~TKeymap": 0x80306aa0,
		"JASystem::TBasicInst::TKeymap::setVeloRegionCount": 0x80306af4,
		"JASystem::TBasicInst::getType": 0x80306b94,
		"JASystem::TBasicWaveBank::TBasicWaveBank": 0x80306ba0,
		"JASystem::TWaveBank::~TWaveBank": 0x80306bd0,
		"JASystem::TBasicWaveBank::~TBasicWaveBank": 0x80306c1c,
		"JASystem::TBasicWaveBank::getWaveGroup": 0x80306ca0,
		"getWaveGroup": 0x80306ca0,
		"JASystem::TBasicWaveBank::setGroupCount": 0x80306cc4,
		"setGroupCount": 0x80306cc4,
		"JASystem::TBasicWaveBank::setWaveTableSize": 0x80306d4c,
		"JASystem::TBasicWaveBank::incWaveTable": 0x80306db0,
		"incWaveTable": 0x80306db0,
		"JASystem::TBasicWaveBank::decWaveTable": 0x80306e10,
		"decWaveTable": 0x80306e10,
		"JASystem::TBasicWaveBank::getWaveHandle": 0x80306ea0,
		"JASystem::TBasicWaveBank::TWaveGroup::TWaveGroup": 0x80306ed4,
		"JASystem::Kernel::THeap::~THeap": 0x80306f34,
		"JASystem::TBasicWaveBank::TWaveGroup::~TWaveGroup": 0x80306f74,
		"JASystem::TBasicWaveBank::TWaveInfo::~TWaveInfo": 0x80306fe4,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveArcFileName": 0x80307044,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveCount": 0x803070b8,
		"setWaveCount": 0x803070b8,
		"JASystem::TBasicWaveBank::TWaveInfo::TWaveInfo": 0x80307258,
		"JASystem::TBasicWaveBank::TWaveHandle::~TWaveHandle": 0x80307288,
		"JASystem::TWaveHandle::~TWaveHandle": 0x803072e4,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveInfo": 0x80307330,
		"JASystem::TBasicWaveBank::TWaveHandle::getWaveInfo": 0x803073b4,
		"JASystem::TBasicWaveBank::TWaveHandle::getWavePtr": 0x803073bc,
		"JASystem::TBasicWaveBank::TWaveGroup::getWaveArcFileName": 0x803073e0,
		"JASystem::TBasicWaveBank::TWaveGroup::getHeap": 0x803073e8,
		"JASystem::TBasicWaveBank::getType": 0x803073f0,
		"JASystem::BNKParser::createBasicBank": 0x803073fc,
		"createBasicBank": 0x803073fc,
		"JASystem::TDrumSet::TDrumSet": 0x80307b2c,
		"JASystem::BNKParser::findOscPtr": 0x80307b94,
		"findOscPtr": 0x80307b94,
		"JASystem::BNKParser::getOscTableEndPtr": 0x80307cf0,
		"getOscTableEndPtr": 0x80307cf0,
		"JASystem::TDrumSet::getParam": 0x80307ddc,
		"JASystem::TDrumSet::getPerc": 0x80307fcc,
		"getPerc": 0x80307fcc,
		"JASystem::TDrumSet::TPerc::TPerc": 0x80307fe0,
		"JASystem::TDrumSet::TPerc::~TPerc": 0x80308014,
		"JASystem::TDrumSet::TPerc::setEffectCount": 0x80308070,
		"JASystem::TDrumSet::TPerc::setVeloRegionCount": 0x803080e8,
		"JASystem::TDrumSet::TPerc::getVeloRegion": 0x80308140,
		"JASystem::TDrumSet::TPerc::setEffect": 0x80308150,
		"JASystem::TDrumSet::TPerc::setRelease": 0x80308160,
		"setRelease": 0x80308160,
		"JASystem::TDrumSet::~TDrumSet": 0x80308168,
		"JASystem::TDrumSet::getType": 0x803081ec,
		"JASystem::TInstEffect::setTarget": 0x803081f8,
		"setTarget": 0x803081f8,
		"JASystem::TInstRand::getY": 0x80308200,
		"JASystem::TInstSense::getY": 0x803082a0,
		"JASystem::TInstSense::setParams": 0x803083c4,
		"setParams": 0x803083c4,
		"JASystem::TSimpleWaveBank::TSimpleWaveBank": 0x803083d8,
		"JASystem::TSimpleWaveBank::~TSimpleWaveBank": 0x80308458,
		"JASystem::TSimpleWaveBank::TWaveHandle::~TWaveHandle": 0x803084e4,
		"JASystem::TSimpleWaveBank::setWaveTableSize": 0x80308540,
		"JASystem::TSimpleWaveBank::TWaveHandle::TWaveHandle": 0x803085c8,
		"JASystem::TSimpleWaveBank::getWaveHandle": 0x803085ec,
		"JASystem::TSimpleWaveBank::setWaveInfo": 0x80308610,
		"JASystem::TSimpleWaveBank::setWaveArcFileName": 0x80308698,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWaveInfo": 0x8030870c,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWavePtr": 0x80308714,
		"JASystem::TSimpleWaveBank::getType": 0x80308738,
		"JASystem::WaveArcLoader::init": 0x8030876c,
		"JASystem::WaveArcLoader::setCurrentDir": 0x803087b8,
		"setCurrentDir": 0x803087b8,
		"JASystem::WaveArcLoader::getCurrentDir": 0x80308818,
		"getCurrentDir": 0x80308818,
		"JASystem::WaveArcLoader::loadWave": 0x80308824,
		"JASystem::WaveArcLoader::eraseWave": 0x80308954,
		"JASystem::WaveArcLoader::getRootHeap": 0x803089e0,
		"getRootHeap": 0x803089e0,
		"JSystem::__sinit_JASWaveArcLoader_cpp": 0x803089ec,
		"__sinit_JASWaveArcLoader_cpp": 0x803089ec,
		"JASystem::TWaveBank::getCurrentHeap": 0x80308a28,
		"JASystem::WaveBankMgr::init": 0x80308a3c,
		"JASystem::WaveBankMgr::getWaveBank": 0x80308a94,
		"getWaveBank": 0x80308a94,
		"JASystem::WaveBankMgr::registWaveBankWS": 0x80308aa4,
		"registWaveBankWS": 0x80308aa4,
		"JASystem::WaveBankMgr::loadWave": 0x80308b24,
		"JASystem::WaveBankMgr::eraseWave": 0x80308c14,
		"JASystem::WSParser::getGroupCount": 0x80308d04,
		"getGroupCount": 0x80308d04,
		"JASystem::WSParser::createBasicWaveBank": 0x80308d2c,
		"createBasicWaveBank": 0x80308d2c,
		"JASystem::WSParser::createSimpleWaveBank": 0x80308f58,
		"createSimpleWaveBank": 0x80308f58,
		"JSystem::Console_printf": 0x80309220,
		"Console_printf": 0x80309220,
		"JASystem::AudioThread::setDSPSyncCount": 0x80309270,
		"setDSPSyncCount": 0x80309270,
		"JASystem::AudioThread::getDSPSyncCount": 0x80309278,
		"getDSPSyncCount": 0x80309278,
		"JASystem::AudioThread::syncAudio": 0x80309280,
		"syncAudio": 0x80309280,
		"JASystem::AudioThread::audioproc": 0x80309300,
		"audioproc": 0x80309300,
		"JASystem::AudioThread::syncDSP": 0x80309460,
		"syncDSP": 0x80309460,
		"JASystem::AudioThread::stop": 0x803094e8,
		"JASystem::AudioThread::setPriority": 0x80309538,
		"setPriority": 0x80309538,
		"JASystem::AudioThread::start": 0x80309554,
		"JASystem::Driver::DSPQueue::init": 0x80309670,
		"JASystem::Driver::DSPQueue::enQueue": 0x803096e0,
		"enQueue": 0x803096e0,
		"JASystem::Driver::DSPQueue::deQueue": 0x80309790,
		"deQueue": 0x80309790,
		"JASystem::Driver::DSPQueue::deleteQueue": 0x80309898,
		"deleteQueue": 0x80309898,
		"JASystem::Driver::DSPQueue::checkQueue": 0x803098f8,
		"checkQueue": 0x803098f8,
		"JASystem::Driver::calcEffect": 0x803099d4,
		"calcEffect": 0x803099d4,
		"JASystem::Driver::calcPan": 0x80309a94,
		"JASystem::Driver::__UpdateJcToDSP": 0x80309b90,
		"__UpdateJcToDSP": 0x80309b90,
		"JASystem::Driver::__UpdateJcToDSPInit": 0x80309cd8,
		"__UpdateJcToDSPInit": 0x80309cd8,
		"JASystem::Driver::extraUpdate": 0x80309de0,
		"extraUpdate": 0x80309de0,
		"JASystem::Driver::updatecallLogicalChannel": 0x80309ec4,
		"updatecallLogicalChannel": 0x80309ec4,
		"JASystem::Driver::killBrokenLogicalChannels": 0x8030a060,
		"killBrokenLogicalChannels": 0x8030a060,
		"JASystem::Driver::updateMixer": 0x8030a108,
		"updateMixer": 0x8030a108,
		"JASystem::Driver::updatecallDSPChannel": 0x8030a33c,
		"updatecallDSPChannel": 0x8030a33c,
		"JASystem::TChannel::init": 0x8030a6e0,
		"JASystem::TChannel::setOscillator": 0x8030a888,
		"setOscillator": 0x8030a888,
		"JASystem::TChannel::setOscInit": 0x8030a898,
		"setOscInit": 0x8030a898,
		"JASystem::TChannel::forceStopOsc": 0x8030a8cc,
		"forceStopOsc": 0x8030a8cc,
		"JASystem::TChannel::releaseOsc": 0x8030a920,
		"releaseOsc": 0x8030a920,
		"JASystem::TChannel::directReleaseOsc": 0x8030a974,
		"directReleaseOsc": 0x8030a974,
		"JASystem::TChannel::bankOscToOfs": 0x8030a988,
		"bankOscToOfs": 0x8030a988,
		"JASystem::TChannel::effectOsc": 0x8030a9dc,
		"effectOsc": 0x8030a9dc,
		"JASystem::TChannel::getOscState": 0x8030aa54,
		"getOscState": 0x8030aa54,
		"JASystem::TChannel::isOsc": 0x8030aa68,
		"isOsc": 0x8030aa68,
		"JASystem::TChannel::copyOsc": 0x8030aa90,
		"copyOsc": 0x8030aa90,
		"JASystem::TChannel::overwriteOsc": 0x8030aaf0,
		"overwriteOsc": 0x8030aaf0,
		"JASystem::TChannel::setKeySweepTarget": 0x8030abd4,
		"setKeySweepTarget": 0x8030abd4,
		"JASystem::TChannel::setPauseFlag": 0x8030ac6c,
		"JASystem::TChannel::setPauseFlagReq": 0x8030ac74,
		"setPauseFlagReq": 0x8030ac74,
		"JASystem::TChannel::setPanPower": 0x8030ac84,
		"setPanPower": 0x8030ac84,
		"JASystem::TChannel::resetInitialVolume": 0x8030acb8,
		"resetInitialVolume": 0x8030acb8,
		"JASystem::TChannel::play": 0x8030ad48,
		"JASystem::TChannel::stop": 0x8030ae6c,
		"JASystem::TChannel::updateJcToDSP": 0x8030aec4,
		"updateJcToDSP": 0x8030aec4,
		"JASystem::TChannel::forceStopLogicalChannel": 0x8030aefc,
		"forceStopLogicalChannel": 0x8030aefc,
		"JASystem::TChannel::stopLogicalChannel": 0x8030af34,
		"stopLogicalChannel": 0x8030af34,
		"JASystem::TChannel::playLogicalChannel": 0x8030afa4,
		"playLogicalChannel": 0x8030afa4,
		"JASystem::TChannel::updateEffectorParam": 0x8030b23c,
		"updateEffectorParam": 0x8030b23c,
		"JASystem::TChannelMgr::init": 0x8030b508,
		"JASystem::TChannelMgr::stopAll": 0x8030b5fc,
		"stopAll": 0x8030b5fc,
		"JASystem::TChannelMgr::stopAllRelease": 0x8030b640,
		"stopAllRelease": 0x8030b640,
		"JASystem::TChannelMgr::addListHead": 0x8030b69c,
		"addListHead": 0x8030b69c,
		"JASystem::TChannelMgr::addListTail": 0x8030b6fc,
		"addListTail": 0x8030b6fc,
		"JASystem::TChannelMgr::getListHead": 0x8030b790,
		"getListHead": 0x8030b790,
		"JASystem::TChannelMgr::cutList": 0x8030b808,
		"cutList": 0x8030b808,
		"JASystem::TChannelMgr::initAllocChannel": 0x8030b884,
		"initAllocChannel": 0x8030b884,
		"JASystem::TChannelMgr::getLogicalChannel": 0x8030b8f8,
		"getLogicalChannel": 0x8030b8f8,
		"JASystem::TChannelMgr::receiveAllChannels": 0x8030ba3c,
		"receiveAllChannels": 0x8030ba3c,
		"JASystem::TChannelMgr::checkLimitStart": 0x8030bb94,
		"checkLimitStart": 0x8030bb94,
		"JASystem::TChannelMgr::checkLimitStop": 0x8030bd18,
		"checkLimitStop": 0x8030bd18,
		"JASystem::ChGlobal::getChannelHandle": 0x8030bde4,
		"getChannelHandle": 0x8030bde4,
		"JASystem::ChGlobal::init": 0x8030be04,
		"JASystem::TOscillator::~TOscillator": 0x8030bf2c,
		"JASystem::TOscillator::TOscillator": 0x8030bf6c,
		"JASystem::TChannel::~TChannel": 0x8030bf9c,
		"JASystem::TChannel::TChannel": 0x8030bfdc,
		"JASystem::ChGlobal::alloc": 0x8030c004,
		"JASystem::ChGlobal::release": 0x8030c0ac,
		"JASystem::ChGlobal::releaseAll": 0x8030c110,
		"releaseAll": 0x8030c110,
		"JASystem::Driver::init": 0x8030c25c,
		"JASystem::Driver::setMixerLevel": 0x8030c294,
		"setMixerLevel": 0x8030c294,
		"JASystem::Driver::getMixerLevel": 0x8030c2d0,
		"getMixerLevel": 0x8030c2d0,
		"JASystem::Driver::setOutputMode": 0x8030c2d8,
		"JASystem::Driver::getOutputMode": 0x8030c2e0,
		"getOutputMode": 0x8030c2e0,
		"JASystem::Driver::getUpdateInterval": 0x8030c2e8,
		"getUpdateInterval": 0x8030c2e8,
		"JASystem::DSPBuf::updateDSP": 0x8030c2f0,
		"updateDSP": 0x8030c2f0,
		"JASystem::DSPBuf::mixDSP": 0x8030c344,
		"mixDSP": 0x8030c344,
		"JASystem::DSPBuf::finishDSPFrame": 0x8030c368,
		"finishDSPFrame": 0x8030c368,
		"JASystem::DSPBuf::process": 0x8030c38c,
		"process": 0x8030c38c,
		"JASystem::TDSPChannel::forceStop": 0x8030c7f0,
		"JASystem::TDSPChannel::forceDelete": 0x8030c880,
		"forceDelete": 0x8030c880,
		"JASystem::TDSPChannel::play": 0x8030c894,
		"JASystem::TDSPChannel::stop": 0x8030c8cc,
		"JASystem::TDSPChannel::initAll": 0x8030c8fc,
		"initAll": 0x8030c8fc,
		"JASystem::TDSPChannel::~TDSPChannel": 0x8030c9ec,
		"JASystem::TDSPChannel::TDSPChannel": 0x8030ca2c,
		"JASystem::TDSPChannel::alloc": 0x8030ca3c,
		"JASystem::TDSPChannel::free": 0x8030cb3c,
		"JASystem::TDSPChannel::getLower": 0x8030cbc4,
		"getLower": 0x8030cbc4,
		"JASystem::TDSPChannel::getLowerActive": 0x8030cc78,
		"getLowerActive": 0x8030cc78,
		"JASystem::TDSPChannel::breakLower": 0x8030cd04,
		"breakLower": 0x8030cd04,
		"JASystem::TDSPChannel::updateAll": 0x8030cdf0,
		"updateAll": 0x8030cdf0,
		"JSystem::DSP_CreateMap": 0x8030d018,
		"DSP_CreateMap": 0x8030d018,
		"JASystem::DSPInterface::getDSPHandle": 0x8030d0a4,
		"getDSPHandle": 0x8030d0a4,
		"JASystem::DSPInterface::invalChannelAll": 0x8030d0b8,
		"invalChannelAll": 0x8030d0b8,
		"JASystem::DSPInterface::initBuffer": 0x8030d0e0,
		"initBuffer": 0x8030d0e0,
		"JASystem::DSPInterface::getFXHandle": 0x8030d1ec,
		"getFXHandle": 0x8030d1ec,
		"JASystem::DSPInterface::FXBuffer::setFXLine": 0x8030d1fc,
		"setFXLine": 0x8030d1fc,
		"JASystem::DSPInterface::DSPBuffer::allocInit": 0x8030d350,
		"allocInit": 0x8030d350,
		"JASystem::DSPInterface::DSPBuffer::playStart": 0x8030d39c,
		"playStart": 0x8030d39c,
		"JASystem::DSPInterface::DSPBuffer::setWaveInfo": 0x8030d458,
		"JASystem::DSPInterface::DSPBuffer::setOscInfo": 0x8030d524,
		"setOscInfo": 0x8030d524,
		"JASystem::DSPInterface::DSPBuffer::initAutoMixer": 0x8030d53c,
		"initAutoMixer": 0x8030d53c,
		"JASystem::DSPInterface::DSPBuffer::setAutoMixer": 0x8030d568,
		"setAutoMixer": 0x8030d568,
		"JASystem::DSPInterface::DSPBuffer::setPitch": 0x8030d58c,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitDelayMax": 0x8030d5a4,
		"setMixerInitDelayMax": 0x8030d5a4,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitVolume": 0x8030d5b0,
		"setMixerInitVolume": 0x8030d5b0,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolume": 0x8030d5d4,
		"setMixerVolume": 0x8030d5d4,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolumeOnly": 0x8030d604,
		"setMixerVolumeOnly": 0x8030d604,
		"JASystem::DSPInterface::DSPBuffer::setPauseFlag": 0x8030d620,
		"JASystem::DSPInterface::DSPBuffer::flushChannel": 0x8030d62c,
		"flushChannel": 0x8030d62c,
		"JASystem::DSPInterface::DSPBuffer::setIIRFilterParam": 0x8030d650,
		"setIIRFilterParam": 0x8030d650,
		"JASystem::DSPInterface::DSPBuffer::setFIR8FilterParam": 0x8030d674,
		"setFIR8FilterParam": 0x8030d674,
		"JASystem::DSPInterface::DSPBuffer::setFilterMode": 0x8030d6b8,
		"setFilterMode": 0x8030d6b8,
		"JASystem::DSPInterface::DSPBuffer::initFilter": 0x8030d6f8,
		"initFilter": 0x8030d6f8,
		"JASystem::DSPInterface::DSPBuffer::setDistFilter": 0x8030d740,
		"setDistFilter": 0x8030d740,
		"JASystem::DSPInterface::DSPBuffer::setBusConnect": 0x8030d748,
		"setBusConnect": 0x8030d748,
		"JASystem::TOscillator::init": 0x8030d76c,
		"JASystem::TOscillator::initStart": 0x8030d7a4,
		"initStart": 0x8030d7a4,
		"JASystem::TOscillator::getOffset": 0x8030d804,
		"getOffset": 0x8030d804,
		"JASystem::TOscillator::getOffsetNoCount": 0x8030d910,
		"getOffsetNoCount": 0x8030d910,
		"JASystem::TOscillator::forceStop": 0x8030d96c,
		"JASystem::TOscillator::release": 0x8030d9a8,
		"JASystem::TOscillator::calc": 0x8030db30,
		"JASystem::Kernel::init": 0x8030ded0,
		"JASystem::Kernel::initSystem": 0x8030df00,
		"initSystem": 0x8030df00,
		"JASystem::Kernel::registerMixCallback": 0x8030dfb4,
		"registerMixCallback": 0x8030dfb4,
		"JASystem::Kernel::vframeWork": 0x8030dfc0,
		"vframeWork": 0x8030dfc0,
		"JASystem::Kernel::updateDac": 0x8030e150,
		"updateDac": 0x8030e150,
		"JASystem::Kernel::mixMonoTrack": 0x8030e1f8,
		"mixMonoTrack": 0x8030e1f8,
		"JASystem::Kernel::mixMonoTrackWide": 0x8030e2f4,
		"mixMonoTrackWide": 0x8030e2f4,
		"JASystem::Kernel::mixExtraTrack": 0x8030e3f0,
		"mixExtraTrack": 0x8030e3f0,
		"JASystem::Kernel::mixInterleaveTrack": 0x8030e508,
		"mixInterleaveTrack": 0x8030e508,
		"JASystem::Calc::initSinfT": 0x8030e5a4,
		"initSinfT": 0x8030e5a4,
		"JASystem::Calc::sinfT": 0x8030e6cc,
		"sinfT": 0x8030e6cc,
		"JASystem::Calc::sinfDolby2": 0x8030e6f8,
		"sinfDolby2": 0x8030e6f8,
		"JASystem::Calc::imixcopy": 0x8030e724,
		"imixcopy": 0x8030e724,
		"JASystem::Calc::bcopy": 0x8030e7f8,
		"bcopy": 0x8030e7f8,
		"JASystem::Calc::bzero": 0x8030ead8,
		"bzero": 0x8030ead8,
		"JASystem::Kernel::resetCallback": 0x8030ed3c,
		"resetCallback": 0x8030ed3c,
		"JASystem::Kernel::registerSubframeCallback": 0x8030edb0,
		"registerSubframeCallback": 0x8030edb0,
		"JASystem::Kernel::registerAiCallback": 0x8030ee08,
		"registerAiCallback": 0x8030ee08,
		"JASystem::Kernel::aiCallback": 0x8030eef0,
		"aiCallback": 0x8030eef0,
		"JASystem::Kernel::subframeCallback": 0x8030ef90,
		"subframeCallback": 0x8030ef90,
		"JASystem::Kernel::TPortCmd::TPortCmd": 0x8030f030,
		"JASystem::Kernel::TPortCmd::addPortCmdOnce": 0x8030f048,
		"addPortCmdOnce": 0x8030f048,
		"JASystem::Kernel::TPortCmd::setPortCmd": 0x8030f06c,
		"setPortCmd": 0x8030f06c,
		"JASystem::Kernel::TPortCmd::addPortCmd": 0x8030f084,
		"addPortCmd": 0x8030f084,
		"JASystem::Kernel::portCmdInit": 0x8030f104,
		"portCmdInit": 0x8030f104,
		"JASystem::Kernel::getPortCmd": 0x8030f14c,
		"getPortCmd": 0x8030f14c,
		"JASystem::Kernel::portCmdMain": 0x8030f18c,
		"portCmdMain": 0x8030f18c,
		"JASystem::Dvd::init": 0x8030f1fc,
		"JASystem::Dvd::extendPath": 0x8030f248,
		"extendPath": 0x8030f248,
		"JASystem::Dvd::dvdProcInit": 0x8030f2d0,
		"dvdProcInit": 0x8030f2d0,
		"JASystem::Dvd::dvdProc": 0x8030f37c,
		"dvdProc": 0x8030f37c,
		"JASystem::Dvd::loadToDramDvdTMain": 0x8030f408,
		"loadToDramDvdTMain": 0x8030f408,
		"JASystem::Dvd::loadToDramDvdT": 0x8030f530,
		"loadToDramDvdT": 0x8030f530,
		"JASystem::Dvd::loadToAramDvdTMain": 0x8030f5e4,
		"loadToAramDvdTMain": 0x8030f5e4,
		"JASystem::Dvd::loadToAramDvdT": 0x8030f84c,
		"loadToAramDvdT": 0x8030f84c,
		"JASystem::Dvd::checkFileExtend": 0x8030f900,
		"checkFileExtend": 0x8030f900,
		"JASystem::Dvd::loadFileDvdT": 0x8030f9b4,
		"loadFileDvdT": 0x8030f9b4,
		"JASystem::Dvd::checkPassDvdT": 0x8030fa9c,
		"checkPassDvdT": 0x8030fa9c,
		"JASystem::Dvd::checkFile": 0x8030fb20,
		"checkFile": 0x8030fb20,
		"JASystem::Dvd::loadFile": 0x8030fb7c,
		"JASystem::Dvd::pauseDvdT": 0x8030fc30,
		"pauseDvdT": 0x8030fc30,
		"JASystem::Dvd::unpauseDvdT": 0x8030fc3c,
		"unpauseDvdT": 0x8030fc3c,
		"JASystem::Dvd::registerFastOpen": 0x8030fc74,
		"registerFastOpen": 0x8030fc74,
		"JASystem::Dvd::openDvd": 0x8030fd64,
		"openDvd": 0x8030fd64,
		"JASystem::Dvd::getCallStack": 0x8030fdbc,
		"getCallStack": 0x8030fdbc,
		"JASystem::Dvd::dvdReadMutex": 0x8030fe18,
		"dvdReadMutex": 0x8030fe18,
		"JASystem::Dvd::doError": 0x8030fea4,
		"doError": 0x8030fea4,
		"JASystem::Dvd::doFinish": 0x8030feec,
		"doFinish": 0x8030feec,
		"JASystem::Dvd::dvdThreadCheckBack": 0x8030ff30,
		"dvdThreadCheckBack": 0x8030ff30,
		"JASystem::Dvd::allocDvdBuffer": 0x8030ff7c,
		"allocDvdBuffer": 0x8030ff7c,
		"JASystem::Dvd::writeBufferSize": 0x80310054,
		"writeBufferSize": 0x80310054,
		"JASystem::Dvd::updateBuffer": 0x8031010c,
		"updateBuffer": 0x8031010c,
		"JASystem::Dvd::aramDmaFinish": 0x803101e0,
		"aramDmaFinish": 0x803101e0,
		"JASystem::HardStream::main": 0x803101f0,
		"JASystem::HardStream::firstBgmCallback": 0x80310674,
		"firstBgmCallback": 0x80310674,
		"JASystem::HardStream::secondBgmCallback": 0x80310700,
		"secondBgmCallback": 0x80310700,
		"JASystem::HardStream::getAddrCallback": 0x80310714,
		"getAddrCallback": 0x80310714,
		"JASystem::HardStream::TControl::TControl": 0x80310894,
		"JASystem::HardStream::TControl::getIntroNum": 0x803108f4,
		"getIntroNum": 0x803108f4,
		"JASystem::HardStream::TControl::getLoopNum": 0x8031092c,
		"getLoopNum": 0x8031092c,
		"JASystem::HardStream::TControl::clearListOne": 0x80310964,
		"clearListOne": 0x80310964,
		"JASystem::HardStream::TControl::getLastAddr": 0x80310998,
		"getLastAddr": 0x80310998,
		"JASystem::HardStream::TControl::startFirst": 0x803109ac,
		"startFirst": 0x803109ac,
		"JASystem::HardStream::TControl::startSecond": 0x80310acc,
		"startSecond": 0x80310acc,
		"JASystem::HardStream::TControl::resetFader": 0x80310bec,
		"resetFader": 0x80310bec,
		"JASystem::HardStream::TControl::getCurVol": 0x80310c28,
		"getCurVol": 0x80310c28,
		"JASystem::HardStream::TControl::calcCurVolume": 0x80310c60,
		"calcCurVolume": 0x80310c60,
		"JASystem::HardStream::TControl::volFloatToU8": 0x80310ee4,
		"volFloatToU8": 0x80310ee4,
		"JSystem::__sinit_JASHardStream_cpp": 0x80310f24,
		"__sinit_JASHardStream_cpp": 0x80310f24,
		"JASystem::HardStream::TControl::~TControl": 0x80310f60,
		"JASystem::Kernel::THeap::THeap": 0x80310fa0,
		"JASystem::Kernel::THeap::selfAlloc": 0x80310fec,
		"selfAlloc": 0x80310fec,
		"JASystem::Kernel::THeap::initMotherHeap": 0x803110ec,
		"initMotherHeap": 0x803110ec,
		"JASystem::Kernel::THeap::allocHeapCheck": 0x80311148,
		"allocHeapCheck": 0x80311148,
		"JASystem::Kernel::THeap::alloc": 0x803112fc,
		"JASystem::Kernel::THeap::free": 0x8031133c,
		"JASystem::Kernel::TSolidHeap::TSolidHeap": 0x803114dc,
		"JASystem::Kernel::TSolidHeap::alloc": 0x803114f8,
		"JASystem::Kernel::TSolidHeap::init": 0x80311554,
		"JASystem::Kernel::TSolidHeap::getRemain": 0x8031159c,
		"getRemain": 0x8031159c,
		"JASystem::Kernel::stackInit": 0x803115b4,
		"stackInit": 0x803115b4,
		"JASystem::Kernel::probeStart": 0x80311684,
		"probeStart": 0x80311684,
		"JASystem::Kernel::probeFinish": 0x80311688,
		"probeFinish": 0x80311688,
		"JASystem::Kernel::sysDramSetup": 0x8031168c,
		"sysDramSetup": 0x8031168c,
		"JASystem::Kernel::allocFromSysDram": 0x803116e4,
		"allocFromSysDram": 0x803116e4,
		"JASystem::Kernel::sysAramSetup": 0x8031173c,
		"sysAramSetup": 0x8031173c,
		"JASystem::Kernel::allocFromSysAramFull": 0x803117a4,
		"allocFromSysAramFull": 0x803117a4,
		"JSystem::__sinit_JASSystemHeap_cpp": 0x80311804,
		"__sinit_JASSystemHeap_cpp": 0x80311804,
		"JASystem::Vload::initHeader": 0x80311840,
		"initHeader": 0x80311840,
		"JASystem::Vload::initHeaderM": 0x80311868,
		"initHeaderM": 0x80311868,
		"JASystem::Vload::getArchiveHandle": 0x803119d4,
		"getArchiveHandle": 0x803119d4,
		"JASystem::Vload::getRealHandle": 0x80311a5c,
		"getRealHandle": 0x80311a5c,
		"JASystem::Vload::checkSize": 0x80311ad4,
		"checkSize": 0x80311ad4,
		"JASystem::Vload::loadFile": 0x80311b08,
		"JASystem::Vload::loadFileAsync": 0x80311bb4,
		"loadFileAsync": 0x80311bb4,
		"JASystem::Vload::initVloadBuffers": 0x80311c54,
		"initVloadBuffers": 0x80311c54,
		"JASystem::TTrack::TNoteMgr::init": 0x80311d18,
		"JASystem::TTrack::TNoteMgr::endProcess": 0x80311d70,
		"endProcess": 0x80311d70,
		"JASystem::TTrack::TNoteMgr::getChannel": 0x80311d98,
		"getChannel": 0x80311d98,
		"JASystem::TTrack::TOuterParam::TOuterParam": 0x80311de8,
		"JASystem::TTrack::TOuterParam::initExtBuffer": 0x80311e34,
		"initExtBuffer": 0x80311e34,
		"JASystem::TTrack::TOuterParam::setOuterSwitch": 0x80311e44,
		"setOuterSwitch": 0x80311e44,
		"JASystem::TTrack::TOuterParam::checkOuterSwitch": 0x80311e4c,
		"checkOuterSwitch": 0x80311e4c,
		"JASystem::TTrack::TOuterParam::setOuterUpdate": 0x80311e6c,
		"setOuterUpdate": 0x80311e6c,
		"JASystem::TTrack::TOuterParam::getOuterUpdate": 0x80311e74,
		"getOuterUpdate": 0x80311e74,
		"JASystem::TTrack::TOuterParam::getIntFirFilter": 0x80311e7c,
		"getIntFirFilter": 0x80311e7c,
		"JASystem::TTrack::TOuterParam::setParam": 0x80311e8c,
		"setParam": 0x80311e8c,
		"JASystem::TTrack::TOuterParam::onSwitch": 0x80311f28,
		"onSwitch": 0x80311f28,
		"JASystem::TTrack::TOuterParam::setFirFilter": 0x80311f44,
		"setFirFilter": 0x80311f44,
		"JASystem::Player::extend8to16": 0x80311fa0,
		"extend8to16": 0x80311fa0,
		"JASystem::Player::pitchToCent": 0x80311fc0,
		"pitchToCent": 0x80311fc0,
		"JASystem::Player::getRandomS32": 0x8031208c,
		"getRandomS32": 0x8031208c,
		"JASystem::TRegisterParam::TRegisterParam": 0x803120c4,
		"JASystem::TRegisterParam::init": 0x80312114,
		"JASystem::TRegisterParam::inherit": 0x8031217c,
		"inherit": 0x8031217c,
		"JASystem::TRegisterParam::getBankNumber": 0x803121ec,
		"getBankNumber": 0x803121ec,
		"JASystem::TRegisterParam::getProgramNumber": 0x803121fc,
		"getProgramNumber": 0x803121fc,
		"JASystem::TSeqCtrl::init": 0x80312208,
		"JASystem::TSeqCtrl::loopE": 0x80312270,
		"loopE": 0x80312270,
		"JASystem::TSeqCtrl::waitCountDown": 0x803122dc,
		"waitCountDown": 0x803122dc,
		"JASystem::TSeqCtrl::callIntr": 0x8031230c,
		"callIntr": 0x8031230c,
		"JASystem::TSeqCtrl::retIntr": 0x80312344,
		"retIntr": 0x80312344,
		"JASystem::TSeqCtrl::get16": 0x80312378,
		"get16": 0x80312378,
		"JASystem::TSeqCtrl::get24": 0x803123a0,
		"get24": 0x803123a0,
		"JASystem::TSeqCtrl::get32": 0x803123c8,
		"get32": 0x803123c8,
		"JASystem::TSeqCtrl::read16": 0x80312400,
		"read16": 0x80312400,
		"JASystem::TSeqCtrl::read24": 0x80312438,
		"read24": 0x80312438,
		"JASystem::TTrack::TTrack": 0x8031247c,
		"JASystem::TTrack::MoveParam_::MoveParam_": 0x8031269c,
		"JASystem::TTrack::AInnerParam_::AInnerParam_": 0x803126b4,
		"JASystem::TTrack::setInterrupt": 0x803127e4,
		"setInterrupt": 0x803127e4,
		"JASystem::TTrack::assignExtBuffer": 0x8031280c,
		"assignExtBuffer": 0x8031280c,
		"JASystem::TTrack::setInnerMemory": 0x80312828,
		"setInnerMemory": 0x80312828,
		"JASystem::TTrack::setPanSwitchExt": 0x80312830,
		"setPanSwitchExt": 0x80312830,
		"JASystem::TTrack::setPanSwitchParent": 0x80312840,
		"setPanSwitchParent": 0x80312840,
		"JASystem::TTrack::flushAll": 0x80312850,
		"flushAll": 0x80312850,
		"JASystem::TTrack::initTimed": 0x80312888,
		"initTimed": 0x80312888,
		"JASystem::TTrack::noteOn": 0x803129a8,
		"JASystem::TTrack::noteOff": 0x80312ce0,
		"noteOff": 0x80312ce0,
		"JASystem::TTrack::gateOn": 0x80312d6c,
		"JASystem::TTrack::oscSetupFull": 0x80312ddc,
		"oscSetupFull": 0x80312ddc,
		"JASystem::TTrack::oscSetupSimpleEnv": 0x80312f08,
		"oscSetupSimpleEnv": 0x80312f08,
		"JASystem::TTrack::oscUpdateParam": 0x80312f78,
		"oscUpdateParam": 0x80312f78,
		"JASystem::TTrack::oscSetupSimple": 0x80312fe0,
		"oscSetupSimple": 0x80312fe0,
		"JASystem::TTrack::updateTrackAll": 0x803130bc,
		"updateTrackAll": 0x803130bc,
		"JASystem::TTrack::updateTrack": 0x80313474,
		"updateTrack": 0x80313474,
		"JASystem::TTrack::updateTempo": 0x803139a4,
		"updateTempo": 0x803139a4,
		"JASystem::TTrack::updateSeq": 0x80313ad0,
		"updateSeq": 0x80313ad0,
		"JASystem::TTrack::incSelfOsc": 0x80313ba4,
		"incSelfOsc": 0x80313ba4,
		"JASystem::TTrack::mainProc": 0x80313c98,
		"JASystem::TTrack::seqTimeToDspTime": 0x8031413c,
		"seqTimeToDspTime": 0x8031413c,
		"JASystem::TTrack::writeTimeParam": 0x803141f8,
		"writeTimeParam": 0x803141f8,
		"JASystem::TTrack::writeRegParam": 0x803143fc,
		"writeRegParam": 0x803143fc,
		"JASystem::TTrack::setSeqData": 0x80314904,
		"JASystem::TTrack::startSeq": 0x803149a8,
		"JASystem::TTrack::stopSeq": 0x80314a24,
		"JASystem::TTrack::closeTrack": 0x80314aa4,
		"closeTrack": 0x80314aa4,
		"JASystem::TTrack::muteTrack": 0x80314c04,
		"muteTrack": 0x80314c04,
		"JASystem::TTrack::initTrack": 0x80314cd4,
		"initTrack": 0x80314cd4,
		"JASystem::TTrack::startTrack": 0x80314f64,
		"startTrack": 0x80314f64,
		"JASystem::TTrack::openTrack": 0x80314ff8,
		"openTrack": 0x80314ff8,
		"JASystem::TTrack::loadTbl": 0x80315050,
		"loadTbl": 0x80315050,
		"JASystem::TTrack::readReg32": 0x803150f8,
		"readReg32": 0x803150f8,
		"JASystem::TTrack::exchangeRegisterValue": 0x80315194,
		"exchangeRegisterValue": 0x80315194,
		"JASystem::TTrack::readRegDirect": 0x8031524c,
		"readRegDirect": 0x8031524c,
		"JASystem::TTrack::writeRegDirect": 0x80315488,
		"writeRegDirect": 0x80315488,
		"JASystem::TTrack::writePortAppDirect": 0x80315554,
		"writePortAppDirect": 0x80315554,
		"JASystem::TTrack::readPortAppDirect": 0x803155b0,
		"readPortAppDirect": 0x803155b0,
		"JASystem::TTrack::setExtFirFilterD": 0x803155d4,
		"setExtFirFilterD": 0x803155d4,
		"JASystem::TTrack::writePortApp": 0x80315600,
		"JASystem::TTrack::readPortApp": 0x803156a8,
		"JASystem::TTrack::pauseTrack": 0x80315718,
		"pauseTrack": 0x80315718,
		"JASystem::TTrack::unPauseTrack": 0x8031584c,
		"unPauseTrack": 0x8031584c,
		"JASystem::TTrack::pauseTrackAll": 0x80315928,
		"pauseTrackAll": 0x80315928,
		"JASystem::TTrack::unPauseTrackAll": 0x8031594c,
		"unPauseTrackAll": 0x8031594c,
		"JASystem::TTrack::reset": 0x80315970,
		"JASystem::TTrack::panCalc": 0x80315980,
		"panCalc": 0x80315980,
		"JASystem::TTrack::rootCallback": 0x803159cc,
		"rootCallback": 0x803159cc,
		"JASystem::TTrack::registerTrackCallback": 0x80315b5c,
		"JSystem::__sinit_JASTrack_cpp": 0x80315b68,
		"__sinit_JASTrack_cpp": 0x80315b68,
		"JASystem::TIntrMgr::init": 0x80315b94,
		"JASystem::TIntrMgr::request": 0x80315bd8,
		"JASystem::TIntrMgr::setIntr": 0x80315bfc,
		"setIntr": 0x80315bfc,
		"JASystem::TIntrMgr::resetInter": 0x80315c20,
		"resetInter": 0x80315c20,
		"JASystem::TIntrMgr::checkIntr": 0x80315c38,
		"checkIntr": 0x80315c38,
		"JASystem::TIntrMgr::timerProcess": 0x80315ca4,
		"timerProcess": 0x80315ca4,
		"JASystem::TrackMgr::init": 0x80315d14,
		"JASystem::TTrack::~TTrack": 0x80315e08,
		"JASystem::TrackMgr::handleToSeq": 0x80315e6c,
		"handleToSeq": 0x80315e6c,
		"JASystem::TrackMgr::reset": 0x80315e90,
		"JASystem::TrackMgr::initRegistTrack": 0x80315f2c,
		"initRegistTrack": 0x80315f2c,
		"JASystem::TrackMgr::getNewTrack": 0x80315fbc,
		"getNewTrack": 0x80315fbc,
		"JASystem::TrackMgr::allocNewRoot": 0x80316044,
		"allocNewRoot": 0x80316044,
		"JASystem::TrackMgr::deAllocRoot": 0x8031608c,
		"deAllocRoot": 0x8031608c,
		"JASystem::TrackMgr::registTrack": 0x803160d8,
		"registTrack": 0x803160d8,
		"JASystem::TrackMgr::unRegistTrack": 0x803161f4,
		"unRegistTrack": 0x803161f4,
		"JASystem::TrackMgr::backTrack": 0x8031626c,
		"backTrack": 0x8031626c,
		"JASystem::TrackMgr::registerTrackCallback": 0x803162cc,
		"JASystem::TTrackPort::init": 0x803162ec,
		"JMath::TRandom_fast_::TRandom_fast_": 0x803163d4,
		"JMath::TRandom_enough_::setSeed": 0x803163dc,
		"setSeed": 0x803163dc,
		"J3DMaterialFactory_v21::J3DMaterialFactory_v21": 0x803164d0,
		"J3DMaterialFactory_v21::countUniqueMaterials": 0x803166b0,
		"J3DMaterialFactory_v21::countStages": 0x80316708,
		"J3DMaterialFactory_v21::create": 0x803167ec,
		"J3DMaterialFactory_v21::newMatColor": 0x80316f38,
		"J3DMaterialFactory_v21::newColorChanNum": 0x80316fc8,
		"J3DMaterialFactory_v21::newColorChan": 0x80317000,
		"J3DMaterialFactory_v21::newTexGenNum": 0x803170c8,
		"J3DMaterialFactory_v21::newTexCoord": 0x80317100,
		"J3DMaterialFactory_v21::newTexMtx": 0x80317174,
		"J3DMaterialFactory_v21::newCullMode": 0x80317208,
		"J3DMaterialFactory_v21::newTexNo": 0x80317248,
		"J3DMaterialFactory_v21::newTevOrder": 0x80317290,
		"J3DMaterialFactory_v21::newTevColor": 0x80317304,
		"J3DMaterialFactory_v21::newTevKColor": 0x8031739c,
		"J3DMaterialFactory_v21::newTevStageNum": 0x8031742c,
		"J3DMaterialFactory_v21::newTevStage": 0x80317464,
		"J3DMaterialFactory_v21::newTevSwapModeTable": 0x803176d0,
		"J3DMaterialFactory_v21::newFog": 0x8031776c,
		"J3DMaterialFactory_v21::newAlphaComp": 0x803177f8,
		"J3DMaterialFactory_v21::newBlend": 0x80317878,
		"J3DMaterialFactory_v21::newZMode": 0x803178f4,
		"J3DMaterialFactory_v21::newZCompLoc": 0x80317958,
		"J3DMaterialFactory_v21::newDither": 0x80317990,
		"J3DMaterialFactory_v21::newNBTScale": 0x803179c8,
		"JASystem::TSeqParser::cmdOpenTrack": 0x80317a88,
		"cmdOpenTrack": 0x80317a88,
		"JASystem::TSeqParser::cmdOpenTrackBros": 0x80317b08,
		"cmdOpenTrackBros": 0x80317b08,
		"JASystem::TSeqParser::cmdCall": 0x80317b9c,
		"cmdCall": 0x80317b9c,
		"JASystem::TSeqParser::cmdRet": 0x80317cb8,
		"cmdRet": 0x80317cb8,
		"JASystem::TSeqParser::cmdJmp": 0x80317d38,
		"cmdJmp": 0x80317d38,
		"JASystem::TSeqParser::cmdLoopS": 0x80317e74,
		"cmdLoopS": 0x80317e74,
		"JASystem::TSeqParser::cmdLoopE": 0x80317eac,
		"cmdLoopE": 0x80317eac,
		"JASystem::TSeqParser::cmdReadPort": 0x80317ee4,
		"cmdReadPort": 0x80317ee4,
		"JASystem::TSeqParser::cmdWritePort": 0x80317f30,
		"cmdWritePort": 0x80317f30,
		"JASystem::TSeqParser::cmdCheckPortImport": 0x80317f58,
		"cmdCheckPortImport": 0x80317f58,
		"JASystem::TSeqParser::cmdCheckPortExport": 0x80317f90,
		"cmdCheckPortExport": 0x80317f90,
		"JASystem::TSeqParser::cmdWait": 0x80317fc8,
		"cmdWait": 0x80317fc8,
		"JASystem::TSeqParser::cmdConnectName": 0x80317fe8,
		"cmdConnectName": 0x80317fe8,
		"JASystem::TSeqParser::cmdParentWritePort": 0x80318004,
		"cmdParentWritePort": 0x80318004,
		"JASystem::TSeqParser::cmdChildWritePort": 0x8031803c,
		"cmdChildWritePort": 0x8031803c,
		"JASystem::TSeqParser::cmdSetLastNote": 0x8031807c,
		"cmdSetLastNote": 0x8031807c,
		"JASystem::TSeqParser::cmdTimeRelate": 0x80318098,
		"cmdTimeRelate": 0x80318098,
		"JASystem::TSeqParser::cmdSimpleOsc": 0x803180bc,
		"cmdSimpleOsc": 0x803180bc,
		"JASystem::TSeqParser::cmdSimpleEnv": 0x803180ec,
		"cmdSimpleEnv": 0x803180ec,
		"JASystem::TSeqParser::cmdSimpleADSR": 0x80318120,
		"cmdSimpleADSR": 0x80318120,
		"JASystem::TSeqParser::cmdTranspose": 0x803181dc,
		"cmdTranspose": 0x803181dc,
		"JASystem::TSeqParser::cmdCloseTrack": 0x80318214,
		"cmdCloseTrack": 0x80318214,
		"JASystem::TSeqParser::cmdOutSwitch": 0x8031826c,
		"cmdOutSwitch": 0x8031826c,
		"JASystem::TSeqParser::cmdUpdateSync": 0x803182c4,
		"cmdUpdateSync": 0x803182c4,
		"JASystem::TSeqParser::cmdBusConnect": 0x803182f0,
		"cmdBusConnect": 0x803182f0,
		"JASystem::TSeqParser::cmdPauseStatus": 0x80318314,
		"cmdPauseStatus": 0x80318314,
		"JASystem::TSeqParser::cmdVolumeMode": 0x80318324,
		"cmdVolumeMode": 0x80318324,
		"JASystem::TSeqParser::cmdSetInterrupt": 0x80318334,
		"cmdSetInterrupt": 0x80318334,
		"JASystem::TSeqParser::cmdDisInterrupt": 0x8031836c,
		"cmdDisInterrupt": 0x8031836c,
		"JASystem::TSeqParser::cmdClrI": 0x80318398,
		"cmdClrI": 0x80318398,
		"JASystem::TSeqParser::cmdSetI": 0x803183b0,
		"cmdSetI": 0x803183b0,
		"JASystem::TSeqParser::cmdRetI": 0x803183c0,
		"cmdRetI": 0x803183c0,
		"JASystem::TSeqParser::cmdIntTimer": 0x803183f0,
		"cmdIntTimer": 0x803183f0,
		"JASystem::TSeqParser::cmdConnectOpen": 0x8031840c,
		"cmdConnectOpen": 0x8031840c,
		"JASystem::TSeqParser::cmdConnectClose": 0x80318448,
		"cmdConnectClose": 0x80318448,
		"JASystem::TSeqParser::cmdSyncCPU": 0x80318490,
		"cmdSyncCPU": 0x80318490,
		"JASystem::TSeqParser::cmdFlushAll": 0x803184f8,
		"cmdFlushAll": 0x803184f8,
		"JASystem::TSeqParser::cmdFlushRelease": 0x80318520,
		"cmdFlushRelease": 0x80318520,
		"JASystem::TSeqParser::cmdTimeBase": 0x80318548,
		"cmdTimeBase": 0x80318548,
		"JASystem::TSeqParser::cmdTempo": 0x80318584,
		"cmdTempo": 0x80318584,
		"JASystem::TSeqParser::cmdFinish": 0x803185cc,
		"cmdFinish": 0x803185cc,
		"JASystem::TSeqParser::cmdNop": 0x803186b8,
		"cmdNop": 0x803186b8,
		"JASystem::TSeqParser::cmdPanPowSet": 0x803186c0,
		"cmdPanPowSet": 0x803186c0,
		"JASystem::TSeqParser::cmdIIRSet": 0x80318744,
		"cmdIIRSet": 0x80318744,
		"JASystem::TSeqParser::cmdFIRSet": 0x80318848,
		"cmdFIRSet": 0x80318848,
		"JASystem::TSeqParser::cmdEXTSet": 0x8031887c,
		"cmdEXTSet": 0x8031887c,
		"JASystem::TSeqParser::cmdPanSwSet": 0x803188d0,
		"cmdPanSwSet": 0x803188d0,
		"JASystem::TSeqParser::cmdOscRoute": 0x803189c0,
		"cmdOscRoute": 0x803189c0,
		"JASystem::TSeqParser::cmdIIRCutOff": 0x80318a10,
		"cmdIIRCutOff": 0x80318a10,
		"JASystem::TSeqParser::cmdOscFull": 0x80318b18,
		"cmdOscFull": 0x80318b18,
		"JASystem::TSeqParser::cmdCheckWave": 0x80318b54,
		"cmdCheckWave": 0x80318b54,
		"JASystem::TSeqParser::cmdPrintf": 0x80318b84,
		"cmdPrintf": 0x80318b84,
		"JASystem::TSeqParser::Cmd_Process": 0x80318da4,
		"Cmd_Process": 0x80318da4,
		"JASystem::TSeqParser::RegCmd_Process": 0x80318efc,
		"RegCmd_Process": 0x80318efc,
		"JASystem::TSeqParser::cmdNoteOff": 0x80318fe0,
		"cmdNoteOff": 0x80318fe0,
		"JASystem::TSeqParser::cmdNoteOn": 0x803190c0,
		"cmdNoteOn": 0x803190c0,
		"JASystem::TSeqParser::conditionCheck": 0x803193a0,
		"conditionCheck": 0x803193a0,
		"JASystem::TSeqParser::mainProc": 0x80319490,
		"JSystem::__sinit_JASSeqParser_cpp": 0x80319764,
		"__sinit_JASSeqParser_cpp": 0x80319764,
		"J3DMaterialTable::clear": 0x80319d98,
		"J3DMaterialTable::J3DMaterialTable": 0x80319db4,
		"J3DMaterialTable::~J3DMaterialTable": 0x80319ddc,
		"JSystem::JPAGetEmitterInfoPtr": 0x80319e28,
		"JPAGetEmitterInfoPtr": 0x80319e28,
		"JPABaseEmitter::JPABaseEmitter": 0x80319e34,
		"JPABaseEmitter::getFovy": 0x80319f4c,
		"getFovy": 0x80319f4c,
		"JPABaseEmitter::getAspect": 0x80319f5c,
		"getAspect": 0x80319f5c,
		"JPABaseEmitter::deleteAllParticle": 0x80319f6c,
		"deleteAllParticle": 0x80319f6c,
		"JPABaseEmitter::createChildParticle": 0x8031a040,
		"createChildParticle": 0x8031a040,
		"JPAParticle::addBaseVelVec": 0x8031a5f4,
		"addBaseVelVec": 0x8031a5f4,
		"JPAParticle::setBaseVelVec": 0x8031a628,
		"setBaseVelVec": 0x8031a628,
		"JPABaseEmitter::getEmitterGlobalTranslation": 0x8031a644,
		"getEmitterGlobalTranslation": 0x8031a644,
		"JPABaseEmitter::calcEmitterGlobalParams": 0x8031a72c,
		"calcEmitterGlobalParams": 0x8031a72c,
		"JPABaseEmitter::loadBaseEmitterBlock": 0x8031aaa0,
		"loadBaseEmitterBlock": 0x8031aaa0,
		"JPABaseEmitter::drawEmitterCallBack": 0x8031ae68,
		"drawEmitterCallBack": 0x8031ae68,
		"JPABaseEmitter::createParticle": 0x8031aea4,
		"createParticle": 0x8031aea4,
		"JPABaseEmitter::calcCurrentRateTimerStep": 0x8031c14c,
		"calcCurrentRateTimerStep": 0x8031c14c,
		"JPABaseEmitter::calcCreateParticle": 0x8031c1a0,
		"calcCreateParticle": 0x8031c1a0,
		"JPABaseEmitter::checkStartFrame": 0x8031c4b0,
		"checkStartFrame": 0x8031c4b0,
		"JPABaseEmitter::checkMaxFrame": 0x8031c50c,
		"checkMaxFrame": 0x8031c50c,
		"JPABaseEmitter::doParticle": 0x8031c5b8,
		"doParticle": 0x8031c5b8,
		"JPABaseEmitter::doChildParticle": 0x8031c724,
		"doChildParticle": 0x8031c724,
		"JPABaseEmitter::calcKeyFrameAnime": 0x8031c880,
		"calcKeyFrameAnime": 0x8031c880,
		"JPABaseEmitter::calc": 0x8031ca50,
		"JPABaseEmitter::setGlobalRTMatrix": 0x8031cb9c,
		"setGlobalRTMatrix": 0x8031cb9c,
		"JPABaseEmitter::setGlobalSRTMatrix": 0x8031cbcc,
		"setGlobalSRTMatrix": 0x8031cbcc,
		"JSystem::__sinit_JPAEmitter_cpp": 0x8031cc00,
		"__sinit_JPAEmitter_cpp": 0x8031cc00,
		"JPAEmitterManager::JPAEmitterManager": 0x8031cc60,
		"JSUList<JPABaseEmitter>::JSUList": 0x8031cf38,
		"JSUList<JPABaseEmitter>::~JSUList": 0x8031cf68,
		"JPAEmitterManager::calcBase": 0x8031cfc0,
		"calcBase": 0x8031cfc0,
		"JPAEmitterManager::calc": 0x8031d09c,
		"JPAEmitterManager::createEmitterBase": 0x8031d27c,
		"createEmitterBase": 0x8031d27c,
		"JPAEmitterManager::createSimpleEmitterID": 0x8031d428,
		"createSimpleEmitterID": 0x8031d428,
		"JPAEmitterManager::createEmitter": 0x8031d490,
		"createEmitter": 0x8031d490,
		"JPAEmitterManager::deleteEmitter": 0x8031d528,
		"deleteEmitter": 0x8031d528,
		"JPAEmitterManager::forceDeleteEmitter": 0x8031d58c,
		"forceDeleteEmitter": 0x8031d58c,
		"JPABaseField::JPABaseField": 0x8031d5f4,
		"JPABaseField::~JPABaseField": 0x8031d68c,
		"JPABaseField::set": 0x8031d6f4,
		"JPABaseField::checkMaxDistance": 0x8031d6f8,
		"JPABaseField::calcFieldFadeScale": 0x8031d750,
		"calcFieldFadeScale": 0x8031d750,
		"JPABaseField::calcFieldVelocity": 0x8031d874,
		"calcFieldVelocity": 0x8031d874,
		"JPABaseField::affect": 0x8031d9e4,
		"JPABaseField::loadFieldBlock": 0x8031da04,
		"loadFieldBlock": 0x8031da04,
		"JPAGravityField::JPAGravityField": 0x8031dc60,
		"JPAGravityField::~JPAGravityField": 0x8031dca4,
		"JPAGravityField::set": 0x8031dd1c,
		"JPAAirField::JPAAirField": 0x8031ddb8,
		"JPAAirField::set": 0x8031ddfc,
		"JPAAirField::affect": 0x8031df44,
		"JPAParticle::getBaseVelVec": 0x8031e17c,
		"getBaseVelVec": 0x8031e17c,
		"JPAMagnetField::JPAMagnetField": 0x8031e198,
		"JPAMagnetField::~JPAMagnetField": 0x8031e1dc,
		"JPAMagnetField::set": 0x8031e254,
		"JPAMagnetField::affect": 0x8031e2cc,
		"JPANewtonField::JPANewtonField": 0x8031e40c,
		"JPANewtonField::~JPANewtonField": 0x8031e450,
		"JPANewtonField::set": 0x8031e4c8,
		"JPANewtonField::affect": 0x8031e54c,
		"JPAVortexField::JPAVortexField": 0x8031e748,
		"JPAVortexField::~JPAVortexField": 0x8031e7a0,
		"JPAVortexField::set": 0x8031e818,
		"JPAVortexField::affect": 0x8031e870,
		"JPAVortexField::checkMaxDistance": 0x8031e9d8,
		"JPAConvectionField::JPAConvectionField": 0x8031e9e0,
		"JPAConvectionField::~JPAConvectionField": 0x8031ea44,
		"JPAConvectionField::set": 0x8031eabc,
		"JPAConvectionField::affect": 0x8031ed70,
		"JPAConvectionField::checkMaxDistance": 0x8031f068,
		"JPARandomField::JPARandomField": 0x8031f070,
		"JPARandomField::~JPARandomField": 0x8031f0b4,
		"JPARandomField::affect": 0x8031f12c,
		"JPADragField::JPADragField": 0x8031f26c,
		"JPADragField::~JPADragField": 0x8031f2b0,
		"JPADragField::affect": 0x8031f328,
		"JPAParticle::getDragForce": 0x8031f448,
		"getDragForce": 0x8031f448,
		"JPAFieldManager::JPAFieldManager": 0x8031f450,
		"JPAFieldManager::deleteAllField": 0x8031f480,
		"deleteAllField": 0x8031f480,
		"JPAFieldManager::calcFieldParams": 0x8031f4f8,
		"calcFieldParams": 0x8031f4f8,
		"JPAFieldManager::affectField": 0x8031f580,
		"affectField": 0x8031f580,
		"JPAFieldManager::setField": 0x8031f658,
		"setField": 0x8031f658,
		"JPAFieldManager::setGravityField": 0x8031f6fc,
		"setGravityField": 0x8031f6fc,
		"JPAFieldManager::setAirField": 0x8031f770,
		"setAirField": 0x8031f770,
		"JPAFieldManager::setMagnetField": 0x8031f7e4,
		"setMagnetField": 0x8031f7e4,
		"JPAFieldManager::setNewtonField": 0x8031f858,
		"setNewtonField": 0x8031f858,
		"JPAFieldManager::setVortexField": 0x8031f8cc,
		"setVortexField": 0x8031f8cc,
		"JPAFieldManager::setConvectionField": 0x8031f940,
		"setConvectionField": 0x8031f940,
		"JPAFieldManager::setRandomField": 0x8031f9b4,
		"setRandomField": 0x8031f9b4,
		"JPAFieldManager::setDragField": 0x8031fa28,
		"setDragField": 0x8031fa28,
		"JPAAirField::~JPAAirField": 0x8031fa9c,
		"JSystem::__sinit_JPAField_cpp": 0x8031fb14,
		"__sinit_JPAField_cpp": 0x8031fb14,
		"JSystem::JPASqrtf": 0x8031fb3c,
		"JPASqrtf": 0x8031fb3c,
		"JSystem::JPAGetXYZRotateMtx": 0x8031fb60,
		"JPAGetXYZRotateMtx": 0x8031fb60,
		"JSystem::JPAGetXYRotateMtx": 0x8031fd78,
		"JPAGetXYRotateMtx": 0x8031fd78,
		"JSystem::JPAGetYZRotateMtx": 0x8031feac,
		"JPAGetYZRotateMtx": 0x8031feac,
		"JSystem::JPAGetYRotateMtx": 0x8031ffe0,
		"JPAGetYRotateMtx": 0x8031ffe0,
		"JSystem::JPAVecToRotaMtx": 0x80320078,
		"JPAVecToRotaMtx": 0x80320078,
		"JSystem::JPAConvertFixToFloat": 0x8032022c,
		"JPAConvertFixToFloat": 0x8032022c,
		"JSystem::JPAConvertFixVecToFloatVec": 0x803202e8,
		"JPAConvertFixVecToFloatVec": 0x803202e8,
		"JSystem::JPAGetRMtxSTVecElement": 0x80320510,
		"JPAGetRMtxSTVecElement": 0x80320510,
		"JSystem::JPAGetRMtxTVecElement": 0x803207a4,
		"JPAGetRMtxTVecElement": 0x803207a4,
		"JSystem::JPAGetKeyFrameValue": 0x80320a14,
		"JPAGetKeyFrameValue": 0x80320a14,
		"JSystem::JPAGetKeyFrameInterpolation": 0x80320a34,
		"JPAGetKeyFrameInterpolation": 0x80320a34,
		"JPABaseParticle::incTimer": 0x80320ae4,
		"incTimer": 0x80320ae4,
		"JPABaseParticle::executeParticleCallBack": 0x80320b44,
		"executeParticleCallBack": 0x80320b44,
		"JPABaseParticle::drawParticleCallBack": 0x80320b80,
		"drawParticleCallBack": 0x80320b80,
		"JPAParticle::JPAParticle": 0x80320bbc,
		"JPAParticle::init": 0x80320c08,
		"JPAParticle::setVelocity": 0x80320c48,
		"setVelocity": 0x80320c48,
		"JPAParticle::calcVelocity": 0x80320d04,
		"JPABaseParticle::initGlobalPosition": 0x80320e2c,
		"initGlobalPosition": 0x80320e2c,
		"JPABaseParticle::calcGlobalPosition": 0x80320e94,
		"calcGlobalPosition": 0x80320e94,
		"JPABaseParticle::getCurrentPosition": 0x80320f2c,
		"getCurrentPosition": 0x80320f2c,
		"JPAParticle::checkCreateChildParticle": 0x80320fb8,
		"checkCreateChildParticle": 0x80320fb8,
		"JPAParticle::getDynamicsWeight": 0x8032107c,
		"getDynamicsWeight": 0x8032107c,
		"JPAParticle::getAirResistance": 0x80321084,
		"getAirResistance": 0x80321084,
		"JPAParticle::getCurrentDragForce": 0x8032108c,
		"getCurrentDragForce": 0x8032108c,
		"JPAParticle::accessBaseVelVec": 0x80321094,
		"accessBaseVelVec": 0x80321094,
		"JPAParticle::accessFAccVec": 0x8032109c,
		"accessFAccVec": 0x8032109c,
		"JPAParticle::accessFVelVec": 0x803210a4,
		"accessFVelVec": 0x803210a4,
		"JPAParticle::getDrawParamPPtr": 0x803210ac,
		"getDrawParamPPtr": 0x803210ac,
		"JPAParticle::getDrawParamCPtr": 0x803210b4,
		"getDrawParamCPtr": 0x803210b4,
		"JPAParticle::getWidth": 0x803210bc,
		"JPAParticle::getHeight": 0x803210dc,
		"JPADrawSetupTev::setupTev": 0x803210fc,
		"setupTev": 0x803210fc,
		"JPADraw::initialize": 0x8032143c,
		"JPADraw::draw": 0x803217a0,
		"JPADraw::calc": 0x80321a24,
		"JPADraw::calcParticle": 0x80321a98,
		"calcParticle": 0x80321a98,
		"JPADraw::calcChild": 0x80321b40,
		"calcChild": 0x80321b40,
		"JPADraw::initParticle": 0x80321be8,
		"JPADraw::initChild": 0x80321f38,
		"initChild": 0x80321f38,
		"JPADraw::swapImage": 0x803221fc,
		"swapImage": 0x803221fc,
		"JPADraw::setDrawExecVisitorsBeforeCB": 0x8032225c,
		"setDrawExecVisitorsBeforeCB": 0x8032225c,
		"JPADraw::setDrawExecVisitorsAfterCB": 0x80322904,
		"setDrawExecVisitorsAfterCB": 0x80322904,
		"JPADraw::setDrawCalcVisitors": 0x80322f04,
		"setDrawCalcVisitors": 0x80322f04,
		"JPADraw::setParticleClipBoard": 0x803237e0,
		"setParticleClipBoard": 0x803237e0,
		"JPADraw::setChildClipBoard": 0x80323b80,
		"setChildClipBoard": 0x80323b80,
		"JPADraw::drawParticle": 0x80323ea0,
		"drawParticle": 0x80323ea0,
		"JPADraw::drawChild": 0x80324100,
		"drawChild": 0x80324100,
		"JPADraw::zDraw": 0x803243a4,
		"zDraw": 0x803243a4,
		"JPADraw::zDrawParticle": 0x8032442c,
		"zDrawParticle": 0x8032442c,
		"JPADraw::zDrawChild": 0x8032463c,
		"zDrawChild": 0x8032463c,
		"JPADraw::getMainTextureID": 0x80324890,
		"getMainTextureID": 0x80324890,
		"JPADraw::loadYBBMtx": 0x803248d0,
		"loadYBBMtx": 0x803248d0,
		"JSystem::__sinit_JPADraw_cpp": 0x803249a0,
		"__sinit_JPADraw_cpp": 0x803249a0,
		"JPADrawClipBoard::~JPADrawClipBoard": 0x80324f1c,
		"JPADrawVisitorContainer::~JPADrawVisitorContainer": 0x80324f5c,
		"JPADrawCalcChildScaleOut::~JPADrawCalcChildScaleOut": 0x80325b3c,
		"JPADrawCalcChildAlphaOut::~JPADrawCalcChildAlphaOut": 0x80325b98,
		"JPADrawCalcAlphaFlickMultSin::~JPADrawCalcAlphaFlickMultSin": 0x80325e60,
		"JPADrawCalcAlphaFlickAddSin::~JPADrawCalcAlphaFlickAddSin": 0x80325ebc,
		"JPADrawCalcAlphaFlickNrmSin::~JPADrawCalcAlphaFlickNrmSin": 0x80325f18,
		"JPADrawCalcAlpha::~JPADrawCalcAlpha": 0x80325f74,
		"JPADrawCalcColorCopyFromEmitter::~JPADrawCalcColorCopyFromEmitter": 0x8032623c,
		"JPADrawCalcEmitterVisitor::~JPADrawCalcEmitterVisitor": 0x80326390,
		"JPADrawCalcScaleAnmTimingReverseY::~JPADrawCalcScaleAnmTimingReverseY": 0x803263dc,
		"JPADrawCalcScaleAnmTimingReverseX::~JPADrawCalcScaleAnmTimingReverseX": 0x80326438,
		"JPADrawCalcScaleAnmTimingRepeatY::~JPADrawCalcScaleAnmTimingRepeatY": 0x80326494,
		"JPADrawCalcScaleAnmTimingRepeatX::~JPADrawCalcScaleAnmTimingRepeatX": 0x803264f0,
		"JPADrawCalcScaleAnmTimingNormal::~JPADrawCalcScaleAnmTimingNormal": 0x8032654c,
		"JPADrawCalcScaleCopyX2Y::~JPADrawCalcScaleCopyX2Y": 0x803265a8,
		"JPADrawCalcScaleYBySpeed::~JPADrawCalcScaleYBySpeed": 0x80326604,
		"JPADrawCalcScaleY::~JPADrawCalcScaleY": 0x80326660,
		"JPADrawCalcScaleXBySpeed::~JPADrawCalcScaleXBySpeed": 0x803266bc,
		"JPADrawCalcScaleX::~JPADrawCalcScaleX": 0x80326718,
		"JPADrawCalcParticleVisitor::~JPADrawCalcParticleVisitor": 0x80326774,
		"JPADrawExecStripeCross::~JPADrawExecStripeCross": 0x8032683c,
		"JPADrawExecStripe::~JPADrawExecStripe": 0x80326898,
		"JPADrawExecLine::~JPADrawExecLine": 0x803268f4,
		"JPADrawExecPoint::~JPADrawExecPoint": 0x80326950,
		"JPADrawExecRotationCross::~JPADrawExecRotationCross": 0x803269ac,
		"JPADrawExecRotation::~JPADrawExecRotation": 0x80326a08,
		"JPADrawExecDirBillBoard::~JPADrawExecDirBillBoard": 0x80326a64,
		"JPADrawExecRotDirectionalCross::~JPADrawExecRotDirectionalCross": 0x80326ac0,
		"JPADrawExecDirectionalCross::~JPADrawExecDirectionalCross": 0x80326b1c,
		"JPADrawExecRotDirectional::~JPADrawExecRotDirectional": 0x80326b78,
		"JPADrawExecDirectional::~JPADrawExecDirectional": 0x80326bd4,
		"JPADrawExecRotYBillBoard::~JPADrawExecRotYBillBoard": 0x80326c30,
		"JPADrawExecYBillBoard::~JPADrawExecYBillBoard": 0x80326c8c,
		"JPADrawExecRotBillBoard::~JPADrawExecRotBillBoard": 0x80326ce8,
		"JPADrawExecBillBoard::~JPADrawExecBillBoard": 0x80326d44,
		"JPADrawExecLoadExTex::~JPADrawExecLoadExTex": 0x80326da0,
		"JPADrawExecLoadDefaultTexture::~JPADrawExecLoadDefaultTexture": 0x80326e78,
		"JPADrawExecRegisterPrmAEnv::~JPADrawExecRegisterPrmAEnv": 0x80326ed4,
		"JPADrawExecRegisterPrmCEnv::~JPADrawExecRegisterPrmCEnv": 0x80326f30,
		"JPADrawExecRegisterEnvColorAnm::~JPADrawExecRegisterEnvColorAnm": 0x80326f8c,
		"JPADrawExecRegisterPrmAlphaAnm::~JPADrawExecRegisterPrmAlphaAnm": 0x80326fe8,
		"JPADrawExecRegisterPrmColorAnm::~JPADrawExecRegisterPrmColorAnm": 0x80327044,
		"JPADrawExecRegisterColorChildPE::~JPADrawExecRegisterColorChildPE": 0x803270a0,
		"JPADrawExecRegisterColorEmitterE::~JPADrawExecRegisterColorEmitterE": 0x803270fc,
		"JPADrawExecRegisterColorEmitterP::~JPADrawExecRegisterColorEmitterP": 0x80327158,
		"JPADrawExecRegisterColorEmitterPE::~JPADrawExecRegisterColorEmitterPE": 0x803271b4,
		"JPADrawExecSetLineWidth::~JPADrawExecSetLineWidth": 0x80327210,
		"JPADrawExecSetPointSize::~JPADrawExecSetPointSize": 0x8032726c,
		"JPADrawExecParticleVisitor::~JPADrawExecParticleVisitor": 0x80327344,
		"JPADrawExecGenIdtMtx::~JPADrawExecGenIdtMtx": 0x80327390,
		"JPADrawExecGenTexMtx0::~JPADrawExecGenTexMtx0": 0x803273ec,
		"JPADrawExecGenPrjTexMtx::~JPADrawExecGenPrjTexMtx": 0x80327448,
		"JPADrawExecGenPrjMtx::~JPADrawExecGenPrjMtx": 0x803274a4,
		"JPADrawExecEmitterVisitor::~JPADrawExecEmitterVisitor": 0x80327500,
		"JPADrawExecLoadExTex::exec": 0x8032754c,
		"JPADrawExecGenPrjMtx::exec": 0x80327740,
		"JPADrawExecGenPrjTexMtx::exec": 0x803277f0,
		"JPADrawExecGenTexMtx0::exec": 0x8032799c,
		"JPADrawExecGenIdtMtx::exec": 0x803279e4,
		"JPADrawExecLoadDefaultTexture::exec": 0x80327bf8,
		"JPADrawExecSetPointSize::exec": 0x80327c64,
		"JPADrawExecSetLineWidth::exec": 0x80327cb8,
		"JPADrawExecRegisterPrmColorAnm::exec": 0x80327d0c,
		"JPADrawExecRegisterPrmAlphaAnm::exec": 0x80327de8,
		"JPADrawExecRegisterEnvColorAnm::exec": 0x80327ed4,
		"JPADrawExecRegisterPrmCEnv::exec": 0x80327f6c,
		"JPADrawExecRegisterPrmAEnv::exec": 0x803280ac,
		"JPADrawExecBillBoard::exec": 0x803283ec,
		"JPADrawExecRotBillBoard::exec": 0x803285c4,
		"JPADrawExecYBillBoard::exec": 0x803287e0,
		"JPADrawExecRotYBillBoard::exec": 0x80328a04,
		"JSystem::dirTypeVel": 0x80328c6c,
		"dirTypeVel": 0x80328c6c,
		"JSystem::dirTypePos": 0x80328c88,
		"dirTypePos": 0x80328c88,
		"JSystem::dirTypePosInv": 0x80328ca4,
		"dirTypePosInv": 0x80328ca4,
		"JSystem::dirTypeEmtrDir": 0x80328ce4,
		"dirTypeEmtrDir": 0x80328ce4,
		"JSystem::dirTypePrevPtcl": 0x80328d00,
		"dirTypePrevPtcl": 0x80328d00,
		"JSystem::rotTypeY": 0x80328da8,
		"rotTypeY": 0x80328da8,
		"JSystem::rotTypeX": 0x80328de8,
		"rotTypeX": 0x80328de8,
		"JSystem::rotTypeZ": 0x80328e28,
		"rotTypeZ": 0x80328e28,
		"JSystem::rotTypeXYZ": 0x80328e68,
		"rotTypeXYZ": 0x80328e68,
		"JSystem::rotTypeYJiggle": 0x80328ec4,
		"rotTypeYJiggle": 0x80328ec4,
		"JPADrawExecDirectional::exec": 0x80328f1c,
		"JPADrawExecRotDirectional::exec": 0x80329330,
		"JPADrawExecDirectionalCross::exec": 0x8032978c,
		"JPADrawExecRotDirectionalCross::exec": 0x80329ce4,
		"JPADrawExecDirBillBoard::exec": 0x8032a284,
		"JPADrawExecRotation::exec": 0x8032a5d4,
		"JPADrawExecRotationCross::exec": 0x8032a7fc,
		"JPADrawExecPoint::exec": 0x8032ab68,
		"JPADrawExecLine::exec": 0x8032abf4,
		"JSystem::stripeGetNext": 0x8032adb4,
		"stripeGetNext": 0x8032adb4,
		"JSystem::stripeGetPrev": 0x8032adbc,
		"stripeGetPrev": 0x8032adbc,
		"JPADrawExecStripe::exec": 0x8032adc4,
		"JPADrawExecStripeCross::exec": 0x8032b234,
		"JPADrawExecRegisterColorEmitterPE::exec": 0x8032ba1c,
		"JPADrawExecRegisterColorEmitterP::exec": 0x8032bb20,
		"JPADrawExecRegisterColorEmitterE::exec": 0x8032bbc0,
		"JPADrawExecRegisterColorChildPE::exec": 0x8032bc48,
		"JPADrawCalcScaleX::calc": 0x8032c058,
		"JPADrawCalcScaleY::calc": 0x8032c0fc,
		"JPADrawCalcScaleXBySpeed::calc": 0x8032c1a0,
		"JPADrawCalcScaleYBySpeed::calc": 0x8032c2d0,
		"JPADrawCalcScaleCopyX2Y::calc": 0x8032c400,
		"JPADrawCalcScaleAnmTimingNormal::calc": 0x8032c438,
		"JPADrawCalcScaleAnmTimingRepeatX::calc": 0x8032c448,
		"JPADrawCalcScaleAnmTimingRepeatY::calc": 0x8032c4b4,
		"JPADrawCalcScaleAnmTimingReverseX::calc": 0x8032c520,
		"JPADrawCalcScaleAnmTimingReverseY::calc": 0x8032c5c0,
		"JPADrawCalcColorCopyFromEmitter::calc": 0x8032c718,
		"JPADrawCalcAlpha::calc": 0x8032ca28,
		"JPADrawCalcAlphaFlickNrmSin::calc": 0x8032caac,
		"JPADrawCalcAlphaFlickAddSin::calc": 0x8032cb9c,
		"JPADrawCalcAlphaFlickMultSin::calc": 0x8032ccc0,
		"JPADrawCalcChildAlphaOut::calc": 0x8032d160,
		"JPADrawCalcChildScaleOut::calc": 0x8032d1a8,
		"JPAExTexShape::JPAExTexShape": 0x8032d300,
		"JPADataBlock::~JPADataBlock": 0x8032d420,
		"JPAExTexShape::~JPAExTexShape": 0x8032d46c,
		"JPADataBlock::JPADataBlock": 0x8032d4c8,
		"JPAEmitterLoaderDataBase::load": 0x8032d548,
		"JPAEmitterLoader_v10::~JPAEmitterLoader_v10": 0x8032d5cc,
		"JPAEmitterLoader_v10::JPAEmitterLoader_v10": 0x8032d628,
		"JPAEmitterLoader::~JPAEmitterLoader": 0x8032d658,
		"JPAEmitterLoader_v10::load": 0x8032d6a4,
		"JPAKeyFrameAnime::JPAKeyFrameAnime": 0x8032da8c,
		"JPAKeyFrameAnime::~JPAKeyFrameAnime": 0x8032dac8,
		"JSystem::makeColorTable": 0x8032db24,
		"makeColorTable": 0x8032db24,
		"JPABaseShape::JPABaseShape": 0x8032dd94,
		"JPABaseShape::~JPABaseShape": 0x8032e2f4,
		"JPAExtraShape::JPAExtraShape": 0x8032e350,
		"JPAExtraShape::~JPAExtraShape": 0x8032e604,
		"JPATextureResource::JPATextureResource": 0x8032e660,
		"JPATextureResource::registration": 0x8032e6d0,
		"registration": 0x8032e6d0,
		"JPAEmitterResource::getByUserIndex": 0x8032e78c,
		"getByUserIndex": 0x8032e78c,
		"JPAResourceManager::JPAResourceManager": 0x8032e7d0,
		"JPASweepShape::JPASweepShape": 0x8032e95c,
		"JPASweepShape::~JPASweepShape": 0x8032eaa8,
		"JPATexture::JPATexture": 0x8032eb04,
		"JPADefaultTexture::initialize": 0x8032eb64,
		"JPATexture::~JPATexture": 0x8032f00c,
		"JStage::TAmbientLight::~TAmbientLight": 0x8032f084,
		"JStage::TAmbientLight::JSGFGetType": 0x8032f0e8,
		"JStage::TAmbientLight::JSGGetColor": 0x8032f0f0,
		"JStage::TAmbientLight::JSGSetColor": 0x8032f108,
		"JStage::TCamera::~TCamera": 0x8032f10c,
		"JStage::TCamera::JSGFGetType": 0x8032f170,
		"JStage::TCamera::JSGGetProjectionType": 0x8032f178,
		"JStage::TCamera::JSGSetProjectionType": 0x8032f180,
		"JStage::TCamera::JSGGetProjectionNear": 0x8032f184,
		"JStage::TCamera::JSGSetProjectionNear": 0x8032f18c,
		"JStage::TCamera::JSGGetProjectionFar": 0x8032f190,
		"JStage::TCamera::JSGSetProjectionFar": 0x8032f198,
		"JStage::TCamera::JSGGetProjectionFovy": 0x8032f19c,
		"JStage::TCamera::JSGSetProjectionFovy": 0x8032f1a4,
		"JStage::TCamera::JSGGetProjectionAspect": 0x8032f1a8,
		"JStage::TCamera::JSGSetProjectionAspect": 0x8032f1b0,
		"JStage::TCamera::JSGGetProjectionField": 0x8032f1b4,
		"JStage::TCamera::JSGSetProjectionField": 0x8032f1b8,
		"JStage::TCamera::JSGGetViewType": 0x8032f1bc,
		"JSGGetViewType": 0x8032f1bc,
		"JStage::TCamera::JSGSetViewType": 0x8032f1c4,
		"JSGSetViewType": 0x8032f1c4,
		"JStage::TCamera::JSGGetViewPosition": 0x8032f1c8,
		"JStage::TCamera::JSGSetViewPosition": 0x8032f1cc,
		"JStage::TCamera::JSGGetViewUpVector": 0x8032f1d0,
		"JStage::TCamera::JSGSetViewUpVector": 0x8032f1d4,
		"JStage::TCamera::JSGGetViewTargetPosition": 0x8032f1d8,
		"JStage::TCamera::JSGSetViewTargetPosition": 0x8032f1dc,
		"JStage::TCamera::JSGGetViewRoll": 0x8032f1e0,
		"JSGGetViewRoll": 0x8032f1e0,
		"JStage::TCamera::JSGSetViewRoll": 0x8032f1e8,
		"JSGSetViewRoll": 0x8032f1e8,
		"JStage::TActor::~TActor": 0x8032f1ec,
		"JStage::TActor::JSGFGetType": 0x8032f250,
		"JStage::TActor::JSGGetTranslation": 0x8032f258,
		"JStage::TActor::JSGSetTranslation": 0x8032f25c,
		"JStage::TActor::JSGGetScaling": 0x8032f260,
		"JStage::TActor::JSGSetScaling": 0x8032f264,
		"JStage::TActor::JSGGetRotation": 0x8032f268,
		"JStage::TActor::JSGSetRotation": 0x8032f26c,
		"JStage::TActor::JSGGetShape": 0x8032f270,
		"JSGGetShape": 0x8032f270,
		"JStage::TActor::JSGSetShape": 0x8032f278,
		"JSGSetShape": 0x8032f278,
		"JStage::TActor::JSGGetAnimation": 0x8032f27c,
		"JSGGetAnimation": 0x8032f27c,
		"JStage::TActor::JSGSetAnimation": 0x8032f284,
		"JSGSetAnimation": 0x8032f284,
		"JStage::TActor::JSGGetAnimationFrame": 0x8032f288,
		"JSGGetAnimationFrame": 0x8032f288,
		"JStage::TActor::JSGSetAnimationFrame": 0x8032f290,
		"JSGSetAnimationFrame": 0x8032f290,
		"JStage::TActor::JSGGetAnimationFrameMax": 0x8032f294,
		"JSGGetAnimationFrameMax": 0x8032f294,
		"JStage::TLight::~TLight": 0x8032f29c,
		"JStage::TLight::JSGFGetType": 0x8032f300,
		"JStage::TLight::JSGGetLightType": 0x8032f308,
		"JStage::TLight::JSGSetLightType": 0x8032f310,
		"JStage::TLight::JSGGetColor": 0x8032f314,
		"JStage::TLight::JSGSetColor": 0x8032f32c,
		"JStage::TLight::JSGGetDistanceAttenuation": 0x8032f330,
		"JSGGetDistanceAttenuation": 0x8032f330,
		"JStage::TLight::JSGSetDistanceAttenuation": 0x8032f334,
		"JSGSetDistanceAttenuation": 0x8032f334,
		"JStage::TLight::JSGGetAngleAttenuation": 0x8032f338,
		"JSGGetAngleAttenuation": 0x8032f338,
		"JStage::TLight::JSGSetAngleAttenuation": 0x8032f33c,
		"JSGSetAngleAttenuation": 0x8032f33c,
		"JStage::TLight::JSGGetPosition": 0x8032f340,
		"JStage::TLight::JSGSetPosition": 0x8032f344,
		"JStage::TLight::JSGGetDirection": 0x8032f348,
		"JSGGetDirection": 0x8032f348,
		"JStage::TLight::JSGSetDirection": 0x8032f34c,
		"JSGSetDirection": 0x8032f34c,
		"JStage::TObject::~TObject": 0x8032f350,
		"JStage::TObject::JSGGetName": 0x8032f39c,
		"JSGGetName": 0x8032f39c,
		"JStage::TObject::JSGGetFlag": 0x8032f3a4,
		"JStage::TObject::JSGSetFlag": 0x8032f3ac,
		"JStage::TObject::JSGGetData": 0x8032f3b0,
		"JSGGetData": 0x8032f3b0,
		"JStage::TObject::JSGSetData": 0x8032f3b8,
		"JSGSetData": 0x8032f3b8,
		"JStage::TObject::JSGGetParent": 0x8032f3bc,
		"JSGGetParent": 0x8032f3bc,
		"JStage::TObject::JSGSetParent": 0x8032f3c0,
		"JSGSetParent": 0x8032f3c0,
		"JStage::TObject::JSGSetRelation": 0x8032f3c4,
		"JSGSetRelation": 0x8032f3c4,
		"JStage::TSystem::~TSystem": 0x8032f3c8,
		"JStage::TSystem::JSGFGetType": 0x8032f42c,
		"JStage::TSystem::JSGFindObject": 0x8032f434,
		"JStage::TSystem::JSGCreateObject": 0x8032f43c,
		"JSGCreateObject": 0x8032f43c,
		"JStage::TSystem::JSGDestroyObject": 0x8032f444,
		"JSGDestroyObject": 0x8032f444,
		"JStage::TSystem::JSGGetSystemData": 0x8032f448,
		"JSGGetSystemData": 0x8032f448,
		"JStage::TSystem::JSGSetSystemData": 0x8032f450,
		"JSGSetSystemData": 0x8032f450,
		"Runtime.PPCEABI.H::__va_arg": 0x8032fe4c,
		"__va_arg": 0x8032fe4c,
		"Runtime.PPCEABI.H::__destroy_global_chain": 0x8032ff40,
		"__destroy_global_chain": 0x8032ff40,
		"Runtime.PPCEABI.H::__register_global_object": 0x8032ff88,
		"__register_global_object": 0x8032ff88,
		"Runtime.PPCEABI.H::__destroy_new_array": 0x8032ffa0,
		"__destroy_new_array": 0x8032ffa0,
		"Runtime.PPCEABI.H::__destroy_arr": 0x8033001c,
		"__destroy_arr": 0x8033001c,
		"Runtime.PPCEABI.H::__construct_array": 0x80330094,
		"__construct_array": 0x80330094,
		"__partial_array_destructor::~__partial_array_destructor": 0x80330194,
		"Runtime.PPCEABI.H::__construct_new_array": 0x8033024c,
		"__construct_new_array": 0x8033024c,
		"Runtime.PPCEABI.H::__ptmf_test": 0x80330354,
		"__ptmf_test": 0x80330354,
		"Runtime.PPCEABI.H::__ptmf_scall": 0x80330384,
		"__ptmf_scall": 0x80330384,
		"Runtime.PPCEABI.H::__unregister_fragment": 0x803303ac,
		"__unregister_fragment": 0x803303ac,
		"Runtime.PPCEABI.H::__register_fragment": 0x803303e0,
		"__register_fragment": 0x803303e0,
		"Runtime.PPCEABI.H::__cvt_fp2unsigned": 0x8033041c,
		"__cvt_fp2unsigned": 0x8033041c,
		"Runtime.PPCEABI.H::__div2u": 0x80330478,
		"__div2u": 0x80330478,
		"Runtime.PPCEABI.H::__div2i": 0x80330564,
		"__div2i": 0x80330564,
		"Runtime.PPCEABI.H::__mod2u": 0x8033069c,
		"__mod2u": 0x8033069c,
		"Runtime.PPCEABI.H::__mod2i": 0x80330780,
		"__mod2i": 0x80330780,
		"Runtime.PPCEABI.H::__shl2i": 0x8033088c,
		"__shl2i": 0x8033088c,
		"Runtime.PPCEABI.H::__shr2u": 0x803308b0,
		"__shr2u": 0x803308b0,
		"Runtime.PPCEABI.H::__shr2i": 0x803308d4,
		"__shr2i": 0x803308d4,
		"Runtime.PPCEABI.H::__cvt_sll_flt": 0x803308fc,
		"__cvt_sll_flt": 0x803308fc,
		"Runtime.PPCEABI.H::__cvt_dbl_usll": 0x803309b0,
		"__cvt_dbl_usll": 0x803309b0,
		"Runtime.PPCEABI.H::GetR2": 0x80330a7c,
		"GetR2": 0x80330a7c,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions": 0x80330a84,
		"__fini_cpp_exceptions": 0x80330a84,
		"Runtime.PPCEABI.H::__init_cpp_exceptions": 0x80330ab8,
		"__init_cpp_exceptions": 0x80330ab8,
		"MSL_C.PPCEABI.bare.H::exit": 0x80330af8,
		"exit": 0x80330af8,
		"MSL_C.PPCEABI.bare.H::__num2dec": 0x80330c04,
		"__num2dec": 0x80330c04,
		"MSL_C.PPCEABI.bare.H::__flush_buffer": 0x80330fb8,
		"__flush_buffer": 0x80330fb8,
		"MSL_C.PPCEABI.bare.H::__prep_buffer": 0x80331084,
		"__prep_buffer": 0x80331084,
		"MSL_C.PPCEABI.bare.H::__kill_critical_regions": 0x803310b8,
		"__kill_critical_regions": 0x803310b8,
		"MSL_C.PPCEABI.bare.H::toupper": 0x803310bc,
		"toupper": 0x803310bc,
		"MSL_C.PPCEABI.bare.H::tolower": 0x803310e4,
		"tolower": 0x803310e4,
		"MSL_C.PPCEABI.bare.H::fwrite": 0x8033110c,
		"fwrite": 0x8033110c,
		"MSL_C.PPCEABI.bare.H::wcstombs": 0x803313e8,
		"wcstombs": 0x803313e8,
		"MSL_C.PPCEABI.bare.H::memcmp": 0x80331424,
		"memcmp": 0x80331424,
		"MSL_C.PPCEABI.bare.H::memchr": 0x80331468,
		"memchr": 0x80331468,
		"MSL_C.PPCEABI.bare.H::memmove": 0x80331494,
		"memmove": 0x80331494,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_unaligned": 0x80331570,
		"__copy_longs_rev_unaligned": 0x80331570,
		"MSL_C.PPCEABI.bare.H::__copy_longs_unaligned": 0x80331620,
		"__copy_longs_unaligned": 0x80331620,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_aligned": 0x803316e4,
		"__copy_longs_rev_aligned": 0x803316e4,
		"MSL_C.PPCEABI.bare.H::__copy_longs_aligned": 0x80331790,
		"__copy_longs_aligned": 0x80331790,
		"MSL_C.PPCEABI.bare.H::__stdio_atexit": 0x8033184c,
		"__stdio_atexit": 0x8033184c,
		"MSL_C.PPCEABI.bare.H::sprintf": 0x80331850,
		"sprintf": 0x80331850,
		"MSL_C.PPCEABI.bare.H::snprintf": 0x80331924,
		"snprintf": 0x80331924,
		"MSL_C.PPCEABI.bare.H::vsnprintf": 0x803319f4,
		"vsnprintf": 0x803319f4,
		"MSL_C.PPCEABI.bare.H::vprintf": 0x80331a64,
		"vprintf": 0x80331a64,
		"MSL_C.PPCEABI.bare.H::__StringWrite": 0x80331ae0,
		"__StringWrite": 0x80331ae0,
		"MSL_C.PPCEABI.bare.H::__FileWrite": 0x80331b4c,
		"__FileWrite": 0x80331b4c,
		"MSL_C.PPCEABI.bare.H::__pformatter": 0x80331ba4,
		"__pformatter": 0x80331ba4,
		"MSL_C.PPCEABI.bare.H::float2str": 0x803321d4,
		"float2str": 0x803321d4,
		"MSL_C.PPCEABI.bare.H::round_decimal": 0x8033280c,
		"round_decimal": 0x8033280c,
		"MSL_C.PPCEABI.bare.H::longlong2str": 0x80332940,
		"longlong2str": 0x80332940,
		"MSL_C.PPCEABI.bare.H::long2str": 0x80332c20,
		"long2str": 0x80332c20,
		"MSL_C.PPCEABI.bare.H::parse_format": 0x80332e44,
		"parse_format": 0x80332e44,
		"MSL_C.PPCEABI.bare.H::srand": 0x8033331c,
		"srand": 0x8033331c,
		"MSL_C.PPCEABI.bare.H::rand": 0x80333324,
		"rand": 0x80333324,
		"MSL_C.PPCEABI.bare.H::__StringRead": 0x80333348,
		"__StringRead": 0x80333348,
		"MSL_C.PPCEABI.bare.H::strstr": 0x803333d8,
		"strstr": 0x803333d8,
		"MSL_C.PPCEABI.bare.H::strrchr": 0x80333444,
		"strrchr": 0x80333444,
		"MSL_C.PPCEABI.bare.H::strchr": 0x8033348c,
		"strchr": 0x8033348c,
		"MSL_C.PPCEABI.bare.H::strcmp": 0x803334bc,
		"strcmp": 0x803334bc,
		"MSL_C.PPCEABI.bare.H::strcat": 0x803335e0,
		"strcat": 0x803335e0,
		"MSL_C.PPCEABI.bare.H::strncpy": 0x8033360c,
		"strncpy": 0x8033360c,
		"MSL_C.PPCEABI.bare.H::strcpy": 0x80333650,
		"strcpy": 0x80333650,
		"MSL_C.PPCEABI.bare.H::strlen": 0x80333704,
		"strlen": 0x80333704,
		"MSL_C.PPCEABI.bare.H::strtol": 0x80333724,
		"strtol": 0x80333724,
		"MSL_C.PPCEABI.bare.H::strtoul": 0x80333814,
		"strtoul": 0x80333814,
		"MSL_C.PPCEABI.bare.H::__strtoul": 0x803338c0,
		"__strtoul": 0x803338c0,
		"MSL_C.PPCEABI.bare.H::__close_console": 0x80333c08,
		"__close_console": 0x80333c08,
		"MSL_C.PPCEABI.bare.H::__write_console": 0x80333c10,
		"__write_console": 0x80333c10,
		"MSL_C.PPCEABI.bare.H::__read_console": 0x80333ca8,
		"__read_console": 0x80333ca8,
		"MSL_C.PPCEABI.bare.H::fwide": 0x80333d88,
		"fwide": 0x80333d88,
		"MSL_C.PPCEABI.bare.H::fabs": 0x80333e08,
		"fabs": 0x80333e08,
		"MSL_C.PPCEABI.bare.H::__ieee754_atan2": 0x80333e10,
		"__ieee754_atan2": 0x80333e10,
		"MSL_C.PPCEABI.bare.H::frexp": 0x803342e8,
		"frexp": 0x803342e8,
		"MSL_C.PPCEABI.bare.H::atan2": 0x80334384,
		"atan2": 0x80334384,
		"MSL_C.PPCEABI.bare.H::fabsf": 0x803343a4,
		"fabsf": 0x803343a4,
		"MSL_C.PPCEABI.bare.H::atanf": 0x803343ac,
		"atanf": 0x803343ac,
		"MSL_C.PPCEABI.bare.H::_inv_sqrtf": 0x803345c0,
		"_inv_sqrtf": 0x803345c0,
		"MSL_C.PPCEABI.bare.H::acosf": 0x80334630,
		"acosf": 0x80334630,
		"MSL_C.PPCEABI.bare.H::atan2f": 0x80334674,
		"atan2f": 0x80334674,
		"MSL_C.PPCEABI.bare.H::tanf": 0x8033474c,
		"tanf": 0x8033474c,
		"MSL_C.PPCEABI.bare.H::cos": 0x80334790,
		"cos": 0x80334790,
		"MSL_C.PPCEABI.bare.H::sin": 0x803347b0,
		"sin": 0x803347b0,
		"MSL_C.PPCEABI.bare.H::cosf": 0x803347d0,
		"cosf": 0x803347d0,
		"MSL_C.PPCEABI.bare.H::sinf": 0x80334964,
		"sinf": 0x80334964,
		"MSL_C.PPCEABI.bare.H::__sinit_trigf_c": 0x80334b08,
		"__sinit_trigf_c": 0x80334b08,
		"MSL_C.PPCEABI.bare.H::powf": 0x80334b38,
		"powf": 0x80334b38,
		"MSL_C.PPCEABI.bare.H::expf": 0x80335278,
		"expf": 0x80335278,
		"TRK_MINNOW_DOLPHIN::TRKHandleRequestEvent": 0x80335360,
		"TRKHandleRequestEvent": 0x80335360,
		"TRK_MINNOW_DOLPHIN::TRKHandleSupportEvent": 0x80335388,
		"TRKHandleSupportEvent": 0x80335388,
		"TRK_MINNOW_DOLPHIN::TRKIdle": 0x803353a8,
		"TRKIdle": 0x803353a8,
		"TRK_MINNOW_DOLPHIN::TRKNubMainLoop": 0x803353d4,
		"TRKNubMainLoop": 0x803353d4,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEventQueue": 0x803354c8,
		"TRKInitializeEventQueue": 0x803354c8,
		"TRK_MINNOW_DOLPHIN::TRKCopyEvent": 0x80335524,
		"TRKCopyEvent": 0x80335524,
		"TRK_MINNOW_DOLPHIN::TRKGetNextEvent": 0x80335548,
		"TRKGetNextEvent": 0x80335548,
		"TRK_MINNOW_DOLPHIN::TRKPostEvent": 0x80335608,
		"TRKPostEvent": 0x80335608,
		"TRK_MINNOW_DOLPHIN::TRKConstructEvent": 0x803356e8,
		"TRKConstructEvent": 0x803356e8,
		"TRK_MINNOW_DOLPHIN::TRKDestructEvent": 0x80335700,
		"TRKDestructEvent": 0x80335700,
		"TRK_MINNOW_DOLPHIN::TRKInitializeNub": 0x80335724,
		"TRKInitializeNub": 0x80335724,
		"TRK_MINNOW_DOLPHIN::TRKTerminateNub": 0x803357f8,
		"TRKTerminateNub": 0x803357f8,
		"TRK_MINNOW_DOLPHIN::TRKNubWelcome": 0x8033581c,
		"TRKNubWelcome": 0x8033581c,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEndian": 0x80335844,
		"TRKInitializeEndian": 0x80335844,
		"TRK_MINNOW_DOLPHIN::TRKMessageSend": 0x803358b8,
		"TRKMessageSend": 0x803358b8,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferUsed": 0x803358e0,
		"TRKSetBufferUsed": 0x803358e0,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMessageBuffers": 0x803358e8,
		"TRKInitializeMessageBuffers": 0x803358e8,
		"TRK_MINNOW_DOLPHIN::TRKGetFreeBuffer": 0x80335960,
		"TRKGetFreeBuffer": 0x80335960,
		"TRK_MINNOW_DOLPHIN::TRKGetBuffer": 0x803359fc,
		"TRKGetBuffer": 0x803359fc,
		"TRK_MINNOW_DOLPHIN::TRKReleaseBuffer": 0x80335a28,
		"TRKReleaseBuffer": 0x80335a28,
		"TRK_MINNOW_DOLPHIN::TRKResetBuffer": 0x80335a90,
		"TRKResetBuffer": 0x80335a90,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferPosition": 0x80335ad0,
		"TRKSetBufferPosition": 0x80335ad0,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer": 0x80335b00,
		"TRKAppendBuffer": 0x80335b00,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer": 0x80335ba4,
		"TRKReadBuffer": 0x80335ba4,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui16": 0x80335c30,
		"TRKAppendBuffer1_ui16": 0x80335c30,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui32": 0x80335c84,
		"TRKAppendBuffer1_ui32": 0x80335c84,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui64": 0x80335ce8,
		"TRKAppendBuffer1_ui64": 0x80335ce8,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui8": 0x80335d70,
		"TRKAppendBuffer_ui8": 0x80335d70,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui32": 0x80335dd8,
		"TRKAppendBuffer_ui32": 0x80335dd8,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui8": 0x80335e54,
		"TRKReadBuffer1_ui8": 0x80335e54,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui16": 0x80335e78,
		"TRKReadBuffer1_ui16": 0x80335e78,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui32": 0x80335ef8,
		"TRKReadBuffer1_ui32": 0x80335ef8,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui64": 0x80335f88,
		"TRKReadBuffer1_ui64": 0x80335f88,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui8": 0x80336038,
		"TRKReadBuffer_ui8": 0x80336038,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui32": 0x803360ac,
		"TRKReadBuffer_ui32": 0x803360ac,
		"TRK_MINNOW_DOLPHIN::TRKTestForPacket": 0x80336128,
		"TRKTestForPacket": 0x80336128,
		"TRK_MINNOW_DOLPHIN::TRKGetInput": 0x803361f8,
		"TRKGetInput": 0x803361f8,
		"TRK_MINNOW_DOLPHIN::TRKProcessInput": 0x80336274,
		"TRKProcessInput": 0x80336274,
		"TRK_MINNOW_DOLPHIN::TRKInitializeSerialHandler": 0x803362c4,
		"TRKInitializeSerialHandler": 0x803362c4,
		"TRK_MINNOW_DOLPHIN::TRKTerminateSerialHandler": 0x803362e8,
		"TRKTerminateSerialHandler": 0x803362e8,
		"TRK_MINNOW_DOLPHIN::usr_put_initialize": 0x803362f0,
		"usr_put_initialize": 0x803362f0,
		"TRK_MINNOW_DOLPHIN::TRKInitializeDispatcher": 0x803362f4,
		"TRKInitializeDispatcher": 0x803362f4,
		"TRK_MINNOW_DOLPHIN::TRKDispatchMessage": 0x80336308,
		"TRKDispatchMessage": 0x80336308,
		"TRK_MINNOW_DOLPHIN::TRKMessageIntoReply": 0x8033638c,
		"TRKMessageIntoReply": 0x8033638c,
		"TRK_MINNOW_DOLPHIN::TRKSendACK": 0x80336424,
		"TRKSendACK": 0x80336424,
		"TRK_MINNOW_DOLPHIN::TRKStandardACK": 0x80336474,
		"TRKStandardACK": 0x80336474,
		"TRK_MINNOW_DOLPHIN::TRKDoUnsupported": 0x803364a8,
		"TRKDoUnsupported": 0x803364a8,
		"TRK_MINNOW_DOLPHIN::TRKDoConnect": 0x803364d0,
		"TRKDoConnect": 0x803364d0,
		"TRK_MINNOW_DOLPHIN::TRKDoDisconnect": 0x803364f8,
		"TRKDoDisconnect": 0x803364f8,
		"TRK_MINNOW_DOLPHIN::TRKDoReset": 0x80336548,
		"TRKDoReset": 0x80336548,
		"TRK_MINNOW_DOLPHIN::TRKDoVersions": 0x80336578,
		"TRKDoVersions": 0x80336578,
		"TRK_MINNOW_DOLPHIN::TRKDoSupportMask": 0x803366fc,
		"TRKDoSupportMask": 0x803366fc,
		"TRK_MINNOW_DOLPHIN::TRKDoCPUType": 0x803367d8,
		"TRKDoCPUType": 0x803367d8,
		"TRK_MINNOW_DOLPHIN::TRKDoReadMemory": 0x80336a1c,
		"TRKDoReadMemory": 0x80336a1c,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteMemory": 0x80336c04,
		"TRKDoWriteMemory": 0x80336c04,
		"TRK_MINNOW_DOLPHIN::TRKDoReadRegisters": 0x80336e00,
		"TRKDoReadRegisters": 0x80336e00,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteRegisters": 0x80337004,
		"TRKDoWriteRegisters": 0x80337004,
		"TRK_MINNOW_DOLPHIN::TRKDoFlushCache": 0x8033720c,
		"TRKDoFlushCache": 0x8033720c,
		"TRK_MINNOW_DOLPHIN::TRKDoContinue": 0x80337344,
		"TRKDoContinue": 0x80337344,
		"TRK_MINNOW_DOLPHIN::TRKDoStep": 0x803373a8,
		"TRKDoStep": 0x803373a8,
		"TRK_MINNOW_DOLPHIN::TRKDoStop": 0x803375ac,
		"TRKDoStop": 0x803375ac,
		"TRK_MINNOW_DOLPHIN::TRKSuppAccessFile": 0x80337630,
		"TRKSuppAccessFile": 0x80337630,
		"TRK_MINNOW_DOLPHIN::TRKRequestSend": 0x80337908,
		"TRKRequestSend": 0x80337908,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMutex": 0x80337aac,
		"TRKInitializeMutex": 0x80337aac,
		"TRK_MINNOW_DOLPHIN::TRKAcquireMutex": 0x80337ab4,
		"TRKAcquireMutex": 0x80337ab4,
		"TRK_MINNOW_DOLPHIN::TRKReleaseMutex": 0x80337abc,
		"TRKReleaseMutex": 0x80337abc,
		"TRK_MINNOW_DOLPHIN::TRKDoNotifyStopped": 0x80337ac4,
		"TRKDoNotifyStopped": 0x80337ac4,
		"TRK_MINNOW_DOLPHIN::TRK_flush_cache": 0x80337b9c,
		"TRK_flush_cache": 0x80337b9c,
		"TRK_MINNOW_DOLPHIN::TRK_fill_mem": 0x80337bd4,
		"TRK_fill_mem": 0x80337bd4,
		"TRK_MINNOW_DOLPHIN::__TRK_get_MSR": 0x80337c98,
		"__TRK_get_MSR": 0x80337c98,
		"TRK_MINNOW_DOLPHIN::__TRK_set_MSR": 0x80337ca0,
		"__TRK_set_MSR": 0x80337ca0,
		"TRK_MINNOW_DOLPHIN::TRKValidMemory32": 0x80337ca8,
		"TRKValidMemory32": 0x80337ca8,
		"TRK_MINNOW_DOLPHIN::TRK_ppc_memcpy": 0x80337de0,
		"TRK_ppc_memcpy": 0x80337de0,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessMemory": 0x80337e1c,
		"TRKTargetAccessMemory": 0x80337e1c,
		"TRK_MINNOW_DOLPHIN::TRKTargetReadInstruction": 0x80337f80,
		"TRKTargetReadInstruction": 0x80337f80,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessDefault": 0x80337fcc,
		"TRKTargetAccessDefault": 0x80337fcc,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessFP": 0x803380c8,
		"TRKTargetAccessFP": 0x803380c8,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended1": 0x80338210,
		"TRKTargetAccessExtended1": 0x80338210,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended2": 0x80338388,
		"TRKTargetAccessExtended2": 0x80338388,
		"TRK_MINNOW_DOLPHIN::TRKTargetVersions": 0x80338504,
		"TRKTargetVersions": 0x80338504,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportMask": 0x8033852c,
		"TRKTargetSupportMask": 0x8033852c,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUType": 0x803385d0,
		"TRKTargetCPUType": 0x803385d0,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandler": 0x80338638,
		"TRKInterruptHandler": 0x80338638,
		"TRK_MINNOW_DOLPHIN::TRKExceptionHandler": 0x803387cc,
		"TRKExceptionHandler": 0x803387cc,
		"TRK_MINNOW_DOLPHIN::TRKPostInterruptEvent": 0x80338868,
		"TRKPostInterruptEvent": 0x80338868,
		"TRK_MINNOW_DOLPHIN::TRKSwapAndGo": 0x80338918,
		"TRKSwapAndGo": 0x80338918,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandlerEnableInterrupts": 0x803389dc,
		"TRKInterruptHandlerEnableInterrupts": 0x803389dc,
		"TRK_MINNOW_DOLPHIN::TRKTargetInterrupt": 0x80338a30,
		"TRKTargetInterrupt": 0x80338a30,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddStopInfo": 0x80338a94,
		"TRKTargetAddStopInfo": 0x80338a94,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddExceptionInfo": 0x80338b24,
		"TRKTargetAddExceptionInfo": 0x80338b24,
		"TRK_MINNOW_DOLPHIN::TRKTargetEnableTrace": 0x80338bac,
		"TRKTargetEnableTrace": 0x80338bac,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepDone": 0x80338be8,
		"TRKTargetStepDone": 0x80338be8,
		"TRK_MINNOW_DOLPHIN::TRKTargetDoStep": 0x80338c6c,
		"TRKTargetDoStep": 0x80338c6c,
		"TRK_MINNOW_DOLPHIN::TRKTargetCheckStep": 0x80338cdc,
		"TRKTargetCheckStep": 0x80338cdc,
		"TRK_MINNOW_DOLPHIN::TRKTargetSingleStep": 0x80338d44,
		"TRKTargetSingleStep": 0x80338d44,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepOutOfRange": 0x80338d88,
		"TRKTargetStepOutOfRange": 0x80338d88,
		"TRK_MINNOW_DOLPHIN::TRKTargetGetPC": 0x80338dd0,
		"TRKTargetGetPC": 0x80338dd0,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportRequest": 0x80338de0,
		"TRKTargetSupportRequest": 0x80338de0,
		"TRK_MINNOW_DOLPHIN::TRKTargetFlushCache": 0x80338ed0,
		"TRKTargetFlushCache": 0x80338ed0,
		"TRK_MINNOW_DOLPHIN::TRKTargetStopped": 0x80338f0c,
		"TRKTargetStopped": 0x80338f0c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetStopped": 0x80338f1c,
		"TRKTargetSetStopped": 0x80338f1c,
		"TRK_MINNOW_DOLPHIN::TRKTargetStop": 0x80338f2c,
		"TRKTargetStop": 0x80338f2c,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSPR": 0x80338f54,
		"TRKPPCAccessSPR": 0x80338f54,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessPairedSingleRegister": 0x80339004,
		"TRKPPCAccessPairedSingleRegister": 0x80339004,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessFPRegister": 0x8033907c,
		"TRKPPCAccessFPRegister": 0x8033907c,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSpecialReg": 0x803391fc,
		"TRKPPCAccessSpecialReg": 0x803391fc,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetInputPendingPtr": 0x80339264,
		"TRKTargetSetInputPendingPtr": 0x80339264,
		"TRK_MINNOW_DOLPHIN::InitMetroTRK": 0x80339274,
		"InitMetroTRK": 0x80339274,
		"TRK_MINNOW_DOLPHIN::EnableMetroTRKInterrupts": 0x80339308,
		"EnableMetroTRKInterrupts": 0x80339308,
		"TRK_MINNOW_DOLPHIN::TRKTargetTranslate": 0x80339328,
		"TRKTargetTranslate": 0x80339328,
		"TRK_MINNOW_DOLPHIN::TRK_copy_vector": 0x80339370,
		"TRK_copy_vector": 0x80339370,
		"TRK_MINNOW_DOLPHIN::__TRK_copy_vectors": 0x803393d0,
		"__TRK_copy_vectors": 0x803393d0,
		"TRK_MINNOW_DOLPHIN::TRKInitializeTarget": 0x80339464,
		"TRKInitializeTarget": 0x80339464,
		"TRK_MINNOW_DOLPHIN::TRKSaveExtended1Block": 0x803394b4,
		"TRKSaveExtended1Block": 0x803394b4,
		"TRK_MINNOW_DOLPHIN::TRKRestoreExtended1Block": 0x8033966c,
		"TRKRestoreExtended1Block": 0x8033966c,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUMinorType": 0x80339824,
		"TRKTargetCPUMinorType": 0x80339824,
		"TRK_MINNOW_DOLPHIN::TRK_main": 0x8033982c,
		"TRK_main": 0x8033982c,
		"TRK_MINNOW_DOLPHIN::TRKLoadContext": 0x80339874,
		"TRKLoadContext": 0x80339874,
		"TRK_MINNOW_DOLPHIN::TRKEXICallBack": 0x803398fc,
		"TRKEXICallBack": 0x803398fc,
		"TRK_MINNOW_DOLPHIN::InitMetroTRKCommTable": 0x80339934,
		"InitMetroTRKCommTable": 0x80339934,
		"TRK_MINNOW_DOLPHIN::TRKUARTInterruptHandler": 0x80339a1c,
		"TRKUARTInterruptHandler": 0x80339a1c,
		"TRK_MINNOW_DOLPHIN::TRKInitializeIntDrivenUART": 0x80339a20,
		"TRKInitializeIntDrivenUART": 0x80339a20,
		"TRK_MINNOW_DOLPHIN::EnableEXI2Interrupts": 0x80339a60,
		"EnableEXI2Interrupts": 0x80339a60,
		"TRK_MINNOW_DOLPHIN::TRKPollUART": 0x80339a90,
		"TRKPollUART": 0x80339a90,
		"TRK_MINNOW_DOLPHIN::TRKReadUARTN": 0x80339ac0,
		"TRKReadUARTN": 0x80339ac0,
		"TRK_MINNOW_DOLPHIN::TRKWriteUARTN": 0x80339b04,
		"TRKWriteUARTN": 0x80339b04,
		"TRK_MINNOW_DOLPHIN::ReserveEXI2Port": 0x80339b48,
		"ReserveEXI2Port": 0x80339b48,
		"TRK_MINNOW_DOLPHIN::UnreserveEXI2Port": 0x80339b78,
		"UnreserveEXI2Port": 0x80339b78,
		"TRK_MINNOW_DOLPHIN::TRK_board_display": 0x80339ba8,
		"TRK_board_display": 0x80339ba8,
		"TRK_MINNOW_DOLPHIN::TRKTargetContinue": 0x80339bcc,
		"TRKTargetContinue": 0x80339bcc,
		"base::PPCMfmsr": 0x80339c00,
		"PPCMfmsr": 0x80339c00,
		"base::PPCMtmsr": 0x80339c08,
		"PPCMtmsr": 0x80339c08,
		"base::PPCMfhid0": 0x80339c10,
		"PPCMfhid0": 0x80339c10,
		"base::PPCMthid0": 0x80339c18,
		"PPCMthid0": 0x80339c18,
		"base::PPCMfl2cr": 0x80339c20,
		"PPCMfl2cr": 0x80339c20,
		"base::PPCMtl2cr": 0x80339c28,
		"PPCMtl2cr": 0x80339c28,
		"base::PPCMtdec": 0x80339c30,
		"PPCMtdec": 0x80339c30,
		"base::PPCSync": 0x80339c38,
		"PPCSync": 0x80339c38,
		"base::PPCHalt": 0x80339c40,
		"PPCHalt": 0x80339c40,
		"base::PPCMfhid2": 0x80339c54,
		"PPCMfhid2": 0x80339c54,
		"base::PPCMthid2": 0x80339c5c,
		"PPCMthid2": 0x80339c5c,
		"base::PPCMtwpar": 0x80339c64,
		"PPCMtwpar": 0x80339c64,
		"base::PPCDisableSpeculation": 0x80339c6c,
		"PPCDisableSpeculation": 0x80339c6c,
		"base::PPCSetFpNonIEEEMode": 0x80339c94,
		"PPCSetFpNonIEEEMode": 0x80339c94,
		"db::DBInit": 0x80339c9c,
		"DBInit": 0x80339c9c,
		"db::__DBExceptionDestinationAux": 0x80339cc4,
		"__DBExceptionDestinationAux": 0x80339cc4,
		"db::__DBExceptionDestination": 0x80339d0c,
		"__DBExceptionDestination": 0x80339d0c,
		"db::__DBIsExceptionMarked": 0x80339d1c,
		"__DBIsExceptionMarked": 0x80339d1c,
		"db::DBPrintf": 0x80339d38,
		"DBPrintf": 0x80339d38,
		"os::OSGetConsoleType": 0x80339d88,
		"OSGetConsoleType": 0x80339d88,
		"os::ClearArena": 0x80339db0,
		"ClearArena": 0x80339db0,
		"os::InquiryCallback": 0x80339ed8,
		"InquiryCallback": 0x80339ed8,
		"os::OSInit": 0x80339f14,
		"OSInit": 0x80339f14,
		"os::OSExceptionInit": 0x8033a2cc,
		"OSExceptionInit": 0x8033a2cc,
		"os::__OSDBIntegrator": 0x8033a54c,
		"__OSDBIntegrator": 0x8033a54c,
		"os::__OSDBJump": 0x8033a570,
		"__OSDBJump": 0x8033a570,
		"os::__OSSetExceptionHandler": 0x8033a574,
		"__OSSetExceptionHandler": 0x8033a574,
		"os::__OSGetExceptionHandler": 0x8033a590,
		"__OSGetExceptionHandler": 0x8033a590,
		"os::OSExceptionVector": 0x8033a5a4,
		"OSExceptionVector": 0x8033a5a4,
		"os::OSDefaultExceptionHandler": 0x8033a640,
		"OSDefaultExceptionHandler": 0x8033a640,
		"os::__OSPSInit": 0x8033a698,
		"__OSPSInit": 0x8033a698,
		"os::__OSGetDIConfig": 0x8033a6d0,
		"__OSGetDIConfig": 0x8033a6d0,
		"os::OSInitAlarm": 0x8033a6e4,
		"OSInitAlarm": 0x8033a6e4,
		"os::OSCreateAlarm": 0x8033a730,
		"OSCreateAlarm": 0x8033a730,
		"os::InsertAlarm": 0x8033a73c,
		"InsertAlarm": 0x8033a73c,
		"os::OSSetAlarm": 0x8033a98c,
		"OSSetAlarm": 0x8033a98c,
		"os::OSCancelAlarm": 0x8033a9f4,
		"OSCancelAlarm": 0x8033a9f4,
		"os::DecrementerExceptionCallback": 0x8033ab10,
		"DecrementerExceptionCallback": 0x8033ab10,
		"os::DecrementerExceptionHandler": 0x8033ad40,
		"DecrementerExceptionHandler": 0x8033ad40,
		"os::DLInsert": 0x8033ad90,
		"DLInsert": 0x8033ad90,
		"os::OSAllocFromHeap": 0x8033ae3c,
		"OSAllocFromHeap": 0x8033ae3c,
		"os::OSFreeToHeap": 0x8033af38,
		"OSFreeToHeap": 0x8033af38,
		"os::OSInitAlloc": 0x8033afb4,
		"OSInitAlloc": 0x8033afb4,
		"os::OSCreateHeap": 0x8033b024,
		"OSCreateHeap": 0x8033b024,
		"os::OSDestroyHeap": 0x8033b090,
		"OSDestroyHeap": 0x8033b090,
		"os::OSCheckHeap": 0x8033b0a4,
		"OSCheckHeap": 0x8033b0a4,
		"os::OSReferentSize": 0x8033b404,
		"OSReferentSize": 0x8033b404,
		"os::OSDumpHeap": 0x8033b410,
		"OSDumpHeap": 0x8033b410,
		"os::OSGetArenaHi": 0x8033b514,
		"OSGetArenaHi": 0x8033b514,
		"os::OSGetArenaLo": 0x8033b51c,
		"OSGetArenaLo": 0x8033b51c,
		"os::OSSetArenaHi": 0x8033b524,
		"OSSetArenaHi": 0x8033b524,
		"os::OSSetArenaLo": 0x8033b52c,
		"OSSetArenaLo": 0x8033b52c,
		"os::__OSInitAudioSystem": 0x8033b534,
		"__OSInitAudioSystem": 0x8033b534,
		"os::__OSStopAudioSystem": 0x8033b6f0,
		"__OSStopAudioSystem": 0x8033b6f0,
		"os::DCEnable": 0x8033b7c8,
		"DCEnable": 0x8033b7c8,
		"os::DCInvalidateRange": 0x8033b7dc,
		"DCInvalidateRange": 0x8033b7dc,
		"os::DCFlushRange": 0x8033b80c,
		"DCFlushRange": 0x8033b80c,
		"os::DCStoreRange": 0x8033b840,
		"DCStoreRange": 0x8033b840,
		"os::DCFlushRangeNoSync": 0x8033b874,
		"DCFlushRangeNoSync": 0x8033b874,
		"os::DCZeroRange": 0x8033b8a4,
		"DCZeroRange": 0x8033b8a4,
		"os::ICInvalidateRange": 0x8033b8d4,
		"ICInvalidateRange": 0x8033b8d4,
		"os::ICFlashInvalidate": 0x8033b90c,
		"ICFlashInvalidate": 0x8033b90c,
		"os::ICEnable": 0x8033b91c,
		"ICEnable": 0x8033b91c,
		"os::__LCEnable": 0x8033b930,
		"__LCEnable": 0x8033b930,
		"os::LCEnable": 0x8033b9fc,
		"LCEnable": 0x8033b9fc,
		"os::LCDisable": 0x8033ba34,
		"LCDisable": 0x8033ba34,
		"os::LCStoreBlocks": 0x8033ba5c,
		"LCStoreBlocks": 0x8033ba5c,
		"os::LCStoreData": 0x8033ba80,
		"LCStoreData": 0x8033ba80,
		"os::LCQueueWait": 0x8033bb2c,
		"LCQueueWait": 0x8033bb2c,
		"os::L2GlobalInvalidate": 0x8033bb44,
		"L2GlobalInvalidate": 0x8033bb44,
		"os::DMAErrorHandler": 0x8033bbdc,
		"DMAErrorHandler": 0x8033bbdc,
		"os::__OSCacheInit": 0x8033bd3c,
		"__OSCacheInit": 0x8033bd3c,
		"os::__OSLoadFPUContext": 0x8033be30,
		"__OSLoadFPUContext": 0x8033be30,
		"os::__OSSaveFPUContext": 0x8033bf54,
		"__OSSaveFPUContext": 0x8033bf54,
		"os::OSSetCurrentContext": 0x8033c07c,
		"OSSetCurrentContext": 0x8033c07c,
		"os::OSGetCurrentContext": 0x8033c0d8,
		"OSGetCurrentContext": 0x8033c0d8,
		"os::OSSaveContext": 0x8033c0e4,
		"OSSaveContext": 0x8033c0e4,
		"os::OSLoadContext": 0x8033c164,
		"OSLoadContext": 0x8033c164,
		"os::OSGetStackPointer": 0x8033c23c,
		"OSGetStackPointer": 0x8033c23c,
		"os::OSClearContext": 0x8033c244,
		"OSClearContext": 0x8033c244,
		"os::OSInitContext": 0x8033c268,
		"OSInitContext": 0x8033c268,
		"os::OSDumpContext": 0x8033c324,
		"OSDumpContext": 0x8033c324,
		"os::OSSwitchFPUContext": 0x8033c5cc,
		"OSSwitchFPUContext": 0x8033c5cc,
		"os::__OSContextInit": 0x8033c650,
		"__OSContextInit": 0x8033c650,
		"os::OSFillFPUContext": 0x8033c698,
		"OSFillFPUContext": 0x8033c698,
		"os::OSReport": 0x8033c7c4,
		"OSReport": 0x8033c7c4,
		"os::OSPanic": 0x8033c844,
		"OSPanic": 0x8033c844,
		"os::OSSetErrorHandler": 0x8033c970,
		"OSSetErrorHandler": 0x8033c970,
		"os::__OSUnhandledException": 0x8033c98c,
		"__OSUnhandledException": 0x8033c98c,
		"os::GetFontCode": 0x8033cb8c,
		"GetFontCode": 0x8033cb8c,
		"os::Decode": 0x8033cd28,
		"Decode": 0x8033cd28,
		"os::OSGetFontEncode": 0x8033ce9c,
		"OSGetFontEncode": 0x8033ce9c,
		"os::ReadROM": 0x8033cef4,
		"ReadROM": 0x8033cef4,
		"os::OSLoadFont": 0x8033cf80,
		"OSLoadFont": 0x8033cf80,
		"os::ExpandFontSheet": 0x8033d2b4,
		"ExpandFontSheet": 0x8033d2b4,
		"os::OSInitFont": 0x8033d664,
		"OSInitFont": 0x8033d664,
		"os::OSGetFontTexture": 0x8033d744,
		"OSGetFontTexture": 0x8033d744,
		"os::OSGetFontWidth": 0x8033d8ec,
		"OSGetFontWidth": 0x8033d8ec,
		"os::OSDisableInterrupts": 0x8033da2c,
		"OSDisableInterrupts": 0x8033da2c,
		"os::OSEnableInterrupts": 0x8033da40,
		"OSEnableInterrupts": 0x8033da40,
		"os::OSRestoreInterrupts": 0x8033da54,
		"OSRestoreInterrupts": 0x8033da54,
		"os::__OSSetInterruptHandler": 0x8033da78,
		"__OSSetInterruptHandler": 0x8033da78,
		"os::__OSGetInterruptHandler": 0x8033da94,
		"__OSGetInterruptHandler": 0x8033da94,
		"os::__OSInterruptInit": 0x8033daa8,
		"__OSInterruptInit": 0x8033daa8,
		"os::SetInterruptMask": 0x8033db1c,
		"SetInterruptMask": 0x8033db1c,
		"os::__OSMaskInterrupts": 0x8033ddf4,
		"__OSMaskInterrupts": 0x8033ddf4,
		"os::__OSUnmaskInterrupts": 0x8033de7c,
		"__OSUnmaskInterrupts": 0x8033de7c,
		"os::__OSDispatchInterrupt": 0x8033df04,
		"__OSDispatchInterrupt": 0x8033df04,
		"os::ExternalInterruptHandler": 0x8033e248,
		"ExternalInterruptHandler": 0x8033e248,
		"os::__OSModuleInit": 0x8033e298,
		"__OSModuleInit": 0x8033e298,
		"os::OSInitMessageQueue": 0x8033e2b0,
		"OSInitMessageQueue": 0x8033e2b0,
		"os::OSSendMessage": 0x8033e310,
		"OSSendMessage": 0x8033e310,
		"os::OSReceiveMessage": 0x8033e3d8,
		"OSReceiveMessage": 0x8033e3d8,
		"os::OnReset": 0x8033e4b4,
		"os::MEMIntrruptHandler": 0x8033e4f0,
		"MEMIntrruptHandler": 0x8033e4f0,
		"os::OSProtectRange": 0x8033e55c,
		"OSProtectRange": 0x8033e55c,
		"os::Config24MB": 0x8033e620,
		"Config24MB": 0x8033e620,
		"os::Config48MB": 0x8033e6a0,
		"Config48MB": 0x8033e6a0,
		"os::RealMode": 0x8033e720,
		"RealMode": 0x8033e720,
		"os::__OSInitMemoryProtection": 0x8033e738,
		"__OSInitMemoryProtection": 0x8033e738,
		"os::OSInitMutex": 0x8033e858,
		"OSInitMutex": 0x8033e858,
		"os::OSLockMutex": 0x8033e890,
		"OSLockMutex": 0x8033e890,
		"os::OSUnlockMutex": 0x8033e96c,
		"OSUnlockMutex": 0x8033e96c,
		"os::__OSUnlockAllMutex": 0x8033ea34,
		"__OSUnlockAllMutex": 0x8033ea34,
		"os::OSTryLockMutex": 0x8033eaa4,
		"OSTryLockMutex": 0x8033eaa4,
		"os::OSInitCond": 0x8033eb60,
		"OSInitCond": 0x8033eb60,
		"os::OSWaitCond": 0x8033eb80,
		"OSWaitCond": 0x8033eb80,
		"os::OSSignalCond": 0x8033ec54,
		"OSSignalCond": 0x8033ec54,
		"os::Run": 0x8033ec74,
		"Run": 0x8033ec74,
		"os::Callback": 0x8033ecb4,
		"os::__OSReboot": 0x8033ecc0,
		"__OSReboot": 0x8033ecc0,
		"os::OSRegisterResetFunction": 0x8033ee80,
		"OSRegisterResetFunction": 0x8033ee80,
		"os::Reset": 0x8033ef04,
		"Reset": 0x8033ef04,
		"os::__OSDoHotReset": 0x8033ef74,
		"__OSDoHotReset": 0x8033ef74,
		"os::OSResetSystem": 0x8033efbc,
		"OSResetSystem": 0x8033efbc,
		"os::OSGetResetCode": 0x8033f234,
		"OSGetResetCode": 0x8033f234,
		"os::__OSResetSWInterruptHandler": 0x8033f264,
		"__OSResetSWInterruptHandler": 0x8033f264,
		"os::OSGetResetButtonState": 0x8033f358,
		"OSGetResetButtonState": 0x8033f358,
		"os::OSGetResetSwitchState": 0x8033f5f0,
		"OSGetResetSwitchState": 0x8033f5f0,
		"os::WriteSramCallback": 0x8033f610,
		"WriteSramCallback": 0x8033f610,
		"os::WriteSram": 0x8033f670,
		"WriteSram": 0x8033f670,
		"os::__OSInitSram": 0x8033f788,
		"__OSInitSram": 0x8033f788,
		"os::__OSLockSram": 0x8033f8bc,
		"__OSLockSram": 0x8033f8bc,
		"os::__OSLockSramEx": 0x8033f918,
		"__OSLockSramEx": 0x8033f918,
		"os::UnlockSram": 0x8033f974,
		"UnlockSram": 0x8033f974,
		"os::__OSUnlockSram": 0x8033fc7c,
		"__OSUnlockSram": 0x8033fc7c,
		"os::__OSUnlockSramEx": 0x8033fca0,
		"__OSUnlockSramEx": 0x8033fca0,
		"os::__OSSyncSram": 0x8033fcc4,
		"__OSSyncSram": 0x8033fcc4,
		"os::__OSReadROM": 0x8033fcd4,
		"__OSReadROM": 0x8033fcd4,
		"os::OSGetSoundMode": 0x8033fdf8,
		"OSGetSoundMode": 0x8033fdf8,
		"os::OSSetSoundMode": 0x8033fe78,
		"OSSetSoundMode": 0x8033fe78,
		"os::OSGetProgressiveMode": 0x8033ff1c,
		"OSGetProgressiveMode": 0x8033ff1c,
		"os::OSGetLanguage": 0x8033ff8c,
		"OSGetLanguage": 0x8033ff8c,
		"os::OSGetEuRgb60Mode": 0x8033fff8,
		"OSGetEuRgb60Mode": 0x8033fff8,
		"os::OSSetEuRgb60Mode": 0x80340068,
		"OSSetEuRgb60Mode": 0x80340068,
		"os::OSGetWirelessID": 0x8034010c,
		"OSGetWirelessID": 0x8034010c,
		"os::OSSetWirelessID": 0x80340190,
		"OSSetWirelessID": 0x80340190,
		"os::OSInitStopwatch": 0x8034023c,
		"OSInitStopwatch": 0x8034023c,
		"os::OSStartStopwatch": 0x80340268,
		"OSStartStopwatch": 0x80340268,
		"os::OSStopStopwatch": 0x803402a4,
		"OSStopStopwatch": 0x803402a4,
		"os::OSCheckStopwatch": 0x80340370,
		"OSCheckStopwatch": 0x80340370,
		"os::OSResetStopwatch": 0x803403e0,
		"OSResetStopwatch": 0x803403e0,
		"os::SystemCallVector": 0x80340408,
		"SystemCallVector": 0x80340408,
		"os::__OSInitSystemCall": 0x80340428,
		"__OSInitSystemCall": 0x80340428,
		"os::__OSThreadInit": 0x8034048c,
		"__OSThreadInit": 0x8034048c,
		"os::OSInitThreadQueue": 0x803405b4,
		"OSInitThreadQueue": 0x803405b4,
		"os::OSGetCurrentThread": 0x803405c4,
		"OSGetCurrentThread": 0x803405c4,
		"os::OSIsThreadTerminated": 0x803405d0,
		"OSIsThreadTerminated": 0x803405d0,
		"os::OSDisableScheduler": 0x80340604,
		"OSDisableScheduler": 0x80340604,
		"os::OSEnableScheduler": 0x80340644,
		"OSEnableScheduler": 0x80340644,
		"os::UnsetRun": 0x80340684,
		"UnsetRun": 0x80340684,
		"os::__OSGetEffectivePriority": 0x803406ec,
		"__OSGetEffectivePriority": 0x803406ec,
		"os::SetEffectivePriority": 0x80340728,
		"SetEffectivePriority": 0x80340728,
		"os::__OSPromoteThread": 0x803408e8,
		"__OSPromoteThread": 0x803408e8,
		"os::SelectThread": 0x80340938,
		"SelectThread": 0x80340938,
		"os::__OSReschedule": 0x80340b38,
		"__OSReschedule": 0x80340b38,
		"os::OSYieldThread": 0x80340b68,
		"OSYieldThread": 0x80340b68,
		"os::OSCreateThread": 0x80340ba4,
		"OSCreateThread": 0x80340ba4,
		"os::OSExitThread": 0x80340cc4,
		"OSExitThread": 0x80340cc4,
		"os::OSCancelThread": 0x80340da8,
		"OSCancelThread": 0x80340da8,
		"os::OSJoinThread": 0x80340f64,
		"OSJoinThread": 0x80340f64,
		"os::OSDetachThread": 0x803410a4,
		"OSDetachThread": 0x803410a4,
		"os::OSResumeThread": 0x80341144,
		"OSResumeThread": 0x80341144,
		"os::OSSuspendThread": 0x803413cc,
		"OSSuspendThread": 0x803413cc,
		"os::OSSleepThread": 0x8034153c,
		"OSSleepThread": 0x8034153c,
		"os::OSWakeupThread": 0x80341628,
		"OSWakeupThread": 0x80341628,
		"os::OSGetThreadPriority": 0x8034172c,
		"OSGetThreadPriority": 0x8034172c,
		"os::OSGetTime": 0x80341734,
		"OSGetTime": 0x80341734,
		"os::OSGetTick": 0x8034174c,
		"OSGetTick": 0x8034174c,
		"os::__OSGetSystemTime": 0x80341754,
		"__OSGetSystemTime": 0x80341754,
		"os::GetDates": 0x803417b8,
		"GetDates": 0x803417b8,
		"os::OSTicksToCalendarTime": 0x80341954,
		"OSTicksToCalendarTime": 0x80341954,
		"os::__init_user": 0x80341b58,
		"__init_user": 0x80341b58,
		"os::__init_cpp": 0x80341b78,
		"__init_cpp": 0x80341b78,
		"os::_ExitProcess": 0x80341bcc,
		"_ExitProcess": 0x80341bcc,
		"mtx::PSMTXIdentity": 0x80341bec,
		"PSMTXIdentity": 0x80341bec,
		"mtx::PSMTXCopy": 0x80341c18,
		"PSMTXCopy": 0x80341c18,
		"mtx::PSMTXConcat": 0x80341c4c,
		"PSMTXConcat": 0x80341c4c,
		"mtx::PSMTXInverse": 0x80341d18,
		"PSMTXInverse": 0x80341d18,
		"mtx::PSMTXRotRad": 0x80341e10,
		"PSMTXRotRad": 0x80341e10,
		"mtx::PSMTXRotTrig": 0x80341e80,
		"PSMTXRotTrig": 0x80341e80,
		"mtx::PSMTXRotAxisRad": 0x80341f28,
		"PSMTXRotAxisRad": 0x80341f28,
		"mtx::PSMTXTrans": 0x8034202c,
		"PSMTXTrans": 0x8034202c,
		"mtx::PSMTXTransApply": 0x80342060,
		"PSMTXTransApply": 0x80342060,
		"mtx::PSMTXScale": 0x803420a0,
		"PSMTXScale": 0x803420a0,
		"mtx::PSMTXScaleApply": 0x803420c8,
		"PSMTXScaleApply": 0x803420c8,
		"mtx::PSMTXQuat": 0x80342114,
		"PSMTXQuat": 0x80342114,
		"mtx::C_MTXLookAt": 0x803421b8,
		"C_MTXLookAt": 0x803421b8,
		"mtx::C_MTXLightFrustum": 0x80342344,
		"C_MTXLightFrustum": 0x80342344,
		"mtx::C_MTXLightPerspective": 0x803423d8,
		"C_MTXLightPerspective": 0x803423d8,
		"mtx::C_MTXLightOrtho": 0x803424a4,
		"C_MTXLightOrtho": 0x803424a4,
		"mtx::PSMTXMultVec": 0x8034252c,
		"PSMTXMultVec": 0x8034252c,
		"mtx::PSMTXMultVecArray": 0x80342580,
		"PSMTXMultVecArray": 0x80342580,
		"mtx::PSMTXMultVecSR": 0x8034260c,
		"PSMTXMultVecSR": 0x8034260c,
		"mtx::C_MTXPerspective": 0x80342660,
		"C_MTXPerspective": 0x80342660,
		"mtx::C_MTXOrtho": 0x80342730,
		"C_MTXOrtho": 0x80342730,
		"mtx::PSVECAdd": 0x803427c8,
		"PSVECAdd": 0x803427c8,
		"mtx::PSVECSubtract": 0x803427ec,
		"PSVECSubtract": 0x803427ec,
		"mtx::PSVECScale": 0x80342810,
		"PSVECScale": 0x80342810,
		"mtx::PSVECNormalize": 0x8034282c,
		"PSVECNormalize": 0x8034282c,
		"mtx::PSVECMag": 0x80342870,
		"PSVECMag": 0x80342870,
		"mtx::PSVECDotProduct": 0x803428ac,
		"PSVECDotProduct": 0x803428ac,
		"mtx::PSVECCrossProduct": 0x803428cc,
		"PSVECCrossProduct": 0x803428cc,
		"mtx::PSVECSquareDistance": 0x80342908,
		"PSVECSquareDistance": 0x80342908,
		"mtx::PSVECDistance": 0x80342930,
		"PSVECDistance": 0x80342930,
		"dvd::__DVDInitWA": 0x8034297c,
		"__DVDInitWA": 0x8034297c,
		"dvd::__DVDInterruptHandler": 0x803429bc,
		"__DVDInterruptHandler": 0x803429bc,
		"dvd::AlarmHandlerForTimeout": 0x80342d34,
		"AlarmHandlerForTimeout": 0x80342d34,
		"dvd::Read": 0x80342da4,
		"Read": 0x80342da4,
		"dvd::SeekTwiceBeforeRead": 0x80342eb4,
		"SeekTwiceBeforeRead": 0x80342eb4,
		"dvd::DVDLowRead": 0x80342f34,
		"DVDLowRead": 0x80342f34,
		"dvd::DVDLowSeek": 0x803431cc,
		"DVDLowSeek": 0x803431cc,
		"dvd::DVDLowWaitCoverClose": 0x80343260,
		"DVDLowWaitCoverClose": 0x80343260,
		"dvd::DVDLowReadDiskID": 0x8034328c,
		"DVDLowReadDiskID": 0x8034328c,
		"dvd::DVDLowStopMotor": 0x80343330,
		"DVDLowStopMotor": 0x80343330,
		"dvd::DVDLowRequestError": 0x803433bc,
		"DVDLowRequestError": 0x803433bc,
		"dvd::DVDLowInquiry": 0x80343448,
		"DVDLowInquiry": 0x80343448,
		"dvd::DVDLowAudioStream": 0x803434e4,
		"DVDLowAudioStream": 0x803434e4,
		"dvd::DVDLowRequestAudioStatus": 0x8034357c,
		"DVDLowRequestAudioStatus": 0x8034357c,
		"dvd::DVDLowAudioBufferConfig": 0x80343608,
		"DVDLowAudioBufferConfig": 0x80343608,
		"dvd::DVDLowReset": 0x803436a4,
		"DVDLowReset": 0x803436a4,
		"dvd::DVDLowBreak": 0x80343760,
		"DVDLowBreak": 0x80343760,
		"dvd::DVDLowClearCallback": 0x80343774,
		"DVDLowClearCallback": 0x80343774,
		"dvd::__DVDLowSetWAType": 0x8034378c,
		"__DVDLowSetWAType": 0x8034378c,
		"dvd::__DVDFSInit": 0x803437d0,
		"__DVDFSInit": 0x803437d0,
		"dvd::DVDConvertPathToEntrynum": 0x80343808,
		"DVDConvertPathToEntrynum": 0x80343808,
		"dvd::DVDFastOpen": 0x80343afc,
		"DVDFastOpen": 0x80343afc,
		"dvd::DVDOpen": 0x80343b70,
		"DVDOpen": 0x80343b70,
		"dvd::DVDClose": 0x80343c38,
		"DVDClose": 0x80343c38,
		"dvd::entryToPath": 0x80343c5c,
		"entryToPath": 0x80343c5c,
		"dvd::DVDGetCurrentDir": 0x80343dbc,
		"DVDGetCurrentDir": 0x80343dbc,
		"dvd::DVDChangeDir": 0x80343e80,
		"DVDChangeDir": 0x80343e80,
		"dvd::DVDReadAsyncPrio": 0x80343ee0,
		"DVDReadAsyncPrio": 0x80343ee0,
		"dvd::cbForReadAsync": 0x80343fa0,
		"cbForReadAsync": 0x80343fa0,
		"dvd::DVDReadPrio": 0x80343fd0,
		"DVDReadPrio": 0x80343fd0,
		"dvd::cbForReadSync": 0x803440e8,
		"cbForReadSync": 0x803440e8,
		"dvd::DVDPrepareStreamAsync": 0x8034410c,
		"DVDPrepareStreamAsync": 0x8034410c,
		"dvd::cbForPrepareStreamAsync": 0x803441f8,
		"cbForPrepareStreamAsync": 0x803441f8,
		"dvd::DVDInit": 0x80344228,
		"DVDInit": 0x80344228,
		"dvd::stateReadingFST": 0x80344324,
		"stateReadingFST": 0x80344324,
		"dvd::cbForStateReadingFST": 0x80344378,
		"cbForStateReadingFST": 0x80344378,
		"dvd::cbForStateError": 0x803443f8,
		"cbForStateError": 0x803443f8,
		"dvd::stateTimeout": 0x803444a0,
		"stateTimeout": 0x803444a0,
		"dvd::stateGettingError": 0x8034453c,
		"stateGettingError": 0x8034453c,
		"dvd::CategorizeError": 0x80344564,
		"CategorizeError": 0x80344564,
		"dvd::cbForStateGettingError": 0x80344618,
		"cbForStateGettingError": 0x80344618,
		"dvd::cbForUnrecoveredError": 0x803448ac,
		"cbForUnrecoveredError": 0x803448ac,
		"dvd::cbForUnrecoveredErrorRetry": 0x80344914,
		"cbForUnrecoveredErrorRetry": 0x80344914,
		"dvd::stateGoToRetry": 0x803449ac,
		"stateGoToRetry": 0x803449ac,
		"dvd::cbForStateGoToRetry": 0x803449d4,
		"cbForStateGoToRetry": 0x803449d4,
		"dvd::stateCheckID": 0x80344b2c,
		"stateCheckID": 0x80344b2c,
		"dvd::stateCheckID3": 0x80344c10,
		"stateCheckID3": 0x80344c10,
		"dvd::stateCheckID2": 0x80344c44,
		"stateCheckID2": 0x80344c44,
		"dvd::cbForStateCheckID1": 0x80344c7c,
		"cbForStateCheckID1": 0x80344c7c,
		"dvd::cbForStateCheckID2": 0x80344d90,
		"cbForStateCheckID2": 0x80344d90,
		"dvd::cbForStateCheckID3": 0x80344e34,
		"cbForStateCheckID3": 0x80344e34,
		"dvd::stateCoverClosed": 0x80344f74,
		"stateCoverClosed": 0x80344f74,
		"dvd::stateCoverClosed_CMD": 0x80345040,
		"stateCoverClosed_CMD": 0x80345040,
		"dvd::cbForStateCoverClosed": 0x80345070,
		"cbForStateCoverClosed": 0x80345070,
		"dvd::stateMotorStopped": 0x803450e0,
		"stateMotorStopped": 0x803450e0,
		"dvd::cbForStateMotorStopped": 0x80345108,
		"cbForStateMotorStopped": 0x80345108,
		"dvd::stateReady": 0x803451ec,
		"stateReady": 0x803451ec,
		"dvd::stateBusy": 0x80345434,
		"stateBusy": 0x80345434,
		"dvd::cbForStateBusy": 0x803456f4,
		"cbForStateBusy": 0x803456f4,
		"dvd::DVDReadAbsAsyncPrio": 0x80345cc8,
		"DVDReadAbsAsyncPrio": 0x80345cc8,
		"dvd::DVDReadAbsAsyncForBS": 0x80345da4,
		"DVDReadAbsAsyncForBS": 0x80345da4,
		"dvd::DVDReadDiskID": 0x80345e74,
		"DVDReadDiskID": 0x80345e74,
		"dvd::DVDPrepareStreamAbsAsync": 0x80345f48,
		"DVDPrepareStreamAbsAsync": 0x80345f48,
		"dvd::DVDCancelStreamAsync": 0x8034600c,
		"DVDCancelStreamAsync": 0x8034600c,
		"dvd::DVDStopStreamAtEndAsync": 0x803460c8,
		"DVDStopStreamAtEndAsync": 0x803460c8,
		"dvd::DVDGetStreamPlayAddrAsync": 0x80346184,
		"DVDGetStreamPlayAddrAsync": 0x80346184,
		"dvd::DVDInquiryAsync": 0x80346240,
		"DVDInquiryAsync": 0x80346240,
		"dvd::DVDReset": 0x80346310,
		"DVDReset": 0x80346310,
		"dvd::DVDGetCommandBlockStatus": 0x80346354,
		"DVDGetCommandBlockStatus": 0x80346354,
		"dvd::DVDGetDriveStatus": 0x803463a0,
		"DVDGetDriveStatus": 0x803463a0,
		"dvd::DVDSetAutoInvalidation": 0x8034644c,
		"DVDSetAutoInvalidation": 0x8034644c,
		"dvd::DVDCancelAsync": 0x8034645c,
		"DVDCancelAsync": 0x8034645c,
		"dvd::DVDCancel": 0x803466cc,
		"DVDCancel": 0x803466cc,
		"dvd::cbForCancelSync": 0x80346778,
		"cbForCancelSync": 0x80346778,
		"dvd::DVDGetCurrentDiskID": 0x8034679c,
		"DVDGetCurrentDiskID": 0x8034679c,
		"dvd::DVDCheckDisk": 0x803467a4,
		"DVDCheckDisk": 0x803467a4,
		"dvd::__DVDPrepareResetAsync": 0x80346888,
		"__DVDPrepareResetAsync": 0x80346888,
		"dvd::__DVDClearWaitingQueue": 0x803469a4,
		"__DVDClearWaitingQueue": 0x803469a4,
		"dvd::__DVDPushWaitingQueue": 0x803469dc,
		"__DVDPushWaitingQueue": 0x803469dc,
		"dvd::__DVDPopWaitingQueue": 0x80346a44,
		"__DVDPopWaitingQueue": 0x80346a44,
		"dvd::__DVDCheckWaitingQueue": 0x80346ae4,
		"__DVDCheckWaitingQueue": 0x80346ae4,
		"dvd::__DVDDequeueWaitingQueue": 0x80346b3c,
		"__DVDDequeueWaitingQueue": 0x80346b3c,
		"dvd::ErrorCode2Num": 0x80346b9c,
		"ErrorCode2Num": 0x80346b9c,
		"dvd::__DVDStoreErrorCode": 0x80346cb8,
		"__DVDStoreErrorCode": 0x80346cb8,
		"dvd::cb": 0x80346d34,
		"dvd::__fstLoad": 0x80346e0c,
		"__fstLoad": 0x80346e0c,
		"vi::__VIRetraceHandler": 0x80346f74,
		"__VIRetraceHandler": 0x80346f74,
		"vi::VISetPostRetraceCallback": 0x8034719c,
		"VISetPostRetraceCallback": 0x8034719c,
		"vi::getTiming": 0x803471e0,
		"getTiming": 0x803471e0,
		"vi::__VIInit": 0x80347270,
		"__VIInit": 0x80347270,
		"vi::VIInit": 0x80347468,
		"VIInit": 0x80347468,
		"vi::VIWaitForRetrace": 0x803478e0,
		"VIWaitForRetrace": 0x803478e0,
		"vi::setFbbRegs": 0x80347934,
		"setFbbRegs": 0x80347934,
		"vi::setVerticalRegs": 0x80347c08,
		"setVerticalRegs": 0x80347c08,
		"vi::VIConfigure": 0x80347da8,
		"VIConfigure": 0x80347da8,
		"vi::VIFlush": 0x80348544,
		"VIFlush": 0x80348544,
		"vi::VISetNextFrameBuffer": 0x80348660,
		"VISetNextFrameBuffer": 0x80348660,
		"vi::VISetBlack": 0x803486cc,
		"VISetBlack": 0x803486cc,
		"vi::VIGetRetraceCount": 0x80348748,
		"VIGetRetraceCount": 0x80348748,
		"vi::getCurrentFieldEvenOdd": 0x80348750,
		"getCurrentFieldEvenOdd": 0x80348750,
		"vi::VIGetNextField": 0x803487b8,
		"VIGetNextField": 0x803487b8,
		"vi::VIGetCurrentLine": 0x80348860,
		"VIGetCurrentLine": 0x80348860,
		"vi::VIGetTvFormat": 0x803488f8,
		"VIGetTvFormat": 0x803488f8,
		"pad::ClampStick": 0x80348974,
		"ClampStick": 0x80348974,
		"pad::PADClamp": 0x80348aa4,
		"PADClamp": 0x80348aa4,
		"pad::UpdateOrigin": 0x80348bac,
		"UpdateOrigin": 0x80348bac,
		"pad::PADOriginCallback": 0x80348d50,
		"PADOriginCallback": 0x80348d50,
		"pad::PADOriginUpdateCallback": 0x80348e14,
		"PADOriginUpdateCallback": 0x80348e14,
		"pad::PADProbeCallback": 0x80348ed4,
		"PADProbeCallback": 0x80348ed4,
		"pad::PADTypeAndStatusCallback": 0x80348fac,
		"PADTypeAndStatusCallback": 0x80348fac,
		"pad::PADReceiveCheckCallback": 0x803492d8,
		"PADReceiveCheckCallback": 0x803492d8,
		"pad::PADReset": 0x8034940c,
		"PADReset": 0x8034940c,
		"pad::PADRecalibrate": 0x8034950c,
		"PADRecalibrate": 0x8034950c,
		"pad::PADInit": 0x80349610,
		"PADInit": 0x80349610,
		"pad::PADRead": 0x80349820,
		"PADRead": 0x80349820,
		"pad::PADControlMotor": 0x80349bcc,
		"PADControlMotor": 0x80349bcc,
		"pad::PADSetSpec": 0x80349c70,
		"PADSetSpec": 0x80349c70,
		"pad::SPEC0_MakeStatus": 0x80349cd0,
		"SPEC0_MakeStatus": 0x80349cd0,
		"pad::SPEC1_MakeStatus": 0x80349e44,
		"SPEC1_MakeStatus": 0x80349e44,
		"pad::SPEC2_MakeStatus": 0x80349fb8,
		"SPEC2_MakeStatus": 0x80349fb8,
		"pad::PADSetAnalogMode": 0x8034a3b0,
		"PADSetAnalogMode": 0x8034a3b0,
		"pad::OnReset": 0x8034a424,
		"pad::SamplingHandler": 0x8034a5b8,
		"SamplingHandler": 0x8034a5b8,
		"pad::PADSetSamplingCallback": 0x8034a618,
		"PADSetSamplingCallback": 0x8034a618,
		"pad::__PADDisableRecalibration": 0x8034a66c,
		"__PADDisableRecalibration": 0x8034a66c,
		"ai::AIRegisterDMACallback": 0x8034a6e8,
		"AIRegisterDMACallback": 0x8034a6e8,
		"ai::AIInitDMA": 0x8034a72c,
		"AIInitDMA": 0x8034a72c,
		"ai::AIStartDMA": 0x8034a7b4,
		"AIStartDMA": 0x8034a7b4,
		"ai::AIResetStreamSampleCount": 0x8034a7cc,
		"AIResetStreamSampleCount": 0x8034a7cc,
		"ai::AISetStreamPlayState": 0x8034a7e4,
		"AISetStreamPlayState": 0x8034a7e4,
		"ai::AIGetStreamPlayState": 0x8034a8bc,
		"AIGetStreamPlayState": 0x8034a8bc,
		"ai::AISetDSPSampleRate": 0x8034a8cc,
		"AISetDSPSampleRate": 0x8034a8cc,
		"ai::AIGetDSPSampleRate": 0x8034a9ac,
		"AIGetDSPSampleRate": 0x8034a9ac,
		"ai::AISetStreamSampleRate": 0x8034a9c0,
		"AISetStreamSampleRate": 0x8034a9c0,
		"ai::__AI_set_stream_sample_rate": 0x8034a9e8,
		"__AI_set_stream_sample_rate": 0x8034a9e8,
		"ai::AIGetStreamSampleRate": 0x8034aabc,
		"AIGetStreamSampleRate": 0x8034aabc,
		"ai::AISetStreamVolLeft": 0x8034aacc,
		"AISetStreamVolLeft": 0x8034aacc,
		"ai::AIGetStreamVolLeft": 0x8034aae8,
		"AIGetStreamVolLeft": 0x8034aae8,
		"ai::AISetStreamVolRight": 0x8034aaf8,
		"AISetStreamVolRight": 0x8034aaf8,
		"ai::AIGetStreamVolRight": 0x8034ab14,
		"AIGetStreamVolRight": 0x8034ab14,
		"ai::AIInit": 0x8034ab24,
		"AIInit": 0x8034ab24,
		"ai::__AISHandler": 0x8034ac88,
		"__AISHandler": 0x8034ac88,
		"ai::__AIDHandler": 0x8034ad04,
		"__AIDHandler": 0x8034ad04,
		"ai::__AICallbackStackSwitch": 0x8034ad94,
		"__AICallbackStackSwitch": 0x8034ad94,
		"ai::__AI_SRC_INIT": 0x8034adec,
		"__AI_SRC_INIT": 0x8034adec,
		"ar::ARRegisterDMACallback": 0x8034afd0,
		"ARRegisterDMACallback": 0x8034afd0,
		"ar::ARStartDMA": 0x8034b014,
		"ARStartDMA": 0x8034b014,
		"ar::ARAlloc": 0x8034b104,
		"ARAlloc": 0x8034b104,
		"ar::ARInit": 0x8034b16c,
		"ARInit": 0x8034b16c,
		"ar::ARGetBaseAddress": 0x8034b228,
		"ARGetBaseAddress": 0x8034b228,
		"ar::ARGetSize": 0x8034b230,
		"ARGetSize": 0x8034b230,
		"ar::__ARHandler": 0x8034b238,
		"__ARHandler": 0x8034b238,
		"ar::__ARChecksize": 0x8034b2b0,
		"__ARChecksize": 0x8034b2b0,
		"ar::__ARQServiceQueueLo": 0x8034bbc4,
		"__ARQServiceQueueLo": 0x8034bbc4,
		"ar::__ARQCallbackHack": 0x8034bcc4,
		"__ARQCallbackHack": 0x8034bcc4,
		"ar::__ARQInterruptServiceRoutine": 0x8034bcc8,
		"__ARQInterruptServiceRoutine": 0x8034bcc8,
		"ar::ARQInit": 0x8034bd94,
		"ARQInit": 0x8034bd94,
		"ar::ARQPostRequest": 0x8034bdfc,
		"ARQPostRequest": 0x8034bdfc,
		"dsp::DSPCheckMailToDSP": 0x8034bf58,
		"DSPCheckMailToDSP": 0x8034bf58,
		"dsp::DSPCheckMailFromDSP": 0x8034bf68,
		"DSPCheckMailFromDSP": 0x8034bf68,
		"dsp::DSPReadMailFromDSP": 0x8034bf78,
		"DSPReadMailFromDSP": 0x8034bf78,
		"dsp::DSPSendMailToDSP": 0x8034bf90,
		"DSPSendMailToDSP": 0x8034bf90,
		"dsp::DSPAssertInt": 0x8034bfa4,
		"DSPAssertInt": 0x8034bfa4,
		"dsp::DSPInit": 0x8034bfe4,
		"DSPInit": 0x8034bfe4,
		"dsp::__DSP_debug_printf": 0x8034c09c,
		"__DSP_debug_printf": 0x8034c09c,
		"dsp::__DSP_exec_task": 0x8034c0ec,
		"__DSP_exec_task": 0x8034c0ec,
		"dsp::__DSP_boot_task": 0x8034c28c,
		"__DSP_boot_task": 0x8034c28c,
		"dsp::__DSP_insert_task": 0x8034c418,
		"__DSP_insert_task": 0x8034c418,
		"dsp::__DSP_remove_task": 0x8034c4b8,
		"__DSP_remove_task": 0x8034c4b8,
		"card::__CARDDefaultApiCallback": 0x8034c54c,
		"__CARDDefaultApiCallback": 0x8034c54c,
		"card::__CARDSyncCallback": 0x8034c550,
		"__CARDSyncCallback": 0x8034c550,
		"card::__CARDExtHandler": 0x8034c584,
		"__CARDExtHandler": 0x8034c584,
		"card::__CARDExiHandler": 0x8034c65c,
		"__CARDExiHandler": 0x8034c65c,
		"card::__CARDTxHandler": 0x8034c774,
		"__CARDTxHandler": 0x8034c774,
		"card::__CARDUnlockedHandler": 0x8034c81c,
		"__CARDUnlockedHandler": 0x8034c81c,
		"card::__CARDEnableInterrupt": 0x8034c8a0,
		"__CARDEnableInterrupt": 0x8034c8a0,
		"card::__CARDReadStatus": 0x8034c960,
		"__CARDReadStatus": 0x8034c960,
		"card::__CARDClearStatus": 0x8034ca50,
		"__CARDClearStatus": 0x8034ca50,
		"card::TimeoutHandler": 0x8034cafc,
		"TimeoutHandler": 0x8034cafc,
		"card::Retry": 0x8034cba0,
		"Retry": 0x8034cba0,
		"card::UnlockedCallback": 0x8034cdcc,
		"UnlockedCallback": 0x8034cdcc,
		"card::__CARDStart": 0x8034cedc,
		"__CARDStart": 0x8034cedc,
		"card::__CARDReadSegment": 0x8034d090,
		"__CARDReadSegment": 0x8034d090,
		"card::__CARDWritePage": 0x8034d1c4,
		"__CARDWritePage": 0x8034d1c4,
		"card::__CARDEraseSector": 0x8034d2e0,
		"__CARDEraseSector": 0x8034d2e0,
		"card::CARDInit": 0x8034d3c0,
		"CARDInit": 0x8034d3c0,
		"card::__CARDSetDiskID": 0x8034d45c,
		"__CARDSetDiskID": 0x8034d45c,
		"card::__CARDGetControlBlock": 0x8034d494,
		"__CARDGetControlBlock": 0x8034d494,
		"card::__CARDPutControlBlock": 0x8034d54c,
		"__CARDPutControlBlock": 0x8034d54c,
		"card::CARDFreeBlocks": 0x8034d5b0,
		"CARDFreeBlocks": 0x8034d5b0,
		"card::__CARDSync": 0x8034d700,
		"__CARDSync": 0x8034d700,
		"card::OnReset": 0x8034d798,
		"card::bitrev": 0x8034d7e8,
		"bitrev": 0x8034d7e8,
		"card::ReadArrayUnlock": 0x8034d954,
		"ReadArrayUnlock": 0x8034d954,
		"card::DummyLen": 0x8034da98,
		"DummyLen": 0x8034da98,
		"card::__CARDUnlock": 0x8034db5c,
		"__CARDUnlock": 0x8034db5c,
		"card::InitCallback": 0x8034e6b4,
		"InitCallback": 0x8034e6b4,
		"card::DoneCallback": 0x8034e724,
		"DoneCallback": 0x8034e724,
		"card::BlockReadCallback": 0x8034ea48,
		"BlockReadCallback": 0x8034ea48,
		"card::__CARDRead": 0x8034eb24,
		"__CARDRead": 0x8034eb24,
		"card::BlockWriteCallback": 0x8034eb88,
		"BlockWriteCallback": 0x8034eb88,
		"card::__CARDWrite": 0x8034ec64,
		"__CARDWrite": 0x8034ec64,
		"card::__CARDGetFatBlock": 0x8034ecc8,
		"__CARDGetFatBlock": 0x8034ecc8,
		"card::__CARDAllocBlock": 0x8034ee6c,
		"__CARDAllocBlock": 0x8034ee6c,
		"card::__CARDUpdateFatBlock": 0x8034ef84,
		"__CARDUpdateFatBlock": 0x8034ef84,
		"card::__CARDGetDirBlock": 0x8034f030,
		"__CARDGetDirBlock": 0x8034f030,
		"card::__CARDUpdateDir": 0x8034f1d0,
		"__CARDUpdateDir": 0x8034f1d0,
		"card::__CARDCheckSum": 0x8034f294,
		"__CARDCheckSum": 0x8034f294,
		"card::VerifyID": 0x8034f444,
		"VerifyID": 0x8034f444,
		"card::VerifyDir": 0x8034f6c8,
		"VerifyDir": 0x8034f6c8,
		"card::VerifyFAT": 0x8034f908,
		"VerifyFAT": 0x8034f908,
		"card::__CARDVerify": 0x8034fb8c,
		"__CARDVerify": 0x8034fb8c,
		"card::CARDCheckExAsync": 0x8034fc18,
		"CARDCheckExAsync": 0x8034fc18,
		"card::CARDCheck": 0x803501a8,
		"CARDCheck": 0x803501a8,
		"card::IsCard": 0x803501fc,
		"IsCard": 0x803501fc,
		"card::CARDProbeEx": 0x803502c8,
		"CARDProbeEx": 0x803502c8,
		"card::DoMount": 0x80350444,
		"DoMount": 0x80350444,
		"card::__CARDMountCallback": 0x80350854,
		"__CARDMountCallback": 0x80350854,
		"card::CARDMountAsync": 0x8035095c,
		"CARDMountAsync": 0x8035095c,
		"card::CARDMount": 0x80350afc,
		"CARDMount": 0x80350afc,
		"card::DoUnmount": 0x80350b44,
		"DoUnmount": 0x80350b44,
		"card::CARDUnmount": 0x80350be0,
		"CARDUnmount": 0x80350be0,
		"card::FormatCallback": 0x80350c8c,
		"FormatCallback": 0x80350c8c,
		"card::__CARDFormatRegionAsync": 0x80350dd0,
		"__CARDFormatRegionAsync": 0x80350dd0,
		"card::CARDFormat": 0x80351428,
		"CARDFormat": 0x80351428,
		"card::__CARDCompareFileName": 0x8035147c,
		"__CARDCompareFileName": 0x8035147c,
		"card::__CARDAccess": 0x803514e4,
		"__CARDAccess": 0x803514e4,
		"card::__CARDIsPublic": 0x8035157c,
		"__CARDIsPublic": 0x8035157c,
		"card::CARDOpen": 0x803515ac,
		"CARDOpen": 0x803515ac,
		"card::CARDClose": 0x80351724,
		"CARDClose": 0x80351724,
		"card::CreateCallbackFat": 0x80351778,
		"CreateCallbackFat": 0x80351778,
		"card::CARDCreateAsync": 0x803518a8,
		"CARDCreateAsync": 0x803518a8,
		"card::CARDCreate": 0x80351ac8,
		"CARDCreate": 0x80351ac8,
		"card::__CARDSeek": 0x80351b10,
		"__CARDSeek": 0x80351b10,
		"card::ReadCallback": 0x80351cc8,
		"ReadCallback": 0x80351cc8,
		"card::CARDReadAsync": 0x80351df8,
		"CARDReadAsync": 0x80351df8,
		"card::CARDRead": 0x80351f40,
		"CARDRead": 0x80351f40,
		"card::CARDWriteAsync": 0x803521a8,
		"CARDWriteAsync": 0x803521a8,
		"card::CARDWrite": 0x803522bc,
		"CARDWrite": 0x803522bc,
		"card::UpdateIconOffsets": 0x80352304,
		"UpdateIconOffsets": 0x80352304,
		"card::CARDGetStatus": 0x803524fc,
		"CARDGetStatus": 0x803524fc,
		"card::CARDSetStatusAsync": 0x80352628,
		"CARDSetStatusAsync": 0x80352628,
		"card::CARDSetStatus": 0x8035279c,
		"CARDSetStatus": 0x8035279c,
		"gx::__GXDefaultTexRegionCallback": 0x803527e4,
		"__GXDefaultTexRegionCallback": 0x803527e4,
		"gx::__GXDefaultTlutRegionCallback": 0x80352860,
		"__GXDefaultTlutRegionCallback": 0x80352860,
		"gx::GXInit": 0x80352884,
		"GXInit": 0x80352884,
		"gx::__GXInitGX": 0x80353050,
		"__GXInitGX": 0x80353050,
		"gx::GXCPInterruptHandler": 0x803538d4,
		"GXCPInterruptHandler": 0x803538d4,
		"gx::GXInitFifoBase": 0x80353a10,
		"GXInitFifoBase": 0x80353a10,
		"gx::GXInitFifoPtrs": 0x80353a7c,
		"GXInitFifoPtrs": 0x80353a7c,
		"gx::GXInitFifoLimits": 0x80353aec,
		"GXInitFifoLimits": 0x80353aec,
		"gx::GXSetCPUFifo": 0x80353af8,
		"GXSetCPUFifo": 0x80353af8,
		"gx::GXSetGPFifo": 0x80353c08,
		"GXSetGPFifo": 0x80353c08,
		"gx::GXGetFifoPtrs": 0x80353d80,
		"GXGetFifoPtrs": 0x80353d80,
		"gx::GXEnableBreakPt": 0x80353e18,
		"GXEnableBreakPt": 0x80353e18,
		"gx::GXDisableBreakPt": 0x80353eb0,
		"GXDisableBreakPt": 0x80353eb0,
		"gx::__GXFifoInit": 0x80353f14,
		"__GXFifoInit": 0x80353f14,
		"gx::__GXFifoReadEnable": 0x80353f60,
		"__GXFifoReadEnable": 0x80353f60,
		"gx::__GXFifoReadDisable": 0x80353f88,
		"__GXFifoReadDisable": 0x80353f88,
		"gx::__GXFifoLink": 0x80353fac,
		"__GXFifoLink": 0x80353fac,
		"gx::__GXWriteFifoIntEnable": 0x80353ff0,
		"__GXWriteFifoIntEnable": 0x80353ff0,
		"gx::__GXWriteFifoIntReset": 0x8035403c,
		"__GXWriteFifoIntReset": 0x8035403c,
		"gx::GXGetCPUFifo": 0x80354088,
		"GXGetCPUFifo": 0x80354088,
		"gx::__GXXfVtxSpecs": 0x80354090,
		"__GXXfVtxSpecs": 0x80354090,
		"gx::GXSetVtxDesc": 0x803541e8,
		"GXSetVtxDesc": 0x803541e8,
		"gx::GXSetVtxDescv": 0x80354548,
		"GXSetVtxDescv": 0x80354548,
		"gx::__GXSetVCD": 0x803548cc,
		"__GXSetVCD": 0x803548cc,
		"gx::__GXCalculateVLim": 0x80354920,
		"__GXCalculateVLim": 0x80354920,
		"gx::GXGetVtxDesc": 0x80354a44,
		"GXGetVtxDesc": 0x80354a44,
		"gx::GXGetVtxDescv": 0x80354bf8,
		"GXGetVtxDescv": 0x80354bf8,
		"gx::GXClearVtxDesc": 0x80354c68,
		"GXClearVtxDesc": 0x80354c68,
		"gx::GXSetVtxAttrFmt": 0x80354cb4,
		"GXSetVtxAttrFmt": 0x80354cb4,
		"gx::GXSetVtxAttrFmtv": 0x80355010,
		"GXSetVtxAttrFmtv": 0x80355010,
		"gx::__GXSetVAT": 0x8035538c,
		"__GXSetVAT": 0x8035538c,
		"gx::GXGetVtxAttrFmt": 0x80355428,
		"GXGetVtxAttrFmt": 0x80355428,
		"gx::GXGetVtxAttrFmtv": 0x80355670,
		"GXGetVtxAttrFmtv": 0x80355670,
		"gx::GXSetArray": 0x803556e4,
		"GXSetArray": 0x803556e4,
		"gx::GXInvalidateVtxCache": 0x80355770,
		"GXInvalidateVtxCache": 0x80355770,
		"gx::GXSetTexCoordGen2": 0x80355780,
		"GXSetTexCoordGen2": 0x80355780,
		"gx::GXSetNumTexGens": 0x80355a50,
		"GXSetNumTexGens": 0x80355a50,
		"gx::GXSetMisc": 0x80355a98,
		"GXSetMisc": 0x80355a98,
		"gx::GXFlush": 0x80355b10,
		"GXFlush": 0x80355b10,
		"gx::GXSetDrawSync": 0x80355b6c,
		"GXSetDrawSync": 0x80355b6c,
		"gx::GXSetDrawDone": 0x80355c24,
		"GXSetDrawDone": 0x80355c24,
		"gx::GXWaitDrawDone": 0x80355cbc,
		"GXWaitDrawDone": 0x80355cbc,
		"gx::GXDrawDone": 0x80355d08,
		"GXDrawDone": 0x80355d08,
		"gx::GXPixModeSync": 0x80355d88,
		"GXPixModeSync": 0x80355d88,
		"gx::GXPokeAlphaMode": 0x80355dac,
		"GXPokeAlphaMode": 0x80355dac,
		"gx::GXPokeAlphaRead": 0x80355dc0,
		"GXPokeAlphaRead": 0x80355dc0,
		"gx::GXPokeAlphaUpdate": 0x80355dd4,
		"GXPokeAlphaUpdate": 0x80355dd4,
		"gx::GXPokeBlendMode": 0x80355df0,
		"GXPokeBlendMode": 0x80355df0,
		"gx::GXPokeColorUpdate": 0x80355e78,
		"GXPokeColorUpdate": 0x80355e78,
		"gx::GXPokeDstAlpha": 0x80355e94,
		"GXPokeDstAlpha": 0x80355e94,
		"gx::GXPokeDither": 0x80355ea8,
		"GXPokeDither": 0x80355ea8,
		"gx::GXPokeZMode": 0x80355ec4,
		"GXPokeZMode": 0x80355ec4,
		"gx::GXPeekARGB": 0x80355eec,
		"GXPeekARGB": 0x80355eec,
		"gx::GXPeekZ": 0x80355f10,
		"GXPeekZ": 0x80355f10,
		"gx::GXSetDrawSyncCallback": 0x80355f38,
		"GXSetDrawSyncCallback": 0x80355f38,
		"gx::GXTokenInterruptHandler": 0x80355f7c,
		"GXTokenInterruptHandler": 0x80355f7c,
		"gx::GXFinishInterruptHandler": 0x80356004,
		"GXFinishInterruptHandler": 0x80356004,
		"gx::__GXPEInit": 0x80356088,
		"__GXPEInit": 0x80356088,
		"gx::__GXSetDirtyState": 0x80356108,
		"__GXSetDirtyState": 0x80356108,
		"gx::GXBegin": 0x803561a8,
		"GXBegin": 0x803561a8,
		"gx::__GXSendFlushPrim": 0x80356298,
		"__GXSendFlushPrim": 0x80356298,
		"gx::GXSetLineWidth": 0x80356320,
		"GXSetLineWidth": 0x80356320,
		"gx::GXSetPointSize": 0x80356378,
		"GXSetPointSize": 0x80356378,
		"gx::GXEnableTexOffsets": 0x803563cc,
		"GXEnableTexOffsets": 0x803563cc,
		"gx::GXSetCullMode": 0x80356430,
		"GXSetCullMode": 0x80356430,
		"gx::GXSetCoPlanar": 0x80356480,
		"GXSetCoPlanar": 0x80356480,
		"gx::__GXSetGenMode": 0x803564c4,
		"__GXSetGenMode": 0x803564c4,
		"gx::GXSetDispCopySrc": 0x803564e8,
		"GXSetDispCopySrc": 0x803564e8,
		"gx::GXSetTexCopySrc": 0x803565a8,
		"GXSetTexCopySrc": 0x803565a8,
		"gx::GXSetDispCopyDst": 0x80356668,
		"GXSetDispCopyDst": 0x80356668,
		"gx::GXSetTexCopyDst": 0x803566ac,
		"GXSetTexCopyDst": 0x803566ac,
		"gx::GXSetDispCopyFrame2Field": 0x8035681c,
		"GXSetDispCopyFrame2Field": 0x8035681c,
		"gx::GXSetCopyClamp": 0x80356848,
		"GXSetCopyClamp": 0x80356848,
		"gx::GXGetNumXfbLines": 0x803568c4,
		"GXGetNumXfbLines": 0x803568c4,
		"gx::GXGetYScaleFactor": 0x80356954,
		"GXGetYScaleFactor": 0x80356954,
		"gx::GXSetDispCopyYScale": 0x80356b8c,
		"GXSetDispCopyYScale": 0x80356b8c,
		"gx::GXSetCopyClear": 0x80356c60,
		"GXSetCopyClear": 0x80356c60,
		"gx::GXSetCopyFilter": 0x80356cc8,
		"GXSetCopyFilter": 0x80356cc8,
		"gx::GXSetDispCopyGamma": 0x80356ef0,
		"GXSetDispCopyGamma": 0x80356ef0,
		"gx::GXCopyDisp": 0x80356f0c,
		"GXCopyDisp": 0x80356f0c,
		"gx::GXCopyTex": 0x8035707c,
		"GXCopyTex": 0x8035707c,
		"gx::GXClearBoundingBox": 0x8035720c,
		"GXClearBoundingBox": 0x8035720c,
		"gx::GXInitLightAttn": 0x80357244,
		"GXInitLightAttn": 0x80357244,
		"gx::GXInitLightAttnA": 0x80357260,
		"GXInitLightAttnA": 0x80357260,
		"gx::GXInitLightAttnK": 0x80357270,
		"GXInitLightAttnK": 0x80357270,
		"gx::GXInitLightDistAttn": 0x80357280,
		"GXInitLightDistAttn": 0x80357280,
		"gx::GXInitLightPos": 0x80357350,
		"GXInitLightPos": 0x80357350,
		"gx::GXInitSpecularDir": 0x80357360,
		"GXInitSpecularDir": 0x80357360,
		"gx::GXInitLightColor": 0x80357434,
		"GXInitLightColor": 0x80357434,
		"gx::GXGetLightColor": 0x8035745c,
		"GXGetLightColor": 0x8035745c,
		"gx::GXLoadLightObjImm": 0x8035748c,
		"GXLoadLightObjImm": 0x8035748c,
		"gx::GXSetChanAmbColor": 0x803575d4,
		"GXSetChanAmbColor": 0x803575d4,
		"gx::GXSetChanMatColor": 0x8035773c,
		"GXSetChanMatColor": 0x8035773c,
		"gx::GXSetNumChans": 0x803578a4,
		"GXSetNumChans": 0x803578a4,
		"gx::GXSetChanCtrl": 0x803578f0,
		"GXSetChanCtrl": 0x803578f0,
		"gx::GXGetTexBufferSize": 0x80357ad4,
		"GXGetTexBufferSize": 0x80357ad4,
		"gx::__GetImageTileCount": 0x80357c30,
		"__GetImageTileCount": 0x80357c30,
		"gx::GXInitTexObj": 0x80357cf8,
		"GXInitTexObj": 0x80357cf8,
		"gx::GXInitTexObjCI": 0x80357f6c,
		"GXInitTexObjCI": 0x80357f6c,
		"gx::GXInitTexObjLOD": 0x80357fb4,
		"GXInitTexObjLOD": 0x80357fb4,
		"gx::GXGetTexObjAll": 0x80358148,
		"GXGetTexObjAll": 0x80358148,
		"gx::GXGetTexObjWidth": 0x803581b0,
		"GXGetTexObjWidth": 0x803581b0,
		"gx::GXGetTexObjHeight": 0x803581c0,
		"GXGetTexObjHeight": 0x803581c0,
		"gx::GXGetTexObjFmt": 0x803581d0,
		"GXGetTexObjFmt": 0x803581d0,
		"gx::GXLoadTexObjPreLoaded": 0x803581d8,
		"GXLoadTexObjPreLoaded": 0x803581d8,
		"gx::GXLoadTexObj": 0x80358380,
		"GXLoadTexObj": 0x80358380,
		"gx::GXInitTlutObj": 0x803583d4,
		"GXInitTlutObj": 0x803583d4,
		"gx::GXLoadTlut": 0x8035841c,
		"GXLoadTlut": 0x8035841c,
		"gx::GXInitTexCacheRegion": 0x803584b8,
		"GXInitTexCacheRegion": 0x803584b8,
		"gx::GXInitTlutRegion": 0x803585d8,
		"GXInitTlutRegion": 0x803585d8,
		"gx::GXInvalidateTexAll": 0x80358620,
		"GXInvalidateTexAll": 0x80358620,
		"gx::GXSetTexRegionCallback": 0x80358668,
		"GXSetTexRegionCallback": 0x80358668,
		"gx::GXSetTlutRegionCallback": 0x8035867c,
		"GXSetTlutRegionCallback": 0x8035867c,
		"gx::GXSetTexCoordScaleManually": 0x80358690,
		"GXSetTexCoordScaleManually": 0x80358690,
		"gx::GXSetTexCoordCylWrap": 0x8035872c,
		"GXSetTexCoordCylWrap": 0x8035872c,
		"gx::__SetSURegs": 0x803587b0,
		"__SetSURegs": 0x803587b0,
		"gx::__GXSetSUTexRegs": 0x8035887c,
		"__GXSetSUTexRegs": 0x8035887c,
		"gx::__GXSetTmemConfig": 0x803589f8,
		"__GXSetTmemConfig": 0x803589f8,
		"gx::GXSetTevIndirect": 0x80358c38,
		"GXSetTevIndirect": 0x80358c38,
		"gx::GXSetIndTexMtx": 0x80358cd4,
		"GXSetIndTexMtx": 0x80358cd4,
		"gx::GXSetIndTexCoordScale": 0x80358e34,
		"GXSetIndTexCoordScale": 0x80358e34,
		"gx::GXSetIndTexOrder": 0x80359008,
		"GXSetIndTexOrder": 0x80359008,
		"gx::GXSetNumIndStages": 0x80359140,
		"GXSetNumIndStages": 0x80359140,
		"gx::GXSetTevDirect": 0x8035916c,
		"GXSetTevDirect": 0x8035916c,
		"gx::GXSetTevIndWarp": 0x803591b4,
		"GXSetTevIndWarp": 0x803591b4,
		"gx::__GXUpdateBPMask": 0x80359218,
		"__GXUpdateBPMask": 0x80359218,
		"gx::__GXFlushTextureState": 0x803592e4,
		"__GXFlushTextureState": 0x803592e4,
		"gx::GXSetTevOp": 0x80359308,
		"GXSetTevOp": 0x80359308,
		"gx::GXSetTevColorIn": 0x803594ac,
		"GXSetTevColorIn": 0x803594ac,
		"gx::GXSetTevAlphaIn": 0x8035952c,
		"GXSetTevAlphaIn": 0x8035952c,
		"gx::GXSetTevColorOp": 0x803595b0,
		"GXSetTevColorOp": 0x803595b0,
		"gx::GXSetTevAlphaOp": 0x80359670,
		"GXSetTevAlphaOp": 0x80359670,
		"gx::GXSetTevColor": 0x80359730,
		"GXSetTevColor": 0x80359730,
		"gx::GXSetTevColorS10": 0x803597a4,
		"GXSetTevColorS10": 0x803597a4,
		"gx::GXSetTevKColor": 0x80359818,
		"GXSetTevKColor": 0x80359818,
		"gx::GXSetTevKColorSel": 0x8035988c,
		"GXSetTevKColorSel": 0x8035988c,
		"gx::GXSetTevKAlphaSel": 0x803598f8,
		"GXSetTevKAlphaSel": 0x803598f8,
		"gx::GXSetTevSwapMode": 0x80359964,
		"GXSetTevSwapMode": 0x80359964,
		"gx::GXSetTevSwapModeTable": 0x803599bc,
		"GXSetTevSwapModeTable": 0x803599bc,
		"gx::GXSetAlphaCompare": 0x80359a5c,
		"GXSetAlphaCompare": 0x80359a5c,
		"gx::GXSetZTexture": 0x80359aac,
		"GXSetZTexture": 0x80359aac,
		"gx::GXSetTevOrder": 0x80359b30,
		"GXSetTevOrder": 0x80359b30,
		"gx::GXSetNumTevStages": 0x80359d0c,
		"GXSetNumTevStages": 0x80359d0c,
		"gx::GXSetFog": 0x80359d40,
		"GXSetFog": 0x80359d40,
		"gx::GXSetFogRangeAdj": 0x80359ef0,
		"GXSetFogRangeAdj": 0x80359ef0,
		"gx::GXSetBlendMode": 0x80359ff0,
		"GXSetBlendMode": 0x80359ff0,
		"gx::GXSetColorUpdate": 0x8035a0f4,
		"GXSetColorUpdate": 0x8035a0f4,
		"gx::GXSetAlphaUpdate": 0x8035a134,
		"GXSetAlphaUpdate": 0x8035a134,
		"gx::GXSetZMode": 0x8035a174,
		"GXSetZMode": 0x8035a174,
		"gx::GXSetZCompLoc": 0x8035a1ec,
		"GXSetZCompLoc": 0x8035a1ec,
		"gx::GXSetPixelFmt": 0x8035a22c,
		"GXSetPixelFmt": 0x8035a22c,
		"gx::GXSetDither": 0x8035a33c,
		"GXSetDither": 0x8035a33c,
		"gx::GXSetDstAlpha": 0x8035a37c,
		"GXSetDstAlpha": 0x8035a37c,
		"gx::GXSetFieldMask": 0x8035a3d0,
		"GXSetFieldMask": 0x8035a3d0,
		"gx::GXSetFieldMode": 0x8035a408,
		"GXSetFieldMode": 0x8035a408,
		"gx::GXDrawSphere": 0x8035a488,
		"GXDrawSphere": 0x8035a488,
		"gx::GXDrawCubeFace": 0x8035a804,
		"GXDrawCubeFace": 0x8035a804,
		"gx::GXDrawCube": 0x8035aa1c,
		"GXDrawCube": 0x8035aa1c,
		"gx::__GXSetRange": 0x8035ac6c,
		"__GXSetRange": 0x8035ac6c,
		"gx::GXCallDisplayList": 0x8035ac70,
		"GXCallDisplayList": 0x8035ac70,
		"gx::GXProject": 0x8035ace0,
		"GXProject": 0x8035ace0,
		"gx::GXSetProjection": 0x8035ae54,
		"GXSetProjection": 0x8035ae54,
		"gx::GXGetProjectionv": 0x8035af28,
		"GXGetProjectionv": 0x8035af28,
		"gx::WriteMTXPS4x3": 0x8035afa0,
		"WriteMTXPS4x3": 0x8035afa0,
		"gx::WriteMTXPS3x3from3x4": 0x8035afd4,
		"WriteMTXPS3x3from3x4": 0x8035afd4,
		"gx::WriteMTXPS4x2": 0x8035b008,
		"WriteMTXPS4x2": 0x8035b008,
		"gx::GXLoadPosMtxImm": 0x8035b02c,
		"GXLoadPosMtxImm": 0x8035b02c,
		"gx::GXLoadPosMtxIndx": 0x8035b068,
		"GXLoadPosMtxIndx": 0x8035b068,
		"gx::GXLoadNrmMtxImm": 0x8035b098,
		"GXLoadNrmMtxImm": 0x8035b098,
		"gx::GXLoadNrmMtxIndx3x3": 0x8035b0d8,
		"GXLoadNrmMtxIndx3x3": 0x8035b0d8,
		"gx::GXSetCurrentMtx": 0x8035b10c,
		"GXSetCurrentMtx": 0x8035b10c,
		"gx::GXLoadTexMtxImm": 0x8035b148,
		"GXLoadTexMtxImm": 0x8035b148,
		"gx::GXSetViewportJitter": 0x8035b1cc,
		"GXSetViewportJitter": 0x8035b1cc,
		"gx::GXSetViewport": 0x8035b2e8,
		"GXSetViewport": 0x8035b2e8,
		"gx::GXGetViewportv": 0x8035b30c,
		"GXGetViewportv": 0x8035b30c,
		"gx::GXSetScissor": 0x8035b358,
		"GXSetScissor": 0x8035b358,
		"gx::GXSetScissorBoxOffset": 0x8035b408,
		"GXSetScissorBoxOffset": 0x8035b408,
		"gx::GXSetClipMode": 0x8035b44c,
		"GXSetClipMode": 0x8035b44c,
		"gx::__GXSetMatrixIndex": 0x8035b474,
		"__GXSetMatrixIndex": 0x8035b474,
		"gx::GXSetGPMetric": 0x8035b4f8,
		"GXSetGPMetric": 0x8035b4f8,
		"gx::GXClearGPMetric": 0x8035bd90,
		"GXClearGPMetric": 0x8035bd90,
		"gx::GXReadPixMetric": 0x8035bda0,
		"GXReadPixMetric": 0x8035bda0,
		"gx::GXClearPixMetric": 0x8035be30,
		"GXClearPixMetric": 0x8035be30,
		"OdemuExi2::DBClose": 0x8035be60,
		"DBClose": 0x8035be60,
		"OdemuExi2::DBOpen": 0x8035be64,
		"DBOpen": 0x8035be64,
		"OdemuExi2::DBWrite": 0x8035be68,
		"DBWrite": 0x8035be68,
		"OdemuExi2::DBRead": 0x8035c0c8,
		"DBRead": 0x8035c0c8,
		"OdemuExi2::DBQueryData": 0x8035c154,
		"DBQueryData": 0x8035c154,
		"OdemuExi2::DBInitInterrupts": 0x8035c1f0,
		"DBInitInterrupts": 0x8035c1f0,
		"OdemuExi2::DBInitComm": 0x8035c244,
		"DBInitComm": 0x8035c244,
		"OdemuExi2::DBGHandler": 0x8035c2bc,
		"DBGHandler": 0x8035c2bc,
		"OdemuExi2::MWCallback": 0x8035c2fc,
		"MWCallback": 0x8035c2fc,
		"OdemuExi2::DBGReadStatus": 0x8035c338,
		"DBGReadStatus": 0x8035c338,
		"OdemuExi2::DBGWrite": 0x8035c3e4,
		"DBGWrite": 0x8035c3e4,
		"OdemuExi2::DBGRead": 0x8035c4c0,
		"DBGRead": 0x8035c4c0,
		"OdemuExi2::DBGReadMailbox": 0x8035c59c,
		"DBGReadMailbox": 0x8035c59c,
		"OdemuExi2::DBGEXIImm": 0x8035c648,
		"DBGEXIImm": 0x8035c648,
		"amcstubs::EXI2_Init": 0x8035c8e0,
		"EXI2_Init": 0x8035c8e0,
		"amcstubs::EXI2_EnableInterrupts": 0x8035c8e4,
		"EXI2_EnableInterrupts": 0x8035c8e4,
		"amcstubs::EXI2_Poll": 0x8035c8e8,
		"EXI2_Poll": 0x8035c8e8,
		"amcstubs::EXI2_ReadN": 0x8035c8f0,
		"EXI2_ReadN": 0x8035c8f0,
		"amcstubs::EXI2_WriteN": 0x8035c8f8,
		"EXI2_WriteN": 0x8035c8f8,
		"amcstubs::EXI2_Reserve": 0x8035c900,
		"EXI2_Reserve": 0x8035c900,
		"amcstubs::EXI2_Unreserve": 0x8035c904,
		"EXI2_Unreserve": 0x8035c904,
		"amcstubs::AMC_IsStub": 0x8035c908,
		"AMC_IsStub": 0x8035c908,
		"odenotstub::Hu_IsStub": 0x8035c910,
		"Hu_IsStub": 0x8035c910,
		"gd::GDInitGDLObj": 0x8035c918,
		"GDInitGDLObj": 0x8035c918,
		"gd::GDFlushCurrToMem": 0x8035c930,
		"GDFlushCurrToMem": 0x8035c930,
		"gd::GDPadCurr32": 0x8035c95c,
		"GDPadCurr32": 0x8035c95c,
		"gd::GDOverflowed": 0x8035ca54,
		"GDOverflowed": 0x8035ca54,
		"gd::GDSetOverflowCallback": 0x8035ca84,
		"GDSetOverflowCallback": 0x8035ca84,
		"gd::GDSetVtxDescv": 0x8035ca8c,
		"GDSetVtxDescv": 0x8035ca8c,
		"gd::GDSetVtxAttrFmtv": 0x8035d088,
		"GDSetVtxAttrFmtv": 0x8035d088,
		"gd::GDSetArray": 0x8035d6a8,
		"GDSetArray": 0x8035d6a8,
		"gd::GDSetArrayRaw": 0x8035d8b4,
		"GDSetArrayRaw": 0x8035d8b4,
		"gd::GDSetCullMode": 0x8035dabc,
		"GDSetCullMode": 0x8035dabc,
		"gd::GDSetGenMode2": 0x8035dc48,
		"GDSetGenMode2": 0x8035dc48,
		"gd::GDSetLightAttn": 0x8035e084,
		"GDSetLightAttn": 0x8035e084,
		"gd::GDSetLightColor": 0x8035e520,
		"GDSetLightColor": 0x8035e520,
		"gd::GDSetLightPos": 0x8035e6c8,
		"GDSetLightPos": 0x8035e6c8,
		"gd::GDSetLightDir": 0x8035e99c,
		"GDSetLightDir": 0x8035e99c,
		"gd::GDSetChanMatColor": 0x8035ec70,
		"GDSetChanMatColor": 0x8035ec70,
		"gd::GDSetChanCtrl": 0x8035ee08,
		"GDSetChanCtrl": 0x8035ee08,
		"gd::GDSetBlendMode": 0x8035f11c,
		"GDSetBlendMode": 0x8035f11c,
		"gd::GDSetBlendModeEtc": 0x8035f3a8,
		"GDSetBlendModeEtc": 0x8035f3a8,
		"gd::GDSetZMode": 0x8035f5b4,
		"GDSetZMode": 0x8035f5b4,
		"gd::GDSetDstAlpha": 0x8035f6b8,
		"GDSetDstAlpha": 0x8035f6b8,
		"gd::GDSetTevOp": 0x8035f7a4,
		"GDSetTevOp": 0x8035f7a4,
		"gd::GDSetTevColorCalc": 0x8035fa38,
		"GDSetTevColorCalc": 0x8035fa38,
		"gd::GDSetTevAlphaCalcAndSwap": 0x8035fc84,
		"GDSetTevAlphaCalcAndSwap": 0x8035fc84,
		"gd::GDSetAlphaCompare": 0x8035fef8,
		"GDSetAlphaCompare": 0x8035fef8,
		"gd::GDSetTevOrder": 0x8035fffc,
		"GDSetTevOrder": 0x8035fffc,
		"gd::GDSetCurrentMtx": 0x8036016c,
		"GDSetCurrentMtx": 0x8036016c,
		"si::SIBusy": 0x80360538,
		"SIBusy": 0x80360538,
		"si::SIIsChanBusy": 0x80360558,
		"SIIsChanBusy": 0x80360558,
		"si::CompleteTransfer": 0x80360594,
		"CompleteTransfer": 0x80360594,
		"si::SIInterruptHandler": 0x80360890,
		"SIInterruptHandler": 0x80360890,
		"si::SIEnablePollingInterrupt": 0x80360bd4,
		"SIEnablePollingInterrupt": 0x80360bd4,
		"si::SIRegisterPollingHandler": 0x80360c6c,
		"SIRegisterPollingHandler": 0x80360c6c,
		"si::SIUnregisterPollingHandler": 0x80360d38,
		"SIUnregisterPollingHandler": 0x80360d38,
		"si::SIInit": 0x80360e2c,
		"SIInit": 0x80360e2c,
		"si::__SITransfer": 0x80360ed0,
		"__SITransfer": 0x80360ed0,
		"si::SIGetStatus": 0x803610dc,
		"SIGetStatus": 0x803610dc,
		"si::SISetCommand": 0x80361158,
		"SISetCommand": 0x80361158,
		"si::SITransferCommands": 0x8036116c,
		"SITransferCommands": 0x8036116c,
		"si::SISetXY": 0x8036117c,
		"SISetXY": 0x8036117c,
		"si::SIEnablePolling": 0x803611e8,
		"SIEnablePolling": 0x803611e8,
		"si::SIDisablePolling": 0x80361284,
		"SIDisablePolling": 0x80361284,
		"si::SIGetResponseRaw": 0x803612f0,
		"SIGetResponseRaw": 0x803612f0,
		"si::SIGetResponse": 0x803613c4,
		"SIGetResponse": 0x803613c4,
		"si::AlarmHandler": 0x80361488,
		"si::SITransfer": 0x80361514,
		"SITransfer": 0x80361514,
		"si::GetTypeCallback": 0x80361680,
		"GetTypeCallback": 0x80361680,
		"si::SIGetType": 0x80361918,
		"SIGetType": 0x80361918,
		"si::SIGetTypeAsync": 0x80361adc,
		"SIGetTypeAsync": 0x80361adc,
		"si::SISetSamplingRate": 0x80361c18,
		"SISetSamplingRate": 0x80361c18,
		"si::SIRefreshSamplingRate": 0x80361cfc,
		"SIRefreshSamplingRate": 0x80361cfc,
		"exi::SetExiInterruptMask": 0x80361d20,
		"SetExiInterruptMask": 0x80361d20,
		"exi::EXIImm": 0x80361e14,
		"EXIImm": 0x80361e14,
		"exi::EXIImmEx": 0x80362070,
		"EXIImmEx": 0x80362070,
		"exi::EXIDma": 0x80362110,
		"EXIDma": 0x80362110,
		"exi::EXISync": 0x803621fc,
		"EXISync": 0x803621fc,
		"exi::EXIClearInterrupts": 0x80362434,
		"EXIClearInterrupts": 0x80362434,
		"exi::EXISetExiCallback": 0x8036247c,
		"EXISetExiCallback": 0x8036247c,
		"exi::__EXIProbe": 0x803624f8,
		"__EXIProbe": 0x803624f8,
		"exi::EXIProbe": 0x8036266c,
		"EXIProbe": 0x8036266c,
		"exi::EXIProbeEx": 0x803626ec,
		"EXIProbeEx": 0x803626ec,
		"exi::EXIAttach": 0x803627a0,
		"EXIAttach": 0x803627a0,
		"exi::EXIDetach": 0x803628ac,
		"EXIDetach": 0x803628ac,
		"exi::EXISelect": 0x80362968,
		"EXISelect": 0x80362968,
		"exi::EXIDeselect": 0x80362a94,
		"EXIDeselect": 0x80362a94,
		"exi::EXIIntrruptHandler": 0x80362ba4,
		"EXIIntrruptHandler": 0x80362ba4,
		"exi::TCIntrruptHandler": 0x80362c6c,
		"TCIntrruptHandler": 0x80362c6c,
		"exi::EXTIntrruptHandler": 0x80362e84,
		"EXTIntrruptHandler": 0x80362e84,
		"exi::EXIInit": 0x80362f4c,
		"EXIInit": 0x80362f4c,
		"exi::EXILock": 0x80363060,
		"EXILock": 0x80363060,
		"exi::EXIUnlock": 0x80363154,
		"EXIUnlock": 0x80363154,
		"exi::EXIGetState": 0x80363230,
		"EXIGetState": 0x80363230,
		"exi::UnlockedHandler": 0x80363248,
		"UnlockedHandler": 0x80363248,
		"exi::EXIGetID": 0x80363270,
		"EXIGetID": 0x80363270,
		"exi::InitializeUART": 0x803635ec,
		"InitializeUART": 0x803635ec,
		"exi::ReadUARTN": 0x8036365c,
		"ReadUARTN": 0x8036365c,
		"exi::WriteUARTN": 0x80363664,
		"WriteUARTN": 0x80363664,
		"thp::THPVideoDecode": 0x80363864,
		"THPVideoDecode": 0x80363864,
		"thp::__THPSetupBuffers": 0x80363aa8,
		"__THPSetupBuffers": 0x80363aa8,
		"thp::__THPReadFrameHeader": 0x80363aec,
		"__THPReadFrameHeader": 0x80363aec,
		"thp::__THPReadScaneHeader": 0x80363c28,
		"__THPReadScaneHeader": 0x80363c28,
		"thp::__THPReadQuantizationTable": 0x80363d44,
		"__THPReadQuantizationTable": 0x80363d44,
		"thp::__THPReadHuffmanTableSpecification": 0x80364100,
		"__THPReadHuffmanTableSpecification": 0x80364100,
		"thp::__THPHuffGenerateSizeTable": 0x803642e0,
		"__THPHuffGenerateSizeTable": 0x803642e0,
		"thp::__THPHuffGenerateCodeTable": 0x803643d0,
		"__THPHuffGenerateCodeTable": 0x803643d0,
		"thp::__THPHuffGenerateDecoderTables": 0x80364438,
		"__THPHuffGenerateDecoderTables": 0x80364438,
		"thp::__THPRestartDefinition": 0x803645f4,
		"__THPRestartDefinition": 0x803645f4,
		"thp::__THPPrepBitStream": 0x80364648,
		"__THPPrepBitStream": 0x80364648,
		"thp::__THPDecompressYUV": 0x80364894,
		"__THPDecompressYUV": 0x80364894,
		"thp::__THPDecompressiMCURow512x448": 0x803649a0,
		"__THPDecompressiMCURow512x448": 0x803649a0,
		"thp::__THPDecompressiMCURow640x480": 0x80366428,
		"__THPDecompressiMCURow640x480": 0x80366428,
		"thp::__THPDecompressiMCURowNxN": 0x80367eb4,
		"__THPDecompressiMCURowNxN": 0x80367eb4,
		"thp::__THPHuffDecodeDCTCompY": 0x80369960,
		"__THPHuffDecodeDCTCompY": 0x80369960,
		"thp::__THPHuffDecodeDCTCompU": 0x80369fdc,
		"__THPHuffDecodeDCTCompU": 0x80369fdc,
		"thp::__THPHuffDecodeDCTCompV": 0x8036a684,
		"__THPHuffDecodeDCTCompV": 0x8036a684,
		"thp::THPInit": 0x8036ad2c,
		"THPInit": 0x8036ad2c,
		"thp::THPAudioDecode": 0x8036ada4,
		"THPAudioDecode": 0x8036ada4,
		"thp::__THPAudioGetNewSample": 0x8036b208,
		"__THPAudioGetNewSample": 0x8036b208,
		"thp::__THPAudioInitialize": 0x8036b298,
		"__THPAudioInitialize": 0x8036b298,
		"THPPlayer::PopDecodedAudioBuffer": 0x8001db0c,
		"PopDecodedAudioBuffer": 0x8001db0c,
		"THPPlayer::PushFreeAudioBuffer": 0x8001db50,
		"PushFreeAudioBuffer": 0x8001db50,
		"THPPlayer::AudioDecode": 0x8001db80,
		"AudioDecode": 0x8001db80,
		"THPPlayer::AudioDecoderForOnMemory": 0x8001dc7c,
		"AudioDecoderForOnMemory": 0x8001dc7c,
		"THPPlayer::AudioDecoder": 0x8001dd2c,
		"AudioDecoder": 0x8001dd2c,
		"THPPlayer::AudioDecodeThreadCancel": 0x8001dd54,
		"AudioDecodeThreadCancel": 0x8001dd54,
		"THPPlayer::AudioDecodeThreadStart": 0x8001dd90,
		"AudioDecodeThreadStart": 0x8001dd90,
		"THPPlayer::CreateAudioDecodeThread": 0x8001ddc4,
		"CreateAudioDecodeThread": 0x8001ddc4,
		"THPPlayer::THPGXYuv2RgbDraw": 0x8001de84,
		"THPGXYuv2RgbDraw": 0x8001de84,
		"THPPlayer::THPGXYuv2RgbSetup": 0x8001e068,
		"THPGXYuv2RgbSetup": 0x8001e068,
		"THPPlayer::THPGXRestore": 0x8001e54c,
		"THPGXRestore": 0x8001e54c,
		"THPPlayer::THPPlayerSetVolume": 0x8001e664,
		"THPPlayerSetVolume": 0x8001e664,
		"THPPlayer::MixAudio": 0x8001e7a0,
		"MixAudio": 0x8001e7a0,
		"THPPlayer::THPPlayerDrawDone": 0x8001e9d8,
		"THPPlayerDrawDone": 0x8001e9d8,
		"THPPlayer::THPPlayerGetState": 0x8001ea4c,
		"THPPlayerGetState": 0x8001ea4c,
		"THPPlayer::THPPlayerGetAudioInfo": 0x8001ea5c,
		"THPPlayerGetAudioInfo": 0x8001ea5c,
		"THPPlayer::THPPlayerGetVideoInfo": 0x8001eaa4,
		"THPPlayerGetVideoInfo": 0x8001eaa4,
		"THPPlayer::THPPlayerDrawCurrentFrame": 0x8001eaec,
		"THPPlayerDrawCurrentFrame": 0x8001eaec,
		"THPPlayer::ProperTimingForGettingNextFrame": 0x8001ebb8,
		"ProperTimingForGettingNextFrame": 0x8001ebb8,
		"THPPlayer::PlayControl": 0x8001ecdc,
		"PlayControl": 0x8001ecdc,
		"THPPlayer::THPPlayerPause": 0x8001efa0,
		"THPPlayerPause": 0x8001efa0,
		"THPPlayer::THPPlayerStop": 0x8001efe0,
		"THPPlayerStop": 0x8001efe0,
		"THPPlayer::THPPlayerPlay": 0x8001f0b8,
		"THPPlayerPlay": 0x8001f0b8,
		"THPPlayer::THPPlayerPrepare": 0x8001f114,
		"THPPlayerPrepare": 0x8001f114,
		"THPPlayer::PrepareReady": 0x8001f384,
		"PrepareReady": 0x8001f384,
		"THPPlayer::InitAllMessageQueue": 0x8001f3b4,
		"InitAllMessageQueue": 0x8001f3b4,
		"THPPlayer::THPPlayerSetBuffer": 0x8001f484,
		"THPPlayerSetBuffer": 0x8001f484,
		"THPPlayer::THPPlayerCalcNeedMemory": 0x8001f6b4,
		"THPPlayerCalcNeedMemory": 0x8001f6b4,
		"THPPlayer::THPPlayerClose": 0x8001f75c,
		"THPPlayerClose": 0x8001f75c,
		"THPPlayer::THPPlayerOpen": 0x8001f7b4,
		"THPPlayerOpen": 0x8001f7b4,
		"THPPlayer::THPPlayerQuit": 0x8001fa44,
		"THPPlayerQuit": 0x8001fa44,
		"THPPlayer::THPPlayerInit": 0x8001fa78,
		"THPPlayerInit": 0x8001fa78,
		"THPPlayer::audioCallbackWithMSound": 0x8001fb40,
		"audioCallbackWithMSound": 0x8001fb40,
		"THPPlayer::PushReadedBuffer2": 0x8001fbf4,
		"PushReadedBuffer2": 0x8001fbf4,
		"THPPlayer::PopReadedBuffer2": 0x8001fc24,
		"PopReadedBuffer2": 0x8001fc24,
		"THPPlayer::PushFreeReadBuffer": 0x8001fc58,
		"PushFreeReadBuffer": 0x8001fc58,
		"THPPlayer::PopReadedBuffer": 0x8001fc88,
		"PopReadedBuffer": 0x8001fc88,
		"THPPlayer::Reader": 0x8001fcbc,
		"Reader": 0x8001fcbc,
		"THPPlayer::ReadThreadCancel": 0x8001fdac,
		"ReadThreadCancel": 0x8001fdac,
		"THPPlayer::ReadThreadStart": 0x8001fde8,
		"ReadThreadStart": 0x8001fde8,
		"THPPlayer::CreateReadThread": 0x8001fe1c,
		"CreateReadThread": 0x8001fe1c,
		"THPPlayer::PopDecodedTextureSet": 0x8001feb8,
		"PopDecodedTextureSet": 0x8001feb8,
		"THPPlayer::PushFreeTextureSet": 0x8001fefc,
		"PushFreeTextureSet": 0x8001fefc,
		"THPPlayer::VideoDecode": 0x8001ff2c,
		"VideoDecode": 0x8001ff2c,
		"THPPlayer::VideoDecoderForOnMemory": 0x8002005c,
		"VideoDecoderForOnMemory": 0x8002005c,
		"THPPlayer::VideoDecoder": 0x80020190,
		"VideoDecoder": 0x80020190,
		"THPPlayer::VideoDecodeThreadCancel": 0x8002026c,
		"VideoDecodeThreadCancel": 0x8002026c,
		"THPPlayer::VideoDecodeThreadStart": 0x800202a8,
		"VideoDecodeThreadStart": 0x800202a8,
		"THPPlayer::CreateVideoDecodeThread": 0x800202dc,
		"CreateVideoDecodeThread": 0x800202dc,
		"TDLColorTexQuad::draw": 0x8021ce60,
		"TDLColorTexQuad::setEnd": 0x8021cf00,
		"TDLColorTexQuad::requestCol": 0x8021d098,
		"requestCol": 0x8021d098,
		"TDLColorTexQuad::createBuffer": 0x8021d27c,
		"TDLTexQuad::draw": 0x8021d35c,
		"TDLTexQuad::setEnd": 0x8021d464,
		"TDLTexQuad::request": 0x8021d5c8,
		"TDLTexQuad::createBuffer": 0x8021d764,
		"TDLTexQuad::createDLBuffer": 0x8021d804,
		"createDLBuffer": 0x8021d804,
		"TSilhouette::~TSilhouette": 0x8021d8bc,
		"MarioUtil::SMS_UnifyMaterial": 0x8021d930,
		"SMS_UnifyMaterial": 0x8021d930,
		"MarioUtil::SMS_CalcMatAnmAndMakeDL": 0x8021d9e4,
		"SMS_CalcMatAnmAndMakeDL": 0x8021d9e4,
		"MarioUtil::SMS_ShowJoint": 0x8021da80,
		"SMS_ShowJoint": 0x8021da80,
		"MarioUtil::SMS_DrawInit": 0x8021dad0,
		"SMS_DrawInit": 0x8021dad0,
		"MarioUtil::SMS_MakeDLAndLock": 0x8021dafc,
		"SMS_MakeDLAndLock": 0x8021dafc,
		"MarioUtil::SMS_DrawShape": 0x8021db84,
		"SMS_DrawShape": 0x8021db84,
		"MarioUtil::SMS_SettingDrawShape": 0x8021dbe8,
		"SMS_SettingDrawShape": 0x8021dbe8,
		"MarioUtil::SMS_DrawCube": 0x8021dc54,
		"SMS_DrawCube": 0x8021dc54,
		"MarioUtil::SMS_CountPolygonNumInShape": 0x8021ddd4,
		"SMS_CountPolygonNumInShape": 0x8021ddd4,
		"MarioUtil::ViewFrustumClipCheck": 0x8021deb0,
		"ViewFrustumClipCheck": 0x8021deb0,
		"MarioUtil::SetViewFrustumClipCheckPerspective": 0x8021e020,
		"SetViewFrustumClipCheckPerspective": 0x8021e020,
		"MarioUtil::SetViewFrustumClipCheck": 0x8021e0c8,
		"SetViewFrustumClipCheck": 0x8021e0c8,
		"MarioUtil::SMS_ResetDamageFogEffect": 0x8021e42c,
		"SMS_ResetDamageFogEffect": 0x8021e42c,
		"MarioUtil::SMS_AddDamageFogEffect": 0x8021e4d8,
		"SMS_AddDamageFogEffect": 0x8021e4d8,
		"TTrembleModelEffect::reset": 0x8021e5f8,
		"TTrembleModelEffect::movement": 0x8021e7d8,
		"JGeometry::TVec3<short><short>::sub": 0x8021ec9c,
		"TTrembleModelEffect::clash": 0x8021ecd0,
		"clash": 0x8021ecd0,
		"JGeometry::TVec3<short><short>::add": 0x8021eee8,
		"TTrembleModelEffect::tremble": 0x8021ef1c,
		"tremble": 0x8021ef1c,
		"TTrembleModelEffect::init": 0x8021f2e0,
		"TSilhouette::perform": 0x8021f868,
		"TSilhouette::setting": 0x8021fc60,
		"setting": 0x8021fc60,
		"TSilhouette::loadAfter": 0x8021fdfc,
		"TSilhouette::load": 0x80220038,
		"TLightWithDBSetManager::~TLightWithDBSetManager": 0x80220098,
		"TLightWithDBSetManager::getLightPos": 0x8022010c,
		"getLightPos": 0x8022010c,
		"TLightWithDBSetManager::makeDrawBuffer": 0x80220114,
		"TLightWithDBSetManager::addChildGroupObj": 0x80220188,
		"addChildGroupObj": 0x80220188,
		"JGadget::TList_pointer<PQ26JDrama8TViewObj>::iterator::iterator": 0x802202b8,
		"JGadget::TList_pointer<JDrama::TViewObj*>::end": 0x802202c4,
		"TLightWithDBSetManager::perform": 0x802202e8,
		"TLightWithDBSetManager::loadAfter": 0x802203e4,
		"TLightWithDBSetManager::TLightWithDBSetManager": 0x80220488,
		"TLightWithDBSet::~TLightWithDBSet": 0x8022088c,
		"TIndirectLightWithDBSet::makeDrawBuffer": 0x80220900,
		"TLightDrawBuffer::setLight": 0x80220a94,
		"TMapObjectLightWithDBSet::makeDrawBuffer": 0x80220ac8,
		"TObjectLightWithDBSet::makeDrawBuffer": 0x80220c5c,
		"TPlayerLightWithDBSet::makeDrawBuffer": 0x80220e00,
		"TLightCommon::~TLightCommon": 0x80220fb0,
		"TLightWithDBSet::resetLightDrawBuffer": 0x80221024,
		"resetLightDrawBuffer": 0x80221024,
		"TLightWithDBSet::changeLightDrawBuffer": 0x80221060,
		"changeLightDrawBuffer": 0x80221060,
		"TLightWithDBSet::perform": 0x802210cc,
		"TLightDrawBuffer::perform": 0x80221214,
		"TLightDrawBuffer::TLightDrawBuffer": 0x80221258,
		"TLightMario::getAmbColor": 0x80221384,
		"TLightMario::getLightColor": 0x80221464,
		"TLightMario::setLight": 0x80221564,
		"TLightMario::perform": 0x802217d4,
		"TLightShadow::perform": 0x80221814,
		"TLightCommon::perform": 0x80221850,
		"TLightCommon::setLight": 0x80221984,
		"TLightCommon::getLightPosition": 0x80221bf4,
		"getLightPosition": 0x80221bf4,
		"TLightCommon::getAmbColor": 0x80221c40,
		"TLightCommon::getLightColor": 0x80221ccc,
		"TLightCommon::loadAfter": 0x80221d84,
		"TLightCommon::TLightCommon": 0x80221f10,
		"TIndirectLightWithDBSet::~TIndirectLightWithDBSet": 0x80221fdc,
		"TMapObjectLightWithDBSet::~TMapObjectLightWithDBSet": 0x80222060,
		"TObjectLightWithDBSet::~TObjectLightWithDBSet": 0x802220e4,
		"TPlayerLightWithDBSet::~TPlayerLightWithDBSet": 0x80222168,
		"TLightDrawBuffer::~TLightDrawBuffer": 0x802221ec,
		"TLightMario::~TLightMario": 0x80222260,
		"TLightShadow::~TLightShadow": 0x802222e4,
		"MarioUtil::MsVECMag2": 0x80222368,
		"MsVECMag2": 0x80222368,
		"MarioUtil::MsVECNormalize": 0x80222390,
		"MsVECNormalize": 0x80222390,
		"MarioUtil::SMSCalcJumpVelocityXZ": 0x802223bc,
		"SMSCalcJumpVelocityXZ": 0x802223bc,
		"MarioUtil::SMSCalcJumpVelocityY": 0x802224b8,
		"SMSCalcJumpVelocityY": 0x802224b8,
		"MarioUtil::SMS_GoRotate": 0x80222560,
		"SMS_GoRotate": 0x80222560,
		"MarioUtil::MsIsInSight": 0x80222648,
		"MsIsInSight": 0x80222648,
		"MarioUtil::MsWrap": 0x802227e8,
		"MarioUtil::MsMtxSetTRS": 0x8022283c,
		"MsMtxSetTRS": 0x8022283c,
		"MarioUtil::MsMtxSetXYZRPH": 0x80222980,
		"MsMtxSetXYZRPH": 0x80222980,
		"MarioUtil::MsMtxSetRotRPH": 0x80222a30,
		"MsMtxSetRotRPH": 0x80222a30,
		"MarioUtil::MsGetRotFromZaxis": 0x80222b28,
		"MsGetRotFromZaxis": 0x80222b28,
		"MarioUtil::matan": 0x80222d5c,
		"matan": 0x80222d5c,
		"MarioUtil::FConverge": 0x80223000,
		"FConverge": 0x80223000,
		"MarioUtil::IConverge": 0x80223030,
		"IConverge": 0x80223030,
		"MarioUtil::SMS_GetActorMtx": 0x80223060,
		"SMS_GetActorMtx": 0x80223060,
		"TRope::moveHead": 0x802230b0,
		"TRope::constraintTail": 0x8022323c,
		"constraintTail": 0x8022323c,
		"TRope::constraintHead": 0x80223468,
		"constraintHead": 0x80223468,
		"TRope::collision": 0x8022360c,
		"collision": 0x8022360c,
		"TRope::TRope": 0x80223774,
		"TRopePoint::TRopePoint": 0x802239c4,
		"MarioUtil::SMS_GetLightPerspectiveForEffectMtx": 0x802239c8,
		"SMS_GetLightPerspectiveForEffectMtx": 0x802239c8,
		"MarioUtil::SMS_MakeJointsToArc": 0x80223a34,
		"SMS_MakeJointsToArc": 0x80223a34,
		"TMultiMtxEffect::setUserArea": 0x80223edc,
		"setUserArea": 0x80223edc,
		"TMultiMtxEffect::setup": 0x80223f2c,
		"JGeometry::TVec3<float><float>::__ct": 0x80224444,
		"__ct": 0x80224444,
		"TParamT<JGeometry::TVec3<float><float>>::TParamT": 0x80224454,
		"MarioUtil::TMtxSwingRZReverseXZCallBack": 0x802244cc,
		"TMtxSwingRZReverseXZCallBack": 0x802244cc,
		"MarioUtil::TMtxSwingRZCallBack": 0x80224578,
		"TMtxSwingRZCallBack": 0x80224578,
		"TMtxSwingRZ::calcLocalXY": 0x8022460c,
		"calcLocalXY": 0x8022460c,
		"MarioUtil::TMtxTimeLagCallBack": 0x8022486c,
		"TMtxTimeLagCallBack": 0x8022486c,
		"TMtxTimeLag::calc": 0x802248a4,
		"MarioUtil::MtxToQuat": 0x80224e38,
		"MtxToQuat": 0x80224e38,
		"TMtxSwingRZ::getParams": 0x80225068,
		"TMtxTimeLag::getParams": 0x80225070,
		"TMtxEffectBase::getParams": 0x80225078,
		"TScreenTexture::~TScreenTexture": 0x80225080,
		"TScreenTexture::perform": 0x802250f4,
		"MarioUtil::SMS_FillScreenAlpha": 0x802250f8,
		"SMS_FillScreenAlpha": 0x802250f8,
		"TScreenTexture::replace": 0x802252b4,
		"replace": 0x802252b4,
		"TScreenTexture::load": 0x802253c8,
		"TAfterEffect::perform": 0x8022544c,
		"TAfterEffect::calcDashBlurValue": 0x80225bec,
		"calcDashBlurValue": 0x80225bec,
		"TAfterEffect::loadAfter": 0x80225cc8,
		"TAfterEffect::load": 0x80225d40,
		"TAfterEffect::~TAfterEffect": 0x80225e2c,
		"TMBindShadowManager::~TMBindShadowManager": 0x80225ea0,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::erase": 0x80225fac,
		"JGadget::TList<P16TMBindShadowBody,Q27JGadget31TAllocator<P16TMBindShadowBody>>::iterator::iterator": 0x80226018,
		"TMBindShadowManager::calcVtx": 0x80226020,
		"calcVtx": 0x80226020,
		"TMBindShadowManager::forceRequest": 0x80226b10,
		"forceRequest": 0x80226b10,
		"TMBindShadowManager::request": 0x80226c40,
		"TMBindShadowManager::drawShadow": 0x80226f68,
		"drawShadow": 0x80226f68,
		"TMBindShadowManager::drawShadowGD": 0x80227994,
		"drawShadowGD": 0x80227994,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::~TSetup5$2216ShadowUtil_cpp": 0x802282d8,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::~TSetup4$2207ShadowUtil_cpp": 0x8022833c,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::~TSetup3$2195ShadowUtil_cpp": 0x802283a0,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::~TSetup2$2190ShadowUtil_cpp": 0x80228404,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::~TCylinder$2171ShadowUtil_cpp": 0x80228468,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::~TSetup1$2172ShadowUtil_cpp": 0x802284cc,
		"TMBindShadowManager::drawShadowVolume": 0x80228530,
		"drawShadowVolume": 0x80228530,
		"MarioUtil::conectCubeSame": 0x80228dbc,
		"conectCubeSame": 0x80228dbc,
		"MarioUtil::conectCubeDiffer": 0x80228f00,
		"conectCubeDiffer": 0x80228f00,
		"TMBindShadowManager::perform": 0x8022905c,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::insert": 0x80229124,
		"TMBindShadowManager::load": 0x802291dc,
		"TMBindShadowManager::TMBindShadowManager": 0x80229338,
		"TAlphaShadowBlendQuad::TAlphaShadowBlendQuad": 0x80229570,
		"TAlphaShadowQuadAry::TAlphaShadowQuadAry": 0x802295a0,
		"TAlphaShadowQuad::TAlphaShadowQuad": 0x802295b8,
		"TCircleShadowRequest::TCircleShadowRequest": 0x802295d4,
		"TModelShadowInfo::TModelShadowInfo": 0x8022961c,
		"TSquareShadowInfo::TSquareShadowInfo": 0x80229648,
		"TMBindShadowBody::entryDrawShadow": 0x80229674,
		"entryDrawShadow": 0x80229674,
		"TMBindShadowBody::TMBindShadowBody": 0x8022994c,
		"TMBindShadowParts::calc": 0x80229d24,
		"TMBindShadowParts::TMBindShadowParts": 0x80229f9c,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::makeDL": 0x8022a288,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::makeDL": 0x8022a2e8,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::makeDL": 0x8022a348,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::makeDL": 0x8022a39c,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::makeDL": 0x8022a3fc,
		"MarioUtil::GDOverflowCheck": 0x8022af40,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::makeDL": 0x8022af78,
		"MarioUtil::ReInitTevStages": 0x8022b0c8,
		"ReInitTevStages": 0x8022b0c8,
		"MarioUtil::ReInitTransform": 0x8022b334,
		"ReInitTransform": 0x8022b334,
		"MarioUtil::ReInitGeometry": 0x8022b5a0,
		"ReInitGeometry": 0x8022b5a0,
		"MarioUtil::ReInitializeGX": 0x8022b6b4,
		"ReInitializeGX": 0x8022b6b4,
		"MarioUtil::SMS_EmitSinkInPollutionEffect": 0x8022b908,
		"SMS_EmitSinkInPollutionEffect": 0x8022b908,
		"MarioUtil::SMS_EmitRippleSea": 0x8022baf0,
		"SMS_EmitRippleSea": 0x8022baf0,
		"MarioUtil::SMS_EmitRipplePool": 0x8022bba0,
		"SMS_EmitRipplePool": 0x8022bba0,
		"MarioUtil::SMS_EmitRippleTiny": 0x8022bc50,
		"SMS_EmitRippleTiny": 0x8022bc50,
		"MarioUtil::SMS_CreateMinimumSDLModel": 0x8022bcd0,
		"SMS_CreateMinimumSDLModel": 0x8022bcd0,
		"MarioUtil::SMS_CreatePartsModel": 0x8022bd54,
		"SMS_CreatePartsModel": 0x8022bd54,
		"MarioUtil::SMS_RideMoveCalcLocalPos": 0x8022bdc4,
		"SMS_RideMoveCalcLocalPos": 0x8022bdc4,
		"MarioUtil::SMS_RideMoveByGroundActor": 0x8022be64,
		"SMS_RideMoveByGroundActor": 0x8022be64,
		"TMultiBtk::update": 0x8022bff8,
		"TMultiBtk::setNthData": 0x8022c084,
		"setNthData": 0x8022c084,
		"TMultiBtk::TMultiBtk": 0x8022c180,
		"RumbleMgr::finishPause": 0x8022c204,
		"finishPause": 0x8022c204,
		"RumbleMgr::startPause": 0x8022c218,
		"startPause": 0x8022c218,
		"RumbleMgr::setActive": 0x8022c28c,
		"setActive": 0x8022c28c,
		"RumbleMgr::update": 0x8022c340,
		"RumbleMgr::reset": 0x8022c914,
		"RumbleMgr::init": 0x8022cb08,
		"RumbleMgr::RumbleMgr": 0x8022cd1c,
		"RumbleControllerMgr::update": 0x8022ce54,
		"RumbleControllerMgr::updateMotorCount": 0x8022cf38,
		"updateMotorCount": 0x8022cf38,
		"RumbleControllerMgr::stop": 0x8022cfb8,
		"RumbleControllerMgr::reset": 0x8022d1a4,
		"RumbleChannelMgr::update": 0x8022d32c,
		"RumbleChannelMgr::RumbleChannelMgr": 0x8022d5dc,
		"RumbleType::getIndex": 0x8022d608,
		"MarioUtil::SMS_ShowAllShapePacket": 0x8022d67c,
		"SMS_ShowAllShapePacket": 0x8022d67c,
		"MarioUtil::SMS_HideAllShapePacket": 0x8022d77c,
		"SMS_HideAllShapePacket": 0x8022d77c,
		"MarioUtil::SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x8022d87c,
		"SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x8022d87c,
		"MarioUtil::SMS_InitPacket_OneTevColorAndOneTevKColor": 0x8022d90c,
		"SMS_InitPacket_OneTevColorAndOneTevKColor": 0x8022d90c,
		"MarioUtil::SMS_InitPacket_OneTevKColorAndFog": 0x8022d9a4,
		"SMS_InitPacket_OneTevKColorAndFog": 0x8022d9a4,
		"MarioUtil::SMS_InitPacket_TwoTevKColor": 0x8022da8c,
		"SMS_InitPacket_TwoTevKColor": 0x8022da8c,
		"MarioUtil::SMS_InitPacket_OneTevKColor": 0x8022db14,
		"SMS_InitPacket_OneTevKColor": 0x8022db14,
		"MarioUtil::SMS_InitPacket_Fog": 0x8022db9c,
		"SMS_InitPacket_Fog": 0x8022db9c,
		"MarioUtil::SMS_InitPacket_ThreeTevColor": 0x8022dc28,
		"SMS_InitPacket_ThreeTevColor": 0x8022dc28,
		"MarioUtil::SMS_InitPacket_TwoTevColor": 0x8022dcc0,
		"SMS_InitPacket_TwoTevColor": 0x8022dcc0,
		"MarioUtil::SMS_InitPacket_OneTevColor": 0x8022dd48,
		"SMS_InitPacket_OneTevColor": 0x8022dd48,
		"MarioUtil::SMS_InitPacket_MatColor": 0x8022ddd0,
		"SMS_InitPacket_MatColor": 0x8022ddd0,
		"MarioUtil::ShapePacketCallBackFunc": 0x8022de58,
		"ShapePacketCallBackFunc": 0x8022de58,
		"MarioUtil::FifoSetFog": 0x8022e5e8,
		"FifoSetFog": 0x8022e5e8,
		"MarioUtil::FifoSetFogRangeAdj": 0x8022e740,
		"FifoSetFogRangeAdj": 0x8022e740,
		"TGDLStatic::make": 0x8022e878,
		"make": 0x8022e878,
		"TGDLStatic::alloc": 0x8022ea08,
		"TGDLStatic::~TGDLStatic": 0x8022eab4,
		"TGDLStatic::TGDLSentinel::~TGDLSentinel": 0x8022eb08,
		"MarioUtil::TGDLStaticOverFlow": 0x8022eb80,
		"TGDLStaticOverFlow": 0x8022eb80,
		"MarioUtil::SMS_ChangeTextureAll": 0x8022eb90,
		"SMS_ChangeTextureAll": 0x8022eb90,
		"MarioUtil::SMS_GetSandRiseUpRatio": 0x8022ecac,
		"SMS_GetSandRiseUpRatio": 0x8022ecac,
		"MarioUtil::SMS_GetGroundActor": 0x8022ecf8,
		"SMS_GetGroundActor": 0x8022ecf8,
		"MarioUtil::SMS_GetMonteVillageAreaInMario": 0x8022ed2c,
		"SMS_GetMonteVillageAreaInMario": 0x8022ed2c,
		"Koga::ToolData::Attach": 0x8022ef28,
		"Attach": 0x8022ef28,
		"Koga::ToolData::~ToolData": 0x8022ef44,
		"Koga::ToolData::ToolData": 0x8022ef90,
		"M3DUtil::M3UMtxCalcBlendAux": 0x8022f428,
		"M3UMtxCalcBlendAux": 0x8022f428,
		"M3UModel::setMtxCalc": 0x8022f844,
		"setMtxCalc": 0x8022f844,
		"M3UModel::perform": 0x8022f848,
		"M3UModel::entryOut": 0x8022f920,
		"M3UModel::entryIn": 0x8022f970,
		"M3UModel::updateOut": 0x8022f9ec,
		"M3UModel::updateIn": 0x8022fa34,
		"M3UModel::updateInTexPatternAnm": 0x8022fa80,
		"updateInTexPatternAnm": 0x8022fa80,
		"M3UModel::updateInMotion": 0x8022fabc,
		"M3UModel::changeAnmTexPattern": 0x8022fbe0,
		"changeAnmTexPattern": 0x8022fbe0,
		"M3UModel::changeMtxCalcAnmTransform": 0x8022fc24,
		"changeMtxCalcAnmTransform": 0x8022fc24,
		"M3UModelCommon::getMtxCalc": 0x8022fc68,
		"MActor::updateMatAnm": 0x8022fcc4,
		"updateMatAnm": 0x8022fcc4,
		"MActor::entryOut": 0x8022fd58,
		"MActorAnmBase::updateOut": 0x8022fdd4,
		"MActor::entryIn": 0x8022fdd8,
		"MActorAnmBase::updateIn": 0x8022fe54,
		"MActor::setBrkFromIndex": 0x8022fe58,
		"setBrkFromIndex": 0x8022fe58,
		"MActorAnmMatEach<J3DAnmTevRegKey>::setAnmFromIndex": 0x8022fea8,
		"MActor::setBrk": 0x8022ff70,
		"setBrk": 0x8022ff70,
		"MActorAnmEach<J3DAnmTevRegKey>::setAnm": 0x8022ffc0,
		"MActor::setBlk": 0x802300ec,
		"setBlk": 0x802300ec,
		"MActorAnmEach<J3DAnmClusterKey>::setAnm": 0x8023013c,
		"MActor::setBtkFromIndex": 0x80230268,
		"setBtkFromIndex": 0x80230268,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::setAnmFromIndex": 0x802302b8,
		"MActor::setBtk": 0x80230380,
		"setBtk": 0x80230380,
		"MActorAnmEach<J3DAnmTextureSRTKey>::setAnm": 0x802303d0,
		"MActor::setBtpFromIndex": 0x802304fc,
		"setBtpFromIndex": 0x802304fc,
		"MActorAnmMatEach<J3DAnmTexPattern>::setAnmFromIndex": 0x8023055c,
		"MActor::setBtp": 0x80230624,
		"setBtp": 0x80230624,
		"MActorAnmEach<J3DAnmTexPattern>::setAnm": 0x80230674,
		"MActor::setBpkFromIndex": 0x802307a0,
		"setBpkFromIndex": 0x802307a0,
		"MActorAnmMatEach<J3DAnmColorKey>::setAnmFromIndex": 0x802307f0,
		"MActor::setBpk": 0x802308b8,
		"setBpk": 0x802308b8,
		"MActorAnmEach<J3DAnmColorKey>::setAnm": 0x80230908,
		"MActorAnmEach<J3DAnmTransformKey>::setAnm": 0x80230a34,
		"MActor::checkCurBckFromIndex": 0x80230b60,
		"checkCurBckFromIndex": 0x80230b60,
		"MActor::setBckFromIndex": 0x80230b90,
		"setBckFromIndex": 0x80230b90,
		"MActor::setBck": 0x80230bcc,
		"setBck": 0x80230bcc,
		"MActor::setFrameRate": 0x80230c08,
		"setFrameRate": 0x80230c08,
		"MActor::getCurAnmIdx": 0x80230c24,
		"getCurAnmIdx": 0x80230c24,
		"MActor::checkBckPass": 0x80230c48,
		"checkBckPass": 0x80230c48,
		"MActor::getFrameCtrl": 0x80230c94,
		"MActor::checkAnmFileExist": 0x80230cb8,
		"checkAnmFileExist": 0x80230cb8,
		"MActor::checkCurAnmFromIndex": 0x80230dd8,
		"checkCurAnmFromIndex": 0x80230dd8,
		"MActor::checkCurAnm": 0x80230e10,
		"checkCurAnm": 0x80230e10,
		"MActor::perform": 0x80230f48,
		"MActor::matAnmFrameUpdate": 0x80231120,
		"matAnmFrameUpdate": 0x80231120,
		"MActor::frameUpdate": 0x80231194,
		"frameUpdate": 0x80231194,
		"MActor::entry": 0x80231254,
		"MActor::setLightType": 0x802313a0,
		"setLightType": 0x802313a0,
		"MActor::setLightData": 0x802313c0,
		"setLightData": 0x802313c0,
		"MActor::setLightID": 0x802314ac,
		"setLightID": 0x802314ac,
		"MActor::viewCalc": 0x802314c0,
		"MActor::calc": 0x802314fc,
		"MActor::calcAnm": 0x80231604,
		"calcAnm": 0x80231604,
		"MActor::updateOutSubBck": 0x80231798,
		"updateOutSubBck": 0x80231798,
		"MActor::updateInSubBck": 0x80231824,
		"updateInSubBck": 0x80231824,
		"MActor::setJointCallback": 0x802318b0,
		"setJointCallback": 0x802318b0,
		"MActor::offMakeDL": 0x802318cc,
		"offMakeDL": 0x802318cc,
		"MActor::unlockDLIfNeed": 0x80231914,
		"unlockDLIfNeed": 0x80231914,
		"MActor::resetDL": 0x80231984,
		"resetDL": 0x80231984,
		"MActor::initDL": 0x80231ac8,
		"initDL": 0x80231ac8,
		"MActor::setAnimation": 0x80231bf0,
		"MActor::curAnmEndsNext": 0x80231c68,
		"curAnmEndsNext": 0x80231c68,
		"MActor::isCurAnmAlreadyEnd": 0x80231dd4,
		"isCurAnmAlreadyEnd": 0x80231dd4,
		"MActor::setModel": 0x80231e9c,
		"MActorAnmBase::setModel": 0x8023218c,
		"MActor::MActor": 0x80232194,
		"MActorAnmBase::MActorAnmBase": 0x8023268c,
		"MActorAnmBlk::verifySuffix": 0x802326f0,
		"MActorAnmBlk::setAnmFromIndex": 0x80232718,
		"MActorAnmBlk::updateOut": 0x80232798,
		"MActorAnmBlk::updateIn": 0x802327c0,
		"MActorAnmBrk::checkUseMaterialID": 0x8023283c,
		"MActorAnmBrk::checkUseMaterialIDInit": 0x8023287c,
		"MActorAnmBrk::updateOut": 0x802328bc,
		"MActorAnmBrk::updateIn": 0x802328e8,
		"MActorAnmBrk::setTevKColorAnmKeyPtr": 0x8023293c,
		"setTevKColorAnmKeyPtr": 0x8023293c,
		"J3DTevKColorAnm::~J3DTevKColorAnm": 0x80232a4c,
		"J3DTevKColorAnm::J3DTevKColorAnm": 0x80232a8c,
		"MActorAnmBrk::setTevColorAnmKeyPtr": 0x80232a9c,
		"setTevColorAnmKeyPtr": 0x80232a9c,
		"J3DTevColorAnm::~J3DTevColorAnm": 0x80232bac,
		"J3DTevColorAnm::J3DTevColorAnm": 0x80232bec,
		"MActorAnmBpk::updateOut": 0x80232bfc,
		"MActorAnmBpk::updateIn": 0x80232c28,
		"MActorAnmBpk::setMatColorAnmKeyPtr": 0x80232c74,
		"setMatColorAnmKeyPtr": 0x80232c74,
		"J3DMatColorAnm::~J3DMatColorAnm": 0x80232d84,
		"J3DMatColorAnm::J3DMatColorAnm": 0x80232dc4,
		"MActorAnmBpk::checkUseMaterialID": 0x80232dd4,
		"MActorAnmBpk::checkUseMaterialIDInit": 0x80232e2c,
		"MActorAnmBtk::updateOut": 0x80232f14,
		"MActorAnmBtk::updateIn": 0x80232f40,
		"MActorAnmBtk::setTexMtxAnmKeyPtr": 0x80232f90,
		"setTexMtxAnmKeyPtr": 0x80232f90,
		"J3DTexMtxAnm::~J3DTexMtxAnm": 0x802330b8,
		"J3DTexMtxAnm::J3DTexMtxAnm": 0x802330f8,
		"MActorAnmBtk::checkUseMaterialID": 0x80233108,
		"MActorAnmBtk::checkUseMaterialIDInit": 0x80233178,
		"MActorAnmBtp::updateOut": 0x80233278,
		"MActorAnmBtp::updateIn": 0x802332a4,
		"MActorAnmBtp::checkUseMaterialID": 0x802332f0,
		"MActorAnmBtp::checkUseMaterialIDInit": 0x80233348,
		"MActorAnmBtp::setTexNoAnmFullPtr": 0x8023343c,
		"setTexNoAnmFullPtr": 0x8023343c,
		"MActorAnmBck::setAnmFromIndex": 0x80233550,
		"MActorAnmBck::updateOut": 0x80233660,
		"MActorAnmBck::updateIn": 0x80233684,
		"MActorAnmBck::setModel": 0x80233764,
		"J3DMtxCalcBasicAnm::J3DMtxCalcBasicAnm": 0x80233834,
		"MActorAnmBck::getOldMotionBlendFrame": 0x80233908,
		"MActorAnmBck::setOldMotionBlendAnmPtr": 0x8023393c,
		"MActorAnmBck::getOldMotionBlendAnmPtr": 0x80233968,
		"MActorAnmBck::setMotionBlendRatio": 0x8023399c,
		"MActorAnmBck::getMotionBlendRatio": 0x802339c8,
		"MActorAnmBck::initNormalMotionBlend": 0x802339fc,
		"initNormalMotionBlend": 0x802339fc,
		"MActorAnmBck::initSimpleMotionBlend": 0x80233a7c,
		"initSimpleMotionBlend": 0x80233a7c,
		"MActorAnmBase::checkUseMaterialID": 0x80233b0c,
		"MActorAnmBase::checkUseMaterialIDInit": 0x80233b10,
		"MActorAnmBrk::verifySuffix": 0x80233b14,
		"MActorAnmBpk::verifySuffix": 0x80233b3c,
		"MActorAnmBtk::verifySuffix": 0x80233b64,
		"MActorAnmBtp::verifySuffix": 0x80233b8c,
		"MActorAnmBck::verifySuffix": 0x80233bb4,
		"MActorAnmData::createSampleModelData": 0x80233bdc,
		"createSampleModelData": 0x80233bdc,
		"MActorAnmData::addFileTable": 0x80233c38,
		"addFileTable": 0x80233c38,
		"MActorAnmData::init": 0x802340b4,
		"MActorAnmData::partsNameToIdx": 0x802346d8,
		"partsNameToIdx": 0x802346d8,
		"M3DUtil::MActorCalcKeyCode": 0x80234778,
		"MActorCalcKeyCode": 0x80234778,
		"MActorAnmData::MActorAnmData": 0x802347a8,
		"MActorAnmDataBase::sortByFileNameRaw": 0x8023480c,
		"sortByFileNameRaw": 0x8023480c,
		"MActorAnmDataBase::checkLower": 0x80234a2c,
		"checkLower": 0x80234a2c,
		"MActorAnmDataEach<J3DAnmClusterKey>::loadAnmPtrArray": 0x80234af4,
		"MActorAnmDataEach<J3DAnmTevRegKey>::loadAnmPtrArray": 0x80234be4,
		"MActorAnmDataEach<J3DAnmTextureSRTKey>::loadAnmPtrArray": 0x80234cd4,
		"MActorAnmDataEach<J3DAnmTexPattern>::loadAnmPtrArray": 0x80234dc4,
		"MActorAnmDataEach<J3DAnmColorKey>::loadAnmPtrArray": 0x80234eb4,
		"MActorAnmDataEach<J3DAnmTransformKey>::loadAnmPtrArray": 0x80234fa4,
		"SDLModel::~SDLModel": 0x80235094,
		"SDLModel::viewCalcSimple": 0x802350f8,
		"viewCalcSimple": 0x802350f8,
		"SDLModel::entry": 0x802351d0,
		"JGadget::TList<SDLDrawBufToken*,JGadget::TAllocator<SDLDrawBufToken*>>::insert": 0x80235350,
		"SDLModel::entryModelDataSDL": 0x80235408,
		"entryModelDataSDL": 0x80235408,
		"SDLMatPacket::~SDLMatPacket": 0x80235a90,
		"SDLModel::SDLModel": 0x80235af4,
		"SDLMatPacket::SDLMatPacket": 0x80235b88,
		"SDLModelData::entrySDLModels": 0x80235bc4,
		"entrySDLModels": 0x80235bc4,
		"SDLModelData::SDLModelData": 0x80235dc0,
		"SDLModelData::recursiveEntry": 0x80235e24,
		"SDLModelData::entryNode": 0x80236130,
		"entryNode": 0x80236130,
		"SDLModelData::entrySameMat": 0x802361bc,
		"entrySameMat": 0x802361bc,
		"M3DUtil::SMS_MakeMActor": 0x80236350,
		"SMS_MakeMActor": 0x80236350,
		"M3DUtil::SMS_MakeMActorWithAnmData": 0x802363c8,
		"SMS_MakeMActorWithAnmData": 0x802363c8,
		"M3DUtil::SMS_MakeMActorsWithAnmData": 0x80236464,
		"SMS_MakeMActorsWithAnmData": 0x80236464,
		"M3DUtil::SMS_MakeSDLModelData": 0x80236548,
		"SMS_MakeSDLModelData": 0x80236548,
		"M3DUtil::SMS_MakeMActorFromSDLModelData": 0x802365a8,
		"SMS_MakeMActorFromSDLModelData": 0x802365a8,
		"SampleCtrlShape::SampleCtrlShape": 0x80236648,
		"SampleCtrlMaterial::SampleCtrlMaterial": 0x80236694,
		"SampleCtrlJoint::SampleCtrlJoint": 0x80236b70,
		"SampleCtrlJoint::~SampleCtrlJoint": 0x80236bd4,
		"SampleCtrlMaterial::~SampleCtrlMaterial": 0x80236c20,
		"SampleCtrlShape::~SampleCtrlShape": 0x80236c6c,
		"SampleCtrlModelData::SampleCtrlModelData": 0x80236cb8,
		"SampleCtrlModelData::makeHierarchy": 0x80236e98,
		"SampleCtrlModelData::~SampleCtrlModelData": 0x80236f94,
		"TMotionBlendCtrl::getOldMotionBlendFrame": 0x80236fe0,
		"TMotionBlendCtrl::setOldMotionBlendAnmPtr": 0x80236fec,
		"TMotionBlendCtrl::getOldMotionBlendAnmPtr": 0x80236ff8,
		"TMotionBlendCtrl::setNewAnm": 0x80237004,
		"setNewAnm": 0x80237004,
		"TMotionBlendCtrl::keepCurAnm": 0x80237028,
		"keepCurAnm": 0x80237028,
		"TMotionBlendCtrl::setMotionBlendRatio": 0x8023703c,
		"TMotionBlendCtrl::getMotionBlendRatio": 0x80237048,
		"TMotionBlendCtrl::execSimpleMotionBlend": 0x80237054,
		"execSimpleMotionBlend": 0x80237054,
		"TLodAnm::setBckAndBtpAnm": 0x802371cc,
		"setBckAndBtpAnm": 0x802371cc,
		"TLodAnm::setBtpAnm_": 0x80237230,
		"setBtpAnm_": 0x80237230,
		"TLodAnm::setBckAnm_": 0x80237308,
		"setBckAnm_": 0x80237308,
		"TLodAnm::TLodAnm": 0x802373ec,
		"TBaseParam::TBaseParam": 0x8027f3d0,
		"TBaseParam::load": 0x8027f420,
		"TMarioParticleManager::~TMarioParticleManager": 0x8027f424,
		"System::SMSSetEmitterPolColor": 0x8027f498,
		"SMSSetEmitterPolColor": 0x8027f498,
		"TMarioParticleManager::getAvailableIdx": 0x8027f5b4,
		"getAvailableIdx": 0x8027f5b4,
		"TMarioParticleManager::emitTry": 0x8027f6d8,
		"emitTry": 0x8027f6d8,
		"TMarioParticleManager::emitParticleCallBack": 0x8027f890,
		"emitParticleCallBack": 0x8027f890,
		"TMarioParticleManager::emitAndBindToMtx": 0x8027fa20,
		"emitAndBindToMtx": 0x8027fa20,
		"TMarioParticleManager::emitAndBindToSRTMtxPtr": 0x8027fb24,
		"emitAndBindToSRTMtxPtr": 0x8027fb24,
		"TMarioParticleManager::emitAndBindToMtxPtr": 0x8027fd68,
		"emitAndBindToMtxPtr": 0x8027fd68,
		"TMarioParticleManager::emitAndBindToPosPtr": 0x8027ffac,
		"emitAndBindToPosPtr": 0x8027ffac,
		"TMarioParticleManager::emitWithRotate": 0x802801d8,
		"emitWithRotate": 0x802801d8,
		"TMarioParticleManager::emit": 0x802802f8,
		"TMarioParticleManager::perform": 0x8028050c,
		"TMarioParticleManager::createEffectInfoAry": 0x802808b4,
		"createEffectInfoAry": 0x802808b4,
		"TMarioParticleManager::TMarioParticleManager": 0x80280978,
		"TMarioParticleManager::TInfo::TInfo": 0x802809e4,
		"TMarioEmitterCallBackBindToSRTMtxPtr::draw": 0x80280a04,
		"TMarioEmitterCallBackBindToSRTMtxPtr::execute": 0x80280a08,
		"TMarioEmitterCallBackBindToMtxPtr::draw": 0x80280a34,
		"TMarioEmitterCallBackBindToMtxPtr::execute": 0x80280a38,
		"TMarioEmitterCallBackBindToPosPtr::draw": 0x80280a64,
		"TMarioEmitterCallBackBindToPosPtr::execute": 0x80280a68,
		"TEmitterIndirectViewObj::perform": 0x80280a88,
		"TEmitterViewObj::perform": 0x80280b44,
		"TEmitterViewObj::TEmitterViewObj": 0x80280be8,
		"TEmitterIndirectViewObj::~TEmitterIndirectViewObj": 0x80280c60,
		"TEmitterViewObj::~TEmitterViewObj": 0x80280ce4,
		"System::__sinit_EmitterViewObj_cpp": 0x80280d5c,
		"__sinit_EmitterViewObj_cpp": 0x80280d5c,
		"TEventWatcher::perform": 0x80280d88,
		"TEventWatcher::launchScript": 0x80280dc8,
		"launchScript": 0x80280dc8,
		"TSpcTypedBinary<TEventWatcher>::initUserBuiltin": 0x80280f8c,
		"System::evIsWaterMelonIsReached": 0x8028183c,
		"evIsWaterMelonIsReached": 0x8028183c,
		"System::evInvalidatePad": 0x802819ac,
		"evInvalidatePad": 0x802819ac,
		"System::evOnNeutralMarioKey": 0x80281af0,
		"evOnNeutralMarioKey": 0x80281af0,
		"System::evWarpFrontToMario": 0x80281b90,
		"evWarpFrontToMario": 0x80281b90,
		"System::evAppear8RedCoinsAndTimer": 0x80281dc4,
		"evAppear8RedCoinsAndTimer": 0x80281dc4,
		"System::evAppearReadyGo": 0x80281fac,
		"evAppearReadyGo": 0x80281fac,
		"System::evSetEventForWaterMelon": 0x8028204c,
		"evSetEventForWaterMelon": 0x8028204c,
		"System::evStartAppearJetBalloon": 0x80282210,
		"evStartAppearJetBalloon": 0x80282210,
		"System::evWarpMario": 0x8028246c,
		"evWarpMario": 0x8028246c,
		"System::evSetCollision": 0x802827ec,
		"evSetCollision": 0x802827ec,
		"System::evChangeSunglass": 0x80282a60,
		"evChangeSunglass": 0x80282a60,
		"System::evStartMiss": 0x80282c54,
		"evStartMiss": 0x80282c54,
		"System::evStartEventSE": 0x80282cec,
		"evStartEventSE": 0x80282cec,
		"System::evStartSE": 0x80282e74,
		"evStartSE": 0x80282e74,
		"System::evStopBGM": 0x80282fd8,
		"evStopBGM": 0x80282fd8,
		"System::evPutNozzle": 0x80283114,
		"evPutNozzle": 0x80283114,
		"System::evEggYoshiStartFruit": 0x802832e4,
		"evEggYoshiStartFruit": 0x802832e4,
		"System::evStartBGM": 0x802834b4,
		"evStartBGM": 0x802834b4,
		"System::evManiCoinDown": 0x802835ec,
		"evManiCoinDown": 0x802835ec,
		"System::evSetEventID": 0x80283688,
		"evSetEventID": 0x80283688,
		"System::evSetTransScale": 0x802838e0,
		"evSetTransScale": 0x802838e0,
		"System::evIsInsideFastCube": 0x80283f54,
		"evIsInsideFastCube": 0x80283f54,
		"System::evIsFinishMareBottleDemo": 0x80284214,
		"evIsFinishMareBottleDemo": 0x80284214,
		"System::evStartMareBottleDemo": 0x80284308,
		"evStartMareBottleDemo": 0x80284308,
		"System::evSetMarioWaiting": 0x80284418,
		"evSetMarioWaiting": 0x80284418,
		"System::evIsInsideCube": 0x802844c0,
		"evIsInsideCube": 0x802844c0,
		"System::evKillWoodBox": 0x80284644,
		"evKillWoodBox": 0x80284644,
		"System::evRefreshWoodBox": 0x802848e8,
		"evRefreshWoodBox": 0x802848e8,
		"System::evCheckWoodBox": 0x80284b8c,
		"evCheckWoodBox": 0x80284b8c,
		"System::evStartMarioTalking": 0x80284e38,
		"evStartMarioTalking": 0x80284e38,
		"System::evChangeNozzle": 0x80284ed0,
		"evChangeNozzle": 0x80284ed0,
		"System::evAppearShineForWoodBox": 0x8028502c,
		"evAppearShineForWoodBox": 0x8028502c,
		"System::evAppearShineFromKageMario": 0x80285198,
		"evAppearShineFromKageMario": 0x80285198,
		"System::evAppearShineFromNPCWithoutDemo": 0x80285454,
		"evAppearShineFromNPCWithoutDemo": 0x80285454,
		"System::evAppearShine": 0x802856e4,
		"evAppearShine": 0x802856e4,
		"System::evAppearShineFromNPC": 0x8028590c,
		"evAppearShineFromNPC": 0x8028590c,
		"System::evAppearMushroom1up": 0x80285c70,
		"evAppearMushroom1up": 0x80285c70,
		"System::evKillMushroom1up": 0x80285e68,
		"evKillMushroom1up": 0x80285e68,
		"System::evKillShine": 0x80286038,
		"evKillShine": 0x80286038,
		"System::evGetTime": 0x80286208,
		"evGetTime": 0x80286208,
		"System::evMonteManReachFlag": 0x802862a4,
		"evMonteManReachFlag": 0x802862a4,
		"System::evStopTimer": 0x80286390,
		"evStopTimer": 0x80286390,
		"System::evStartMonteman": 0x8028642c,
		"evStartMonteman": 0x8028642c,
		"System::evStartTimer": 0x802865b8,
		"evStartTimer": 0x802865b8,
		"System::evInsertTimer": 0x80286724,
		"evInsertTimer": 0x80286724,
		"System::evForceCloseTalk": 0x80286958,
		"evForceCloseTalk": 0x80286958,
		"System::evRaiseBuilding": 0x802869f0,
		"evRaiseBuilding": 0x802869f0,
		"System::evIsMapEventFinishedAll": 0x80286b80,
		"evIsMapEventFinishedAll": 0x80286b80,
		"System::evStartOpenModelGate": 0x80286d54,
		"evStartOpenModelGate": 0x80286d54,
		"System::evStartEMarioDisappear": 0x80286f18,
		"evStartEMarioDisappear": 0x80286f18,
		"System::evStartEMarioGateDrawing": 0x802870dc,
		"evStartEMarioGateDrawing": 0x802870dc,
		"System::evStartEMarioRunAway": 0x802872a0,
		"evStartEMarioRunAway": 0x802872a0,
		"System::evIsEMarioDownWaitingToTalk": 0x80287464,
		"evIsEMarioDownWaitingToTalk": 0x80287464,
		"System::evIsEMarioReachedToGoal": 0x8028762c,
		"evIsEMarioReachedToGoal": 0x8028762c,
		"System::evLaunchEventClearDemo": 0x802877f4,
		"evLaunchEventClearDemo": 0x802877f4,
		"System::evIsBossDefeated": 0x802878a4,
		"evIsBossDefeated": 0x802878a4,
		"System::evSetGraffitoMultiplied": 0x80287950,
		"evSetGraffitoMultiplied": 0x80287950,
		"System::evIsGraffitoCoverage0": 0x80287afc,
		"evIsGraffitoCoverage0": 0x80287afc,
		"System::evGameOver": 0x80287ba8,
		"evGameOver": 0x80287ba8,
		"System::evRegisterMovie": 0x80287c48,
		"evRegisterMovie": 0x80287c48,
		"System::evSetNextStage": 0x80287d8c,
		"evSetNextStage": 0x80287d8c,
		"System::evGetPollutionLevel": 0x80287f94,
		"evGetPollutionLevel": 0x80287f94,
		"System::evGetRestTime": 0x8028802c,
		"evGetRestTime": 0x8028802c,
		"System::evSetPollutionIncreaseCount": 0x80288108,
		"evSetPollutionIncreaseCount": 0x80288108,
		"System::evSetAttentionTime": 0x802881c0,
		"evSetAttentionTime": 0x802881c0,
		"System::evSetTimeLimit": 0x80288278,
		"evSetTimeLimit": 0x80288278,
		"System::evSetDead4LiveActor": 0x802883cc,
		"evSetDead4LiveActor": 0x802883cc,
		"System::evSetHide4LiveActor": 0x802885f8,
		"evSetHide4LiveActor": 0x802885f8,
		"System::evIsOnLiveActorFlag": 0x80288824,
		"evIsOnLiveActorFlag": 0x80288824,
		"System::evPushNerve4LiveActor": 0x80288a8c,
		"evPushNerve4LiveActor": 0x80288a8c,
		"System::evSetFlagNPCCanTaken": 0x80288ce0,
		"evSetFlagNPCCanTaken": 0x80288ce0,
		"System::evIsTalkModeNow": 0x80288ef4,
		"evIsTalkModeNow": 0x80288ef4,
		"System::evSetValue2TalkVariable": 0x80288fb8,
		"evSetValue2TalkVariable": 0x80288fb8,
		"System::evGetTalkSelectedValue": 0x8028909c,
		"evGetTalkSelectedValue": 0x8028909c,
		"System::evGetTalkMode": 0x80289138,
		"evGetTalkMode": 0x80289138,
		"System::evSetTalkMsgID": 0x802891d0,
		"evSetTalkMsgID": 0x802891d0,
		"System::evGetTalkNPCName": 0x802893d0,
		"evGetTalkNPCName": 0x802893d0,
		"System::evGetTalkNPC": 0x80289510,
		"evGetTalkNPC": 0x80289510,
		"System::evIsNearActors": 0x802895b8,
		"evIsNearActors": 0x802895b8,
		"System::evIsNearSameActors": 0x8028993c,
		"evIsNearSameActors": 0x8028993c,
		"System::evSetFlagNPCDead": 0x80289e44,
		"evSetFlagNPCDead": 0x80289e44,
		"System::evSetFlagNPCDontThrow": 0x8028a0cc,
		"evSetFlagNPCDontThrow": 0x8028a0cc,
		"System::evSetFlagNPCDontTalk": 0x8028a354,
		"evSetFlagNPCDontTalk": 0x8028a354,
		"System::evGetNPCType": 0x8028a5dc,
		"evGetNPCType": 0x8028a5dc,
		"System::evGetNameRefName": 0x8028a7bc,
		"evGetNameRefName": 0x8028a7bc,
		"System::evGetNameRefHandle": 0x8028a924,
		"evGetNameRefHandle": 0x8028a924,
		"System::evSetSystemFlag": 0x8028aa74,
		"evSetSystemFlag": 0x8028aa74,
		"System::evGetSystemFlag": 0x8028ac60,
		"evGetSystemFlag": 0x8028ac60,
		"TSpcTypedInterp<TEventWatcher>::~TSpcTypedInterp": 0x8028ad9c,
		"~TSpcTypedInterp": 0x8028ad9c,
		"TSpcTypedBinary<TEventWatcher>::~TSpcTypedBinary": 0x8028ae00,
		"TSpcTypedInterp<TEventWatcher>::dispatchBuiltin": 0x8028ae64,
		"System::__sinit_EventWatcher_cpp": 0x8028aedc,
		"__sinit_EventWatcher_cpp": 0x8028aedc,
		"TFlagManager::saveOption": 0x8028b1d8,
		"saveOption": 0x8028b1d8,
		"TFlagManager::loadOption": 0x8028b344,
		"loadOption": 0x8028b344,
		"TFlagManager::correctOptFlag": 0x8028b4b8,
		"correctOptFlag": 0x8028b4b8,
		"TFlagManager::resetOpt": 0x8028b5d4,
		"resetOpt": 0x8028b5d4,
		"TFlagManager::saveFail": 0x8028b5e4,
		"saveFail": 0x8028b5e4,
		"TFlagManager::saveSuccess": 0x8028b61c,
		"saveSuccess": 0x8028b61c,
		"TFlagManager::save": 0x8028b674,
		"TFlagManager::correctFlag": 0x8028b808,
		"correctFlag": 0x8028b808,
		"TFlagManager::firstStart": 0x8028b9c0,
		"firstStart": 0x8028b9c0,
		"TFlagManager::restore": 0x8028bc14,
		"restore": 0x8028bc14,
		"TFlagManager::load": 0x8028be68,
		"TFlagManager::setNozzleRight": 0x8028c1b4,
		"setNozzleRight": 0x8028c1b4,
		"TFlagManager::getNozzleRight": 0x8028c254,
		"getNozzleRight": 0x8028c254,
		"TFlagManager::setBlueCoinFlag": 0x8028c2e4,
		"setBlueCoinFlag": 0x8028c2e4,
		"TFlagManager::getBlueCoinFlag": 0x8028c398,
		"getBlueCoinFlag": 0x8028c398,
		"TFlagManager::incGoldCoinFlag": 0x8028c428,
		"incGoldCoinFlag": 0x8028c428,
		"TFlagManager::setShineFlag": 0x8028c4c4,
		"setShineFlag": 0x8028c4c4,
		"TFlagManager::getShineFlag": 0x8028c540,
		"getShineFlag": 0x8028c540,
		"TFlagManager::incMario": 0x8028c584,
		"incMario": 0x8028c584,
		"TFlagManager::decFlag": 0x8028c5e8,
		"decFlag": 0x8028c5e8,
		"TFlagManager::incFlag": 0x8028c60c,
		"incFlag": 0x8028c60c,
		"TFlagManager::setBool": 0x8028c6fc,
		"setBool": 0x8028c6fc,
		"TFlagManager::getBool": 0x8028c83c,
		"getBool": 0x8028c83c,
		"TFlagManager::setFlag": 0x8028c934,
		"setFlag": 0x8028c934,
		"TFlagManager::getFlag": 0x8028cb64,
		"getFlag": 0x8028cb64,
		"TFlagManager::resetStage": 0x8028cd0c,
		"resetStage": 0x8028cd0c,
		"TFlagManager::resetGame": 0x8028ceb8,
		"resetGame": 0x8028ceb8,
		"TFlagManager::resetCard": 0x8028d088,
		"resetCard": 0x8028d088,
		"TFlagManager::start": 0x8028d29c,
		"TGCLogoDir::direct_dolby": 0x8028d33c,
		"direct_dolby": 0x8028d33c,
		"TGCLogoDir::direct_nlogo": 0x8028d4a0,
		"direct_nlogo": 0x8028d4a0,
		"TGCLogoDir::direct": 0x8028d8a4,
		"TGCLogoDir::setup": 0x8028daa8,
		"TGCLogoDir::TGCLogoDir": 0x8028e1c8,
		"TNintendo2D::perform": 0x8028e288,
		"TNintendo2D::~TNintendo2D": 0x8028e458,
		"System::__sinit_GCLogoDir_cpp": 0x8028e4cc,
		"__sinit_GCLogoDir_cpp": 0x8028e4cc,
		"TGXAlphaUpdate::~TGXAlphaUpdate": 0x8028e7d0,
		"TGXAlphaUpdate::perform": 0x8028e844,
		"TReInitGX::perform": 0x8028e898,
		"TSMSDrawInit::perform": 0x8028e8c0,
		"TJ3DSysSetViewMtx::perform": 0x8028e8e8,
		"TJ3DSysFlag::perform": 0x8028e91c,
		"TReInitGX::~TReInitGX": 0x8028e9a0,
		"TSMSDrawInit::~TSMSDrawInit": 0x8028ea14,
		"TJ3DSysSetViewMtx::~TJ3DSysSetViewMtx": 0x8028ea88,
		"TJ3DSysFlag::~TJ3DSysFlag": 0x8028eafc,
		"TMarDirector::registerEventWatcher": 0x8028eb70,
		"registerEventWatcher": 0x8028eb70,
		"TMarDirector::setup": 0x8028ebf8,
		"TMarDirector::setupThreadFunc": 0x8028ec6c,
		"TMarDirector::TMarDirector": 0x8028ec8c,
		"TMarDirector::TDemoInfo::TDemoInfo": 0x8028f008,
		"JGadget::TSingleNodeLinkList::Initialize_": 0x8028f014,
		"Initialize_": 0x8028f014,
		"System::__sinit_MarDirector_cpp": 0x8028f02c,
		"__sinit_MarDirector_cpp": 0x8028f02c,
		"TMarDirector::moveStage": 0x8028f41c,
		"moveStage": 0x8028f41c,
		"TMarDirector::updateGameMode": 0x8028f84c,
		"updateGameMode": 0x8028f84c,
		"TGameSequence::set": 0x802900d4,
		"TMarDirector::nextStateInitialize": 0x802900e8,
		"nextStateInitialize": 0x802900e8,
		"TMarDirector::setMario": 0x80290774,
		"setMario": 0x80290774,
		"TMarDirector::currentStateFinalize": 0x80290a48,
		"currentStateFinalize": 0x80290a48,
		"TMarDirector::changeState": 0x80290d18,
		"System::decideNextScenario": 0x80291484,
		"decideNextScenario": 0x80291484,
		"System::decideNextStage": 0x802915d8,
		"decideNextStage": 0x802915d8,
		"JDrama::TFlagT<unsigned_short><unsigned_short>::set": 0x802916bc,
		"System::__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x802916c4,
		"__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x802916c4,
		"TMarDirector::direct": 0x802916d0,
		"System::__sinit_MarDirectorDirect_cpp": 0x80291be0,
		"__sinit_MarDirectorDirect_cpp": 0x80291be0,
		"TMarDirector::fireStreamingMovie": 0x80291edc,
		"fireStreamingMovie": 0x80291edc,
		"TMarDirector::fireEndDemoCamera": 0x802920c4,
		"fireEndDemoCamera": 0x802920c4,
		"TMarDirector::fireStartDemoCamera": 0x802920d4,
		"fireStartDemoCamera": 0x802920d4,
		"TMarDirector::setNextStage": 0x802921b4,
		"setNextStage": 0x802921b4,
		"TMarDirector::movement": 0x80292344,
		"TMarDirector::fireRideYoshi": 0x80292374,
		"fireRideYoshi": 0x80292374,
		"TMarDirector::fireGetStar": 0x802923fc,
		"fireGetStar": 0x802923fc,
		"TMarDirector::fireGetNozzle": 0x802924bc,
		"fireGetNozzle": 0x802924bc,
		"TMarDirector::fireGetBlueCoin": 0x802925cc,
		"fireGetBlueCoin": 0x802925cc,
		"TMarDirector::movement_game": 0x80292664,
		"movement_game": 0x80292664,
		"TMarDirector::findNearestTalkNPC": 0x80292828,
		"findNearestTalkNPC": 0x80292828,
		"TMarDirector::entryNPC": 0x802928e8,
		"entryNPC": 0x802928e8,
		"System::__sinit_MarDirectorEvent_cpp": 0x8029291c,
		"__sinit_MarDirectorEvent_cpp": 0x8029291c,
		"TMarDirector::setupPerformList_console": 0x80292c18,
		"setupPerformList_console": 0x80292c18,
		"TMarDirector::initECDisp": 0x80292d28,
		"initECDisp": 0x80292d28,
		"TMarDirector::initECTMir": 0x802939b8,
		"initECTMir": 0x802939b8,
		"TMarDirector::initECTGft": 0x80293ab0,
		"initECTGft": 0x80293ab0,
		"TMarDirector::preEntry": 0x80294080,
		"preEntry": 0x80294080,
		"TMarDirector::setup2": 0x802945d4,
		"setup2": 0x802945d4,
		"System::__sinit_MarDirectorSetup2_cpp": 0x80294b90,
		"__sinit_MarDirectorSetup2_cpp": 0x80294b90,
		"System::MarErrInit": 0x80294e9c,
		"MarErrInit": 0x80294e9c,
		"System::MarErrException": 0x80294f1c,
		"MarErrException": 0x80294f1c,
		"TMarNameRefGen::getNameRef": 0x80294fb8,
		"TStagePositionInfo::~TStagePositionInfo": 0x80296cd4,
		"std::__copy<TStagePositionInfo,0,0>::copy": 0x80296d38,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::TVector": 0x80296ef0,
		"TScenarioArchiveName::~TScenarioArchiveName": 0x80296f1c,
		"std::__copy<TScenarioArchiveName,0,0>::copy": 0x80296f80,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::TVector": 0x802970a4,
		"TCubeGeneralInfo::TCubeGeneralInfo": 0x802970d0,
		"std::__copy<TCameraMapTool,0,0>::copy": 0x80297178,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::TVector": 0x80297380,
		"TStageEventInfo::~TStageEventInfo": 0x802973ac,
		"std::__copy<TStageEventInfo,0,0>::copy": 0x80297410,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::TVector": 0x802975f0,
		"TCubeManagerMarioIn::~TCubeManagerMarioIn": 0x8029761c,
		"TSunGlass::TSunGlass": 0x802976a0,
		"JGadget::TList_pointer<THitActor*>::TList_pointer": 0x80297750,
		"TList_pointer": 0x80297750,
		"TWaterSplash::TWaterSplash": 0x802977f4,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::searchF": 0x802977f8,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::loadAfter": 0x80297894,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::load": 0x802978f4,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::erase": 0x80297aec,
		"TStagePositionInfo::TStagePositionInfo": 0x80297bd0,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::InsertRaw": 0x80297c14,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::searchF": 0x802980c4,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::loadAfter": 0x80298160,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::load": 0x802981c0,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::perform": 0x802982d0,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::searchF": 0x8029838c,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfterSuper": 0x80298474,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfter": 0x80298494,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadSuper": 0x8029854c,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::load": 0x8029856c,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::searchF": 0x802986b4,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::loadAfter": 0x80298750,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::load": 0x802987b0,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::erase": 0x802989a8,
		"TCameraMapTool::TCameraMapTool": 0x80298a8c,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::InsertRaw": 0x80298b00,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::searchF": 0x80299000,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::loadAfter": 0x8029909c,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::load": 0x802990fc,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::searchF": 0x8029920c,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::loadAfter": 0x802992a8,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::load": 0x80299308,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::erase": 0x802994e0,
		"TScenarioArchiveName::TScenarioArchiveName": 0x802995c4,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::InsertRaw": 0x802995f8,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::~TNameRefAryT": 0x802999e4,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::~TNameRefPtrAryT": 0x80299a68,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::~TNameRefAryT": 0x80299ae0,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::~TNameRefAryT": 0x80299b64,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::~TNameRefAryT": 0x80299be8,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::erase": 0x80299c6c,
		"TCubeManagerFast::~TCubeManagerFast": 0x80299ce8,
		"TCubeManagerArea::~TCubeManagerArea": 0x80299d7c,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::searchF": 0x80299e10,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::loadAfter": 0x80299eac,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::load": 0x80299f0c,
		"TStageEventInfo::TStageEventInfo": 0x8029a16c,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::InsertRaw": 0x8029a1d8,
		"TStageEventInfo::operator_=": 0x8029a4f8,
		"System::__sinit_MarNameRefGen_cpp": 0x8029a54c,
		"__sinit_MarNameRefGen_cpp": 0x8029a54c,
		"TMenuDirector::setFixedStageValue": 0x8029a848,
		"setFixedStageValue": 0x8029a848,
		"TMenuDirector::direct": 0x8029ac80,
		"TMenuDirector::rsetup": 0x8029b578,
		"TMenuDirector::setup": 0x8029be94,
		"TMenuDirector::setupThreadFunc": 0x8029bfc0,
		"TMenuDirector::TMenuDirector": 0x8029c098,
		"System::__sinit_MenuDir_cpp": 0x8029c16c,
		"__sinit_MenuDir_cpp": 0x8029c16c,
		"TParams::finalize": 0x8029c66c,
		"TParams::init": 0x8029c67c,
		"TParamT<JGeometry::TVec3<float><float>>::load": 0x8029c7b4,
		"TParamT<float><float>::load": 0x8029c808,
		"TParamT<long><long>::load": 0x8029c85c,
		"TParamT<short><short>::load": 0x8029c8b0,
		"TParamT<unsigned_char><unsigned_char>::load": 0x8029c904,
		"TPerformList::~TPerformList": 0x8029c958,
		"TPerformList::load": 0x8029cb88,
		"JGadget::TSingleLinkList<TPerformLink,0>::Element_getNode": 0x8029cce8,
		"JGadget::TSingleLinkList<12TPerformLink,0>::iterator::iterator": 0x8029ccec,
		"JGadget::TSingleNodeLinkList::end": 0x8029ccf8,
		"TPerformList::perform": 0x8029cd04,
		"System::SMSSetupMovieRenderingInfo": 0x8029cddc,
		"SMSSetupMovieRenderingInfo": 0x8029cddc,
		"System::SMSSetupGameRenderingInfo": 0x8029cf10,
		"SMSSetupGameRenderingInfo": 0x8029cf10,
		"System::SMSSetupTitleRenderingInfo": 0x8029d070,
		"SMSSetupTitleRenderingInfo": 0x8029d070,
		"System::SMSSetupTitleRenderMode": 0x8029d0ac,
		"SMSSetupTitleRenderMode": 0x8029d0ac,
		"System::SMSSetupGCLogoRenderingInfo": 0x8029d1e0,
		"SMSSetupGCLogoRenderingInfo": 0x8029d1e0,
		"System::SMSGetRederRect_Game": 0x8029d2dc,
		"SMSGetRederRect_Game": 0x8029d2dc,
		"TSnapTimeObj::~TSnapTimeObj": 0x8029d330,
		"TSnapTimeObj::perform": 0x8029d3a4,
		"TTalkCursor::~TTalkCursor": 0x8029d488,
		"TTalkCursor::associateNPC": 0x8029d4fc,
		"associateNPC": 0x8029d4fc,
		"TTalkCursor::perform": 0x8029d588,
		"TTalkCursor::loadAfter": 0x8029d5c8,
		"System::SMS_ResetTexCacheRegion": 0x8029d6b8,
		"SMS_ResetTexCacheRegion": 0x8029d6b8,
		"TAlphaCatch::~TAlphaCatch": 0x8029d6f4,
		"TAlphaCatch::perform": 0x8029d768,
		"TZBufferCatch::perform": 0x8029d7ac,
		"TZBufferCatch::~TZBufferCatch": 0x8029d7e4,
		"TApplication::mountStageArchive": 0x8029d858,
		"mountStageArchive": 0x8029d858,
		"TApplication::drawDVDErr": 0x8029da04,
		"drawDVDErr": 0x8029da04,
		"TApplication::gameLoop": 0x8029de60,
		"gameLoop": 0x8029de60,
		"TTimeRec::crTimeAry": 0x8029e290,
		"crTimeAry": 0x8029e290,
		"TApplication::proc": 0x8029e2a8,
		"TApplication::checkAdditionalMovie": 0x8029e740,
		"checkAdditionalMovie": 0x8029e740,
		"TApplication::finalize": 0x8029e924,
		"TApplication::initialize_nlogoAfter": 0x8029e9dc,
		"initialize_nlogoAfter": 0x8029e9dc,
		"TApplication::initialize_bootAfter": 0x8029ec8c,
		"initialize_bootAfter": 0x8029ec8c,
		"System::SetupThreadFuncLogo": 0x8029ef6c,
		"SetupThreadFuncLogo": 0x8029ef6c,
		"TApplication::setupThreadFuncLogo": 0x8029ef8c,
		"setupThreadFuncLogo": 0x8029ef8c,
		"TApplication::initialize": 0x8029f440,
		"System::SetupThreadFuncBoot": 0x8029f8fc,
		"SetupThreadFuncBoot": 0x8029f8fc,
		"System::SMSSwitch2DArchive": 0x8029f938,
		"SMSSwitch2DArchive": 0x8029f938,
		"System::SMSMountAramArchive": 0x8029fa00,
		"SMSMountAramArchive": 0x8029fa00,
		"System::SMSLoadArchive": 0x8029fab8,
		"SMSLoadArchive": 0x8029fab8,
		"TApplication::TApplication": 0x8029fb8c,
		"System::SMSGetAnmFrameRate": 0x8029fc5c,
		"SMSGetAnmFrameRate": 0x8029fc5c,
		"System::SMSGetVSyncTimesPerSec": 0x8029fc8c,
		"SMSGetVSyncTimesPerSec": 0x8029fc8c,
		"TMarioGamePad::~TMarioGamePad": 0x8029fd58,
		"System::__sinit_Application_cpp": 0x8029fdbc,
		"__sinit_Application_cpp": 0x8029fdbc,
		"TScenarioArchiveName::load": 0x802a00b8,
		"TMarioGamePad::read": 0x802a00fc,
		"TMarioGamePad::onNeutralMarioKey": 0x802a017c,
		"onNeutralMarioKey": 0x802a017c,
		"TMarioGamePad::updateMeaning": 0x802a0188,
		"updateMeaning": 0x802a0188,
		"TMarioGamePad::reset": 0x802a0a24,
		"System::__sinit_MarioGamePad_cpp": 0x802a0a9c,
		"__sinit_MarioGamePad_cpp": 0x802a0a9c,
		"TStageEventInfo::load": 0x802a0aa8,
		"System::SMS_getShineIDofExStage": 0x802a0b40,
		"SMS_getShineIDofExStage": 0x802a0b40,
		"System::SMS_getShineStage": 0x802a0b70,
		"SMS_getShineStage": 0x802a0b70,
		"System::SMS_isOptionMap": 0x802a0b88,
		"SMS_isOptionMap": 0x802a0b88,
		"System::SMS_isDivingMap": 0x802a0ba4,
		"SMS_isDivingMap": 0x802a0ba4,
		"System::SMS_isMultiPlayerMap": 0x802a0bd8,
		"SMS_isMultiPlayerMap": 0x802a0bd8,
		"System::SMS_isExMap": 0x802a0c00,
		"SMS_isExMap": 0x802a0c00,
		"System::SMSGetGCLogoVideoWidth": 0x802a0c48,
		"SMSGetGCLogoVideoWidth": 0x802a0c48,
		"System::SMSGetGCLogoRenderHeight": 0x802a0c50,
		"SMSGetGCLogoRenderHeight": 0x802a0c50,
		"System::SMSGetGCLogoRenderWidth": 0x802a0c58,
		"SMSGetGCLogoRenderWidth": 0x802a0c58,
		"System::SMSGetTitleRenderHeight": 0x802a0c60,
		"SMSGetTitleRenderHeight": 0x802a0c60,
		"System::SMSGetTitleRenderWidth": 0x802a0c68,
		"SMSGetTitleRenderWidth": 0x802a0c68,
		"System::SMSGetGameRenderHeight": 0x802a0c70,
		"SMSGetGameRenderHeight": 0x802a0c70,
		"System::SMSGetGameRenderWidth": 0x802a0c78,
		"SMSGetGameRenderWidth": 0x802a0c78,
		"System::SMSGetTitleVideoWidth": 0x802a0cc0,
		"SMSGetTitleVideoWidth": 0x802a0cc0,
		"System::SMSGetGameVideoWidth": 0x802a0d08,
		"SMSGetGameVideoWidth": 0x802a0d08,
		"TStagePositionInfo::load": 0x802a0d10,
		"TProcessMeter::TProcessMeter": 0x802a0dd8,
		"TTimeRec::drawSyncCallback": 0x802a0e18,
		"TTimeRec::snapGXTime": 0x802a0e68,
		"snapGXTime": 0x802a0e68,
		"TTimeRec::flip": 0x802a0f14,
		"flip": 0x802a0f14,
		"TTimeArray::TTimeArray": 0x802a0fa4,
		"TTimeRec::start": 0x802a0fb0,
		"TTimeArray::append": 0x802a104c,
		"TDrawSyncManager::pushBreakPoint": 0x802a1080,
		"pushBreakPoint": 0x802a1080,
		"TDrawSyncManager::drawSyncCallbackSub": 0x802a10d8,
		"drawSyncCallbackSub": 0x802a10d8,
		"TDrawSyncManager::setCallback": 0x802a119c,
		"setCallback": 0x802a119c,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::DestroyElement_": 0x802a11d0,
		"TDrawSyncManager::threadFunc": 0x802a11e4,
		"threadFunc": 0x802a11e4,
		"TFifo::getLoopIdx": 0x802a135c,
		"getLoopIdx": 0x802a135c,
		"TDrawSyncManager::drawSyncCallback": 0x802a1378,
		"TDrawSyncManager::start": 0x802a13ac,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::insert": 0x802a14e4,
		"TDrawSyncManager::TDrawSyncTokenRange::TDrawSyncTokenRange": 0x802a188c,
		"TTHPRender::~TTHPRender": 0x802a189c,
		"TTHPRender::perform": 0x802a1910,
		"TTHPRender::TTHPRender": 0x802a1980,
		"TMarNameRefGen::getNameRef_BossEnemy": 0x802a19f8,
		"getNameRef_BossEnemy": 0x802a19f8,
		"System::__sinit_MarNameRefGen_BossEnemy_cpp": 0x802a232c,
		"__sinit_MarNameRefGen_BossEnemy_cpp": 0x802a232c,
		"TMarNameRefGen::getNameRef_Enemy": 0x802a2628,
		"getNameRef_Enemy": 0x802a2628,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::TRotation3": 0x802a46f0,
		"TNameKuriLauncherManager::~TNameKuriLauncherManager": 0x802a47c0,
		"THamuKuriLauncherManager::~THamuKuriLauncherManager": 0x802a4834,
		"TMarNameRefGen::getNameRef_Map": 0x802a48a8,
		"getNameRef_Map": 0x802a48a8,
		"TMarNameRefGen::getNameRef_MapObj": 0x802a4be0,
		"getNameRef_MapObj": 0x802a4be0,
		"TTelesaSlot::TTelesaSlot": 0x802a8324,
		"TFence::TFence": 0x802a83bc,
		"TMarNameRefGen::getNameRef_NPC": 0x802a8538,
		"getNameRef_NPC": 0x802a8538,
		"TMareWManager::~TMareWManager": 0x802a9498,
		"TMareMManager::~TMareMManager": 0x802a952c,
		"TCardManager::cmdLoop": 0x802a95c0,
		"cmdLoop": 0x802a95c0,
		"TCardManager::writeOptionBlock_": 0x802a97e8,
		"writeOptionBlock_": 0x802a97e8,
		"TCardManager::writeBlock_": 0x802a9980,
		"writeBlock_": 0x802a9980,
		"TCardManager::readBlock_": 0x802a9ba0,
		"readBlock_": 0x802a9ba0,
		"TCardManager::getBookmarkInfos_": 0x802a9e0c,
		"getBookmarkInfos_": 0x802a9e0c,
		"TCardManager::open_": 0x802a9fe0,
		"open_": 0x802a9fe0,
		"TCardManager::setCardStat_": 0x802aa170,
		"setCardStat_": 0x802aa170,
		"TCardManager::filledInitData_": 0x802aa3b4,
		"filledInitData_": 0x802aa3b4,
		"TCardManager::createFile_": 0x802aa6ec,
		"createFile_": 0x802aa6ec,
		"TCardManager::mount_": 0x802aa824,
		"mount_": 0x802aa824,
		"System::detachCallback": 0x802aaa70,
		"detachCallback": 0x802aaa70,
		"TCardManager::getLastStatus": 0x802aaa80,
		"getLastStatus": 0x802aaa80,
		"TCardManager::writeOptionBlock": 0x802aaad8,
		"writeOptionBlock": 0x802aaad8,
		"TCardManager::getOptionWriteStream": 0x802aab28,
		"getOptionWriteStream": 0x802aab28,
		"TCardManager::getOptionReadStream": 0x802aac2c,
		"getOptionReadStream": 0x802aac2c,
		"TCardManager::readOptionBlock": 0x802aac5c,
		"readOptionBlock": 0x802aac5c,
		"TCardManager::writeBlock": 0x802aacac,
		"writeBlock": 0x802aacac,
		"TCardManager::getWriteStream": 0x802aad0c,
		"getWriteStream": 0x802aad0c,
		"TCardManager::getReadStream": 0x802aad60,
		"getReadStream": 0x802aad60,
		"TCardManager::readBlock": 0x802aad90,
		"readBlock": 0x802aad90,
		"TCardManager::getBookmarkInfos": 0x802aadf0,
		"getBookmarkInfos": 0x802aadf0,
		"TCardManager::createFile": 0x802aae50,
		"createFile": 0x802aae50,
		"TCardManager::format": 0x802aaea0,
		"format": 0x802aaea0,
		"TCardManager::unmount": 0x802aaef0,
		"TCardManager::probe": 0x802aaf6c,
		"probe": 0x802aaf6c,
		"TCardManager::~TCardManager": 0x802aaff0,
		"TCardManager::TCardManager": 0x802ab09c,
		"TCardManager::TCriteria::TCriteria": 0x802ab168,
		"System::cardmain": 0x802ab174,
		"cardmain": 0x802ab174,
		"TCardManager::copyTo": 0x802ab194,
		"copyTo": 0x802ab194,
		"TCardManager::decideUseSector": 0x802ab330,
		"decideUseSector": 0x802ab330,
		"TCardManager::TCriteria::set": 0x802ab3a0,
		"System::CalcCheckSum": 0x802ab404,
		"CalcCheckSum": 0x802ab404,
		"TMarDirector::loadParticleMario": 0x802ab668,
		"loadParticleMario": 0x802ab668,
		"TMarDirector::loadParticle": 0x802ac8cc,
		"loadParticle": 0x802ac8cc,
		"TMarDirector::initLoadParticle": 0x802ad24c,
		"initLoadParticle": 0x802ad24c,
		"TMarDirector::loadResource": 0x802ad3d8,
		"loadResource": 0x802ad3d8,
		"System::__sinit_MarDirectorLoadResource_cpp": 0x802ad7b8,
		"__sinit_MarDirectorLoadResource_cpp": 0x802ad7b8,
		"TMovieDirector::direct": 0x802adab4,
		"TMovieDirector::decideNextMode": 0x802ae35c,
		"decideNextMode": 0x802ae35c,
		"TMovieDirector::rsetup": 0x802ae600,
		"TMovieDirector::setup": 0x802aee78,
		"TMovieDirector::setupThreadFunc": 0x802aefac,
		"TMovieDirector::TMovieDirector": 0x802aefcc,
		"TMovieDirector::getStreamMovieName": 0x802af084,
		"getStreamMovieName": 0x802af084,
		"System::__sinit_MovieDirector_cpp": 0x802af348,
		"__sinit_MovieDirector_cpp": 0x802af348,
		"TMarDirector::createObjects": 0x802af64c,
		"createObjects": 0x802af64c,
		"TMarDirector::setupObjects": 0x802af6c4,
		"setupObjects": 0x802af6c4,
		"TMarDirector::decideMarioPosIdx": 0x802b1778,
		"decideMarioPosIdx": 0x802b1778,
		"System::__sinit_MarDirectorSetupObjects_cpp": 0x802b1a08,
		"__sinit_MarDirectorSetupObjects_cpp": 0x802b1a08,
		"MSStage::setPosPtr": 0x802b1d04,
		"setPosPtr": 0x802b1d04,
		"MSSTageSimpleEnvironment::proc": 0x802b1d08,
		"MSStageCubeSwitch::proc": 0x802b1d44,
		"MSStageCubeFadeMonte::proc": 0x802b1f1c,
		"MSStageCubeFade::proc": 0x802b28e0,
		"MSStageDistFadeMonte::proc": 0x802b2c2c,
		"MSStageDistFade::proc": 0x802b2fd0,
		"MSStageDistFade::MSStageDistFade": 0x802b32a8,
		"MSStage::stageLoop": 0x802b3300,
		"stageLoop": 0x802b3300,
		"MSStage::init": 0x802b332c,
		"MSMainProc::startStageBGM": 0x802b36c8,
		"startStageBGM": 0x802b36c8,
		"MSMainProc::endStageEntranceDemo": 0x802b37ac,
		"endStageEntranceDemo": 0x802b37ac,
		"MSMainProc::entranceDemoLoop": 0x802b384c,
		"entranceDemoLoop": 0x802b384c,
		"MSMainProc::startStageEntranceDemo": 0x802b3850,
		"startStageEntranceDemo": 0x802b3850,
		"MSMainProc::setMSoundEnterStage": 0x802b38f0,
		"setMSoundEnterStage": 0x802b38f0,
		"MSMainProc::setBossNotDamagedFlag": 0x802b42c0,
		"setBossNotDamagedFlag": 0x802b42c0,
		"MSMainProc::setBossLivesFlag2": 0x802b42c8,
		"setBossLivesFlag2": 0x802b42c8,
		"MSMainProc::setBossLivesFlagOnlyFlag": 0x802b4314,
		"setBossLivesFlagOnlyFlag": 0x802b4314,
		"MSMainProc::setBossLivesFlag": 0x802b431c,
		"setBossLivesFlag": 0x802b431c,
		"MSMainProc::fromTalkingCameraDemo": 0x802b4368,
		"fromTalkingCameraDemo": 0x802b4368,
		"MSMainProc::toTalkingCameraDemo": 0x802b4390,
		"toTalkingCameraDemo": 0x802b4390,
		"MSMainProc::fromInnerCameraDemo": 0x802b43fc,
		"fromInnerCameraDemo": 0x802b43fc,
		"MSMainProc::toInnerCameraDemo": 0x802b440c,
		"toInnerCameraDemo": 0x802b440c,
		"MSMainProc::getMonteVillageActorArea": 0x802b441c,
		"getMonteVillageActorArea": 0x802b441c,
		"System::__sinit_MSoundMainSide_cpp": 0x802b453c,
		"__sinit_MSoundMainSide_cpp": 0x802b453c,
		"TTargetArrow::~TTargetArrow": 0x802b4838,
		"TTargetArrow::setPos": 0x802b48ac,
		"setPos": 0x802b48ac,
		"TTargetArrow::perform": 0x802b48dc,
		"TTargetArrow::loadAfter": 0x802b4918,
		"TLiveActor::stopAnmSound": 0x8020f838,
		"stopAnmSound": 0x8020f838,
		"TLiveActor::getBasNameTable": 0x8020f874,
		"TLiveActor::setCurAnmSound": 0x8020f87c,
		"setCurAnmSound": 0x8020f87c,
		"TLiveActor::setAnmSound": 0x8020f970,
		"setAnmSound": 0x8020f970,
		"TLiveActor::updateAnmSound": 0x8020fa14,
		"TLiveActor::initAnmSound": 0x8020fa7c,
		"TLiveActor::getTakingMtx": 0x8020fb8c,
		"TLiveActor::getFocalPoint": 0x8020fbac,
		"TLiveActor::getJointTransByIndex": 0x8020fbc8,
		"getJointTransByIndex": 0x8020fbc8,
		"TLiveActor::hasMapCollision": 0x8020fc50,
		"TLiveActor::getGravityY": 0x8020fc6c,
		"TLiveActor::calcVelocityToJumpToY": 0x8020fc74,
		"calcVelocityToJumpToY": 0x8020fc74,
		"TLiveActor::performOnlyDraw": 0x8020fcc8,
		"performOnlyDraw": 0x8020fcc8,
		"TLiveActor::perform": 0x8020fda4,
		"TLiveActor::drawObject": 0x8020ff1c,
		"TLiveActor::requestShadow": 0x8020ff74,
		"TLiveActor::moveObject": 0x802100e0,
		"TLiveActor::setGroundCollision": 0x80210244,
		"TLiveActor::getShadowType": 0x80210298,
		"TLiveActor::receiveMessage": 0x802102a0,
		"TLiveActor::kill": 0x802102a8,
		"TLiveActor::calcRootMatrix": 0x802102c4,
		"TLiveActor::control": 0x80210368,
		"TLiveActor::bind": 0x80210430,
		"TLiveActor::load": 0x8021068c,
		"TLiveActor::init": 0x80210724,
		"TLiveActor::initLodAnm": 0x80210910,
		"initLodAnm": 0x80210910,
		"TLiveActor::getRootJointMtx": 0x8021099c,
		"TLiveActor::getModel": 0x802109a4,
		"getModel": 0x802109a4,
		"TLiveActor::calcRideMomentum": 0x802109b0,
		"calcRideMomentum": 0x802109b0,
		"Strategic::MsWrap": 0x80210bcc,
		"TLiveActor::belongToGround": 0x80210c14,
		"belongToGround": 0x80210c14,
		"TLiveActor::calcRidePos": 0x80210c94,
		"calcRidePos": 0x80210c94,
		"TLiveActor::TLiveActor": 0x80210dc4,
		"Strategic::__sinit_liveactor_cpp": 0x80210ef4,
		"__sinit_liveactor_cpp": 0x80210ef4,
		"TSpcTypedBinary<TLiveActor>::initUserBuiltin": 0x802111f8,
		"Strategic::linPushNerve": 0x802112ec,
		"linPushNerve": 0x802112ec,
		"Strategic::linSetSRT": 0x802114e4,
		"linSetSRT": 0x802114e4,
		"Strategic::linGetSRT": 0x802118d4,
		"linGetSRT": 0x802118d4,
		"Strategic::linSetAnmRate": 0x8021206c,
		"linSetAnmRate": 0x8021206c,
		"Strategic::linSetBls": 0x802122e0,
		"linSetBls": 0x802122e0,
		"Strategic::linSetBlk": 0x802123f4,
		"linSetBlk": 0x802123f4,
		"Strategic::linSetBtk": 0x8021251c,
		"linSetBtk": 0x8021251c,
		"Strategic::linSetBtp": 0x80212644,
		"linSetBtp": 0x80212644,
		"Strategic::linSetBpk": 0x8021276c,
		"linSetBpk": 0x8021276c,
		"Strategic::linSetBck": 0x80212894,
		"linSetBck": 0x80212894,
		"Strategic::NerveGetByIndex": 0x802129bc,
		"NerveGetByIndex": 0x802129bc,
		"TLiveManager::hasMapCollision": 0x80212d54,
		"TLiveManager::getActorByFlag": 0x80212d9c,
		"getActorByFlag": 0x80212d9c,
		"TLiveManager::perform": 0x80212ddc,
		"TLiveManager::setFlagOutOfCube": 0x80212ed8,
		"TLiveManager::clipActors": 0x80212fa0,
		"TLiveManager::clipActorsAux": 0x80212fc8,
		"clipActorsAux": 0x80212fc8,
		"TLiveManager::manageActor": 0x802130f0,
		"manageActor": 0x802130f0,
		"TLiveManager::load": 0x8021311c,
		"TLiveManager::createSpcBinary": 0x8021315c,
		"createSpcBinary": 0x8021315c,
		"TLiveManager::TLiveManager": 0x802131e0,
		"TObjCheckList::TObjCheckList": 0x8021324c,
		"TObjHitCheck::TObjHitCheck": 0x8021325c,
		"TObjHitCheck::clearHitNum": 0x80213434,
		"clearHitNum": 0x80213434,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::begin": 0x80213848,
		"TObjHitCheck::checkActorsHit": 0x80213854,
		"checkActorsHit": 0x80213854,
		"TObjHitCheck::entryGroup": 0x80213ba0,
		"entryGroup": 0x80213ba0,
		"TObjHitCheck::checkAndEntryGroup": 0x80213d78,
		"checkAndEntryGroup": 0x80213d78,
		"TObjHitCheck::checkWater": 0x80214038,
		"checkWater": 0x80214038,
		"TObjHitCheck::suffererIsInAttackArea": 0x802141f0,
		"suffererIsInAttackArea": 0x802141f0,
		"Strategic::checkDistance": 0x80214244,
		"checkDistance": 0x80214244,
		"TObjManager::searchF": 0x802142b8,
		"TObjManager::getModelDataKeeper": 0x80214348,
		"getModelDataKeeper": 0x80214348,
		"TObjManager::createAnmData": 0x80214394,
		"TObjManager::createModelData": 0x802143f4,
		"TObjManager::createModelDataArrayBase": 0x80214428,
		"createModelDataArrayBase": 0x80214428,
		"TObjManager::createModelDataArray": 0x80214510,
		"TObjManager::perform": 0x80214538,
		"TObjManager::getMActorAnmData": 0x80214624,
		"TObjManager::load": 0x80214670,
		"TObjManager::manageObj": 0x80214718,
		"manageObj": 0x80214718,
		"TObjManager::TObjManager": 0x80214738,
		"TObjChara::getRes": 0x802147c4,
		"TObjChara::~TObjChara": 0x80214804,
		"TObjChara::load": 0x80214878,
		"TMActorKeeper::createMActorFromAllBmd": 0x80214ab0,
		"createMActorFromAllBmd": 0x80214ab0,
		"TMActorKeeper::createMActor": 0x80214bc8,
		"createMActor": 0x80214bc8,
		"TMActorKeeper::createMActorFromNthData": 0x80214e1c,
		"createMActorFromNthData": 0x80214e1c,
		"TMActorKeeper::createMActorFromDefaultBmd": 0x80214f5c,
		"createMActorFromDefaultBmd": 0x80214f5c,
		"TMActorKeeper::getMActor": 0x80215080,
		"TMActorKeeper::createAndRegister": 0x8021517c,
		"createAndRegister": 0x8021517c,
		"TModelDataKeeper::TModelDataKeeper": 0x80215238,
		"TModelDataKeeper::getModelDataNum": 0x80215254,
		"getModelDataNum": 0x80215254,
		"TModelDataKeeper::getDataByName": 0x80215280,
		"getDataByName": 0x80215280,
		"TModelDataKeeper::getNthData": 0x8021539c,
		"getNthData": 0x8021539c,
		"TModelDataKeeper::createAndKeepData": 0x80215414,
		"createAndKeepData": 0x80215414,
		"TModelDataKeeper::loadModelData": 0x802154f8,
		"loadModelData": 0x802154f8,
		"TModelDataNode::registerDataAndJoinNewNode": 0x80215570,
		"registerDataAndJoinNewNode": 0x80215570,
		"TSpcInterp::update": 0x802155d4,
		"TSpcInterp::verifyArgNum": 0x80215af0,
		"verifyArgNum": 0x80215af0,
		"TSpcInterp::dump": 0x80215c10,
		"TSpcInterp::~TSpcInterp": 0x80215ea8,
		"TSpcInterp::TSpcInterp": 0x80215f5c,
		"TSpcStack<unsigned_long><unsigned_long>::~TSpcStack": 0x80216160,
		"TSpcStack<TSpcSlice>::~TSpcStack": 0x802161c0,
		"TSpcSlice::TSpcSlice": 0x80216224,
		"TSpcInterp::dispatchBuiltin": 0x80216234,
		"TSpcInterp::dispatchBuiltinDefault": 0x80216254,
		"dispatchBuiltinDefault": 0x80216254,
		"TSpcInterp::execend": 0x80216448,
		"execend": 0x80216448,
		"TSpcInterp::execint1": 0x80216484,
		"execint1": 0x80216484,
		"TSpcInterp::execint0": 0x802164fc,
		"execint0": 0x802164fc,
		"TSpcInterp::execpop": 0x80216570,
		"execpop": 0x80216570,
		"TSpcInterp::execjmp": 0x802165b4,
		"execjmp": 0x802165b4,
		"TSpcInterp::execjne": 0x8021660c,
		"execjne": 0x8021660c,
		"TSpcInterp::execret0": 0x80216734,
		"execret0": 0x80216734,
		"TSpcInterp::execret": 0x80216910,
		"execret": 0x80216910,
		"TSpcInterp::execmkds": 0x80216a98,
		"execmkds": 0x80216a98,
		"TSpcInterp::execmkfr": 0x80216bac,
		"execmkfr": 0x80216bac,
		"TSpcInterp::execfunc": 0x80216c98,
		"execfunc": 0x80216c98,
		"TSpcInterp::execcall": 0x80216d54,
		"execcall": 0x80216d54,
		"TSpcInterp::execshr": 0x80216f98,
		"execshr": 0x80216f98,
		"TSpcInterp::execshl": 0x80217168,
		"execshl": 0x80217168,
		"TSpcInterp::execbor": 0x80217338,
		"execbor": 0x80217338,
		"TSpcInterp::execband": 0x80217508,
		"execband": 0x80217508,
		"TSpcInterp::execor": 0x802176d8,
		"execor": 0x802176d8,
		"TSpcSlice::getDataInt": 0x802178a4,
		"getDataInt": 0x802178a4,
		"TSpcInterp::execand": 0x802178ec,
		"execand": 0x802178ec,
		"TSpcInterp::execnot": 0x80217ab8,
		"execnot": 0x80217ab8,
		"TSpcInterp::execneg": 0x80217bec,
		"execneg": 0x80217bec,
		"TSpcInterp::execle": 0x80217d04,
		"execle": 0x80217d04,
		"TSpcSlice::getDataFloat": 0x80217ee0,
		"getDataFloat": 0x80217ee0,
		"TSpcInterp::execge": 0x80217f38,
		"execge": 0x80217f38,
		"TSpcInterp::execlt": 0x80218114,
		"execlt": 0x80218114,
		"TSpcInterp::execgt": 0x802182ec,
		"execgt": 0x802182ec,
		"TSpcInterp::execne": 0x802184c4,
		"execne": 0x802184c4,
		"TSpcSlice::operator_!=": 0x8021862c,
		"operator_!=": 0x8021862c,
		"TSpcInterp::execeq": 0x802187c8,
		"execeq": 0x802187c8,
		"TSpcSlice::operator_==": 0x80218930,
		"TSpcInterp::execass": 0x80218acc,
		"execass": 0x80218acc,
		"TSpcInterp::execmod": 0x80218c28,
		"execmod": 0x80218c28,
		"TSpcInterp::execdiv": 0x80218e00,
		"execdiv": 0x80218e00,
		"TSpcInterp::execmul": 0x802190d8,
		"execmul": 0x802190d8,
		"TSpcInterp::execsub": 0x802193b0,
		"execsub": 0x802193b0,
		"TSpcInterp::execadd": 0x80219688,
		"execadd": 0x80219688,
		"TSpcInterp::execdec": 0x80219960,
		"execdec": 0x80219960,
		"TSpcInterp::execinc": 0x80219acc,
		"execinc": 0x80219acc,
		"TSpcInterp::execnop": 0x80219c38,
		"execnop": 0x80219c38,
		"TSpcInterp::execvar": 0x80219c3c,
		"execvar": 0x80219c3c,
		"TSpcInterp::execadr": 0x80219d50,
		"execadr": 0x80219d50,
		"TSpcInterp::fetchU32": 0x80219dd4,
		"fetchU32": 0x80219dd4,
		"TSpcInterp::execstr": 0x80219e28,
		"execstr": 0x80219e28,
		"TSpcBinary::getHeader": 0x80219f20,
		"getHeader": 0x80219f20,
		"TSpcInterp::execflt": 0x80219f28,
		"execflt": 0x80219f28,
		"TSpcInterp::execint": 0x80219ff0,
		"execint": 0x80219ff0,
		"TSpcInterp::fetchS32": 0x8021a074,
		"fetchS32": 0x8021a074,
		"TSpcBinary::bindSystemDataToSymbol": 0x8021a0c8,
		"bindSystemDataToSymbol": 0x8021a0c8,
		"TSpcBinary::searchSymbol": 0x8021a1a4,
		"searchSymbol": 0x8021a1a4,
		"TSpcBinary::initUserBuiltin": 0x8021a25c,
		"TSpcBinary::init": 0x8021a260,
		"TSpcBinary::~TSpcBinary": 0x8021a500,
		"TSpcBinary::TSpcBinary": 0x8021a54c,
		"Strategic::spcTypeof": 0x8021a560,
		"spcTypeof": 0x8021a560,
		"Strategic::spcFloat": 0x8021a6cc,
		"spcFloat": 0x8021a6cc,
		"Strategic::spcInt": 0x8021a8a8,
		"spcInt": 0x8021a8a8,
		"Strategic::spcDump": 0x8021aa68,
		"spcDump": 0x8021aa68,
		"Strategic::spcPrint": 0x8021ab48,
		"spcPrint": 0x8021ab48,
		"Strategic::spcUnlock": 0x8021ad40,
		"spcUnlock": 0x8021ad40,
		"Strategic::spcLock": 0x8021ae24,
		"spcLock": 0x8021ae24,
		"Strategic::spcExit": 0x8021af08,
		"spcExit": 0x8021af08,
		"Strategic::spcYield": 0x8021aff0,
		"spcYield": 0x8021aff0,
		"TStrategy::~TStrategy": 0x8021b0d4,
		"TStrategy::perform": 0x8021b148,
		"TStrategy::searchF": 0x8021b2d0,
		"TStrategy::loadAfter": 0x8021b360,
		"TStrategy::load": 0x8021b3d4,
		"TStrategy::TStrategy": 0x8021b4ec,
		"TIdxGroupObj::loadSuper": 0x8021b5a4,
		"TIdxGroupObj::~TIdxGroupObj": 0x8021b5ec,
		"TQuestionManager::~TQuestionManager": 0x8021b714,
		"TQuestionManager::perform": 0x8021b788,
		"TQuestionManager::draw": 0x8021b898,
		"TQuestionManager::makeDL": 0x8021ba0c,
		"TQuestionManager::request": 0x8021bb34,
		"TQuestionManager::load": 0x8021bbc8,
		"TQuestionRequest::TQuestionRequest": 0x8021bcb8,
		"TSMSSmplChara::~TSMSSmplChara": 0x8021bcbc,
		"TSMSSmplChara::getRes": 0x8021bd3c,
		"TSMSSmplChara::load": 0x8021bd80,
		"THitActor::THitActor": 0x8021bdc8,
		"THitActor::initHitActor": 0x8021bef4,
		"initHitActor": 0x8021bef4,
		"THitActor::perform": 0x8021bfc0,
		"THitActor::calcEntryRadius": 0x8021bfe0,
		"calcEntryRadius": 0x8021bfe0,
		"TBinder::~TBinder": 0x8021c064,
		"TBinder::TBinder": 0x8021c0b0,
		"TSharedParts::perform": 0x8021c0c0,
		"TSharedParts::getConnectedMtx": 0x8021c184,
		"getConnectedMtx": 0x8021c184,
		"TMirrorActor::~TMirrorActor": 0x8021c488,
		"TMirrorActor::TMirrorActor": 0x8021c4fc,
		"TMirrorActor::init": 0x8021c574,
		"TMirrorActor::entryMirrorDrawBufferAlways": 0x8021c770,
		"entryMirrorDrawBufferAlways": 0x8021c770,
		"TMirrorActor::perform": 0x8021c864,
		"TMirrorActor::checkIsInMirror": 0x8021c9a0,
		"checkIsInMirror": 0x8021c9a0,
		"Strategic::__sinit_MirrorActor_cpp": 0x8021cb64,
		"__sinit_MirrorActor_cpp": 0x8021cb64,
		"TMario::actnMain": 0x80237444,
		"actnMain": 0x80237444,
		"TMario::taking": 0x8023769c,
		"taking": 0x8023769c,
		"Player::__sinit_MarioAction_cpp": 0x802377c0,
		"__sinit_MarioAction_cpp": 0x802377c0,
		"TMario::demoMain": 0x80237abc,
		"demoMain": 0x80237abc,
		"TMario::footDowning": 0x80237dfc,
		"footDowning": 0x80237dfc,
		"TMario::electricDamage": 0x80237f44,
		"electricDamage": 0x80237f44,
		"TMario::warpOut": 0x802380c8,
		"warpOut": 0x802380c8,
		"TMario::toroccoStart": 0x80238384,
		"toroccoStart": 0x80238384,
		"TMario::waitingStart": 0x80238448,
		"waitingStart": 0x80238448,
		"TMario::returnStart": 0x80238548,
		"returnStart": 0x80238548,
		"TMario::rollingStart": 0x802386e0,
		"rollingStart": 0x802386e0,
		"TMario::isUnUsualStageStart": 0x802387e4,
		"isUnUsualStageStart": 0x802387e4,
		"TMario::warpIn": 0x802389a8,
		"warpIn": 0x802389a8,
		"TMario::jumpingDemoCommon": 0x80238e74,
		"jumpingDemoCommon": 0x80238e74,
		"TMario::readBillboard": 0x80238efc,
		"readBillboard": 0x80238efc,
		"TMario::winDemo": 0x80239104,
		"winDemo": 0x80239104,
		"Player::__sinit_MarioAutodemo_cpp": 0x802391e8,
		"__sinit_MarioAutodemo_cpp": 0x802391e8,
		"M3UModelMario::updateOut": 0x802394e4,
		"M3UModelMario::updateIn": 0x8023952c,
		"M3UModelMario::updateInMotion": 0x80239560,
		"M3UModelMario::changeMtxCalcSIAnmBQAnmTransform": 0x802396bc,
		"changeMtxCalcSIAnmBQAnmTransform": 0x802396bc,
		"TMarioCap::mtxEffectHide": 0x80239728,
		"mtxEffectHide": 0x80239728,
		"TMarioCap::mtxEffectShow": 0x8023979c,
		"mtxEffectShow": 0x8023979c,
		"TMarioCap::perform": 0x80239810,
		"TMarioCap::createMirrorCap": 0x80239e94,
		"createMirrorCap": 0x80239e94,
		"TMarioCap::TMarioCap": 0x80239f14,
		"TMario::considerTake": 0x8023a3a4,
		"considerTake": 0x8023a3a4,
		"TMario::damageExec": 0x8023a598,
		"JGeometry::TVec3<float><float>::operator*=": 0x8023ab30,
		"operator*=": 0x8023ab30,
		"TMario::calcDamagePos": 0x8023ab74,
		"calcDamagePos": 0x8023ab74,
		"TMario::loserExec": 0x8023ae88,
		"loserExec": 0x8023ae88,
		"TMario::normalizeNozzle": 0x8023afd8,
		"normalizeNozzle": 0x8023afd8,
		"TMario::resetNozzle": 0x8023b040,
		"resetNozzle": 0x8023b040,
		"TMario::trampleExec": 0x8023b044,
		"trampleExec": 0x8023b044,
		"TMario::canTake": 0x8023b2dc,
		"canTake": 0x8023b2dc,
		"TMario::isTakeSituation": 0x8023b328,
		"isTakeSituation": 0x8023b328,
		"TMario::dropObject": 0x8023b528,
		"dropObject": 0x8023b528,
		"TMario::getAttackAngle": 0x8023b57c,
		"getAttackAngle": 0x8023b57c,
		"TMario::decHP": 0x8023b5b4,
		"decHP": 0x8023b5b4,
		"TMario::incHP": 0x8023b6b4,
		"incHP": 0x8023b6b4,
		"TMario::rumbleStart": 0x8023b7cc,
		"rumbleStart": 0x8023b7cc,
		"Player::__sinit_MarioCollision_cpp": 0x8023b800,
		"__sinit_MarioCollision_cpp": 0x8023b800,
		"TMario::addDamageFog": 0x8023bafc,
		"addDamageFog": 0x8023bafc,
		"TMario::addDirty": 0x8023bdf8,
		"addDirty": 0x8023bdf8,
		"TMario::boxDrawPrepare": 0x8023bf18,
		"boxDrawPrepare": 0x8023bf18,
		"TMario::drawLogic": 0x8023c114,
		"drawLogic": 0x8023c114,
		"TMario::drawSpecial": 0x8023c2ac,
		"drawSpecial": 0x8023c2ac,
		"TMario::entryModels": 0x8023c318,
		"entryModels": 0x8023c318,
		"TMario::calcView": 0x8023c44c,
		"calcView": 0x8023c44c,
		"TMario::calcAnim": 0x8023c58c,
		"TMario::addUpper": 0x8023cc00,
		"addUpper": 0x8023cc00,
		"TMario::setUpperDamageRun": 0x8023cdb4,
		"setUpperDamageRun": 0x8023cdb4,
		"TMario::addCallBack": 0x8023ce4c,
		"addCallBack": 0x8023ce4c,
		"TMario::calcBaseMtx": 0x8023d1dc,
		"calcBaseMtx": 0x8023d1dc,
		"TMario::considerWaist": 0x8023dd5c,
		"considerWaist": 0x8023dd5c,
		"TMario::isUpperPumpingStyle": 0x8023e0f4,
		"isUpperPumpingStyle": 0x8023e0f4,
		"TMario::finalDrawInitialize": 0x8023e118,
		"finalDrawInitialize": 0x8023e118,
		"TMario::initMirrorModel": 0x8023e1e8,
		"initMirrorModel": 0x8023e1e8,
		"TMario::initModel": 0x8023e304,
		"TMario::loadAnmTexPattern": 0x8023f294,
		"loadAnmTexPattern": 0x8023f294,
		"TMario::loadBas": 0x8023f2f8,
		"loadBas": 0x8023f2f8,
		"TMario::setReverseAnimation": 0x8023f340,
		"setReverseAnimation": 0x8023f340,
		"TMario::setAnimation": 0x8023f3fc,
		"TMario::changeHand": 0x8023f734,
		"changeHand": 0x8023f734,
		"TMario::isAnimeLoopOrStop": 0x8023fb34,
		"isAnimeLoopOrStop": 0x8023fb34,
		"TMario::isLast1AnimeFrame": 0x8023fb58,
		"isLast1AnimeFrame": 0x8023fb58,
		"TMario::getMotionFrameCtrl": 0x8023fba8,
		"getMotionFrameCtrl": 0x8023fba8,
		"TMario::getCurrentFrame": 0x8023fbb4,
		"getCurrentFrame": 0x8023fbb4,
		"TMario::getTakenMtx": 0x8023fbcc,
		"getTakenMtx": 0x8023fbcc,
		"TMario::getTakingMtx": 0x8023fbdc,
		"TMario::getTrampleCt": 0x8023fbf8,
		"getTrampleCt": 0x8023fbf8,
		"TMario::setPositions": 0x8023fc40,
		"setPositions": 0x8023fc40,
		"TMario::takeOffGlass": 0x8023fce4,
		"takeOffGlass": 0x8023fce4,
		"TMario::wearGlass": 0x8023fd30,
		"wearGlass": 0x8023fd30,
		"TMario::isWearingHelm": 0x8023fd7c,
		"isWearingHelm": 0x8023fd7c,
		"TMario::isWearingCap": 0x8023fdac,
		"isWearingCap": 0x8023fdac,
		"TMario::setDivHelm": 0x8023fddc,
		"setDivHelm": 0x8023fddc,
		"TMario::getWallAngle": 0x8023fe34,
		"getWallAngle": 0x8023fe34,
		"TMario::getPumpFrame": 0x8023fe64,
		"getPumpFrame": 0x8023fe64,
		"TMario::getCenterAnmMtx": 0x8023fe74,
		"getCenterAnmMtx": 0x8023fe74,
		"TMario::getRootAnmMtx": 0x8023fe90,
		"getRootAnmMtx": 0x8023fe90,
		"Player::MarioFootDirLCtrl": 0x8023fea0,
		"MarioFootDirLCtrl": 0x8023fea0,
		"Player::MarioFootPosLCtrl": 0x80240130,
		"MarioFootPosLCtrl": 0x80240130,
		"Player::MarioFootDirRCtrl": 0x80240268,
		"MarioFootDirRCtrl": 0x80240268,
		"Player::MarioFootPosRCtrl": 0x802404f8,
		"MarioFootPosRCtrl": 0x802404f8,
		"Player::MarioWaistCtrl": 0x80240630,
		"MarioWaistCtrl": 0x80240630,
		"Player::MarioHeadCtrl": 0x802408a4,
		"MarioHeadCtrl": 0x802408a4,
		"TMarioAnimeData::isPumpOK": 0x80240ca0,
		"isPumpOK": 0x80240ca0,
		"Player::__sinit_MarioDraw_cpp": 0x80240cbc,
		"__sinit_MarioDraw_cpp": 0x80240cbc,
		"TMario::jumpMain": 0x80240fb8,
		"jumpMain": 0x80240fb8,
		"TMario::diving": 0x80242038,
		"diving": 0x80242038,
		"TMario::hipAttacking": 0x80242434,
		"hipAttacking": 0x80242434,
		"TMario::rocketing": 0x802429f0,
		"rocketing": 0x802429f0,
		"TMario::rocketCheck": 0x80242e28,
		"rocketCheck": 0x80242e28,
		"TMario::boardJumping": 0x80242f2c,
		"boardJumping": 0x80242f2c,
		"TMario::thrownDowning": 0x802430d8,
		"thrownDowning": 0x802430d8,
		"TMario::fireDowning": 0x802432a0,
		"fireDowning": 0x802432a0,
		"TMario::slipFalling": 0x80243508,
		"slipFalling": 0x80243508,
		"TMario::catchStop": 0x802437b0,
		"catchStop": 0x802437b0,
		"TMario::stayWall": 0x802438b0,
		"stayWall": 0x802438b0,
		"TMario::jumpDownCommon": 0x80243b98,
		"jumpDownCommon": 0x80243b98,
		"TMario::jumpCatch": 0x80243c90,
		"jumpCatch": 0x80243c90,
		"TMario::landing": 0x80243f5c,
		"landing": 0x80243f5c,
		"TMario::checkBackTrig": 0x802440d0,
		"checkBackTrig": 0x802440d0,
		"TMario::considerJumpRotate": 0x8024416c,
		"considerJumpRotate": 0x8024416c,
		"TMario::jumpingBasic": 0x802441e0,
		"jumpingBasic": 0x802441e0,
		"TMario::doJumping": 0x80244864,
		"doJumping": 0x80244864,
		"TMario::startJumpWall": 0x80244b3c,
		"startJumpWall": 0x80244b3c,
		"Player::__sinit_MarioJump_cpp": 0x80244c0c,
		"__sinit_MarioJump_cpp": 0x80244c0c,
		"TMario::perform": 0x80245034,
		"TMario::isMario": 0x80245898,
		"isMario": 0x80245898,
		"Player::__sinit_MarioMain_cpp": 0x802458b4,
		"__sinit_MarioMain_cpp": 0x802458b4,
		"TMario::playerControl": 0x80245bc4,
		"TYoshi::onYoshi": 0x80246070,
		"TMario::gunExec": 0x8024608c,
		"gunExec": 0x8024608c,
		"TMario::checkWet": 0x802464d4,
		"checkWet": 0x802464d4,
		"TBGCheckData::isMarioThrough": 0x802466dc,
		"isMarioThrough": 0x802466dc,
		"TMario::thinkYoshiHeadCollision": 0x80246730,
		"thinkYoshiHeadCollision": 0x80246730,
		"TMario::getOffYoshi": 0x802468f8,
		"getOffYoshi": 0x802468f8,
		"TMario::thinkParams": 0x802469d0,
		"thinkParams": 0x802469d0,
		"TMario::thinkSand": 0x80246cd4,
		"thinkSand": 0x80246cd4,
		"TMario::thinkWaterSurface": 0x80246d70,
		"thinkWaterSurface": 0x80246d70,
		"TMario::thinkSituation": 0x802475fc,
		"thinkSituation": 0x802475fc,
		"TMario::calcGroundMtx": 0x80247c70,
		"calcGroundMtx": 0x80247c70,
		"TMario::stateMachine": 0x80247e28,
		"stateMachine": 0x80247e28,
		"TMario::checkPlayerAction": 0x80247f24,
		"checkPlayerAction": 0x80247f24,
		"TMario::checkRideReCalc": 0x80247f90,
		"checkRideReCalc": 0x80247f90,
		"TMario::checkRideMovement": 0x8024803c,
		"checkRideMovement": 0x8024803c,
		"TMario::checkCurrentPlane": 0x8024830c,
		"checkCurrentPlane": 0x8024830c,
		"TMario::getDmgMapCode": 0x80248dc8,
		"getDmgMapCode": 0x80248dc8,
		"TMario::checkGroundPlane": 0x80248e40,
		"checkGroundPlane": 0x80248e40,
		"TMario::makeHistory": 0x80248f64,
		"makeHistory": 0x80248f64,
		"TMario::checkStickRotate": 0x80249090,
		"checkStickRotate": 0x80249090,
		"TMario::checkController": 0x80249220,
		"TMario::checkThrowObject": 0x80249f9c,
		"checkThrowObject": 0x80249f9c,
		"TMario::checkReturn": 0x80249ff0,
		"TMario::checkEnforceJump": 0x8024a110,
		"checkEnforceJump": 0x8024a110,
		"MSound::startForceJumpSound": 0x8024a248,
		"startForceJumpSound": 0x8024a248,
		"TMario::checkSink": 0x8024a328,
		"checkSink": 0x8024a328,
		"TMario::thinkHeight": 0x8024a644,
		"thinkHeight": 0x8024a644,
		"TMario::thinkDirty": 0x8024a790,
		"thinkDirty": 0x8024a790,
		"TMario::dirtyLimitCheck": 0x8024a93c,
		"dirtyLimitCheck": 0x8024a93c,
		"TMario::checkGraffito": 0x8024a968,
		"checkGraffito": 0x8024a968,
		"TMario::checkGraffitoElec": 0x8024afb0,
		"checkGraffitoElec": 0x8024afb0,
		"TMario::checkGraffitoSlip": 0x8024b168,
		"checkGraffitoSlip": 0x8024b168,
		"TMario::checkGraffitoFire": 0x8024b3ec,
		"checkGraffitoFire": 0x8024b3ec,
		"TMario::checkAllMotions": 0x8024b66c,
		"checkAllMotions": 0x8024b66c,
		"TMario::changePlayerDropping": 0x8024b79c,
		"changePlayerDropping": 0x8024b79c,
		"TMario::changePlayerJumping": 0x8024b7f4,
		"changePlayerJumping": 0x8024b7f4,
		"TMario::changePlayerTriJump": 0x8024bae0,
		"changePlayerTriJump": 0x8024bae0,
		"TMario::changePlayerStatus": 0x8024bdc0,
		"changePlayerStatus": 0x8024bdc0,
		"TMario::throwMario": 0x8024bf8c,
		"TMario::setStatusToJumping": 0x8024c12c,
		"setStatusToJumping": 0x8024c12c,
		"TMario::checkPlayerAround": 0x8024cc84,
		"checkPlayerAround": 0x8024cc84,
		"TMario::getSlideStopCatch": 0x8024ccf8,
		"getSlideStopCatch": 0x8024ccf8,
		"TMario::getSlideStopNormal": 0x8024ce78,
		"getSlideStopNormal": 0x8024ce78,
		"TMario::canSlipJump": 0x8024cff0,
		"canSlipJump": 0x8024cff0,
		"TMario::isSlipStart": 0x8024d18c,
		"isSlipStart": 0x8024d18c,
		"TMario::isFrontSlip": 0x8024d2fc,
		"isFrontSlip": 0x8024d2fc,
		"TMario::checkRoofPlane": 0x8024d34c,
		"checkRoofPlane": 0x8024d34c,
		"TMario::checkWallPlane": 0x8024d388,
		"checkWallPlane": 0x8024d388,
		"TMario::setPlayerVelocity": 0x8024d4c0,
		"setPlayerVelocity": 0x8024d4c0,
		"TMario::setNormalAttackArea": 0x8024d520,
		"setNormalAttackArea": 0x8024d520,
		"TMario::canBendBody": 0x8024d564,
		"canBendBody": 0x8024d564,
		"TMario::considerRotateJumpStart": 0x8024d5a4,
		"considerRotateJumpStart": 0x8024d5a4,
		"TMario::addVelocity": 0x8024d630,
		"addVelocity": 0x8024d630,
		"TMario::onYoshi": 0x8024d654,
		"TMario::windMove": 0x8024d69c,
		"windMove": 0x8024d69c,
		"TMario::flowMove": 0x8024d6d0,
		"flowMove": 0x8024d6d0,
		"TMario::warpRequest": 0x8024d728,
		"warpRequest": 0x8024d728,
		"TMario::moveRequest": 0x8024d818,
		"TMario::isForceSlip": 0x8024daa4,
		"isForceSlip": 0x8024daa4,
		"TMario::getRidingMtx": 0x8024db4c,
		"getRidingMtx": 0x8024db4c,
		"TMario::isWallInFront": 0x8024dbc8,
		"isWallInFront": 0x8024dbc8,
		"TMario::isInvincible": 0x8024dc30,
		"isInvincible": 0x8024dc30,
		"TMario::isUnderWater": 0x8024dce4,
		"isUnderWater": 0x8024dce4,
		"TMario::canSquat": 0x8024dd2c,
		"canSquat": 0x8024dd2c,
		"TMario::getJumpSlideControl": 0x8024ddb8,
		"getJumpSlideControl": 0x8024ddb8,
		"TMario::getJumpAccelControl": 0x8024de54,
		"getJumpAccelControl": 0x8024de54,
		"Player::__sinit_MarioMove_cpp": 0x8024de70,
		"__sinit_MarioMove_cpp": 0x8024de70,
		"TMario::jumpProcess": 0x8024e16c,
		"jumpProcess": 0x8024e16c,
		"TMario::fallProcess": 0x8024e2d8,
		"fallProcess": 0x8024e2d8,
		"TMario::checkGroundAtJumping": 0x8024e420,
		"checkGroundAtJumping": 0x8024e420,
		"TMario::hangonCheck": 0x8024ea00,
		"hangonCheck": 0x8024ea00,
		"TMario::barProcess": 0x8024ebf0,
		"barProcess": 0x8024ebf0,
		"TMario::walkProcess": 0x8024ee50,
		"walkProcess": 0x8024ee50,
		"TMario::waitProcess": 0x8024ef10,
		"waitProcess": 0x8024ef10,
		"TMario::stopProcess": 0x8024f030,
		"stopProcess": 0x8024f030,
		"TMario::checkGroundAtWalking": 0x8024f080,
		"checkGroundAtWalking": 0x8024f080,
		"TMario::checkDescent": 0x8024f31c,
		"checkDescent": 0x8024f31c,
		"TMario::playerRefrection": 0x8024f8ec,
		"playerRefrection": 0x8024f8ec,
		"Player::__sinit_MarioPhysics_cpp": 0x8024f984,
		"__sinit_MarioPhysics_cpp": 0x8024f984,
		"TMarioInputReplay::reset": 0x8024fc80,
		"TMarioInputReplay::play": 0x8024fce0,
		"TMarioInputReplay::init": 0x8024fdc4,
		"TRecordValueManager<unsigned_char><unsigned_char>::reset": 0x8024feb4,
		"TRecordValueManager<unsigned_char><unsigned_char>::get": 0x8024fed4,
		"TRecordValueManager<unsigned_short><unsigned_short>::reset": 0x8024ff2c,
		"TRecordValueManager<unsigned_short><unsigned_short>::get": 0x8024ff4c,
		"TRecordValueManager<short><short>::reset": 0x8024ffa4,
		"TRecordValueManager<short><short>::get": 0x8024ffc4,
		"TRecordValueManager<float><float>::reset": 0x8025001c,
		"TRecordValueManager<float><float>::get": 0x8025003c,
		"TMario::moveMain": 0x80250094,
		"moveMain": 0x80250094,
		"TMario::jumpSlipEvents": 0x80250ab0,
		"jumpSlipEvents": 0x80250ab0,
		"TMario::jumpSlipCommon": 0x80250be8,
		"jumpSlipCommon": 0x80250be8,
		"TMario::loserDown": 0x80250d20,
		"loserDown": 0x80250d20,
		"TMario::downingCommon": 0x80250e44,
		"downingCommon": 0x80250e44,
		"TMario::oilSlip": 0x80250f94,
		"oilSlip": 0x80250f94,
		"TMario::oilRun": 0x802511c4,
		"oilRun": 0x802511c4,
		"TMario::catching": 0x80251498,
		"catching": 0x80251498,
		"TMario::slipBackCommon": 0x802515ec,
		"slipBackCommon": 0x802515ec,
		"TMario::slipForeCommon": 0x802516cc,
		"slipForeCommon": 0x802516cc,
		"TMario::slippingBasic": 0x80251794,
		"slippingBasic": 0x80251794,
		"TMario::fireDashing": 0x80251ab0,
		"fireDashing": 0x80251ab0,
		"TMario::walkEnd": 0x80251c38,
		"walkEnd": 0x80251c38,
		"TMario::surfing": 0x80251e80,
		"surfing": 0x80251e80,
		"TMario::turnEnd": 0x80252160,
		"turnEnd": 0x80252160,
		"TMario::turnning": 0x802523c4,
		"turnning": 0x802523c4,
		"TMario::rotating": 0x802527b0,
		"rotating": 0x802527b0,
		"TMario::running": 0x802528d8,
		"running": 0x802528d8,
		"TMario::doPushingAnimation": 0x80253068,
		"doPushingAnimation": 0x80253068,
		"TMario::doSurfing": 0x802531c0,
		"doSurfing": 0x802531c0,
		"TMario::getSurfingParamsWater": 0x802535d0,
		"getSurfingParamsWater": 0x802535d0,
		"TMario::doRunning": 0x80253604,
		"doRunning": 0x80253604,
		"TMario::slopeProcess": 0x802538f0,
		"slopeProcess": 0x802538f0,
		"TMario::doSliding": 0x80253a64,
		"doSliding": 0x80253a64,
		"TMario::slideProcess": 0x80253e50,
		"slideProcess": 0x80253e50,
		"TMario::getSlideStickMult": 0x80254218,
		"getSlideStickMult": 0x80254218,
		"TMario::getChangeAngleSpeed": 0x802542c0,
		"getChangeAngleSpeed": 0x802542c0,
		"TMario::getSlopeSlideAccele": 0x80254474,
		"getSlopeSlideAccele": 0x80254474,
		"TMario::getSlopeNormalAccele": 0x802545d0,
		"getSlopeNormalAccele": 0x802545d0,
		"TMario::doRunningAnimation": 0x8025472c,
		"doRunningAnimation": 0x8025472c,
		"TMario::isRunningInWater": 0x80254a1c,
		"isRunningInWater": 0x80254a1c,
		"TMario::considerRotateStart": 0x80254a64,
		"considerRotateStart": 0x80254a64,
		"Player::__sinit_MarioRun_cpp": 0x80254af4,
		"__sinit_MarioRun_cpp": 0x80254af4,
		"TMario::specMain": 0x80254df0,
		"specMain": 0x80254df0,
		"TMario::fencePunch": 0x80255bbc,
		"fencePunch": 0x80255bbc,
		"TMario::fenceMove": 0x80255e74,
		"fenceMove": 0x80255e74,
		"TMario::pulling": 0x80256634,
		"pulling": 0x80256634,
		"TMario::getCurrentPullParams": 0x80256b38,
		"getCurrentPullParams": 0x80256b38,
		"TMario::wireRolling": 0x80256bf4,
		"wireRolling": 0x80256bf4,
		"TMario::wireHanging": 0x80257328,
		"wireHanging": 0x80257328,
		"TMario::changeWireHanging": 0x8025791c,
		"changeWireHanging": 0x8025791c,
		"TMario::wireSWait": 0x802579a8,
		"wireSWait": 0x802579a8,
		"TMario::wireWait": 0x80257d34,
		"wireWait": 0x80257d34,
		"TMario::wireMove": 0x80258184,
		"wireMove": 0x80258184,
		"TMario::getOnWirePosAngle": 0x802582bc,
		"getOnWirePosAngle": 0x802582bc,
		"TMario::hanging": 0x802584a4,
		"hanging": 0x802584a4,
		"TMario::startHangLanding": 0x80258ed0,
		"startHangLanding": 0x80258ed0,
		"TMario::moveRoof": 0x80258fa8,
		"moveRoof": 0x80258fa8,
		"TMario::roofCommonEvents": 0x8025920c,
		"roofCommonEvents": 0x8025920c,
		"TMario::doRoofMovingProcess": 0x8025930c,
		"doRoofMovingProcess": 0x8025930c,
		"TMario::hangingCheckRoof": 0x8025946c,
		"hangingCheckRoof": 0x8025946c,
		"TMario::barClimb": 0x80259608,
		"barClimb": 0x80259608,
		"TMario::barWait": 0x802598d4,
		"barWait": 0x802598d4,
		"Player::__sinit_MarioSpecial_cpp": 0x80259d38,
		"__sinit_MarioSpecial_cpp": 0x80259d38,
		"TMario::stateMachineUpper": 0x8025a034,
		"stateMachineUpper": 0x8025a034,
		"TMario::checkPumpEnable": 0x8025a22c,
		"checkPumpEnable": 0x8025a22c,
		"TMario::checkPumping": 0x8025a400,
		"checkPumping": 0x8025a400,
		"Player::__sinit_MarioUpper_cpp": 0x8025a518,
		"__sinit_MarioUpper_cpp": 0x8025a518,
		"TMario::askJumpIntoWaterEffectExist": 0x8025a814,
		"askJumpIntoWaterEffectExist": 0x8025a814,
		"TMario::sinkInSandEffect": 0x8025a848,
		"sinkInSandEffect": 0x8025a848,
		"TMario::kickFruitEffect": 0x8025a8a4,
		"kickFruitEffect": 0x8025a8a4,
		"TMario::toroccoEffect": 0x8025a948,
		"toroccoEffect": 0x8025a948,
		"TMario::sleepingEffectKill": 0x8025aa68,
		"sleepingEffectKill": 0x8025aa68,
		"TMario::sleepingEffect": 0x8025aaa8,
		"sleepingEffect": 0x8025aaa8,
		"TMario::kickRoofEffect": 0x8025aadc,
		"kickRoofEffect": 0x8025aadc,
		"TMario::elecEndEffect": 0x8025ab70,
		"elecEndEffect": 0x8025ab70,
		"TMario::elecEffect": 0x8025aba4,
		"elecEffect": 0x8025aba4,
		"TMario::rocketEffectStart": 0x8025ac14,
		"rocketEffectStart": 0x8025ac14,
		"TMario::meltInWaterEffect": 0x8025ace0,
		"meltInWaterEffect": 0x8025ace0,
		"TMario::emitSandEffect": 0x8025ad8c,
		"emitSandEffect": 0x8025ad8c,
		"TMario::emitDirtyFootPrint": 0x8025adb4,
		"emitDirtyFootPrint": 0x8025adb4,
		"TMario::emitFootPrintWithEffect": 0x8025addc,
		"emitFootPrintWithEffect": 0x8025addc,
		"TMario::emitRotateShootEffect": 0x8025b078,
		"emitRotateShootEffect": 0x8025b078,
		"TMario::emitBlurSpinJump": 0x8025b0d0,
		"emitBlurSpinJump": 0x8025b0d0,
		"TMario::emitBlurHipDropSuper": 0x8025b184,
		"emitBlurHipDropSuper": 0x8025b184,
		"TMario::emitBlurHipDrop": 0x8025b228,
		"emitBlurHipDrop": 0x8025b228,
		"TMario::warpOutEffect": 0x8025b26c,
		"warpOutEffect": 0x8025b26c,
		"TMario::warpInLight": 0x8025b4f8,
		"warpInLight": 0x8025b4f8,
		"TMario::warpInEffect": 0x8025b52c,
		"warpInEffect": 0x8025b52c,
		"TWarpInCallBack::execute": 0x8025b6a8,
		"TMario::surfingEffect": 0x8025b82c,
		"surfingEffect": 0x8025b82c,
		"TMario::frontSlipEffect": 0x8025b9d8,
		"frontSlipEffect": 0x8025b9d8,
		"TMario::treeSlipEffect": 0x8025bb4c,
		"treeSlipEffect": 0x8025bb4c,
		"TMario::wallSlipEffect": 0x8025bbfc,
		"wallSlipEffect": 0x8025bbfc,
		"TMario::blurEffect": 0x8025bc30,
		"blurEffect": 0x8025bc30,
		"TMario::runningRippleEffect": 0x8025bc70,
		"runningRippleEffect": 0x8025bc70,
		"TMario::swimmingBubbleEffect": 0x8025bcc8,
		"swimmingBubbleEffect": 0x8025bcc8,
		"TMario::bubbleFromBody": 0x8025bd9c,
		"bubbleFromBody": 0x8025bd9c,
		"TMario::bubbleFromMouth": 0x8025be60,
		"bubbleFromMouth": 0x8025be60,
		"TBubbleCallBack::execute": 0x8025bed0,
		"TMario::inOutWaterEffect": 0x8025bf74,
		"inOutWaterEffect": 0x8025bf74,
		"TMario::rippleEffect": 0x8025c12c,
		"rippleEffect": 0x8025c12c,
		"TMario::smallTouchDownEffect": 0x8025c1c8,
		"smallTouchDownEffect": 0x8025c1c8,
		"TMario::strongTouchDownEffect": 0x8025c26c,
		"strongTouchDownEffect": 0x8025c26c,
		"TMario::emitGetCoinEffect": 0x8025c2dc,
		"emitGetCoinEffect": 0x8025c2dc,
		"TMario::emitGetWaterEffect": 0x8025c334,
		"emitGetWaterEffect": 0x8025c334,
		"TMario::emitGetEffect": 0x8025c368,
		"emitGetEffect": 0x8025c368,
		"TMario::emitSweatSometimes": 0x8025c3b4,
		"emitSweatSometimes": 0x8025c3b4,
		"TMario::emitSweat": 0x8025c3e8,
		"emitSweat": 0x8025c3e8,
		"TMario::emitSmoke": 0x8025c4bc,
		"emitSmoke": 0x8025c4bc,
		"TMario::moveParticle": 0x8025c610,
		"moveParticle": 0x8025c610,
		"TMario::initParticle": 0x8025c67c,
		"Player::__sinit_MarioParticle_cpp": 0x8025c754,
		"__sinit_MarioParticle_cpp": 0x8025c754,
		"TMario::waitMain": 0x8025ca68,
		"waitMain": 0x8025ca68,
		"TMario::jumpEndEvents": 0x8025d340,
		"jumpEndEvents": 0x8025d340,
		"TMario::jumpEndCommon": 0x8025d3b8,
		"jumpEndCommon": 0x8025d3b8,
		"TMario::squatStandup": 0x8025d438,
		"squatStandup": 0x8025d438,
		"TMario::squating": 0x8025d554,
		"squating": 0x8025d554,
		"TMario::getSideWalkValues": 0x8025d890,
		"getSideWalkValues": 0x8025d890,
		"TMario::sleeping": 0x8025d960,
		"sleeping": 0x8025d960,
		"TMario::sleepily": 0x8025daf4,
		"sleepily": 0x8025daf4,
		"TMario::waiting": 0x8025dc14,
		"waiting": 0x8025dc14,
		"TMario::changeMontemanWaitingAnim": 0x8025deb4,
		"changeMontemanWaitingAnim": 0x8025deb4,
		"TMario::stopCommon": 0x8025ded4,
		"stopCommon": 0x8025ded4,
		"TMario::waitingCommonEvents": 0x8025df90,
		"waitingCommonEvents": 0x8025df90,
		"TMario::canPut": 0x8025e1b0,
		"canPut": 0x8025e1b0,
		"TMario::canSleep": 0x8025e270,
		"canSleep": 0x8025e270,
		"TMario::startTalking": 0x8025e42c,
		"startTalking": 0x8025e42c,
		"Player::__sinit_MarioWait_cpp": 0x8025e4b4,
		"__sinit_MarioWait_cpp": 0x8025e4b4,
		"TSplashManager::~TSplashManager": 0x8025e7b0,
		"TSplashManager::perform": 0x8025e850,
		"TSplashManager::draw": 0x8025e8d0,
		"TSplashManager::makeDL": 0x8025eaf0,
		"TSplashManager::move": 0x8025ec78,
		"TSplashManager::newSplash": 0x8025ed38,
		"newSplash": 0x8025ed38,
		"TSplashManager::load": 0x8025eddc,
		"Player::__sinit_SplashManager_cpp": 0x8025ef74,
		"__sinit_SplashManager_cpp": 0x8025ef74,
		"TYoshiTongue::getTakingMtx": 0x8025f30c,
		"TYoshiTongue::checkTaking": 0x8025f318,
		"checkTaking": 0x8025f318,
		"TYoshiTongue::checkTaken": 0x8025f31c,
		"checkTaken": 0x8025f31c,
		"TYoshiTongue::entry": 0x8025f320,
		"TYoshiTongue::viewCalc": 0x8025f37c,
		"TYoshiTongue::calcAnim": 0x8025f3d8,
		"TYoshiTongue::movement": 0x8025f654,
		"JGeometry::TVec3<float><float>::operator_-=": 0x8025fef4,
		"operator_-=": 0x8025fef4,
		"TYoshiTongue::findTarget": 0x8025ff28,
		"findTarget": 0x8025ff28,
		"TYoshiTongue::canGo": 0x8026023c,
		"canGo": 0x8026023c,
		"TYoshiTongue::emit": 0x80260378,
		"TYoshiTongue::initInLoadAfter": 0x8026050c,
		"TYoshiTongue::init": 0x80260618,
		"Player::__sinit_Tongue_cpp": 0x8026080c,
		"__sinit_Tongue_cpp": 0x8026080c,
		"TWaterGun::changeBackup": 0x80260b10,
		"changeBackup": 0x80260b10,
		"TWaterGun::damage": 0x80260bbc,
		"damage": 0x80260bbc,
		"TWaterGun::suck": 0x80260c0c,
		"suck": 0x80260c0c,
		"TWaterGun::emit": 0x80260d24,
		"TWaterGun::triggerPressureMovement": 0x80260fc8,
		"triggerPressureMovement": 0x80260fc8,
		"TWaterGun::rotateProp": 0x80261060,
		"rotateProp": 0x80261060,
		"TWaterGun::getEmitPosDirSpeed": 0x80261114,
		"getEmitPosDirSpeed": 0x80261114,
		"TWaterGun::getPressureMax": 0x802611d4,
		"getPressureMax": 0x802611d4,
		"TWaterGun::getPressure": 0x80261240,
		"getPressure": 0x80261240,
		"TWaterGun::isPressureOn": 0x802612ac,
		"isPressureOn": 0x802612ac,
		"TWaterGun::setAmountToRate": 0x80261328,
		"setAmountToRate": 0x80261328,
		"TWaterGun::getCurrentNozzle": 0x80261398,
		"getCurrentNozzle": 0x80261398,
		"TWaterGun::perform": 0x802614a8,
		"TWaterGun::calcAnimation": 0x802615f4,
		"calcAnimation": 0x802615f4,
		"TWaterGun::setBaseTRMtx": 0x80261880,
		"setBaseTRMtx": 0x80261880,
		"TWaterGun::movement": 0x8026196c,
		"TWaterGun::changeNozzle": 0x80261ef0,
		"changeNozzle": 0x80261ef0,
		"TWaterGun::getNozzleMtx": 0x80262030,
		"getNozzleMtx": 0x80262030,
		"TWaterGun::getEmitMtx": 0x8026204c,
		"getEmitMtx": 0x8026204c,
		"TWaterGun::initInLoadAfter": 0x80262144,
		"TWaterGun::init": 0x80262148,
		"TWaterGun::TWaterGun": 0x802627d4,
		"TNozzleDeform::animation": 0x80262b80,
		"TNozzleDeform::emit": 0x8026330c,
		"TNozzleDeform::movement": 0x802636b4,
		"TNozzleTrigger::animation": 0x802637dc,
		"TNozzleTrigger::emit": 0x80263d50,
		"TNozzleTrigger::movement": 0x80264058,
		"TNozzleTrigger::init": 0x80264470,
		"TNozzleBase::animation": 0x80264490,
		"TNozzleBase::emit": 0x80264948,
		"TNozzleBase::emitCommon": 0x80264c14,
		"emitCommon": 0x80264c14,
		"TNozzleBase::movement": 0x80264dac,
		"TNozzleBase::calcGunAngle": 0x80264e74,
		"calcGunAngle": 0x80264e74,
		"TNozzleBase::init": 0x80264fa8,
		"TNozzleBase::TNozzleBase": 0x80264fcc,
		"Player::WaterGunDivingCtrlR": 0x802657cc,
		"WaterGunDivingCtrlR": 0x802657cc,
		"Player::WaterGunDivingCtrlL": 0x8026585c,
		"WaterGunDivingCtrlL": 0x8026585c,
		"Player::RotateCtrl": 0x802658ec,
		"RotateCtrl": 0x802658ec,
		"Player::NozzleCtrl": 0x80265970,
		"NozzleCtrl": 0x80265970,
		"TNozzleBase::getWaistAngle": 0x80265a1c,
		"getWaistAngle": 0x80265a1c,
		"TNozzleDeform::getNozzleKind": 0x80265a24,
		"Player::__sinit_WaterGun_cpp": 0x80265a2c,
		"__sinit_WaterGun_cpp": 0x80265a2c,
		"TYoshi::entry": 0x80265d28,
		"TYoshi::viewCalc": 0x80266048,
		"TYoshi::calcAnim": 0x802660c8,
		"TYoshi::movement": 0x80266504,
		"TYoshi::thinkHoldOut": 0x80267238,
		"thinkHoldOut": 0x80267238,
		"TYoshi::doEat": 0x80267398,
		"doEat": 0x80267398,
		"TYoshi::doSearch": 0x802674bc,
		"doSearch": 0x802674bc,
		"TYoshi::thinkUpper": 0x80267a1c,
		"thinkUpper": 0x80267a1c,
		"TYoshi::thinkAnimation": 0x80267bc4,
		"thinkAnimation": 0x80267bc4,
		"TYoshi::getOff": 0x80267fb8,
		"getOff": 0x80267fb8,
		"TYoshi::ride": 0x80268174,
		"ride": 0x80268174,
		"TYoshi::kill": 0x80268264,
		"TYoshi::disappear": 0x8026837c,
		"disappear": 0x8026837c,
		"TYoshi::appearFromEgg": 0x80268490,
		"appearFromEgg": 0x80268490,
		"TYoshi::setEggYoshiPtr": 0x80268618,
		"setEggYoshiPtr": 0x80268618,
		"TYoshi::getEmitPosDir": 0x80268620,
		"getEmitPosDir": 0x80268620,
		"TYoshi::changeAnimation": 0x8026866c,
		"changeAnimation": 0x8026866c,
		"TYoshi::thinkBtp": 0x80268708,
		"thinkBtp": 0x80268708,
		"TYoshi::initInLoadAfter": 0x802687b8,
		"TYoshi::init": 0x8026888c,
		"TYoshi::getMtxPtrFootR": 0x80269330,
		"getMtxPtrFootR": 0x80269330,
		"TYoshi::getMtxPtrFootL": 0x8026934c,
		"getMtxPtrFootL": 0x8026934c,
		"TYoshi::getFrameCtrl": 0x80269368,
		"Player::YoshiHeadCtrl": 0x80269390,
		"YoshiHeadCtrl": 0x80269390,
		"Player::__sinit_Yoshi_cpp": 0x8026941c,
		"__sinit_Yoshi_cpp": 0x8026941c,
		"TMarioEffect::perform": 0x8026979c,
		"TMarioEffect::setJumpIntoWaterEffectSmall": 0x80269a7c,
		"setJumpIntoWaterEffectSmall": 0x80269a7c,
		"TMarioEffect::setJumpIntoWaterEffect": 0x80269c18,
		"setJumpIntoWaterEffect": 0x80269c18,
		"TMarioEffect::init": 0x80269e50,
		"Player::__sinit_MarioEffect_cpp": 0x8026a060,
		"__sinit_MarioEffect_cpp": 0x8026a060,
		"TMario::swimMain": 0x8026a364,
		"swimMain": 0x8026a364,
		"TMario::swimPaddle": 0x8026aa5c,
		"swimPaddle": 0x8026aa5c,
		"TMario::checkSwimJump": 0x8026ab8c,
		"checkSwimJump": 0x8026ab8c,
		"TMario::doSwimming": 0x8026acfc,
		"doSwimming": 0x8026acfc,
		"Player::__sinit_MarioSwim_cpp": 0x8026b080,
		"__sinit_MarioSwim_cpp": 0x8026b080,
		"Player::SMS_IsMarioRoofing": 0x8026b37c,
		"SMS_IsMarioRoofing": 0x8026b37c,
		"Player::SMS_IsMarioFencing": 0x8026b3a8,
		"SMS_IsMarioFencing": 0x8026b3a8,
		"Player::SMS_GetMarioRfPlane": 0x8026b3dc,
		"SMS_GetMarioRfPlane": 0x8026b3dc,
		"Player::SMS_GetMarioWlPlane": 0x8026b3e8,
		"SMS_GetMarioWlPlane": 0x8026b3e8,
		"Player::SMS_GetMarioGrPlane": 0x8026b3f4,
		"SMS_GetMarioGrPlane": 0x8026b3f4,
		"Player::SMS_WindMoveMario": 0x8026b40c,
		"SMS_WindMoveMario": 0x8026b40c,
		"Player::SMS_FlowMoveMario": 0x8026b434,
		"SMS_FlowMoveMario": 0x8026b434,
		"Player::SMS_MarioWarpRequest": 0x8026b45c,
		"SMS_MarioWarpRequest": 0x8026b45c,
		"Player::SMS_MarioMoveRequest": 0x8026b484,
		"SMS_MarioMoveRequest": 0x8026b484,
		"Player::SMS_IsMarioDashing": 0x8026b4b8,
		"SMS_IsMarioDashing": 0x8026b4b8,
		"Player::SMS_IsMarioOnYoshi": 0x8026b4ec,
		"SMS_IsMarioOnYoshi": 0x8026b4ec,
		"Player::SMS_IsMarioOpeningDoor": 0x8026b520,
		"SMS_IsMarioOpeningDoor": 0x8026b520,
		"Player::SMS_IsMarioOnWire": 0x8026b548,
		"SMS_IsMarioOnWire": 0x8026b548,
		"Player::SMS_IsMarioTouchGround4cm": 0x8026b590,
		"SMS_IsMarioTouchGround4cm": 0x8026b590,
		"Player::SMS_ThrowMario": 0x8026b5d4,
		"SMS_ThrowMario": 0x8026b5d4,
		"Player::SMS_SendMessageToMario": 0x8026b5fc,
		"SMS_SendMessageToMario": 0x8026b5fc,
		"Player::SMS_GetMarioWaterGun": 0x8026b64c,
		"SMS_GetMarioWaterGun": 0x8026b64c,
		"Player::SMS_GetMarioGravity": 0x8026b658,
		"SMS_GetMarioGravity": 0x8026b658,
		"Player::SMS_GetMarioGrLevel": 0x8026b664,
		"SMS_GetMarioGrLevel": 0x8026b664,
		"Player::SMS_GetMarioDamageRadius": 0x8026b670,
		"SMS_GetMarioDamageRadius": 0x8026b670,
		"Player::SMS_GetMarioHP": 0x8026b67c,
		"SMS_GetMarioHP": 0x8026b67c,
		"Player::SMS_IsMarioHeadSlideAttack": 0x8026b688,
		"SMS_IsMarioHeadSlideAttack": 0x8026b688,
		"Player::SMS_IsMarioStatusElecDamage": 0x8026b6b4,
		"SMS_IsMarioStatusElecDamage": 0x8026b6b4,
		"Player::SMS_IsMarioStatusThrownDown": 0x8026b6d8,
		"SMS_IsMarioStatusThrownDown": 0x8026b6d8,
		"Player::SMS_IsMarioStatusHipDrop": 0x8026b6fc,
		"SMS_IsMarioStatusHipDrop": 0x8026b6fc,
		"Player::SMS_IsMarioStatusTypeSwimming": 0x8026b720,
		"SMS_IsMarioStatusTypeSwimming": 0x8026b720,
		"Player::SMS_IsMarioStatusTypeJumping": 0x8026b740,
		"SMS_IsMarioStatusTypeJumping": 0x8026b740,
		"Player::SMS_GetMarioHitActor": 0x8026b760,
		"SMS_GetMarioHitActor": 0x8026b760,
		"Player::SMS_AskJumpIntoWaterEffectExist": 0x8026b768,
		"SMS_AskJumpIntoWaterEffectExist": 0x8026b768,
		"Player::SMS_GetYoshi": 0x8026b78c,
		"SMS_GetYoshi": 0x8026b78c,
		"Player::SMS_SetMarioAccessParams": 0x8026b798,
		"SMS_SetMarioAccessParams": 0x8026b798,
		"TMario::TSurfingParams::TSurfingParams": 0x8026b7fc,
		"TMario::TDirtyParams::TDirtyParams": 0x8026bc58,
		"TMario::TGraffitoParams::TGraffitoParams": 0x8026c0dc,
		"TMario::TWireParams::TWireParams": 0x8026c4e0,
		"TMario::TSwimParams::TSwimParams": 0x8026c80c,
		"TMario::TRunParams::TRunParams": 0x8026cd74,
		"TMario::TJumpParams::TJumpParams": 0x8026d198,
		"TMario::TDeParams::TDeParams": 0x8026d9f0,
		"TMario::setGamePad": 0x8026e378,
		"setGamePad": 0x8026e378,
		"TMario::resetHistory": 0x8026e380,
		"resetHistory": 0x8026e380,
		"TMario::initValues": 0x8026e43c,
		"TMario::loadAfter": 0x8026e868,
		"TMario::load": 0x8026e95c,
		"TMario::TMario": 0x8026ea40,
		"Player::__sinit_MarioInit_cpp": 0x802738b0,
		"__sinit_MarioInit_cpp": 0x802738b0,
		"TModelWaterManager::~TModelWaterManager": 0x80273bc8,
		"TModelWaterManager::perform": 0x80273c3c,
		"TModelWaterManager::drawRefracAndSpec": 0x80273eb8,
		"drawRefracAndSpec": 0x80273eb8,
		"TModelWaterManager::drawShineShadowVolume": 0x80274408,
		"drawShineShadowVolume": 0x80274408,
		"TModelWaterManager::drawMirror": 0x802749b8,
		"drawMirror": 0x802749b8,
		"TModelWaterManager::drawWaterVolume": 0x802751a4,
		"drawWaterVolume": 0x802751a4,
		"TModelWaterManager::drawSilhouette": 0x80275a8c,
		"drawSilhouette": 0x80275a8c,
		"TModelWaterManager::drawTouching": 0x80275e78,
		"drawTouching": 0x80275e78,
		"TModelWaterManager::calcVMAll": 0x80275fa8,
		"calcVMAll": 0x80275fa8,
		"TModelWaterManager::calcVMMtxWall": 0x80276130,
		"calcVMMtxWall": 0x80276130,
		"TModelWaterManager::calcVMMtxGround": 0x80276244,
		"calcVMMtxGround": 0x80276244,
		"TModelWaterManager::calcDrawVtx": 0x80276380,
		"calcDrawVtx": 0x80276380,
		"TModelWaterManager::calcWorldMinMax": 0x8027666c,
		"calcWorldMinMax": 0x8027666c,
		"TModelWaterManager::move": 0x802767d4,
		"TBGCheckData::isWaterSlip": 0x80277828,
		"isWaterSlip": 0x80277828,
		"TModelWaterManager::garbageCollect": 0x8027785c,
		"garbageCollect": 0x8027785c,
		"TModelWaterManager::wind": 0x80277974,
		"wind": 0x80277974,
		"TModelWaterManager::askDoWaterHitCheck": 0x802779e8,
		"askDoWaterHitCheck": 0x802779e8,
		"TModelWaterManager::emitRequest": 0x80277a10,
		"emitRequest": 0x80277a10,
		"TModelWaterManager::makeEmit": 0x80277ab4,
		"makeEmit": 0x80277ab4,
		"TModelWaterManager::askHitWaterParticleOnGround": 0x80277d80,
		"askHitWaterParticleOnGround": 0x80277d80,
		"TModelWaterManager::loadAfter": 0x80277e14,
		"TModelWaterManager::load": 0x80277f10,
		"TWaterEmitInfo::TWaterEmitInfo": 0x80278480,
		"Player::__sinit_ModelWaterManager_cpp": 0x80278868,
		"__sinit_ModelWaterManager_cpp": 0x80278868,
		"TMarioPositionObj::~TMarioPositionObj": 0x80278ba8,
		"TMarioPositionObj::perform": 0x80278c1c,
		"TMarioPositionObj::load": 0x80278c20,
		"TMario::checkCollision": 0x80278d74,
		"checkCollision": 0x80278d74,
		"TMario::hangPole": 0x8027a0e0,
		"hangPole": 0x8027a0e0,
		"TMario::hitNormal": 0x8027a374,
		"hitNormal": 0x8027a374,
		"Player::__sinit_MarioCheckCol_cpp": 0x8027a584,
		"__sinit_MarioCheckCol_cpp": 0x8027a584,
		"TMario::receiveMessage": 0x8027a880,
		"TMario::getGesso": 0x8027cb44,
		"getGesso": 0x8027cb44,
		"Player::__sinit_MarioReceiveMsg_cpp": 0x8027cc68,
		"__sinit_MarioReceiveMsg_cpp": 0x8027cc68,
		"TMarioSoundValues::TMarioSoundValues": 0x8027cf64,
		"TMario::startSoundActor": 0x8027cfb8,
		"TMario::stopVoice": 0x8027d01c,
		"stopVoice": 0x8027d01c,
		"TMario::startVoiceIfNoVoice": 0x8027d064,
		"startVoiceIfNoVoice": 0x8027d064,
		"TMario::startVoice": 0x8027d108,
		"startVoice": 0x8027d108,
		"TMario::getVoiceStatus": 0x8027d184,
		"getVoiceStatus": 0x8027d184,
		"TMario::soundTorocco": 0x8027d1f0,
		"soundTorocco": 0x8027d1f0,
		"TMario::animSound": 0x8027d2e4,
		"animSound": 0x8027d2e4,
		"TMario::soundMovement": 0x8027d5c8,
		"soundMovement": 0x8027d5c8,
		"Player::__sinit_MarioSound_cpp": 0x8027f0d4,
		"__sinit_MarioSound_cpp": 0x8027f0d4,
		"TBaseNPC::monteMESetAnmWhenNear": 0x801fa30c,
		"monteMESetAnmWhenNear": 0x801fa30c,
		"TBaseNPC::monteMESetAnmWhenFar": 0x801fa530,
		"monteMESetAnmWhenFar": 0x801fa530,
		"TBaseNPC::sunflowerReviving": 0x801fa750,
		"sunflowerReviving": 0x801fa750,
		"TBaseNPC::sunflowerReviveIn": 0x801fa81c,
		"sunflowerReviveIn": 0x801fa81c,
		"TBaseNPC::sunflowerDownIn_": 0x801fa8f8,
		"sunflowerDownIn_": 0x801fa8f8,
		"TBaseNPC::peachTiredIn_": 0x801fa934,
		"peachTiredIn_": 0x801fa934,
		"TBaseNPC::peachParasolOut_": 0x801fa9f0,
		"peachParasolOut_": 0x801fa9f0,
		"TBaseNPC::peachParasolIn_": 0x801faa20,
		"peachParasolIn_": 0x801faa20,
		"TBaseNPC::npcMareStanding": 0x801faa50,
		"npcMareStanding": 0x801faa50,
		"TBaseNPC::npcMareStandIn": 0x801fabac,
		"npcMareStandIn": 0x801fabac,
		"TBaseNPC::npcBlowning": 0x801fad00,
		"npcBlowning": 0x801fad00,
		"TBaseNPC::npcBlownIn": 0x801fad2c,
		"npcBlownIn": 0x801fad2c,
		"TBaseNPC::npcMadding": 0x801fae08,
		"npcMadding": 0x801fae08,
		"TBaseNPC::npcMadIn": 0x801fb0d0,
		"npcMadIn": 0x801fb0d0,
		"TBaseNPC::npcThrowing": 0x801fb1dc,
		"npcThrowing": 0x801fb1dc,
		"TBaseNPC::npcThrowIn": 0x801fb28c,
		"npcThrowIn": 0x801fb28c,
		"TBaseNPC::npcSinking": 0x801fb360,
		"npcSinking": 0x801fb360,
		"TBaseNPC::npcWetting": 0x801fb4a4,
		"npcWetting": 0x801fb4a4,
		"TBaseNPC::npcWetIn": 0x801fc10c,
		"npcWetIn": 0x801fc10c,
		"TBaseNPC::npcHappyIn": 0x801fc404,
		"npcHappyIn": 0x801fc404,
		"TBaseNPC::npcDanceIn": 0x801fc4e8,
		"npcDanceIn": 0x801fc4e8,
		"TBaseNPC::npcTakenIn": 0x801fc5c8,
		"npcTakenIn": 0x801fc5c8,
		"TBaseNPC::npcTalkOut": 0x801fc69c,
		"npcTalkOut": 0x801fc69c,
		"TBaseNPC::npcTalking": 0x801fc868,
		"npcTalking": 0x801fc868,
		"TBaseNPC::npcTalkIn": 0x801fca08,
		"npcTalkIn": 0x801fca08,
		"TBaseNPC::npcStepIn": 0x801fcb9c,
		"npcStepIn": 0x801fcb9c,
		"TBaseNPC::npcRecoverAfterIn": 0x801fcc70,
		"npcRecoverAfterIn": 0x801fcc70,
		"TBaseNPC::npcRecoverFromSinking": 0x801fcd44,
		"npcRecoverFromSinking": 0x801fcd44,
		"TBaseNPC::npcFallIn": 0x801fcf24,
		"npcFallIn": 0x801fcf24,
		"TBaseNPC::npcWaitIn": 0x801fcff8,
		"npcWaitIn": 0x801fcff8,
		"TBaseNPC::getNpcWaitAnmBase_": 0x801fd1d0,
		"getNpcWaitAnmBase_": 0x801fd1d0,
		"TBaseNPC::walkAnmRateChange_": 0x801fd238,
		"walkAnmRateChange_": 0x801fd238,
		"TBaseNPC::randomizeBckAndBtpFrame_": 0x801fd664,
		"randomizeBckAndBtpFrame_": 0x801fd664,
		"TBaseNPC::requestTalkAnm_": 0x801fd7bc,
		"requestTalkAnm_": 0x801fd7bc,
		"TBaseNPC::setKeepAnm_": 0x801fd888,
		"setKeepAnm_": 0x801fd888,
		"TBaseNPC::requestNpcAnm_": 0x801fd8e0,
		"requestNpcAnm_": 0x801fd8e0,
		"TBaseNPC::setNpcAnm_": 0x801fd980,
		"setNpcAnm_": 0x801fd980,
		"NPC::CLBPalFrame": 0x801fddf4,
		"NPC::__sinit_NpcAnm_cpp": 0x801fde80,
		"__sinit_NpcAnm_cpp": 0x801fde80,
		"TBaseNPC::getPtrInitPollutionColor": 0x801fe1e8,
		"getPtrInitPollutionColor": 0x801fe1e8,
		"TBaseNPC::setBalloonMessage": 0x801fe320,
		"setBalloonMessage": 0x801fe320,
		"TBaseNPC::setDummyConnectActor": 0x801fe344,
		"setDummyConnectActor": 0x801fe344,
		"TBaseNPC::perform": 0x801fe394,
		"TBaseNPC::getAnmOffDist_": 0x801feb7c,
		"getAnmOffDist_": 0x801feb7c,
		"TBaseNPC::updateForbidCount_": 0x801fec80,
		"updateForbidCount_": 0x801fec80,
		"TBaseNPC::calcRootMatrix": 0x801fecc0,
		"TBaseNPC::execMotionBlend_": 0x801fede8,
		"execMotionBlend_": 0x801fede8,
		"TBaseNPC::moveObject": 0x801fee7c,
		"TBaseNPC::receiveMessage": 0x801ff2cc,
		"TBaseNPC::getFocalPoint": 0x801ff4e8,
		"TBaseNPC::getCursorPos": 0x801ff51c,
		"getCursorPos": 0x801ff51c,
		"TBaseNPC::isInMadSearchRange": 0x801ff550,
		"isInMadSearchRange": 0x801ff550,
		"TBaseNPC::isInBodyTurnSearchRange": 0x801ff5bc,
		"isInBodyTurnSearchRange": 0x801ff5bc,
		"TBaseNPC::isNeedNeckStraight": 0x801ff628,
		"isNeedNeckStraight": 0x801ff628,
		"TBaseNPC::isPartsAnmNpc": 0x801ff778,
		"isPartsAnmNpc": 0x801ff778,
		"TBaseNPC::isBehaveToWaterNpc": 0x801ff7f4,
		"isBehaveToWaterNpc": 0x801ff7f4,
		"TBaseNPC::isMadNpc": 0x801ff82c,
		"isMadNpc": 0x801ff82c,
		"TBaseNPC::isBeTrampledNpc": 0x801ff900,
		"isBeTrampledNpc": 0x801ff900,
		"TBaseNPC::isPollutionNpc": 0x801ffaa8,
		"isPollutionNpc": 0x801ffaa8,
		"TBaseNPC::isSmallNpc": 0x801ffae0,
		"isSmallNpc": 0x801ffae0,
		"TBaseNPC::isChild": 0x801ffc18,
		"isChild": 0x801ffc18,
		"TBaseNPC::isSunflower": 0x801ffc50,
		"isSunflower": 0x801ffc50,
		"TBaseNPC::isJellyFishMare": 0x801ffc7c,
		"isJellyFishMare": 0x801ffc7c,
		"TBaseNPC::isSpecialMareW": 0x801ffcac,
		"isSpecialMareW": 0x801ffcac,
		"TBaseNPC::isSpecialMareM": 0x801ffcd8,
		"isSpecialMareM": 0x801ffcd8,
		"TBaseNPC::isNormalMareW": 0x801ffd04,
		"isNormalMareW": 0x801ffd04,
		"TBaseNPC::isNormalMareM": 0x801ffd24,
		"isNormalMareM": 0x801ffd24,
		"TBaseNPC::isSpecialMonteW": 0x801ffd44,
		"isSpecialMonteW": 0x801ffd44,
		"TBaseNPC::isSpecialMonteM": 0x801ffd64,
		"isSpecialMonteM": 0x801ffd64,
		"TBaseNPC::isNormalMonteW": 0x801ffd90,
		"isNormalMonteW": 0x801ffd90,
		"TBaseNPC::isNormalMonteM": 0x801ffdbc,
		"isNormalMonteM": 0x801ffdbc,
		"TBaseNPC::loadAfter": 0x801ffde8,
		"TBaseNPC::load": 0x801ffe70,
		"TBaseNPC::TBaseNPC": 0x801fff4c,
		"NPC::__sinit_NpcBase_cpp": 0x80200250,
		"__sinit_NpcBase_cpp": 0x80200250,
		"NPC::NPCNeckCallBack": 0x80200554,
		"NPCNeckCallBack": 0x80200554,
		"NPC::CLBEaseOutInbetween": 0x8020097c,
		"NPC::CLBPalIntSpeed": 0x80200a20,
		"CLBPalIntSpeed": 0x80200a20,
		"TSunflowerSManager::~TSunflowerSManager": 0x80200a74,
		"TSunflowerSManager::createModelData": 0x80200ae8,
		"TSunflowerLManager::createModelData": 0x80200b1c,
		"TRaccoonDogManager::createModelData": 0x80200b50,
		"TPeachManager::createModelData": 0x80200b84,
		"TKinojiiManager::createModelData": 0x80200bb8,
		"TKinopioManager::createModelData": 0x80200bec,
		"TMareWBaseManager::createModelData": 0x80200c5c,
		"TMareMBaseManager::createModelData": 0x80200cc8,
		"TMonteWCManager::createModelData": 0x80200d34,
		"TMonteWBManager::createModelData": 0x80200d9c,
		"TMonteWAManager::createModelData": 0x80200e08,
		"TMonteWManager::createModelData": 0x80200eac,
		"TMonteMHManager::createModelData": 0x80200f50,
		"TMonteMGManager::createModelData": 0x80200fb8,
		"TMonteMFManager::createModelData": 0x80201020,
		"TMonteMEManager::createModelData": 0x80201088,
		"TMonteMDManager::createModelData": 0x802010bc,
		"TMonteMCManager::createModelData": 0x80201128,
		"TMonteMBManager::createModelData": 0x802011cc,
		"TMonteMAManager::createModelData": 0x80201238,
		"TMonteMManager::createModelData": 0x802012dc,
		"TSunflowerLManager::load": 0x80201380,
		"TRaccoonDogManager::load": 0x802013bc,
		"TPeachManager::load": 0x80201430,
		"TKinojiiManager::load": 0x802014a4,
		"TKinopioManager::load": 0x80201518,
		"TMareWBManager::load": 0x8020158c,
		"TMareWAManager::load": 0x80201600,
		"TMareMDManager::load": 0x80201674,
		"TMareMCManager::load": 0x802016e8,
		"TMareMBManager::load": 0x8020175c,
		"TMareMAManager::load": 0x802017d0,
		"TMonteWCManager::load": 0x80201844,
		"TMonteMHManager::load": 0x802018b8,
		"TMonteMGManager::load": 0x8020192c,
		"TMonteMFManager::load": 0x802019a0,
		"TMonteWSpecialManager::createAnmData": 0x80201a14,
		"TMonteMSpecialManager::createAnmData": 0x80201a34,
		"TMonteWBaseManager::createAnmData": 0x80201a54,
		"TMonteMBaseManager::createAnmData": 0x80201ab0,
		"TMareBaseManager::getBmt_": 0x80201b0c,
		"TMareWBaseManager::TMareWBaseManager": 0x80201b88,
		"TMareBaseManager::~TMareBaseManager": 0x80201c7c,
		"TMareMBaseManager::TMareMBaseManager": 0x80201cf0,
		"TMonteWBaseManager::TMonteWBaseManager": 0x80201de4,
		"TMonteMBaseManager::TMonteMBaseManager": 0x80201e88,
		"TNPCManager::perform": 0x80201f2c,
		"TNPCManager::clipEnemies": 0x80202098,
		"TNPCManager::getPartsSDLModelData": 0x80202258,
		"getPartsSDLModelData": 0x80202258,
		"TNPCManager::getBmt_": 0x802022cc,
		"TNPCManager::makePartsModelData_": 0x802022d4,
		"makePartsModelData_": 0x802022d4,
		"TNPCManager::load": 0x80202424,
		"TNPCManager::TNPCManager": 0x80202458,
		"TMareJellyFishManager::createModelData": 0x80202578,
		"TMareJellyFishManager::perform": 0x80202654,
		"TMareJellyFishManager::TMareJellyFishManager": 0x80202658,
		"TBoardNpcManager::createModelData": 0x8020270c,
		"TBoardNpcManager::clipActors": 0x80202740,
		"TMonteWBManager::~TMonteWBManager": 0x80202874,
		"TMonteWAManager::~TMonteWAManager": 0x802028f8,
		"TMonteWManager::~TMonteWManager": 0x8020297c,
		"TMonteMEManager::~TMonteMEManager": 0x80202a00,
		"TMonteMDManager::~TMonteMDManager": 0x80202a94,
		"TMonteMCManager::~TMonteMCManager": 0x80202b18,
		"TMonteMBManager::~TMonteMBManager": 0x80202b9c,
		"TMonteMAManager::~TMonteMAManager": 0x80202c20,
		"TMonteMManager::~TMonteMManager": 0x80202ca4,
		"TSunflowerLManager::~TSunflowerLManager": 0x80202d28,
		"TRaccoonDogManager::~TRaccoonDogManager": 0x80202d9c,
		"TPeachManager::~TPeachManager": 0x80202e10,
		"TKinojiiManager::~TKinojiiManager": 0x80202e84,
		"TKinopioManager::~TKinopioManager": 0x80202ef8,
		"TMareWBManager::~TMareWBManager": 0x80202f6c,
		"TMareWAManager::~TMareWAManager": 0x80203000,
		"TMareMDManager::~TMareMDManager": 0x80203094,
		"TMareMCManager::~TMareMCManager": 0x80203128,
		"TMareMBManager::~TMareMBManager": 0x802031bc,
		"TMareMAManager::~TMareMAManager": 0x80203250,
		"TMonteWCManager::~TMonteWCManager": 0x802032e4,
		"TMonteMHManager::~TMonteMHManager": 0x80203378,
		"TMonteMGManager::~TMonteMGManager": 0x8020340c,
		"TMonteMFManager::~TMonteMFManager": 0x802034a0,
		"TMareJellyFishManager::~TMareJellyFishManager": 0x80203724,
		"TBoardNpcManager::~TBoardNpcManager": 0x802037a8,
		"TNerveNPCMareStand::~TNerveNPCMareStand": 0x8020383c,
		"TNerveNPCMareStand::execute": 0x80203898,
		"TNerveNPCMareStand::theNerve": 0x802038f0,
		"TNerveNPCBlown::execute": 0x80203954,
		"TNerveNPCBlown::theNerve": 0x80203a68,
		"TNerveNPCBlown::~TNerveNPCBlown": 0x80203acc,
		"TNerveNPCMad::execute": 0x80203b28,
		"TNerveNPCMad::theNerve": 0x80203b80,
		"TNerveNPCMad::~TNerveNPCMad": 0x80203be4,
		"TNerveNPCThrow::execute": 0x80203c40,
		"TNerveNPCThrow::theNerve": 0x80203c98,
		"TNerveNPCThrow::~TNerveNPCThrow": 0x80203cfc,
		"TNerveNPCTalk::execute": 0x80203d58,
		"TNerveNPCTalk::theNerve": 0x80203e08,
		"TNerveNPCTalk::~TNerveNPCTalk": 0x80203e6c,
		"TNerveNPCSetPosAfterSinkBottom::execute": 0x80203ec8,
		"TNerveNPCSetPosAfterSinkBottom::theNerve": 0x80203ef0,
		"TNerveNPCSetPosAfterSinkBottom::~TNerveNPCSetPosAfterSinkBottom": 0x80203f54,
		"TNerveNPCRecoverAfter::execute": 0x80203fb0,
		"TNerveNPCRecoverAfter::theNerve": 0x8020401c,
		"TNerveNPCRecoverAfter::~TNerveNPCRecoverAfter": 0x80204080,
		"TNerveNPCRecoverFromSink::execute": 0x802040dc,
		"TNerveNPCRecoverFromSink::theNerve": 0x80204198,
		"TNerveNPCRecoverFromSink::~TNerveNPCRecoverFromSink": 0x802041fc,
		"TNerveNPCSink::execute": 0x80204258,
		"TNerveNPCSink::theNerve": 0x80204280,
		"TNerveNPCSink::~TNerveNPCSink": 0x802042e4,
		"TNerveNPCWet::execute": 0x80204340,
		"TNerveNPCWet::theNerve": 0x80204398,
		"TNerveNPCWet::~TNerveNPCWet": 0x802043fc,
		"TNerveNPCTurnToMario::execute": 0x80204458,
		"TNerveNPCWaitMarioApproach::~TNerveNPCWaitMarioApproach": 0x802047c0,
		"TNerveNPCTurnToMario::theNerve": 0x8020481c,
		"TNerveNPCTurnToMario::~TNerveNPCTurnToMario": 0x80204880,
		"TNerveNPCWaitMarioApproach::execute": 0x802048dc,
		"TNerveNPCWaitMarioApproach::theNerve": 0x80204aa0,
		"TNerveNPCWaitContinue::execute": 0x80204b04,
		"TNerveNPCWaitContinue::theNerve": 0x80204b4c,
		"TNerveNPCWaitContinue::~TNerveNPCWaitContinue": 0x80204bb0,
		"TNerveNPCGraphWait::execute": 0x80204c0c,
		"TNerveNPCGraphWander::~TNerveNPCGraphWander": 0x80204d8c,
		"TNerveNPCGraphWait::theNerve": 0x80204de8,
		"TNerveNPCGraphWait::~TNerveNPCGraphWait": 0x80204e4c,
		"TNerveNPCUTurn::execute": 0x80204ea8,
		"TNerveNPCUTurn::theNerve": 0x80204f84,
		"TNerveNPCUTurn::~TNerveNPCUTurn": 0x80204fe8,
		"TNerveNPCGraphWander::execute": 0x80205044,
		"TGraphTracer::getCurGraphIndex": 0x802053f8,
		"getCurGraphIndex": 0x802053f8,
		"TNerveNPCGraphWander::theNerve": 0x80205400,
		"TNpcParams::TNpcParams": 0x80205464,
		"TNpcSaveIndividual::TNpcSaveIndividual": 0x80205584,
		"TNpcSaveNormal::TNpcSaveNormal": 0x80205db8,
		"TNpcSaveStageFarClip::TNpcSaveStageFarClip": 0x802063b4,
		"TNpcEvent::reviveOneSunflower": 0x80206668,
		"reviveOneSunflower": 0x80206668,
		"NPC::ReviveSunflowerCallBack": 0x802067bc,
		"ReviveSunflowerCallBack": 0x802067bc,
		"TNpcEvent::initDownSunflowerNum": 0x80206844,
		"initDownSunflowerNum": 0x80206844,
		"TNpcEvent::initNpcBuiltin": 0x8020688c,
		"initNpcBuiltin": 0x8020688c,
		"NPC::evCheckMonteClear": 0x80206a3c,
		"evCheckMonteClear": 0x80206a3c,
		"NPC::evIsDemoMode": 0x80206bec,
		"evIsDemoMode": 0x80206bec,
		"NPC::evFireStartDemoCamera": 0x80206cac,
		"evFireStartDemoCamera": 0x80206cac,
		"NPC::evSetFruitType": 0x80206dfc,
		"evSetFruitType": 0x80206dfc,
		"NPC::evGetFruitNum": 0x802070dc,
		"evGetFruitNum": 0x802070dc,
		"NPC::evResetFruitNum": 0x80207310,
		"evResetFruitNum": 0x80207310,
		"NPC::evNpcDanceOffHappyOn": 0x8020744c,
		"evNpcDanceOffHappyOn": 0x8020744c,
		"NPC::evNpcDanceOn": 0x80207598,
		"evNpcDanceOn": 0x80207598,
		"NPC::evSetNpcTalkForbidCount": 0x802076d4,
		"evSetNpcTalkForbidCount": 0x802076d4,
		"NPC::evSetNpcBalloonMessage": 0x802078c0,
		"evSetNpcBalloonMessage": 0x802078c0,
		"NPC::evOnTalkToDummyNpc": 0x80207b64,
		"evOnTalkToDummyNpc": 0x80207b64,
		"NPC::evConnectDummyNpc": 0x80207c5c,
		"evConnectDummyNpc": 0x80207c5c,
		"NPC::ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x80207e1c,
		"ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x80207e1c,
		"NPC::ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x80208000,
		"ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x80208000,
		"NPC::evIsGameModeNormal": 0x80208214,
		"evIsGameModeNormal": 0x80208214,
		"NPC::evIsNpcSinkBottom": 0x802082bc,
		"evIsNpcSinkBottom": 0x802082bc,
		"NPC::evCheckLatestNerve4Npc": 0x8020842c,
		"evCheckLatestNerve4Npc": 0x8020842c,
		"NPC::evCheckCurNerve4Npc": 0x80208600,
		"evCheckCurNerve4Npc": 0x80208600,
		"NPC::evGetAddressFromViewObjName": 0x802087d0,
		"evGetAddressFromViewObjName": 0x802087d0,
		"NPC::__sinit_NpcEvent_cpp": 0x80208924,
		"__sinit_NpcEvent_cpp": 0x80208924,
		"NPC::SMSGetNpcInitData": 0x80208c20,
		"SMSGetNpcInitData": 0x80208c20,
		"NPC::__sinit_NpcInitData_cpp": 0x80208c38,
		"__sinit_NpcInitData_cpp": 0x80208c38,
		"TBaseNPC::setIndividualDifference_": 0x80208c54,
		"setIndividualDifference_": 0x80208c54,
		"TBaseNPC::init": 0x80209538,
		"TNpcInbetween::execMotionBlend": 0x80209c4c,
		"execMotionBlend": 0x80209c4c,
		"TNpcInbetween::execPosInbetween": 0x80209e28,
		"execPosInbetween": 0x80209e28,
		"TNpcParts::partsPerform": 0x80209f04,
		"partsPerform": 0x80209f04,
		"TNpcParts::partsFrameUpdate": 0x8020a0b4,
		"partsFrameUpdate": 0x8020a0b4,
		"TNpcParts::getPartsMActor": 0x8020a11c,
		"getPartsMActor": 0x8020a11c,
		"TNpcParts::setPartsAnmFrame": 0x8020a140,
		"setPartsAnmFrame": 0x8020a140,
		"TNpcParts::addJellyFishParts": 0x8020a2c4,
		"addJellyFishParts": 0x8020a2c4,
		"TNpcParts::TNpcParts": 0x8020a43c,
		"NPC::SMS_InitChangeNpcColor": 0x8020a86c,
		"SMS_InitChangeNpcColor": 0x8020a86c,
		"TBaseNPC::getBasNameTable": 0x8020aa9c,
		"TBaseNPC::kill": 0x8020ac24,
		"TBaseNPC::setPosAndInitAfterSinkBottom": 0x8020ac28,
		"setPosAndInitAfterSinkBottom": 0x8020ac28,
		"TBaseNPC::changeNerveProc_": 0x8020b024,
		"changeNerveProc_": 0x8020b024,
		"TBaseNPC::isNowCanTaken": 0x8020b694,
		"isNowCanTaken": 0x8020b694,
		"TBaseNPC::isStateGoToMad_": 0x8020b7c4,
		"isStateGoToMad_": 0x8020b7c4,
		"TBaseNPC::behaveToSandBomb_": 0x8020b838,
		"behaveToSandBomb_": 0x8020b838,
		"TBaseNPC::behaveToHitObject_": 0x8020ba54,
		"behaveToHitObject_": 0x8020ba54,
		"TBaseNPC::behaveToBeTrampled_": 0x8020bec4,
		"behaveToBeTrampled_": 0x8020bec4,
		"TBaseNPC::behaveToBeTaken_": 0x8020c3cc,
		"behaveToBeTaken_": 0x8020c3cc,
		"TBaseNPC::releaseTaken_": 0x8020c4b4,
		"releaseTaken_": 0x8020c4b4,
		"TBaseNPC::changeNerveToMad_": 0x8020c5a8,
		"changeNerveToMad_": 0x8020c5a8,
		"TBaseNPC::changeNerveFromTalk_": 0x8020c66c,
		"changeNerveFromTalk_": 0x8020c66c,
		"TBaseNPC::isNerveCanGoToMad": 0x8020c854,
		"isNerveCanGoToMad": 0x8020c854,
		"TBaseNPC::isNerveCanGoToTalk": 0x8020c8f8,
		"isNerveCanGoToTalk": 0x8020c8f8,
		"TBaseNPC::isNerveMaybeDontCalcAnim1": 0x8020ca28,
		"isNerveMaybeDontCalcAnim1": 0x8020ca28,
		"TBaseNPC::isNerveMaybeDontCalcAnim0": 0x8020ca9c,
		"isNerveMaybeDontCalcAnim0": 0x8020ca9c,
		"TBaseNPC::isNerveMaybeDontMovement": 0x8020cb04,
		"isNerveMaybeDontMovement": 0x8020cb04,
		"TBaseNPC::isNerveWalk": 0x8020cb78,
		"isNerveWalk": 0x8020cb78,
		"NPC::__sinit_NpcChange_cpp": 0x8020cbec,
		"__sinit_NpcChange_cpp": 0x8020cbec,
		"TNpcThrow::throwMario": 0x8020cee8,
		"TNpcTrample::updateTrample": 0x8020d02c,
		"updateTrample": 0x8020d02c,
		"TNpcTrample::startTrample": 0x8020d120,
		"startTrample": 0x8020d120,
		"TBaseNPC::emitParticle_": 0x8020d180,
		"TBaseNPC::isPolWaitCEffectEmitTime_": 0x8020d8a0,
		"isPolWaitCEffectEmitTime_": 0x8020d8a0,
		"TBaseNPC::emitHappyEffect_": 0x8020d9f0,
		"emitHappyEffect_": 0x8020d9f0,
		"TBaseNPC::emitSinkEffect_": 0x8020db54,
		"emitSinkEffect_": 0x8020db54,
		"TBaseNPC::getEffectScale_": 0x8020dbac,
		"getEffectScale_": 0x8020dbac,
		"NPC::IsCheckPassFrame": 0x8020dc00,
		"IsCheckPassFrame": 0x8020dc00,
		"TBaseNPC::setSmokeEffectMtxPtr_": 0x8020dc8c,
		"setSmokeEffectMtxPtr_": 0x8020dc8c,
		"TBaseNPC::setPollutionEffectMtxPtr_": 0x8020dd18,
		"setPollutionEffectMtxPtr_": 0x8020dd18,
		"TBaseNPC::setNoteEffectMtxPtr_": 0x8020de70,
		"setNoteEffectMtxPtr_": 0x8020de70,
		"TBaseNPC::setHappyEffectMtxPtr_": 0x8020df18,
		"setHappyEffectMtxPtr_": 0x8020df18,
		"NPC::SMSGetNpcInitAnmData": 0x8020e01c,
		"SMSGetNpcInitAnmData": 0x8020e01c,
		"TBaseNPC::setKinoActionFlag_": 0x8020e030,
		"setKinoActionFlag_": 0x8020e030,
		"TBaseNPC::setMareActionFlag_": 0x8020e064,
		"setMareActionFlag_": 0x8020e064,
		"TBaseNPC::setMonteActionFlag_": 0x8020e098,
		"setMonteActionFlag_": 0x8020e098,
		"TNpcCoin::updateCoin": 0x8020e0cc,
		"updateCoin": 0x8020e0cc,
		"TNpcCoin::requestAppearCoin": 0x8020e268,
		"requestAppearCoin": 0x8020e268,
		"TNpcCoin::TNpcCoin": 0x8020e4dc,
		"NPC::__sinit_NpcCoin_cpp": 0x8020e554,
		"__sinit_NpcCoin_cpp": 0x8020e554,
		"TNpcBalloon::updateBalloon": 0x8020e850,
		"updateBalloon": 0x8020e850,
		"TNpcBalloon::setNextMessage": 0x8020e8bc,
		"setNextMessage": 0x8020e8bc,
		"TBaseNPC::isTurnToMarioWhenApproach": 0x8020e8c8,
		"isTurnToMarioWhenApproach": 0x8020e8c8,
		"TBaseNPC::isTurnToMarioWhenTalk": 0x8020e92c,
		"isTurnToMarioWhenTalk": 0x8020e92c,
		"TBaseNPC::isNeedTurnToFirstState": 0x8020e9a0,
		"isNeedTurnToFirstState": 0x8020e9a0,
		"TBaseNPC::execTurnToFirstState": 0x8020ea88,
		"execTurnToFirstState": 0x8020ea88,
		"TBaseNPC::execUTurn": 0x8020eb6c,
		"execUTurn": 0x8020eb6c,
		"TBaseNPC::execWalk": 0x8020ed4c,
		"TBaseNPC::bind": 0x8020f13c,
		"TBaseNPC::setVariableDamageRadius_": 0x8020f354,
		"setVariableDamageRadius_": 0x8020f354,
		"TBaseNPC::execNpcObjCollision_": 0x8020f430,
		"execNpcObjCollision_": 0x8020f430,
		"TBaseNPC::initNpcObjCollision_": 0x8020f75c,
		"initNpcObjCollision_": 0x8020f75c,
		"MAnmSoundNPC::startAnimSound": 0x80012a20,
		"MAnmSound::setSpeedModifySound": 0x80012dd4,
		"MAnmSound::startAnimSound": 0x80012e50,
		"MAnmSound::animeLoop": 0x80012ec8,
		"animeLoop": 0x80012ec8,
		"MAnmSound::initAnmSound": 0x80012f0c,
		"MAnmSound::MAnmSound": 0x80012f2c,
		"MSound::__sinit_MAnmSound_cpp": 0x80012f70,
		"__sinit_MAnmSound_cpp": 0x80012f70,
		"MSound::getMapInfoGround": 0x8001326c,
		"MSound::getSwitch": 0x80013274,
		"getSwitch": 0x80013274,
		"MSound::getBstSwitch": 0x800132d4,
		"getBstSwitch": 0x800132d4,
		"MSound::gateCheck": 0x80013310,
		"MSound::cameraLooksAtMario": 0x80013360,
		"cameraLooksAtMario": 0x80013360,
		"MSound::startSoundActorSpecial": 0x800133b8,
		"startSoundActorSpecial": 0x800133b8,
		"MSound::startBeeSe": 0x80013528,
		"startBeeSe": 0x80013528,
		"MSound::getWallSound": 0x800136d8,
		"getWallSound": 0x800136d8,
		"MSound::checkMarioVoicePlaying": 0x80013738,
		"checkMarioVoicePlaying": 0x80013738,
		"MSound::stopMarioVoice": 0x8001375c,
		"stopMarioVoice": 0x8001375c,
		"MSound::getMarioVoiceID": 0x800137cc,
		"getMarioVoiceID": 0x800137cc,
		"MSound::startMarioVoice": 0x80013804,
		"startMarioVoice": 0x80013804,
		"MSound::playTimer": 0x80013eec,
		"playTimer": 0x80013eec,
		"MSound::setSeExtParameter": 0x80013fd8,
		"MSoundSESystem::MSRandVol::getRandomVolumeNormal": 0x800140c0,
		"getRandomVolumeNormal": 0x800140c0,
		"MSound::stopAllSound": 0x80014114,
		"stopAllSound": 0x80014114,
		"MSound::fadeOutAllSound": 0x800141a4,
		"fadeOutAllSound": 0x800141a4,
		"MSound::resetAudioAll": 0x800142b4,
		"resetAudioAll": 0x800142b4,
		"MSound::setCategoryVOLs": 0x80014388,
		"setCategoryVOLs": 0x80014388,
		"MSound::talkModeOut": 0x80014444,
		"talkModeOut": 0x80014444,
		"MSound::talkModeIn": 0x8001458c,
		"talkModeIn": 0x8001458c,
		"MSound::demoModeOut": 0x80014688,
		"demoModeOut": 0x80014688,
		"MSound::demoModeIn": 0x800147a0,
		"demoModeIn": 0x800147a0,
		"MSound::pauseOff": 0x80014874,
		"pauseOff": 0x80014874,
		"MSound::pauseOn": 0x80014a94,
		"pauseOn": 0x80014a94,
		"MSound::initSound": 0x80014bd8,
		"initSound": 0x80014bd8,
		"MSound::startSoundSetGrp": 0x80014cec,
		"MSound::startSoundSet": 0x80014d78,
		"MSound::mainLoop": 0x80014e04,
		"mainLoop": 0x80014e04,
		"MSound::MSound": 0x80014ecc,
		"JAICamera::JAICamera": 0x80015210,
		"MSound::getDistFromCamera": 0x800152ac,
		"getDistFromCamera": 0x800152ac,
		"MSound::setPlayerInfo": 0x800152d8,
		"setPlayerInfo": 0x800152d8,
		"MSound::setCameraInfo": 0x800153d4,
		"MSound::checkWaveOnAram": 0x80015428,
		"checkWaveOnAram": 0x80015428,
		"MSound::exitStage": 0x8001555c,
		"exitStage": 0x8001555c,
		"MSound::enterStage": 0x8001569c,
		"enterStage": 0x8001569c,
		"MSound::loadWave": 0x800156f8,
		"MSound::loadGroupWave": 0x80015748,
		"MSound::setRegisterTrackCallback": 0x8001580c,
		"MSound::makeSound": 0x80015834,
		"MSHandle::MSHandle": 0x800158c8,
		"MSSeCallBack::setParameterSeqSync": 0x80015904,
		"MSSeCallBack::setWaterCameraFir": 0x80015e10,
		"setWaterCameraFir": 0x80015e10,
		"MSound::__sinit_MSound_cpp": 0x800162a8,
		"__sinit_MSound_cpp": 0x800162a8,
		"MSBgm::setStageBgmYoshiPercussion": 0x800165a4,
		"setStageBgmYoshiPercussion": 0x800165a4,
		"MSBgm::setDolby": 0x80016658,
		"MSBgm::setPan": 0x800166a0,
		"MSBgm::setVolume": 0x800166e8,
		"MSBgm::setTrackVolume": 0x80016754,
		"setTrackVolume": 0x80016754,
		"MSBgm::stopTrackBGMs": 0x8001679c,
		"stopTrackBGMs": 0x8001679c,
		"MSBgm::stopTrackBGM": 0x80016848,
		"stopTrackBGM": 0x80016848,
		"MSBgm::stopBGM": 0x800168c8,
		"stopBGM": 0x800168c8,
		"MSBgm::getHandle": 0x800169a8,
		"getHandle": 0x800169a8,
		"MSBgm::startBGM": 0x800169d4,
		"startBGM": 0x800169d4,
		"MSBgm::getSceneNo": 0x80016b1c,
		"getSceneNo": 0x80016b1c,
		"MSBgm::init": 0x80016cbc,
		"JALList<MSBgm>::JALList": 0x80016d44,
		"JALList": 0x80016d44,
		"JALListS<MSBgm,unsigned_long><MSBgm,unsigned_long>::search": 0x80016da0,
		"MSound::__sinit_MSoundBGM_cpp": 0x80016dd4,
		"__sinit_MSoundBGM_cpp": 0x80016dd4,
		"JADPrm<unsigned_char><unsigned_char>::JADPrm": 0x800170d0,
		"MSound::__sinit_MSoundDebug_cpp": 0x800170d8,
		"__sinit_MSoundDebug_cpp": 0x800170d8,
		"MSSceneSE::sortMaxTrans": 0x800173d4,
		"sortMaxTrans": 0x800173d4,
		"MSSceneSE::frameLoop": 0x800175a8,
		"frameLoop": 0x800175a8,
		"MSSceneSE::MSSceneSE": 0x800179c0,
		"MSound::__sinit_MSoundScene_cpp": 0x80017b3c,
		"__sinit_MSoundScene_cpp": 0x80017b3c,
		"MSoundSESystem::MSoundSE::checkMonoSound": 0x80017e38,
		"checkMonoSound": 0x80017e38,
		"MSoundSESystem::MSoundSE::startSoundNpcActor": 0x80017f0c,
		"startSoundNpcActor": 0x80017f0c,
		"MSoundSESystem::MSoundSE::getNewIDBySurfaceCode": 0x8001801c,
		"getNewIDBySurfaceCode": 0x8001801c,
		"MSoundSESystem::MSoundSE::startSoundActorInner": 0x80018134,
		"startSoundActorInner": 0x80018134,
		"MSoundSESystem::MSoundSE::checkSoundArea": 0x800184f4,
		"checkSoundArea": 0x800184f4,
		"MSoundSESystem::MSoundSE::startSoundActorWithInfo": 0x80018650,
		"startSoundActorWithInfo": 0x80018650,
		"MSoundSESystem::MSoundSE::startSoundSystemSE": 0x800188c0,
		"MSoundSESystem::MSoundSE::startSoundActor": 0x80018a30,
		"MSoundSESystem::MSoundSE::getRandomID": 0x80018a70,
		"getRandomID": 0x80018a70,
		"MSoundSESystem::MSoundSE::construct": 0x80018cdc,
		"construct": 0x80018cdc,
		"MSoundSESystem::MSRandPlay::randPlay": 0x80019fe8,
		"randPlay": 0x80019fe8,
		"MSoundSESystem::MSRandPlay::MSRandPlay": 0x8001a1ac,
		"MSoundSESystem::MSRandPlay::startSeRandPlay": 0x8001a24c,
		"startSeRandPlay": 0x8001a24c,
		"MSoundSESystem::MSRandPlayVec::~MSRandPlayVec": 0x8001a2ac,
		"MSoundSESystem::MSRandPlayVec::MSRandPlayVec": 0x8001a30c,
		"MSoundSESystem::MSRandPlay::createRandPlayVec": 0x8001a364,
		"createRandPlayVec": 0x8001a364,
		"MSoundSESystem::MSRandPlay::registerTrans": 0x8001a408,
		"registerTrans": 0x8001a408,
		"MSoundSESystem::MSRandVol::getRandVol": 0x8001a45c,
		"getRandVol": 0x8001a45c,
		"MSoundSESystem::MSRandVol::MSRandVol": 0x8001a4d8,
		"MSound::__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x8001a580,
		"__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x8001a580,
		"MSSetSoundTL<MSSetSoundGrp>::MSSetSoundTL": 0x8001a5f0,
		"JALListFrameLoop<MSSetSoundGrp>::frameLoopDyna": 0x8001a848,
		"MSound::__ct__9JADPrm<l>FlPCc": 0x8001a84c,
		"__ct__9JADPrm<l>FlPCc": 0x8001a84c,
		"MSound::__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x8001a85c,
		"__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x8001a85c,
		"MSound::__sinit_MSoundSE_cpp": 0x8001a8b0,
		"__sinit_MSoundSE_cpp": 0x8001a8b0,
		"JSUList<MSoundSESystem::MSRandPlay>::~JSUList": 0x8001ac08,
		"JSUList<MSoundSESystem::MSRandVol>::~JSUList": 0x8001ac60,
		"MSSetSoundGrp::startSoundSetGrp": 0x8001acc0,
		"MSSetSound::startSoundSet": 0x8001ad60,
		"MSSetSound::init": 0x8001aec4,
		"JALListGrp<MSSetSoundGrp,unsigned_long,MSSetSoundMember><MSSetSoundGrp,unsigned_long,MSSetSoundMember>::searchGroup": 0x8001b454,
		"MSSetSoundTL<MSSetSound>::startSoundSetDyna": 0x8001b4b0,
		"JALListD<MSSetSoundMember,unsigned_long><MSSetSoundMember,unsigned_long>::searchD": 0x8001bbfc,
		"searchD": 0x8001bbfc,
		"MSSetSoundTL<MSSetSound>::MSSetSoundTL": 0x8001bc28,
		"MSSetSoundTL<MSSetSoundGrp>::startSoundSetDyna": 0x8001be80,
		"JALListFrameLoop<MSSetSound>::frameLoopDyna": 0x8001c5cc,
		"MSound::__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x8001c5d0,
		"__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x8001c5d0,
		"MSound::__sinit_MSoundStruct_cpp": 0x8001c624,
		"__sinit_MSoundStruct_cpp": 0x8001c624,
		"MSHandle::calcVolume": 0x8001c928,
		"calcVolume": 0x8001c928,
		"MSHandle::setDistanceVolumeCommon": 0x8001ca08,
		"MSHandle::setSeDistanceVolume": 0x8001caac,
		"MSHandle::calcDolby": 0x8001cba4,
		"calcDolby": 0x8001cba4,
		"MSHandle::setSeDistanceDolby": 0x8001cc94,
		"MSHandle::calcPan": 0x8001cce8,
		"MSHandle::setSeDistancePan": 0x8001ce08,
		"MSHandle::setSeDistancePitch": 0x8001cea8,
		"MSHandle::setSeDistanceParameters": 0x8001cfbc,
		"MSHandle::MSACos": 0x8001d10c,
		"MSACos": 0x8001d10c,
		"MSound::__sinit_MSHandle_cpp": 0x8001d168,
		"__sinit_MSHandle_cpp": 0x8001d168,
		"MSBgmXFade::xFadeBgmForce": 0x8001d464,
		"xFadeBgmForce": 0x8001d464,
		"MSBgmXFade::xFadeBgm": 0x8001d540,
		"xFadeBgm": 0x8001d540,
		"MSModBgm::changeTempo": 0x8001d650,
		"changeTempo": 0x8001d650,
		"MSModBgm::loop": 0x8001d6d8,
		"loop": 0x8001d6d8,
		"MSModBgm::modBgm": 0x8001d714,
		"modBgm": 0x8001d714,
		"MSound::__sinit_MSModBgm_cpp": 0x8001d810,
		"__sinit_MSModBgm_cpp": 0x8001d810,
		"TWoodBarrel::getFlushTime": 0x801a6a94,
		"TMapObjGeneral::getLivingTime": 0x801a6a9c,
		"TMapObjGeneral::checkIllegalAttr": 0x801a6aa4,
		"TWoodBarrel::TWoodBarrel": 0x801a6aa8,
		"TWoodBarrel::load": 0x801a6b78,
		"TWoodBarrel::loadAfter": 0x801a6bd0,
		"TWoodBarrel::control": 0x801a6c38,
		"TWoodBarrel::receiveMessage": 0x801a6cdc,
		"TWoodBarrel::touchActor": 0x801a6d1c,
		"TWoodBarrel::touchPlayer": 0x801a6de8,
		"TWoodBarrel::touchGround": 0x801a6e34,
		"TWoodBarrel::touchWall": 0x801a6eb8,
		"TWoodBarrel::appear": 0x801a6ee4,
		"TWoodBarrel::appeared": 0x801a6f64,
		"TWoodBarrel::kill": 0x801a7018,
		"TWoodBarrel::breaking": 0x801a70c0,
		"TWoodBarrel::hold": 0x801a7140,
		"TWoodBarrel::put": 0x801a7198,
		"MoveBG::__sinit_WoodBarrel_cpp": 0x801a725c,
		"__sinit_WoodBarrel_cpp": 0x801a725c,
		"TMapObjBase::TMapObjBase": 0x801a7560,
		"TMapObjBase::load": 0x801a7608,
		"TMapObjBase::loadAfter": 0x801a76ec,
		"TMapObjBase::initAndRegister": 0x801a772c,
		"initAndRegister": 0x801a772c,
		"TMapObjBase::receiveMessage": 0x801a77fc,
		"TMapObjBase::calcRootMatrix": 0x801a7858,
		"TMapObjBase::getRootJointMtx": 0x801a7904,
		"TMapObjBase::getShadowType": 0x801a7938,
		"TMapObjBase::perform": 0x801a7a00,
		"TMapObjBase::setGroundCollision": 0x801a7e2c,
		"TMapObjBase::control": 0x801a7fb0,
		"TMapObjBase::ensureTakeSituation": 0x801a8128,
		"TMapObjBase::touchActor": 0x801a8188,
		"TMapObjBase::touchPlayer": 0x801a8234,
		"TMapObjBase::touchEnemy": 0x801a8270,
		"TMapObjBase::touchBoss": 0x801a82ac,
		"touchBoss": 0x801a82ac,
		"TMapObjBase::makeObjAppeared": 0x801a82e8,
		"TMapObjBase::makeObjDead": 0x801a85f0,
		"TMapObjBase::makeObjDefault": 0x801a87ac,
		"TMapObjBase::startAnim": 0x801a888c,
		"startAnim": 0x801a888c,
		"TMapObjBase::startBck": 0x801a8a80,
		"startBck": 0x801a8a80,
		"TMapObjBase::startControlAnim": 0x801a8ab0,
		"startControlAnim": 0x801a8ab0,
		"TMapObjBase::animIsFinished": 0x801a8b2c,
		"animIsFinished": 0x801a8b2c,
		"TMapObjBase::hasAnim": 0x801a8bac,
		"hasAnim": 0x801a8bac,
		"TMapObjBase::hasModelOrAnimData": 0x801a8bf4,
		"hasModelOrAnimData": 0x801a8bf4,
		"TMapObjBase::startSound": 0x801a8c48,
		"startSound": 0x801a8c48,
		"TMapObjBase::soundBas": 0x801a8d40,
		"soundBas": 0x801a8d40,
		"TMapObjBase::setUpMapCollision": 0x801a8de4,
		"setUpMapCollision": 0x801a8de4,
		"TMapObjBase::setUpCurrentMapCollision": 0x801a8f10,
		"setUpCurrentMapCollision": 0x801a8f10,
		"TMapObjBase::removeMapCollision": 0x801a8fe8,
		"removeMapCollision": 0x801a8fe8,
		"TMapObjBase::setObjHitData": 0x801a9044,
		"setObjHitData": 0x801a9044,
		"TMapObjBase::sleep": 0x801a90f0,
		"TMapObjBase::awake": 0x801a9164,
		"TMapObjBase::getSDLModelFlag": 0x801a91a8,
		"TMapObjBase::changeObjSRT": 0x801a91b0,
		"changeObjSRT": 0x801a91b0,
		"TMapObjBase::changeObjMtx": 0x801a9220,
		"changeObjMtx": 0x801a9220,
		"MoveBG::__sinit_MapObjBase_cpp": 0x801a9318,
		"__sinit_MapObjBase_cpp": 0x801a9318,
		"TMapObjGeneral::getFlushTime": 0x801a961c,
		"TMapObjManager::initKeyCode": 0x801a9624,
		"initKeyCode": 0x801a9624,
		"TMapObjGeneral::initMapObj": 0x801a9694,
		"TMapObjBase::initMapObj": 0x801a96dc,
		"TMapObjBase::initActorData": 0x801a9988,
		"initActorData": 0x801a9988,
		"TMapObjBase::initModelData": 0x801a9aec,
		"initModelData": 0x801a9aec,
		"TMapObjBase::makeMActors": 0x801a9c1c,
		"TMapObjBase::initMActor": 0x801a9f28,
		"initMActor": 0x801a9f28,
		"TMapObjBase::initBckMoveData": 0x801a9fd4,
		"initBckMoveData": 0x801a9fd4,
		"TMapObjBase::initObjCollisionData": 0x801aa0bc,
		"initObjCollisionData": 0x801aa0bc,
		"TMapObjBase::initMapCollisionData": 0x801aa244,
		"TMapObjBase::checkIllegalAttr": 0x801aa300,
		"TMapObjBase::initUnique": 0x801aa304,
		"MoveBG::__sinit_MapObjInit_cpp": 0x801aab48,
		"__sinit_MapObjInit_cpp": 0x801aab48,
		"TMapObjGeneral::TMapObjGeneral": 0x801aae4c,
		"TMapObjGeneral::loadAfter": 0x801aaea8,
		"TMapObjGeneral::receiveMessage": 0x801aaf14,
		"TMapObjGeneral::perform": 0x801ab21c,
		"TMapObjGeneral::calcRootMatrix": 0x801ab314,
		"TMapObjGeneral::control": 0x801ab4b0,
		"TMapObjGeneral::bind": 0x801ab570,
		"TMapObjGeneral::calcVelocity": 0x801ab7f0,
		"TMapObjGeneral::checkGroundCollision": 0x801ab994,
		"TMapObjGeneral::touchGround": 0x801aba44,
		"TMapObjGeneral::checkRoofCollision": 0x801abc1c,
		"checkRoofCollision": 0x801abc1c,
		"TMapObjGeneral::touchRoof": 0x801abca8,
		"TMapObjGeneral::checkWallCollision": 0x801abcb4,
		"TMapObjGeneral::touchWall": 0x801abd9c,
		"TMapObjGeneral::work": 0x801abde4,
		"work": 0x801abde4,
		"TMapObjGeneral::appear": 0x801abed4,
		"TMapObjGeneral::kill": 0x801abfcc,
		"TMapObjGeneral::ensureTakeSituation": 0x801ac04c,
		"TMapObjGeneral::hold": 0x801ac0b8,
		"TMapObjGeneral::recover": 0x801ac12c,
		"recover": 0x801ac12c,
		"TMapObjGeneral::touchPlayer": 0x801ac234,
		"TMapObjGeneral::touchWater": 0x801ac288,
		"TMapObjGeneral::receiveMessageFromPlayer": 0x801ac304,
		"receiveMessageFromPlayer": 0x801ac304,
		"TMapObjGeneral::makeObjBuried": 0x801ac328,
		"makeObjBuried": 0x801ac328,
		"TMapObjGeneral::makeObjRecovered": 0x801ac394,
		"makeObjRecovered": 0x801ac394,
		"TMapObjGeneral::appeared": 0x801ac3e0,
		"TMapObjGeneral::appearing": 0x801ac438,
		"TMapObjGeneral::breaking": 0x801ac4fc,
		"TMapObjGeneral::sinking": 0x801ac57c,
		"sinking": 0x801ac57c,
		"TMapObjGeneral::recovering": 0x801ac69c,
		"recovering": 0x801ac69c,
		"TMapObjGeneral::holding": 0x801ac7b0,
		"holding": 0x801ac7b0,
		"TMapObjGeneral::touchingPlayer": 0x801ac808,
		"touchingPlayer": 0x801ac808,
		"TMapObjGeneral::touchingWater": 0x801ac85c,
		"touchingWater": 0x801ac85c,
		"TMapObjGeneral::thrown": 0x801ac8b0,
		"TMapObjGeneral::put": 0x801aca94,
		"TMapObjGeneral::sink": 0x801acba4,
		"sink": 0x801acba4,
		"TMapObjGeneral::waitToAppear": 0x801acc0c,
		"waitToAppear": 0x801acc0c,
		"TMapObjGeneral::waitingToRecover": 0x801acc30,
		"waitingToRecover": 0x801acc30,
		"TMapObjGeneral::waitingToAppear": 0x801acc88,
		"TMapObjGeneral::isPollutedGround": 0x801acde8,
		"isPollutedGround": 0x801acde8,
		"MoveBG::__sinit_MapObjGeneral_cpp": 0x801acedc,
		"__sinit_MapObjGeneral_cpp": 0x801acedc,
		"TMapObjBaseManager::~TMapObjBaseManager": 0x801ad1d8,
		"TMapObjBaseManager::TMapObjBaseManager": 0x801ad26c,
		"TMapObjBaseManager::load": 0x801ad2b4,
		"TMapObjBaseManager::getObjNumWithActorType": 0x801ad30c,
		"getObjNumWithActorType": 0x801ad30c,
		"TMapObjBaseManager::createModelData": 0x801ad360,
		"TMapObjBaseManager::clipActors": 0x801ad394,
		"TMapObjBaseManager::getActorTypeByEventID": 0x801ad3c8,
		"getActorTypeByEventID": 0x801ad3c8,
		"TMapObjBaseManager::newAndRegisterObjByEventID": 0x801ad4c8,
		"newAndRegisterObjByEventID": 0x801ad4c8,
		"TMapObjBaseManager::newAndRegisterObj": 0x801adb3c,
		"newAndRegisterObj": 0x801adb3c,
		"MoveBG::newUniqueObjByName": 0x801adc68,
		"newUniqueObjByName": 0x801adc68,
		"MoveBG::newItemByName": 0x801aeb78,
		"newItemByName": 0x801aeb78,
		"TMapObjBaseManager::makeObjAppeared": 0x801aec0c,
		"TMapObjManager::TMapObjManager": 0x801aef54,
		"TMapObjManager::load": 0x801af084,
		"TMapObjManager::loadAfter": 0x801af544,
		"TMapObjManager::entryStaticDrawBufferSun": 0x801af720,
		"entryStaticDrawBufferSun": 0x801af720,
		"TMapObjManager::entryStaticDrawBufferShadow": 0x801af770,
		"entryStaticDrawBufferShadow": 0x801af770,
		"TMerryPole::getRootJointMtx": 0x801af844,
		"TMapObjManager::~TMapObjManager": 0x801af84c,
		"TMapObjManager::hasMapCollision": 0x801af8e0,
		"MoveBG::__sinit_MapObjManager_cpp": 0x801af8e8,
		"__sinit_MapObjManager_cpp": 0x801af8e8,
		"TMapObjTurn::TMapObjTurn": 0x801afc88,
		"TMapObjTurn::initMapObj": 0x801afd74,
		"TMapObjTurn::loadAfter": 0x801afde4,
		"TMapObjTurn::receiveMessage": 0x801afe24,
		"TMapObjTurn::control": 0x801afec0,
		"TMapObjTurn::turn": 0x801b0448,
		"turn": 0x801b0448,
		"TMapObjTurn::touchWater": 0x801b053c,
		"TMapObjMessenger::TMapObjMessenger": 0x801b06d0,
		"TMapObjMessenger::receiveMessage": 0x801b071c,
		"TMapObjLibWave::TMapObjLibWave": 0x801b074c,
		"TMapObjLibWave::movement": 0x801b07f4,
		"TMapObjLibWave::getCurrentHeight": 0x801b084c,
		"getCurrentHeight": 0x801b084c,
		"TMapObjLibWave::push": 0x801b0884,
		"TMapObjBase::emitAndBindScale": 0x801b0928,
		"emitAndBindScale": 0x801b0928,
		"TMapObjBase::emitAndRotateScale": 0x801b0a1c,
		"emitAndRotateScale": 0x801b0a1c,
		"TMapObjBase::emitAndSRT": 0x801b0b0c,
		"emitAndSRT": 0x801b0b0c,
		"TMapObjBase::emitColumnWater": 0x801b0bec,
		"emitColumnWater": 0x801b0bec,
		"TMapObjBase::marioHipAttack": 0x801b0c40,
		"marioHipAttack": 0x801b0c40,
		"TMapObjBase::marioHeadAttack": 0x801b0cb0,
		"marioHeadAttack": 0x801b0cb0,
		"TMapObjBase::sendMsg": 0x801b0db4,
		"sendMsg": 0x801b0db4,
		"TMapObjBase::waterHitPlane": 0x801b0e44,
		"waterHitPlane": 0x801b0e44,
		"TMapObjBase::getWaterPos": 0x801b0ed0,
		"getWaterPos": 0x801b0ed0,
		"TMapObjBase::getWaterSpeed": 0x801b0ee8,
		"getWaterSpeed": 0x801b0ee8,
		"TMapObjBase::getWaterPlane": 0x801b0f00,
		"getWaterPlane": 0x801b0f00,
		"TMapObjBase::getWaterID": 0x801b0f18,
		"getWaterID": 0x801b0f18,
		"TMapObjBase::getDistance": 0x801b0f20,
		"getDistance": 0x801b0f20,
		"TMapObjBase::getDistanceXZ": 0x801b0f9c,
		"getDistanceXZ": 0x801b0f9c,
		"TMapObjBase::getRotYFromAxisZ": 0x801b1000,
		"getRotYFromAxisZ": 0x801b1000,
		"TMapObjBase::getRotYFromAxisX": 0x801b103c,
		"getRotYFromAxisX": 0x801b103c,
		"TMapObjBase::makeVecToLocalZ": 0x801b1078,
		"makeVecToLocalZ": 0x801b1078,
		"TMapObjBase::getNormalVecFromTarget": 0x801b10e4,
		"getNormalVecFromTarget": 0x801b10e4,
		"TMapObjBase::getNormalVecFromTargetXZ": 0x801b1128,
		"getNormalVecFromTargetXZ": 0x801b1128,
		"TMapObjBase::rotateVecByAxisY": 0x801b116c,
		"rotateVecByAxisY": 0x801b116c,
		"TMapObjBase::getVerticalVecToTargetXZ": 0x801b1388,
		"getVerticalVecToTargetXZ": 0x801b1388,
		"JGeometry::SMatrix33C<float><float>::at": 0x801b14f4,
		"at": 0x801b14f4,
		"JGeometry::SMatrix33C<float><float>::SMatrix33C": 0x801b1508,
		"SMatrix33C": 0x801b1508,
		"TMapObjBase::calcReflectingVelocity": 0x801b150c,
		"calcReflectingVelocity": 0x801b150c,
		"TMapObjBase::makeObjMtxRotByAxis": 0x801b1578,
		"makeObjMtxRotByAxis": 0x801b1578,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setRotate": 0x801b170c,
		"TMapObjBase::makeMtxRotByAxis": 0x801b1860,
		"makeMtxRotByAxis": 0x801b1860,
		"TMapObjBase::concatOnlyRotFromRight": 0x801b1a04,
		"concatOnlyRotFromRight": 0x801b1a04,
		"TMapObjBase::concatOnlyRotFromLeft": 0x801b1a70,
		"concatOnlyRotFromLeft": 0x801b1a70,
		"TMapObjBase::updateObjMtx": 0x801b1adc,
		"updateObjMtx": 0x801b1adc,
		"TMapObjBase::updateRootMtxTrans": 0x801b1b94,
		"updateRootMtxTrans": 0x801b1b94,
		"TMapObjBase::makeRootMtxRotX": 0x801b1be4,
		"makeRootMtxRotX": 0x801b1be4,
		"TMapObjBase::setRootMtxRotY": 0x801b1c94,
		"setRootMtxRotY": 0x801b1c94,
		"TMapObjBase::makeRootMtxRotY": 0x801b1d48,
		"makeRootMtxRotY": 0x801b1d48,
		"TMapObjBase::setRootMtxRotZ": 0x801b1df8,
		"setRootMtxRotZ": 0x801b1df8,
		"TMapObjBase::makeRootMtxRotZ": 0x801b1eac,
		"makeRootMtxRotZ": 0x801b1eac,
		"TMapObjBase::makeLowerStr": 0x801b1f5c,
		"makeLowerStr": 0x801b1f5c,
		"TMapObjBase::moveJoint": 0x801b1fb0,
		"moveJoint": 0x801b1fb0,
		"TMapObjBase::getJointTransX": 0x801b2020,
		"getJointTransX": 0x801b2020,
		"TMapObjBase::getJointTransZ": 0x801b2028,
		"getJointTransZ": 0x801b2028,
		"TMapObjBase::setJointTransX": 0x801b2030,
		"setJointTransX": 0x801b2030,
		"TMapObjBase::setJointTransY": 0x801b2080,
		"setJointTransY": 0x801b2080,
		"TMapObjBase::setJointTransZ": 0x801b20d0,
		"setJointTransZ": 0x801b20d0,
		"TMapObjBase::getJointScaleY": 0x801b2120,
		"getJointScaleY": 0x801b2120,
		"TMapObjBase::setJointScaleY": 0x801b2128,
		"setJointScaleY": 0x801b2128,
		"TMapObjBase::calcMap": 0x801b2178,
		"calcMap": 0x801b2178,
		"TMapObjBase::getBuildingJointObj": 0x801b21b8,
		"getBuildingJointObj": 0x801b21b8,
		"TMapObjBase::getBuildingJoint": 0x801b21e0,
		"getBuildingJoint": 0x801b21e0,
		"TMapObjBase::newAndInitBuildingCollisionMove": 0x801b220c,
		"newAndInitBuildingCollisionMove": 0x801b220c,
		"TMapObjBase::newAndInitBuildingCollisionWarp": 0x801b22a0,
		"newAndInitBuildingCollisionWarp": 0x801b22a0,
		"TMapObjBase::joinToGroup": 0x801b2334,
		"joinToGroup": 0x801b2334,
		"TMapObjBase::startAllAnim": 0x801b23d8,
		"startAllAnim": 0x801b23d8,
		"TMapObjBase::initPacketMatColor": 0x801b2508,
		"initPacketMatColor": 0x801b2508,
		"TMapObjBase::isFruit": 0x801b2584,
		"isFruit": 0x801b2584,
		"TMapObjBase::isCoin": 0x801b2658,
		"isCoin": 0x801b2658,
		"TMapObjBase::throwObjFromPointWithRot": 0x801b26cc,
		"throwObjFromPointWithRot": 0x801b26cc,
		"TMapObjBase::throwObjToFrontFromPoint": 0x801b2790,
		"throwObjToFrontFromPoint": 0x801b2790,
		"TMapObjBase::throwObjToFront": 0x801b28a4,
		"throwObjToFront": 0x801b28a4,
		"TMapObjBase::checkOnManhole": 0x801b29bc,
		"checkOnManhole": 0x801b29bc,
		"TMapObjBase::loadHideObjInfo": 0x801b2a44,
		"loadHideObjInfo": 0x801b2a44,
		"TMapObjBase::isDemo": 0x801b2b20,
		"isDemo": 0x801b2b20,
		"TMapObjBase::isHideObj": 0x801b2b78,
		"isHideObj": 0x801b2b78,
		"MoveBG::__sinit_MapObjLib_cpp": 0x801b2d10,
		"__sinit_MapObjLib_cpp": 0x801b2d10,
		"TNozzleBox::TNozzleBox": 0x801b30b8,
		"TNozzleBox::load": 0x801b313c,
		"TNozzleBox::loadAfter": 0x801b3354,
		"TNozzleBox::control": 0x801b352c,
		"TNozzleBox::touchPlayer": 0x801b3584,
		"TNozzleBox::receiveMessage": 0x801b364c,
		"TNozzleBox::breaking": 0x801b37bc,
		"TNozzleBox::makeModelValid": 0x801b3804,
		"makeModelValid": 0x801b3804,
		"TItemNozzle::load": 0x801b3894,
		"TItemNozzle::initMapObj": 0x801b3958,
		"TItemNozzle::control": 0x801b3aa4,
		"TItemNozzle::appearing": 0x801b3ac4,
		"TItemNozzle::receiveMessage": 0x801b3ae8,
		"TItemNozzle::put": 0x801b3bac,
		"TItemNozzle::touchPlayer": 0x801b3bc4,
		"TEggYoshi::TEggYoshi": 0x801b3d54,
		"TEggYoshi::load": 0x801b3da8,
		"TEggYoshi::receiveMessage": 0x801b3fe4,
		"TEggYoshi::startFruit": 0x801b4250,
		"startFruit": 0x801b4250,
		"TEggYoshi::perform": 0x801b4320,
		"TEggYoshi::control": 0x801b4460,
		"TEggYoshi::touchActor": 0x801b467c,
		"TEggYoshi::touchFruit": 0x801b4750,
		"TEggYoshi::decideRandomLoveFruit": 0x801b48d4,
		"decideRandomLoveFruit": 0x801b48d4,
		"TShine::TShine": 0x801b4a0c,
		"TShine::loadBeforeInit": 0x801b4ad0,
		"TShine::loadAfter": 0x801b4bc0,
		"TShine::initMapObj": 0x801b4c28,
		"TShine::makeMActors": 0x801b4c8c,
		"TShine::kill": 0x801b4d88,
		"TShine::appearWithDemo": 0x801b4dbc,
		"appearWithDemo": 0x801b4dbc,
		"TShine::appearSimple": 0x801b4e68,
		"appearSimple": 0x801b4e68,
		"TShine::appearWithTimeCallback": 0x801b4f70,
		"appearWithTimeCallback": 0x801b4f70,
		"TShine::appearWithTime": 0x801b4fd8,
		"appearWithTime": 0x801b4fd8,
		"TShine::touchPlayer": 0x801b51ec,
		"TShine::receiveMessage": 0x801b5294,
		"TShine::perform": 0x801b5448,
		"TShine::control": 0x801b54a8,
		"TShine::movingCircle": 0x801b5af0,
		"movingCircle": 0x801b5af0,
		"TShine::calc": 0x801b5c60,
		"TCoinBlue::TCoinBlue": 0x801b5f40,
		"TCoinBlue::load": 0x801b605c,
		"TCoinBlue::loadBeforeInit": 0x801b60c8,
		"TCoinBlue::taken": 0x801b611c,
		"TCoinBlue::makeObjAppeared": 0x801b61e8,
		"TCoinRed::TCoinRed": 0x801b6250,
		"TCoinRed::taken": 0x801b62e0,
		"TCoinEmpty::TCoinEmpty": 0x801b63e0,
		"TCoinEmpty::kill": 0x801b6460,
		"TCoinEmpty::makeObjAppeared": 0x801b6464,
		"TCoinEmpty::appear": 0x801b6468,
		"TFlowerCoin::load": 0x801b646c,
		"TCoin::TCoin": 0x801b64c0,
		"TCoin::initMapObj": 0x801b652c,
		"TCoin::loadAfter": 0x801b659c,
		"TCoin::perform": 0x801b6684,
		"TCoin::makeObjAppeared": 0x801b68e4,
		"TCoin::appear": 0x801b6928,
		"TCoin::appearWithoutSound": 0x801b6a60,
		"appearWithoutSound": 0x801b6a60,
		"TCoin::makeObjDead": 0x801b6afc,
		"TCoin::taken": 0x801b6b40,
		"TItem::TItem": 0x801b6ccc,
		"TItem::load": 0x801b6d20,
		"TItem::initMapObj": 0x801b6d58,
		"TItem::perform": 0x801b6d94,
		"TItem::appear": 0x801b6e20,
		"TItem::killByTimer": 0x801b6e6c,
		"TItem::appearing": 0x801b6ea0,
		"TItem::calc": 0x801b6f84,
		"TItem::calcRootMatrix": 0x801b70fc,
		"TItem::receiveMessage": 0x801b7128,
		"TItem::touchPlayer": 0x801b7178,
		"TItem::taken": 0x801b71f4,
		"TItem::appeared": 0x801b7280,
		"TEggYoshi::getHitObjNumMax": 0x801b74ac,
		"MoveBG::__sinit_Item_cpp": 0x801b77c0,
		"__sinit_Item_cpp": 0x801b77c0,
		"TItemManager::~TItemManager": 0x801b7b0c,
		"TItemManager::hasMapCollision": 0x801b7ba0,
		"TItemManager::TItemManager": 0x801b7ba8,
		"TItemManager::load": 0x801b7c34,
		"TItemManager::loadAfter": 0x801b7cb4,
		"TItemManager::newAndRegisterCoinReal": 0x801b7d88,
		"newAndRegisterCoinReal": 0x801b7d88,
		"TItemManager::perform": 0x801b7dd8,
		"TItemManager::newAndRegisterCoin": 0x801b7e9c,
		"newAndRegisterCoin": 0x801b7e9c,
		"TItemManager::makeShineAppearWithDemoOffset": 0x801b7f84,
		"makeShineAppearWithDemoOffset": 0x801b7f84,
		"TItemManager::makeShineAppearWithDemo": 0x801b8044,
		"makeShineAppearWithDemo": 0x801b8044,
		"TItemManager::makeShineAppearWithTime": 0x801b80ec,
		"makeShineAppearWithTime": 0x801b80ec,
		"TItemManager::resetNozzleBoxesModel": 0x801b819c,
		"resetNozzleBoxesModel": 0x801b819c,
		"MoveBG::__sinit_ItemManager_cpp": 0x801b827c,
		"__sinit_ItemManager_cpp": 0x801b827c,
		"TBasketReverse::initMapObj": 0x801b85fc,
		"TBasketReverse::kill": 0x801b862c,
		"TRedCoinSwitch::TRedCoinSwitch": 0x801b86e4,
		"TRedCoinSwitch::load": 0x801b8744,
		"TRedCoinSwitch::loadAfter": 0x801b87f8,
		"TRedCoinSwitch::control": 0x801b889c,
		"TRedCoinSwitch::receiveMessage": 0x801b8954,
		"TMapObjSwitch::TMapObjSwitch": 0x801b8a14,
		"TMapObjSwitch::load": 0x801b8aa8,
		"TMapObjSwitch::receiveMessage": 0x801b8bb0,
		"TMapObjSwitch::control": 0x801b8cd0,
		"THideObjInfo::THideObjInfo": 0x801b8d28,
		"THideObjInfo::load": 0x801b8e38,
		"THideObjInfo::action": 0x801b8eb4,
		"TMapObjWaterSpray::TMapObjWaterSpray": 0x801b8f54,
		"TMapObjWaterSpray::load": 0x801b8fd0,
		"TMapObjWaterSpray::calc": 0x801b918c,
		"TDamageObj::load": 0x801b929c,
		"TDamageObj::init": 0x801b93b8,
		"TDamageObj::perform": 0x801b9428,
		"TMapObjStartDemo::load": 0x801b9480,
		"TMapObjStartDemo::touchPlayer": 0x801b94d0,
		"TMapObjChangeStageHipDrop::initMapObj": 0x801b9500,
		"TMapObjChangeStageHipDrop::touchPlayer": 0x801b955c,
		"TMapObjChangeStage::load": 0x801b95d8,
		"TMapObjChangeStage::touchPlayer": 0x801b9628,
		"TMapObjBillboard::touchWater": 0x801b96a4,
		"TMapObjBillboard::touchActor": 0x801b98b0,
		"TManhole::TManhole": 0x801b9998,
		"TManhole::initMapObj": 0x801b9a04,
		"TManhole::loadAfter": 0x801b9a78,
		"TManhole::makeManholeUnuseful": 0x801b9ab8,
		"makeManholeUnuseful": 0x801b9ab8,
		"TManhole::setGroundCollision": 0x801b9b1c,
		"TManhole::calc": 0x801b9c08,
		"TManhole::appeared": 0x801b9ce0,
		"TManhole::animationFinished": 0x801b9ea0,
		"animationFinished": 0x801b9ea0,
		"TManhole::touchPlayer": 0x801ba024,
		"TDoor::TDoor": 0x801ba338,
		"TDoor::load": 0x801ba384,
		"TDoor::touchPlayer": 0x801ba3e0,
		"MoveBG::__sinit_MapObjTown_cpp": 0x801baa2c,
		"__sinit_MapObjTown_cpp": 0x801baa2c,
		"TSuperHipDropBlock::loadAfter": 0x801bae24,
		"TSuperHipDropBlock::receiveMessage": 0x801baea8,
		"TTelesaBlock::setGroundCollision": 0x801baf48,
		"TTelesaBlock::perform": 0x801baf9c,
		"TTelesaBlock::initMapObj": 0x801bb138,
		"TJuiceBlock::kill": 0x801bb1c4,
		"TJuiceBlock::moveObject": 0x801bb1f8,
		"TJuiceBlock::initMapObj": 0x801bb250,
		"TBrickBlock::initMapObj": 0x801bb2a4,
		"TBrickBlock::receiveMessage": 0x801bb36c,
		"TBrickBlock::kill": 0x801bb448,
		"TIceBlock::initMapObj": 0x801bb518,
		"TIceBlock::calc": 0x801bb5a8,
		"TIceBlock::control": 0x801bb60c,
		"TIceBlock::touchWater": 0x801bb7ec,
		"TIceBlock::getSDLModelFlag": 0x801bb974,
		"TLeanBlock::TLeanBlock": 0x801bb97c,
		"TLeanBlock::initMapObj": 0x801bba24,
		"TLeanBlock::calcDefaultMtx": 0x801bbaa4,
		"TLeanBlock::calcLeanMtx": 0x801bbadc,
		"calcLeanMtx": 0x801bbadc,
		"TLeanBlock::control": 0x801bbc2c,
		"TLeanBlock::touchPlayer": 0x801bbd98,
		"TSandBlock::initMapObj": 0x801bbe3c,
		"TSandBlock::control": 0x801bbef0,
		"TSandBlock::touchPlayer": 0x801bc14c,
		"TBreakableBlock::touchPlayer": 0x801bc19c,
		"MoveBG::__sinit_MapObjBlock_cpp": 0x801bc4d4,
		"__sinit_MapObjBlock_cpp": 0x801bc4d4,
		"TWoodLog::control": 0x801bc8ac,
		"TBellWatermill::TBellWatermill": 0x801bc9a4,
		"TBellWatermill::loadAfter": 0x801bca20,
		"TBellWatermill::control": 0x801bcb50,
		"TBellWatermill::touchWater": 0x801bd32c,
		"TBiancoBell::TBiancoBell": 0x801bd394,
		"TBiancoBell::initMapObj": 0x801bd3e4,
		"TBiancoBell::touchPlayer": 0x801bd478,
		"TBiancoBell::touchWater": 0x801bd598,
		"TLampSeesawMain::TLampSeesawMain": 0x801bd6bc,
		"TLampSeesawMain::loadAfter": 0x801bd7c8,
		"TLampSeesawMain::control": 0x801bd88c,
		"TLampSeesawMain::touchPlayer": 0x801bda78,
		"TLampSeesawMain::pushDown": 0x801bdac4,
		"TLampSeesaw::TLampSeesaw": 0x801bdadc,
		"TLampSeesaw::load": 0x801bdb30,
		"TLampSeesaw::touchPlayer": 0x801bdba8,
		"TLampSeesaw::pushDown": 0x801bdbf8,
		"TLeafBoatRotten::TLeafBoatRotten": 0x801bdbfc,
		"TLeafBoatRotten::load": 0x801bdce0,
		"TLeafBoatRotten::perform": 0x801bdd4c,
		"TLeafBoatRotten::control": 0x801bdd6c,
		"TLeafBoat::TLeafBoat": 0x801be028,
		"TLeafBoat::initMapObj": 0x801be0c0,
		"TLeafBoat::calc": 0x801be108,
		"TLeafBoat::control": 0x801be1e0,
		"TLeafBoat::bind": 0x801be3a4,
		"TLeafBoat::touchWall": 0x801be5ec,
		"TLeafBoat::touchActor": 0x801be724,
		"TBiancoMiniWindmill::TBiancoMiniWindmill": 0x801be8d4,
		"TBiancoMiniWindmill::initMapObj": 0x801be9a0,
		"TBiancoMiniWindmill::control": 0x801beabc,
		"TBiancoMiniWindmill::calc": 0x801beb2c,
		"TBiancoMiniWindmill::touchWater": 0x801becc8,
		"TBiancoWatermillVertical::TBiancoWatermillVertical": 0x801bede4,
		"TBiancoWatermillVertical::load": 0x801bee48,
		"TBiancoWatermillVertical::loadAfter": 0x801beea8,
		"TBiancoWatermillVertical::control": 0x801bef6c,
		"TBiancoWatermillVertical::setGroundCollision": 0x801bf134,
		"TBiancoWatermillVertical::touchWater": 0x801bf1a8,
		"TBiancoWatermill::TBiancoWatermill": 0x801bf320,
		"TBiancoWatermill::initMapObj": 0x801bf374,
		"TBiancoWatermill::control": 0x801bf3e4,
		"TBiancoWatermill::touchWater": 0x801bf468,
		"TBiancoWatermill::turnByEnemy": 0x801bf470,
		"turnByEnemy": 0x801bf470,
		"TMapObjRootPakkun::initMapObj": 0x801bf474,
		"TMapObjRootPakkun::drawObject": 0x801bf4d4,
		"TBigWindmill::load": 0x801bf568,
		"TBigWindmill::control": 0x801bf648,
		"MoveBG::__sinit_MapObjBianco_cpp": 0x801bfcf0,
		"__sinit_MapObjBianco_cpp": 0x801bfcf0,
		"TWaterHitPictureHideObj::getObjAppearPos": 0x801c00e8,
		"TPictureTelesa::control": 0x801c00f0,
		"TPictureTelesa::touchActor": 0x801c013c,
		"TPictureTelesa::afterFinishedAnim": 0x801c02a0,
		"TPanelRevolve::control": 0x801c0348,
		"TPanelRevolve::touchPlayer": 0x801c03b4,
		"TPanelRevolve::receiveMessage": 0x801c0454,
		"TChestRevolve::control": 0x801c04ec,
		"TChestRevolve::touchWater": 0x801c0550,
		"TWarpAreaActor::TWarpAreaActor": 0x801c05bc,
		"TWarpAreaActor::load": 0x801c060c,
		"TWarpAreaActor::perform": 0x801c06c8,
		"TSirenaCasinoRoof::getSDLModelFlag": 0x801c0764,
		"TSirenaCasinoRoof::perform": 0x801c076c,
		"TSirenaCasinoRoof::initMapObj": 0x801c07cc,
		"TSirenabossWall::getSDLModelFlag": 0x801c08a0,
		"TSirenabossWall::drawObject": 0x801c08a8,
		"TSirenabossWall::perform": 0x801c08dc,
		"TSirenabossWall::initMapObj": 0x801c093c,
		"TSakuCasino::calcRootMatrix": 0x801c0a00,
		"TSakuCasino::loadAfter": 0x801c0b34,
		"TSakuCasino::initMapObj": 0x801c0b98,
		"TSakuCasino::TSakuCasino": 0x801c0ca8,
		"TCloset::touchWater": 0x801c0d04,
		"TCloset::calcRootMatrix": 0x801c0e64,
		"TCloset::moveObject": 0x801c0f90,
		"TCloset::initMapObj": 0x801c131c,
		"TCloset::TCloset": 0x801c1514,
		"TDonchou::touchWater": 0x801c15c0,
		"TDonchou::calcRootMatrix": 0x801c15ec,
		"TDonchou::loadAfter": 0x801c1860,
		"TDonchou::initMapObj": 0x801c1928,
		"TDonchou::TDonchou": 0x801c1a40,
		"TCasinoPanelGate::touchWater": 0x801c1a9c,
		"TCasinoPanelGate::calcRootMatrix": 0x801c1d20,
		"TCasinoPanelGate::moveObject": 0x801c1dec,
		"TCasinoPanelGate::initMapObj": 0x801c2200,
		"TCasinoPanelGate::TCasinoPanelGate": 0x801c2300,
		"TItemSlotDrum::getResultFromAng": 0x801c23ac,
		"TItemSlotDrum::getForcastResult": 0x801c23f0,
		"TItemSlotDrum::generateItem": 0x801c254c,
		"TItemSlotDrum::touchWater": 0x801c2a38,
		"TItemSlotDrum::calcRootMatrix": 0x801c2bc8,
		"TItemSlotDrum::moveObject": 0x801c2cf8,
		"TItemSlotDrum::loadAfter": 0x801c3264,
		"TItemSlotDrum::TItemSlotDrum": 0x801c3310,
		"TSlotDrum::touchWater": 0x801c343c,
		"TSlotDrum::calcRootMatrix": 0x801c3564,
		"TSlotDrum::moveObject": 0x801c3614,
		"TSlotDrum::initNeonMatColor": 0x801c3ae0,
		"TSlotDrum::initMapObj": 0x801c3ba0,
		"TSlotDrum::TSlotDrum": 0x801c3d30,
		"TSirenaRollMapObj::TSirenaRollMapObj": 0x801c3dd4,
		"MoveBG::partsRollCallback": 0x801c3e60,
		"partsRollCallback": 0x801c3e60,
		"TRoulette::switchStop": 0x801c3fc0,
		"switchStop": 0x801c3fc0,
		"TRoulette::setRollSp": 0x801c40e0,
		"setRollSp": 0x801c40e0,
		"TRoulette::calcRootMatrix": 0x801c4104,
		"TRoulette::moveObject": 0x801c41a8,
		"TRoulette::perform": 0x801c429c,
		"TRoulette::initMapObj": 0x801c42fc,
		"TRoulette::TRoulette": 0x801c44c0,
		"TRouletteSw::perform": 0x801c4594,
		"TRouletteSw::receiveMessage": 0x801c45c8,
		"TCloset::getRollAngY": 0x801c499c,
		"TCasinoPanelGate::getRollAngX": 0x801c4acc,
		"MoveBG::__sinit_MapObjSirena_cpp": 0x801c4c80,
		"__sinit_MapObjSirena_cpp": 0x801c4c80,
		"TFruitLauncher::loadAfter": 0x801c5070,
		"TFruitLauncher::fireObj": 0x801c52c4,
		"fireObj": 0x801c52c4,
		"TLiveActor::getMActor": 0x801c5890,
		"TFruitSwitch::receiveMessage": 0x801c5898,
		"TSurfGesoObj::initMapObj": 0x801c5918,
		"TRiccoWatermill::TRiccoWatermill": 0x801c5a28,
		"TRiccoWatermill::loadAfter": 0x801c5a94,
		"TRiccoWatermill::calc": 0x801c5b74,
		"TRiccoWatermill::control": 0x801c5b94,
		"TRiccoWatermill::touchWater": 0x801c5f9c,
		"TCraneCargo::calc": 0x801c608c,
		"TCraneCargo::control": 0x801c60d0,
		"TCraneUpDown::initMapObj": 0x801c6100,
		"TCraneUpDown::control": 0x801c6220,
		"TCraneRotY::load": 0x801c6524,
		"TCraneRotY::control": 0x801c65e0,
		"TCraneRotY::calc": 0x801c677c,
		"MoveBG::__sinit_MapObjRicco_cpp": 0x801c6ae4,
		"__sinit_MapObjRicco_cpp": 0x801c6ae4,
		"TSandEgg::getSDLModelFlag": 0x801c6ec4,
		"TMammaMirrorMapOperator::TMammaMirrorMapOperator": 0x801c6ecc,
		"TMammaMirrorMapOperator::loadAfter": 0x801c7068,
		"TMammaMirrorMapOperator::perform": 0x801c7324,
		"TGoalWatermelon::TGoalWatermelon": 0x801c7574,
		"TGoalWatermelon::load": 0x801c75d4,
		"TGoalWatermelon::loadAfter": 0x801c764c,
		"TGoalWatermelon::control": 0x801c76fc,
		"TGoalWatermelon::touchActor": 0x801c777c,
		"TSandBird::TSandBird": 0x801c7888,
		"TSandBird::initMapObj": 0x801c795c,
		"TSandBird::nameIsObj": 0x801c79ec,
		"TSandBird::makeObjFromJointName": 0x801c7a28,
		"TSandBird::control": 0x801c7ab4,
		"TMammaYacht::initMapObj": 0x801c7cf8,
		"TMammaYacht::control": 0x801c7dcc,
		"TMammaBlockRotate::TMammaBlockRotate": 0x801c7e6c,
		"TMammaBlockRotate::load": 0x801c7ec4,
		"TMammaBlockRotate::initMapObj": 0x801c7f8c,
		"TMammaBlockRotate::control": 0x801c8104,
		"TMammaBlockRotate::touchWater": 0x801c8364,
		"TShiningStone::TShiningStone": 0x801c83b4,
		"TShiningStone::load": 0x801c841c,
		"TShiningStone::perform": 0x801c866c,
		"TShiningStone::putOnLight": 0x801c8744,
		"putOnLight": 0x801c8744,
		"TLeanMirror::TLeanMirror": 0x801c89e4,
		"TLeanMirror::load": 0x801c8aa4,
		"TLeanMirror::initMapObj": 0x801c8be0,
		"TLeanMirror::getSDLModelFlag": 0x801c8cb8,
		"TLeanMirror::loadAfter": 0x801c8cc0,
		"TLeanMirror::control": 0x801c8de8,
		"TLeanMirror::controlShake": 0x801c902c,
		"controlShake": 0x801c902c,
		"TLeanMirror::controlGoTarget": 0x801c9360,
		"controlGoTarget": 0x801c9360,
		"MoveBG::startCameraShakeSE": 0x801c951c,
		"startCameraShakeSE": 0x801c951c,
		"TLeanMirror::release": 0x801c9524,
		"TLeanMirror::touchEnemy": 0x801c9774,
		"TLeanMirror::touchPlayer": 0x801c9854,
		"TLeanMirror::receiveMessage": 0x801c9968,
		"TLeanMirror::draw": 0x801c9b84,
		"TSandCastle::TSandCastle": 0x801c9ce4,
		"TSandCastle::initMapObj": 0x801c9ea0,
		"TSandCastle::loadAfter": 0x801c9ee4,
		"TSandCastle::findTriggerActor": 0x801c9f98,
		"TSandCastle::calcRootMatrix": 0x801c9ff8,
		"TSandCastle::waitBeforeExplode": 0x801ca038,
		"MoveBG::SandCastleCallBack": 0x801ca0b8,
		"SandCastleCallBack": 0x801ca0b8,
		"TSandCastle::explode": 0x801ca14c,
		"TSandCastle::expanded": 0x801ca2b4,
		"TSandCastle::withering": 0x801ca3a8,
		"TSandBombBase::TSandBombBase": 0x801ca4e8,
		"TSandBombBase::initMapObj": 0x801ca568,
		"TSandBombBase::loadAfter": 0x801ca698,
		"TSandBombBase::findTriggerActor": 0x801ca6f0,
		"TSandBombBase::control": 0x801ca738,
		"TSandBombBase::grow": 0x801ca9d0,
		"TSandBombBase::waitBeforeExplode": 0x801ca9dc,
		"TSandBombBase::explode": 0x801ca9f0,
		"TSandBombBase::exploding": 0x801cab30,
		"exploding": 0x801cab30,
		"TSandBombBase::expanded": 0x801cacb4,
		"TSandBombBase::withered": 0x801cad74,
		"withered": 0x801cad74,
		"TSandBomb::initMapObj": 0x801cada8,
		"TSandBomb::getSDLModelFlag": 0x801cadc8,
		"TSandBomb::touchWater": 0x801cadd0,
		"TSandBomb::makeObjAppeared": 0x801caf1c,
		"TSandLeafBase::initMapObj": 0x801caf60,
		"TSandLeafBase::control": 0x801caff4,
		"TSandLeafBase::grow": 0x801cb1b4,
		"TSandBase::TSandBase": 0x801cb340,
		"TSandBase::withering": 0x801cb398,
		"TSandLeaf::control": 0x801cb444,
		"TSandLeaf::touchWater": 0x801cb49c,
		"TMammaMirrorMapOperator::~TMammaMirrorMapOperator": 0x801cb4d0,
		"TMapObjBall::getDepthAtFloating": 0x801cb64c,
		"MoveBG::__sinit_MapObjMamma_cpp": 0x801cbad4,
		"__sinit_MapObjMamma_cpp": 0x801cbad4,
		"TPinnaCoaster::TPinnaCoaster": 0x801cbec4,
		"TPinnaCoaster::initMapObj": 0x801cbf20,
		"TPinnaCoaster::control": 0x801cc018,
		"TAmiKing::touchPlayer": 0x801cc1b0,
		"TAmiKing::bind": 0x801cc1d4,
		"TAmiKing::moveObject": 0x801cc3a8,
		"TAmiKing::initMapObj": 0x801cc710,
		"TAmiKing::loadAfter": 0x801cc798,
		"TWaterRecoverObj::touchPlayer": 0x801cc7f4,
		"TPinnaEntrance::loadAfter": 0x801cc884,
		"TBalloonKoopaJr::load": 0x801cc8ec,
		"TBalloonKoopaJr::kill": 0x801cca0c,
		"TBalloonKoopaJr::touchActor": 0x801ccab8,
		"TChangeStageMerrygoround::calc": 0x801ccae4,
		"TChangeStageMerrygoround::touchPlayer": 0x801ccb48,
		"TMerrygoround::TMerrygoround": 0x801ccc1c,
		"TMerrygoround::initMapObj": 0x801ccd18,
		"TMerrygoround::draw": 0x801cd004,
		"TMerrygoround::control": 0x801cd008,
		"TShellCup::TShellCup": 0x801cd1c0,
		"TPinnaShell::TPinnaShell": 0x801cd2c0,
		"TShellCup::initMapObj": 0x801cd368,
		"TShellCup::loadAfter": 0x801cd5b8,
		"TShellCup::perform": 0x801cd730,
		"MoveBG::MsMtxSetRotX": 0x801cd87c,
		"MsMtxSetRotX": 0x801cd87c,
		"TShellCup::control": 0x801cd8f8,
		"TPinnaShell::control": 0x801cd95c,
		"TPinnaShell::receiveMessage": 0x801cdcd0,
		"TViking::TViking": 0x801cdd80,
		"TViking::initMapObj": 0x801cde88,
		"TViking::loadAfter": 0x801cdf48,
		"TViking::reset": 0x801cdf88,
		"TViking::control": 0x801cdfbc,
		"TViking::roll": 0x801ce120,
		"roll": 0x801ce120,
		"THorizontalViking::initMapObj": 0x801ce4c4,
		"THorizontalViking::reset": 0x801ce51c,
		"THorizontalViking::control": 0x801ce550,
		"TFerrisWheel::TFerrisWheel": 0x801ce674,
		"TFerrisWheel::initMapObj": 0x801ce6cc,
		"TFerrisWheel::control": 0x801ce810,
		"TFerrisWheel::becomeCalmlyCallback": 0x801ce9a8,
		"becomeCalmlyCallback": 0x801ce9a8,
		"TAmiKing::touchWater": 0x801ceaac,
		"MoveBG::__sinit_MapObjPinna_cpp": 0x801cef38,
		"__sinit_MapObjPinna_cpp": 0x801cef38,
		"TGateShadow::~TGateShadow": 0x801cf294,
		"TGateShadow::perform": 0x801cf308,
		"MoveBG::__sinit_MapObjSample_cpp": 0x801cf30c,
		"__sinit_MapObjSample_cpp": 0x801cf30c,
		"TMareEventPoint::load": 0x801cf68c,
		"TMareEventPoint::receiveMessage": 0x801cf6e0,
		"TMareCork::drawObject": 0x801cf7d4,
		"TMareCork::getTakingMtx": 0x801cf8b8,
		"TMareCork::calcRootMatrix": 0x801cf8cc,
		"TMareCork::moveObject": 0x801cf9c4,
		"TMareCork::loadAfter": 0x801cfa38,
		"TMareFall::load": 0x801cfb84,
		"TMareFall::calc": 0x801cfc14,
		"TMuddyBoat::TMuddyBoat": 0x801cfcd4,
		"TMuddyBoat::initMapObj": 0x801cfd70,
		"TMuddyBoat::getSDLModelFlag": 0x801cfe40,
		"TMuddyBoat::calc": 0x801cfe48,
		"TMuddyBoat::control": 0x801d0000,
		"TMuddyBoat::bind": 0x801d0298,
		"TMapObjBase::getObjCollisionHeightOffset": 0x801d07ec,
		"getObjCollisionHeightOffset": 0x801d07ec,
		"TMuddyBoat::kill": 0x801d07f4,
		"TMuddyBoat::calcRootMatrix": 0x801d08dc,
		"TMuddyBoat::moveByWater": 0x801d08e0,
		"moveByWater": 0x801d08e0,
		"TMapObjPuncher::load": 0x801d0a90,
		"TMapObjPuncher::control": 0x801d0b10,
		"TMapObjPuncher::touchPlayer": 0x801d0c04,
		"TWireBell::TWireBell": 0x801d0d78,
		"TWireBell::loadAfter": 0x801d0df4,
		"TWireBell::control": 0x801d0e30,
		"TWireBell::draw": 0x801d0ed0,
		"TWireBell::initDraw": 0x801d1034,
		"TMapObjGrowTree::TMapObjGrowTree": 0x801d1240,
		"TMapObjGrowTree::initMapObj": 0x801d12a0,
		"TMapObjGrowTree::loadAfter": 0x801d1304,
		"TMapObjGrowTree::control": 0x801d1338,
		"TMapObjGrowTree::touchWater": 0x801d160c,
		"TMapObjElasticCode::initMapObj": 0x801d18f4,
		"TMapObjElasticCode::control": 0x801d1940,
		"TMapObjElasticCode::draw": 0x801d1a50,
		"TCogwheel::TCogwheel": 0x801d1c44,
		"TCogwheel::initMapObj": 0x801d1cd0,
		"TCogwheel::control": 0x801d1f5c,
		"TCogwheel::calc": 0x801d211c,
		"TCogwheel::draw": 0x801d21e0,
		"TCogwheel::initDraw": 0x801d246c,
		"TCogwheelScale::TCogwheelScale": 0x801d2678,
		"TCogwheelScale::control": 0x801d26f0,
		"TCogwheelScale::touchPlayer": 0x801d27a0,
		"TCogwheelScale::receiveMessage": 0x801d28a8,
		"TCogwheelScale::touchWater": 0x801d28f4,
		"MoveBG::__sinit_MapObjMare_cpp": 0x801d2dbc,
		"__sinit_MapObjMare_cpp": 0x801d2dbc,
		"TMapObjFlagManager::~TMapObjFlagManager": 0x801d3120,
		"TMapObjFlagManager::TMapObjFlagManager": 0x801d3194,
		"TMapObjFlagManager::TMapObjFlagInfo::TMapObjFlagInfo": 0x801d3220,
		"TMapObjFlagManager::load": 0x801d3230,
		"TMapObjFlagManager::registerObj": 0x801d32c4,
		"registerObj": 0x801d32c4,
		"TMapObjFlagManager::perform": 0x801d38ec,
		"TMapObjFlagManager::initDraw": 0x801d3afc,
		"TMapObjFlag::TMapObjFlag": 0x801d3cc4,
		"TMapObjFlag::load": 0x801d3db8,
		"TMapObjFlag::init": 0x801d3e0c,
		"TMapObjFlag::updateVertex": 0x801d40ec,
		"updateVertex": 0x801d40ec,
		"TMapObjFlag::draw": 0x801d4224,
		"MoveBG::__sinit_MapObjFlag_cpp": 0x801d4560,
		"__sinit_MapObjFlag_cpp": 0x801d4560,
		"TMapObjWave::~TMapObjWave": 0x801d4864,
		"TMapObjWave::TMapObjWave": 0x801d48d8,
		"TMapObjWave::load": 0x801d4ae0,
		"TMapObjWave::perform": 0x801d4cb0,
		"TMapObjWave::updateTime": 0x801d4d38,
		"updateTime": 0x801d4d38,
		"TMapObjWave::updateHeightAndAlpha": 0x801d4ddc,
		"updateHeightAndAlpha": 0x801d4ddc,
		"TMapObjWave::draw": 0x801d50f4,
		"TMapObjWave::noWave": 0x801d5420,
		"noWave": 0x801d5420,
		"TMapObjWave::getHeight": 0x801d5440,
		"TMapObjWave::getWaveHeight": 0x801d556c,
		"getWaveHeight": 0x801d556c,
		"TMapObjWave::initDraw": 0x801d55f8,
		"MoveBG::__sinit_MapObjWave_cpp": 0x801d5924,
		"__sinit_MapObjWave_cpp": 0x801d5924,
		"TMapObjFloatOnSea::TMapObjFloatOnSea": 0x801d5cc4,
		"TMapObjFloatOnSea::initMapObj": 0x801d5d2c,
		"TMapObjFloatOnSea::calc": 0x801d5e4c,
		"TMapObjFloatOnSea::control": 0x801d5ef0,
		"TMapObjFloatOnSea::touchPlayer": 0x801d5f70,
		"MoveBG::__sinit_MapObjFloat_cpp": 0x801d5fb4,
		"__sinit_MapObjFloat_cpp": 0x801d5fb4,
		"TMapObjPlane::hasMapCollision": 0x801d633c,
		"TSandPlane::load": 0x801d6344,
		"TRockPlane::load": 0x801d63c0,
		"TMapObjPlane::TMapObjPlane": 0x801d643c,
		"TMapObjPlane::load": 0x801d64b0,
		"TMapObjPlane::makeMountain": 0x801d661c,
		"makeMountain": 0x801d661c,
		"TMapObjPlane::perform": 0x801d6778,
		"TMapObjPlane::receiveMessage": 0x801d67c4,
		"TMapObjPlane::depress": 0x801d6824,
		"depress": 0x801d6824,
		"TMapObjPlane::calcNrm": 0x801d6ad4,
		"calcNrm": 0x801d6ad4,
		"TMapObjPlane::updateCheckData": 0x801d6f98,
		"updateCheckData": 0x801d6f98,
		"TMapObjPlane::draw": 0x801d7168,
		"TMapObjPlane::initDraw": 0x801d7340,
		"MoveBG::__sinit_MapObjPlane_cpp": 0x801d76c8,
		"__sinit_MapObjPlane_cpp": 0x801d76c8,
		"TRideCloud::perform": 0x801d7a78,
		"TRideCloud::control": 0x801d7ab0,
		"TRideCloud::getShadowType": 0x801d7db4,
		"TRideCloud::load": 0x801d7dbc,
		"TRideCloud::initMapObj": 0x801d7f08,
		"TRideCloud::calcRootMatrix": 0x801d7f3c,
		"TRideCloud::setGroundCollision": 0x801d7fe8,
		"TRideCloud::touchWater": 0x801d8060,
		"TRideCloud::TRideCloud": 0x801d8088,
		"MoveBG::__sinit_MapObjCloud_cpp": 0x801d8194,
		"__sinit_MapObjCloud_cpp": 0x801d8194,
		"TBigWatermelon::TBigWatermelon": 0x801d8534,
		"TBigWatermelon::initMapObj": 0x801d8628,
		"TBigWatermelon::loadAfter": 0x801d877c,
		"TBigWatermelon::receiveMessage": 0x801d87f8,
		"TBigWatermelon::checkWallCollision": 0x801d8934,
		"TBigWatermelon::startEvent": 0x801d8954,
		"TBigWatermelon::control": 0x801d8b74,
		"TBigWatermelon::appearing": 0x801d8e04,
		"TBigWatermelon::kill": 0x801d8f14,
		"TBigWatermelon::touchActor": 0x801d9074,
		"TBigWatermelon::touchGround": 0x801d936c,
		"TBigWatermelon::rebound": 0x801d938c,
		"TBigWatermelon::touchWall": 0x801d9590,
		"TBigWatermelon::touchWaterSurface": 0x801d95b0,
		"TCoverFruit::loadAfter": 0x801d9620,
		"TCoverFruit::receiveMessage": 0x801d9678,
		"TCoverFruit::calcRootMatrix": 0x801d9718,
		"TRandomFruit::TRandomFruit": 0x801d985c,
		"TRandomFruit::initMapObj": 0x801d998c,
		"TResetFruit::TResetFruit": 0x801d9acc,
		"TResetFruit::initMapObj": 0x801d9b34,
		"TResetFruit::receiveMessage": 0x801d9b78,
		"TResetFruit::getLivingTime": 0x801d9f54,
		"TResetFruit::makeObjAppeared": 0x801d9f5c,
		"TResetFruit::killByTimer": 0x801da08c,
		"TResetFruit::perform": 0x801da0a8,
		"TResetFruit::control": 0x801da28c,
		"TResetFruit::appearing": 0x801da8bc,
		"TResetFruit::breaking": 0x801da9bc,
		"TResetFruit::kicked": 0x801daad8,
		"TResetFruit::makeObjLiving": 0x801dad7c,
		"makeObjLiving": 0x801dad7c,
		"TResetFruit::touchGround": 0x801dadfc,
		"TResetFruit::touchActor": 0x801daf24,
		"TResetFruit::touchWater": 0x801db058,
		"TResetFruit::touchWaterSurface": 0x801db1a8,
		"TResetFruit::touchPollution": 0x801db2ac,
		"TResetFruit::hold": 0x801db3d8,
		"TResetFruit::thrown": 0x801db524,
		"TResetFruit::makeObjWaitingToAppear": 0x801db558,
		"makeObjWaitingToAppear": 0x801db558,
		"TResetFruit::waitingToAppear": 0x801db624,
		"TResetFruit::checkGroundCollision": 0x801db760,
		"TMapObjBall::TMapObjBall": 0x801db8f8,
		"TMapObjBall::initMapObj": 0x801db9a0,
		"TMapObjBall::receiveMessage": 0x801dbe94,
		"TMapObjBall::control": 0x801dbf8c,
		"TMapObjBall::makeObjAppeared": 0x801dc09c,
		"TMapObjBall::makeObjDefault": 0x801dc194,
		"TMapObjBall::checkWallCollision": 0x801dc1ec,
		"TMapObjBall::calcCurrentMtx": 0x801dc2c8,
		"calcCurrentMtx": 0x801dc2c8,
		"TMapObjBall::touchActor": 0x801dc6f8,
		"TMapObjBall::boundByActor": 0x801dc84c,
		"boundByActor": 0x801dc84c,
		"TMapObjBall::touchWater": 0x801dcda0,
		"TMapObjBall::kicked": 0x801dcea0,
		"TMapObjBall::hold": 0x801dd0bc,
		"TMapObjBall::put": 0x801dd154,
		"TMapObjBall::touchGround": 0x801dd194,
		"TMapObjBall::rebound": 0x801dd468,
		"TMapObjBall::touchWaterSurface": 0x801dd5f0,
		"TMapObjBall::touchPollution": 0x801dd61c,
		"TMapObjBall::touchWall": 0x801dd648,
		"TMapObjBall::touchRoof": 0x801dd9ac,
		"MoveBG::__sinit_MapObjBall_cpp": 0x801ddb18,
		"__sinit_MapObjBall_cpp": 0x801ddb18,
		"TAirportEventSink::~TAirportEventSink": 0x801dde3c,
		"TAirportEventSink::TAirportEventSink": 0x801dded0,
		"TAirportEventSink::loadAfter": 0x801ddf34,
		"TAirportEventSink::watch": 0x801ddfc8,
		"TAirportEventSink::control": 0x801de098,
		"TAirportEventSink::finishControl": 0x801de10c,
		"TAirportSwitch::TAirportSwitch": 0x801de19c,
		"TAirportSwitch::loadAfter": 0x801de1e8,
		"TAirportSwitch::breaking": 0x801de25c,
		"MoveBG::__sinit_MapObjAirport_cpp": 0x801de3c4,
		"__sinit_MapObjAirport_cpp": 0x801de3c4,
		"TTurboNozzleDoor::touchPlayer": 0x801de74c,
		"TTurboNozzleDoor::loadAfter": 0x801de8b8,
		"TDemoCannon::perform": 0x801dea14,
		"TDemoCannon::startDemo": 0x801decbc,
		"TDemoCannon::initMapObj": 0x801ded28,
		"TDemoCannon::loadAfter": 0x801dee84,
		"TMareGate::loadAfter": 0x801defd8,
		"TMareGate::control": 0x801df030,
		"TMapObjSmoke::load": 0x801df098,
		"TMapObjSmoke::control": 0x801df0f4,
		"TMapObjSmoke::touchWater": 0x801df120,
		"TDptMonteFence::touchPlayer": 0x801df174,
		"TBellDolpic::control": 0x801df21c,
		"TBellDolpic::receiveMessage": 0x801df42c,
		"TBellDolpic::touchPlayer": 0x801df5a4,
		"TBellDolpic::ring": 0x801df5c8,
		"ring": 0x801df5c8,
		"TBellDolpic::calcRootMatrix": 0x801df764,
		"TBellDolpic::initMapObj": 0x801df7cc,
		"TBellDolpic::TBellDolpic": 0x801df89c,
		"TMonumentShine::control": 0x801df924,
		"TMonumentShine::receiveMessage": 0x801dfbc0,
		"TMonumentShine::hitByWater": 0x801dfd04,
		"hitByWater": 0x801dfd04,
		"TMonumentShine::initMapObj": 0x801dfe90,
		"TMonumentShine::TMonumentShine": 0x801dff40,
		"MoveBG::__sinit_MapObjDolpic_cpp": 0x801e02d8,
		"__sinit_MapObjDolpic_cpp": 0x801e02d8,
		"TMapObjRevivalPollution::~TMapObjRevivalPollution": 0x801e060c,
		"TMapObjRevivalPollution::TMapObjRevivalPollution": 0x801e0680,
		"TMapObjRevivalPollution::load": 0x801e06f0,
		"TMapObjRevivalPollution::loadAfter": 0x801e07d8,
		"TMapObjRevivalPollution::perform": 0x801e0884,
		"TRevivalPolluter::TRevivalPolluter": 0x801e08e4,
		"TPolluterBase::TPolluterBase": 0x801e090c,
		"TPolluterBase::load": 0x801e0958,
		"TPolluterBase::perform": 0x801e0a78,
		"MoveBG::__sinit_MapObjPollution_cpp": 0x801e0b58,
		"__sinit_MapObjPollution_cpp": 0x801e0b58,
		"TMapObjGrassManager::~TMapObjGrassManager": 0x801e0e5c,
		"TMapObjGrassManager::TMapObjGrassManager": 0x801e0ed0,
		"TMapObjGrassManager::load": 0x801e0f94,
		"TMapObjGrassManager::perform": 0x801e0fe4,
		"TMapObjGrassManager::initDrawNear": 0x801e121c,
		"initDrawNear": 0x801e121c,
		"TMapObjGrassGroup::TMapObjGrassGroup": 0x801e1468,
		"TMapObjGrassGroup::load": 0x801e14cc,
		"TMapObjGrassGroup::drawFar": 0x801e1758,
		"drawFar": 0x801e1758,
		"TMapObjGrassGroup::drawNear": 0x801e1880,
		"drawNear": 0x801e1880,
		"MoveBG::__sinit_MapObjGrass_cpp": 0x801e1a28,
		"__sinit_MapObjGrass_cpp": 0x801e1a28,
		"TMapObjPoleManager::~TMapObjPoleManager": 0x801e1d3c,
		"TMapObjPoleManager::TMapObjPoleManager": 0x801e1db0,
		"TMapObjPoleManager::TMapObjPoleInfo::TMapObjPoleInfo": 0x801e1e3c,
		"TMapObjPoleManager::load": 0x801e1e4c,
		"TMapObjPoleManager::perform": 0x801e1e88,
		"TMapObjPoleManager::initDraw": 0x801e1f34,
		"TMapObjPole::draw": 0x801e2104,
		"MoveBG::__sinit_MapObjPole_cpp": 0x801e225c,
		"__sinit_MapObjPole_cpp": 0x801e225c,
		"TMapObjWaterFilter::TMapObjWaterFilter": 0x801e25c4,
		"TMapObjWaterFilter::init": 0x801e26cc,
		"TMapObjWaterFilter::perform": 0x801e2718,
		"TMapObjSeaIndirect::TMapObjSeaIndirect": 0x801e28ac,
		"TMapObjSeaIndirect::init": 0x801e29a4,
		"TMapObjSeaIndirect::perform": 0x801e2acc,
		"MoveBG::__sinit_MapObjWater_cpp": 0x801e2b3c,
		"__sinit_MapObjWater_cpp": 0x801e2b3c,
		"TModelGate::getTakingMtx": 0x801e2ee4,
		"TModelGate::perform": 0x801e2eec,
		"TModelGate::receiveMessage": 0x801e3ab4,
		"TModelGate::screenBlur": 0x801e3c5c,
		"screenBlur": 0x801e3c5c,
		"TModelGate::startOpen": 0x801e3eac,
		"startOpen": 0x801e3eac,
		"TModelGate::loadAfter": 0x801e3f20,
		"MoveBG::__sinit_ModelGate_cpp": 0x801e4798,
		"__sinit_ModelGate_cpp": 0x801e4798,
		"TRailFence::TRailFence": 0x801e4b38,
		"TRailFence::load": 0x801e4bc4,
		"TRailFence::initMapCollisionData": 0x801e4c64,
		"TRailFence::control": 0x801e4c84,
		"TRailFence::goOnRail": 0x801e4e40,
		"goOnRail": 0x801e4e40,
		"TRailFence::receiveMessage": 0x801e505c,
		"TFenceWaterH::changeStatusToWait": 0x801e50e8,
		"TFenceWaterH::changeStatusToGo": 0x801e5120,
		"TFenceWaterH::control": 0x801e5190,
		"TFenceWater::initMapObj": 0x801e5458,
		"TFenceWater::initMapCollisionData": 0x801e55b0,
		"TFenceWater::control": 0x801e55d0,
		"TFenceWater::controlRotation": 0x801e56c4,
		"controlRotation": 0x801e56c4,
		"TFenceWater::changeStatusToWait": 0x801e57f8,
		"TFenceWater::changeStatusToGo": 0x801e5810,
		"TFenceWater::receiveMessage": 0x801e5874,
		"TFenceWater::draw": 0x801e58ec,
		"TRevolvingFenceInner::initMapObj": 0x801e58f0,
		"TRevolvingFenceInner::initMapCollisionData": 0x801e59d4,
		"TRevolvingFenceInner::control": 0x801e5a84,
		"TRevolvingFenceInner::setGroundCollision": 0x801e5ad0,
		"TRevolvingFenceInner::controlGroundRoof": 0x801e5bd8,
		"controlGroundRoof": 0x801e5bd8,
		"TRevolvingFenceInner::controlWall": 0x801e5cdc,
		"controlWall": 0x801e5cdc,
		"MoveBG::MsMtxSetRotY": 0x801e5f9c,
		"MsMtxSetRotY": 0x801e5f9c,
		"TRevolvingFenceInner::receiveMessage": 0x801e6060,
		"TRevolvingFenceOuter::initMapCollisionData": 0x801e62fc,
		"TRevolvingFenceOuter::receiveMessage": 0x801e647c,
		"TFence::initMapObj": 0x801e64d8,
		"TFence::initMapCollisionData": 0x801e6524,
		"TFence::receiveMessage": 0x801e669c,
		"MoveBG::__sinit_MapObjFence_cpp": 0x801e6948,
		"__sinit_MapObjFence_cpp": 0x801e6948,
		"TMapObjOptionWall::TMapObjOptionWall": 0x801e6cf8,
		"TMapObjOptionWall::init": 0x801e6d44,
		"TMapObjOptionWall::offCollision": 0x801e6db4,
		"offCollision": 0x801e6db4,
		"TMapObjOptionWall::onCollision": 0x801e6de4,
		"onCollision": 0x801e6de4,
		"TFileLoadBlock::TFileLoadBlock": 0x801e6e14,
		"TFileLoadBlock::initMapObj": 0x801e6e78,
		"TFileLoadBlock::loadAfter": 0x801e6f60,
		"TFileLoadBlock::receiveMessage": 0x801e70e0,
		"TFileLoadBlock::touchPlayer": 0x801e71d4,
		"TFileLoadBlock::makeBlockRock": 0x801e72c4,
		"makeBlockRock": 0x801e72c4,
		"TFileLoadBlock::makeBlockNormal": 0x801e72fc,
		"makeBlockNormal": 0x801e72fc,
		"MoveBG::__sinit_MapObjOption_cpp": 0x801e73b8,
		"__sinit_MapObjOption_cpp": 0x801e73b8,
		"TWoodBlock::load": 0x801e7760,
		"TWoodBlock::calcRecycle": 0x801e7894,
		"TWoodBlock::TWoodBlock": 0x801e7af4,
		"TRollBlock::control": 0x801e7c28,
		"TRollBlock::calcRootMatrix": 0x801e7c9c,
		"TRollBlock::getRootJointMtx": 0x801e7dd8,
		"TRollBlock::setGroundCollision": 0x801e7dfc,
		"TRollBlock::load": 0x801e7e5c,
		"TRollBlock::TRollBlock": 0x801e7f04,
		"TRailBlock::control": 0x801e7f54,
		"TRailBlock::calcRootMatrix": 0x801e8500,
		"TRailBlock::getRootJointMtx": 0x801e8598,
		"TRailBlock::initMapObj": 0x801e85bc,
		"TRailBlock::TRailBlock": 0x801e863c,
		"TNormalLift::perform": 0x801e86f8,
		"TNormalLift::setGroundCollision": 0x801e8754,
		"TNormalLift::control": 0x801e8810,
		"TNormalLift::initMapObj": 0x801e89c4,
		"TNormalLift::readRailFlag": 0x801e8a08,
		"TNormalLift::load": 0x801e8afc,
		"TNormalLift::resetPosition": 0x801e8c38,
		"TNormalLift::TNormalLift": 0x801e8cf0,
		"TRailMapObj::perform": 0x801e8d90,
		"TRailMapObj::control": 0x801e8dc8,
		"TRailMapObj::readRailFlag": 0x801e8ee4,
		"TRailMapObj::getShadowType": 0x801e8f3c,
		"TRailMapObj::setGroundCollision": 0x801e8f44,
		"TRailMapObj::load": 0x801e8fe0,
		"TRailMapObj::initMapObj": 0x801e90bc,
		"TRailMapObj::resetPosition": 0x801e9100,
		"TRailMapObj::calcRecycle": 0x801e91ac,
		"TRailMapObj::checkMarioRiding": 0x801e9300,
		"TRailMapObj::moveToNextNode": 0x801e93f8,
		"moveToNextNode": 0x801e93f8,
		"TRailMapObj::resetStep": 0x801e96b0,
		"resetStep": 0x801e96b0,
		"TRailMapObj::initGraphTracer": 0x801e9730,
		"initGraphTracer": 0x801e9730,
		"TRailMapObj::TRailMapObj": 0x801e98a4,
		"TFluffManager::TFluffManager": 0x801e9ae0,
		"TFluffManager::load": 0x801e9b5c,
		"TFluffManager::loadAfter": 0x801e9cf0,
		"TFluffManager::control": 0x801ea0b4,
		"TFluff::TFluff": 0x801ea420,
		"TFluff::initMapObj": 0x801ea4ac,
		"TFluff::appear": 0x801ea4e8,
		"TFluff::control": 0x801ea6dc,
		"TFluff::kill": 0x801eaa0c,
		"TFluff::move": 0x801eaa70,
		"TFluff::touchWater": 0x801eacac,
		"TGoalFlag::initMapObj": 0x801ead38,
		"TGoalFlag::touchActor": 0x801ead58,
		"TSwingBoard::TSwingBoard": 0x801eae3c,
		"TSwingBoard::load": 0x801eaee4,
		"TSwingBoard::control": 0x801eb100,
		"TSwingBoard::draw": 0x801eb3f4,
		"TSwingBoard::initDraw": 0x801eb508,
		"TSwingBoard::drawOneRope": 0x801eb714,
		"THangingBridge::THangingBridge": 0x801eb8b0,
		"THangingBridge::loadAfter": 0x801eb934,
		"THangingBridge::perform": 0x801ebed0,
		"THangingBridge::initDraw": 0x801ebfd4,
		"THangingBridge::drawRopeBetweenBoards": 0x801ec228,
		"drawRopeBetweenBoards": 0x801ec228,
		"THangingBridge::drawUpper": 0x801ec964,
		"THangingBridge::drawLowerPlus": 0x801ecb48,
		"drawLowerPlus": 0x801ecb48,
		"THangingBridge::drawLowerMinus": 0x801ecdc4,
		"drawLowerMinus": 0x801ecdc4,
		"THangingBridgeBoard::THangingBridgeBoard": 0x801ed038,
		"THangingBridgeBoard::initMapObj": 0x801ed0d4,
		"THangingBridgeBoard::setGroundCollision": 0x801ed118,
		"THangingBridgeBoard::calcDefaultMtx": 0x801ed20c,
		"THangingBridgeBoard::control": 0x801ed274,
		"THangingBridgeBoard::drawOneRope": 0x801ed4ec,
		"TJumpMushroom::load": 0x801ed678,
		"TJumpMushroom::receiveMessage": 0x801ed6dc,
		"TMapObjMonteRoot::initMapObj": 0x801ed704,
		"TFluff::getRadiusAtY": 0x801ed7dc,
		"TGoalFlag::getRadiusAtY": 0x801ed868,
		"THangingBridge::~THangingBridge": 0x801ed8f4,
		"MoveBG::__sinit_MapObjMonte_cpp": 0x801edb0c,
		"__sinit_MapObjMonte_cpp": 0x801edb0c,
		"TMapObjTree::getRadiusAtY": 0x801ededc,
		"TMapObjTreeScale::TMapObjTreeScale": 0x801edf08,
		"TMapObjTreeScale::loadAfter": 0x801ee190,
		"TMapObjTreeScale::control": 0x801ee2cc,
		"TMapObjTreeScale::touchWater": 0x801ee688,
		"TMapObjTree::TMapObjTree": 0x801ee714,
		"TMapObjTree::initMapObj": 0x801ee78c,
		"TMapObjTree::initEach": 0x801ee93c,
		"initEach": 0x801ee93c,
		"TMapObjTree::perform": 0x801eeab0,
		"TMapObjTree::controlLeaf": 0x801eeb4c,
		"controlLeaf": 0x801eeb4c,
		"TMapObjTree::touchPlayer": 0x801eed08,
		"TMapObjLeaf::TMapObjLeaf": 0x801eedcc,
		"MoveBG::__sinit_MapObjTree_cpp": 0x801eee64,
		"__sinit_MapObjTree_cpp": 0x801eee64,
		"TMapObjSteam::load": 0x801ef20c,
		"TMapObjSteam::control": 0x801ef268,
		"TJointCoin::TJointCoin": 0x801ef294,
		"TJointCoin::initMapObj": 0x801ef2ec,
		"TJointCoin::nameIsObj": 0x801ef4b8,
		"TJointCoin::loadAfter": 0x801ef4f4,
		"TJointCoin::makeObjFromJointName": 0x801ef5d4,
		"TJointCoin::makeObj": 0x801ef6f8,
		"makeObj": 0x801ef6f8,
		"TJointCoin::control": 0x801ef89c,
		"TMapObjNail::TMapObjNail": 0x801ef9b8,
		"TMapObjNail::receiveMessage": 0x801efa04,
		"MoveBG::__sinit_MapObjEx_cpp": 0x801efbe4,
		"__sinit_MapObjEx_cpp": 0x801efbe4,
		"TPoolManager::TPoolManager": 0x801efef8,
		"TPoolManager::subWaterLevel": 0x801eff38,
		"subWaterLevel": 0x801eff38,
		"TPoolManager::getWaterLevel": 0x801effe0,
		"getWaterLevel": 0x801effe0,
		"TPool::TPool": 0x801f0048,
		"TPool::load": 0x801f00c4,
		"TPool::makeObjAppeared": 0x801f0108,
		"TPool::draw": 0x801f013c,
		"TPoolManager::~TPoolManager": 0x801f033c,
		"MoveBG::__sinit_Pool_cpp": 0x801f03d0,
		"__sinit_Pool_cpp": 0x801f03d0,
		"TBathtub::getNumKillerBurstable": 0x801f0758,
		"getNumKillerBurstable": 0x801f0758,
		"TBathtub::isKillerAttackable": 0x801f0904,
		"isKillerAttackable": 0x801f0904,
		"TBathtub::getNumKillerLaunchable": 0x801f0920,
		"getNumKillerLaunchable": 0x801f0920,
		"TBathtub::TBathtub": 0x801f0a64,
		"JGeometry::SMatrix33R<float><float>::SMatrix33R": 0x801f0b54,
		"SMatrix33R": 0x801f0b54,
		"TBathtub::load": 0x801f0b58,
		"TBathtub::updatePosture_": 0x801f1030,
		"updatePosture_": 0x801f1030,
		"TBathtub::getNextGrip": 0x801f162c,
		"getNextGrip": 0x801f162c,
		"TBathtub::getNextJuncture": 0x801f187c,
		"getNextJuncture": 0x801f187c,
		"TBathtub::getNearGrip": 0x801f1abc,
		"getNearGrip": 0x801f1abc,
		"TBathtub::calcRootMatrix": 0x801f1c88,
		"TBathtub::allowsTumble": 0x801f1dbc,
		"allowsTumble": 0x801f1dbc,
		"TBathtub::startDemo": 0x801f2040,
		"TBathtub::setupCollisions_": 0x801f22dc,
		"setupCollisions_": 0x801f22dc,
		"TBathtub::calcBathtubData": 0x801f2770,
		"calcBathtubData": 0x801f2770,
		"TBathtub::control": 0x801f2b24,
		"TBathtub::perform": 0x801f2fd0,
		"TBathtub::getRootJointMtx": 0x801f32e0,
		"TBathtub::receiveMessage": 0x801f331c,
		"TBathtub::getKoopaJrMtxInDemo": 0x801f33dc,
		"getKoopaJrMtxInDemo": 0x801f33dc,
		"TBathtub::getPeachMtxInDemo": 0x801f33f8,
		"getPeachMtxInDemo": 0x801f33f8,
		"TBathtub::getSubmarineMtxInDemo": 0x801f3414,
		"getSubmarineMtxInDemo": 0x801f3414,
		"TBathtub::getTakingMtx": 0x801f3430,
		"TBathtub::tumble": 0x801f344c,
		"tumble": 0x801f344c,
		"TBathtub::getNumGripsDead": 0x801f34d4,
		"getNumGripsDead": 0x801f34d4,
		"TBathtub::quake": 0x801f3558,
		"quake": 0x801f3558,
		"TBathtub::hipdrop": 0x801f3694,
		"hipdrop": 0x801f3694,
		"TBathtub::loadAfter": 0x801f3778,
		"TBathtubGrip::control": 0x801f386c,
		"TBathtubGrip::calcRootMatrix": 0x801f3c00,
		"TBathtubGrip::getRootJointMtx": 0x801f3dfc,
		"TBathtubGrip::receiveMessage": 0x801f3e20,
		"TBathtubGrip::perform": 0x801f4144,
		"TBathtubGrip::TBathtubGrip": 0x801f4214,
		"TBathtubGrip::kill": 0x801f45fc,
		"TBathtubGripPartsHard::receiveMessage": 0x801f46ac,
		"TBathtubGripPartsFragile::receiveMessage": 0x801f46e8,
		"TBathtubGripParts::getRootJointMtx": 0x801f4718,
		"TBathtubParams::TBathtubParams": 0x801f4760,
		"MoveBG::__sinit_MapObjCorona_cpp": 0x801f4dd4,
		"__sinit_MapObjCorona_cpp": 0x801f4dd4,
		"TJumpBase::control": 0x801f517c,
		"TJumpBase::calcRootMatrix": 0x801f5690,
		"TJumpBase::getRootJointMtx": 0x801f5740,
		"TJumpBase::receiveMessage": 0x801f5750,
		"TJumpBase::ensureTakeSituation": 0x801f58b8,
		"TJumpBase::initMapObj": 0x801f58fc,
		"TJumpBase::TJumpBase": 0x801f596c,
		"TMushroom1up::perform": 0x801f59b8,
		"TMushroom1up::control": 0x801f5a98,
		"TMushroom1up::load": 0x801f5f10,
		"TMushroom1up::initMapObj": 0x801f5f4c,
		"TMushroom1up::makeObjAppeared": 0x801f5fcc,
		"TMushroom1up::touchPlayer": 0x801f60e0,
		"TMushroom1up::TMushroom1up": 0x801f6178,
		"MoveBG::__sinit_MapObjItem2_cpp": 0x801f6268,
		"__sinit_MapObjItem2_cpp": 0x801f6268,
		"TWoodBox::TWoodBox": 0x801f6610,
		"TWoodBox::loadAfter": 0x801f673c,
		"TWoodBox::kill": 0x801f683c,
		"TBreakHideObj::initMapObj": 0x801f6b24,
		"TBreakHideObj::control": 0x801f6bdc,
		"TBreakHideObj::receiveMessage": 0x801f6c58,
		"TBreakHideObj::kill": 0x801f6d24,
		"THideObjPictureTwin::THideObjPictureTwin": 0x801f6d84,
		"THideObjPictureTwin::initMapObj": 0x801f6efc,
		"THideObjPictureTwin::loadAfter": 0x801f6f44,
		"THideObjPictureTwin::afterFinishedAnim": 0x801f701c,
		"TWaterHitPictureHideObj::TWaterHitPictureHideObj": 0x801f71d0,
		"TWaterHitPictureHideObj::load": 0x801f727c,
		"TWaterHitPictureHideObj::loadAfter": 0x801f7438,
		"TWaterHitPictureHideObj::receiveMessage": 0x801f779c,
		"TWaterHitPictureHideObj::control": 0x801f7934,
		"TWaterHitPictureHideObj::touchActor": 0x801f7a0c,
		"TWaterHitPictureHideObj::touchWater": 0x801f7a3c,
		"TWaterHitPictureHideObj::forward": 0x801f7b90,
		"forward": 0x801f7b90,
		"TWaterHitPictureHideObj::afterFinishedAnim": 0x801f7c6c,
		"THipDropHideObj::touchPlayer": 0x801f7d58,
		"TFruitBasketEvent::TFruitBasketEvent": 0x801f7db8,
		"TFruitBasketEvent::reset": 0x801f7f78,
		"TFruitBasketEvent::getFruitNum": 0x801f7f94,
		"getFruitNum": 0x801f7f94,
		"TFruitBasketEvent::countFruit": 0x801f7fa4,
		"TFruitBasket::loadAfter": 0x801f8088,
		"TFruitBasket::touchFruit": 0x801f81b0,
		"TFruitBasket::countFruit": 0x801f824c,
		"TFruitHitHideObj::load": 0x801f83f8,
		"TFruitHitHideObj::touchActor": 0x801f8484,
		"TFruitHitHideObj::touchFruit": 0x801f84e0,
		"TWaterHitHideObj::load": 0x801f8574,
		"TWaterHitHideObj::touchWater": 0x801f8600,
		"THideObj::touchPlayer": 0x801f8664,
		"THideObjBase::THideObjBase": 0x801f86d0,
		"THideObjBase::load": 0x801f8738,
		"THideObjBase::loadAfter": 0x801f87c4,
		"THideObjBase::receiveMessage": 0x801f88bc,
		"THideObjBase::emitEffect": 0x801f8950,
		"THideObjBase::appearObjFromPoint": 0x801f8988,
		"appearObjFromPoint": 0x801f8988,
		"THideObjBase::appearObj": 0x801f8ae0,
		"appearObj": 0x801f8ae0,
		"THideObjPictureTwin::getObjAppearPos": 0x801f8bc8,
		"MoveBG::__sinit_MapObjHide_cpp": 0x801f8e44,
		"__sinit_MapObjHide_cpp": 0x801f8e44,
		"TLampTrapIron::perform": 0x801f921c,
		"TLampTrapIron::control": 0x801f92c0,
		"TLampTrapIron::receiveMessage": 0x801f9348,
		"TLampTrapIron::loadAfter": 0x801f93ec,
		"TLampTrapIron::initMapObj": 0x801f951c,
		"TLampTrapIron::TLampTrapIron": 0x801f9564,
		"TLampTrapIronHit::perform": 0x801f95b8,
		"TLampTrapIronHit::receiveMessage": 0x801f9694,
		"TLampTrapSpike::perform": 0x801f96c4,
		"TLampTrapSpike::control": 0x801f9724,
		"TLampTrapSpike::receiveMessage": 0x801f9b70,
		"TLampTrapSpike::loadAfter": 0x801f9b90,
		"TLampTrapSpike::initMapObj": 0x801f9cc0,
		"TLampTrapSpike::TLampTrapSpike": 0x801f9cf8,
		"TLampTrapSpikeHit::perform": 0x801f9d50,
		"TLampTrapSpikeHit::receiveMessage": 0x801f9e34,
		"MoveBG::__sinit_MapObjTrap_cpp": 0x801f9ff0,
		"__sinit_MapObjTrap_cpp": 0x801f9ff0,
		"TJointModel::getJ3DModelDataFlag": 0x80180728,
		"TJointObj::newJointObj": 0x80180730,
		"TJointModel::TJointModel": 0x80180770,
		"TJointModel::initJointModel": 0x801807c0,
		"TJointModel::initActor": 0x8018080c,
		"initActor": 0x8018080c,
		"TJointModel::perform": 0x80180950,
		"Map::__sinit_JointModel_cpp": 0x80180994,
		"__sinit_JointModel_cpp": 0x80180994,
		"TJointModelManager::~TJointModelManager": 0x80180c90,
		"JGadget::TList<16MActorSubAnmInfo,Q27JGadget30TAllocator<16MActorSubAnmInfo>>::iterator::iterator": 0x80180e14,
		"TJointModelManager::newJointModel": 0x80180e1c,
		"TJointModelManager::TJointModelManager": 0x80180e5c,
		"TJointModelManager::initJointModel": 0x80180f4c,
		"TJointModelManager::perform": 0x80181034,
		"Map::__sinit_JointModelManager_cpp": 0x801810a4,
		"__sinit_JointModelManager_cpp": 0x801810a4,
		"TJointObj::TJointObj": 0x801813a0,
		"TJointObj::initJointObj": 0x801813d0,
		"initJointObj": 0x801813d0,
		"TJointObj::initChildren": 0x80181484,
		"initChildren": 0x80181484,
		"TJointObj::kill": 0x8018156c,
		"TJointObj::alive": 0x80181654,
		"alive": 0x80181654,
		"TJointObj::sleep": 0x8018171c,
		"TJointObj::awake": 0x80181814,
		"TJointObj::sit": 0x801818f0,
		"sit": 0x801818f0,
		"TJointObj::stand": 0x801819c0,
		"stand": 0x801819c0,
		"Map::__sinit_JointObj_cpp": 0x80181a90,
		"__sinit_JointObj_cpp": 0x80181a90,
		"TMap::~TMap": 0x80181d8c,
		"TMap::TMap": 0x80181e00,
		"TMap::load": 0x80181f00,
		"TMap::loadAfter": 0x80181f84,
		"TMap::perform": 0x80181fa8,
		"TMap::changeModel": 0x8018208c,
		"TMap::checkGroundExactY": 0x80182114,
		"checkGroundExactY": 0x80182114,
		"TMap::checkGroundIgnoreWaterThrough": 0x801821a8,
		"checkGroundIgnoreWaterThrough": 0x801821a8,
		"TMap::checkRoofIgnoreWaterThrough": 0x80182234,
		"checkRoofIgnoreWaterThrough": 0x80182234,
		"TMap::isTouchedWallsAndMoveXZ": 0x80182260,
		"isTouchedWallsAndMoveXZ": 0x80182260,
		"TMap::isTouchedOneWallAndMoveXZ": 0x80182298,
		"isTouchedOneWallAndMoveXZ": 0x80182298,
		"TMap::isTouchedOneWall": 0x80182344,
		"isTouchedOneWall": 0x80182344,
		"TMap::intersectLine": 0x801823e4,
		"TMap::isInArea": 0x80182408,
		"TMap::getIllegalCheckData": 0x8018244c,
		"getIllegalCheckData": 0x8018244c,
		"TMap::update": 0x80182458,
		"Map::initStage": 0x801826bc,
		"initStage": 0x801826bc,
		"Map::initStageCommon": 0x8018286c,
		"initStageCommon": 0x8018286c,
		"Map::initPinnaParco": 0x80182b4c,
		"initPinnaParco": 0x80182b4c,
		"Map::initMare": 0x80182c30,
		"initMare": 0x80182c30,
		"Map::initMonte": 0x80182f20,
		"initMonte": 0x80182f20,
		"Map::__sinit_Map_cpp": 0x801830e0,
		"__sinit_Map_cpp": 0x801830e0,
		"TMapCollisionData::polygonIsInGrid": 0x801833dc,
		"polygonIsInGrid": 0x801833dc,
		"Map::checkLinesCollision": 0x80183a14,
		"checkLinesCollision": 0x80183a14,
		"TMapCollisionData::intersectLine": 0x80183aec,
		"Map::bgIntersectLine": 0x8018464c,
		"bgIntersectLine": 0x8018464c,
		"TMapCollisionData::checkGround": 0x80184a14,
		"TMapCollisionData::checkGroundList": 0x80184bbc,
		"checkGroundList": 0x80184bbc,
		"TMapCollisionData::checkRoof": 0x80184d54,
		"TMapCollisionData::checkRoofList": 0x80184eb0,
		"checkRoofList": 0x80184eb0,
		"TMapCollisionData::checkWalls": 0x80184ff8,
		"TMapCollisionData::checkWallList": 0x80185118,
		"checkWallList": 0x80185118,
		"Map::__sinit_MapCheck_cpp": 0x80185554,
		"__sinit_MapCheck_cpp": 0x80185554,
		"TMapCollisionData::TMapCollisionData": 0x80185850,
		"TMapCollisionData::init": 0x8018593c,
		"TBGCheckListRoot::TBGCheckListRoot": 0x80185d64,
		"TMapCollisionData::initMoveCollision": 0x80185da8,
		"initMoveCollision": 0x80185da8,
		"TBGCheckListWarp::TBGCheckListWarp": 0x80185de4,
		"TBGCheckList::TBGCheckList": 0x80185e18,
		"TBGCheckListWarp::setPreNode": 0x80185e34,
		"TBGCheckList::setPreNode": 0x80185e3c,
		"Map::__sinit_MapCollisionData_cpp": 0x80185e40,
		"__sinit_MapCollisionData_cpp": 0x80185e40,
		"TMapCollisionWarp::TMapCollisionWarp": 0x80186144,
		"TMapCollisionWarp::init": 0x801861d4,
		"TMapCollisionWarp::remove": 0x80186240,
		"TMapCollisionWarp::setUpTrans": 0x801862b0,
		"TMapCollisionWarp::setUp": 0x80186348,
		"TMapCollisionMove::TMapCollisionMove": 0x80186418,
		"TMapCollisionMove::moveTrans": 0x801865ac,
		"TMapCollisionMove::move": 0x80186610,
		"TMapCollisionStatic::TMapCollisionStatic": 0x801866b4,
		"TMapCollisionStatic::init": 0x80186740,
		"TMapCollisionStatic::setUp": 0x801867bc,
		"TMapCollisionBase::init": 0x80186810,
		"TMapCollisionBase::setAllActor": 0x801869c8,
		"setAllActor": 0x801869c8,
		"TMapCollisionBase::setAllData": 0x801869f8,
		"setAllData": 0x801869f8,
		"TMapCollisionBase::setAllBGType": 0x80186a28,
		"setAllBGType": 0x80186a28,
		"TMapCollisionBase::setVertexData": 0x80186a54,
		"setVertexData": 0x80186a54,
		"TMapCollisionMove::moveSRT": 0x80186ab4,
		"TMapCollisionStatic::remove": 0x80186ba0,
		"TMapCollisionManager::TMapCollisionManager": 0x80186ba4,
		"TMapCollisionManager::init": 0x80186c1c,
		"TMapCollisionManager::createCollision": 0x80186d84,
		"createCollision": 0x80186d84,
		"TMapCollisionManager::changeCollision": 0x80186e68,
		"changeCollision": 0x80186e68,
		"TMapDrawWall::~TMapDrawWall": 0x80186ee0,
		"TMap::draw": 0x80186f54,
		"TMapDrawWall::TMapDrawWall": 0x80186f58,
		"TMapDrawWall::load": 0x80186fd8,
		"TMapDrawWall::perform": 0x80187014,
		"Map::__sinit_MapDraw_cpp": 0x8018733c,
		"__sinit_MapDraw_cpp": 0x8018733c,
		"TMapEvent::startControl": 0x801876bc,
		"TMapEvent::getBuilding": 0x801876c8,
		"TMapEvent::TMapEvent": 0x801876e4,
		"TMapEvent::load": 0x801877a4,
		"TMapEvent::perform": 0x801877e4,
		"TMapEvent::finishControl": 0x801878d0,
		"TMapEvent::isFinishedAll": 0x80187924,
		"Map::__sinit_MapEvent_cpp": 0x80187954,
		"__sinit_MapEvent_cpp": 0x80187954,
		"TMapEventSinkShadowMario::~TMapEventSinkShadowMario": 0x80187c50,
		"TMapEventSink::watch": 0x80187ce4,
		"TMapEventSinkShadowMario::initWithBuildingNum": 0x80187cec,
		"TMapEventSinkShadowMario::initBuilding": 0x80187dbc,
		"TMapEventSinkShadowMario::loadAfter": 0x80187e7c,
		"TMapEventSinkShadowMario::raiseBuilding": 0x80187f44,
		"raiseBuilding": 0x80187f44,
		"TMapEventSinkShadowMario::rising": 0x80187f74,
		"J3DTransformInfo::operator_=": 0x80188000,
		"TMapEventSinkBianco::load": 0x8018804c,
		"TMapEventSinkBianco::loadAfter": 0x80188144,
		"TMapEventSinkBianco::watch": 0x801882bc,
		"TMapEventSinkBianco::startControl": 0x801883d0,
		"TMapEventSinkBianco::control": 0x80188558,
		"TMapEventSinkBianco::rising": 0x801885dc,
		"TMapEventSinkBianco::finishControl": 0x80188668,
		"TMapEventSinkInPollutionReset::loadAfter": 0x8018883c,
		"TMapEventSinkInPollutionReset::makeBuildingRecovered": 0x80188970,
		"TMapEventSinkInPollution::loadAfter": 0x80188b0c,
		"TMapEventSinkInPollution::initBuriedBuilding": 0x80188ba4,
		"initBuriedBuilding": 0x80188ba4,
		"TMapEventSinkInPollution::watch": 0x80188c4c,
		"TMapEventSink::TMapEventSink": 0x80188cfc,
		"TMapEventSink::load": 0x80188d98,
		"TMapEventSink::initWithBuildingNum": 0x80188ea4,
		"TMapEventSink::initBuilding": 0x80188f54,
		"TMapEventSink::startControl": 0x80189004,
		"TMapEventSink::control": 0x801891c0,
		"TMapEventSink::rising": 0x80189320,
		"TMapEventSink::finishControl": 0x801893bc,
		"TMapEventSink::makeBuildingRecovered": 0x80189440,
		"TMapEventSink::isFinishedAll": 0x80189570,
		"TMapEventSink::getPollutionObj": 0x801895ac,
		"getPollutionObj": 0x801895ac,
		"TMapEventSink::getSinkOffsetY": 0x801895e0,
		"getSinkOffsetY": 0x801895e0,
		"TMapEventSink::isBuried": 0x801895f4,
		"isBuried": 0x801895f4,
		"TMapEventSink::getBuilding": 0x80189610,
		"TMapEventSinkBianco::~TMapEventSinkBianco": 0x80189634,
		"Map::__sinit_MapEventSink_cpp": 0x80189884,
		"__sinit_MapEventSink_cpp": 0x80189884,
		"TMapCollisionBase::initCheckData": 0x80189b80,
		"initCheckData": 0x80189b80,
		"TMapCollisionBase::initAllCheckData": 0x80189c34,
		"initAllCheckData": 0x80189c34,
		"TMapCollisionBase::update": 0x80189e70,
		"TMapCollisionBase::updateTrans": 0x80189f04,
		"updateTrans": 0x80189f04,
		"TMapCollisionBase::setCheckData": 0x8018a09c,
		"setCheckData": 0x8018a09c,
		"TMapCollisionMove::setList": 0x8018a300,
		"setList": 0x8018a300,
		"TBGCheckData::setVertex": 0x8018a364,
		"setVertex": 0x8018a364,
		"Map::__sinit_MapMakeData_cpp": 0x8018a52c,
		"__sinit_MapMakeData_cpp": 0x8018a52c,
		"TMapCollisionData::removeCheckListData": 0x8018a828,
		"removeCheckListData": 0x8018a828,
		"TMapCollisionData::updateCheckListNode": 0x8018aa88,
		"updateCheckListNode": 0x8018aa88,
		"TMapCollisionData::addCheckDataToGrid": 0x8018ab88,
		"addCheckDataToGrid": 0x8018ab88,
		"TMapCollisionData::getGridArea": 0x8018b100,
		"getGridArea": 0x8018b100,
		"Map::addGroundNode": 0x8018b2e0,
		"addGroundNode": 0x8018b2e0,
		"Map::addRoofNode": 0x8018b328,
		"addRoofNode": 0x8018b328,
		"Map::addWallNode": 0x8018b370,
		"addWallNode": 0x8018b370,
		"Map::addAfterPreNode": 0x8018b3b8,
		"addAfterPreNode": 0x8018b3b8,
		"TMapCollisionData::allocCheckList": 0x8018b44c,
		"allocCheckList": 0x8018b44c,
		"TMapCollisionData::getEntryID": 0x8018b4b8,
		"getEntryID": 0x8018b4b8,
		"TMapCollisionData::allocCheckData": 0x8018b4fc,
		"allocCheckData": 0x8018b4fc,
		"TMirrorMapDrawBuf::~TMirrorMapDrawBuf": 0x8018b518,
		"TMirrorMapDrawBuf::perform": 0x8018b59c,
		"TMirrorModelManager::TMirrorModelManager": 0x8018b5e8,
		"TMirrorModelManager::load": 0x8018b670,
		"TMirrorModelManager::loadAfter": 0x8018b81c,
		"TMirrorModelManager::perform": 0x8018b92c,
		"JGeometry::TVec3<float><float>::scaleAdd": 0x8018bd64,
		"scaleAdd": 0x8018bd64,
		"TMirrorModel::calc": 0x8018bd98,
		"TMirrorModelManager::isInMirror": 0x8018bdac,
		"isInMirror": 0x8018bdac,
		"TMirrorModelManager::isUpperThanMirrorPlane": 0x8018bdf0,
		"isUpperThanMirrorPlane": 0x8018bdf0,
		"TMirrorModel::getD": 0x8018bed0,
		"getD": 0x8018bed0,
		"TMirrorModel::getNormalVec": 0x8018bed8,
		"getNormalVec": 0x8018bed8,
		"TMirrorModelObj::init": 0x8018bee0,
		"TMirrorModelObj::calc": 0x8018c030,
		"TMirrorModelObj::setPlane": 0x8018c064,
		"TMirrorModel::TMirrorModel": 0x8018c118,
		"TMirrorModel::init": 0x8018c154,
		"TMirrorModel::initPlaneInfo": 0x8018c27c,
		"initPlaneInfo": 0x8018c27c,
		"TMirrorModel::setPlane": 0x8018c460,
		"TMirrorCamera::TMirrorCamera": 0x8018c500,
		"TMirrorCamera::drawSetting": 0x8018c7a8,
		"drawSetting": 0x8018c7a8,
		"TMirrorCamera::perform": 0x8018c844,
		"TMirrorModelManager::~TMirrorModelManager": 0x8018c8fc,
		"Map::__sinit_MapMirror_cpp": 0x8018c9dc,
		"__sinit_MapMirror_cpp": 0x8018c9dc,
		"TMapModel::getJ3DModelDataFlag": 0x8018cce0,
		"TMapModelManager::TMapModelManager": 0x8018cce8,
		"TMapModelManager::init": 0x8018cd2c,
		"TMapModel::initJointModel": 0x8018cdbc,
		"TMapModel::initUnderpass": 0x8018ce4c,
		"initUnderpass": 0x8018ce4c,
		"TMapModel::perform": 0x8018d0cc,
		"TMapModelManager::~TMapModelManager": 0x8018d26c,
		"TMapModelManager::newJointModel": 0x8018d3c4,
		"Map::__sinit_MapModel_cpp": 0x8018d42c,
		"__sinit_MapModel_cpp": 0x8018d42c,
		"TMapWarp::TMapWarp": 0x8018d728,
		"TMapWarp::init": 0x8018d744,
		"TMapWarp::TMapWarpInfo::TMapWarpInfo": 0x8018da6c,
		"TMapWarp::initModel": 0x8018da70,
		"TMapWarp::watchToWarp": 0x8018db08,
		"watchToWarp": 0x8018db08,
		"TMapWarp::changeModel": 0x8018de28,
		"Map::__sinit_MapWarp_cpp": 0x8018dec4,
		"__sinit_MapWarp_cpp": 0x8018dec4,
		"TMapObjSoundGroup::~TMapObjSoundGroup": 0x8018e1c0,
		"TMapObjSoundGroup::TMapObjSoundGroup": 0x8018e234,
		"TMapObjSoundGroup::load": 0x8018e2a8,
		"TMapObjSoundGroup::perform": 0x8018e39c,
		"TMapModelActor::perform": 0x8018e52c,
		"TMapStaticObj::TMapStaticObj": 0x8018e608,
		"TMapStaticObj::load": 0x8018e66c,
		"TMapStaticObj::loadAfter": 0x8018e6b0,
		"TMapStaticObj::init": 0x8018e6f4,
		"TMapStaticObj::initModel": 0x8018eaec,
		"TMapStaticObj::initUnique": 0x8018ec1c,
		"TMapStaticObj::perform": 0x8018ee9c,
		"TMapStaticObj::getModelData": 0x8018f18c,
		"getModelData": 0x8018f18c,
		"Map::__sinit_MapStaticObject_cpp": 0x8018f2a4,
		"__sinit_MapStaticObject_cpp": 0x8018f2a4,
		"TMapWire::TMapWire": 0x8018f5b0,
		"TMapWire::init": 0x8018f62c,
		"TMapWire::getPointPosOnWire": 0x8018fd48,
		"getPointPosOnWire": 0x8018fd48,
		"TMapWire::getPosInWire": 0x8018fed8,
		"TMapWire::move": 0x80190074,
		"TMapWire::calcViewAndDBEntry": 0x801902f4,
		"calcViewAndDBEntry": 0x801902f4,
		"TMapWire::setFootPointsAtHanged": 0x80190344,
		"setFootPointsAtHanged": 0x80190344,
		"TMapWire::getPointPosAtHanged": 0x801905dc,
		"getPointPosAtHanged": 0x801905dc,
		"TMapWire::release": 0x80190680,
		"TMapWire::getPointPowerAtReleased": 0x80190ac4,
		"getPointPowerAtReleased": 0x80190ac4,
		"TMapWire::drawUpper": 0x80190b00,
		"TMapWire::drawLower": 0x80190c30,
		"drawLower": 0x80190c30,
		"TMapWirePoint::TMapWirePoint": 0x80190e3c,
		"Map::__sinit_MapWire_cpp": 0x80190e64,
		"__sinit_MapWire_cpp": 0x80190e64,
		"TMapWireManager::~TMapWireManager": 0x80191160,
		"TMapWireManager::TMapWireManager": 0x801911d4,
		"TMapWireManager::load": 0x80191288,
		"TMapWireManager::loadAfter": 0x80191438,
		"JGadget::TList_pointer<THitActor*>::insert": 0x80191540,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::getChildren": 0x8019158c,
		"getChildren": 0x8019158c,
		"JDrama::TNameRef::search": 0x80191594,
		"JDrama::TNameRefGen::getRootNameRef": 0x801915ec,
		"getRootNameRef": 0x801915ec,
		"JDrama::TNameRefGen::getInstance": 0x801915f4,
		"getInstance": 0x801915f4,
		"TMapWireManager::perform": 0x80191698,
		"TMapWireManager::getPointPosInNthWire": 0x80191850,
		"getPointPosInNthWire": 0x80191850,
		"TMapWireManager::getWireNo": 0x801918b0,
		"getWireNo": 0x801918b0,
		"TMapWireActorManager::doActorToWire": 0x801918d4,
		"doActorToWire": 0x801918d4,
		"Map::initDraw": 0x80191ab8,
		"TMapWireActor::TMapWireActor": 0x80191c00,
		"TMapWireActor::receiveMessage": 0x80191c6c,
		"TMapWireActor::getTipPoints": 0x80191ca0,
		"getTipPoints": 0x80191ca0,
		"TMapWireActor::getPosInWire": 0x80191cdc,
		"TMapWireActor::getTakingMtx": 0x80191e84,
		"Map::__sinit_MapWireManager_cpp": 0x80191e8c,
		"__sinit_MapWireManager_cpp": 0x80191e8c,
		"TMapXlu::TMapXlu": 0x8019219c,
		"TMapXlu::init": 0x801921ac,
		"TMapXlu::changeXluJoint": 0x801922c0,
		"changeXluJoint": 0x801922c0,
		"TMapXlu::changeNormalJoint": 0x801923d8,
		"changeNormalJoint": 0x801923d8,
		"Map::__sinit_MapXlu_cpp": 0x801924d8,
		"__sinit_MapXlu_cpp": 0x801924d8,
		"TPollutionLayer::action": 0x801927d4,
		"TPollutionLayer::getPlaneType": 0x80192ba0,
		"TPollutionLayer::fire": 0x80192ba8,
		"fire": 0x80192ba8,
		"TPollutionLayer::getPollutedPos": 0x80192cf8,
		"getPollutedPos": 0x80192cf8,
		"TPollutionLayer::getPollutedPosNear": 0x80192e20,
		"getPollutedPosNear": 0x80192e20,
		"TPollutionLayer::getTexPosS": 0x80193064,
		"TPollutionLayer::isInArea": 0x80193090,
		"Map::__sinit_PollutionAction_cpp": 0x801930d0,
		"__sinit_PollutionAction_cpp": 0x801930d0,
		"TPollutionRevivalTexStamp::TPollutionRevivalTexStamp": 0x801933cc,
		"TPollutionTexStamp::TPollutionTexStamp": 0x801933f8,
		"TPollutionLayerTaskInfo::TPollutionLayerTaskInfo": 0x80193418,
		"TPollutionTexStamp::pushTask": 0x80193434,
		"pushTask": 0x80193434,
		"TPollutionCounterLayer::TPollutionCounterLayer": 0x801934b0,
		"TPollutionJointObjTaskInfo::TPollutionJointObjTaskInfo": 0x80193580,
		"TPollutionModelTaskInfo::TPollutionModelTaskInfo": 0x80193594,
		"TPollutionCounterLayer::init": 0x801935a4,
		"TPollutionCounterLayer::offLayer": 0x80193828,
		"offLayer": 0x80193828,
		"TPollutionCounterLayer::stampIsCleanType": 0x80193848,
		"stampIsCleanType": 0x80193848,
		"TPollutionCounterLayer::registerLayer": 0x80193870,
		"registerLayer": 0x80193870,
		"TPollutionCounterLayer::registerTexStamp": 0x801938bc,
		"registerTexStamp": 0x801938bc,
		"TPollutionCounterLayer::registerRevivalTexStamp": 0x80193960,
		"registerRevivalTexStamp": 0x80193960,
		"TPollutionCounterLayer::pushModelStampTask": 0x801939a8,
		"pushModelStampTask": 0x801939a8,
		"TPollutionCounterLayer::calcViewMtx": 0x801939f4,
		"calcViewMtx": 0x801939f4,
		"TPollutionCounterLayer::pushJointObjStampTask": 0x80193b74,
		"pushJointObjStampTask": 0x80193b74,
		"TPollutionCounterLayer::resetTask": 0x80193bbc,
		"resetTask": 0x80193bbc,
		"TPollutionCounterLayer::countTexDegree": 0x80193c28,
		"countTexDegree": 0x80193c28,
		"TPollutionCounterLayer::cleanProhibitArea": 0x80193e7c,
		"cleanProhibitArea": 0x80193e7c,
		"TPollutionCounterLayer::drawRevivalTexStamp": 0x80194060,
		"drawRevivalTexStamp": 0x80194060,
		"Map::initGXforStamp": 0x8019434c,
		"initGXforStamp": 0x8019434c,
		"Map::doTask": 0x80194618,
		"doTask": 0x80194618,
		"TPollutionCounterLayer::drawJointObjStamp": 0x80194808,
		"drawJointObjStamp": 0x80194808,
		"Map::initGXforPollutionLayer": 0x80194a90,
		"initGXforPollutionLayer": 0x80194a90,
		"Map::drawTex": 0x80194e50,
		"drawTex": 0x80194e50,
		"TPollutionCounterObj::TPollutionCounterObj": 0x80194f34,
		"TPollutionCounterObj::init": 0x80194f74,
		"TPollutionCounterObj::registerPollutionObj": 0x801951f8,
		"registerPollutionObj": 0x801951f8,
		"TPollutionCounterObj::countObjDegree": 0x801952a0,
		"countObjDegree": 0x801952a0,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setEular": 0x80195574,
		"Map::initDrawObjGX": 0x8019561c,
		"initDrawObjGX": 0x8019561c,
		"TPollutionCounterBase::drawSyncCallback": 0x801957d4,
		"Map::drawBlack": 0x8019585c,
		"drawBlack": 0x8019585c,
		"TPollutionCounterObj::getCounterNo": 0x801959e8,
		"TPollutionCounterObj::getTokenNo": 0x801959f0,
		"TPollutionCounterLayer::getCounterNo": 0x801959f8,
		"TPollutionCounterLayer::getTokenNo": 0x80195a00,
		"Map::__sinit_PollutionCount_cpp": 0x80195a08,
		"__sinit_PollutionCount_cpp": 0x80195a08,
		"TPollutionManager::~TPollutionManager": 0x80195d04,
		"TPollutionManager::TPollutionManager": 0x80195da0,
		"TPollutionManager::load": 0x80195e14,
		"TPollutionManager::setDataAddress": 0x80195f78,
		"setDataAddress": 0x80195f78,
		"TPollutionManager::newJointModel": 0x80195fc4,
		"TPollutionManager::perform": 0x80196150,
		"TPollutionManager::cleanedAll": 0x801961e8,
		"cleanedAll": 0x801961e8,
		"TPollutionManager::isPolluted": 0x801962f4,
		"TPollutionManager::getPollutionDegree": 0x801963a8,
		"getPollutionDegree": 0x801963a8,
		"TPollutionManager::getPollutionType": 0x801964a0,
		"getPollutionType": 0x801964a0,
		"TPollutionManager::stampGround": 0x8019655c,
		"stampGround": 0x8019655c,
		"TPollutionManager::clean": 0x8019663c,
		"clean": 0x8019663c,
		"TPollutionManager::stamp": 0x8019670c,
		"TPollutionManager::stampModel": 0x801967cc,
		"TPollutionLayerWallMinusX::getPlaneType": 0x8019686c,
		"TPollutionLayerWallMinusX::getTexPosS": 0x80196874,
		"TPollutionLayerWallPlusX::isInArea": 0x801968a0,
		"TPollutionLayerWallPlusX::isInAreaSize": 0x801968e0,
		"TPollutionLayerWallBase::getTexPosT": 0x80196930,
		"TPollutionLayer::getTexResource": 0x8019695c,
		"TPollutionLayer::newJointObj": 0x8019696c,
		"TPollutionLayer::getJ3DModelDataFlag": 0x801969ac,
		"TPollutionLayerWallMinusZ::getPlaneType": 0x801969b4,
		"TPollutionLayerWallMinusZ::getTexPosS": 0x801969bc,
		"TPollutionLayerWallPlusZ::isInArea": 0x801969e8,
		"TPollutionLayerWallPlusZ::isInAreaSize": 0x80196a28,
		"Map::__sinit_PollutionManager_cpp": 0x80196a78,
		"__sinit_PollutionManager_cpp": 0x80196a78,
		"TPollutionObj::TPollutionObj": 0x80196d74,
		"TPollutionObj::initAreaInfo": 0x80196dcc,
		"initAreaInfo": 0x80196dcc,
		"TPollutionLayer::getTexPosT": 0x80196f18,
		"TPollutionObj::isCleaned": 0x80196f44,
		"isCleaned": 0x80196f44,
		"TPollutionObj::updateDepthMap": 0x80196f64,
		"updateDepthMap": 0x80196f64,
		"TPollutionObj::getDepthFromMap": 0x80197008,
		"getDepthFromMap": 0x80197008,
		"TPollutionObj::newJointObj": 0x8019723c,
		"Map::__sinit_PollutionObj_cpp": 0x801972a4,
		"__sinit_PollutionObj_cpp": 0x801972a4,
		"TPollutionPos::TPollutionPos": 0x801975a0,
		"TPollutionPos::init": 0x801975d0,
		"TPollutionPos::worldToTexSize": 0x80197618,
		"worldToTexSize": 0x80197618,
		"TPollutionPos::worldToDepth": 0x80197638,
		"worldToDepth": 0x80197638,
		"TPollutionPos::isProhibit": 0x80197660,
		"isProhibit": 0x80197660,
		"TPollutionPos::isSame": 0x801976dc,
		"TPollutionPos::getDepthWorld": 0x801977b0,
		"getDepthWorld": 0x801977b0,
		"TPollutionPos::getEdgeDegree": 0x8019782c,
		"getEdgeDegree": 0x8019782c,
		"Map::__sinit_PollutionPos_cpp": 0x80197980,
		"__sinit_PollutionPos_cpp": 0x80197980,
		"TShimmer::TShimmer": 0x80197ce8,
		"TShimmer::load": 0x80197e34,
		"TShimmer::loadAfter": 0x80197fc8,
		"TShimmer::perform": 0x801980c4,
		"Map::__sinit_Shimmer_cpp": 0x8019834c,
		"__sinit_Shimmer_cpp": 0x8019834c,
		"TSky::TSky": 0x801986bc,
		"TSky::load": 0x801987d4,
		"TSky::perform": 0x8019886c,
		"Map::__sinit_Sky_cpp": 0x80198bc4,
		"__sinit_Sky_cpp": 0x80198bc4,
		"TMapEventSirenaSink::~TMapEventSirenaSink": 0x80198ec8,
		"TMapEventSirenaSink::initPollution": 0x80198f5c,
		"initPollution": 0x80198f5c,
		"TMapEventSirenaSink::makePollutionRecovered": 0x80198f60,
		"makePollutionRecovered": 0x80198f60,
		"TMapEventSirenaSink::TMapEventSirenaSink": 0x80198f64,
		"TMapEventSirenaSink::load": 0x80198fc8,
		"TMapEventSirenaSink::loadAfter": 0x801990c0,
		"TMapEventSirenaSink::watch": 0x80199164,
		"Map::__sinit_MapEventSirena_cpp": 0x8019927c,
		"__sinit_MapEventSirena_cpp": 0x8019927c,
		"TPollutionLayer::isInAreaSize": 0x80199578,
		"TPollutionLayer::TPollutionLayer": 0x801995c8,
		"TPollutionLayer::initJointModel": 0x80199688,
		"TPollutionLayer::initLayerInfo": 0x8019983c,
		"TPollutionLayer::initTexImage": 0x8019993c,
		"initTexImage": 0x8019993c,
		"TPollutionLayer::perform": 0x80199b10,
		"TPollutionLayer::isPolluted": 0x80199b70,
		"TPollutionLayer::stamp": 0x80199cc8,
		"TPollutionLayer::cleaned": 0x80199e14,
		"cleaned": 0x80199e14,
		"TPollutionLayer::appearItem": 0x8019a1e8,
		"appearItem": 0x8019a1e8,
		"TPollutionLayer::stampModel": 0x8019a1ec,
		"TPollutionLayerWallBase::TPollutionLayerWallBase": 0x8019a264,
		"TPollutionLayerWallPlusX::initLayerInfo": 0x8019a2ac,
		"TPollutionLayerWallPlusX::stamp": 0x8019a300,
		"TPollutionLayerWallPlusX::getTexPosS": 0x8019a400,
		"TPollutionLayerWallPlusZ::initLayerInfo": 0x8019a42c,
		"TPollutionLayerWallPlusZ::stamp": 0x8019a470,
		"TPollutionLayerWave::initJointModel": 0x8019a570,
		"TPollutionLayerWave::getTexResource": 0x8019a684,
		"TPollutionLayerWave::perform": 0x8019a6c4,
		"TPollutionLayerWave::draw": 0x8019a704,
		"TPollutionLayerWave::initGX": 0x8019a888,
		"initGX": 0x8019a888,
		"TPollutionLayerWallPlusX::getPlaneType": 0x8019aaa8,
		"TPollutionLayerWallPlusZ::getPlaneType": 0x8019aab0,
		"TPollutionLayerWave::getPlaneType": 0x8019aab8,
		"Map::__sinit_PollutionLayer_cpp": 0x8019aac0,
		"__sinit_PollutionLayer_cpp": 0x8019aac0,
		"TPollutionTest::loadAfter": 0x8019adbc,
		"TPollutionTest::~TPollutionTest": 0x8019addc,
		"TPollutionTest::perform": 0x8019ae50,
		"Map::__sinit_PollutionEvent_cpp": 0x8019ae54,
		"__sinit_PollutionEvent_cpp": 0x8019ae54,
		"TMapCheckGroundPlane::TMapCheckGroundPlane": 0x8019b150,
		"TMapCheckGroundPlane::init": 0x8019b178,
		"TMapCheckGroundPlane::checkPlaneGround": 0x8019b240,
		"checkPlaneGround": 0x8019b240,
		"TMapCheckGroundPlane::getCheckData": 0x8019b374,
		"getCheckData": 0x8019b374,
		"Map::__sinit_MapCollisionPlane_cpp": 0x8019b398,
		"__sinit_MapCollisionPlane_cpp": 0x8019b398,
		"TMarineSnow::perform": 0x8019b700,
		"TMarineSnow::loadAfter": 0x8019b75c,
		"TMarineSnow::TMarineSnow": 0x8019b7b4,
		"TBGCheckData::TBGCheckData": 0x8019b8c0,
		"TBGCheckData::getPlaneType": 0x8019b918,
		"TBGCheckData::getActiveJumpPower": 0x8019b9ac,
		"getActiveJumpPower": 0x8019b9ac,
		"Map::__sinit_MapData_cpp": 0x8019ba10,
		"__sinit_MapData_cpp": 0x8019ba10,
		"TDolpicEventRiccoMammaGate::~TDolpicEventRiccoMammaGate": 0x8019bd0c,
		"TDolpicEventRiccoMammaGate::TDolpicEventRiccoMammaGate": 0x8019bda0,
		"TDolpicEventRiccoMammaGate::load": 0x8019be28,
		"TDolpicEventRiccoMammaGate::loadAfter": 0x8019c0a8,
		"TDolpicEventRiccoMammaGate::watch": 0x8019c180,
		"TDolpicEventRiccoMammaGate::control": 0x8019c390,
		"TDolpicEventRiccoMammaGate::isFinishedAll": 0x8019c580,
		"TDolpicEventBiancoGate::TDolpicEventBiancoGate": 0x8019c5b0,
		"TDolpicEventBiancoGate::loadAfter": 0x8019c5fc,
		"TDolpicEventBiancoGate::watch": 0x8019c688,
		"TDolpicEventBiancoGate::control": 0x8019c6f8,
		"TDolpicEventBiancoGate::isFinishedAll": 0x8019c7ac,
		"TDolpicEventBiancoGate::~TDolpicEventBiancoGate": 0x8019c7dc,
		"Map::__sinit_MapEventDolpic_cpp": 0x8019c870,
		"__sinit_MapEventDolpic_cpp": 0x8019c870,
		"TMareEventBumpyWall::TMareEventBumpyWall": 0x8019cbf0,
		"TMareEventBumpyWall::load": 0x8019cc58,
		"TMareEventBumpyWall::control": 0x8019cd64,
		"TMareEventBumpyWall::bumpUpX": 0x8019ce10,
		"bumpUpX": 0x8019ce10,
		"TMareEventBumpyWall::bumpDownX": 0x8019cf60,
		"bumpDownX": 0x8019cf60,
		"TMareEventBumpyWall::bumpUpZ": 0x8019d0b4,
		"bumpUpZ": 0x8019d0b4,
		"TMareEventBumpyWall::bumpDownZ": 0x8019d204,
		"bumpDownZ": 0x8019d204,
		"TMareEventBumpyWall::touchWater": 0x8019d354,
		"TMareEventDepressWall::TMareEventDepressWall": 0x8019d400,
		"TMareEventDepressWall::init1stEvent": 0x8019d4a4,
		"init1stEvent": 0x8019d4a4,
		"TMareEventDepressWall::init2ndEvent": 0x8019d558,
		"init2ndEvent": 0x8019d558,
		"TMareEventDepressWall::init3rdEvent": 0x8019d60c,
		"init3rdEvent": 0x8019d60c,
		"TMareEventDepressWall::initCommon": 0x8019d794,
		"initCommon": 0x8019d794,
		"TMareEventDepressWall::startEvent": 0x8019dc0c,
		"TMareEventDepressWall::perform": 0x8019dcc4,
		"TMareEventDepressWall::depressing": 0x8019dde0,
		"depressing": 0x8019dde0,
		"TMareEventDepressWall::rising": 0x8019e22c,
		"TMareEventWallRock::TMareEventWallRock": 0x8019e594,
		"TMareEventWallRock::load": 0x8019e608,
		"TMareWallRock::TMareWallRock": 0x8019e788,
		"TMareWallRock::load": 0x8019e814,
		"TMareWallRock::loadAfter": 0x8019e834,
		"TMareWallRock::initEffect": 0x8019e9f4,
		"initEffect": 0x8019e9f4,
		"TMareWallRock::perform": 0x8019eb78,
		"TMareWallRock::movement": 0x8019ebd8,
		"TMareWallRock::appear": 0x8019ef60,
		"TMareEventDepressWall::~TMareEventDepressWall": 0x8019f0f8,
		"TMareEventWallRock::~TMareEventWallRock": 0x8019f16c,
		"TMareEventWallRock::perform": 0x8019f1e0,
		"Map::__sinit_MapEventMare_cpp": 0x8019f1e4,
		"__sinit_MapEventMare_cpp": 0x8019f1e4,
		"TBathWaterManager::~TBathWaterManager": 0x8019f4f0,
		"TBathWaterManager::perform": 0x8019f59c,
		"JGeometry::TBox<JGeometry::TVec3<float><float>>::operator_=": 0x801a0920,
		"TBathtubData::getPos": 0x801a0954,
		"getPos": 0x801a0954,
		"JMath::TRandom_fast_::get_ufloat_1": 0x801a0af4,
		"get_ufloat_1": 0x801a0af4,
		"JGeometry::TVec3<float><float>::setMax": 0x801a0b38,
		"setMax": 0x801a0b38,
		"JGeometry::TVec3<float><float>::setMin": 0x801a0b84,
		"setMin": 0x801a0b84,
		"TBathWater::TDrop::calcBathtub": 0x801a0bd0,
		"calcBathtub": 0x801a0bd0,
		"TBathtubData::getGravityDir": 0x801a13c4,
		"getGravityDir": 0x801a13c4,
		"TBathWaterManager::throwMario": 0x801a1600,
		"TBathWaterManager::getWaterHeight": 0x801a18f8,
		"getWaterHeight": 0x801a18f8,
		"TBathWaterManager::initializeIfYet_": 0x801a1944,
		"initializeIfYet_": 0x801a1944,
		"TBathWaterManager::loadAfter": 0x801a2600,
		"TBathWaterMeshRenderer::clearHeightMap": 0x801a298c,
		"clearHeightMap": 0x801a298c,
		"TBathWaterManager::load": 0x801a2b48,
		"TBathWaterManager::TBathWaterManager": 0x801a2bd8,
		"TBathWater::TDrop::TDrop": 0x801a2d5c,
		"TBathWaterPreprocessor::~TBathWaterPreprocessor": 0x801a2d60,
		"TBathWaterPreprocessor::perform": 0x801a2dd4,
		"Map::init_tobj_resource": 0x801a2e3c,
		"init_tobj_resource": 0x801a2e3c,
		"Map::draw_mist": 0x801a2ef8,
		"draw_mist": 0x801a2ef8,
		"@unnamed@::clearEFB_alpha": 0x801a36c4,
		"clearEFB_alpha": 0x801a36c4,
		"Map::drawCap": 0x801a39d0,
		"drawCap": 0x801a39d0,
		"TBathWaterGlobalParams::TBathWaterGlobalParams": 0x801a3ad0,
		"TBathWaterParams::TBathWaterParams": 0x801a3fbc,
		"TBathWaterMeshRenderer::getHeight": 0x801a4418,
		"TBathWaterMeshRenderer::prerender": 0x801a44e0,
		"JGeometry::SMatrix44C<float><float>::SMatrix44C": 0x801a4f20,
		"SMatrix44C": 0x801a4f20,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setLookDir": 0x801a4f24,
		"setLookDir": 0x801a4f24,
		"TBathWaterMeshRenderer::render": 0x801a5104,
		"TBathWaterMeshRenderer::calcCoord": 0x801a5f28,
		"calcCoord": 0x801a5f28,
		"TBathWaterMeshRenderer::makeNormalMap": 0x801a635c,
		"makeNormalMap": 0x801a635c,
		"TBathWaterMeshRenderer::makeHeightMap": 0x801a656c,
		"makeHeightMap": 0x801a656c,
		"Map::__sinit_BathWaterManager_cpp": 0x801a667c,
		"__sinit_BathWaterManager_cpp": 0x801a667c,
		"TStickyStainManager::~TStickyStainManager": 0x801a6980,
		"TStickyStainManager::perform": 0x801a69f4,
		"TCoord2D::update": 0x8013362c,
		"TCoord2D::setValue": 0x801336d4,
		"setValue": 0x801336d4,
		"TCoord2D::TCoord2D": 0x8013374c,
		"TExPane::update": 0x8013376c,
		"TExPane::TExPane": 0x80133a50,
		"TFlashPane::~TFlashPane": 0x80133b24,
		"TFlashPane::perform": 0x80133b98,
		"TMenuPlane::perform": 0x80133c08,
		"TMenuPlane::TMenuPlane": 0x80133d94,
		"TMenuBase::perform": 0x80133f64,
		"TMenuPlane::~TMenuPlane": 0x80134058,
		"TMenuBase::~TMenuBase": 0x801340cc,
		"TSMSFader::setFadeStatus": 0x801341b4,
		"setFadeStatus": 0x801341b4,
		"TSMSFader::setDisplaySize": 0x801341fc,
		"setDisplaySize": 0x801341fc,
		"TSMSFader::load": 0x80134224,
		"TSMSFader::setColor": 0x8013433c,
		"TSMSFader::startFadeoutT": 0x80134384,
		"startFadeoutT": 0x80134384,
		"TSMSFader::startFadeinT": 0x801343b0,
		"startFadeinT": 0x801343b0,
		"TSMSFader::startWipe": 0x801343dc,
		"startWipe": 0x801343dc,
		"TSMSFader::requestWipe": 0x801343ec,
		"requestWipe": 0x801343ec,
		"TSMSFader::drawFadeinout": 0x801345d0,
		"drawFadeinout": 0x801345d0,
		"TSMSFader::draw": 0x80134804,
		"TSMSFader::update": 0x801349a0,
		"TSMSFader::perform": 0x80134afc,
		"TSMSFader::TSMSFader": 0x80134b84,
		"@unnamed@::draw_wipe_box": 0x80134c48,
		"draw_wipe_box": 0x80134c48,
		"@unnamed@::fill_rect": 0x80134f0c,
		"fill_rect": 0x80134f0c,
		"GC2D::__sinit_ScrnFader_cpp": 0x80135048,
		"__sinit_ScrnFader_cpp": 0x80135048,
		"TGCConsole2::~TGCConsole2": 0x80135344,
		"TGCConsole2::perform": 0x801353b8,
		"TGCConsole2::drawWater": 0x80138e1c,
		"drawWater": 0x80138e1c,
		"TGCConsole2::drawJuice": 0x8013947c,
		"drawJuice": 0x8013947c,
		"TGCConsole2::processDisappearBalloon": 0x80139a94,
		"processDisappearBalloon": 0x80139a94,
		"TGCConsole2::processAppearBalloon": 0x80139c68,
		"processAppearBalloon": 0x80139c68,
		"TGCConsole2::processAppearTimer": 0x80139d7c,
		"processAppearTimer": 0x80139d7c,
		"TGCConsole2::processAppearRed": 0x8013a208,
		"processAppearRed": 0x8013a208,
		"TGCConsole2::processAppearJet": 0x8013a520,
		"processAppearJet": 0x8013a520,
		"TGCConsole2::checkChangeTelopArray": 0x8013a7e8,
		"checkChangeTelopArray": 0x8013a7e8,
		"TGCConsole2::processDrawTelop": 0x8013a974,
		"processDrawTelop": 0x8013a974,
		"TGCConsole2::processAppearMario": 0x8013aa1c,
		"processAppearMario": 0x8013aa1c,
		"TGCConsole2::processAppearCoin": 0x8013ad40,
		"processAppearCoin": 0x8013ad40,
		"TGCConsole2::processAppearTank": 0x8013b0a4,
		"processAppearTank": 0x8013b0a4,
		"TGCConsole2::processDownCoin": 0x8013b32c,
		"processDownCoin": 0x8013b32c,
		"TGCConsole2::processAppearStar": 0x8013b69c,
		"processAppearStar": 0x8013b69c,
		"TBlendPane::setPaneBlend": 0x801399c0,
		"setPaneBlend": 0x801399c0,
		"TExPane::setPaneOffset": 0x8013bdfc,
		"setPaneOffset": 0x8013bdfc,
		"TCoord2D::roundf": 0x8013bec8,
		"roundf": 0x8013bec8,
		"TGCConsole2::processInsertLife": 0x8013bf10,
		"processInsertLife": 0x8013bf10,
		"TGCConsole2::processAppearLife": 0x8013c0d4,
		"processAppearLife": 0x8013c0d4,
		"TGCConsole2::getFinishedTime": 0x8013c1cc,
		"getFinishedTime": 0x8013c1cc,
		"TGCConsole2::stopMoveTimer": 0x8013c1d4,
		"stopMoveTimer": 0x8013c1d4,
		"TGCConsole2::startMoveTimer": 0x8013c1ec,
		"startMoveTimer": 0x8013c1ec,
		"TGCConsole2::setTimer": 0x8013cff0,
		"setTimer": 0x8013cff0,
		"TGCConsole2::processMoveNozzle": 0x8013dab4,
		"processMoveNozzle": 0x8013dab4,
		"TGCConsole2::startAppearMario": 0x8013dbf4,
		"startAppearMario": 0x8013dbf4,
		"TGCConsole2::startDisappearMario": 0x8013dde8,
		"startDisappearMario": 0x8013dde8,
		"TGCConsole2::drawWaterBack": 0x8013df34,
		"drawWaterBack": 0x8013df34,
		"TGCConsole2::startAppearStar": 0x8013e790,
		"startAppearStar": 0x8013e790,
		"TGCConsole2::startDisappearStar": 0x8013eb5c,
		"startDisappearStar": 0x8013eb5c,
		"TGCConsole2::startAppearBalloon": 0x8013ee7c,
		"startAppearBalloon": 0x8013ee7c,
		"TGCConsole2::startDisappearBalloon": 0x8013f134,
		"startDisappearBalloon": 0x8013f134,
		"TGCConsole2::pauseOut": 0x8013f18c,
		"pauseOut": 0x8013f18c,
		"TGCConsole2::pauseIn": 0x8013f520,
		"pauseIn": 0x8013f520,
		"TGCConsole2::startAppearRedCoin": 0x8013f64c,
		"startAppearRedCoin": 0x8013f64c,
		"TGCConsole2::startInsertJetBalloon": 0x8013f7f0,
		"startInsertJetBalloon": 0x8013f7f0,
		"TGCConsole2::startAppearJetBalloon": 0x8013f994,
		"startAppearJetBalloon": 0x8013f994,
		"TGCConsole2::startInsertTimer": 0x8013fac0,
		"startInsertTimer": 0x8013fac0,
		"TGCConsole2::startAppearTimer": 0x8013fc5c,
		"startAppearTimer": 0x8013fc5c,
		"TGCConsole2::startDisappearTimer": 0x8013fe68,
		"startDisappearTimer": 0x8013fe68,
		"TGCConsole2::startDisappearTelop": 0x8013ff98,
		"startDisappearTelop": 0x8013ff98,
		"TGCConsole2::startAppearTelop": 0x801400e0,
		"startAppearTelop": 0x801400e0,
		"TGCConsole2::startDownLeftBot": 0x801402b8,
		"startDownLeftBot": 0x801402b8,
		"TGCConsole2::startAppearLife": 0x8014067c,
		"startAppearLife": 0x8014067c,
		"TGCConsole2::resetLife": 0x80140be4,
		"resetLife": 0x80140be4,
		"TGCConsole2::startInsertLife": 0x80140cec,
		"startInsertLife": 0x80140cec,
		"TGCConsole2::startDisappearCoin": 0x801411a8,
		"startDisappearCoin": 0x801411a8,
		"TGCConsole2::startAppearCoin": 0x80141478,
		"startAppearCoin": 0x80141478,
		"TGCConsole2::startAppearTank": 0x8014178c,
		"startAppearTank": 0x8014178c,
		"TGCConsole2::endCameraDemo": 0x801418b0,
		"endCameraDemo": 0x801418b0,
		"TGCConsole2::startCameraDemo": 0x80141b14,
		"startCameraDemo": 0x80141b14,
		"TGCConsole2::entryHelpActor": 0x80142434,
		"entryHelpActor": 0x80142434,
		"TGCConsole2::loadAfter": 0x80142514,
		"TGCConsole2::load": 0x8014398c,
		"TGCConsole2::TGCConsole2": 0x8014484c,
		"JUTPoint::JUTPoint": 0x80144d54,
		"GC2D::__sinit_GCConsole2_cpp": 0x80144db0,
		"__sinit_GCConsole2_cpp": 0x80144db0,
		"TTalk2D2::~TTalk2D2": 0x80145130,
		"TTalk2D2::openWindow": 0x801451a4,
		"openWindow": 0x801451a4,
		"TTalk2D2::setTagParam": 0x80145678,
		"setTagParam": 0x80145678,
		"TTalk2D2::setupTextBox": 0x80146230,
		"setupTextBox": 0x80146230,
		"TTalk2D2::setupBoardTextBox": 0x80146794,
		"setupBoardTextBox": 0x80146794,
		"TTalk2D2::perform": 0x80146aa4,
		"TTalk2D2::eraseBoardWindow": 0x801470dc,
		"eraseBoardWindow": 0x801470dc,
		"TTalk2D2::eraseNormalWindow": 0x80147174,
		"eraseNormalWindow": 0x80147174,
		"TTalk2D2::closeNormalWindow": 0x80147398,
		"closeNormalWindow": 0x80147398,
		"TTalk2D2::checkControler": 0x80147578,
		"checkControler": 0x80147578,
		"TTalk2D2::moveTalkWindow": 0x80147894,
		"moveTalkWindow": 0x80147894,
		"TTalk2D2::checkBoardControler": 0x80147b6c,
		"checkBoardControler": 0x80147b6c,
		"TTalk2D2::moveBoardWindow": 0x80147d24,
		"moveBoardWindow": 0x80147d24,
		"TTalk2D2::openNormalWindow": 0x80147dcc,
		"openNormalWindow": 0x80147dcc,
		"TTalk2D2::openBoardWindow": 0x80148078,
		"openBoardWindow": 0x80148078,
		"TTalk2D2::makeBoxLine": 0x8014815c,
		"makeBoxLine": 0x8014815c,
		"TTalk2D2::openTalkWindow": 0x80148758,
		"openTalkWindow": 0x80148758,
		"TTalk2D2::forceCloseTalk": 0x801489b8,
		"forceCloseTalk": 0x801489b8,
		"TTalk2D2::setMessageID": 0x80148a58,
		"setMessageID": 0x80148a58,
		"TTalk2D2::loadAfter": 0x80148e50,
		"TTalk2D2::load": 0x801493d4,
		"TTalk2D2::TTalk2D2": 0x80149808,
		"GC2D::__sinit_Talk2D2_cpp": 0x801499a8,
		"__sinit_Talk2D2_cpp": 0x801499a8,
		"TBoundPane::update": 0x80149ca4,
		"TBoundPane::setPaneSize": 0x8014a024,
		"TBoundPane::setPanePosition": 0x8014a098,
		"setPanePosition": 0x8014a098,
		"TBoundPane::TBoundPane": 0x8014a10c,
		"TPauseMenu2::~TPauseMenu2": 0x8014a210,
		"TPauseMenu2::drawAppearPane": 0x8014a284,
		"drawAppearPane": 0x8014a284,
		"TPauseMenu2::setDrawEnd": 0x8014a4ac,
		"setDrawEnd": 0x8014a4ac,
		"TPauseMenu2::setDrawStart": 0x8014a504,
		"setDrawStart": 0x8014a504,
		"TPauseMenu2::getNextState": 0x8014a6dc,
		"TPauseMenu2::perform": 0x8014a79c,
		"TPauseMenu2::disappearWindow": 0x8014b0e4,
		"disappearWindow": 0x8014b0e4,
		"TPauseMenu2::appearWindow": 0x8014b520,
		"appearWindow": 0x8014b520,
		"TPauseMenu2::loadAfter": 0x8014b8d8,
		"TPauseMenu2::load": 0x8014bb28,
		"TPauseMenu2::TPauseMenu2": 0x8014be88,
		"GC2D::__sinit_PauseMenu2_cpp": 0x8014bf9c,
		"__sinit_PauseMenu2_cpp": 0x8014bf9c,
		"TMessageLoader::getMessageEntry": 0x8014c298,
		"getMessageEntry": 0x8014c298,
		"TMessageLoader::parseBlock": 0x8014c2c4,
		"parseBlock": 0x8014c2c4,
		"JSUIosBase::JSUIosBase": 0x8014c500,
		"TMessageLoader::loadMessageData": 0x8014c518,
		"loadMessageData": 0x8014c518,
		"TSwitchHelpActor::check": 0x8014c6a4,
		"TSwitchHelpActor::TSwitchHelpActor": 0x8014c6d8,
		"THelpActor::check": 0x8014c7cc,
		"THelpActor::perform": 0x8014c7ec,
		"THelpActor::loadAfter": 0x8014c944,
		"THelpActor::load": 0x8014c9f0,
		"THelpActor::THelpActor": 0x8014ca94,
		"GC2D::SMSGetMessageData": 0x8014cb00,
		"SMSGetMessageData": 0x8014cb00,
		"GC2D::SMSMakeTextBuffer": 0x8014cde8,
		"SMSMakeTextBuffer": 0x8014cde8,
		"TCardSave::~TCardSave": 0x8014cec8,
		"TCardSave::getNextState": 0x8014cf3c,
		"TCardSave::execMovement_": 0x8014cf7c,
		"execMovement_": 0x8014cf7c,
		"TCardSave::waitForAnyKeyBM": 0x80150284,
		"TCardSave::waitForSelect3": 0x80150ab8,
		"waitForSelect3": 0x80150ab8,
		"TCardSave::waitForSelect2": 0x80151460,
		"waitForSelect2": 0x80151460,
		"TCardSave::waitForSelectOver": 0x80151b40,
		"waitForSelectOver": 0x80151b40,
		"TCardSave::waitForAnyKey": 0x80152158,
		"TCardSave::drawMessageBM": 0x80152660,
		"TCardSave::drawMessage": 0x80152b8c,
		"TCardSave::waitForChoiceBM": 0x80152ea4,
		"TCardSave::waitForChoice": 0x80154930,
		"TCardSave::waitForStop": 0x801562e4,
		"waitForStop": 0x801562e4,
		"TCardSave::perform": 0x80157074,
		"TCardSave::init": 0x80157158,
		"TCardSave::initData": 0x80157224,
		"TCardSave::load": 0x8015848c,
		"TCardSave::TCardSave": 0x801584cc,
		"TCardSave::changeMode": 0x801586cc,
		"GC2D::__sinit_CardSave_cpp": 0x8015877c,
		"__sinit_CardSave_cpp": 0x8015877c,
		"TCardLoad::~TCardLoad": 0x80158a78,
		"TCardLoad::changeScene": 0x80158aec,
		"changeScene": 0x80158aec,
		"TCardLoad::setSelected": 0x8015a25c,
		"setSelected": 0x8015a25c,
		"TCardLoad::selectFunction": 0x8015a2d0,
		"selectFunction": 0x8015a2d0,
		"TCardLoad::selectBookmark": 0x8015bc20,
		"selectBookmark": 0x8015bc20,
		"TCardLoad::drawMessageBM": 0x8015cb5c,
		"TCardLoad::drawMessage": 0x8015d37c,
		"TCardLoad::waitForStart": 0x8015d8c8,
		"waitForStart": 0x8015d8c8,
		"TCardLoad::waitForAnyKeyBM": 0x8015e290,
		"TCardLoad::waitForAnyKey": 0x8015eb38,
		"TCardLoad::waitForChoiceBM": 0x8015f0d4,
		"TCardLoad::waitForChoice": 0x80160244,
		"TCardLoad::changeMode": 0x801612d0,
		"TCardLoad::titleDraw": 0x801613ac,
		"titleDraw": 0x801613ac,
		"TCardLoad::perform": 0x80161efc,
		"JSUInputStream::JSUInputStream": 0x80162d40,
		"TCardLoad::loadAfter": 0x80162d64,
		"TCardLoad::setupScoreScreen": 0x80162e68,
		"setupScoreScreen": 0x80162e68,
		"TCardLoad::load": 0x80164478,
		"TCardLoad::TCardLoad": 0x80165610,
		"GC2D::__sinit_CardLoad_cpp": 0x80165890,
		"__sinit_CardLoad_cpp": 0x80165890,
		"TConsoleStr::~TConsoleStr": 0x80165b8c,
		"TConsoleStr::startOpenWipe": 0x80165c00,
		"startOpenWipe": 0x80165c00,
		"TConsoleStr::startCloseWipe": 0x80165dc0,
		"startCloseWipe": 0x80165dc0,
		"TConsoleStr::processScenario": 0x80166354,
		"processScenario": 0x80166354,
		"TConsoleStr::processMiss": 0x80166424,
		"processMiss": 0x80166424,
		"TConsoleStr::processShineGet": 0x801667b0,
		"processShineGet": 0x801667b0,
		"TConsoleStr::processGo": 0x80166ac0,
		"processGo": 0x80166ac0,
		"TConsoleStr::processReady": 0x8016721c,
		"processReady": 0x8016721c,
		"TConsoleStr::startAppearScenario": 0x80167754,
		"startAppearScenario": 0x80167754,
		"TConsoleStr::startAppearMiss": 0x80167898,
		"startAppearMiss": 0x80167898,
		"TConsoleStr::startAppearShineGet": 0x801679a8,
		"startAppearShineGet": 0x801679a8,
		"TConsoleStr::startAppearGo": 0x801679d0,
		"startAppearGo": 0x801679d0,
		"TConsoleStr::startAppearReady": 0x80167a3c,
		"startAppearReady": 0x80167a3c,
		"TConsoleStr::perform": 0x80167aa8,
		"TConsoleStr::loadAfter": 0x801681cc,
		"TConsoleStr::load": 0x80168224,
		"TConsoleStr::getWipeCloseTime": 0x80168778,
		"getWipeCloseTime": 0x80168778,
		"TConsoleStr::TConsoleStr": 0x801687a0,
		"GC2D::__sinit_ConsoleStr_cpp": 0x80168858,
		"__sinit_ConsoleStr_cpp": 0x80168858,
		"TSelectMenu::~TSelectMenu": 0x801688c0,
		"TSelectMenu::startOpenWindow": 0x80168934,
		"startOpenWindow": 0x80168934,
		"TSelectMenu::getPrevIndex": 0x80168b80,
		"getPrevIndex": 0x80168b80,
		"TSelectMenu::getNextIndex": 0x80168bd8,
		"getNextIndex": 0x80168bd8,
		"TSelectMenu::perform": 0x80168c34,
		"TSelectMenu::startMove": 0x8016a3e0,
		"startMove": 0x8016a3e0,
		"TSelectMenu::initData": 0x8016a440,
		"TSelectMenu::TSelectMenu": 0x8016b374,
		"TSelectGrad::perform": 0x8016b504,
		"TSelectGrad::setStageColor": 0x8016b8c0,
		"setStageColor": 0x8016b8c0,
		"TSelectGrad::TSelectGrad": 0x8016b9f0,
		"TSelectGrad::~TSelectGrad": 0x8016baf8,
		"GC2D::__sinit_SelectMenu_cpp": 0x8016bb6c,
		"__sinit_SelectMenu_cpp": 0x8016bb6c,
		"TSelectDir::direct": 0x8016be68,
		"TSelectDir::changeOrder": 0x8016c12c,
		"changeOrder": 0x8016c12c,
		"TSelectDir::rsetup": 0x8016c154,
		"TSelectDir::setupThreadFunc": 0x8016d3a8,
		"TSelectDir::setup": 0x8016d3c8,
		"TSelectDir::TSelectDir": 0x8016d500,
		"GC2D::__sinit_SelectDir_cpp": 0x8016d640,
		"__sinit_SelectDir_cpp": 0x8016d640,
		"TSelectShine::~TSelectShine": 0x8016d94c,
		"TSelectShine::move": 0x8016d998,
		"TSelectShine::TSelectShine": 0x8016de68,
		"TSelectShineManager::perform": 0x8016e120,
		"JGeometry::TVec2<float><float>::sub": 0x8016e5bc,
		"TSelectShineManager::startDecrease": 0x8016e5f0,
		"startDecrease": 0x8016e5f0,
		"TSelectShineManager::startIncrease": 0x8016e6f4,
		"startIncrease": 0x8016e6f4,
		"TSelectShineManager::startClose": 0x8016e7f8,
		"startClose": 0x8016e7f8,
		"TSelectShineManager::initData": 0x8016e914,
		"TSelectShineManager::TSelectShineManager": 0x8016ee7c,
		"TSelectShineManager::~TSelectShineManager": 0x8016ef40,
		"GC2D::__sinit_SelectShine2_cpp": 0x8016efb4,
		"__sinit_SelectShine2_cpp": 0x8016efb4,
		"TBlendPane::update": 0x8016efd4,
		"TBlendPane::TBlendPane": 0x8016f0d4,
		"TGuide::~TGuide": 0x8016f124,
		"TGuide::perform": 0x8016f198,
		"TExPane::setPaneSize": 0x8016f7a8,
		"TExPane::setPaneAlpha": 0x8016f86c,
		"setPaneAlpha": 0x8016f86c,
		"TGuide::appearGuidePane": 0x8016f90c,
		"appearGuidePane": 0x8016f90c,
		"TGuide::placeMario": 0x8016fcc4,
		"placeMario": 0x8016fcc4,
		"TGuide::changeBotStatus": 0x8016ff24,
		"changeBotStatus": 0x8016ff24,
		"TGuide::checkPoint": 0x80170580,
		"checkPoint": 0x80170580,
		"TGuide::linkSelect": 0x801706b4,
		"linkSelect": 0x801706b4,
		"TGuide::startMoveCursor": 0x80171480,
		"startMoveCursor": 0x80171480,
		"TGuide::setup": 0x80171494,
		"TGuide::resetScore": 0x801714f0,
		"resetScore": 0x801714f0,
		"TGuide::resetObjects": 0x80171e28,
		"resetObjects": 0x80171e28,
		"TGuide::load": 0x801721b0,
		"TGuide::TGuide": 0x80172bb4,
		"GC2D::__sinit_Guide_cpp": 0x80172cf8,
		"__sinit_Guide_cpp": 0x80172cf8,
		"TSunShine::~TSunShine": 0x80172ff4,
		"TSunShine::loadAfter": 0x80173078,
		"TSunShine::perform": 0x801730d4,
		"TSunGlass::load": 0x801731b0,
		"TSunGlass::loadAfter": 0x801731ec,
		"TSunGlass::perform": 0x80173294,
		"TSunGlass::draw": 0x80173384,
		"TSunGlass::startFade": 0x801735a4,
		"startFade": 0x801735a4,
		"TShineFader::~TShineFader": 0x80173790,
		"TShineFader::load": 0x80173824,
		"TShineFader::registFadeout": 0x80173844,
		"registFadeout": 0x80173844,
		"TShineFader::perform": 0x80173888,
		"TShineFader::update": 0x80173904,
		"TProgSelect::~TProgSelect": 0x80173a24,
		"TProgSelect::perform": 0x80173a98,
		"TProgSelect::TProgSelect": 0x80173e80,
		"GC2D::Hx_Test5": 0x801740fc,
		"Hx_Test5": 0x801740fc,
		"GC2D::Hx_Test4": 0x80174628,
		"Hx_Test4": 0x80174628,
		"GC2D::Hxs1_Test2": 0x80174a44,
		"Hxs1_Test2": 0x80174a44,
		"GC2D::Hx_Test2R": 0x80174d24,
		"Hx_Test2R": 0x80174d24,
		"GC2D::Hx_Test2": 0x801751f4,
		"Hx_Test2": 0x801751f4,
		"GC2D::Hxs1_Test1": 0x80175688,
		"Hxs1_Test1": 0x80175688,
		"GC2D::Hx_Test1": 0x8017589c,
		"Hx_Test1": 0x8017589c,
		"GC2D::Hx_MovieStartSyncEx": 0x80175aa8,
		"Hx_MovieStartSyncEx": 0x80175aa8,
		"GC2D::Hx_Logo": 0x80175b4c,
		"Hx_Logo": 0x80175b4c,
		"GC2D::Hxs_PenDraw": 0x80175fac,
		"Hxs_PenDraw": 0x80175fac,
		"GC2D::Hxs_Logo_MagDraw": 0x80176180,
		"Hxs_Logo_MagDraw": 0x80176180,
		"GC2D::Hxs_Logo_TexDraw": 0x80176328,
		"Hxs_Logo_TexDraw": 0x80176328,
		"GC2D::Hxs_Logo_TexSetup": 0x80176554,
		"Hxs_Logo_TexSetup": 0x80176554,
		"GC2D::Hxs_Logo_ExtraDraw": 0x801766dc,
		"Hxs_Logo_ExtraDraw": 0x801766dc,
		"GC2D::Hx_GameOver": 0x80176864,
		"Hx_GameOver": 0x80176864,
		"GC2D::Hxs_GameOver": 0x80176d5c,
		"Hxs_GameOver": 0x80176d5c,
		"GC2D::Hx_Door": 0x801772b8,
		"Hx_Door": 0x801772b8,
		"GC2D::Hxs_FrBufferMorf2B": 0x8017749c,
		"Hxs_FrBufferMorf2B": 0x8017749c,
		"GC2D::Hxs_FrBufferMorf2": 0x801776a8,
		"Hxs_FrBufferMorf2": 0x801776a8,
		"GC2D::Hxs2_Circle": 0x8017790c,
		"Hxs2_Circle": 0x8017790c,
		"GC2D::Hxs1_Circle": 0x80177cdc,
		"Hxs1_Circle": 0x80177cdc,
		"GC2D::Hx_Circle": 0x80177fec,
		"Hx_Circle": 0x80177fec,
		"GC2D::Hx_MotionUpdate": 0x80178338,
		"Hx_MotionUpdate": 0x80178338,
		"GC2D::Hx_MotionSet": 0x801783a4,
		"Hx_MotionSet": 0x801783a4,
		"GC2D::Hx_TimerCountDown": 0x8017841c,
		"Hx_TimerCountDown": 0x8017841c,
		"GC2D::Hx_UpdateWipe": 0x80178444,
		"Hx_UpdateWipe": 0x80178444,
		"GC2D::Hx_GetWipeType": 0x80178584,
		"Hx_GetWipeType": 0x80178584,
		"GC2D::dummy_handler": 0x80178598,
		"dummy_handler": 0x80178598,
		"GC2D::Hx_StartWipe": 0x8017859c,
		"Hx_StartWipe": 0x8017859c,
		"GC2D::Hx_RemoveResource": 0x80178658,
		"Hx_RemoveResource": 0x80178658,
		"GC2D::Hx_ProvideResourceEx": 0x801786c4,
		"Hx_ProvideResourceEx": 0x801786c4,
		"GC2D::Hx_ProvideResource": 0x8017871c,
		"Hx_ProvideResource": 0x8017871c,
		"GC2D::Hx_ResetWipe": 0x801787a4,
		"Hx_ResetWipe": 0x801787a4,
		"GC2D::Hx_Warning": 0x801787e0,
		"Hx_Warning": 0x801787e0,
		"GC2D::Frb2_RendBox": 0x801787e4,
		"Frb2_RendBox": 0x801787e4,
		"GC2D::Frb2_InitBlackBox": 0x80178894,
		"Frb2_InitBlackBox": 0x80178894,
		"GC2D::Frb2_InitGx": 0x8017891c,
		"Frb2_InitGx": 0x8017891c,
		"GC2D::Hx_FrBufferMorf": 0x80178a5c,
		"Hx_FrBufferMorf": 0x80178a5c,
		"GC2D::__Hx_FrBufferMorf": 0x80178a98,
		"__Hx_FrBufferMorf": 0x80178a98,
		"GC2D::Hx_SetVFilter": 0x80178d08,
		"Hx_SetVFilter": 0x80178d08,
		"GC2D::Hx_GetFrBuffer": 0x80179004,
		"Hx_GetFrBuffer": 0x80179004,
		"GC2D::Hgx_ReadTexture": 0x801790b4,
		"Hgx_ReadTexture": 0x801790b4,
		"GC2D::Hgx_init_tobj_resource": 0x8017913c,
		"Hgx_init_tobj_resource": 0x8017913c,
		"GC2D::Hx_GxInit": 0x801791dc,
		"Hx_GxInit": 0x801791dc,
		"GC2D::Hx_CameraInit": 0x80179344,
		"Hx_CameraInit": 0x80179344,
		"TMovieSubTitle::~TMovieSubTitle": 0x80179518,
		"TMovieSubTitle::setCurMessage": 0x8017958c,
		"setCurMessage": 0x8017958c,
		"TMovieSubTitle::perform": 0x801799fc,
		"TMovieSubTitle::setupResource": 0x80179c10,
		"setupResource": 0x80179c10,
		"TMovieSubTitle::TMovieSubTitle": 0x80179da4,
		"TOptionControl::resetChangedSetting": 0x80179e2c,
		"resetChangedSetting": 0x80179e2c,
		"TOptionControl::isChangedSetting": 0x80179ed8,
		"isChangedSetting": 0x80179ed8,
		"MSound::startSoundSystemSE": 0x8017a584,
		"TOptionControl::setType": 0x8017a708,
		"setType": 0x8017a708,
		"TOptionControl::movementOption2Card": 0x8017a9a0,
		"movementOption2Card": 0x8017a9a0,
		"TOptionControl::movementOption": 0x8017aa98,
		"movementOption": 0x8017aa98,
		"JGeometry::TUtil<int><int>::mod": 0x8017ace4,
		"JGeometry::TUtil<long><long>::clamp": 0x8017ad24,
		"clamp": 0x8017ad24,
		"TOptionControl::movementCard2Option": 0x8017ad44,
		"movementCard2Option": 0x8017ad44,
		"TOptionControl::draw": 0x8017af54,
		"TOptionControl::loadSetting": 0x8017af84,
		"loadSetting": 0x8017af84,
		"TOptionControl::load": 0x8017b678,
		"TOptionSoundUnit::setInfluencedAlphaRecursive": 0x8017b8e0,
		"JSUTree<J2DPane>::getObject": 0x8017b9cc,
		"getObject": 0x8017b9cc,
		"TOptionSoundUnit::adjustView": 0x8017b9dc,
		"TOptionSoundUnit::setState": 0x8017bdf0,
		"TOptionSoundUnit::typeToFlag": 0x8017c1a0,
		"typeToFlag": 0x8017c1a0,
		"TOptionSoundUnit::flagToType": 0x8017c1dc,
		"flagToType": 0x8017c1dc,
		"TOptionSoundUnit::update": 0x8017c218,
		"TOptionSoundUnit::initSurroundAnm": 0x8017c804,
		"initSurroundAnm": 0x8017c804,
		"TOptionSoundUnit::initSteleoAnm": 0x8017cb7c,
		"initSteleoAnm": 0x8017cb7c,
		"TOptionSoundUnit::TOptionSoundUnit": 0x8017cdac,
		"@unnamed@::ArrayWrapper<TPatternAnmControl*>::ArrayWrapper": 0x8017d2e0,
		"ArrayWrapper": 0x8017d2e0,
		"TOptionRumbleUnit::setInfluencedAlphaRecursive": 0x8017eda8,
		"TOptionRumbleUnit::setState": 0x8017ee94,
		"TOptionRumbleUnit::update": 0x8017f1c8,
		"TOptionRumbleUnit::TOptionRumbleUnit": 0x8017f6c4,
		"TPatternAnmControl::hide": 0x8017fa0c,
		"hide": 0x8017fa0c,
		"TPatternAnmControl::show": 0x8017fa88,
		"show": 0x8017fa88,
		"TPatternAnmControl::update": 0x8017fb28,
		"TPatternAnmControl::setupAnm": 0x8017fc38,
		"setupAnm": 0x8017fc38,
		"GC2D::__sinit_Option_cpp": 0x80180050,
		"__sinit_Option_cpp": 0x80180050,
		"TMovieRumble::~TMovieRumble": 0x8018034c,
		"TMovieRumble::checkRumbleOff": 0x801803c0,
		"checkRumbleOff": 0x801803c0,
		"TMovieRumble::perform": 0x801804cc,
		"TMovieRumble::init": 0x8018054c,
		"TMovieRumble::TMovieRumble": 0x801806ac,
		"TConductor::perform": 0x80033f90,
		"TConductor::searchF": 0x80034400,
		"TConductor::genEnemyFromPollution": 0x80034614,
		"genEnemyFromPollution": 0x80034614,
		"TConductor::killEnemiesWithin": 0x80034960,
		"killEnemiesWithin": 0x80034960,
		"TConductor::makeOneEnemyAppear": 0x80034a38,
		"makeOneEnemyAppear": 0x80034a38,
		"TConductor::makeEnemyAppear": 0x80034bcc,
		"makeEnemyAppear": 0x80034bcc,
		"TConductor::isBossDefeated": 0x80034df8,
		"isBossDefeated": 0x80034df8,
		"TConductor::getManagerByName": 0x80034fd8,
		"getManagerByName": 0x80034fd8,
		"TConductor::getGraphByName": 0x80035094,
		"TConductor::init": 0x800350c8,
		"TConductor::registerEnemyInfoTable": 0x800351f8,
		"registerEnemyInfoTable": 0x800351f8,
		"TConductor::registerSDLModelData": 0x80035200,
		"registerSDLModelData": 0x80035200,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::insert": 0x80035248,
		"TConductor::registerAreaCylinderManager": 0x80035300,
		"registerAreaCylinderManager": 0x80035300,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::insert": 0x80035348,
		"TConductor::registerGenerator": 0x80035400,
		"registerGenerator": 0x80035400,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::insert": 0x80035448,
		"TConductor::registerOtherObj": 0x80035500,
		"registerOtherObj": 0x80035500,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::insert": 0x80035548,
		"TConductor::registerAloneActor": 0x80035600,
		"registerAloneActor": 0x80035600,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::insert": 0x80035648,
		"TConductor::registerEnemyManager": 0x80035700,
		"registerEnemyManager": 0x80035700,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::insert": 0x80035748,
		"TConductor::registerManager": 0x80035800,
		"registerManager": 0x80035800,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::insert": 0x80035848,
		"TConductor::initGraphGroup": 0x80035900,
		"TConductor::makeGraphGroup": 0x80035924,
		"makeGraphGroup": 0x80035924,
		"TConductor::~TConductor": 0x80035980,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::erase": 0x80035da4,
		"JGadget::TList<P12TLiveManager,Q27JGadget27TAllocator<P12TLiveManager>>::iterator::iterator": 0x80035e10,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::erase": 0x80035e30,
		"JGadget::TList<P13TEnemyManager,Q27JGadget28TAllocator<P13TEnemyManager>>::iterator::iterator": 0x80035e9c,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::erase": 0x80035ebc,
		"JGadget::TList<P10TLiveActor,Q27JGadget25TAllocator<P10TLiveActor>>::iterator::iterator": 0x80035f28,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::erase": 0x80035f48,
		"JGadget::TList<PQ26JDrama8TViewObj,Q27JGadget31TAllocator<PQ26JDrama8TViewObj>>::iterator::iterator": 0x80035fb4,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::erase": 0x80035fd4,
		"JGadget::TList<P20TAreaCylinderManager,Q27JGadget35TAllocator<P20TAreaCylinderManager>>::iterator::iterator": 0x80036040,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::erase": 0x80036060,
		"JGadget::TList<P10TGenerator,Q27JGadget25TAllocator<P10TGenerator>>::iterator::iterator": 0x800360cc,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::erase": 0x800360ec,
		"JGadget::TList<P12SDLModelData,Q27JGadget27TAllocator<P12SDLModelData>>::iterator::iterator": 0x80036158,
		"TConductor::TConductor": 0x80036160,
		"TEffectModel::control": 0x800363c4,
		"TEffectExplosion::generate": 0x8003644c,
		"TEffectExplosion::reset": 0x800365ac,
		"TEffectExplosion::init": 0x800366d0,
		"TEffectExplosionManager::createModelData": 0x800367f4,
		"TEffectExplosionManager::createEnemyInstance": 0x80036828,
		"TEffectExplosionManager::loadAfter": 0x80036898,
		"TEffectExplosionManager::load": 0x8003695c,
		"TEffectExplosionManager::TEffectExplosionManager": 0x800369c8,
		"TEffectModelManager::~TEffectModelManager": 0x80036a10,
		"TEffectColumSand::generate": 0x80036a74,
		"TEffectColumSand::reset": 0x80036b2c,
		"TEffectColumSand::init": 0x80036c60,
		"TEffectColumSandManager::createModelData": 0x80036d28,
		"TEffectColumSandManager::createEnemyInstance": 0x80036d5c,
		"TEffectColumSandManager::loadAfter": 0x80036dcc,
		"TEffectColumSandManager::load": 0x80036e24,
		"TEffectColumSandManager::TEffectColumSandManager": 0x80036e90,
		"TEffectBombColumWater::generate": 0x80036ed8,
		"TEffectBombColumWater::reset": 0x8003703c,
		"TEffectBombColumWater::init": 0x80037190,
		"TEffectBombColumWaterManager::createModelData": 0x80037264,
		"TEffectBombColumWaterManager::createEnemyInstance": 0x80037298,
		"TEffectBombColumWaterManager::loadAfter": 0x80037308,
		"TEffectBombColumWaterManager::load": 0x800373cc,
		"TEffectBombColumWaterManager::TEffectBombColumWaterManager": 0x80037438,
		"TEffectColumWater::generate": 0x80037480,
		"TEffectColumWater::reset": 0x800375b8,
		"TEffectColumWater::init": 0x8003770c,
		"TEffectColumWaterManager::createModelData": 0x800377e0,
		"TEffectColumWaterManager::createEnemyInstance": 0x80037814,
		"TEffectColumWaterManager::loadAfter": 0x80037884,
		"TEffectColumWaterManager::load": 0x80037910,
		"TEffectColumWaterManager::TEffectColumWaterManager": 0x8003797c,
		"TEffectModel::calcRootMatrix": 0x800379c4,
		"TEffectModel::moveObject": 0x80037ab8,
		"TEffectModel::reset": 0x80037b1c,
		"TEffectModel::init": 0x80037be0,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::insert": 0x80037c4c,
		"TEffectObjManager::perform": 0x80037d04,
		"TEffectObjManager::load": 0x80037dd8,
		"TEffectObjManager::TEffectObjManager": 0x80037df8,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::erase": 0x80037f10,
		"TEffectObjBase::behaveToWater": 0x80037f7c,
		"TEffectObjBase::moveObject": 0x80038064,
		"TEffectObjBase::receiveMessage": 0x80038234,
		"TEffectObjBase::perform": 0x80038274,
		"TEffectObjBase::reset": 0x800382cc,
		"TEffectObjBase::init": 0x800382f8,
		"TEffectObjBase::load": 0x80038358,
		"TEffectObjBase::TEffectObjBase": 0x800383e0,
		"TEffectBiancoFunsui::emitEffect": 0x80038438,
		"TEffectBiancoFunsui::loadAfter": 0x80038508,
		"TEffectPinnaFunsui::emitEffect": 0x80038578,
		"TEffectPinnaFunsui::loadAfter": 0x80038648,
		"TSimpleEffect::perform": 0x800386b8,
		"TEffectExplosionManager::~TEffectExplosionManager": 0x800386ec,
		"TEffectColumSandManager::~TEffectColumSandManager": 0x800387e4,
		"TEffectBombColumWaterManager::~TEffectBombColumWaterManager": 0x800388dc,
		"TEffectColumWaterManager::~TEffectColumWaterManager": 0x800389d4,
		"TEffectObjManager::~TEffectObjManager": 0x80038a48,
		"JGadget::TList<P14TEffectObjBase,Q27JGadget29TAllocator<P14TEffectObjBase>>::iterator::iterator": 0x80038b54,
		"Enemy::__sinit_effectObj_cpp": 0x80038d54,
		"__sinit_effectObj_cpp": 0x80038d54,
		"TEMarioManager::~TEMarioManager": 0x80039098,
		"TEMarioManager::createEnemyInstance": 0x800390fc,
		"TEMarioManager::load": 0x80039158,
		"TEMarioManager::TEMarioManager": 0x800391c4,
		"TEMario::perform": 0x80039200,
		"TEMario::forceDisappear": 0x800394f0,
		"forceDisappear": 0x800394f0,
		"TEMario::startGateDrawing": 0x80039518,
		"TEMario::startMonteReplay": 0x8003953c,
		"TEMario::startRunAway": 0x80039560,
		"TEMario::isDownWaitingToTalk": 0x80039584,
		"isDownWaitingToTalk": 0x80039584,
		"TEMario::isReachedToGate": 0x800395a4,
		"isReachedToGate": 0x800395a4,
		"TEMario::isGoal": 0x800395c4,
		"isGoal": 0x800395c4,
		"TEMario::kill": 0x800395e4,
		"TEMario::receiveMessage": 0x80039624,
		"TEMario::init": 0x800396b8,
		"TEMario::loadAfter": 0x8003986c,
		"TEMario::load": 0x800398c8,
		"TEMario::TEMario": 0x80039c68,
		"Enemy::__sinit_emario_cpp": 0x80039d18,
		"__sinit_emario_cpp": 0x80039d18,
		"TSpineEnemy::perform": 0x8003a01c,
		"TSpineEnemy::checkCurAnmEnd": 0x8003a0e0,
		"checkCurAnmEnd": 0x8003a0e0,
		"TSpineEnemy::getCurAnmFrameNo": 0x8003a17c,
		"getCurAnmFrameNo": 0x8003a17c,
		"TSpineEnemy::doShortCut": 0x8003a218,
		"doShortCut": 0x8003a218,
		"TSpineEnemy::zigzagToCurPathNode": 0x8003a538,
		"zigzagToCurPathNode": 0x8003a538,
		"TSpineEnemy::walkToCurPathNode": 0x8003aa68,
		"walkToCurPathNode": 0x8003aa68,
		"TSpineEnemy::turnToCurPathNode": 0x8003af4c,
		"turnToCurPathNode": 0x8003af4c,
		"TSpineEnemy::goToDirLimitedNextGraphNode": 0x8003b130,
		"goToDirLimitedNextGraphNode": 0x8003b130,
		"TSpineEnemy::goToDirectedNextGraphNode": 0x8003b2e0,
		"goToDirectedNextGraphNode": 0x8003b2e0,
		"TSpineEnemy::goToRandomEscapeGraphNode": 0x8003b3f4,
		"goToRandomEscapeGraphNode": 0x8003b3f4,
		"TSpineEnemy::goToRandomNextGraphNode": 0x8003b4fc,
		"goToRandomNextGraphNode": 0x8003b4fc,
		"TSpineEnemy::jumpToNextGraphNode": 0x8003b600,
		"jumpToNextGraphNode": 0x8003b600,
		"TSpineEnemy::goToShortestNextGraphNode": 0x8003b720,
		"goToShortestNextGraphNode": 0x8003b720,
		"TSpineEnemy::setGoalPathFromGraph": 0x8003b844,
		"setGoalPathFromGraph": 0x8003b844,
		"TSpineEnemy::isInSight": 0x8003b8f0,
		"isInSight": 0x8003b8f0,
		"TSpineEnemy::receiveMessage": 0x8003b924,
		"TSpineEnemy::updateSquareToMario": 0x8003b984,
		"updateSquareToMario": 0x8003b984,
		"TSpineEnemy::calcTurnSpeedToReach": 0x8003b9bc,
		"calcTurnSpeedToReach": 0x8003b9bc,
		"TSpineEnemy::calcMinimumTurnRadius": 0x8003ba9c,
		"calcMinimumTurnRadius": 0x8003ba9c,
		"TSpineEnemy::resetSRTV": 0x8003bb30,
		"resetSRTV": 0x8003bb30,
		"TSpineEnemy::resetToPosition": 0x8003bc7c,
		"resetToPosition": 0x8003bc7c,
		"TSpineEnemy::getSaveParam": 0x8003bd88,
		"TSpineEnemy::calcRootMatrix": 0x8003bd94,
		"TSpineEnemy::calcEnemyRootMatrix": 0x8003be30,
		"calcEnemyRootMatrix": 0x8003be30,
		"TSpineEnemy::load": 0x8003c1ec,
		"TSpineEnemy::reset": 0x8003c2b0,
		"TSpineEnemy::init": 0x8003c368,
		"TSpineEnemy::TSpineEnemy": 0x8003c458,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::~TSolidStack": 0x8003c5e4,
		"TSolidStack<TPathNode>::~TSolidStack": 0x8003c630,
		"TPathNode::TPathNode": 0x8003c67c,
		"TSpineBase<TLiveActor>::~TSpineBase": 0x8003c698,
		"~TSpineBase": 0x8003c698,
		"Enemy::__sinit_enemy_cpp": 0x8003c800,
		"__sinit_enemy_cpp": 0x8003c800,
		"TEnemyPolluteModel::~TEnemyPolluteModel": 0x8003cb04,
		"TEnemyPolluteModel::setAnm": 0x8003cb78,
		"TEnemyPolluteModel::perform": 0x8003cb7c,
		"TEnemyPolluteModel::TEnemyPolluteModel": 0x8003cc60,
		"TEnemyPolluteModelManager::generatePolluteModel": 0x8003cd30,
		"generatePolluteModel": 0x8003cd30,
		"TEnemyPolluteModelManager::perform": 0x8003ceb8,
		"TEnemyPolluteModelManager::init": 0x8003cfc8,
		"TEnemyAttachment::perform": 0x8003d000,
		"TEnemyAttachment::behaveToHost": 0x8003d124,
		"TEnemyAttachment::calcRootMatrix": 0x8003d128,
		"TEnemyAttachment::sendMessage": 0x8003d1cc,
		"TEnemyAttachment::moveObject": 0x8003d280,
		"TEnemyAttachment::set": 0x8003d31c,
		"TEnemyAttachment::kill": 0x8003d358,
		"TEnemyAttachment::rebirth": 0x8003d374,
		"TEnemyAttachment::bind": 0x8003d398,
		"TEnemyAttachment::setBehavior": 0x8003d318,
		"TEnemyAttachment::getNowGravity": 0x8003d618,
		"TEnemyAttachment::recoverScale": 0x8003d620,
		"TEnemyAttachment::forceKill": 0x8003d66c,
		"TEnemyAttachment::behaveToHitWall": 0x8003d724,
		"TEnemyAttachment::behaveToHitGround": 0x8003d750,
		"TEnemyAttachment::loadInit": 0x8003d7a4,
		"TEnemyAttachment::TEnemyAttachment": 0x8003d820,
		"TEnemyPolluteModelManager::~TEnemyPolluteModelManager": 0x8003d880,
		"TEnemyAttachment::appear": 0x8003d960,
		"TEnemyAttachment::receiveMessage": 0x8003d97c,
		"TEnemyManager::copyAnmMtx": 0x8003da40,
		"copyAnmMtx": 0x8003da40,
		"TEnemyManager::countLivingEnemy": 0x8003dbf4,
		"countLivingEnemy": 0x8003dbf4,
		"TEnemyManager::killChildrenWithin": 0x8003dc5c,
		"killChildrenWithin": 0x8003dc5c,
		"TEnemyManager::killChildren": 0x8003dd34,
		"killChildren": 0x8003dd34,
		"TEnemyManager::getFarOutEnemy": 0x8003dd6c,
		"getFarOutEnemy": 0x8003dd6c,
		"TEnemyManager::getDeadEnemy": 0x8003de0c,
		"getDeadEnemy": 0x8003de0c,
		"TEnemyManager::getNearestEnemy": 0x8003de74,
		"getNearestEnemy": 0x8003de74,
		"TEnemyManager::perform": 0x8003df34,
		"TEnemyManager::performShared": 0x8003e1b8,
		"performShared": 0x8003e1b8,
		"TEnemyManager::copyFromShared": 0x8003e5ac,
		"copyFromShared": 0x8003e5ac,
		"TEnemyManager::updateAnmSoundShared": 0x8003e81c,
		"updateAnmSoundShared": 0x8003e81c,
		"TEnemyManager::setSharedFlags": 0x8003e974,
		"setSharedFlags": 0x8003e974,
		"TEnemyManager::clipEnemies": 0x8003ea54,
		"TEnemyManager::createEnemies": 0x8003ea98,
		"TEnemyManager::createEnemyInstance": 0x8003ec04,
		"TEnemyManager::load": 0x8003ec0c,
		"TEnemyManager::getSharedMActorSet": 0x8003ec68,
		"getSharedMActorSet": 0x8003ec68,
		"TEnemyManager::createSharedMActorSet": 0x8003ecb0,
		"createSharedMActorSet": 0x8003ecb0,
		"TSharedMActorSet::TSharedMActorSet": 0x8003ed9c,
		"TEnemyManager::~TEnemyManager": 0x8003edb0,
		"TEnemyManager::TEnemyManager": 0x8003ee44,
		"TSharedMActorSet::init": 0x8003ef40,
		"TSpineEnemyParams::TSpineEnemyParams": 0x8003f0a8,
		"Enemy::__sinit_enemymanager_cpp": 0x8003f28c,
		"__sinit_enemymanager_cpp": 0x8003f28c,
		"TEnemyMario::perform": 0x8003f664,
		"TEnemyMario::drawHPMeter": 0x8003fc14,
		"drawHPMeter": 0x8003fc14,
		"TEnemyMario::damageExec": 0x8003feb8,
		"TEnemyMario::playerControl": 0x8003febc,
		"TEnemyMario::checkController": 0x8003ff5c,
		"TEnemyMario::checkReturn": 0x8004051c,
		"TEnemyMario::reachGoal": 0x8004065c,
		"reachGoal": 0x8004065c,
		"TEnemyMario::thinkTrample": 0x8004067c,
		"thinkTrample": 0x8004067c,
		"TEnemyMario::hitWater": 0x800406d8,
		"TEnemyMario::consider": 0x8004088c,
		"consider": 0x8004088c,
		"JGeometry::TRotation3<JGeometry::TMatrix44<JGeometry::SMatrix44C<float><float>>>::TRotation3": 0x800410f4,
		"TPathNode::getPoint": 0x80041100,
		"TEnemyMario::startGateDrawing": 0x80041120,
		"TEnemyMario::emWaitingToInviteMario": 0x80041184,
		"emWaitingToInviteMario": 0x80041184,
		"TEnemyMario::decideDoingAfterCarry": 0x80041320,
		"decideDoingAfterCarry": 0x80041320,
		"TEnemyMario::emRunAwayToNearestNode": 0x80041484,
		"emRunAwayToNearestNode": 0x80041484,
		"TEnemyMario::findRunAwayNearestNode": 0x80041964,
		"findRunAwayNearestNode": 0x80041964,
		"TEnemyMario::startRunAway": 0x80041c08,
		"TEnemyMario::emDownAnimation": 0x80041c1c,
		"emDownAnimation": 0x80041c1c,
		"TEnemyMario::emReplayJumpToNearestNode": 0x80041d48,
		"emReplayJumpToNearestNode": 0x80041d48,
		"TEnemyMario::emReplay": 0x8004252c,
		"emReplay": 0x8004252c,
		"TEnemyMario::emDisappearToGate": 0x80042774,
		"emDisappearToGate": 0x80042774,
		"TEnemyMario::startDisappear": 0x800428e0,
		"startDisappear": 0x800428e0,
		"TEnemyMario::emWalkAround": 0x8004299c,
		"emWalkAround": 0x8004299c,
		"TEnemyMario::emJumping": 0x80042b64,
		"emJumping": 0x80042b64,
		"TEnemyMario::emWaiting": 0x80042cc0,
		"emWaiting": 0x80042cc0,
		"TEnemyMario::tryTake": 0x80042dd8,
		"tryTake": 0x80042dd8,
		"TEnemyMario::startMonteReplay": 0x80042ec8,
		"TEnemyMario::initEnemyValues": 0x80043010,
		"initEnemyValues": 0x80043010,
		"TEnemyMario::initModel": 0x80044284,
		"TEnemyMario::initValues": 0x80044b1c,
		"Enemy::__sinit_enemyMario_cpp": 0x80044e4c,
		"__sinit_enemyMario_cpp": 0x80044e4c,
		"TNerveGessoTurn::~TNerveGessoTurn": 0x80045444,
		"TNerveGessoTurn::execute": 0x800454a0,
		"TNerveGessoLand::execute": 0x800455a4,
		"TNerveGessoLand::~TNerveGessoLand": 0x80045618,
		"TNerveGessoFindMario::execute": 0x80045674,
		"TNerveGessoFindMario::~TNerveGessoFindMario": 0x800456e0,
		"TNerveGessoRolling::execute": 0x8004573c,
		"TNerveGessoRolling::~TNerveGessoRolling": 0x80045810,
		"TNerveGessoFall::execute": 0x8004586c,
		"TNerveGessoFall::~TNerveGessoFall": 0x80045f7c,
		"TNerveGessoPollute::execute": 0x80045fd8,
		"TNerveGessoPollute::~TNerveGessoPollute": 0x80046134,
		"TNerveGessoPunch::execute": 0x80046190,
		"TNerveGessoPunch::~TNerveGessoPunch": 0x800461fc,
		"TNerveGessoFreeze::execute": 0x80046258,
		"TNerveGessoFreeze::~TNerveGessoFreeze": 0x800466a4,
		"TNerveGessoStay::execute": 0x80046700,
		"TNerveGessoStay::~TNerveGessoStay": 0x8004690c,
		"TGessoPolluteObj::sendMessage": 0x80046968,
		"TGessoPolluteObj::calcRootMatrix": 0x80046a0c,
		"TGessoPolluteObj::set": 0x80046a8c,
		"TGessoPolluteObj::rebirth": 0x80046bcc,
		"TGessoPolluteObj::pollute": 0x80046d14,
		"TGessoPolluteObj::getNowGravity": 0x80046d88,
		"TGessoPolluteObj::loadInit": 0x80046da8,
		"TLandGesso::load": 0x80046eb4,
		"TSurfGesso::perform": 0x80046efc,
		"TSurfGesso::load": 0x80046f30,
		"TGesso::getBasNameTable": 0x80046f78,
		"TGesso::initAttacker": 0x80046f84,
		"TGesso::rollCheck": 0x80046fd4,
		"rollCheck": 0x80046fd4,
		"TGesso::behaveToFindMario": 0x800472ec,
		"TGesso::genRandomItem": 0x8004754c,
		"TGesso::calcRootMatrix": 0x800475c0,
		"TGesso::kill": 0x80047728,
		"TGesso::bind": 0x80047778,
		"TGesso::setWaitAnm": 0x80047a30,
		"TGesso::setWalkAnm": 0x80047ab4,
		"TGesso::getGravityY": 0x80047ae4,
		"TGesso::setDeadAnm": 0x80047b18,
		"TGesso::setAfterDeadEffect": 0x80047be0,
		"TGesso::pollute": 0x80047c24,
		"TGesso::setPolluteGoal": 0x80047e08,
		"setPolluteGoal": 0x80047e08,
		"TGesso::setBehavior": 0x80047fe4,
		"TGesso::attackToMario": 0x800481a8,
		"TGesso::doKeepDistance": 0x80048464,
		"TGesso::isResignationAttack": 0x800484b0,
		"TGesso::walkBehavior": 0x800484e4,
		"TGesso::behaveToWater": 0x80048730,
		"TGesso::load": 0x80048b04,
		"TGesso::reset": 0x80048bdc,
		"TGesso::init": 0x80048d78,
		"TGesso::TGesso": 0x80048ee0,
		"Enemy::GessoBodyCallback": 0x80048ff4,
		"GessoBodyCallback": 0x80048ff4,
		"TGessoManager::createModelData": 0x800491a4,
		"TGessoManager::initSetEnemies": 0x800491d8,
		"TGessoManager::perform": 0x80049294,
		"TGessoManager::clipEnemies": 0x80049354,
		"TGessoManager::createEnemyInstance": 0x8004947c,
		"TGessoManager::loadAfter": 0x800494c4,
		"TGessoManager::load": 0x800494e4,
		"TGessoManager::TGessoManager": 0x8004953c,
		"TGessoPolluteModel::setAnm": 0x800495e8,
		"TGessoPolluteModelManager::init": 0x80049638,
		"TGessoSaveLoadParams::TGessoSaveLoadParams": 0x80049700,
		"TGesso::setRunAnm": 0x80049a9c,
		"TSmallEnemy::isEatenByYosshi": 0x80049ac8,
		"TSmallEnemy::jumpBehavior": 0x80049ad0,
		"jumpBehavior": 0x80049ad0,
		"TSmallEnemy::behaveToTaken": 0x80049ad4,
		"TSmallEnemy::behaveToRelease": 0x80049ad8,
		"TSmallEnemy::setGenerateAnm": 0x80049adc,
		"TSmallEnemy::setFreezeAnm": 0x80049ae0,
		"TSmallEnemy::setMeltAnm": 0x80049ae4,
		"TSmallEnemy::isHitValid": 0x80049ae8,
		"TSmallEnemy::isInhibitedForceMove": 0x80049b14,
		"TSmallEnemy::endHitWaterJump": 0x80049b1c,
		"TSmallEnemy::setDeadEffect": 0x80049b20,
		"setDeadEffect": 0x80049b20,
		"TSurfGesso::isFindMario": 0x80049c2c,
		"TGessoManager::~TGessoManager": 0x80049d6c,
		"TGessoPolluteModel::~TGessoPolluteModel": 0x80049de0,
		"TGessoPolluteModelManager::~TGessoPolluteModelManager": 0x80049e64,
		"Enemy::__sinit_gesso_cpp": 0x80049ee8,
		"__sinit_gesso_cpp": 0x80049ee8,
		"TGraphTracer::traceSpline": 0x8004a204,
		"traceSpline": 0x8004a204,
		"TGraphTracer::calcSplineSpeed": 0x8004a3c8,
		"calcSplineSpeed": 0x8004a3c8,
		"TGraphTracer::moveTo": 0x8004a638,
		"moveTo": 0x8004a638,
		"TGraphTracer::setTo": 0x8004a6f8,
		"setTo": 0x8004a6f8,
		"TGraphTracer::TGraphTracer": 0x8004a7a4,
		"TGraphGroup::perform": 0x8004a7d4,
		"TGraphGroup::getGraphByName": 0x8004a82c,
		"TGraphGroup::initGraphGroup": 0x8004a8d0,
		"TGraphGroup::TGraphGroup": 0x8004aab4,
		"TGraphWeb::getNeighborNodeIndexByFlag": 0x8004ac00,
		"getNeighborNodeIndexByFlag": 0x8004ac00,
		"TGraphWeb::getNearestPosOnGraphLink": 0x8004acf4,
		"getNearestPosOnGraphLink": 0x8004acf4,
		"TGraphWeb::isDummy": 0x8004afbc,
		"isDummy": 0x8004afbc,
		"TGraphWeb::indexToPoint": 0x8004afe0,
		"indexToPoint": 0x8004afe0,
		"TGraphWeb::startIsEnd": 0x8004b06c,
		"startIsEnd": 0x8004b06c,
		"TGraphWeb::initGoalIndex": 0x8004b0e4,
		"initGoalIndex": 0x8004b0e4,
		"TGraphWeb::calcGraphDirection": 0x8004b1a8,
		"calcGraphDirection": 0x8004b1a8,
		"TGraphWeb::findNearestVisibleIndex": 0x8004b25c,
		"findNearestVisibleIndex": 0x8004b25c,
		"TGraphWeb::findNearestNodeIndex": 0x8004b414,
		"findNearestNodeIndex": 0x8004b414,
		"TGraphWeb::getEscapeDirLimited": 0x8004b510,
		"getEscapeDirLimited": 0x8004b510,
		"TGraphWeb::getRandomButDirLimited": 0x8004b98c,
		"getRandomButDirLimited": 0x8004b98c,
		"TGraphWeb::getAimToDirNextIndex": 0x8004bdb8,
		"getAimToDirNextIndex": 0x8004bdb8,
		"TGraphWeb::getEscapeFromMarioIndex": 0x8004bfd8,
		"getEscapeFromMarioIndex": 0x8004bfd8,
		"TGraphWeb::getRandomNextIndex": 0x8004c228,
		"getRandomNextIndex": 0x8004c228,
		"TGraphWeb::getShortestNextIndex": 0x8004c380,
		"getShortestNextIndex": 0x8004c380,
		"TGraphWeb::translateNodes": 0x8004c55c,
		"translateNodes": 0x8004c55c,
		"TGraphWeb::filterRailNode": 0x8004c750,
		"filterRailNode": 0x8004c750,
		"TGraphWeb::~TGraphWeb": 0x8004c89c,
		"TGraphWeb::TGraphWeb": 0x8004c8e8,
		"TSplineRail::getPosAndRot": 0x8004ca4c,
		"getPosAndRot": 0x8004ca4c,
		"TSplinePath::getPoint": 0x8004cc80,
		"TSplineRail::TSplineRail": 0x8004cd60,
		"TGraphNode::getPoint": 0x8004d30c,
		"TGraphNode::TGraphNode": 0x8004d380,
		"TNerveDoroHanePrepareAttack::~TNerveDoroHanePrepareAttack": 0x8004d3a0,
		"TNerveDoroHanePrepareAttack::execute": 0x8004d3fc,
		"TNerveDoroHaneHitWater::execute": 0x8004d47c,
		"TNerveDoroHaneHitWater::~TNerveDoroHaneHitWater": 0x8004d5f4,
		"TNerveDoroHaneRise::execute": 0x8004d650,
		"TNerveDoroHaneRise::~TNerveDoroHaneRise": 0x8004d7ec,
		"TNerveFireHamuKuriRecover::execute": 0x8004d848,
		"TFireHamuKuri::setBckAnm": 0x8004d92c,
		"TNerveFireHamuKuriRecover::~TNerveFireHamuKuriRecover": 0x8004d94c,
		"TNerveDoroHamuKuriRobCap::execute": 0x8004d9a8,
		"TNerveDoroHamuKuriRobCap::~TNerveDoroHamuKuriRobCap": 0x8004db4c,
		"TNerveHaneHamuKuriMoveOnGraph::execute": 0x8004dba8,
		"TNerveHaneHamuKuriMoveOnGraph::~TNerveHaneHamuKuriMoveOnGraph": 0x8004dea8,
		"TNerveHaneHamuKuriUpWait::execute": 0x8004df04,
		"TNerveHaneHamuKuriUpWait::~TNerveHaneHamuKuriUpWait": 0x8004e08c,
		"TNerveDangoHamuKuriWait::execute": 0x8004e0e8,
		"TNerveDangoHamuKuriWait::~TNerveDangoHamuKuriWait": 0x8004e19c,
		"TNerveHamuKuriJitabata::execute": 0x8004e1f8,
		"TNerveHamuKuriJitabata::~TNerveHamuKuriJitabata": 0x8004e328,
		"TNerveHamuKuriLand::execute": 0x8004e384,
		"TNerveHamuKuriLand::~TNerveHamuKuriLand": 0x8004e404,
		"TNerveHamuKuriWallDie::execute": 0x8004e460,
		"TNerveHamuKuriWallDie::~TNerveHamuKuriWallDie": 0x8004e700,
		"TNerveHamuKuriBoundFreeze::execute": 0x8004e75c,
		"TNerveHamuKuriBoundFreeze::~TNerveHamuKuriBoundFreeze": 0x8004ea70,
		"TNerveHamuKuriGoForSearchActor::execute": 0x8004eacc,
		"TNerveHamuKuriGoForSearchActor::~TNerveHamuKuriGoForSearchActor": 0x8004ecb8,
		"TDoroHamuKuri::isCollidMove": 0x8004ed14,
		"TDoroHamuKuri::onHaveCap": 0x8004f0d0,
		"TDoroHamuKuri::setBehavior": 0x8004f0f0,
		"TDoroHamuKuri::attackToMario": 0x8004f360,
		"TDoroHamuKuri::setMActorAndKeeper": 0x8004f444,
		"TDoroHamuKuri::kill": 0x8004f4b0,
		"TDoroHamuKuri::reset": 0x8004f4d0,
		"TDoroHamuKuri::init": 0x8004f548,
		"TDoroHamuKuri::TDoroHamuKuri": 0x8004f718,
		"TFireHamuKuri::changeTevColor": 0x8004f7f8,
		"changeTevColor": 0x8004f7f8,
		"TFireHamuKuri::sendAttackMsgToMario": 0x8004f9c4,
		"TFireHamuKuri::setWalkAnm": 0x8004fa00,
		"TFireHamuKuri::isHitValid": 0x8004fa30,
		"TFireHamuKuri::walkBehavior": 0x8004fad0,
		"TFireHamuKuri::calcRootMatrix": 0x8004fc4c,
		"TFireHamuKuri::moveObject": 0x8004fe20,
		"TFireHamuKuri::setMActorAndKeeper": 0x8004fe54,
		"TFireHamuKuri::reset": 0x8004fef4,
		"TFireHamuKuri::behaveToWater": 0x8004ffac,
		"THamuKuri::canDoJitabata": 0x8005038c,
		"TFireHamuKuri::init": 0x800503b0,
		"TFireHamuKuri::TFireHamuKuri": 0x8005048c,
		"TBossDangoHamuKuri::generateBody": 0x800504e0,
		"generateBody": 0x800504e0,
		"TBossDangoHamuKuri::genEventCoin": 0x8005066c,
		"TBossDangoHamuKuri::moveObject": 0x80050748,
		"TBossDangoHamuKuri::setGenerateAnm": 0x800507a0,
		"TBossDangoHamuKuri::reset": 0x80050810,
		"TBossDangoHamuKuri::perform": 0x800508e4,
		"TBossDangoHamuKuri::init": 0x80050904,
		"TBossDangoHamuKuri::TBossDangoHamuKuri": 0x80050a40,
		"TDangoHamuKuri::swingBody": 0x80050b6c,
		"swingBody": 0x80050b6c,
		"TDangoHamuKuri::behaveToWater": 0x80050d40,
		"TDangoHamuKuri::forceKill": 0x800511e0,
		"TDangoHamuKuri::isHitValid": 0x80051340,
		"TDangoHamuKuri::receiveMessage": 0x80051368,
		"TDangoHamuKuri::reset": 0x80051568,
		"TDangoHamuKuri::calcRootMatrix": 0x8005162c,
		"TDangoHamuKuri::setRunAnm": 0x80051808,
		"TDangoHamuKuri::getTakingMtx": 0x8005185c,
		"TDangoHamuKuri::attackToMario": 0x80051924,
		"TDangoHamuKuri::isCollidMove": 0x80051a84,
		"TDangoHamuKuri::updateAnmSound": 0x80051aa4,
		"TDangoHamuKuri::moveObject": 0x80051ae8,
		"TDangoHamuKuri::changeByJuice": 0x80051b40,
		"TDangoHamuKuri::perform": 0x80051b74,
		"TDangoHamuKuri::init": 0x80051c00,
		"TDangoHamuKuri::TDangoHamuKuri": 0x80051d00,
		"THaneHamuKuri2::isReachedToGoal": 0x80051d78,
		"THaneHamuKuri2::walkBehavior": 0x80051e20,
		"THaneHamuKuri2::sendAttackMsgToMario": 0x80051f8c,
		"THaneHamuKuri2::reset": 0x80051fac,
		"THaneHamuKuri2::THaneHamuKuri2": 0x80052098,
		"TDoroHaneKuri::isCollidMove": 0x800521a8,
		"TDoroHaneKuri::setBehavior": 0x80052270,
		"TDoroHaneKuri::behaveToWater": 0x80052338,
		"TDoroHaneKuri::setMActorAndKeeper": 0x80052458,
		"TDoroHaneKuri::attackToMario": 0x800524c4,
		"TDoroHaneKuri::onHaveCap": 0x80052680,
		"TDoroHaneKuri::reset": 0x8005269c,
		"TDoroHaneKuri::init": 0x8005272c,
		"TDoroHaneKuri::TDoroHaneKuri": 0x800528fc,
		"THaneHamuKuri::getBasNameTable": 0x80052978,
		"THaneHamuKuri::isHitValid": 0x80052984,
		"THaneHamuKuri::isCollidMove": 0x800529b0,
		"THaneHamuKuri::setDeadAnm": 0x800529d0,
		"THaneHamuKuri::setBckAnm": 0x80052aa8,
		"THaneHamuKuri::setCrashAnm": 0x80052ac8,
		"THaneHamuKuri::behaveToWater": 0x80052af8,
		"THaneHamuKuri::setRollAnm": 0x80052b3c,
		"THaneHamuKuri::setRunAnm": 0x80052b6c,
		"THaneHamuKuri::setWalkAnm": 0x80052b9c,
		"THaneHamuKuri::setWaitAnm": 0x80052bcc,
		"THaneHamuKuri::setMActorAndKeeper": 0x80052bfc,
		"THaneHamuKuri::attackToMario": 0x80052c68,
		"THaneHamuKuri::isReachedToGoal": 0x80052cd8,
		"THaneHamuKuri::bind": 0x80052d80,
		"THaneHamuKuri::walkBehavior": 0x80052f60,
		"THaneHamuKuri::reset": 0x80053800,
		"THaneHamuKuri::moveObject": 0x80053874,
		"THaneHamuKuri::init": 0x80053894,
		"THaneHamuKuri::THaneHamuKuri": 0x80053978,
		"THamuKuri::forceRoll": 0x800539d8,
		"forceRoll": 0x800539d8,
		"THamuKuri::isCollidMove": 0x80053bdc,
		"THamuKuri::isHitValid": 0x80054094,
		"THamuKuri::isResignationAttack": 0x800541d0,
		"THamuKuri::getTakingMtx": 0x800542bc,
		"THamuKuri::getBasNameTable": 0x800543bc,
		"THamuKuri::initAttacker": 0x800543c8,
		"THamuKuri::walkBehavior": 0x8005444c,
		"THamuKuri::setCrashAnm": 0x8005448c,
		"THamuKuri::setRollAnm": 0x80054590,
		"THamuKuri::setRunAnm": 0x800545c0,
		"THamuKuri::setWaitAnm": 0x800545f0,
		"THamuKuri::setDeadAnm": 0x80054620,
		"THamuKuri::setWalkAnm": 0x80054770,
		"THamuKuri::setGenerateAnm": 0x800547a0,
		"THamuKuri::setBckAnm": 0x800547d0,
		"THamuKuri::endHitWaterJump": 0x800547f0,
		"THamuKuri::setAfterDeadEffect": 0x8005483c,
		"THamuKuri::genRandomItem": 0x80054a24,
		"THamuKuri::getGravityY": 0x80054a44,
		"THamuKuri::makeCapFly": 0x80054ab4,
		"makeCapFly": 0x80054ab4,
		"THamuKuri::onHaveCap": 0x80054e18,
		"THamuKuri::selectCapHolder": 0x80054e24,
		"selectCapHolder": 0x80054e24,
		"THamuKuri::setBehavior": 0x80054ed4,
		"THamuKuri::moveObject": 0x80055048,
		"THamuKuri::attackToMario": 0x80055208,
		"THamuKuri::behaveToFindMario": 0x800552ec,
		"THamuKuri::jumpToSearchActor": 0x80055348,
		"jumpToSearchActor": 0x80055348,
		"THamuKuri::isFindMario": 0x800554fc,
		"THamuKuri::behaveToWater": 0x80055584,
		"THamuKuri::bind": 0x800557c0,
		"THamuKuri::reset": 0x80055a20,
		"THamuKuri::setMActorAndKeeper": 0x80055a74,
		"THamuKuri::init": 0x80055b58,
		"THamuKuri::THamuKuri": 0x80055be8,
		"TDoroHamuKuriManager::perform": 0x80055c68,
		"TDoroHamuKuriManager::createModelData": 0x80055d14,
		"TDoroHamuKuriManager::createEnemyInstance": 0x80055d48,
		"TDoroHamuKuriManager::loadAfter": 0x80055da4,
		"TDoroHamuKuriManager::load": 0x80055efc,
		"TDoroHamuKuriManager::TDoroHamuKuriManager": 0x80055f68,
		"THamuKuriManager::~THamuKuriManager": 0x80055fcc,
		"TDoroHige::perform": 0x80056040,
		"TFireHamuKuriManager::createModelData": 0x80056094,
		"TFireHamuKuriManager::initSetEnemies": 0x800560c8,
		"TFireHamuKuriManager::createEnemyInstance": 0x8005625c,
		"TFireHamuKuriManager::load": 0x800562c8,
		"TFireHamuKuriManager::TFireHamuKuriManager": 0x80056378,
		"TBossDangoHamuKuriManager::createEnemyInstance": 0x800563d8,
		"TBossDangoHamuKuriManager::load": 0x8005643c,
		"TBossDangoHamuKuriManager::TBossDangoHamuKuriManager": 0x800564ec,
		"TDangoHamuKuriManager::~TDangoHamuKuriManager": 0x8005655c,
		"TDoroHaneKuriManager::perform": 0x800565e0,
		"TDangoHamuKuriManager::createModelDataArray": 0x8005668c,
		"TDangoHamuKuriManager::createEnemyInstance": 0x800566fc,
		"TDangoHamuKuriManager::load": 0x80056744,
		"TDangoHamuKuriManager::TDangoHamuKuriManager": 0x800567b0,
		"TDoroHaneKuriManager::createModelData": 0x80056810,
		"TDoroHaneKuriManager::createEnemyInstance": 0x80056844,
		"TDoroHaneKuriManager::loadAfter": 0x800568a8,
		"TDoroHaneKuriManager::load": 0x80056a00,
		"TDoroHaneKuriManager::TDoroHaneKuriManager": 0x80056b60,
		"THaneHamuKuriManager::~THaneHamuKuriManager": 0x80056bd0,
		"THaneHamuKuriManager::createAnmData": 0x80056c54,
		"THaneHamuKuriManager::createModelData": 0x80056c74,
		"THaneHamuKuriManager::createEnemyInstance": 0x80056ca8,
		"THaneHamuKuriManager::load": 0x80056cf0,
		"THaneHamuKuriManager::THaneHamuKuriManager": 0x80056e50,
		"THamuKuriManager::createEnemyInstance": 0x80056eb0,
		"THamuKuriManager::checkSerialKill": 0x80056ef8,
		"checkSerialKill": 0x80056ef8,
		"THamuKuriManager::requestSerialKill": 0x80057068,
		"requestSerialKill": 0x80057068,
		"THamuKuriManager::setSearchHamuKuri": 0x80057158,
		"setSearchHamuKuri": 0x80057158,
		"THamuKuriManager::perform": 0x8005741c,
		"THamuKuriManager::createAnmData": 0x800574a4,
		"THamuKuriManager::createModelData": 0x80057504,
		"THamuKuriManager::loadAfter": 0x80057538,
		"THamuKuriManager::load": 0x8005764c,
		"THamuKuriManager::THamuKuriManager": 0x800576b8,
		"THamuKuriSaveLoadParams::THamuKuriSaveLoadParams": 0x8005770c,
		"THamuKuriLauncher::stateLaunch": 0x800579d0,
		"THamuKuriLauncher::drawObject": 0x80057ba0,
		"TBossDangoHamuKuri::changeByJuice": 0x80057d00,
		"TBossDangoHamuKuri::isFindMario": 0x80057d08,
		"THaneHamuKuri2::forceKill": 0x80057dac,
		"THaneHamuKuri2::isHitValid": 0x80057db0,
		"THaneHamuKuri2::behaveToWater": 0x80057db8,
		"THaneHamuKuri::setBehavior": 0x80057dbc,
		"THaneHamuKuri::setGenerateAnm": 0x80057dc0,
		"THaneHamuKuri::canDoJitabata": 0x80057dc4,
		"TDoroHamuKuriManager::~TDoroHamuKuriManager": 0x80057f04,
		"TSmallEnemyManager::initSetEnemies": 0x80057f88,
		"TDoroHige::~TDoroHige": 0x80057f8c,
		"TFireHamuKuriManager::~TFireHamuKuriManager": 0x80058010,
		"TBossDangoHamuKuriManager::~TBossDangoHamuKuriManager": 0x80058094,
		"TBossDangoHamuKuriManager::clipEnemies": 0x80058128,
		"TDangoHamuKuriManager::clipEnemies": 0x8005812c,
		"TDoroHaneKuriManager::~TDoroHaneKuriManager": 0x80058130,
		"Enemy::__sinit_hamukuri_cpp": 0x80058248,
		"__sinit_hamukuri_cpp": 0x80058248,
		"Enemy::__sinit_hinokuri2_cpp": 0x8005862c,
		"__sinit_hinokuri2_cpp": 0x8005862c,
		"TNerveMameGessoWait::~TNerveMameGessoWait": 0x80058928,
		"TNerveMameGessoWait::execute": 0x80058984,
		"TNerveMameGessoGraphJumpWander::~TNerveMameGessoGraphJumpWander": 0x80058ad8,
		"TNerveMameGessoObject::execute": 0x80058b34,
		"TNerveMameGessoObject::~TNerveMameGessoObject": 0x80058e60,
		"TNerveMameGessoThrown::execute": 0x80058ebc,
		"TNerveMameGessoThrown::~TNerveMameGessoThrown": 0x80059104,
		"TNerveMameGessoPickUp::execute": 0x80059160,
		"TNerveMameGessoPickUp::~TNerveMameGessoPickUp": 0x80059214,
		"TNerveMameGessoTrample::execute": 0x80059270,
		"TNerveMameGessoTrample::~TNerveMameGessoTrample": 0x80059364,
		"TNerveMameGessoJitabata::execute": 0x800593c0,
		"TNerveMameGessoJitabata::~TNerveMameGessoJitabata": 0x800595bc,
		"TNerveMameGessoDamage::execute": 0x80059618,
		"TNerveMameGessoDamage::~TNerveMameGessoDamage": 0x80059954,
		"TNerveMameGessoGraphJumpWander::execute": 0x800599b0,
		"TMameGesso::getBasNameTable": 0x80059ffc,
		"TMameGesso::doKeepDistance": 0x8005a008,
		"TMameGesso::isInhibitedForceMove": 0x8005a038,
		"TMameGesso::calcObjCollision": 0x8005a040,
		"calcObjCollision": 0x8005a040,
		"TMameGesso::isCollidMove": 0x8005a1b0,
		"TMameGesso::behaveToRelease": 0x8005a25c,
		"TMameGesso::behaveToTaken": 0x8005a380,
		"TMameGesso::behaveToWater": 0x8005a498,
		"TMameGesso::setDeadAnm": 0x8005a610,
		"TMameGesso::setFreezeAnm": 0x8005a61c,
		"TMameGesso::setWaitAnm": 0x8005a654,
		"TMameGesso::getGravityY": 0x8005a6fc,
		"TMameGesso::kill": 0x8005a7f4,
		"TMameGesso::isHitValid": 0x8005aba8,
		"TMameGesso::reset": 0x8005acc4,
		"TMameGesso::calcRootMatrix": 0x8005adb4,
		"TMameGesso::attackToMario": 0x8005aed0,
		"TMameGesso::setMActorAndKeeper": 0x8005af68,
		"TMameGesso::moveObject": 0x8005afd4,
		"TMameGesso::init": 0x8005b068,
		"TMameGesso::load": 0x8005b184,
		"TMameGesso::TMameGesso": 0x8005b1cc,
		"TMameGessoManager::perform": 0x8005b260,
		"TMameGessoManager::initSetEnemies": 0x8005b31c,
		"TMameGessoManager::createEnemyInstance": 0x8005b320,
		"TMameGessoManager::loadAfter": 0x8005b368,
		"TMameGessoManager::load": 0x8005b388,
		"TMameGessoManager::TMameGessoManager": 0x8005b3e0,
		"TMameGessoSaveLoadParams::TMameGessoSaveLoadParams": 0x8005b41c,
		"TMameGesso::changeByJuice": 0x8005b6f0,
		"TMameGesso::isEatenByYosshi": 0x8005b6f8,
		"TMameGesso::forceKill": 0x8005b700,
		"TSmallEnemy::setBehavior": 0x8005b704,
		"TSmallEnemy::setWalkAnm": 0x8005b708,
		"TSmallEnemy::setRunAnm": 0x8005b70c,
		"TMameGessoManager::~TMameGessoManager": 0x8005b7ac,
		"Enemy::__sinit_mameGesso_cpp": 0x8005b820,
		"__sinit_mameGesso_cpp": 0x8005b820,
		"TNerveNKFollowMario::~TNerveNKFollowMario": 0x8005ba94,
		"TNerveNKFollowMario::execute": 0x8005baf0,
		"TNerveNameKuriJumpAttackPrepare::~TNerveNameKuriJumpAttackPrepare": 0x8005bc7c,
		"TNerveNKFollowMario::theNerve": 0x8005bcd8,
		"TNerveNameKuriDrawPollute::execute": 0x8005bd3c,
		"TNerveNameKuriDrawPollute::theNerve": 0x8005bd44,
		"TNerveNameKuriDrawPollute::~TNerveNameKuriDrawPollute": 0x8005bda8,
		"TNerveNameKuriDiffuse::execute": 0x8005be04,
		"TNerveNameKuriDiffuse::theNerve": 0x8005be38,
		"TNerveNameKuriDiffuse::~TNerveNameKuriDiffuse": 0x8005be9c,
		"TNerveNameKuriExplosion::execute": 0x8005bef8,
		"TNerveNameKuriExplosion::theNerve": 0x8005bf6c,
		"TNerveNameKuriExplosion::~TNerveNameKuriExplosion": 0x8005bfd0,
		"TNerveNameKuriJumpAttackPrepare::execute": 0x8005c02c,
		"TNerveNameKuriJumpAttack::~TNerveNameKuriJumpAttack": 0x8005c218,
		"TNerveNameKuriJumpAttackPrepare::theNerve": 0x8005c274,
		"TNerveNameKuriJumpAttack::execute": 0x8005c2d8,
		"TNerveNameKuriJumpAttack::theNerve": 0x8005c7c0,
		"TNerveNameKuriLand::execute": 0x8005c824,
		"TNerveNameKuriLand::theNerve": 0x8005c8b4,
		"TNerveNameKuriLand::~TNerveNameKuriLand": 0x8005c918,
		"TDiffusionNameKuriManager::createEnemyInstance": 0x8005c974,
		"TDiffusionNameKuriManager::load": 0x8005ca6c,
		"TNameKuri::getBasNameTable": 0x8005cd10,
		"TNameKuri::isCollidMove": 0x8005cd1c,
		"TNameKuri::isHitValid": 0x8005ce18,
		"TNameKuri::endHitWaterJump": 0x8005ce5c,
		"TNameKuri::behaveToFindMario": 0x8005ce70,
		"TNameKuri::attackToMario": 0x8005cf4c,
		"TNameKuri::reset": 0x8005d01c,
		"TNameKuri::setMActorAndKeeper": 0x8005d154,
		"TNameKuri::setMeltAnm": 0x8005d1c0,
		"TNameKuri::setWaitAnm": 0x8005d318,
		"TNameKuri::setAfterDeadEffect": 0x8005d348,
		"TNameKuri::setDeadAnm": 0x8005d3c4,
		"TNameKuri::setWalkAnm": 0x8005d51c,
		"TNameKuri::setGenerateAnm": 0x8005d54c,
		"TNameKuri::setBckAnm": 0x8005d5b0,
		"TNameKuri::getGravityY": 0x8005d5d0,
		"TNameKuri::behaveToWater": 0x8005d674,
		"TNameKuri::setBehavior": 0x8005d7b4,
		"TNameKuri::moveObject": 0x8005d7b8,
		"TNameKuri::perform": 0x8005d9e4,
		"TNameKuri::calcRootMatrix": 0x8005db04,
		"TNameKuri::init": 0x8005dea4,
		"TNameKuri::TNameKuri": 0x8005e058,
		"Enemy::NameKuriScaleCallback": 0x8005e0cc,
		"NameKuriScaleCallback": 0x8005e0cc,
		"Enemy::NameKuriAttackCallback": 0x8005e1bc,
		"NameKuriAttackCallback": 0x8005e1bc,
		"TNameIndParCallback::draw": 0x8005e350,
		"TNameIndParCallback::execute": 0x8005e354,
		"TNameKuriManager::perform": 0x8005e70c,
		"TNameKuriManager::createModelData": 0x8005e72c,
		"TNameKuriManager::createEnemyInstance": 0x8005e760,
		"TNameKuriManager::initSetEnemies": 0x8005e7ec,
		"TNameKuriManager::loadAfter": 0x8005e960,
		"TNameKuriManager::load": 0x8005e9c4,
		"TNameKuriManager::TNameKuriManager": 0x8005ec68,
		"TNameKuriLauncher::stateLaunch": 0x8005ecb4,
		"TDiffusionNameKuriManager::~TDiffusionNameKuriManager": 0x8005ee44,
		"Enemy::__sinit_namekuri_cpp": 0x8005efc8,
		"__sinit_namekuri_cpp": 0x8005efc8,
		"TNerveStayPakkunAppear::~TNerveStayPakkunAppear": 0x8005f2dc,
		"TNerveStayPakkunAppear::execute": 0x8005f338,
		"TNervePakkunStay::~TNervePakkunStay": 0x8005f4ec,
		"TNerveStayPakkunHide::execute": 0x8005f548,
		"TNerveStayPakkunHide::~TNerveStayPakkunHide": 0x8005f7f8,
		"TNervePakkunFreeze::execute": 0x8005f854,
		"TNervePakkunFreeze::~TNervePakkunFreeze": 0x8005f98c,
		"TNervePakkunShoot::execute": 0x8005f9e8,
		"TNervePakkunShoot::~TNervePakkunShoot": 0x8005fb48,
		"TNervePakkunHide::execute": 0x8005fba4,
		"TNervePakkunAppear::~TNervePakkunAppear": 0x8005fd0c,
		"TNervePakkunHide::~TNervePakkunHide": 0x8005fd68,
		"TNervePakkunAppear::execute": 0x8005fdc4,
		"TNervePakkunStay::execute": 0x8005fed8,
		"TNervePakkunGenerate::execute": 0x8006098c,
		"TNervePakkunGenerate::~TNervePakkunGenerate": 0x80060b88,
		"TStayPakkun::getSaveParam": 0x80060be4,
		"TStayPakkun::shoot": 0x80060bf0,
		"TStayPakkun::kill": 0x80060c20,
		"TStayPakkun::shootIn": 0x80060ca0,
		"TStayPakkun::isHitValid": 0x80060dc0,
		"TStayPakkun::setBehavior": 0x80060fd0,
		"TStayPakkun::calcRootMatrix": 0x8006110c,
		"TStayPakkun::genRandomItem": 0x80061130,
		"TStayPakkun::setDeadAnm": 0x8006128c,
		"TStayPakkun::reset": 0x800612bc,
		"TStayPakkun::init": 0x80061324,
		"TStayPakkun::load": 0x80061458,
		"TPakkunSeed::forceKill": 0x8006153c,
		"TPakkunSeed::set": 0x80061624,
		"TPakkunSeed::rebirth": 0x800616cc,
		"TPakkunSeed::shoot": 0x800618f0,
		"TPakkunSeed::appear": 0x8006194c,
		"TPakkunSeed::getNowGravity": 0x80061974,
		"TPakkunSeed::behaveToHitGround": 0x800619c4,
		"TPakkunSeed::calcRootMatrix": 0x80061ae0,
		"TPakkunSeed::behaveToHitWall": 0x80061b48,
		"TPakkunSeed::behaveToHost": 0x80061bcc,
		"TPakkunSeed::moveObject": 0x80061bf0,
		"TPakkunSeed::loadInit": 0x80061cf4,
		"TPakkun::getBasNameTable": 0x80061e74,
		"TPakkun::shoot": 0x80061e80,
		"TPakkun::shootIn": 0x80061eb0,
		"TPakkun::reset": 0x80061f00,
		"TPakkun::setMActorAndKeeper": 0x80061f48,
		"TPakkun::behaveToWater": 0x80061fb4,
		"TPakkun::onShootLiner": 0x800621f0,
		"onShootLiner": 0x800621f0,
		"TPakkun::perform": 0x8006234c,
		"TPakkun::setDeadAnm": 0x800624b4,
		"TPakkun::setFreezeAnm": 0x800624f0,
		"TPakkun::setWaitAnm": 0x80062520,
		"TPakkun::kill": 0x80062550,
		"TPakkun::isInhibitedForceMove": 0x80062590,
		"TPakkun::init": 0x80062598,
		"TPakkun::load": 0x80062840,
		"TPakkun::TPakkun": 0x80062900,
		"TPakkunManager::clipEnemies": 0x80062964,
		"TPakkunManager::createEnemyInstance": 0x80062b50,
		"TPakkunManager::createModelData": 0x80062b98,
		"TPakkunManager::loadAfter": 0x80062bcc,
		"TPakkunManager::load": 0x80062bec,
		"TPakkunManager::TPakkunManager": 0x80063120,
		"Enemy::PakkunRootCallback2": 0x80063174,
		"PakkunRootCallback2": 0x80063174,
		"Enemy::PakkunRootCallback": 0x80063228,
		"PakkunRootCallback": 0x80063228,
		"Enemy::PakkunSeedCallback": 0x8006338c,
		"PakkunSeedCallback": 0x8006338c,
		"TStayPakkun::setAfterDeadEffect": 0x8006349c,
		"TPakkun::isCollidMove": 0x800634a0,
		"TPakkun::decHpByWater": 0x800634a8,
		"TSmallEnemy::initAttacker": 0x800634ac,
		"TPakkunManager::~TPakkunManager": 0x8006365c,
		"Enemy::__sinit_pakkun_cpp": 0x800636d0,
		"__sinit_pakkun_cpp": 0x800636d0,
		"TNerveSmallEnemyChange::~TNerveSmallEnemyChange": 0x800639e4,
		"TNerveSmallEnemyChange::execute": 0x80063a40,
		"TNerveSmallEnemyChange::theNerve": 0x80063b34,
		"TNerveSmallEnemyWait::execute": 0x80063b98,
		"TSmallEnemy::setWaitAnm": 0x80063c30,
		"TNerveSmallEnemyWait::theNerve": 0x80063c34,
		"TNerveSmallEnemyWait::~TNerveSmallEnemyWait": 0x80063c98,
		"TNerveSmallEnemyHitWaterJump::execute": 0x80063cf4,
		"TNerveSmallEnemyHitWaterJump::theNerve": 0x80063efc,
		"TNerveSmallEnemyHitWaterJump::~TNerveSmallEnemyHitWaterJump": 0x80063f60,
		"TNerveSmallEnemyJump::execute": 0x80063fbc,
		"TNerveSmallEnemyJump::theNerve": 0x800640cc,
		"TNerveSmallEnemyJump::~TNerveSmallEnemyJump": 0x80064130,
		"TNerveSmallEnemyFreeze::execute": 0x8006418c,
		"TNerveSmallEnemyFreeze::theNerve": 0x8006422c,
		"TNerveSmallEnemyFreeze::~TNerveSmallEnemyFreeze": 0x80064290,
		"TNerveSmallEnemyDie::execute": 0x800642ec,
		"TNerveSmallEnemyDie::~TNerveSmallEnemyDie": 0x80064634,
		"TSmallEnemy::setDeadAnm": 0x80064690,
		"TNerveSmallEnemyDie::theNerve": 0x80064694,
		"TSmallEnemy::perform": 0x800646f8,
		"TSmallEnemy::behaveToHitOthers": 0x80064774,
		"behaveToHitOthers": 0x80064774,
		"TSmallEnemy::isHitWallInBound": 0x800648bc,
		"isHitWallInBound": 0x800648bc,
		"TSmallEnemy::isEaten": 0x800649f4,
		"isEaten": 0x800649f4,
		"TSmallEnemy::expandCollision": 0x80064a90,
		"expandCollision": 0x80064a90,
		"TSmallEnemy::setBckAnm": 0x80064bcc,
		"TSmallEnemy::generateEffectColumWater": 0x80064c40,
		"TSmallEnemy::isFindMarioFromParam": 0x80064cd0,
		"isFindMarioFromParam": 0x80064cd0,
		"TSmallEnemy::isMarioInWater": 0x80064d8c,
		"isMarioInWater": 0x80064d8c,
		"TSmallEnemy::isFindMario": 0x80064e5c,
		"TSmallEnemy::kill": 0x80064fc8,
		"TSmallEnemy::decHpByWater": 0x80065158,
		"TSmallEnemy::changeOut": 0x800651a4,
		"TSmallEnemy::scalingChangeActor": 0x80065280,
		"TSmallEnemy::changeMove": 0x80065314,
		"changeMove": 0x80065314,
		"TSmallEnemy::getChangeBlockTime": 0x80065770,
		"TSmallEnemy::changeByJuice": 0x80065778,
		"TSmallEnemy::receiveMessage": 0x800659e0,
		"TSmallEnemy::updateAnmSound": 0x80065c10,
		"TSmallEnemy::moveObject": 0x80065c30,
		"TSmallEnemy::isCollidMove": 0x80066090,
		"TSmallEnemy::generateItem": 0x800660fc,
		"TSmallEnemy::setAfterDeadEffect": 0x80066204,
		"TSmallEnemy::genEventCoin": 0x800662fc,
		"TSmallEnemy::genRandomItem": 0x80066600,
		"TSmallEnemy::forceKill": 0x80066690,
		"TSmallEnemy::reset": 0x800668b4,
		"TSmallEnemy::attackToMario": 0x80066ce8,
		"TSmallEnemy::sendAttackMsgToMario": 0x80066df8,
		"TSmallEnemy::behaveToWater": 0x80066e1c,
		"TSmallEnemy::loadAfter": 0x80066f94,
		"TSmallEnemy::load": 0x80066fc8,
		"TSmallEnemy::init": 0x80067038,
		"TSmallEnemy::setMActorAndKeeper": 0x800673c4,
		"TSmallEnemy::TSmallEnemy": 0x8006742c,
		"TSmallEnemyManager::getHolder": 0x800674b8,
		"getHolder": 0x800674b8,
		"TSmallEnemyManager::createEnemies": 0x8006752c,
		"TSmallEnemyManager::loadAfter": 0x8006756c,
		"TSmallEnemyManager::load": 0x800675c4,
		"TSmallEnemyManager::createModelData": 0x800675e4,
		"TSmallEnemyManager::TSmallEnemyManager": 0x80067618,
		"TSmallEnemyParams::TSmallEnemyParams": 0x80067664,
		"Enemy::__sinit_smallEnemy_cpp": 0x80067ba8,
		"__sinit_smallEnemy_cpp": 0x80067ba8,
		"TSpider::bind": 0x80067eac,
		"TSpider::~TSpider": 0x80068420,
		"TSpider::TSpider": 0x80068484,
		"TSplinePath::calcSpline": 0x800684d8,
		"calcSpline": 0x800684d8,
		"TSplinePath::calcTable": 0x800685bc,
		"calcTable": 0x800685bc,
		"TSplinePath::makeTable": 0x8006871c,
		"makeTable": 0x8006871c,
		"TSplinePath::TSplinePath": 0x80068a80,
		"TNerveTypicalGraphWander::~TNerveTypicalGraphWander": 0x80068b98,
		"TNerveTypicalGraphWander::execute": 0x80068bf4,
		"TNerveTypicalGraphWander::theNerve": 0x80068cf8,
		"TTypicalManager::createEnemyInstance": 0x80068d5c,
		"TTypicalManager::load": 0x80068de4,
		"TTypicalManager::TTypicalManager": 0x80068ea4,
		"TTypicalEnemy::init": 0x80068ee0,
		"TTypicalEnemy::TTypicalEnemy": 0x80068f98,
		"TTypicalManager::~TTypicalManager": 0x80069000,
		"TWalker::setMode": 0x800690d8,
		"setMode": 0x800690d8,
		"TWalker::bind": 0x80069144,
		"TWalker::reset": 0x80069da8,
		"TWalker::~TWalker": 0x80069dc8,
		"TWalker::TWalker": 0x80069e40,
		"TSolidStack<TBGCheckData_const*>::~TSolidStack": 0x80069efc,
		"Enemy::calcFarthestVertex": 0x80069f48,
		"calcFarthestVertex": 0x80069f48,
		"TNerveWalkerTraceMario::~TNerveWalkerTraceMario": 0x8006a110,
		"TNerveWalkerTraceMario::execute": 0x8006a16c,
		"TNerveWalkerTraceMario::theNerve": 0x8006a428,
		"TNerveWalkerEscape::execute": 0x8006a48c,
		"TNerveWalkerEscape::theNerve": 0x8006a5ec,
		"TNerveWalkerEscape::~TNerveWalkerEscape": 0x8006a650,
		"TNerveWalkerPostAttack::execute": 0x8006a6ac,
		"TNerveWalkerPostAttack::theNerve": 0x8006a744,
		"TNerveWalkerPostAttack::~TNerveWalkerPostAttack": 0x8006a7a8,
		"TNerveWalkerAttack::execute": 0x8006a804,
		"TNerveWalkerAttack::theNerve": 0x8006a980,
		"TNerveWalkerAttack::~TNerveWalkerAttack": 0x8006a9e4,
		"TNerveWalkerGraphWander::execute": 0x8006aa40,
		"TNerveWalkerGraphWander::theNerve": 0x8006ab1c,
		"TNerveWalkerGraphWander::~TNerveWalkerGraphWander": 0x8006ab80,
		"TNerveWalkerGenerate::execute": 0x8006abdc,
		"TNerveWalkerGenerate::theNerve": 0x8006acbc,
		"TNerveWalkerGenerate::~TNerveWalkerGenerate": 0x8006ad20,
		"TWalkerEnemy::initialGraphNode": 0x8006ad7c,
		"initialGraphNode": 0x8006ad7c,
		"TWalkerEnemy::isReachedToGoalXZ": 0x8006ada8,
		"TWalkerEnemy::isResignationAttack": 0x8006ae70,
		"TWalkerEnemy::initAttacker": 0x8006af4c,
		"TWalkerEnemy::behaveToFindMario": 0x8006af70,
		"TWalkerEnemy::walkBehavior": 0x8006b288,
		"TWalkerEnemy::reset": 0x8006b39c,
		"TWalkerEnemy::attackToMario": 0x8006b500,
		"TWalkerEnemy::moveObject": 0x8006b6b4,
		"TWalkerEnemy::init": 0x8006b884,
		"TWalkerEnemy::TWalkerEnemy": 0x8006b9b0,
		"TWalkerEnemyParams::TWalkerEnemyParams": 0x8006b9f4,
		"Enemy::__sinit_walkerEnemy_cpp": 0x8006bb38,
		"__sinit_walkerEnemy_cpp": 0x8006bb38,
		"TNerveBGRoll::~TNerveBGRoll": 0x8006be3c,
		"TNerveBGRoll::execute": 0x8006be98,
		"MActorAnmEach<J3DAnmTransformKey>::setFrameCtrl": 0x8006c5b4,
		"setFrameCtrl": 0x8006c5b4,
		"MActorAnmDataEach<J3DAnmTransformKey>::getAnmPtr": 0x8006c640,
		"getAnmPtr": 0x8006c640,
		"TMActorKeeper::getMActorAnmData": 0x8006c664,
		"TNerveBGRoll::theNerve": 0x8006c66c,
		"TNerveBGPolDrop::execute": 0x8006c6d0,
		"TNerveBGPolDrop::~TNerveBGPolDrop": 0x8006ca0c,
		"TNerveBGPolDrop::theNerve": 0x8006ca68,
		"TNerveBGPollute::execute": 0x8006cacc,
		"TNerveBGPollute::theNerve": 0x8006cd3c,
		"TNerveBGPollute::~TNerveBGPollute": 0x8006cda0,
		"TNerveBGDie::execute": 0x8006cdfc,
		"TNerveBGDie::theNerve": 0x8006d510,
		"TNerveBGDie::~TNerveBGDie": 0x8006d574,
		"TNerveBGTug::execute": 0x8006d5d0,
		"TNerveBGTug::theNerve": 0x8006da6c,
		"TNerveBGTug::~TNerveBGTug": 0x8006dad0,
		"TNerveBGTentacleDamage::execute": 0x8006db2c,
		"TNerveBGTentacleDamage::~TNerveBGTentacleDamage": 0x8006ddf4,
		"TNerveBGTentacleDamage::theNerve": 0x8006de50,
		"TNerveBGBeakDamage::execute": 0x8006deb4,
		"TNerveBGBeakDamage::theNerve": 0x8006e434,
		"TNerveBGBeakDamage::~TNerveBGBeakDamage": 0x8006e498,
		"TNerveBGEyeDamage::execute": 0x8006e4f4,
		"TNerveBGEyeDamage::theNerve": 0x8006e798,
		"TNerveBGEyeDamage::~TNerveBGEyeDamage": 0x8006e7fc,
		"TNerveBGWait::execute": 0x8006e858,
		"TNerveBGWait::theNerve": 0x8006ec5c,
		"TNerveBGWait::~TNerveBGWait": 0x8006ecc0,
		"TBossGessoManager::load": 0x8006ed1c,
		"TBossGessoManager::initJParticle": 0x8006ed90,
		"TBossGessoManager::createModelData": 0x8006f274,
		"TBossGessoManager::TBossGessoManager": 0x8006f2a8,
		"TBossGesso::perform": 0x8006f2e4,
		"TBossGesso::calcRootMatrix": 0x8006fcb0,
		"TBossGesso::reset": 0x8006fe78,
		"TBossGesso::moveObject": 0x8006ff40,
		"Enemy::MsGetRotFromZaxisY": 0x80070644,
		"MsGetRotFromZaxisY": 0x80070644,
		"Enemy::SMS_GetMarioPos": 0x8007070c,
		"SMS_GetMarioPos": 0x8007070c,
		"TBossGesso::doAttackShoot": 0x80070714,
		"doAttackShoot": 0x80070714,
		"TBossGesso::doAttackUnison": 0x80070920,
		"doAttackUnison": 0x80070920,
		"TBossGesso::doAttackSkipRope": 0x80070bd0,
		"doAttackSkipRope": 0x80070bd0,
		"TBossGesso::doAttackDouble": 0x80070dac,
		"doAttackDouble": 0x80070dac,
		"TBossGesso::doAttackSingle": 0x80071060,
		"doAttackSingle": 0x80071060,
		"TBossGesso::receiveMessage": 0x80071ab8,
		"TBossGesso::getBasNameTable": 0x80071b10,
		"TBossGesso::beakHeld": 0x80071b1c,
		"beakHeld": 0x80071b1c,
		"TBossGesso::tentacleHeld": 0x80071b38,
		"tentacleHeld": 0x80071b38,
		"TBossGesso::launchPolDrop": 0x80071ba0,
		"TBossGesso::changeAllTentacleState": 0x80071c9c,
		"changeAllTentacleState": 0x80071c9c,
		"TBossGesso::gotTentacleDamage": 0x80071d40,
		"gotTentacleDamage": 0x80071d40,
		"TBossGesso::changeAttackMode": 0x80071ed4,
		"changeAttackMode": 0x80071ed4,
		"TBossGesso::stopIfRoll": 0x800724f0,
		"stopIfRoll": 0x800724f0,
		"TBossGesso::is2ndFightNow": 0x8007260c,
		"is2ndFightNow": 0x8007260c,
		"TBossGesso::showMessage": 0x8007262c,
		"TBossGesso::lenFromToeToMario": 0x800726b0,
		"lenFromToeToMario": 0x800726b0,
		"TBossGesso::rumblePad": 0x8007284c,
		"TBossGesso::init": 0x800729ac,
		"TBossGesso::TBossGesso": 0x8007326c,
		"TBGBinder::bind": 0x80073340,
		"TBGBodyHit::perform": 0x80073994,
		"TBGBodyHit::receiveMessage": 0x800739fc,
		"TBGEyeHit::perform": 0x80073a64,
		"TBGEyeHit::receiveMessage": 0x80073ab4,
		"TBGBeakHit::perform": 0x80073d70,
		"TBGBeakHit::receiveMessage": 0x800743c8,
		"TBGBeakHit::moveRequest": 0x80074b28,
		"TBGBeakHit::getTakingMtx": 0x80074cd8,
		"TBossGessoParams::TBossGessoParams": 0x80074ce0,
		"TBossGessoManager::~TBossGessoManager": 0x8007528c,
		"TBGBinder::~TBGBinder": 0x8007535c,
		"TBossGessoMtxCalc::~TBossGessoMtxCalc": 0x800753c0,
		"Enemy::__sinit_bossgesso_cpp": 0x80075610,
		"__sinit_bossgesso_cpp": 0x80075610,
		"TNerveElecCarapaceReturn::~TNerveElecCarapaceReturn": 0x80075968,
		"TNerveElecCarapaceReturn::execute": 0x800759c4,
		"TNerveElecNokonokoFreeze::~TNerveElecNokonokoFreeze": 0x80075d54,
		"TNerveElecCarapaceWait::execute": 0x80075db0,
		"TNerveElecCarapaceWait::~TNerveElecCarapaceWait": 0x80075dcc,
		"TNerveElecCarapaceMove::execute": 0x80075e28,
		"TNerveElecNokonokoCollect::~TNerveElecNokonokoCollect": 0x80076320,
		"TNerveElecCarapaceMove::~TNerveElecCarapaceMove": 0x8007637c,
		"TNerveElecNokonokoAttack::execute": 0x800763d8,
		"TNerveElecNokonokoAttack::~TNerveElecNokonokoAttack": 0x80076464,
		"TNerveElecNokonokoRebirth::execute": 0x800764c0,
		"TNerveElecNokonokoRebirth::~TNerveElecNokonokoRebirth": 0x800765d8,
		"TNerveElecNokonokoFreeze::execute": 0x80076634,
		"TNerveElecNokonokoTurn::execute": 0x80076938,
		"TNerveElecNokonokoTurn::~TNerveElecNokonokoTurn": 0x80076b5c,
		"TNerveElecNokonokoCollect::execute": 0x80076bb8,
		"TNerveElecNokonokoShoot::execute": 0x80076e94,
		"TNerveElecNokonokoShoot::~TNerveElecNokonokoShoot": 0x8007708c,
		"TElecCarapace::reflect": 0x800770e8,
		"reflect": 0x800770e8,
		"TElecCarapace::receiveMessage": 0x800772fc,
		"TElecCarapace::sendMessage": 0x8007738c,
		"TElecCarapace::calcRootMatrix": 0x80077584,
		"TElecCarapace::bind": 0x80077780,
		"TElecCarapace::shoot": 0x800777c0,
		"TElecCarapace::appear": 0x80077ab4,
		"TElecCarapace::getNowGravity": 0x80077b1c,
		"TElecCarapace::behaveToHitWall": 0x80077b50,
		"TElecCarapace::kill": 0x80077c50,
		"TElecCarapace::behaveToHitGround": 0x80077c70,
		"TElecCarapace::setBehavior": 0x80077d30,
		"TElecCarapace::perform": 0x80077d98,
		"TElecCarapace::loadInit": 0x80077ee8,
		"TElecCarapace::TElecCarapace": 0x800780d8,
		"TElecNokonoko::genRandomItem": 0x80078154,
		"TElecNokonoko::setMeltAnm": 0x80078208,
		"TElecNokonoko::setDeadAnm": 0x800782dc,
		"TElecNokonoko::setRunAnm": 0x8007830c,
		"TElecNokonoko::setWalkAnm": 0x8007835c,
		"TElecNokonoko::setWaitAnm": 0x800783ac,
		"TElecNokonoko::getBasNameTable": 0x800783e4,
		"TElecNokonoko::behaveToWater": 0x800783f0,
		"TElecNokonoko::behaveToFindMario": 0x80078598,
		"TElecNokonoko::isResignationAttack": 0x8007872c,
		"TElecNokonoko::receiveMessage": 0x80078884,
		"TElecNokonoko::sendAttackMsgToMario": 0x80078a08,
		"TElecNokonoko::calcRootMatrix": 0x80078a44,
		"TElecNokonoko::attackToMario": 0x80078de0,
		"TElecNokonoko::moveObject": 0x80078ff0,
		"TElecNokonoko::setMActorAndKeeper": 0x80079068,
		"TElecNokonoko::load": 0x80079100,
		"TElecNokonoko::rest": 0x80079140,
		"rest": 0x80079140,
		"TElecNokonoko::init": 0x80079174,
		"TElecNokonoko::TElecNokonoko": 0x800792ec,
		"TElecNokonokoManager::perform": 0x80079340,
		"TElecNokonokoManager::clipEnemies": 0x800793e0,
		"TElecNokonokoManager::createModelData": 0x80079508,
		"TElecNokonokoManager::createEnemyInstance": 0x8007953c,
		"TElecNokonokoManager::initSetEnemies": 0x800795a8,
		"TElecNokonokoManager::load": 0x800795ac,
		"TElecNokonokoManager::TElecNokonokoManager": 0x80079778,
		"TElecCarapace::rebirth": 0x80079838,
		"TElecCarapace::recoverScale": 0x8007983c,
		"TElecCarapace::getPhaseShift": 0x80079840,
		"TElecNokonokoManager::~TElecNokonokoManager": 0x800798f8,
		"Enemy::__sinit_elecNokonoko_cpp": 0x8007996c,
		"__sinit_elecNokonoko_cpp": 0x8007996c,
		"TNerveKageMarioModokiWait::~TNerveKageMarioModokiWait": 0x80079c78,
		"TNerveKageMarioModokiWait::execute": 0x80079cd4,
		"TKageMarioModoki::init": 0x80079e70,
		"TKageMarioModoki::load": 0x80079f74,
		"TKageMarioModokiManager::createModelData": 0x80079fb4,
		"TKageMarioModokiManager::createEnemyInstance": 0x80079fe8,
		"TKageMarioModokiManager::load": 0x8007a044,
		"TNerveTelesaTrample::execute": 0x8007a0b0,
		"TNerveTelesaTrample::~TNerveTelesaTrample": 0x8007a110,
		"TNerveTelesaAttackMario::execute": 0x8007a16c,
		"TNerveTelesaAttackMario::~TNerveTelesaAttackMario": 0x8007a438,
		"TNerveTelesaFreeze::execute": 0x8007a494,
		"TNerveTelesaFreeze::~TNerveTelesaFreeze": 0x8007a6b4,
		"TNerveTelesaDie::execute": 0x8007a710,
		"TNerveTelesaDie::~TNerveTelesaDie": 0x8007a974,
		"TNerveTelesaImitate::execute": 0x8007a9d0,
		"TNerveTelesaImitate::~TNerveTelesaImitate": 0x8007ad80,
		"TMarioModokiTelesa::init": 0x8007addc,
		"TMarioModokiTelesa::load": 0x8007ae70,
		"TMarioModokiTelesa::TMarioModokiTelesa": 0x8007b22c,
		"TBoxTelesa::isHitValid": 0x8007b314,
		"TBoxTelesa::reset": 0x8007b44c,
		"TBoxTelesa::load": 0x8007b6f8,
		"TBoxTelesa::TBoxTelesa": 0x8007b800,
		"TLoopTelesa::load": 0x8007b844,
		"TLoopTelesa::TLoopTelesa": 0x8007b8bc,
		"TSeeTelesa::load": 0x8007b900,
		"TSeeTelesa::TSeeTelesa": 0x8007b988,
		"TTelesa::changeTevKColor": 0x8007b9cc,
		"changeTevKColor": 0x8007b9cc,
		"TTelesa::isCollidMove": 0x8007bbe4,
		"TTelesa::setAttacker": 0x8007bc04,
		"setAttacker": 0x8007bc04,
		"TTelesa::initItemAttacker": 0x8007bd78,
		"initItemAttacker": 0x8007bd78,
		"TTelesa::initAttacker": 0x8007bfe4,
		"TTelesa::kill": 0x8007c2c8,
		"TTelesa::forceKill": 0x8007c404,
		"TTelesa::getGravityY": 0x8007c4dc,
		"TTelesa::reduceFlyForce": 0x8007c500,
		"reduceFlyForce": 0x8007c500,
		"TTelesa::setWaitAnm": 0x8007c59c,
		"TTelesa::setWalkAnm": 0x8007c5cc,
		"TTelesa::getBasNameTable": 0x8007c640,
		"TTelesa::changeOut": 0x8007c64c,
		"TTelesa::scalingChangeActor": 0x8007c728,
		"TTelesa::changeByJuice": 0x8007c7a4,
		"TTelesa::isReachedToGoal": 0x8007c9c4,
		"TTelesa::bind": 0x8007ca8c,
		"TTelesa::moveObject": 0x8007cdd0,
		"TTelesa::calcRootMatrix": 0x8007ce04,
		"TTelesa::walkBehavior": 0x8007d00c,
		"TTelesa::behaveToWater": 0x8007d1cc,
		"TTelesa::attackToMario": 0x8007d45c,
		"TTelesa::setBehavior": 0x8007d4d8,
		"TTelesa::drawObject": 0x8007d63c,
		"TTelesa::perform": 0x8007d668,
		"TTelesa::reset": 0x8007d7c4,
		"TTelesa::setMActorAndKeeper": 0x8007da68,
		"TTelesa::init": 0x8007dad4,
		"TTelesa::load": 0x8007dd6c,
		"TTelesa::TTelesa": 0x8007ddcc,
		"TTelesaManager::setFlagOutOfCube": 0x8007de6c,
		"TTelesaManager::telesaForceKill": 0x8007df40,
		"telesaForceKill": 0x8007df40,
		"TTelesaManager::createModelData": 0x8007e008,
		"TTelesaManager::createEnemies": 0x8007e03c,
		"TTelesaManager::createEnemyInstance": 0x8007e11c,
		"TTelesaManager::load": 0x8007e160,
		"TTelesaManager::TTelesaManager": 0x8007e210,
		"TTelesaSaveLoadParams::TTelesaSaveLoadParams": 0x8007e25c,
		"TKageMarioModokiManager::~TKageMarioModokiManager": 0x8007e63c,
		"TTelesa::isFindMario": 0x8007e6b0,
		"TTelesa::decHpByWater": 0x8007e6b8,
		"TTelesa::isInhibitedForceMove": 0x8007e6bc,
		"TTelesa::getChangeBlockTime": 0x8007e6c4,
		"TBoxTelesa::isEatenByYosshi": 0x8007e768,
		"TTelesaManager::~TTelesaManager": 0x8007e944,
		"Enemy::__sinit_telesa_cpp": 0x8007e9b8,
		"__sinit_telesa_cpp": 0x8007e9b8,
		"TNerveFireWanwanEscape::~TNerveFireWanwanEscape": 0x8007ece4,
		"TNerveFireWanwanEscape::execute": 0x8007ed40,
		"TNerveFireWanwanRecover::~TNerveFireWanwanRecover": 0x8007efe0,
		"TNerveFireWanwanEscape::theNerve": 0x8007f03c,
		"TNerveFireWanwanFreeze::execute": 0x8007f0a0,
		"TNerveFireWanwanFreeze::theNerve": 0x8007f210,
		"TNerveFireWanwanFreeze::~TNerveFireWanwanFreeze": 0x8007f274,
		"TNerveFireWanwanFly::execute": 0x8007f2d0,
		"TNerveFireWanwanFly::~TNerveFireWanwanFly": 0x8007f5cc,
		"TNerveFireWanwanHungTail::execute": 0x8007f628,
		"TNerveFireWanwanHungTail::~TNerveFireWanwanHungTail": 0x8007f890,
		"TNerveFireWanwanDie::execute": 0x8007f8ec,
		"TNerveFireWanwanDie::theNerve": 0x8007fb4c,
		"TNerveFireWanwanDie::~TNerveFireWanwanDie": 0x8007fbb0,
		"TNerveFireWanwanRecover::execute": 0x8007fc0c,
		"TNerveFireWanwanRecover::theNerve": 0x8007fe50,
		"TNerveFireWanwanRecoverGraph::execute": 0x8007feb4,
		"TNerveFireWanwanGraphWander::~TNerveFireWanwanGraphWander": 0x80080458,
		"JGeometry::TQuat4<float><float>::slerp": 0x800804fc,
		"slerp": 0x800804fc,
		"TNerveFireWanwanRecoverGraph::~TNerveFireWanwanRecoverGraph": 0x80080744,
		"TNerveFireWanwanTired::execute": 0x800807a0,
		"TNerveFireWanwanFindMario::~TNerveFireWanwanFindMario": 0x80080968,
		"TNerveFireWanwanTired::~TNerveFireWanwanTired": 0x800809c4,
		"TNerveFireWanwanAttack::execute": 0x80080a20,
		"TNerveFireWanwanAttack::~TNerveFireWanwanAttack": 0x80080cd0,
		"TNerveFireWanwanFindMario::execute": 0x80080d2c,
		"TNerveFireWanwanTurn::execute": 0x80081240,
		"TNerveFireWanwanTurn::theNerve": 0x8008145c,
		"TNerveFireWanwanTurn::~TNerveFireWanwanTurn": 0x800814c0,
		"TNerveFireWanwanGraphWander::execute": 0x8008151c,
		"TNerveFireWanwanGraphWander::theNerve": 0x800816b4,
		"TFireWanwan::isCollidMove": 0x80081718,
		"TFireWanwan::doKeepDistance": 0x80081720,
		"TFireWanwan::getBasNameTable": 0x80081734,
		"TFireWanwan::getGravityY": 0x80081740,
		"TFireWanwan::checkWalls": 0x80081868,
		"TFireWanwan::bindPoint": 0x80081a84,
		"bindPoint": 0x80081a84,
		"TFireWanwan::bindBody": 0x80081e5c,
		"bindBody": 0x80081e5c,
		"TFireWanwan::bind": 0x800821d4,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setQuat": 0x800829d8,
		"setQuat": 0x800829d8,
		"TFireWanwan::attackToMario": 0x80082a78,
		"TFireWanwan::sendAttackMsgToMario": 0x80082c54,
		"TTakeActor::isTaken": 0x80082c58,
		"isTaken": 0x80082c58,
		"TFireWanwan::initEscapeNextGraphNode": 0x80082c74,
		"initEscapeNextGraphNode": 0x80082c74,
		"TFireWanwan::checkHitActors": 0x80082e78,
		"TFireWanwan::emitEffects": 0x80083144,
		"TFireWanwan::updatePollute": 0x800836a0,
		"updatePollute": 0x800836a0,
		"TFireWanwan::updateRumble": 0x80083868,
		"updateRumble": 0x80083868,
		"TFireWanwan::moveObject": 0x80083a60,
		"TFireWanwan::calcRootMatrix": 0x80084148,
		"TFireWanwan::perform": 0x80084310,
		"TFireWanwan::isHitValid": 0x80084458,
		"TFireWanwan::kill": 0x80084460,
		"TFireWanwan::behaveToWater": 0x80084578,
		"TFireWanwan::receiveMessage": 0x80084900,
		"TFireWanwan::isMissMario": 0x80084a58,
		"isMissMario": 0x80084a58,
		"TFireWanwan::isFindMario": 0x80084c18,
		"TFireWanwan::reset": 0x80084c84,
		"TFireWanwan::setMActorAndKeeper": 0x80084dd8,
		"TFireWanwan::init": 0x80084e44,
		"TFireWanwan::TFireWanwan": 0x8008513c,
		"TFireWanwanTailHit::getHostPos": 0x80085198,
		"getHostPos": 0x80085198,
		"TFireWanwanTailHit::moveRequest": 0x800851a4,
		"TFireWanwanTailHit::getTakingMtx": 0x800852c8,
		"TFireWanwanTailHit::movementBody": 0x800852d0,
		"movementBody": 0x800852d0,
		"TFireWanwanTailHit::performNodes": 0x800856e4,
		"performNodes": 0x800856e4,
		"TFireWanwanTailHit::perform": 0x800859ac,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::operator_[]": 0x80086008,
		"operator_[]": 0x80086008,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::size": 0x80086018,
		"size": 0x80086018,
		"TFireWanwanTailHit::init": 0x80086020,
		"TTailRubber::Node::Node": 0x800864f8,
		"TFireWanwanTailHit::receiveMessage": 0x800864fc,
		"TFireWanwanTailNode::perform": 0x80086780,
		"TFireWanwanManager::perform": 0x80086970,
		"TFireWanwanManager::createModelData": 0x80086c0c,
		"TFireWanwanManager::load": 0x80086c40,
		"TFireWanwanManager::TFireWanwanManager": 0x80086c98,
		"TFireWanwanSaveLoadParams::TFireWanwanSaveLoadParams": 0x80086cf4,
		"TTailRubber::getLength": 0x800872ac,
		"TTailRubber::restrict": 0x8008738c,
		"restrict": 0x8008738c,
		"TTailRubber::adjust": 0x80087800,
		"TTailRubber::bindOne": 0x80087cb8,
		"bindOne": 0x80087cb8,
		"TFireWanwanManager::~TFireWanwanManager": 0x80087f0c,
		"MyUtil::value_lerp": 0x80087f80,
		"value_lerp": 0x80087f80,
		"Enemy::__sinit_fireWanwan_cpp": 0x80088258,
		"__sinit_fireWanwan_cpp": 0x80088258,
		"TStageEnemyInfo::~TStageEnemyInfo": 0x80088564,
		"TStageEnemyInfoTable::getMatchedInfo": 0x800885c8,
		"getMatchedInfo": 0x800885c8,
		"TStageEnemyInfoTable::TStageEnemyInfoTable": 0x800886dc,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::~TNameRefPtrAryT": 0x80088768,
		"TStageEnemyInfo::load": 0x800887e0,
		"TStageEnemyInfoTable::~TStageEnemyInfoTable": 0x8008886c,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::loadAfter": 0x800888f4,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::searchF": 0x80088954,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::load": 0x800889f0,
		"TOneShotGenerator::receiveMessage": 0x80088b84,
		"TOneShotGenerator::loadAfter": 0x80088c7c,
		"TOneShotGenerator::load": 0x80088db0,
		"TOneShotGenerator::TOneShotGenerator": 0x80088e00,
		"TGenerator::perform": 0x80088e60,
		"TGenerator::load": 0x80088f80,
		"TGenerator::TGenerator": 0x80089128,
		"TGenerator::~TGenerator": 0x800891ac,
		"TNerveBPCannonL::~TNerveBPCannonL": 0x80089228,
		"TNerveBPCannonL::execute": 0x80089284,
		"TNerveBPWaitL::~TNerveBPWaitL": 0x800893bc,
		"TNerveBPCannonL::theNerve": 0x80089418,
		"TNerveBPWaitL::execute": 0x8008947c,
		"TNerveBPWaitL::theNerve": 0x800896b0,
		"TNerveBPBreakSleep::execute": 0x80089714,
		"TNerveBPTakeOff::~TNerveBPTakeOff": 0x80089808,
		"TNerveBPBreakSleep::theNerve": 0x80089864,
		"TNerveBPBreakSleep::~TNerveBPBreakSleep": 0x800898c8,
		"TNerveBPSleep::execute": 0x80089924,
		"TNerveBPSleep::theNerve": 0x8008995c,
		"TNerveBPSleep::~TNerveBPSleep": 0x800899c0,
		"TNerveBPFall::execute": 0x80089a1c,
		"TNerveBPTornado::~TNerveBPTornado": 0x80089f38,
		"TNerveBPWait::~TNerveBPWait": 0x80089f94,
		"TNerveBPVomit::~TNerveBPVomit": 0x80089ff0,
		"TNerveBPFall::theNerve": 0x8008a04c,
		"TNerveBPFall::~TNerveBPFall": 0x8008a0b0,
		"TNerveBPHover::execute": 0x8008a10c,
		"TNerveBPFly::~TNerveBPFly": 0x8008a494,
		"TNerveBPFlyPivot::~TNerveBPFlyPivot": 0x8008a4f0,
		"TNerveBPFlyCannon::~TNerveBPFlyCannon": 0x8008a54c,
		"TNerveBPHover::~TNerveBPHover": 0x8008a5a8,
		"TNerveBPHover::theNerve": 0x8008a604,
		"TNerveBPFlyPivot::execute": 0x8008a668,
		"TNerveBPFlyPivot::theNerve": 0x8008a714,
		"TNerveBPFlyCannon::execute": 0x8008a778,
		"TNerveBPFlyCannon::theNerve": 0x8008a80c,
		"TNerveBPTouchDown::execute": 0x8008a870,
		"TNerveBPTouchDown::theNerve": 0x8008aa00,
		"TNerveBPTouchDown::~TNerveBPTouchDown": 0x8008aa64,
		"TNerveBPFly::execute": 0x8008aac0,
		"TNerveBPFly::theNerve": 0x8008ad8c,
		"TNerveBPTakeOff::execute": 0x8008adf0,
		"TNerveBPTakeOff::theNerve": 0x8008b018,
		"TNerveBPDie::execute": 0x8008b07c,
		"TNerveBPDie::theNerve": 0x8008b194,
		"TNerveBPDie::~TNerveBPDie": 0x8008b1f8,
		"TNerveBPPreDie::execute": 0x8008b254,
		"TNerveBPPreDie::theNerve": 0x8008b42c,
		"TNerveBPPreDie::~TNerveBPPreDie": 0x8008b490,
		"TNerveBPJumpReact::execute": 0x8008b4ec,
		"TNerveBPJumpReact::theNerve": 0x8008b550,
		"TNerveBPJumpReact::~TNerveBPJumpReact": 0x8008b5b4,
		"TNerveBPStompReact::execute": 0x8008b610,
		"TNerveBPStompReact::theNerve": 0x8008b74c,
		"TNerveBPStompReact::~TNerveBPStompReact": 0x8008b7b0,
		"TNerveBPSwing::execute": 0x8008b80c,
		"TNerveBPSwing::theNerve": 0x8008b8bc,
		"TNerveBPSwing::~TNerveBPSwing": 0x8008b920,
		"TNerveBPGetUp::execute": 0x8008b97c,
		"TNerveBPGetUp::theNerve": 0x8008ba34,
		"TNerveBPGetUp::~TNerveBPGetUp": 0x8008ba98,
		"TNerveBPTumbleOut::execute": 0x8008baf4,
		"TNerveBPTumbleOut::theNerve": 0x8008bd68,
		"TNerveBPTumbleOut::~TNerveBPTumbleOut": 0x8008bdcc,
		"TNerveBPTumble::execute": 0x8008be28,
		"TNerveBPTumble::theNerve": 0x8008bfa0,
		"TNerveBPTumble::~TNerveBPTumble": 0x8008c004,
		"TNerveBPTumbleIn::execute": 0x8008c060,
		"TNerveBPTumbleIn::theNerve": 0x8008c1b4,
		"TNerveBPTumbleIn::~TNerveBPTumbleIn": 0x8008c218,
		"TNerveBPSwallow::execute": 0x8008c274,
		"TNerveBPSwallow::theNerve": 0x8008c464,
		"TNerveBPSwallow::~TNerveBPSwallow": 0x8008c4c8,
		"TNerveBPPivot::execute": 0x8008c524,
		"TNerveBPPivot::theNerve": 0x8008c67c,
		"TNerveBPPivot::~TNerveBPPivot": 0x8008c6e0,
		"TNerveBPTornado::execute": 0x8008c73c,
		"TNerveBPTornado::theNerve": 0x8008c8b8,
		"TNerveBPVomit::execute": 0x8008c91c,
		"TNerveBPVomit::theNerve": 0x8008cc8c,
		"TNerveBPCannon::execute": 0x8008ccf0,
		"TNerveBPCannon::theNerve": 0x8008ce14,
		"TNerveBPCannon::~TNerveBPCannon": 0x8008ce78,
		"TNerveBPWait::execute": 0x8008ced4,
		"TNerveBPWait::theNerve": 0x8008db2c,
		"TBossPakkunManager::load": 0x8008db90,
		"TBossPakkunManager::createModelData": 0x8008de54,
		"TBossPakkunManager::TBossPakkunManager": 0x8008deb0,
		"TBossPakkun::perform": 0x8008defc,
		"TBossPakkun::receiveMessage": 0x8008e6cc,
		"TBossPakkun::kill": 0x8008e91c,
		"TBossPakkun::setGroundCollision": 0x8008e99c,
		"TBossPakkun::getBasNameTable": 0x8008eb20,
		"TBossPakkun::changeBck": 0x8008eb2c,
		"TBossPakkun::launchPolDrop": 0x8008eea4,
		"TBossPakkun::gotHipDropDamage": 0x8008f0ac,
		"gotHipDropDamage": 0x8008f0ac,
		"TBossPakkun::showMessage": 0x8008f654,
		"TBossPakkun::rumblePad": 0x8008f6c4,
		"TBossPakkun::checkMarioRiding": 0x8008f824,
		"TBossPakkun::init": 0x8008f8cc,
		"TBossPakkun::TBossPakkun": 0x8009009c,
		"TBossPakkunMtxCalc::calcHeadDir": 0x800901c0,
		"calcHeadDir": 0x800901c0,
		"TBossPakkunMtxCalc::calcBellyScale": 0x80090584,
		"calcBellyScale": 0x80090584,
		"TBPNavel::perform": 0x800907f4,
		"TBPNavel::receiveMessage": 0x8009085c,
		"TBPHeadHit::perform": 0x8009096c,
		"TBPHeadHit::throwActor": 0x80090a30,
		"throwActor": 0x80090a30,
		"TBPHeadHit::receiveMessage": 0x80090c80,
		"TBPTornado::perform": 0x80091248,
		"TBPTornado::TBPTornado": 0x80091974,
		"TBPVomit::perform": 0x80091a68,
		"TBPPolDrop::perform": 0x80091b38,
		"TBPPolDrop::move": 0x80091dac,
		"TBPPolDrop::TBPPolDrop": 0x800920b8,
		"TBossPakkunParams::TBossPakkunParams": 0x800921f4,
		"TBossPakkunManager::~TBossPakkunManager": 0x8009264c,
		"TBossPakkunMtxCalc::~TBossPakkunMtxCalc": 0x8009271c,
		"TBPVomit::~TBPVomit": 0x80092954,
		"Enemy::__sinit_bosspakkun_cpp": 0x80092a4c,
		"__sinit_bosspakkun_cpp": 0x80092a4c,
		"TNerveTobiPukuSwimWander::~TNerveTobiPukuSwimWander": 0x80092d84,
		"TNerveTobiPukuSwimWander::execute": 0x80092de0,
		"TNerveTobiPukuReturnLaunch::execute": 0x80092e94,
		"TNerveTobiPukuPrepareFly::~TNerveTobiPukuPrepareFly": 0x800930e8,
		"TNerveTobiPukuReturnLaunch::~TNerveTobiPukuReturnLaunch": 0x80093144,
		"TNerveTobiPukuPrepareFly::execute": 0x800931a0,
		"TNerveTobiPukuBound::execute": 0x80093348,
		"TNerveTobiPukuLand::~TNerveTobiPukuLand": 0x80093510,
		"TNerveTobiPukuBound::~TNerveTobiPukuBound": 0x8009356c,
		"TNerveTobiPukuLand::execute": 0x800935c8,
		"TNerveTobiPukuPitiPiti::~TNerveTobiPukuPitiPiti": 0x80093b70,
		"TNerveTobiPukuDie::execute": 0x80093bcc,
		"TNerveTobiPukuDie::~TNerveTobiPukuDie": 0x80093dc8,
		"TNerveTobiPukuPitiPiti::execute": 0x80093e24,
		"TNerveTobiPukuFall::execute": 0x80093f3c,
		"TNerveTobiPukuFall::~TNerveTobiPukuFall": 0x80094120,
		"TNerveTobiPukuHitWater::execute": 0x8009417c,
		"TNerveTobiPukuHitWater::~TNerveTobiPukuHitWater": 0x800943cc,
		"TNerveTobiPukuAttack::execute": 0x80094428,
		"TNerveTobiPukuAttack::~TNerveTobiPukuAttack": 0x800945c0,
		"TNerveTobiPukuFly::execute": 0x8009461c,
		"TNerveTobiPukuFly::~TNerveTobiPukuFly": 0x800947b0,
		"TNerveTobiPukuGenerate::execute": 0x8009480c,
		"TNerveTobiPukuGenerate::~TNerveTobiPukuGenerate": 0x800949b8,
		"TMoePuku::getBasNameTable": 0x80094a14,
		"TMoePuku::generateEffectColumWater": 0x80094a20,
		"TMoePuku::setJumpStartAnm": 0x80094b8c,
		"TMoePuku::setFallEndLandAnm": 0x80094bdc,
		"TMoePuku::setDeadAnm": 0x80094c0c,
		"TMoePuku::setDownLandAnm": 0x80094c3c,
		"TMoePuku::setDownAirAnm": 0x80094c6c,
		"TMoePuku::setFallAnm": 0x80094c9c,
		"TMoePuku::setPichiAnm": 0x80094ccc,
		"TMoePuku::setAttackAnm": 0x80094cfc,
		"TMoePuku::setSwimAnm": 0x80094d2c,
		"TMoePuku::setJumpAnm": 0x80094d5c,
		"TMoePuku::isJumpStartBck": 0x80094d8c,
		"TMoePuku::isFallEndLandBck": 0x80094dbc,
		"TMoePuku::isAttackBck": 0x80094dec,
		"TMoePuku::isDeadBck": 0x80094e1c,
		"TMoePuku::isJumpBck": 0x80094e4c,
		"TMoePuku::isPichiEffect": 0x80094e7c,
		"TMoePuku::hitWater": 0x80094eac,
		"TMoePuku::calcRootMatrix": 0x80094f6c,
		"TPukuPuku::reset": 0x800951b4,
		"TPukuPuku::init": 0x800952f0,
		"TPukuPuku::load": 0x800953c4,
		"TPukuPuku::TPukuPuku": 0x8009540c,
		"TTobiPuku::getBasNameTable": 0x800954ec,
		"TTobiPuku::scalingChangeActor": 0x800954f8,
		"TTobiPuku::initAttacker": 0x8009558c,
		"TTobiPuku::changeOut": 0x80095670,
		"TTobiPuku::genEventCoin": 0x80095710,
		"TTobiPuku::forceKill": 0x8009573c,
		"TTobiPuku::kill": 0x80095894,
		"TTobiPuku::hitWater": 0x80095a10,
		"TTobiPuku::getGravityY": 0x80095b64,
		"TTobiPuku::attackToMario": 0x80095b84,
		"TTobiPuku::generateEffectColumWater": 0x80095d00,
		"TTobiPuku::isReachedToGoalXZ": 0x80095e1c,
		"TTobiPuku::swimEffect": 0x80095ee4,
		"TTobiPuku::walkBehavior": 0x80095f94,
		"TTobiPuku::behaveToWater": 0x80096064,
		"TTobiPuku::setJumpStartAnm": 0x800961b0,
		"TTobiPuku::setFallEndLandAnm": 0x80096200,
		"TTobiPuku::setDeadAnm": 0x80096230,
		"TTobiPuku::setDownLandAnm": 0x80096260,
		"TTobiPuku::setDownAirAnm": 0x80096290,
		"TTobiPuku::setFallAnm": 0x800962c0,
		"TTobiPuku::setPichiAnm": 0x800962f0,
		"TTobiPuku::setAttackAnm": 0x80096320,
		"TTobiPuku::setSwimAnm": 0x80096350,
		"TTobiPuku::setJumpAnm": 0x80096380,
		"TTobiPuku::isJumpStartBck": 0x800963b0,
		"TTobiPuku::isFallEndLandBck": 0x800963e0,
		"TTobiPuku::isAttackBck": 0x80096410,
		"TTobiPuku::isDeadBck": 0x80096440,
		"TTobiPuku::isJumpBck": 0x80096470,
		"TTobiPuku::isPichiEffect": 0x800964a0,
		"TTobiPuku::calcRootMatrix": 0x800964d0,
		"TTobiPuku::hitWall": 0x80096624,
		"hitWall": 0x80096624,
		"TTobiPuku::moveObject": 0x80096780,
		"TTobiPuku::reset": 0x800967f0,
		"TTobiPuku::init": 0x800968c8,
		"TTobiPuku::TTobiPuku": 0x80096934,
		"TMoePukuLaunchPad::launch": 0x800969e8,
		"TTobiPukuLaunchPad::forceLaunch": 0x80096a48,
		"forceLaunch": 0x80096a48,
		"TTobiPukuLaunchPad::launch": 0x80096c2c,
		"TTobiPukuLaunchPad::reset": 0x80096c8c,
		"TTobiPukuLaunchPad::load": 0x80096cc4,
		"TTobiPukuLaunchPad::init": 0x80096d44,
		"TTobiPukuLaunchPad::perform": 0x80096d94,
		"TTobiPukuLaunchPad::TTobiPukuLaunchPad": 0x80096e50,
		"TMoePukuManager::createEnemyInstance": 0x80096ea8,
		"TTobiPukuManager::createEnemyInstance": 0x80096f04,
		"TTobiPukuManager::load": 0x80096f4c,
		"TTobiPukuManager::TTobiPukuManager": 0x800970bc,
		"TMoePukuLaunchPadManager::createEnemyInstance": 0x800970f8,
		"TTobiPukuLaunchPadManager::perform": 0x80097200,
		"TTobiPukuLaunchPadManager::createEnemyInstance": 0x80097298,
		"TTobiPukuLaunchPadManager::load": 0x80097308,
		"TTobiPukuLaunchPadManager::TTobiPukuLaunchPadManager": 0x80097478,
		"Enemy::TobiPukuRollCallback": 0x800974bc,
		"TobiPukuRollCallback": 0x800974bc,
		"TMoePuku::swimEffect": 0x800976e0,
		"TTobiPuku::isInhibitedForceMove": 0x800976e4,
		"TMoePukuManager::~TMoePukuManager": 0x800978d4,
		"TMoePukuLaunchPadManager::~TMoePukuLaunchPadManager": 0x800979cc,
		"Enemy::__sinit_tobiPuku_cpp": 0x80097ac4,
		"__sinit_tobiPuku_cpp": 0x80097ac4,
		"TNerveTinKoopaBreak::~TNerveTinKoopaBreak": 0x80097de8,
		"TNerveTinKoopaBreak::execute": 0x80097e44,
		"TNerveTinKoopaDamage::execute": 0x8009823c,
		"TNerveTinKoopaDamage::~TNerveTinKoopaDamage": 0x800983b8,
		"TNerveTinKoopaWait::execute": 0x80098414,
		"TNerveTinKoopaWait::~TNerveTinKoopaWait": 0x800984f4,
		"TTinKoopaManager::createEnemyInstance": 0x80098550,
		"TTinKoopaManager::loadAfter": 0x80098558,
		"TTinKoopaManager::load": 0x8009865c,
		"TTinKoopaManager::createModelData": 0x800986b4,
		"TTinKoopaManager::TTinKoopaManager": 0x800986e8,
		"TTinKoopa::emitTinKoopaEffects": 0x80098724,
		"emitTinKoopaEffects": 0x80098724,
		"TTinKoopa::checkTinKoopaFirstFlameMessage": 0x80099328,
		"checkTinKoopaFirstFlameMessage": 0x80099328,
		"TTinKoopa::checkTinKoopaKillerApproachingMessage": 0x80099434,
		"checkTinKoopaKillerApproachingMessage": 0x80099434,
		"TTinKoopa::launchKiller": 0x800995c8,
		"TTinKoopa::hitParts": 0x800996cc,
		"hitParts": 0x800996cc,
		"TTinKoopa::receiveMessage": 0x80099920,
		"TTinKoopa::getBasNameTable": 0x8009995c,
		"TTinKoopa::perform": 0x80099968,
		"TTinKoopa::resetTinKoopa": 0x80099bf4,
		"resetTinKoopa": 0x80099bf4,
		"TTinKoopa::reset": 0x80099d08,
		"TTinKoopa::calcCoasterDistance": 0x80099f84,
		"calcCoasterDistance": 0x80099f84,
		"TTinKoopa::TTinKoopa": 0x8009a030,
		"TTinKoopaPartsBase::perform": 0x8009a0c0,
		"TTinKoopaPartsBase::receiveMessage": 0x8009a1f0,
		"TTinKoopaPartsBase::emitPartsTrackEffects": 0x8009a470,
		"emitPartsTrackEffects": 0x8009a470,
		"TTinKoopaPartsBase::startBreaking": 0x8009a54c,
		"startBreaking": 0x8009a54c,
		"TTinKoopaPartsBase::reset": 0x8009a758,
		"TTinKoopaPartsBase::initTinKoopaPartsBase": 0x8009a7a4,
		"initTinKoopaPartsBase": 0x8009a7a4,
		"TTinKoopaLaunchOrder::checkOrder": 0x8009a984,
		"checkOrder": 0x8009a984,
		"TTinKoopaFlame::emitFlameEffects": 0x8009aaf0,
		"emitFlameEffects": 0x8009aaf0,
		"TTinKoopaFlame::perform": 0x8009ad24,
		"TTinKoopaFlame::receiveMessage": 0x8009ae6c,
		"TTinKoopa::makeLaunchSchedule": 0x8009af54,
		"makeLaunchSchedule": 0x8009af54,
		"TTinKoopa::init": 0x8009b130,
		"TTinKoopaParams::TTinKoopaParams": 0x8009b714,
		"TTinKoopaManager::~TTinKoopaManager": 0x8009ba18,
		"TTinKoopaManager::hasMapCollision": 0x8009ba7c,
		"TTinKoopaMtxCalc::~TTinKoopaMtxCalc": 0x8009ba84,
		"TTinKoopa::hasMapCollision": 0x8009bc8c,
		"Enemy::__sinit_tinkoopa_cpp": 0x8009bc94,
		"__sinit_tinkoopa_cpp": 0x8009bc94,
		"TCommonLauncherManager::~TCommonLauncherManager": 0x8009bfbc,
		"TCommonLauncherManager::load": 0x8009c030,
		"TCommonLauncherManager::createModelData": 0x8009c050,
		"TCommonLauncherManager::TCommonLauncherManager": 0x8009c084,
		"TCommonLauncher::perform": 0x8009c130,
		"TCommonLauncher::getBasNameTable": 0x8009c29c,
		"TCommonLauncher::stateDie": 0x8009c2a8,
		"TCommonLauncher::stateLaunch": 0x8009c49c,
		"TCommonLauncher::stateNormal": 0x8009c63c,
		"TCommonLauncher::stateHitByWater": 0x8009c6e4,
		"TCommonLauncher::stateInitial": 0x8009c798,
		"TCommonLauncher::load": 0x8009c7c8,
		"TCommonLauncher::init": 0x8009c81c,
		"TCommonLauncher::TCommonLauncher": 0x8009cb08,
		"TLauncherManager::load": 0x8009cbf4,
		"TLauncherManager::TLauncherManager": 0x8009ccb4,
		"TLauncher::stateDie": 0x8009ccf0,
		"TLauncher::stateLaunch": 0x8009cd80,
		"TLauncher::stateNormal": 0x8009cdfc,
		"TLauncher::stateHitByWater": 0x8009ce44,
		"TLauncher::stateInitial": 0x8009cec4,
		"TLauncher::changeState": 0x8009cf00,
		"TLauncher::getProperEnemy": 0x8009cf08,
		"getProperEnemy": 0x8009cf08,
		"TLauncher::resetLaunchTimer": 0x8009cf6c,
		"resetLaunchTimer": 0x8009cf6c,
		"TLauncher::control": 0x8009cfc0,
		"TLauncher::bind": 0x8009d0b8,
		"TLauncher::receiveMessage": 0x8009d0bc,
		"TLauncher::init": 0x8009d1a4,
		"TLauncher::TLauncher": 0x8009d2f0,
		"Enemy::__sinit_launcher_cpp": 0x8009d3d4,
		"__sinit_launcher_cpp": 0x8009d3d4,
		"TNerveBWFall::~TNerveBWFall": 0x8009d6e0,
		"TNerveBWFall::execute": 0x8009d73c,
		"TNerveBWGraphWander::~TNerveBWGraphWander": 0x8009d93c,
		"TNerveBWFall::theNerve": 0x8009d998,
		"TNerveBWShake::execute": 0x8009d9fc,
		"TNerveBWShake::theNerve": 0x8009db94,
		"TNerveBWShake::~TNerveBWShake": 0x8009dbf8,
		"TNerveBWJumpAway::execute": 0x8009dc54,
		"TNerveBWJumpAway::theNerve": 0x8009dee0,
		"TNerveBWJumpAway::~TNerveBWJumpAway": 0x8009df44,
		"TNerveBWDie::execute": 0x8009dfa0,
		"TNerveBWDie::~TNerveBWDie": 0x8009e400,
		"TNerveBWDie::theNerve": 0x8009e45c,
		"TNerveBWJumpToBath::execute": 0x8009e4c0,
		"TNerveBWJumpToBath::theNerve": 0x8009e7f4,
		"TNerveBWJumpToBath::~TNerveBWJumpToBath": 0x8009e858,
		"TNerveBWWakeup::execute": 0x8009e8b4,
		"TNerveBWWakeup::theNerve": 0x8009ea48,
		"TNerveBWWakeup::~TNerveBWWakeup": 0x8009eaac,
		"TNerveBWStun::execute": 0x8009eb08,
		"TNerveBWStun::theNerve": 0x8009ee1c,
		"TNerveBWStun::~TNerveBWStun": 0x8009ee80,
		"TNerveBWJump::execute": 0x8009eedc,
		"TNerveBWJump::theNerve": 0x8009f05c,
		"TNerveBWJump::~TNerveBWJump": 0x8009f0c0,
		"TNerveBWBark::execute": 0x8009f11c,
		"TNerveBWBark::theNerve": 0x8009f398,
		"TNerveBWBark::~TNerveBWBark": 0x8009f3fc,
		"TNerveBWRoll::execute": 0x8009f458,
		"TNerveBWRoll::~TNerveBWRoll": 0x8009f598,
		"TNerveBWRoll::theNerve": 0x8009f604,
		"TNerveBWGraphWander::execute": 0x8009f668,
		"TNerveBWGraphWander::theNerve": 0x800a0054,
		"TBossWanwanManager::load": 0x800a00b8,
		"TBossWanwanManager::createModelData": 0x800a02b0,
		"TBossWanwanManager::createEnemyInstance": 0x800a02e4,
		"TBossWanwanManager::TBossWanwanManager": 0x800a032c,
		"TBossWanwan::perform": 0x800a0368,
		"TBossWanwan::emitEffects": 0x800a0bcc,
		"TBossWanwan::control": 0x800a1050,
		"TBossWanwan::slideToCurPathNode": 0x800a136c,
		"slideToCurPathNode": 0x800a136c,
		"TBossWanwan::calcRootMatrix": 0x800a1624,
		"TBossWanwan::receiveMessage": 0x800a1708,
		"TBossWanwan::shakeCamera": 0x800a1958,
		"shakeCamera": 0x800a1958,
		"TBossWanwan::init": 0x800a1ad4,
		"TBossWanwan::TBossWanwan": 0x800a2264,
		"TBWBinder::bind": 0x800a256c,
		"TBWHit::perform": 0x800a30bc,
		"TBWHit::receiveMessage": 0x800a3178,
		"TBWPicket::perform": 0x800a31a8,
		"TBWPicket::getTakingMtx": 0x800a36d8,
		"TBWPicket::moveRequest": 0x800a36e0,
		"TBWPicket::receiveMessage": 0x800a3898,
		"TBWLeash::perform": 0x800a39cc,
		"TBWLeash::TBWLeash": 0x800a3f00,
		"TBWLeashNode::perform": 0x800a423c,
		"TBWLeashNode::calcMatrix": 0x800a4468,
		"calcMatrix": 0x800a4468,
		"TBWLeashNode::calcTemperature": 0x800a472c,
		"calcTemperature": 0x800a472c,
		"TBWParams::TBWParams": 0x800a47d0,
		"TBossWanwanManager::~TBossWanwanManager": 0x800a4b48,
		"TBossWanwan::kill": 0x800a4c18,
		"TBossWanwanMtxCalc::~TBossWanwanMtxCalc": 0x800a4c1c,
		"TBWBinder::~TBWBinder": 0x800a4cc8,
		"TBWLeash::~TBWLeash": 0x800a4e4c,
		"Enemy::__sinit_bosswanwan_cpp": 0x800a4f44,
		"__sinit_bosswanwan_cpp": 0x800a4f44,
		"TNerveChuuHanaWait::~TNerveChuuHanaWait": 0x800a52bc,
		"TNerveChuuHanaWait::execute": 0x800a5318,
		"TNerveChuuHanaJumpPrepare::execute": 0x800a5384,
		"TNerveChuuHanaJumpPrepare::~TNerveChuuHanaJumpPrepare": 0x800a5528,
		"TNerveChuuHanaAttack::execute": 0x800a5584,
		"TNerveChuuHanaFall2::~TNerveChuuHanaFall2": 0x800a5984,
		"TNerveChuuHanaWalkOnPanel::~TNerveChuuHanaWalkOnPanel": 0x800a59e0,
		"TNerveChuuHanaAttack::~TNerveChuuHanaAttack": 0x800a5a3c,
		"TNerveChuuHanaObject::execute": 0x800a5a98,
		"TNerveChuuHanaObject::~TNerveChuuHanaObject": 0x800a5aa0,
		"TNerveChuuHanaFall2::execute": 0x800a5afc,
		"TNerveChuuHanaFall::execute": 0x800a5c28,
		"TNerveChuuHanaFall::~TNerveChuuHanaFall": 0x800a5c30,
		"TNerveChuuHanaRoll::execute": 0x800a5c8c,
		"TNerveChuuHanaKeepBalance::~TNerveChuuHanaKeepBalance": 0x800a5eac,
		"TNerveChuuHanaRoll::~TNerveChuuHanaRoll": 0x800a5f08,
		"TNerveChuuHanaStick::execute": 0x800a5f64,
		"TNerveChuuHanaStick::~TNerveChuuHanaStick": 0x800a620c,
		"TNerveChuuHanaKeepBalance::execute": 0x800a6268,
		"TNerveChuuHanaForceJumped::execute": 0x800a6654,
		"TNerveChuuHanaForceJumped::~TNerveChuuHanaForceJumped": 0x800a6904,
		"TNerveChuuHanaWalkOnPanel::execute": 0x800a6960,
		"TChuuHana::getBasNameTable": 0x800a6be8,
		"TChuuHana::checkStretchType": 0x800a6bf4,
		"checkStretchType": 0x800a6bf4,
		"TChuuHana::setGoal": 0x800a70c4,
		"setGoal": 0x800a70c4,
		"TChuuHana::willFall": 0x800a722c,
		"willFall": 0x800a722c,
		"TChuuHana::getGravityY": 0x800a742c,
		"TChuuHana::forceKill": 0x800a7690,
		"TChuuHana::kill": 0x800a77b4,
		"TChuuHana::setWalkAnm": 0x800a7828,
		"TChuuHana::receiveMessage": 0x800a78cc,
		"TChuuHana::bind": 0x800a7a5c,
		"TChuuHana::calcRootMatrix": 0x800a7d44,
		"TChuuHana::isCollidMove": 0x800a7fc8,
		"TChuuHana::moveObject": 0x800a83c4,
		"TChuuHana::attackToMario": 0x800a8750,
		"TChuuHana::behaveToWater": 0x800a89b4,
		"TChuuHana::setBckAnm": 0x800a8fcc,
		"TChuuHana::reset": 0x800a9058,
		"TChuuHana::perform": 0x800a91dc,
		"TChuuHana::setMActorAndKeeper": 0x800a9298,
		"TChuuHana::init": 0x800a9304,
		"TChuuHana::TChuuHana": 0x800a9454,
		"TChuuHanaAseParCallback::draw": 0x800a9508,
		"TChuuHanaAseParCallback::execute": 0x800a950c,
		"Enemy::ChuuHanaBodyCallback": 0x800a9580,
		"ChuuHanaBodyCallback": 0x800a9580,
		"TChuuHanaManager::initSetEnemies": 0x800a9824,
		"TChuuHanaManager::createEnemyInstance": 0x800a99ac,
		"TChuuHanaManager::perform": 0x800a99f4,
		"TChuuHanaManager::load": 0x800a9b44,
		"TChuuHanaManager::TChuuHanaManager": 0x800a9b9c,
		"TChuuHanaSaveLoadParams::TChuuHanaSaveLoadParams": 0x800a9bfc,
		"TChuuHana::isFindMario": 0x800aa0e0,
		"TChuuHanaManager::~TChuuHanaManager": 0x800aa184,
		"Enemy::__sinit_chuuhana_cpp": 0x800aa1f8,
		"__sinit_chuuhana_cpp": 0x800aa1f8,
		"TNerveGorogoroDie::~TNerveGorogoroDie": 0x800aa4fc,
		"TNerveGorogoroDie::execute": 0x800aa558,
		"TNerveGorogoroRollOnGraph::execute": 0x800aa78c,
		"TNerveGorogoroRollOnGraph::~TNerveGorogoroRollOnGraph": 0x800aa84c,
		"TGorogoro::generateByGateKeeper": 0x800aa8a8,
		"generateByGateKeeper": 0x800aa8a8,
		"TGorogoro::setMActorAndKeeper": 0x800aae2c,
		"TGorogoro::isRolling": 0x800aae98,
		"TGorogoro::getBasNameTable": 0x800aaf44,
		"TGorogoro::bound": 0x800aaf50,
		"TGorogoro::setMeltAnm": 0x800aafb8,
		"TGorogoro::setDeadAnm": 0x800ab0b0,
		"TGorogoro::flagJump": 0x800ab17c,
		"TGorogoro::walkBehavior": 0x800ab254,
		"TGorogoro::boundSE": 0x800ab548,
		"TGorogoro::rollSE": 0x800ab5c0,
		"TGorogoro::behaveToWater": 0x800ab638,
		"TGorogoro::forceKill": 0x800ab88c,
		"TGorogoro::kill": 0x800aba78,
		"TGorogoro::reset": 0x800abbcc,
		"TGorogoro::calcRootMatrix": 0x800abc24,
		"TGorogoro::perform": 0x800abe18,
		"TGorogoro::init": 0x800abea4,
		"TGorogoroManager::perform": 0x800ac104,
		"TGorogoroManager::createModelData": 0x800ac628,
		"TGorogoroManager::initSetEnemies": 0x800ac65c,
		"TGorogoroManager::createEnemyInstance": 0x800ac7c4,
		"TGorogoroManager::loadAfter": 0x800ac84c,
		"TGorogoroManager::load": 0x800ac8e8,
		"TGorogoroManager::TGorogoroManager": 0x800aca58,
		"TGorogoroPolluteModel::setAnm": 0x800acab0,
		"TGorogoroPolluteModelManager::init": 0x800acb00,
		"TNerveIgaigaShootFromCannon::execute": 0x800acbd0,
		"TNerveIgaigaRollOnGraph::~TNerveIgaigaRollOnGraph": 0x800acd48,
		"TNerveIgaigaShootFromCannon::~TNerveIgaigaShootFromCannon": 0x800acda4,
		"TNerveIgaigaWaterHit::execute": 0x800ace00,
		"TNerveIgaigaWaterHit::~TNerveIgaigaWaterHit": 0x800ad070,
		"TNerveIgaigaRollOnGraph::execute": 0x800ad0cc,
		"TIgaiga::shoot": 0x800ad1ec,
		"TIgaiga::bound": 0x800ad2b4,
		"TIgaiga::isHitValid": 0x800ad358,
		"TIgaiga::getBasNameTable": 0x800ad378,
		"TIgaiga::setMeltAnm": 0x800ad384,
		"TIgaiga::setDeadAnm": 0x800ad5e8,
		"TIgaiga::setWalkAnm": 0x800ad750,
		"TIgaiga::isReachedToGoalXZ": 0x800ad780,
		"TIgaiga::walkBehavior": 0x800ad83c,
		"TIgaiga::boundSE": 0x800ad9d8,
		"TIgaiga::rollSE": 0x800ada50,
		"TIgaiga::moveObject": 0x800ada98,
		"TIgaiga::kill": 0x800add24,
		"TIgaiga::reset": 0x800add4c,
		"TIgaiga::behaveToWater": 0x800ade8c,
		"TIgaiga::isRolling": 0x800adfd8,
		"TIgaiga::calcRootMatrix": 0x800ae118,
		"TIgaiga::perform": 0x800ae13c,
		"TIgaiga::setMActorAndKeeper": 0x800ae15c,
		"TIgaiga::init": 0x800ae1c8,
		"TIgaiga::TIgaiga": 0x800ae2d0,
		"Enemy::RollEnemyBodyCallback": 0x800ae374,
		"RollEnemyBodyCallback": 0x800ae374,
		"TRollEnemy::isRolling": 0x800ae4a4,
		"TIgaigaManager::perform": 0x800ae4ac,
		"TIgaigaManager::initSetEnemies": 0x800ae50c,
		"TIgaigaManager::createEnemyInstance": 0x800ae5c8,
		"TIgaigaManager::createModelData": 0x800ae610,
		"TIgaigaManager::load": 0x800ae644,
		"TIgaigaManager::TIgaigaManager": 0x800ae7c8,
		"TIgaigaPolluteModel::setAnm": 0x800ae814,
		"TIgaigaPolluteModelManager::init": 0x800ae864,
		"TRollEnemy::setBehavior": 0x800ae934,
		"TRollEnemy::isReachedToGoalXZ": 0x800aeb5c,
		"TRollEnemy::isCollidMove": 0x800aec10,
		"TRollEnemy::flagJump": 0x800aec90,
		"TRollEnemy::attackToMario": 0x800aed68,
		"TRollEnemy::behaveToWater": 0x800aed8c,
		"TRollEnemy::walkBehavior": 0x800aef24,
		"TRollEnemy::rollSE": 0x800af130,
		"TRollEnemy::boundSE": 0x800af134,
		"TRollEnemy::bound": 0x800af138,
		"TRollEnemy::reset": 0x800af13c,
		"TRollEnemy::TRollEnemy": 0x800af334,
		"TRollEnemy::setAfterDeadEffect": 0x800af3a4,
		"TGorogoroManager::~TGorogoroManager": 0x800af444,
		"TGorogoroPolluteModel::~TGorogoroPolluteModel": 0x800af4b8,
		"TGorogoroPolluteModelManager::~TGorogoroPolluteModelManager": 0x800af53c,
		"TIgaigaManager::~TIgaigaManager": 0x800af65c,
		"TIgaigaPolluteModel::~TIgaigaPolluteModel": 0x800af6d0,
		"TIgaigaPolluteModelManager::~TIgaigaPolluteModelManager": 0x800af754,
		"Enemy::__sinit_igaiga_cpp": 0x800af7d8,
		"__sinit_igaiga_cpp": 0x800af7d8,
		"TNervePoihanaTrapped::~TNervePoihanaTrapped": 0x800afaec,
		"TNervePoihanaTrapped::execute": 0x800afb48,
		"TNervePoihanaFreeze::~TNervePoihanaFreeze": 0x800b0018,
		"TNervePoihanaThrow::execute": 0x800b0074,
		"TNervePoihanaThrow::~TNervePoihanaThrow": 0x800b0240,
		"TNervePoihanaFreeze::execute": 0x800b029c,
		"TNervePoihanaSleep::execute": 0x800b049c,
		"TNervePoihanaSleep::~TNervePoihanaSleep": 0x800b07d0,
		"TSleepPoiHana::load": 0x800b082c,
		"TSleepPoiHana::TSleepPoiHana": 0x800b0874,
		"TPoiHanaRed::attackToMario": 0x800b0998,
		"TPoiHanaRed::init": 0x800b0bc0,
		"TPoiHana::getBasNameTable": 0x800b0c0c,
		"TPoiHana::changeByJuice": 0x800b0c18,
		"TPoiHana::genEventCoin": 0x800b0c68,
		"TPoiHana::isMoving": 0x800b0d98,
		"isMoving": 0x800b0d98,
		"TPoiHana::getGravityY": 0x800b0e7c,
		"TPoiHana::generateItem": 0x800b0f18,
		"TPoiHana::calcRootMatrix": 0x800b0f30,
		"TPoiHana::doKeepDistance": 0x800b12c0,
		"TPoiHana::isInhibitedForceMove": 0x800b12f4,
		"TPoiHana::walkBehavior": 0x800b1310,
		"TPoiHana::isCollidMove": 0x800b1488,
		"TPoiHana::isHitValid": 0x800b1684,
		"TPoiHana::setDeadAnm": 0x800b1750,
		"TPoiHana::setFreezeAnm": 0x800b1998,
		"TPoiHana::setRunAnm": 0x800b19c8,
		"TPoiHana::setWaitAnm": 0x800b19f8,
		"TPoiHana::setWalkAnm": 0x800b1a28,
		"TPoiHana::attackToMario": 0x800b1a58,
		"TPoiHana::behaveToWater": 0x800b1c64,
		"TPoiHana::bind": 0x800b1d74,
		"TPoiHana::perform": 0x800b1e94,
		"TPoiHana::moveObject": 0x800b1ee8,
		"TPoiHana::reset": 0x800b21c4,
		"TPoiHana::setMActorAndKeeper": 0x800b2214,
		"TPoiHana::init": 0x800b2280,
		"TPoiHana::load": 0x800b2504,
		"TPoiHana::TPoiHana": 0x800b2544,
		"TPoiHanaCollision::receiveMessage": 0x800b25b8,
		"TPoiHanaManager::initSetEnemies": 0x800b25e8,
		"TPoiHanaManager::perform": 0x800b2688,
		"TPoiHanaManager::createEnemyInstance": 0x800b26a8,
		"TPoiHanaManager::load": 0x800b270c,
		"TPoiHanaManager::TPoiHanaManager": 0x800b2920,
		"TPoiHanaManager::~TPoiHanaManager": 0x800b2b18,
		"Enemy::__sinit_poihana_cpp": 0x800b2b8c,
		"__sinit_poihana_cpp": 0x800b2b8c,
		"TNerveTamaNokoWait::~TNerveTamaNokoWait": 0x800b2ea8,
		"TNerveTamaNokoWait::execute": 0x800b2f04,
		"TNerveTamaNokoHitWater::execute": 0x800b308c,
		"TNerveTamaNokoSleep::~TNerveTamaNokoSleep": 0x800b33c4,
		"TNerveTamaNokoHitWater::~TNerveTamaNokoHitWater": 0x800b3420,
		"TNerveTamaNokoSink::execute": 0x800b347c,
		"TNerveTamaNokoSink::~TNerveTamaNokoSink": 0x800b3694,
		"TNerveTamaNokoThrown::execute": 0x800b36f0,
		"TNerveTamaNokoThrown::~TNerveTamaNokoThrown": 0x800b37fc,
		"TNerveTamaNokoPickUp::execute": 0x800b3858,
		"TNerveTamaNokoPickUp::~TNerveTamaNokoPickUp": 0x800b390c,
		"TNerveTamaNokoDown::execute": 0x800b3968,
		"TNerveTamaNokoDown::~TNerveTamaNokoDown": 0x800b3bec,
		"TNerveTamaNokoAttack::execute": 0x800b3c48,
		"TNerveTamaNokoAttack::~TNerveTamaNokoAttack": 0x800b43f8,
		"TNerveTamaNokoSleep::execute": 0x800b4454,
		"TTamaNoko::isCollidMove": 0x800b44fc,
		"TTamaNoko::isReachedToGoal": 0x800b45c8,
		"TTamaNoko::setDeadAnm": 0x800b4690,
		"TTamaNoko::setWalkAnm": 0x800b46c0,
		"TTamaNoko::getGravityY": 0x800b46f0,
		"TTamaNoko::getBasNameTable": 0x800b47e4,
		"TTamaNoko::setAfterDeadEffect": 0x800b47f0,
		"TTamaNoko::landEffect": 0x800b48f0,
		"landEffect": 0x800b48f0,
		"TTamaNoko::requestShadow": 0x800b4c18,
		"TTamaNoko::calcRootMatrix": 0x800b4df4,
		"TTamaNoko::doKeepDistance": 0x800b521c,
		"TTamaNoko::attackToMario": 0x800b52a8,
		"TTamaNoko::isHitValid": 0x800b5368,
		"TTamaNoko::receiveMessage": 0x800b53fc,
		"TTamaNoko::changeByJuice": 0x800b5554,
		"TTamaNoko::behaveToRelease": 0x800b555c,
		"TTamaNoko::behaveToTaken": 0x800b5680,
		"TTamaNoko::walkBehavior": 0x800b5798,
		"TTamaNoko::behaveToWater": 0x800b5cc4,
		"TTamaNoko::behaveToFindMario": 0x800b5ea4,
		"TTamaNoko::moveObject": 0x800b5f48,
		"TTamaNoko::perform": 0x800b5fdc,
		"TTamaNoko::reset": 0x800b6048,
		"TTamaNoko::setMActorAndKeeper": 0x800b60a0,
		"TTamaNoko::init": 0x800b610c,
		"TTamaNoko::load": 0x800b6204,
		"TTamaNoko::TTamaNoko": 0x800b6244,
		"TTamaNokoManager::createModelData": 0x800b62a4,
		"TTamaNokoManager::createEnemyInstance": 0x800b62d8,
		"TTamaNokoManager::initSetEnemies": 0x800b6320,
		"TTamaNokoManager::loadAfter": 0x800b644c,
		"TTamaNokoManager::load": 0x800b64a8,
		"TTamaNokoManager::TTamaNokoManager": 0x800b66bc,
		"TTamaNokoFlower::perform": 0x800b66f8,
		"TTamaNoko::forceKill": 0x800b6aa0,
		"TTamaNokoManager::~TTamaNokoManager": 0x800b6b40,
		"TTamaNokoFlower::~TTamaNokoFlower": 0x800b6bb4,
		"Enemy::__sinit_tamaNoko_cpp": 0x800b6c38,
		"__sinit_tamaNoko_cpp": 0x800b6c38,
		"TNerveBossTelesaFallDemo::~TNerveBossTelesaFallDemo": 0x800b6f3c,
		"TNerveBossTelesaFallDemo::execute": 0x800b6f98,
		"TNerveBossTelesaHideWait::~TNerveBossTelesaHideWait": 0x800b7184,
		"TNerveBossTelesaFreeze::execute": 0x800b71e0,
		"TNerveBossTelesaFreeze::~TNerveBossTelesaFreeze": 0x800b7390,
		"TNerveBossTelesaPrepareSlot::execute": 0x800b73ec,
		"TNerveBossTelesaHide::~TNerveBossTelesaHide": 0x800b7a54,
		"TNerveBossTelesaPrepareSlot::~TNerveBossTelesaPrepareSlot": 0x800b7ab0,
		"TNerveBossTelesaSpitSlotItem::execute": 0x800b7b0c,
		"TNerveBossTelesaSpitSlotItem::~TNerveBossTelesaSpitSlotItem": 0x800b7d5c,
		"TNerveBossTelesaSlotStart::execute": 0x800b7db8,
		"TNerveBossTelesaSlotStart::~TNerveBossTelesaSlotStart": 0x800b806c,
		"TNerveBossTelesaAppear::execute": 0x800b80c8,
		"TNerveBossTelesaAppear::~TNerveBossTelesaAppear": 0x800b8494,
		"TNerveBossTelesaHideWait::execute": 0x800b84f0,
		"TNerveBossTelesaHide::execute": 0x800b86f0,
		"TNerveBossTelesaSpit::execute": 0x800b88c8,
		"TNerveBossTelesaSpit::~TNerveBossTelesaSpit": 0x800b89f8,
		"TNerveBossTelesaDie::execute": 0x800b8a54,
		"TNerveBossTelesaDie::~TNerveBossTelesaDie": 0x800b931c,
		"TBossTelesa::forceHide": 0x800b9378,
		"forceHide": 0x800b9378,
		"TBossTelesa::forceAllItemKill": 0x800b9514,
		"forceAllItemKill": 0x800b9514,
		"TBossTelesa::generateSlotItem": 0x800b9608,
		"generateSlotItem": 0x800b9608,
		"TBossTelesa::rouletteStart": 0x800ba15c,
		"rouletteStart": 0x800ba15c,
		"TBossTelesa::genAttacker": 0x800ba418,
		"genAttacker": 0x800ba418,
		"TBossTelesa::getBasNameTable": 0x800ba78c,
		"TBossTelesa::flashItem": 0x800ba798,
		"flashItem": 0x800ba798,
		"TBossTelesa::slotFall": 0x800baa1c,
		"slotFall": 0x800baa1c,
		"TBossTelesa::rouletteFall": 0x800bab64,
		"rouletteFall": 0x800bab64,
		"TBossTelesa::damageRecover": 0x800baccc,
		"damageRecover": 0x800baccc,
		"TBossTelesa::setSpicy": 0x800baf4c,
		"setSpicy": 0x800baf4c,
		"TBossTelesa::checkHitObject": 0x800bb0e4,
		"checkHitObject": 0x800bb0e4,
		"TBossTelesa::receiveMessage": 0x800bb3ac,
		"TBossTelesa::perform": 0x800bb3b4,
		"TBossTelesa::calcRootMatrix": 0x800bb508,
		"TBossTelesa::getTakingMtx": 0x800bba7c,
		"TBossTelesa::kill": 0x800bbae4,
		"TBossTelesa::moveObject": 0x800bbbfc,
		"TBossTelesa::reset": 0x800bc4e0,
		"TBossTelesa::loadAfter": 0x800bc608,
		"TBossTelesa::init": 0x800bd314,
		"TBossTelesa::TBossTelesa": 0x800bdaa0,
		"TTelesaSlot::getResultFromAng": 0x800bdb5c,
		"TTelesaSlot::getForcastResult": 0x800bdc04,
		"TTelesaSlot::getSlotResult": 0x800bdd34,
		"getSlotResult": 0x800bdd34,
		"TTelesaSlot::isRollDrum": 0x800bddc0,
		"isRollDrum": 0x800bddc0,
		"TTelesaSlot::forceStopSlot": 0x800bde0c,
		"forceStopSlot": 0x800bde0c,
		"TTelesaSlot::touchWater": 0x800bdf88,
		"TTelesaSlot::moveStart": 0x800bdf90,
		"moveStart": 0x800bdf90,
		"TTelesaSlot::moveObject": 0x800be034,
		"TTelesaSlot::calcRootMatrix": 0x800be48c,
		"TTelesaSlot::randomReset": 0x800be550,
		"randomReset": 0x800be550,
		"TTelesaSlot::initMapObj": 0x800be63c,
		"TBossTelesaKillSmallEnemy::checkHit": 0x800be7c0,
		"TBossTelesaTongue::receiveMessage": 0x800be8f8,
		"TBossTelesaBody::receiveMessage": 0x800bea1c,
		"TBossTelesaManager::perform": 0x800bec64,
		"TBossTelesaManager::createModelData": 0x800bec84,
		"TBossTelesaManager::createEnemyInstance": 0x800becb8,
		"TBossTelesaManager::load": 0x800bed00,
		"TBossTelesaManager::TBossTelesaManager": 0x800bed6c,
		"TBossTelesaSaveLoadParams::TBossTelesaSaveLoadParams": 0x800beda8,
		"TNerveBubbleSplit::execute": 0x800bf148,
		"TNerveBubbleSplit::~TNerveBubbleSplit": 0x800bf208,
		"TNerveBubbleLive::execute": 0x800bf264,
		"TBubble::appendEnemy": 0x800bf64c,
		"appendEnemy": 0x800bf64c,
		"TNerveBubbleLive::~TNerveBubbleLive": 0x800bf860,
		"TBubble::getBasNameTable": 0x800bf8bc,
		"TBubble::getTakingMtx": 0x800bf8c8,
		"TBubble::setDeadAnm": 0x800bf8d8,
		"TBubble::calcRootMatrix": 0x800bf908,
		"TBubble::attackToMario": 0x800bf9d0,
		"TBubble::behaveToWater": 0x800bfa1c,
		"TBubble::kill": 0x800bfb08,
		"TBubble::getGravityY": 0x800bfc2c,
		"TBubble::split": 0x800bfc5c,
		"split": 0x800bfc5c,
		"TBubble::reset": 0x800bfe14,
		"TBubble::init": 0x800bff28,
		"TBubbleManager::createModelData": 0x800c0050,
		"TBubbleManager::createEnemyInstance": 0x800c0084,
		"TBubbleManager::load": 0x800c0114,
		"TBubbleManager::TBubbleManager": 0x800c02b0,
		"TTelesaSlot::initNeonMatColor": 0x800c04e4,
		"TBossTelesaManager::~TBossTelesaManager": 0x800c0764,
		"TBossTelesaManager::clipEnemies": 0x800c07c8,
		"TBubble::setAfterDeadEffect": 0x800c07cc,
		"TBubbleManager::~TBubbleManager": 0x800c086c,
		"Enemy::__sinit_bosstelesa_cpp": 0x800c08e0,
		"__sinit_bosstelesa_cpp": 0x800c08e0,
		"TNerveRHGraphWander::~TNerveRHGraphWander": 0x800c0c14,
		"TNerveRHGraphWander::execute": 0x800c0c70,
		"TRiccoHookManager::createEnemyInstance": 0x800c0f50,
		"TRiccoHookManager::load": 0x800c0f58,
		"TRiccoHookManager::createModelData": 0x800c1084,
		"TRiccoHookManager::TRiccoHookManager": 0x800c10b8,
		"TRiccoHook::perform": 0x800c10f4,
		"TRiccoHook::receiveMessage": 0x800c11e4,
		"TRiccoHook::kill": 0x800c11ec,
		"TRiccoHook::init": 0x800c11f0,
		"TRiccoHook::TRiccoHook": 0x800c144c,
		"THookTake::perform": 0x800c149c,
		"THookTake::receiveMessage": 0x800c1580,
		"THookTake::getRadiusAtY": 0x800c15c8,
		"THookTake::getTakingMtx": 0x800c15fc,
		"TRiccoHookManager::~TRiccoHookManager": 0x800c1604,
		"TNerveBombHeiExplosion::~TNerveBombHeiExplosion": 0x800c1a7c,
		"TNerveBombHeiExplosion::execute": 0x800c1ad8,
		"TNerveBombHeiThrown::execute": 0x800c1d60,
		"TNerveBombHeiThrown::~TNerveBombHeiThrown": 0x800c1f14,
		"TNerveBombHeiPickUp::execute": 0x800c1f70,
		"TNerveBombHeiPickUp::~TNerveBombHeiPickUp": 0x800c1f9c,
		"TNerveBombHeiWaitExplosion::execute": 0x800c1ff8,
		"TNerveBombHeiWaitExplosion::~TNerveBombHeiWaitExplosion": 0x800c2268,
		"TNerveBombHeiWalkExplosion::execute": 0x800c22c4,
		"TNerveBombHeiWalkExplosion::~TNerveBombHeiWalkExplosion": 0x800c2474,
		"TNerveBombHeiAttack::execute": 0x800c24d0,
		"TNerveBombHeiAttack::~TNerveBombHeiAttack": 0x800c25c0,
		"TNerveBombHeiGenerate::execute": 0x800c261c,
		"TNerveBombHeiGenerate::~TNerveBombHeiGenerate": 0x800c2850,
		"TBombHei::getBasNameTable": 0x800c28ac,
		"TBombHei::isDamageToCannon": 0x800c28b8,
		"isDamageToCannon": 0x800c28b8,
		"TBombHei::forceKill": 0x800c29a8,
		"TBombHei::isCollidMove": 0x800c2bb4,
		"TBombHei::moveObject": 0x800c2ef8,
		"TBombHei::walkBehavior": 0x800c315c,
		"TBombHei::getGravityY": 0x800c31e0,
		"TBombHei::reset": 0x800c3270,
		"TBombHei::behaveToRelease": 0x800c32c8,
		"TBombHei::behaveToTaken": 0x800c3448,
		"TBombHei::attackToMario": 0x800c359c,
		"TBombHei::calcRootMatrix": 0x800c3628,
		"TBombHei::setDeadAnm": 0x800c36e4,
		"TBombHei::setFreezeAnm": 0x800c37c0,
		"TBombHei::setWalkAnm": 0x800c37f0,
		"TBombHei::genEventCoin": 0x800c3820,
		"TBombHei::kill": 0x800c3930,
		"TBombHei::isHitValid": 0x800c3ac4,
		"TBombHei::changeOut": 0x800c3b1c,
		"TBombHei::behaveToWater": 0x800c3c10,
		"TBombHei::setMActorAndKeeper": 0x800c3d24,
		"TBombHei::init": 0x800c3da4,
		"TBombHei::TBombHei": 0x800c3e9c,
		"TBombHeiManager::createEnemyInstance": 0x800c3ef8,
		"TBombHeiManager::createModelData": 0x800c3f68,
		"TBombHeiManager::load": 0x800c3f9c,
		"TBombHeiManager::TBombHeiManager": 0x800c412c,
		"TBombHei::setAfterDeadEffect": 0x800c4170,
		"TBombHei::doKeepDistance": 0x800c4174,
		"TBombHeiManager::~TBombHeiManager": 0x800c4228,
		"Enemy::__sinit_bombhei_cpp": 0x800c42a0,
		"__sinit_bombhei_cpp": 0x800c42a0,
		"TNerveCannonObject::~TNerveCannonObject": 0x800c45a4,
		"TNerveCannonObject::execute": 0x800c4600,
		"TNerveCannonDamageDemo::execute": 0x800c47e0,
		"TNerveCannonDamageDemo::~TNerveCannonDamageDemo": 0x800c4a0c,
		"TNerveCannonDamage::execute": 0x800c4a68,
		"TNerveCannonSearch::~TNerveCannonSearch": 0x800c507c,
		"TNerveCannonDamage::~TNerveCannonDamage": 0x800c50d8,
		"TNerveCannonClose::execute": 0x800c5134,
		"TNerveCannonOpen::~TNerveCannonOpen": 0x800c546c,
		"TNerveCannonClose::~TNerveCannonClose": 0x800c54c8,
		"TNerveCannonForceBombShoot::execute": 0x800c5524,
		"TNerveCannonForceBombShoot::~TNerveCannonForceBombShoot": 0x800c57d0,
		"TNerveCannonShoot::execute": 0x800c582c,
		"TNerveCannonShoot::~TNerveCannonShoot": 0x800c5bc8,
		"TNerveCannonSearch::execute": 0x800c5c24,
		"TNerveCannonOpen::execute": 0x800c62e8,
		"TCannon::startChorobeiShout": 0x800c64b0,
		"startChorobeiShout": 0x800c64b0,
		"TCannon::isObject": 0x800c64b4,
		"isObject": 0x800c64b4,
		"TCannon::setKillerGoalPoint": 0x800c650c,
		"setKillerGoalPoint": 0x800c650c,
		"TCannon::killerShoot": 0x800c674c,
		"killerShoot": 0x800c674c,
		"TCannon::bombShoot": 0x800c7044,
		"bombShoot": 0x800c7044,
		"TCannon::bombSet": 0x800c7210,
		"bombSet": 0x800c7210,
		"TCannon::getTakingMtx": 0x800c7474,
		"TCannon::calcRootMatrix": 0x800c7538,
		"TCannon::perform": 0x800c79c4,
		"TCannon::getBasNameTable": 0x800c7e60,
		"TCannon::receiveMessage": 0x800c7e6c,
		"TCannon::moveObject": 0x800c7eb4,
		"TCannon::reset": 0x800c8190,
		"TCannon::init": 0x800c82b8,
		"TCannon::loadAfter": 0x800c889c,
		"TCannon::load": 0x800c8a4c,
		"TCannon::TCannon": 0x800c8af4,
		"TCannonDom::perform": 0x800c8bbc,
		"TCannonDom::TCannonDom": 0x800c8cb4,
		"TChorobei::receiveMessage": 0x800c8dc4,
		"TChorobei::checkHit": 0x800c8dcc,
		"TChorobei::perform": 0x800c9058,
		"TChorobei::TChorobei": 0x800c9180,
		"TCannonManager::createEnemyInstance": 0x800c9294,
		"TCannonManager::load": 0x800c92d8,
		"TCannonManager::TCannonManager": 0x800c9330,
		"TCannonSaveLoadParams::TCannonSaveLoadParams": 0x800c936c,
		"TCannon::isCollidMove": 0x800c9610,
		"TCannon::isHitVallid": 0x800c9618,
		"isHitVallid": 0x800c9618,
		"TCannon::isInhibitedForceMove": 0x800c9620,
		"TCannonDom::~TCannonDom": 0x800c96ac,
		"TCannonManager::~TCannonManager": 0x800c97b4,
		"TCannonManager::clipEnemies": 0x800c9828,
		"Enemy::__sinit_cannon_cpp": 0x800c982c,
		"__sinit_cannon_cpp": 0x800c982c,
		"TNerveBossEelSleepOnBottom::~TNerveBossEelSleepOnBottom": 0x800c9b38,
		"TNerveBossEelSleepOnBottom::execute": 0x800c9b94,
		"TNerveBossEelSleepOnBottom::theNerve": 0x800c9d28,
		"TNerveBossEelMouthOpenWait::execute": 0x800c9d8c,
		"TNerveBossEelEat::~TNerveBossEelEat": 0x800ca294,
		"TNerveBossEelMouthOpenWait::theNerve": 0x800ca2f0,
		"TNerveBossEelMouthOpenWait::~TNerveBossEelMouthOpenWait": 0x800ca354,
		"TNerveBossEelDie::execute": 0x800ca3b0,
		"TNerveBossEelDie::theNerve": 0x800ca830,
		"TNerveBossEelDie::~TNerveBossEelDie": 0x800ca894,
		"TNerveBossEelEat::execute": 0x800ca8f0,
		"TNerveBossEelQuickBack::~TNerveBossEelQuickBack": 0x800caf24,
		"TNerveBossEelEat::theNerve": 0x800caf80,
		"TNerveBossEelQuickBack::execute": 0x800cafe4,
		"TNerveBossEelQuickBack::theNerve": 0x800cb108,
		"TNerveBossEelSlowBack::execute": 0x800cb16c,
		"TNerveBossEelSlowBack::theNerve": 0x800cb194,
		"TNerveBossEelSlowBack::~TNerveBossEelSlowBack": 0x800cb1f8,
		"Enemy::ExecBackNerve_Sub": 0x800cb254,
		"ExecBackNerve_Sub": 0x800cb254,
		"TNerveBossEelSecondSpin::~TNerveBossEelSecondSpin": 0x800cb5fc,
		"TNerveBossEelOutWait::execute": 0x800cb658,
		"TNerveBossEelOutWait::~TNerveBossEelOutWait": 0x800cbc0c,
		"TNerveBossEelOutWait::theNerve": 0x800cbc68,
		"TNerveBossEelAppear::execute": 0x800cbccc,
		"TNerveBossEelAppear::theNerve": 0x800cc018,
		"TNerveBossEelAppear::~TNerveBossEelAppear": 0x800cc07c,
		"TNerveBossEelSecondSpin::execute": 0x800cc0d8,
		"TNerveBossEelSecondSpin::theNerve": 0x800cc4e8,
		"TNerveBossEelFirstSpin::execute": 0x800cc54c,
		"TNerveBossEelFirstSpin::theNerve": 0x800cc894,
		"TNerveBossEelFirstSpin::~TNerveBossEelFirstSpin": 0x800cc8f8,
		"TNerveBossEelWaitAppear::execute": 0x800cc954,
		"TNerveBossEelWaitAppear::theNerve": 0x800ccb40,
		"TNerveBossEelWaitAppear::~TNerveBossEelWaitAppear": 0x800ccba4,
		"TBossEel::getBasNameTable": 0x800ccc00,
		"Enemy::hoseiDiveCameraCallback": 0x800ccc0c,
		"hoseiDiveCameraCallback": 0x800ccc0c,
		"TBossEel::isInBossEelMoguDemo": 0x800ccc6c,
		"isInBossEelMoguDemo": 0x800ccc6c,
		"TBossEel::perform": 0x800cccc8,
		"TBossEel::collideToMario": 0x800cd900,
		"collideToMario": 0x800cd900,
		"TBossEel::forceShedTears": 0x800cdcd0,
		"forceShedTears": 0x800cdcd0,
		"TBossEel::shedTears": 0x800cddf4,
		"shedTears": 0x800cddf4,
		"TBossEel::updateTearsCnt": 0x800cdf5c,
		"updateTearsCnt": 0x800cdf5c,
		"TBossEel::getTakingMtx": 0x800ce1f0,
		"TBossEel::init": 0x800ce204,
		"TBossEelTearsRecoverCollision::perform": 0x800ced88,
		"TBossEelTearsRecoverCollision::behaveToMario": 0x800cee38,
		"TBossEelTearsRecoverCollision::initCollision": 0x800cee7c,
		"TBossEelBarrierCollision::behaveToMario": 0x800ceed0,
		"TBossEelBarrierCollision::initCollision": 0x800cef3c,
		"TBossEelAwaCollision::perform": 0x800cef90,
		"TBossEelAwaCollision::behaveToMario": 0x800cf0cc,
		"TBossEelAwaCollision::initCollision": 0x800cf148,
		"TBossEelBodyCollision::initCollision": 0x800cf19c,
		"TBossEelCollision::behaveToMario": 0x800cf1f8,
		"TBossEelCollision::initCollision": 0x800cf420,
		"TBossEelCollision::perform": 0x800cf460,
		"TNerveBEelTearsMarioRecover::~TNerveBEelTearsMarioRecover": 0x800cf53c,
		"TBossEel::TBossEel": 0x800cf598,
		"TBossEelHeartCoin::generate": 0x800cf680,
		"TBossEelHeartCoin::perform": 0x800cf74c,
		"TBossEelEye::perform": 0x800cf9a4,
		"TBossEelEye::TBossEelEye": 0x800cfc54,
		"TBossEelVortex::reset": 0x800cfd9c,
		"TBossEelVortex::perform": 0x800cfdc0,
		"TBossEelTooth::perform": 0x800d0110,
		"TBossEelTooth::receiveMessage": 0x800d0720,
		"TBossEelTooth::TBossEelTooth": 0x800d0a54,
		"TBossEelManager::clipEnemies": 0x800d0c7c,
		"TBossEelManager::createModelData": 0x800d0ca4,
		"TBossEelManager::loadAfter": 0x800d0cd8,
		"TBossEelSaveParams::TBossEelSaveParams": 0x800d0f7c,
		"TNerveOilBallStay::execute": 0x800d15f0,
		"TNerveOilBallStay::theNerve": 0x800d167c,
		"TNerveOilBallStay::~TNerveOilBallStay": 0x800d16e0,
		"TOilBall::calcRootMatrix": 0x800d173c,
		"TOilBall::moveObject": 0x800d175c,
		"TNerveBEelTearsSplit::~TNerveBEelTearsSplit": 0x800d1ac8,
		"TNerveBEelTearsMoveUp::~TNerveBEelTearsMoveUp": 0x800d1b24,
		"TOilBall::reset": 0x800d1b80,
		"TNerveBEelTearsGenerate::~TNerveBEelTearsGenerate": 0x800d1d10,
		"TOilBall::load": 0x800d1d6c,
		"TNerveBEelTearsSplit::execute": 0x800d1dcc,
		"TNerveBEelTearsSplit::theNerve": 0x800d201c,
		"TNerveBEelTearsMarioRecover::execute": 0x800d2080,
		"TNerveBEelTearsMarioRecover::theNerve": 0x800d21e0,
		"TNerveBEelTearsWaterHit::execute": 0x800d2244,
		"TNerveBEelTearsWaterHit::theNerve": 0x800d2508,
		"TNerveBEelTearsWaterHit::~TNerveBEelTearsWaterHit": 0x800d256c,
		"TNerveBEelTearsMoveUp::execute": 0x800d25c8,
		"TNerveBEelTearsMoveUp::theNerve": 0x800d2634,
		"TNerveBEelTearsGenerate::execute": 0x800d2698,
		"TNerveBEelTearsGenerate::theNerve": 0x800d2790,
		"TBEelTears::getBasNameTable": 0x800d27f4,
		"TBEelTears::reset": 0x800d2800,
		"TBEelTears::kill": 0x800d28ec,
		"TBEelTears::receiveMessage": 0x800d2918,
		"TBEelTears::perform": 0x800d2b14,
		"TBEelTears::calcRootMatrix": 0x800d2c60,
		"TBEelTears::moveObject": 0x800d2dc8,
		"TBEelTears::setMActorAndKeeper": 0x800d3190,
		"TBEelTears::init": 0x800d3210,
		"TBEelTears::TBEelTears": 0x800d352c,
		"TBEelTearsManager::splitTears": 0x800d358c,
		"splitTears": 0x800d358c,
		"TBEelTearsManager::createEnemies": 0x800d3808,
		"TBEelTearsManager::createEnemyInstance": 0x800d38c0,
		"TBEelTearsManager::perform": 0x800d3938,
		"TBEelTearsManager::createModelData": 0x800d3a34,
		"TBEelTearsManager::loadAfter": 0x800d3a68,
		"TBEelTearsManager::load": 0x800d3b2c,
		"TBEelTearsManager::TBEelTearsManager": 0x800d3b98,
		"TBEelTearsSaveLoadParams::TBEelTearsSaveLoadParams": 0x800d3bd4,
		"TBEelTearsDrop::perform": 0x800d3f7c,
		"TBEelTearsDrop::TBEelTearsDrop": 0x800d40cc,
		"TBossEel::hasMapCollision": 0x800d4364,
		"TBossEel::receiveMessage": 0x800d436c,
		"TBossEelHeartCoin::~TBossEelHeartCoin": 0x800d45e4,
		"TBossEelEye::~TBossEelEye": 0x800d4668,
		"TBossEelManager::~TBossEelManager": 0x800d47f4,
		"TBEelTearsManager::~TBEelTearsManager": 0x800d4948,
		"Enemy::__sinit_bosseel_cpp": 0x800d4a30,
		"__sinit_bosseel_cpp": 0x800d4a30,
		"TNerveKillerExplosion::~TNerveKillerExplosion": 0x800d4d84,
		"TNerveKillerExplosion::execute": 0x800d4de0,
		"TKiller::isFindMario": 0x800d5084,
		"TKiller::calcRootMatrix": 0x800d513c,
		"TKiller::bind": 0x800d5504,
		"TNerveFlyEnemyChaseFly::~TNerveFlyEnemyChaseFly": 0x800d58fc,
		"TKiller::setColorType": 0x800d5958,
		"setColorType": 0x800d5958,
		"TKiller::reset": 0x800d599c,
		"TKiller::changeOut": 0x800d5ab0,
		"TKiller::flyBehavior": 0x800d5ba4,
		"TKiller::isCollidMove": 0x800d5c5c,
		"TKiller::isRollFly": 0x800d5dc0,
		"isRollFly": 0x800d5dc0,
		"TKiller::setChaseFlyAnm": 0x800d5e6c,
		"TKiller::setNormalFlyAnm": 0x800d5e9c,
		"TKiller::getBasNameTable": 0x800d5f00,
		"TKiller::attackToMario": 0x800d5f0c,
		"TKiller::setDeadAnm": 0x800d605c,
		"TKiller::isHitValid": 0x800d6100,
		"TKiller::genEventCoin": 0x800d6174,
		"TKiller::behaveToWater": 0x800d6358,
		"TNerveFlyEnemyNormalFly::~TNerveFlyEnemyNormalFly": 0x800d6568,
		"TKiller::setMActorAndKeeper": 0x800d65c4,
		"TKiller::init": 0x800d6718,
		"TKiller::TKiller": 0x800d68b8,
		"Enemy::KillerBodyCallback": 0x800d69c8,
		"KillerBodyCallback": 0x800d69c8,
		"TKillerManager::createEnemyInstance": 0x800d6bc0,
		"TFlyEnemy::TFlyEnemy": 0x800d6c28,
		"TKillerManager::createModelData": 0x800d6c88,
		"TKillerManager::load": 0x800d6cbc,
		"TKillerManager::TKillerManager": 0x800d6edc,
		"TNerveFlyEnemyChaseFly::execute": 0x800d6f20,
		"TFlyEnemy::flyBehavior": 0x800d7468,
		"Enemy::MsSin": 0x800d747c,
		"MsSin": 0x800d747c,
		"Enemy::MsCos": 0x800d74b4,
		"MsCos": 0x800d74b4,
		"TFlyEnemy::setChaseFlyAnm": 0x800d7534,
		"TNerveFlyEnemyNormalFly::execute": 0x800d7538,
		"TFlyEnemy::setNormalFlyAnm": 0x800d7788,
		"TFlyEnemy::bind": 0x800d778c,
		"TFlyEnemy::calcChaseParam": 0x800d7830,
		"calcChaseParam": 0x800d7830,
		"TFlyEnemy::fly": 0x800d7a60,
		"fly": 0x800d7a60,
		"TFlyEnemy::reset": 0x800d7ca4,
		"TFlyEnemy::getGravityY": 0x800d7cf4,
		"TFlyEnemy::init": 0x800d7d84,
		"TKiller::forceKill": 0x800d7dc8,
		"TFlyEnemy::setAfterDeadEffect": 0x800d7dcc,
		"TKillerManager::~TKillerManager": 0x800d7e6c,
		"Enemy::__sinit_killer_cpp": 0x800d7ee0,
		"__sinit_killer_cpp": 0x800d7ee0,
		"TBeamManager::~TBeamManager": 0x800d81ec,
		"TBeamManager::perform": 0x800d8260,
		"TBeamManager::requestCone": 0x800d8390,
		"requestCone": 0x800d8390,
		"TBeamManager::setupMaterial": 0x800d8488,
		"setupMaterial": 0x800d8488,
		"TBeamManager::TBeamManager": 0x800d8560,
		"TConeBeam::drawConeBeam": 0x800d860c,
		"drawConeBeam": 0x800d860c,
		"TConeBeam::calcVertices": 0x800d8788,
		"calcVertices": 0x800d8788,
		"TConeBeam::drawConeBeamAux": 0x800d8e18,
		"drawConeBeamAux": 0x800d8e18,
		"TConeBeam::TConeBeam": 0x800d8fe4,
		"TNerveSamboHeadHitWall::~TNerveSamboHeadHitWall": 0x800d9064,
		"TNerveSamboHeadHitWall::execute": 0x800d90c0,
		"TNerveSamboHeadRecoverWater::execute": 0x800d92d4,
		"TNerveSamboHeadRecoverWater::~TNerveSamboHeadRecoverWater": 0x800d9360,
		"TNerveSamboHeadHitWater::execute": 0x800d93bc,
		"TNerveSamboHeadAttack::~TNerveSamboHeadAttack": 0x800d98bc,
		"TNerveSamboHeadHitWater::~TNerveSamboHeadHitWater": 0x800d9918,
		"TNerveSamboHeadHide::execute": 0x800d9974,
		"TNerveSamboHeadAppear::~TNerveSamboHeadAppear": 0x800d9bb4,
		"TNerveSamboHeadHide::~TNerveSamboHeadHide": 0x800d9c10,
		"TNerveSamboHeadAttack::execute": 0x800d9c6c,
		"TNerveSamboHeadAppear::execute": 0x800d9fec,
		"TSamboHead::getBasNameTable": 0x800da26c,
		"TSamboHead::genEventCoin": 0x800da278,
		"TSamboHead::calcRootMatrix": 0x800da544,
		"TSamboHead::setAfterDeadEffect": 0x800da568,
		"TSamboHead::setDeadAnm": 0x800da698,
		"TSamboHead::getGravityY": 0x800da6c8,
		"TSamboHead::attackToMario": 0x800da7c0,
		"TSamboHead::behaveToWater": 0x800da944,
		"TSamboHead::kill": 0x800dac6c,
		"TSamboHead::reset": 0x800dad2c,
		"TSamboHead::setMActorAndKeeper": 0x800dad80,
		"TSamboHead::init": 0x800dadec,
		"TSamboHead::load": 0x800daf3c,
		"TSamboHead::TSamboHead": 0x800daffc,
		"TSamboHeadManager::createEnemyInstance": 0x800db05c,
		"TSamboHeadManager::createModelData": 0x800db0d4,
		"TSamboHeadManager::load": 0x800db108,
		"TSamboHeadManager::TSamboHeadManager": 0x800db3a0,
		"Enemy::SamboHeadRollCallback": 0x800db3e4,
		"SamboHeadRollCallback": 0x800db3e4,
		"TNerveHanaSamboFreeze::execute": 0x800db6e8,
		"TNerveHanaSamboFreeze::~TNerveHanaSamboFreeze": 0x800db7e4,
		"TNerveHanaSamboDie::execute": 0x800db840,
		"TNerveHanaSamboDie::~TNerveHanaSamboDie": 0x800dba7c,
		"TNerveHanaSamboHide::execute": 0x800dbad8,
		"TNerveHanaSamboAppear::~TNerveHanaSamboAppear": 0x800dbd6c,
		"TNerveHanaSamboHide::~TNerveHanaSamboHide": 0x800dbdc8,
		"TNerveHanaSamboAttack::execute": 0x800dbe24,
		"TNerveHanaSamboWait::~TNerveHanaSamboWait": 0x800dc018,
		"TNerveHanaSamboAttack::~TNerveHanaSamboAttack": 0x800dc074,
		"TNerveHanaSamboWait::execute": 0x800dc0d0,
		"TNerveHanaSamboAppear::execute": 0x800dc2dc,
		"THanaSambo::createPollen": 0x800dc52c,
		"createPollen": 0x800dc52c,
		"THanaSambo::perform": 0x800dc6d4,
		"THanaSambo::getBasNameTable": 0x800dc734,
		"THanaSambo::setDeadAnm": 0x800dc740,
		"THanaSambo::setWaitAnm": 0x800dc7e0,
		"THanaSambo::reset": 0x800dc824,
		"THanaSambo::kill": 0x800dc870,
		"THanaSambo::drawObject": 0x800dca30,
		"THanaSambo::moveObject": 0x800dca70,
		"THanaSambo::setMActorAndKeeper": 0x800dcbec,
		"THanaSambo::init": 0x800dcc6c,
		"THanaSambo::load": 0x800dcf1c,
		"THanaSambo::THanaSambo": 0x800dcfdc,
		"THanaSamboHead::receiveMessage": 0x800dd058,
		"THanaSamboManager::createModelData": 0x800dd1d0,
		"THanaSamboManager::createEnemyInstance": 0x800dd204,
		"THanaSamboManager::load": 0x800dd298,
		"THanaSamboManager::THanaSamboManager": 0x800dd4ac,
		"TSamboFlower::drawObject": 0x800dd4e8,
		"TSamboFlower::moveObject": 0x800dd5a0,
		"TSamboFlower::reset": 0x800dd748,
		"TSamboFlower::receiveMessage": 0x800dd7b4,
		"TSamboFlower::setMActorAndKeeper": 0x800dd8a0,
		"TSamboFlower::init": 0x800dd938,
		"TSamboFlower::loadAfter": 0x800dda4c,
		"TSamboFlower::load": 0x800ddad0,
		"TSamboFlowerManager::dropLeaf": 0x800ddb50,
		"dropLeaf": 0x800ddb50,
		"TSamboFlowerManager::perform": 0x800ddd80,
		"TSamboFlowerManager::loadAfter": 0x800dde38,
		"TSamboFlowerManager::createEnemyInstance": 0x800de1f0,
		"TSamboFlowerManager::createModelData": 0x800de2a0,
		"TSamboFlowerManager::load": 0x800de2d4,
		"TSamboFlowerSaveLoadParams::TSamboFlowerSaveLoadParams": 0x800de340,
		"TSamboLeaf::perform": 0x800de5e0,
		"TSamboFlowerCoinUnit::checkGenCoin": 0x800de804,
		"checkGenCoin": 0x800de804,
		"TSamboHeadManager::~TSamboHeadManager": 0x800debf4,
		"THanaSambo::behaveToWater": 0x800dec68,
		"THanaSambo::isHitValid": 0x800dec6c,
		"THanaSambo::isCollidMove": 0x800dec90,
		"THanaSamboManager::~THanaSamboManager": 0x800deda0,
		"TSamboFlower::control": 0x800dee14,
		"TSamboFlowerManager::~TSamboFlowerManager": 0x800dee84,
		"TSamboLeaf::~TSamboLeaf": 0x800deee8,
		"Enemy::__sinit_hanasambo_cpp": 0x800def5c,
		"__sinit_hanasambo_cpp": 0x800def5c,
		"TNervePopoThrown::~TNervePopoThrown": 0x800df278,
		"TNervePopoThrown::execute": 0x800df2d4,
		"TNervePopoWait::execute": 0x800df36c,
		"TNervePopoWait::~TNervePopoWait": 0x800df45c,
		"TNervePopoExplosion::execute": 0x800df4b8,
		"TNervePopoExplosion::~TNervePopoExplosion": 0x800df6bc,
		"TNervePopoFly::execute": 0x800df718,
		"TNervePopoFly::~TNervePopoFly": 0x800df9fc,
		"TNervePopoAttack::execute": 0x800dfa58,
		"TNervePopoAttack::~TNervePopoAttack": 0x800dfbf0,
		"TNervePopoPossessedNozzle::execute": 0x800dfc4c,
		"TNervePopoPossessedNozzle::~TNervePopoPossessedNozzle": 0x800dfe1c,
		"TPopo::getBasNameTable": 0x800dfe78,
		"TPopo::thrownByChorobei": 0x800dfe84,
		"thrownByChorobei": 0x800dfe84,
		"TPopo::possessedIn": 0x800dff10,
		"possessedIn": 0x800dff10,
		"TPopo::explosion": 0x800e0024,
		"explosion": 0x800e0024,
		"TPopo::flyBehavior": 0x800e0170,
		"TPopo::isCollidMove": 0x800e0334,
		"TPopo::isFindMario": 0x800e0484,
		"TPopo::isHitValid": 0x800e0554,
		"TPopo::bind": 0x800e0634,
		"TPopo::forceKill": 0x800e0a20,
		"TPopo::kill": 0x800e0c44,
		"TPopo::calcRootMatrix": 0x800e0ca4,
		"TPopo::attackToMario": 0x800e1168,
		"TPopo::walkBehavior": 0x800e1410,
		"TPopo::behaveToFindMario": 0x800e18f0,
		"TPopo::getGravityY": 0x800e1adc,
		"TPopo::behaveToWater": 0x800e1c90,
		"TPopo::checkTrigger": 0x800e1f38,
		"checkTrigger": 0x800e1f38,
		"TPopo::reset": 0x800e2248,
		"TPopo::setMActorAndKeeper": 0x800e238c,
		"TPopo::perform": 0x800e240c,
		"TPopo::init": 0x800e2460,
		"TPopo::load": 0x800e26ac,
		"TPopo::TPopo": 0x800e270c,
		"Enemy::PopoNonScaleCallback": 0x800e2788,
		"PopoNonScaleCallback": 0x800e2788,
		"Enemy::PopoPossessedCallback": 0x800e2924,
		"PopoPossessedCallback": 0x800e2924,
		"Enemy::PopoRollCallback": 0x800e2cd4,
		"PopoRollCallback": 0x800e2cd4,
		"TPopoCollision::receiveMessage": 0x800e2f04,
		"TPopoManager::perform": 0x800e2fe0,
		"TPopoManager::createModelData": 0x800e30a0,
		"TPopoManager::initSetEnemies": 0x800e30d4,
		"TPopoManager::createEnemyInstance": 0x800e3114,
		"TPopoManager::load": 0x800e3158,
		"TPopoManager::TPopoManager": 0x800e31fc,
		"TPopoSaveLoadParams::TPopoSaveLoadParams": 0x800e3254,
		"TPopoManager::~TPopoManager": 0x800e3674,
		"Enemy::__sinit_popo_cpp": 0x800e36e8,
		"__sinit_popo_cpp": 0x800e36e8,
		"TNerveSBH_Fall::~TNerveSBH_Fall": 0x800e39f4,
		"TNerveSBH_Fall::execute": 0x800e3a50,
		"TNerveSBH_SleepContinue::~TNerveSBH_SleepContinue": 0x800e3b8c,
		"TNerveSBH_Fall::theNerve": 0x800e3be8,
		"TNerveSBH_SleepContinue::execute": 0x800e3c4c,
		"TNerveSBH_SleepContinue::theNerve": 0x800e3c54,
		"TSleepBossHanachan::startFall": 0x800e3cb8,
		"startFall": 0x800e3cb8,
		"TSleepBossHanachan::getBasNameTable": 0x800e3da4,
		"TSleepBossHanachan::calcRootMatrix": 0x800e3dac,
		"TSleepBossHanachan::init": 0x800e3db0,
		"TSleepBossHanachanManager::createModelData": 0x800e3f70,
		"TSleepBossHanachanManager::~TSleepBossHanachanManager": 0x800e4028,
		"TDemoBossHanachan::receiveMessage": 0x800e4110,
		"TDemoBossHanachan::initBase": 0x800e4118,
		"initBase": 0x800e4118,
		"TDemoBossHanachanManager::clipEnemies": 0x800e4218,
		"TDemoBossHanachanSaveParams::TDemoBossHanachanSaveParams": 0x800e4244,
		"TNerveFruitsBoatBckTrace::~TNerveFruitsBoatBckTrace": 0x800e437c,
		"TNerveFruitsBoatBckTrace::execute": 0x800e43d8,
		"TNerveFruitsBoatGraphWander::execute": 0x800e4538,
		"TNerveFruitsBoatGraphWander::~TNerveFruitsBoatGraphWander": 0x800e495c,
		"TFruitsBoatManager::createEnemyInstance": 0x800e4a00,
		"TFruitsBoatManager::load": 0x800e4a08,
		"TFruitsBoatManager::createModelData": 0x800e4b08,
		"TFruitsBoatManager::TFruitsBoatManager": 0x800e4bac,
		"TFruitsBoat::requestShadow": 0x800e4bfc,
		"TFruitsBoat::moveObject": 0x800e4d5c,
		"TFruitsBoat::calcRootMatrix": 0x800e5594,
		"TFruitsBoat::setGroundCollision": 0x800e5644,
		"TFruitsBoat::receiveMessage": 0x800e57e8,
		"TFruitsBoat::init": 0x800e57f0,
		"TFruitsBoat::load": 0x800e5c94,
		"TFruitsBoat::getRootJointMtx": 0x800e5dec,
		"TFruitsBoat::setBckTrack": 0x800e5dfc,
		"setBckTrack": 0x800e5dfc,
		"TFruitsBoat::TFruitsBoat": 0x800e5f14,
		"TFruitsBoatManager::~TFruitsBoatManager": 0x800e5f9c,
		"Enemy::__sinit_fruitsboat_cpp": 0x800e606c,
		"__sinit_fruitsboat_cpp": 0x800e606c,
		"TSphereLink::setDegreeZAndRevisionPosXZ": 0x800e63f4,
		"setDegreeZAndRevisionPosXZ": 0x800e63f4,
		"TSphereLink::moveHead": 0x800e6610,
		"TBGCheckData::isIllegalData": 0x800e69e4,
		"isIllegalData": 0x800e69e4,
		"TSphereLink::TSphereLink": 0x800e6a00,
		"TSpherePoint::TSpherePoint": 0x800e6be0,
		"TWaterHitActor::receiveMessage": 0x800e6be4,
		"TWaterHitActor::onWaterHitCounter": 0x800e6c54,
		"onWaterHitCounter": 0x800e6c54,
		"Enemy::BHSCalcRevisionDistXZByRotateZ": 0x800e6c60,
		"BHSCalcRevisionDistXZByRotateZ": 0x800e6c60,
		"Enemy::BHSCalcCentrifugalForce": 0x800e6cec,
		"BHSCalcCentrifugalForce": 0x800e6cec,
		"TBossHanachan::hasMapCollision": 0x800e7010,
		"TBossHanachan::removeAllMapCollision": 0x800e7018,
		"removeAllMapCollision": 0x800e7018,
		"TBossHanachan::execDamage": 0x800e709c,
		"execDamage": 0x800e709c,
		"TBossHanachan::goToInitialRecoverGraphNode": 0x800e737c,
		"goToInitialRecoverGraphNode": 0x800e737c,
		"TBossHanachan::execSlip": 0x800e7414,
		"execSlip": 0x800e7414,
		"TBossHanachan::execWalk": 0x800e77b4,
		"TBossHanachan::getBodyMaxRotateZ": 0x800e79b8,
		"getBodyMaxRotateZ": 0x800e79b8,
		"TBossHanachan::checkFallDecideAndSetup": 0x800e7ac0,
		"checkFallDecideAndSetup": 0x800e7ac0,
		"TBossHanachan::isTumbleCompletelyAllBody": 0x800e7bc8,
		"isTumbleCompletelyAllBody": 0x800e7bc8,
		"TBossHanachan::perform": 0x800e7cc4,
		"TBossHanachan::moveObject": 0x800e94e8,
		"TBossHanachan::bind": 0x800e95bc,
		"TBossHanachan::kill": 0x800e98c8,
		"Enemy::CalcRevisionPosByRotateZ": 0x800e98cc,
		"CalcRevisionPosByRotateZ": 0x800e98cc,
		"TBossHanachan::throwMario_": 0x800e999c,
		"throwMario_": 0x800e999c,
		"TBossHanachan::init": 0x800e9d1c,
		"TBossHanachan::setRandomWeakBodyIndex": 0x800ea264,
		"setRandomWeakBodyIndex": 0x800ea264,
		"TBossHanachan::TBossHanachan": 0x800ea2cc,
		"TBossHanachanManager::hasMapCollision": 0x800ea3b4,
		"TBossHanachanManager::clipEnemies": 0x800ea3bc,
		"TBossHanachanManager::loadAfter": 0x800ea3e8,
		"TBossHanachanManager::createModelData": 0x800ea474,
		"TBossHanachanManager::TBossHanachanManager": 0x800ea4cc,
		"TBossHanachanManager::~TBossHanachanManager": 0x800ea5b4,
		"Enemy::__sinit_BossHanachanMain_cpp": 0x800ea618,
		"__sinit_BossHanachanMain_cpp": 0x800ea618,
		"TNerveBossHanachanDead::~TNerveBossHanachanDead": 0x800ea91c,
		"TNerveBossHanachanDead::execute": 0x800ea978,
		"TNerveBossHanachanDead::theNerve": 0x800ea9e4,
		"TNerveBossHanachanSnort::execute": 0x800eaa48,
		"TNerveBossHanachanGraphWander::~TNerveBossHanachanGraphWander": 0x800eaba0,
		"TNerveBossHanachanSnort::theNerve": 0x800eabfc,
		"TNerveBossHanachanSnort::~TNerveBossHanachanSnort": 0x800eac60,
		"TNerveBossHanachanDamage::execute": 0x800eacbc,
		"TNerveBossHanachanGetUp::~TNerveBossHanachanGetUp": 0x800eadb4,
		"TNerveBossHanachanDamage::theNerve": 0x800eae10,
		"TNerveBossHanachanDamage::~TNerveBossHanachanDamage": 0x800eae74,
		"TNerveBossHanachanGetUp::execute": 0x800eaed0,
		"TNerveBossHanachanGetUp::theNerve": 0x800eafb4,
		"TNerveBossHanachanDown::execute": 0x800eb018,
		"TNerveBossHanachanDown::theNerve": 0x800eb0f8,
		"TNerveBossHanachanDown::~TNerveBossHanachanDown": 0x800eb15c,
		"TNerveBossHanachanTumble::execute": 0x800eb1b8,
		"TNerveBossHanachanTumble::theNerve": 0x800eb2d4,
		"TNerveBossHanachanTumble::~TNerveBossHanachanTumble": 0x800eb338,
		"TNerveBossHanachanGraphWander::execute": 0x800eb394,
		"TNerveBossHanachanGraphWander::theNerve": 0x800eb484,
		"Enemy::__sinit_BossHanachanNerve_cpp": 0x800eb4e8,
		"__sinit_BossHanachanNerve_cpp": 0x800eb4e8,
		"TBossHanachan::changeAnmRateAndFrameUpdate_": 0x800eb7e4,
		"changeAnmRateAndFrameUpdate_": 0x800eb7e4,
		"TBossHanachan::isAllBckAlreadyEnd": 0x800ebe50,
		"isAllBckAlreadyEnd": 0x800ebe50,
		"TBossHanachan::isFinishedGetUp": 0x800ebf08,
		"isFinishedGetUp": 0x800ebf08,
		"TBossHanachan::considerSetAnm": 0x800ebf64,
		"considerSetAnm": 0x800ebf64,
		"TBossHanachan::setAnmTimerWhenDead": 0x800ebfd8,
		"setAnmTimerWhenDead": 0x800ebfd8,
		"TBossHanachan::setAnmTimerWhenDamage": 0x800ec124,
		"setAnmTimerWhenDamage": 0x800ec124,
		"TBossHanachan::setAnmTimerWhenSnort": 0x800ec270,
		"setAnmTimerWhenSnort": 0x800ec270,
		"TBossHanachan::setAnmTimerWhenGetUp": 0x800ec2e8,
		"setAnmTimerWhenGetUp": 0x800ec2e8,
		"TBossHanachan::setTumbleAnm": 0x800ec35c,
		"setTumbleAnm": 0x800ec35c,
		"TBossHanachan::setHeadAndBodyAnm": 0x800ec500,
		"setHeadAndBodyAnm": 0x800ec500,
		"TBossHanachanPartsHead::receiveMessage": 0x800ec6a4,
		"TBossHanachanPartsBody::receiveMessage": 0x800ec83c,
		"TBossHanachanPartsHead::setAnm_": 0x800eca60,
		"TBossHanachanPartsBody::setAnm_": 0x800ecb7c,
		"TBossHanachanPartsBase::considerSetAnm_": 0x800eccb0,
		"considerSetAnm_": 0x800eccb0,
		"TBossHanachanPartsBase::calcRotateZWhenGetUp_": 0x800ed3e4,
		"calcRotateZWhenGetUp_": 0x800ed3e4,
		"TBossHanachanPartsBase::getSandActor_": 0x800ed498,
		"getSandActor_": 0x800ed498,
		"TBossHanachanPartsBase::copyFrameFromOldAnmToNewAnm_": 0x800ed4ec,
		"copyFrameFromOldAnmToNewAnm_": 0x800ed4ec,
		"TBossHanachanPartsBase::isCurBckAlreadyEnd_": 0x800ed580,
		"isCurBckAlreadyEnd_": 0x800ed580,
		"TBossHanachanPartsBase::setDamageFog_": 0x800ed658,
		"setDamageFog_": 0x800ed658,
		"TBossHanachanPartsBase::entryCircleShadow_": 0x800ed748,
		"entryCircleShadow_": 0x800ed748,
		"TBossHanachanPartsBase::moveMapCollision_": 0x800ed810,
		"moveMapCollision_": 0x800ed810,
		"TBossHanachanPartsBase::changeTumbleAnmRate_": 0x800ed860,
		"changeTumbleAnmRate_": 0x800ed860,
		"TBossHanachanPartsBody::initFootHitActor_": 0x800ed91c,
		"initFootHitActor_": 0x800ed91c,
		"TBossHanachanPartsBase::initMapCollisionAndHitActor_": 0x800edac0,
		"initMapCollisionAndHitActor_": 0x800edac0,
		"TBossHanachanPartsHead::TBossHanachanPartsHead": 0x800edce0,
		"TBossHanachanPartsBody::TBossHanachanPartsBody": 0x800ede0c,
		"TBossHanachanPartsBase::TBossHanachanPartsBase": 0x800edf10,
		"Enemy::CLBPalFrame": 0x800ee204,
		"Enemy::__sinit_BossHanachanParts_cpp": 0x800ee260,
		"__sinit_BossHanachanParts_cpp": 0x800ee260,
		"TBossHanachanChangeSaveParams::TBossHanachanChangeSaveParams": 0x800ee574,
		"TBossHanachanCommonSaveParams::TBossHanachanCommonSaveParams": 0x800eebbc,
		"TNerveAmiNokoFreeze::~TNerveAmiNokoFreeze": 0x800ef13c,
		"TNerveAmiNokoFreeze::execute": 0x800ef198,
		"TNerveAmiNokoDie::execute": 0x800ef2b4,
		"TNerveAmiNokoDie::~TNerveAmiNokoDie": 0x800ef75c,
		"TNerveAmiNokoTurn::execute": 0x800ef7b8,
		"TNerveAmiNokoWalkOnFence::~TNerveAmiNokoWalkOnFence": 0x800efcc8,
		"TNerveAmiNokoTurn::~TNerveAmiNokoTurn": 0x800efd24,
		"TNerveAmiNokoWalkOnFence::execute": 0x800efd80,
		"TAmiNoko::getBasNameTable": 0x800f01f8,
		"TAmiNoko::getGravityY": 0x800f0204,
		"TAmiNoko::perform": 0x800f0290,
		"TAmiNoko::bind": 0x800f030c,
		"TAmiNoko::calcRootMatrix": 0x800f0538,
		"TAmiNoko::isHitValid": 0x800f10f0,
		"TAmiNoko::setWalkAnm": 0x800f1248,
		"TAmiNoko::attackToMario": 0x800f129c,
		"TAmiNoko::behaveToWater": 0x800f14c4,
		"TAmiNoko::reset": 0x800f15e4,
		"TAmiNoko::setMActorAndKeeper": 0x800f1604,
		"TAmiNoko::init": 0x800f1670,
		"TAmiNoko::load": 0x800f1894,
		"TAmiNoko::TAmiNoko": 0x800f18dc,
		"TAmiHit::perform": 0x800f1984,
		"TAmiHit::receiveMessage": 0x800f1b40,
		"TAmiNokoManager::createEnemyInstance": 0x800f1b70,
		"TAmiNokoManager::createModelData": 0x800f1b78,
		"TAmiNokoManager::load": 0x800f1bac,
		"TAmiNokoManager::TAmiNokoManager": 0x800f1c88,
		"TAmiNoko::isCollidMove": 0x800f1d60,
		"TAmiNokoManager::~TAmiNokoManager": 0x800f1dec,
		"Enemy::__sinit_amiNoko_cpp": 0x800f1e60,
		"__sinit_amiNoko_cpp": 0x800f1e60,
		"TNerveBGKLaunchName::~TNerveBGKLaunchName": 0x800f216c,
		"TNerveBGKLaunchName::execute": 0x800f21c8,
		"TNerveBGKAppear::~TNerveBGKAppear": 0x800f22ec,
		"TNerveBGKLaunchGoro::execute": 0x800f2348,
		"TNerveBGKSleep::~TNerveBGKSleep": 0x800f251c,
		"TNerveBGKLaunchGoro::~TNerveBGKLaunchGoro": 0x800f2578,
		"TNerveBGKDive::execute": 0x800f25d4,
		"TNerveBGKDive::~TNerveBGKDive": 0x800f27dc,
		"TNerveBGKDie::execute": 0x800f2838,
		"TNerveBGKDie::~TNerveBGKDie": 0x800f2c44,
		"TNerveBGKAwakeDamage::execute": 0x800f2ca0,
		"TNerveBGKWait::~TNerveBGKWait": 0x800f2ea0,
		"TNerveBGKWait2::~TNerveBGKWait2": 0x800f2efc,
		"TNerveBGKAwakeDamage::~TNerveBGKAwakeDamage": 0x800f2f58,
		"TNerveBGKSleepDamage::execute": 0x800f2fb4,
		"TNerveBGKSleepDamage::~TNerveBGKSleepDamage": 0x800f3188,
		"TNerveBGKWait2::execute": 0x800f31e4,
		"TNerveBGKWait::execute": 0x800f35a8,
		"TNerveBGKAppear::execute": 0x800f3b68,
		"TNerveBGKSleep::execute": 0x800f3e00,
		"TBiancoGateKeeper::perform": 0x800f40f4,
		"TBiancoGateKeeper::controlCollision": 0x800f4444,
		"TBiancoGateKeeper::emitParticles": 0x800f45c0,
		"emitParticles": 0x800f45c0,
		"TBiancoGateKeeper::getBasNameTable": 0x800f477c,
		"TBiancoGateKeeper::isDamageFogSituation": 0x800f4788,
		"isDamageFogSituation": 0x800f4788,
		"TBiancoGateKeeper::isHeadHitActive": 0x800f48f4,
		"isHeadHitActive": 0x800f48f4,
		"TBiancoGateKeeper::getRumblePow": 0x800f49e0,
		"getRumblePow": 0x800f49e0,
		"TBiancoGateKeeper::launchNamekuri": 0x800f4abc,
		"launchNamekuri": 0x800f4abc,
		"TBiancoGateKeeper::changeBck": 0x800f4db8,
		"TBiancoGateKeeper::kill": 0x800f5074,
		"TBiancoGateKeeper::init": 0x800f50b0,
		"TBiancoGateKeeper::TBiancoGateKeeper": 0x800f5810,
		"TBiancoGateKeeperManager::createModelData": 0x800f5dfc,
		"TBiancoGateKeeperManager::load": 0x800f5e30,
		"TBiancoGateKeeperManager::initJParticle": 0x800f5f6c,
		"TBiancoGateKeeperManager::TBiancoGateKeeperManager": 0x800f60f0,
		"TGateKeeperBase::perform": 0x800f612c,
		"TGateKeeperBase::receiveMessage": 0x800f6264,
		"TGateKeeperBase::kill": 0x800f6304,
		"TGKHitObj::perform": 0x800f6314,
		"TGKHitObj::receiveMessage": 0x800f63a0,
		"TBGKMtxCalc::~TBGKMtxCalc": 0x800f6560,
		"TBiancoGateKeeperManager::~TBiancoGateKeeperManager": 0x800f660c,
		"Enemy::__sinit_gatekeeper_cpp": 0x800f66f4,
		"__sinit_gatekeeper_cpp": 0x800f66f4,
		"TBossHanachan::emitCamShake_": 0x800f6a24,
		"emitCamShake_": 0x800f6a24,
		"TBossHanachan::emitOneTimeSandPillar_": 0x800f6cb8,
		"emitOneTimeSandPillar_": 0x800f6cb8,
		"TBossHanachan::emitParticle_": 0x800f6dec,
		"TBossHanachan::staticLoadParticle": 0x800f7200,
		"staticLoadParticle": 0x800f7200,
		"Enemy::__sinit_BossHanachanEffect_cpp": 0x800f7534,
		"__sinit_BossHanachanEffect_cpp": 0x800f7534,
		"TEggGenManager::~TEggGenManager": 0x800f7830,
		"TEggGenManager::load": 0x800f7894,
		"TEggGenManager::createModelData": 0x800f7900,
		"TEggGenManager::TEggGenManager": 0x800f7934,
		"TEggGenerator::control": 0x800f7970,
		"TEggGenerator::init": 0x800f79e8,
		"TEggGenerator::TEggGenerator": 0x800f7ad8,
		"TNerveSealDie::~TNerveSealDie": 0x800f7ba8,
		"TNerveSealDie::execute": 0x800f7c04,
		"TNerveSealSleep::~TNerveSealSleep": 0x800f7df0,
		"TNerveSealWait::execute": 0x800f7e4c,
		"TNerveSealWait::~TNerveSealWait": 0x800f7f88,
		"TNerveSealSleep::execute": 0x800f7fe4,
		"TSealManager::load": 0x800f8110,
		"TSealManager::createModelData": 0x800f8130,
		"TSealManager::TSealManager": 0x800f8164,
		"TSeal::perform": 0x800f81a0,
		"TSeal::calcRootMatrix": 0x800f82c4,
		"TSeal::receiveMessage": 0x800f8368,
		"TSeal::init": 0x800f8568,
		"TSeal::TSeal": 0x800f8840,
		"TSealManager::~TSealManager": 0x800f8898,
		"Enemy::__sinit_seal_cpp": 0x800f8968,
		"__sinit_seal_cpp": 0x800f8968,
		"TBGPolDrop::perform": 0x800f8cd8,
		"TBGPolDrop::launch": 0x800f8f0c,
		"TBGPolDrop::move": 0x800f8f68,
		"TBGPolDrop::TBGPolDrop": 0x800f91b8,
		"Enemy::__sinit_bgpoldrop_cpp": 0x800f92d4,
		"__sinit_bgpoldrop_cpp": 0x800f92d4,
		"TBGTentacle::~TBGTentacle": 0x800f95d8,
		"TBGTentacle::perform": 0x800f964c,
		"TBGTentacle::resetAllNodes": 0x800f99cc,
		"resetAllNodes": 0x800f99cc,
		"TBGTentacle::calcAttackGuideAnm": 0x800f9b40,
		"calcAttackGuideAnm": 0x800f9b40,
		"TBGTentacle::decideAtkColExists": 0x800f9fc0,
		"decideAtkColExists": 0x800f9fc0,
		"TBGTentacle::calcAtkParticleAndSE": 0x800fa180,
		"calcAtkParticleAndSE": 0x800fa180,
		"TBGTentacle::decideOwnState": 0x800fa610,
		"decideOwnState": 0x800fa610,
		"TBGTentacle::moveConstraint": 0x800fa940,
		"moveConstraint": 0x800fa940,
		"TBGTentacle::moveNode": 0x800fadcc,
		"moveNode": 0x800fadcc,
		"TBGTentacle::changeStateAndFixNodes": 0x800fb72c,
		"changeStateAndFixNodes": 0x800fb72c,
		"TBGTentacle::setAttackTarget": 0x800fb9f8,
		"setAttackTarget": 0x800fb9f8,
		"TBGTentacle::beatNode": 0x800fbe64,
		"beatNode": 0x800fbe64,
		"TBGTentacle::TBGTentacle": 0x800fc000,
		"TBGTentacle::TNode::calcPosition": 0x800fc670,
		"calcPosition": 0x800fc670,
		"TBGTentacle::TNode::calcVelocity": 0x800fc9b8,
		"TBGTentacle::TNode::TNode": 0x800fcda0,
		"TBGAttackHit::perform": 0x800fcdd4,
		"TBGTakeHit::perform": 0x800fd1e8,
		"TBGTakeHit::receiveMessage": 0x800fd91c,
		"TBGTakeHit::moveRequest": 0x800fda80,
		"TBGTakeHit::getTakingMtx": 0x800fdd68,
		"TBGTentacle::TTentacleParams::TTentacleParams": 0x800fe52c,
		"Enemy::__sinit_bgtentacle_cpp": 0x800feae0,
		"__sinit_bgtentacle_cpp": 0x800feae0,
		"TEffectEnemy::setDeadAnm": 0x800fef10,
		"TEffectEnemy::sendAttackMsgToMario": 0x800fef8c,
		"TEffectEnemy::behaveToWater": 0x800ff010,
		"TEffectEnemy::reset": 0x800ff050,
		"TEffectEnemy::perform": 0x800ff070,
		"TEffectEnemy::forceKill": 0x800ff1c0,
		"TEffectEnemy::kill": 0x800ff2e8,
		"TEffectEnemy::setMActorAndKeeper": 0x800ff338,
		"TEffectEnemy::init": 0x800ff3a4,
		"TEffectEnemy::TEffectEnemy": 0x800ff3dc,
		"TEffectEnemyManager::initSetEnemies": 0x800ff428,
		"TEffectEnemyManager::createEnemyInstance": 0x800ff42c,
		"TEffectEnemyManager::loadAfter": 0x800ff490,
		"TEffectEnemyManager::load": 0x800ff4b0,
		"TEffectEnemyManager::~TEffectEnemyManager": 0x800ff508,
		"Enemy::__sinit_effectEnemy_cpp": 0x800ff57c,
		"__sinit_effectEnemy_cpp": 0x800ff57c,
		"TNerveHauntLegHaunt::~TNerveHauntLegHaunt": 0x800ff880,
		"TNerveHauntLegHaunt::execute": 0x800ff8dc,
		"THauntLeg::getTakingMtx": 0x800ffbd0,
		"THauntLeg::getBasNameTable": 0x800ffc70,
		"THauntLeg::isCollidMove": 0x800ffc7c,
		"THauntLeg::attackToMario": 0x800ffdd0,
		"THauntLeg::setDeadAnm": 0x800ffe20,
		"THauntLeg::setRunAnm": 0x800ffe88,
		"THauntLeg::setWalkAnm": 0x800ffeb8,
		"THauntLeg::setWaitAnm": 0x800ffee8,
		"THauntLeg::setGenerateAnm": 0x800fff18,
		"THauntLeg::calcRootMatrix": 0x800fff48,
		"THauntLeg::reset": 0x80100350,
		"THauntLeg::setMActorAndKeeper": 0x80100384,
		"THauntLeg::init": 0x801003f0,
		"THauntedObject::receiveMessage": 0x8010055c,
		"THauntLegManager::createModelData": 0x801005b0,
		"THauntLegManager::initSetEnemies": 0x801005e4,
		"THauntLegManager::createEnemyInstance": 0x801007a8,
		"THauntLegManager::load": 0x8010081c,
		"THauntLegManager::THauntLegManager": 0x80100874,
		"Enemy::HauntLegCallback": 0x801008b8,
		"HauntLegCallback": 0x801008b8,
		"THauntLegManager::~THauntLegManager": 0x80100b48,
		"Enemy::__sinit_hauntLeg_cpp": 0x80100bbc,
		"__sinit_hauntLeg_cpp": 0x80100bbc,
		"TAreaCylinderManager::~TAreaCylinderManager": 0x80100ec8,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::erase": 0x80100fd4,
		"JGadget::TList<P13TAreaCylinder,Q27JGadget28TAllocator<P13TAreaCylinder>>::iterator::iterator": 0x80101040,
		"TAreaCylinderManager::perform": 0x80101048,
		"TAreaCylinderManager::getCylinderContains": 0x8010104c,
		"getCylinderContains": 0x8010104c,
		"TAreaCylinderManager::contain": 0x80101114,
		"contain": 0x80101114,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::insert": 0x801011e0,
		"TAreaCylinder::perform": 0x80101298,
		"TAreaCylinder::load": 0x8010129c,
		"TAreaCylinder::TAreaCylinder": 0x801014f8,
		"TAreaCylinder::~TAreaCylinder": 0x80101574,
		"TNerveWireTrapGoWait::~TNerveWireTrapGoWait": 0x801015e8,
		"TNerveWireTrapGoWait::execute": 0x80101644,
		"TNerveWireTrapWait::execute": 0x8010169c,
		"TNerveWireTrapWait::~TNerveWireTrapWait": 0x801016c0,
		"TNerveWireTrapSearch::execute": 0x8010171c,
		"TNerveWireTrapSearch::~TNerveWireTrapSearch": 0x801019a4,
		"TNerveWireTrapOnewayMoveEnd::execute": 0x80101a00,
		"TNerveWireTrapOnewayMoveEnd::~TNerveWireTrapOnewayMoveEnd": 0x80101aec,
		"TNerveWireTrapOnewayMove::execute": 0x80101b48,
		"TNerveWireTrapOnewayMoveStart::~TNerveWireTrapOnewayMoveStart": 0x80101ed8,
		"TNerveWireTrapOnewayMove::~TNerveWireTrapOnewayMove": 0x80101f34,
		"TNerveWireTrapOnewayMoveStart::execute": 0x80101f90,
		"TNerveWireTrapReturnMove::execute": 0x8010204c,
		"TNerveWireTrapReturnMove::~TNerveWireTrapReturnMove": 0x80102234,
		"TWireTrapManager::createModelData": 0x80102290,
		"TWireTrapManager::load": 0x801022c4,
		"TWireTrapManager::TWireTrapManager": 0x801023d4,
		"TWireTrap::getWireBinder": 0x80102410,
		"getWireBinder": 0x80102410,
		"TWireTrap::getNerveFromMode": 0x80102418,
		"getNerveFromMode": 0x80102418,
		"TWireTrap::getWireDir": 0x8010253c,
		"getWireDir": 0x8010253c,
		"TWireTrap::checkHitActors": 0x80102548,
		"TWireBinder::getDir": 0x80102ae8,
		"getDir": 0x80102ae8,
		"TWireTrap::moveObject": 0x80102af0,
		"TWireTrap::calcRootMatrix": 0x80102bc0,
		"TWireTrap::kill": 0x801031f8,
		"TWireTrap::receiveMessage": 0x80103300,
		"TWireTrap::load": 0x8010350c,
		"TWireTrap::init": 0x8010373c,
		"TWireTrap::TWireTrap": 0x801038e4,
		"TWireTrapManager::~TWireTrapManager": 0x80103934,
		"Enemy::__sinit_wireTrap_cpp": 0x80103a04,
		"__sinit_wireTrap_cpp": 0x80103a04,
		"TBossHanachanPartsBase::getBasNameTable": 0x80103d08,
		"TNerveRocketWait::~TNerveRocketWait": 0x80103d1c,
		"TNerveRocketWait::execute": 0x80103d78,
		"TNerveRocketFly::execute": 0x80103dc8,
		"TNerveRocketFly::~TNerveRocketFly": 0x80104060,
		"TNerveRocketPossessedNozzle::execute": 0x801040bc,
		"TNerveRocketPossessedNozzle::~TNerveRocketPossessedNozzle": 0x80104358,
		"TRocket::getBasNameTable": 0x801043b4,
		"TRocket::isAttack": 0x801043c0,
		"TRocket::isCollidMove": 0x8010444c,
		"TRocket::getGravityY": 0x80104554,
		"TRocket::setDeadAnm": 0x801045ec,
		"TRocket::bind": 0x801046d8,
		"TRocket::behaveToWater": 0x80104920,
		"TRocket::attackToMario": 0x8010494c,
		"TRocket::reset": 0x80104a78,
		"TRocket::setMActorAndKeeper": 0x80104b58,
		"TRocket::calcRootMatrix": 0x80104bc4,
		"TRocket::init": 0x80104f90,
		"TRocket::load": 0x80105058,
		"TRocket::TRocket": 0x801050b8,
		"TRocketManager::perform": 0x80105108,
		"TRocketManager::createModelData": 0x801051bc,
		"TRocketManager::initSetEnemies": 0x801051f0,
		"TRocketManager::createEnemyInstance": 0x80105354,
		"TRocketManager::loadAfter": 0x801053bc,
		"TRocketManager::load": 0x801053dc,
		"TRocketManager::TRocketManager": 0x80105508,
		"TRocketManager::~TRocketManager": 0x801055dc,
		"TRocketManager::clipEnemies": 0x80105650,
		"Enemy::__sinit_rocket_cpp": 0x80105654,
		"__sinit_rocket_cpp": 0x80105654,
		"TNerveKazekunHitWater::~TNerveKazekunHitWater": 0x80105958,
		"TNerveKazekunHitWater::execute": 0x801059b4,
		"TNerveKazekunDisappear::~TNerveKazekunDisappear": 0x80105b18,
		"TNerveKazekunHitWater::theNerve": 0x80105b74,
		"TNerveKazekunWait::execute": 0x80105bd8,
		"TNerveKazekunSearch::~TNerveKazekunSearch": 0x80105cc4,
		"TNerveKazekunWait::~TNerveKazekunWait": 0x80105d20,
		"TNerveKazekunDisappear::execute": 0x80105d7c,
		"TNerveKazekunAttack::execute": 0x80105eb8,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::getQuat": 0x8010644c,
		"TNerveKazekunAttack::theNerve": 0x8010670c,
		"TNerveKazekunAttack::~TNerveKazekunAttack": 0x80106770,
		"TNerveKazekunPreAttack::execute": 0x801067cc,
		"TNerveKazekunPreAttack::theNerve": 0x80106a04,
		"TNerveKazekunPreAttack::~TNerveKazekunPreAttack": 0x80106a68,
		"TNerveKazekunTurn::execute": 0x80106ac4,
		"TNerveKazekunTurn::~TNerveKazekunTurn": 0x80106cfc,
		"TNerveKazekunAppear::execute": 0x80106d58,
		"TNerveKazekunAppear::~TNerveKazekunAppear": 0x80106e70,
		"TNerveKazekunSearch::execute": 0x80106ecc,
		"TKazekunManager::createModelData": 0x80106fd8,
		"TKazekunManager::load": 0x8010700c,
		"TKazekunManager::TKazekunManager": 0x801070a0,
		"TKazekunParams::TKazekunParams": 0x801070dc,
		"TKazekun::doAttackPose": 0x801073dc,
		"doAttackPose": 0x801073dc,
		"TKazekun::flyAroundMario": 0x80107900,
		"flyAroundMario": 0x80107900,
		"TKazekun::setDeadAnm": 0x80107c94,
		"TKazekun::isCollidMove": 0x80107ce4,
		"TKazekun::attackToMario": 0x80107cec,
		"TKazekun::getBasNameTable": 0x80107dd4,
		"TKazekun::behaveToWater": 0x80107de0,
		"TKazekun::bind": 0x80107f34,
		"TKazekun::calcRootMatrix": 0x80107f68,
		"TKazekun::reset": 0x801081ac,
		"TKazekun::init": 0x80108224,
		"TKazekun::TKazekun": 0x80108428,
		"Enemy::SMS_CalcToDirMatrix": 0x80108480,
		"SMS_CalcToDirMatrix": 0x80108480,
		"TKazekunManager::~TKazekunManager": 0x801086bc,
		"Enemy::__sinit_Kazekun_cpp": 0x801087b4,
		"__sinit_Kazekun_cpp": 0x801087b4,
		"TBossMantaManager::~TBossMantaManager": 0x80108ab8,
		"TBossMantaParams::TBossMantaParams": 0x80108b1c,
		"TBossMantaManager::spawn": 0x80108e64,
		"spawn": 0x80108e64,
		"TBossMantaManager::createEnemies": 0x80109060,
		"TBossMantaManager::setupEfbAlpha": 0x801091b4,
		"setupEfbAlpha": 0x801091b4,
		"TBossMantaManager::perform": 0x80109468,
		"TBossMantaManager::updateMantaEscape": 0x801094fc,
		"updateMantaEscape": 0x801094fc,
		"TBossMantaManager::drawMantaShadow": 0x80109654,
		"drawMantaShadow": 0x80109654,
		"TBossMantaManager::createEnemyInstance": 0x80109d04,
		"TBossMantaManager::createModelData": 0x80109d4c,
		"TBossMantaManager::loadAfter": 0x80109d80,
		"TBossMantaManager::load": 0x80109f2c,
		"TBossMantaManager::TBossMantaManager": 0x80109f98,
		"TBossMantaAdditionalCollision::perform": 0x8010a06c,
		"TBossMantaAdditionalCollision::receiveMessage": 0x8010a20c,
		"TBossMantaAdditionalCollisionSet::update": 0x8010a24c,
		"TBossMantaAdditionalCollisionSet::adapt": 0x8010a42c,
		"adapt": 0x8010a42c,
		"TBossMantaAdditionalCollisionSet::TBossMantaAdditionalCollisionSet": 0x8010a500,
		"TBossMantaManager::TMantaMessageState::update": 0x8010a668,
		"TNerveMantaSpawn::~TNerveMantaSpawn": 0x8010a81c,
		"TBossMantaManager::TMantaBattleState::update": 0x8010a878,
		"TBossManta::updateAttractor": 0x8010ab8c,
		"updateAttractor": 0x8010ab8c,
		"TBossManta::getPolluteRadius": 0x8010b25c,
		"getPolluteRadius": 0x8010b25c,
		"TNerveMantaMove::~TNerveMantaMove": 0x8010b2d8,
		"TBossManta::calcRootMatrix": 0x8010b334,
		"TBossManta::control": 0x8010b454,
		"TBossManta::initNthGeneration": 0x8010b6b0,
		"initNthGeneration": 0x8010b6b0,
		"TNerveMantaAppearDemo::~TNerveMantaAppearDemo": 0x8010be58,
		"TBossManta::receiveMessage": 0x8010beb4,
		"TBossManta::collidedWithWater": 0x8010bf04,
		"collidedWithWater": 0x8010bf04,
		"TNerveMantaDeath::~TNerveMantaDeath": 0x8010c390,
		"TNerveMantaHitWater::~TNerveMantaHitWater": 0x8010c3ec,
		"TBossManta::moveObject": 0x8010c448,
		"TBossManta::init": 0x8010c628,
		"TBossManta::getIntoGraphVec": 0x8010c8bc,
		"getIntoGraphVec": 0x8010c8bc,
		"TBossManta::TBossManta": 0x8010cb4c,
		"TNerveMantaAppearDemo::execute": 0x8010cbe8,
		"TNerveMantaDeath::execute": 0x8010cd94,
		"TNerveMantaSpawn::execute": 0x8010ce80,
		"TNerveMantaHitWater::execute": 0x8010d01c,
		"TNerveMantaMove::execute": 0x8010d20c,
		"TNerveMantaHitWater::theNerve": 0x8010dbc0,
		"TBossManta::drawObject": 0x8010dd14,
		"TBossManta::reset": 0x8010dd18,
		"Enemy::__sinit_bossManta_cpp": 0x8010dd1c,
		"__sinit_bossManta_cpp": 0x8010dd1c,
		"TWireBinder::~TWireBinder": 0x8010e028,
		"TWireBinder::isEndWire": 0x8010e08c,
		"isEndWire": 0x8010e08c,
		"TWireBinder::isOnWire": 0x8010e0f4,
		"isOnWire": 0x8010e0f4,
		"TWireBinder::getDirAtPos": 0x8010e1c8,
		"getDirAtPos": 0x8010e1c8,
		"TWireBinder::bind": 0x8010e304,
		"TMapWireManager::getWire": 0x8010e5bc,
		"getWire": 0x8010e5bc,
		"TWireBinder::init": 0x8010e5cc,
		"TNerveYumboFreeze::~TNerveYumboFreeze": 0x8010e6d8,
		"TNerveYumboFreeze::execute": 0x8010e734,
		"TNerveYumboDancing::~TNerveYumboDancing": 0x8010e864,
		"TNerveYumboAttack::execute": 0x8010e8c0,
		"TNerveYumboAppearing::~TNerveYumboAppearing": 0x8010eaf0,
		"TNerveYumboAttack::theNerve": 0x8010eb4c,
		"TNerveYumboAttack::~TNerveYumboAttack": 0x8010ebb0,
		"TNerveYumboAppearing::execute": 0x8010ec0c,
		"TNerveYumboHiding::execute": 0x8010ee3c,
		"TNerveYumboHiding::theNerve": 0x8010efe8,
		"TNerveYumboHiding::~TNerveYumboHiding": 0x8010f04c,
		"TNerveYumboDancing::execute": 0x8010f0a8,
		"TYumbo::getBasNameTable": 0x8010f358,
		"TYumboManager::createModelData": 0x8010f364,
		"TYumboManager::load": 0x8010f398,
		"TYumboManager::TYumboManager": 0x8010f564,
		"TYumbo::attackToMario": 0x8010f5a8,
		"TYumbo::doKeepDistance": 0x8010f654,
		"TYumbo::setDeadAnm": 0x8010f6e4,
		"TYumbo::shotSeeds": 0x8010f714,
		"shotSeeds": 0x8010f714,
		"TYumbo::behaveToWater": 0x8010fc0c,
		"TYumbo::perform": 0x8010fd64,
		"TYumbo::moveObject": 0x8010fde4,
		"TYumbo::receiveMessage": 0x8010ffe8,
		"TYumbo::reset": 0x801100f0,
		"TYumbo::init": 0x801100f4,
		"TYumbo::TYumbo": 0x80110330,
		"TYumboSeed::perform": 0x80110380,
		"TYumboSeed::init": 0x80110584,
		"TYumboManager::~TYumboManager": 0x801106dc,
		"Enemy::__sinit_yunbo_cpp": 0x801107d4,
		"__sinit_yunbo_cpp": 0x801107d4,
		"TKoopaJrSubmarineManager::~TKoopaJrSubmarineManager": 0x80110ae0,
		"TKoopaJrSubmarineManager::createEnemyInstance": 0x80110b44,
		"TKoopaJrSubmarineManager::loadAfter": 0x80110b8c,
		"TKoopaJrSubmarineManager::load": 0x80110bc0,
		"TKoopaJrSubmarineManager::createModelData": 0x80110c2c,
		"TKoopaJrSubmarineManager::TKoopaJrSubmarineManager": 0x80110c60,
		"TNerveKoopaJrSubmarineLaunchKiller::execute": 0x80110c9c,
		"TNerveKoopaJrSubmarineLaunchKiller::~TNerveKoopaJrSubmarineLaunchKiller": 0x80110d00,
		"TNerveKoopaJrSubmarineCannonOpenClose::execute": 0x80110d5c,
		"TNerveKoopaJrSubmarineCannonOpenClose::~TNerveKoopaJrSubmarineCannonOpenClose": 0x80110dc4,
		"TNerveKoopaJrSubmarineWait::execute": 0x80110e20,
		"TNerveKoopaJrSubmarineWait::~TNerveKoopaJrSubmarineWait": 0x80110ea8,
		"TKoopaJrSubmarine::checkNerve": 0x80110f04,
		"checkNerve": 0x80110f04,
		"TNerveKoopaJrWait::~TNerveKoopaJrWait": 0x8011127c,
		"JGeometry::TUtil<float><float>::mod": 0x801112d8,
		"TKoopaJrSubmarine::makeRoundVelocity": 0x80111334,
		"makeRoundVelocity": 0x80111334,
		"TKoopaJrSubmarine::makeRelativeAngle": 0x80111610,
		"makeRelativeAngle": 0x80111610,
		"TKoopaJrSubmarine::getBasNameTable": 0x80111808,
		"TKoopaJrSubmarine::makeKillerVelocity": 0x80111810,
		"makeKillerVelocity": 0x80111810,
		"TKoopaJrSubmarine::launchKiller": 0x80111f1c,
		"TKoopaJrSubmarine::appearShineKiller": 0x80112054,
		"appearShineKiller": 0x80112054,
		"TKoopaJrSubmarine::receiveMessage": 0x80112198,
		"TKoopaJrSubmarine::calcRootMatrix": 0x80112218,
		"TKoopaJrSubmarine::bind": 0x801126a4,
		"TKoopaJrSubmarine::moveSwing": 0x80112798,
		"moveSwing": 0x80112798,
		"TKoopaJrSubmarine::makeCollisionPositions": 0x80112a70,
		"makeCollisionPositions": 0x80112a70,
		"TKoopaJrSubmarine::perform": 0x80112b4c,
		"TKoopaJrSubmarine::resetKoopaJrSubmarine": 0x80112cec,
		"resetKoopaJrSubmarine": 0x80112cec,
		"TKoopaJrSubmarine::reset": 0x80112e10,
		"TKoopaJrSubmarine::init": 0x80112e44,
		"TKoopaJrSubmarine::TKoopaJrSubmarine": 0x8011328c,
		"TKoopaJrManager::createEnemyInstance": 0x80113300,
		"TKoopaJrManager::loadAfter": 0x80113308,
		"TKoopaJrManager::load": 0x80113364,
		"TKoopaJrManager::createModelData": 0x801133bc,
		"TKoopaJrManager::TKoopaJrManager": 0x801133f0,
		"TNerveKoopaJrYahoo::execute": 0x8011342c,
		"TNerveKoopaJrYahoo::~TNerveKoopaJrYahoo": 0x801134bc,
		"TNerveKoopaJrLaunch::execute": 0x80113518,
		"TNerveKoopaJrLaunch::~TNerveKoopaJrLaunch": 0x801135a8,
		"TNerveKoopaJrDemo::execute": 0x80113604,
		"TNerveKoopaJrDemo::~TNerveKoopaJrDemo": 0x80113678,
		"TNerveKoopaJrDamage::execute": 0x801136d4,
		"TNerveKoopaJrDamage::theNerve": 0x80113770,
		"TNerveKoopaJrDamage::~TNerveKoopaJrDamage": 0x801137d4,
		"TNerveKoopaJrWait::execute": 0x80113830,
		"TKoopaJr::checkNerveKillerHit": 0x801138dc,
		"checkNerveKillerHit": 0x801138dc,
		"TKoopaJr::checkNerveKillerLaunchFast": 0x80113a08,
		"checkNerveKillerLaunchFast": 0x80113a08,
		"TKoopaJr::checkNerveKillerLaunchNormal": 0x80113c2c,
		"checkNerveKillerLaunchNormal": 0x80113c2c,
		"TSpineBase<TLiveActor>::pushNerve": 0x80113e50,
		"pushNerve": 0x80113e50,
		"TKoopaJr::receiveMessage": 0x80113ea4,
		"TKoopaJr::getBasNameTable": 0x801140a4,
		"TKoopaJr::calcRootMatrix": 0x801140b0,
		"TKoopaJr::perform": 0x801141ac,
		"TKoopaJr::reset": 0x8011467c,
		"TKoopaJr::init": 0x801146e8,
		"TKoopaJr::TKoopaJr": 0x80114930,
		"TCallbackHitActor::receiveMessage": 0x801149a4,
		"TKoopaJrSubmarineParams::TKoopaJrSubmarineParams": 0x801149d4,
		"TKoopaJrParams::TKoopaJrParams": 0x80114f40,
		"TDirectionCalc::d2r": 0x80115140,
		"d2r": 0x80115140,
		"TDirectionCalc::absDirection": 0x80115154,
		"absDirection": 0x80115154,
		"TDirectionCalc::calcTurnDirection": 0x801151f8,
		"calcTurnDirection": 0x801151f8,
		"TDirectionCalc::calcNearerDirection": 0x801152fc,
		"calcNearerDirection": 0x801152fc,
		"TKoopaJrManager::~TKoopaJrManager": 0x8011545c,
		"Enemy::__sinit_koopajr_cpp": 0x801155b0,
		"__sinit_koopajr_cpp": 0x801155b0,
		"TNerveKumokunPreFly::~TNerveKumokunPreFly": 0x801158c4,
		"TNerveKumokunPreFly::execute": 0x80115920,
		"TNerveKumokunFly::~TNerveKumokunFly": 0x80115a5c,
		"TNerveKumokunFly::execute": 0x80115ab8,
		"TBGCheckData::getNormal": 0x80115ef4,
		"getNormal": 0x80115ef4,
		"TNerveKumokunPostFreeze::execute": 0x80115efc,
		"TNerveKumokunSearch::~TNerveKumokunSearch": 0x801160bc,
		"TNerveKumokunPostFreeze::~TNerveKumokunPostFreeze": 0x80116118,
		"TNerveKumokunFreeze::execute": 0x80116174,
		"TNerveKumokunFreeze::~TNerveKumokunFreeze": 0x801163e4,
		"TNerveKumokunWait::execute": 0x80116440,
		"JGeometry::TQuat4<float><float>::rotate": 0x80116844,
		"rotate": 0x80116844,
		"JGeometry::TVec3<float><float>::negate": 0x801168dc,
		"negate": 0x801168dc,
		"JGeometry::TVec4<float><float>::xyz": 0x80116904,
		"xyz": 0x80116904,
		"TKumokun::getQuat": 0x8011692c,
		"TNerveKumokunWait::theNerve": 0x80116934,
		"TNerveKumokunWait::~TNerveKumokunWait": 0x80116998,
		"TNerveKumokunSearch::execute": 0x801169f4,
		"TNerveKumokunPreWalk::~TNerveKumokunPreWalk": 0x80116fcc,
		"TNerveKumokunSearch::theNerve": 0x8011703c,
		"TNerveKumokunPostWalk::execute": 0x801170a0,
		"TNerveKumokunPostWalk::theNerve": 0x80117260,
		"TNerveKumokunPostWalk::~TNerveKumokunPostWalk": 0x801172c4,
		"TNerveKumokunWalk::execute": 0x80117320,
		"TNerveKumokunWalk::~TNerveKumokunWalk": 0x80117524,
		"TNerveKumokunPreWalk::execute": 0x80117580,
		"TNerveKumokunPreWalk::theNerve": 0x8011775c,
		"TKumokunManager::createModelData": 0x801177c0,
		"TKumokunManager::load": 0x801177f4,
		"TKumokunManager::TKumokunManager": 0x801179dc,
		"TKumokun::getPlaneNormal": 0x80117a18,
		"getPlaneNormal": 0x80117a18,
		"TKumokun::isCollidMove": 0x80117a54,
		"TKumokun::doKeepDistance": 0x80117a5c,
		"TKumokun::isAttack": 0x80117dfc,
		"TKumokun::isOnSamePlaneWithMario": 0x80117f8c,
		"isOnSamePlaneWithMario": 0x80117f8c,
		"TKumokun::rotateGoalDirToLocal": 0x80118310,
		"rotateGoalDirToLocal": 0x80118310,
		"TKumokun::decideTargetAtDir": 0x80118454,
		"decideTargetAtDir": 0x80118454,
		"TKumokun::attackToMario": 0x8011877c,
		"TKumokun::calcRootMatrix": 0x8011893c,
		"TKumokun::setDeadAnm": 0x80118cd4,
		"TKumokun::changeBck": 0x80118f14,
		"TKumokun::behaveToWater": 0x8011901c,
		"TKumokun::receiveMessage": 0x801190c8,
		"TKumokun::control": 0x8011954c,
		"TKumokun::moveObject": 0x80119594,
		"TKumokun::bindOnFlying": 0x80119678,
		"bindOnFlying": 0x80119678,
		"TKumokun::checkOnMovingRoof": 0x80119934,
		"checkOnMovingRoof": 0x80119934,
		"TKumokun::checkOnMovingFloor": 0x80119ccc,
		"checkOnMovingFloor": 0x80119ccc,
		"TKumokun::checkOnMovingWall": 0x80119f60,
		"checkOnMovingWall": 0x80119f60,
		"TKumokun::bind": 0x8011a2d4,
		"TKumokun::reset": 0x8011a9c8,
		"TKumokun::initAttachPlane": 0x8011a9cc,
		"initAttachPlane": 0x8011a9cc,
		"TKumokun::init": 0x8011ade4,
		"TKumokun::getBasNameTable": 0x8011afc4,
		"TKumokun::TKumokun": 0x8011b03c,
		"TSolidStack<char_const*>::~TSolidStack": 0x8011b0cc,
		"TWallAtGraph::init": 0x8011b118,
		"JGeometry::TPartition3<float><float>::TPartition3": 0x8011b438,
		"TPartition3": 0x8011b438,
		"TKumokunManager::~TKumokunManager": 0x8011b43c,
		"TKoopaManager::~TKoopaManager": 0x8011b554,
		"TKoopaManager::loadAfter": 0x8011b5b8,
		"TKoopaManager::load": 0x8011b710,
		"TKoopaManager::createModelData": 0x8011bd0c,
		"TKoopaManager::createEnemyInstance": 0x8011bd40,
		"TKoopaManager::TKoopaManager": 0x8011bd48,
		"TKoopa::calcRootMatrix": 0x8011bd84,
		"TKoopa::receiveMessage": 0x8011c090,
		"TKoopa::perform": 0x8011c0b0,
		"TNerveKoopaTumble::~TNerveKoopaTumble": 0x8011c574,
		"TNerveKoopaTurn::~TNerveKoopaTurn": 0x8011c5e0,
		"TKoopa::reset": 0x8011c63c,
		"TKoopa::getBasNameTable": 0x8011c720,
		"TKoopa::init": 0x8011c72c,
		"TNerveKoopaProvoke::~TNerveKoopaProvoke": 0x8011cb68,
		"TKoopa::loadAfter": 0x8011cbc4,
		"TKoopa::load": 0x8011cde4,
		"TKoopa::TKoopa": 0x8011ce04,
		"TKoopa::updateAnmSound": 0x8011ce6c,
		"TKoopa::fall": 0x8011cf34,
		"fall": 0x8011cf34,
		"TNerveKoopaFall::~TNerveKoopaFall": 0x8011cfcc,
		"TKoopa::getTargetDir": 0x8011d028,
		"getTargetDir": 0x8011d028,
		"TKoopa::stagger": 0x8011d124,
		"stagger": 0x8011d124,
		"TNerveKoopaStagger::~TNerveKoopaStagger": 0x8011d418,
		"TNerveKoopaGetShowered::~TNerveKoopaGetShowered": 0x8011d474,
		"TNerveKoopaGetDown::~TNerveKoopaGetDown": 0x8011d4d0,
		"TNerveKoopaFlame::~TNerveKoopaFlame": 0x8011d52c,
		"TKoopa::getShowered": 0x8011d598,
		"getShowered": 0x8011d598,
		"TNerveKoopaWait::~TNerveKoopaWait": 0x8011d9d8,
		"TKoopa::effectsTumble": 0x8011da44,
		"effectsTumble": 0x8011da44,
		"TKoopa::getDown": 0x8011daf0,
		"getDown": 0x8011daf0,
		"TKoopa::allowsLaunch": 0x8011de38,
		"allowsLaunch": 0x8011de38,
		"TKoopa::getNeckFocus": 0x8011ded0,
		"getNeckFocus": 0x8011ded0,
		"TKoopa::isFlaming": 0x8011e1bc,
		"isFlaming": 0x8011e1bc,
		"TKoopa::getFlameDirRate": 0x8011e204,
		"getFlameDirRate": 0x8011e204,
		"TKoopa::changeAnm": 0x8011e364,
		"changeAnm": 0x8011e364,
		"TKoopa::setUpHitActors": 0x8011e444,
		"TKoopa::getFlameDirDegree": 0x8011f2b0,
		"getFlameDirDegree": 0x8011f2b0,
		"TKoopaBody::attack_": 0x8011f30c,
		"TKoopaBody::receiveMessage": 0x8011f384,
		"TKoopaHead::attack_": 0x8011f638,
		"TKoopaHead::receiveMessage": 0x8011f6b0,
		"TKoopaHand::attack_": 0x8011f9c8,
		"TKoopaHand::receiveMessage": 0x8011fa04,
		"TKoopaFlame::attack_": 0x8011fa0c,
		"TKoopaFlame::receiveMessage": 0x8011fad0,
		"TKoopaFlame::control": 0x8011faec,
		"TKoopaParts::perform": 0x8011fbdc,
		"TKoopaParts::control": 0x8011fc74,
		"TKoopaParts::TKoopaParts": 0x8011fc78,
		"TNerveKoopaGetDown::execute": 0x8011fdd0,
		"TNerveKoopaGetShowered::execute": 0x80120158,
		"TNerveKoopaStagger::execute": 0x80120254,
		"TNerveKoopaProvoke::execute": 0x80120350,
		"TNerveKoopaFlame::execute": 0x801204b8,
		"TNerveKoopaTurnR::~TNerveKoopaTurnR": 0x80120f6c,
		"TNerveKoopaTurnL::~TNerveKoopaTurnL": 0x80120fd8,
		"TEnemyManager::getSaveParam": 0x80121044,
		"TNerveKoopaFall::execute": 0x8012105c,
		"TNerveKoopaTumble::execute": 0x80121130,
		"TNerveKoopaWait::execute": 0x801212e4,
		"TNerveKoopaTurnR::execute": 0x80121bc0,
		"TNerveKoopaTurnL::execute": 0x80121d50,
		"Enemy::__sinit_Koopa_cpp": 0x801221c4,
		"__sinit_Koopa_cpp": 0x801221c4,
		"TNerveKukkuRecoverGraph::~TNerveKukkuRecoverGraph": 0x801224f0,
		"TNerveKukkuRecoverGraph::execute": 0x8012254c,
		"TNerveKukkuGraphWander::~TNerveKukkuGraphWander": 0x801226b8,
		"TNerveKukkuPostFall::execute": 0x80122714,
		"TNerveKukkuPostFall::theNerve": 0x80122850,
		"TNerveKukkuPostFall::~TNerveKukkuPostFall": 0x801228b4,
		"TNerveKukkuFall::execute": 0x80122910,
		"TNerveKukkuFall::theNerve": 0x80122ba8,
		"TNerveKukkuFall::~TNerveKukkuFall": 0x80122c0c,
		"TNerveKukkuGraphWander::execute": 0x80122c68,
		"TKukku::getBasNameTable": 0x80123050,
		"TKukkuManager::createModelData": 0x8012305c,
		"TKukkuManager::load": 0x80123090,
		"TKukkuManager::TKukkuManager": 0x80123330,
		"TKukku::setAfterDeadEffect": 0x8012336c,
		"TKukku::setDeadAnm": 0x801233b8,
		"TKukku::dropCoins": 0x801233f8,
		"dropCoins": 0x801233f8,
		"TKukku::calcMomentum": 0x80123838,
		"calcMomentum": 0x80123838,
		"TKukku::updateRotation": 0x80123954,
		"updateRotation": 0x80123954,
		"TKukku::behaveToWater": 0x80123b9c,
		"TKukku::perform": 0x80123d4c,
		"TKukku::bind": 0x80123dcc,
		"TKukku::calcRootMatrix": 0x80123dec,
		"TKukku::control": 0x801241c4,
		"TKukku::receiveMessage": 0x801241fc,
		"TKukku::reset": 0x8012428c,
		"TKukku::init": 0x801242bc,
		"TKukku::TKukku": 0x80124538,
		"TKukkuBall::perform": 0x80124584,
		"TKukkuBall::init": 0x80124828,
		"TKukkuManager::~TKukkuManager": 0x801249cc,
		"Enemy::__sinit_Kukku_cpp": 0x80124ac4,
		"__sinit_Kukku_cpp": 0x80124ac4,
		"TNerveAmenboHitWater::~TNerveAmenboHitWater": 0x80124dd0,
		"TNerveAmenboHitWater::execute": 0x80124e2c,
		"TNerveAmenboSearch::~TNerveAmenboSearch": 0x801250c4,
		"TNerveAmenboWalk::execute": 0x80125120,
		"TNerveAmenboWalk::~TNerveAmenboWalk": 0x80125478,
		"TNerveAmenboPreAttack::execute": 0x801254d4,
		"TNerveAmenboPreAttack::~TNerveAmenboPreAttack": 0x80125654,
		"TNerveAmenboTurn::execute": 0x801256b0,
		"TNerveAmenboTurn::~TNerveAmenboTurn": 0x80125970,
		"TNerveAmenboSearch::execute": 0x801259cc,
		"JGeometry::TVec4<float><float>::operator_=": 0x80125f60,
		"TAmenbo::getQuat": 0x80125f84,
		"TAmenbo::getBasNameTable": 0x80125f9c,
		"TAmenboManager::createModelData": 0x80125fa8,
		"TAmenboManager::load": 0x80125fdc,
		"TAmenboManager::TAmenboManager": 0x80126250,
		"TAmenbo::deactivateJumpBase": 0x8012628c,
		"deactivateJumpBase": 0x8012628c,
		"TAmenbo::isFindOutMario": 0x8012632c,
		"isFindOutMario": 0x8012632c,
		"TAmenbo::changeByJuice": 0x801264b0,
		"TAmenbo::setDeadAnm": 0x80126500,
		"TAmenbo::attackToMario": 0x80126550,
		"TAmenbo::doKeepDistance": 0x80126634,
		"TAmenbo::isCollidMove": 0x80126708,
		"TAmenbo::forceKill": 0x80126718,
		"TAmenbo::calcRootMatrix": 0x80126798,
		"TAmenbo::behaveToWater": 0x801268f8,
		"TAmenbo::receiveMessage": 0x801269c4,
		"TMapCollisionBase::isSetUp": 0x80126a14,
		"isSetUp": 0x80126a14,
		"TAmenbo::perform": 0x80126a44,
		"TAmenbo::control": 0x80126ad0,
		"TAmenbo::bind": 0x80126ec4,
		"TAmenbo::kill": 0x8012719c,
		"TAmenbo::reset": 0x801271cc,
		"TAmenbo::init": 0x801271d0,
		"TAmenbo::TAmenbo": 0x80127430,
		"TAmenbo::EffectOnJoint::EffectOnJoint": 0x801274a4,
		"TAmenboManager::~TAmenboManager": 0x8012752c,
		"TBathtubPeachManager::~TBathtubPeachManager": 0x801275a8,
		"TBathtubPeachManager::load": 0x8012760c,
		"TBathtubPeachManager::createModelData": 0x80127784,
		"TBathtubPeachManager::createEnemyInstance": 0x801277b8,
		"TBathtubPeachManager::TBathtubPeachManager": 0x801277c0,
		"TBathtubPeach::calcRootMatrix": 0x801277fc,
		"TBathtubPeach::receiveMessage": 0x801278a8,
		"TBathtubPeach::getRootJointMtx": 0x801278c8,
		"TBathtubPeach::perform": 0x801278ec,
		"TBathtubPeach::reset": 0x8012790c,
		"TBathtubPeach::init": 0x80127a40,
		"TNervePeachEscape::~TNervePeachEscape": 0x80127afc,
		"TBathtubPeach::getBasNameTable": 0x80127b58,
		"TBathtubPeach::TBathtubPeach": 0x80127b64,
		"TNervePeachEscape::execute": 0x80127bdc,
		"JGeometry::TVec2<float><float>::dot": 0x80128108,
		"TNervePeachStagger::~TNervePeachStagger": 0x80128124,
		"TNervePeachStagger::execute": 0x80128180,
		"Enemy::__sinit_BathtubPeach_cpp": 0x801282e8,
		"__sinit_BathtubPeach_cpp": 0x801282e8,
		"TBathtubKillerManager::~TBathtubKillerManager": 0x801285ec,
		"TBathtubKillerManager::createEnemyInstance": 0x80128660,
		"TBathtubKillerManager::createModelData": 0x801286d4,
		"TBathtubKillerManager::countActiveKillers": 0x80128708,
		"countActiveKillers": 0x80128708,
		"TBathtubKillerManager::loadAfter": 0x80128774,
		"TBathtubKillerManager::load": 0x80128890,
		"TBathtubKillerManager::TBathtubKillerManager": 0x801288fc,
		"TNerveBathtubKillerExplosion::execute": 0x80128938,
		"TNerveBathtubKillerExplosion::theNerve": 0x80128ad4,
		"TNerveBathtubKillerExplosion::~TNerveBathtubKillerExplosion": 0x80128b38,
		"TNerveBathtubKillerBreak::execute": 0x80128b94,
		"TNerveBathtubKillerBreak::theNerve": 0x80128cb0,
		"TNerveBathtubKillerBreak::~TNerveBathtubKillerBreak": 0x80128d14,
		"TNerveBathtubKillerStraight::execute": 0x80128d70,
		"TNerveBathtubKillerStraight::~TNerveBathtubKillerStraight": 0x80128f00,
		"TNerveBathtubKillerChaseStraight::execute": 0x80128f5c,
		"TNerveBathtubKillerChase::~TNerveBathtubKillerChase": 0x8012939c,
		"TNerveBathtubKillerChaseStraight::~TNerveBathtubKillerChaseStraight": 0x801293f8,
		"TNerveBathtubKillerChase::execute": 0x80129454,
		"TNerveBathtubKillerWander::execute": 0x801297e4,
		"TNerveBathtubKillerWander::~TNerveBathtubKillerWander": 0x80129b9c,
		"TBathtubKiller::isAboided": 0x80129bf8,
		"isAboided": 0x80129bf8,
		"TBathtubKiller::getBasNameTable": 0x80129f3c,
		"TBathtubKiller::behaveToWater": 0x80129f48,
		"TBathtubKiller::isCollidMove": 0x8012a060,
		"TBathtubKiller::attackToMario": 0x8012a48c,
		"TBathtubKiller::receiveMessage": 0x8012a620,
		"TBathtubKiller::calcRootMatrix": 0x8012a88c,
		"TBathtubKiller::getGravityY": 0x8012a91c,
		"TBathtubKiller::makeQuat": 0x8012a94c,
		"makeQuat": 0x8012a94c,
		"TBathtubKiller::moveChasing": 0x8012af48,
		"moveChasing": 0x8012af48,
		"TBathtubKiller::makeInitialVelocity": 0x8012b1a4,
		"makeInitialVelocity": 0x8012b1a4,
		"TBathtubKiller::perform": 0x8012b548,
		"TBathtubKiller::bind": 0x8012b9d4,
		"TBathtubKiller::generateItemBathtubKiller": 0x8012bdc0,
		"generateItemBathtubKiller": 0x8012bdc0,
		"TBathtubKiller::resetBathtubKiller": 0x8012c04c,
		"resetBathtubKiller": 0x8012c04c,
		"TBathtubKiller::reset": 0x8012c3b4,
		"TBathtubKiller::setMActorAndKeeper": 0x8012c424,
		"TBathtubKiller::init": 0x8012c594,
		"TBathtubKiller::TBathtubKiller": 0x8012c614,
		"TBathtubKillerParams::TBathtubKillerParams": 0x8012c660,
		"Enemy::__sinit_BathtubKiller_cpp": 0x8012ce0c,
		"__sinit_BathtubKiller_cpp": 0x8012ce0c,
		"TCoasterKillerManager::~TCoasterKillerManager": 0x8012d110,
		"TCoasterKillerManager::createEnemyInstance": 0x8012d184,
		"TCoasterKillerManager::createModelData": 0x8012d2b8,
		"TCoasterKillerManager::loadAfter": 0x8012d2ec,
		"TCoasterKillerManager::load": 0x8012d320,
		"TCoasterKillerManager::TCoasterKillerManager": 0x8012d444,
		"TNerveCoasterKillerExplosion::execute": 0x8012d488,
		"TNerveCoasterKillerExplosion::~TNerveCoasterKillerExplosion": 0x8012d608,
		"TCoasterKiller::setDeadAnm": 0x8012d664,
		"TCoasterKiller::setNormalFlyAnm": 0x8012d718,
		"TCoasterKiller::getBasNameTable": 0x8012d76c,
		"TCoasterKiller::behaveToWater": 0x8012d778,
		"TCoasterKiller::isCollidMove": 0x8012d890,
		"TCoasterKiller::attackToMario": 0x8012dabc,
		"TCoasterKiller::setMActorAndKeeper": 0x8012dbf0,
		"TCoasterKiller::perform": 0x8012dd44,
		"TCoasterKiller::reset": 0x8012deac,
		"TCoasterKiller::init": 0x8012defc,
		"TNerveCoasterEnemyWander::~TNerveCoasterEnemyWander": 0x8012e03c,
		"TCoasterKiller::TCoasterKiller": 0x8012e098,
		"TNerveCoasterEnemyWander::execute": 0x8012e0f8,
		"TCoasterEnemy::setWalkAnm": 0x8012e230,
		"TCoasterEnemy::setNormalFlyAnm": 0x8012e25c,
		"TCoasterEnemy::calcRootMatrix": 0x8012e260,
		"TCoasterEnemy::moveCoaster": 0x8012e2f0,
		"moveCoaster": 0x8012e2f0,
		"TCoasterEnemy::makeCoasterGoalPath": 0x8012e9a0,
		"makeCoasterGoalPath": 0x8012e9a0,
		"TCoasterEnemy::getGravityY": 0x8012e9dc,
		"TCoasterEnemy::perform": 0x8012e9e4,
		"TCoasterEnemy::reset": 0x8012ea10,
		"TCoasterEnemy::bind": 0x8012ea60,
		"TCoasterEnemy::moveObject": 0x8012eb3c,
		"TCoasterEnemy::init": 0x8012eb5c,
		"Enemy::__sinit_coasterkiller_cpp": 0x8012ece0,
		"__sinit_coasterkiller_cpp": 0x8012ece0,
		"TNerveDebuTelesaWait::~TNerveDebuTelesaWait": 0x8012efec,
		"TNerveDebuTelesaWait::execute": 0x8012f048,
		"TDebuTelesaManager::clipEnemies": 0x8012f098,
		"TDebuTelesaManager::createModelData": 0x8012f180,
		"TDebuTelesaManager::load": 0x8012f1b4,
		"TDebuTelesaManager::TDebuTelesaManager": 0x8012f264,
		"TDebuTelesa::setDeadAnm": 0x8012f2a0,
		"TDebuTelesa::doKeepDistance": 0x8012f2d0,
		"TDebuTelesa::isCollidMove": 0x8012f2d8,
		"TDebuTelesa::attackToMario": 0x8012f2e0,
		"TDebuTelesa::behaveToWater": 0x8012f30c,
		"TDebuTelesa::getBasNameTable": 0x8012f310,
		"TDebuTelesa::receiveMessage": 0x8012f318,
		"TDebuTelesa::kill": 0x8012f3c8,
		"TDebuTelesa::calcRootMatrix": 0x8012f3e8,
		"TDebuTelesa::reset": 0x8012f4f8,
		"TDebuTelesa::init": 0x8012f4fc,
		"TDebuTelesa::TDebuTelesa": 0x8012f628,
		"TDebuTelesaManager::~TDebuTelesaManager": 0x8012f678,
		"TDebuTelesa::changeByJuice": 0x8012f770,
		"Enemy::__sinit_DebuTelesa_cpp": 0x8012f778,
		"__sinit_DebuTelesa_cpp": 0x8012f778,
		"TNerveTabePukuDrag::~TNerveTabePukuDrag": 0x8012fa7c,
		"TNerveTabePukuDrag::execute": 0x8012fad8,
		"TNerveTabePukuRecoverGraph::~TNerveTabePukuRecoverGraph": 0x8012fe38,
		"TNerveTabePukuDrag::theNerve": 0x8012fea4,
		"TNerveTabePukuDive::execute": 0x8012ff08,
		"TNerveTabePukuDive::theNerve": 0x801300cc,
		"TNerveTabePukuDive::~TNerveTabePukuDive": 0x80130130,
		"TNerveTabePukuBite::execute": 0x8013018c,
		"TNerveTabePukuBite::theNerve": 0x80130284,
		"TNerveTabePukuBite::~TNerveTabePukuBite": 0x801302e8,
		"TNerveTabePukuAttack::execute": 0x80130344,
		"TNerveTabePukuAttack::~TNerveTabePukuAttack": 0x801306d4,
		"TNerveTabePukuRecoverGraph::execute": 0x80130730,
		"TNerveTabePukuGraphWander::~TNerveTabePukuGraphWander": 0x80130934,
		"TNerveTabePukuRecoverGraph::theNerve": 0x80130990,
		"TNerveTabePukuFound::execute": 0x801309f4,
		"TNerveTabePukuFound::~TNerveTabePukuFound": 0x80130c9c,
		"TNerveTabePukuGraphWander::execute": 0x80130cf8,
		"TTabePukuManager::createModelData": 0x80130ee0,
		"TTabePukuManager::load": 0x80130f14,
		"TTabePukuManager::TTabePukuManager": 0x80131150,
		"TTabePuku::swimTo": 0x8013118c,
		"swimTo": 0x8013118c,
		"TTabePuku::doKeepDistance": 0x801319a0,
		"TTabePuku::isFindMario": 0x80131aac,
		"TTabePuku::forceKill": 0x80131acc,
		"TTabePuku::behaveToWater": 0x80131ad0,
		"TTabePuku::attackToMario": 0x80131ad4,
		"TTabePuku::getBasNameTable": 0x80131cac,
		"TTabePuku::getTakingMtx": 0x80131cb8,
		"TTabePuku::receiveMessage": 0x80131e3c,
		"TTabePuku::calcRootMatrix": 0x80131e78,
		"TTabePuku::bind": 0x80132038,
		"TTabePuku::control": 0x801321e4,
		"TTabePuku::perform": 0x80132330,
		"TTabePuku::reset": 0x80132394,
		"TTabePuku::init": 0x801323a0,
		"TTabePuku::TTabePuku": 0x80132550,
		"TTPHitActor::bind": 0x801325a0,
		"TTPHitActor::updateTerrainCollsion": 0x80132840,
		"updateTerrainCollsion": 0x80132840,
		"TTPHitActor::receiveMessage": 0x801329e4,
		"TTPHitActor::init": 0x80132a14,
		"TTabePukuManager::~TTabePukuManager": 0x80132b04,
		"Enemy::__sinit_TabePuku_cpp": 0x80132c80,
		"__sinit_TabePuku_cpp": 0x80132c80,
		"TBathtubBinder::float_": 0x80132fa4,
		"float_": 0x80132fa4,
		"TBathtubBinder::bind": 0x80133420,
		"TBathtubBinder::init": 0x80133458,
		"TBathtubBinder::~TBathtubBinder": 0x80133580,
		"TBathtubBinder::TBathtubBinder": 0x801335e4,
		"CPolarSubCamera::execGroundCheck_": 0x800203a0,
		"execGroundCheck_": 0x800203a0,
		"CPolarSubCamera::execRoofCheck_": 0x800204f0,
		"execRoofCheck_": 0x800204f0,
		"CPolarSubCamera::execWallCheck_": 0x80020634,
		"execWallCheck_": 0x80020634,
		"CPolarSubCamera::isNeedWallCheck_": 0x80020868,
		"isNeedWallCheck_": 0x80020868,
		"CPolarSubCamera::isNeedRoofCheck_": 0x80020928,
		"isNeedRoofCheck_": 0x80020928,
		"CPolarSubCamera::isNeedGroundCheck_": 0x800209e8,
		"isNeedGroundCheck_": 0x800209e8,
		"CPolarSubCamera::calcInHouseNo_": 0x80020b54,
		"calcInHouseNo_": 0x80020b54,
		"CPolarSubCamera::execCameraModeChangeProc_": 0x800211d8,
		"execCameraModeChangeProc_": 0x800211d8,
		"CPolarSubCamera::isChangeToParallelCameraCByMoveBG_": 0x80021bc8,
		"isChangeToParallelCameraCByMoveBG_": 0x80021bc8,
		"CPolarSubCamera::isChangeToParallelCameraByMoveBG_": 0x80021c10,
		"isChangeToParallelCameraByMoveBG_": 0x80021c10,
		"CPolarSubCamera::isChangeToCancanCamera_": 0x80021d0c,
		"isChangeToCancanCamera_": 0x80021d0c,
		"CPolarSubCamera::isChangeToBossGesoCamera_": 0x80021d38,
		"isChangeToBossGesoCamera_": 0x80021d38,
		"CPolarSubCamera::doLButtonCameraOff_": 0x80021dc8,
		"doLButtonCameraOff_": 0x80021dc8,
		"CPolarSubCamera::execFrontRotate_": 0x80021ef0,
		"execFrontRotate_": 0x80021ef0,
		"CPolarSubCamera::changeCamModeSpecifyCamMapToolAndFrame_": 0x80021fd4,
		"changeCamModeSpecifyCamMapToolAndFrame_": 0x80021fd4,
		"CPolarSubCamera::changeCamModeSpecifyCamMapTool_": 0x80022028,
		"changeCamModeSpecifyCamMapTool_": 0x80022028,
		"CPolarSubCamera::changeCamModeSpecifyFrame_": 0x800220a4,
		"changeCamModeSpecifyFrame_": 0x800220a4,
		"CPolarSubCamera::changeCamModeSub_": 0x800220d8,
		"changeCamModeSub_": 0x800220d8,
		"TTargetCamera::operator_=": 0x8002274c,
		"CPolarSubCamera::setUpFromLButtonCamera_": 0x800227e0,
		"setUpFromLButtonCamera_": 0x800227e0,
		"CPolarSubCamera::setUpToLButtonCamera_": 0x800227f0,
		"setUpToLButtonCamera_": 0x800227f0,
		"CPolarSubCamera::getCameraInbetweenFrame_": 0x80022874,
		"getCameraInbetweenFrame_": 0x80022874,
		"Camera::__sinit_CameraChange_cpp": 0x80022ba0,
		"__sinit_CameraChange_cpp": 0x80022ba0,
		"CPolarSubCamera::controlByCameraCode_": 0x80022e9c,
		"controlByCameraCode_": 0x80022e9c,
		"CPolarSubCamera::getFinalAngleZ": 0x80023090,
		"getFinalAngleZ": 0x80023090,
		"CPolarSubCamera::getOffsetAngleY": 0x800230a4,
		"getOffsetAngleY": 0x800230a4,
		"CPolarSubCamera::getOffsetAngleX": 0x800230b0,
		"getOffsetAngleX": 0x800230b0,
		"CPolarSubCamera::perform": 0x800230bc,
		"JGeometry::TUtil<float><float>::one": 0x80023544,
		"one": 0x80023544,
		"Camera::MsSqrtf": 0x8002355c,
		"MsSqrtf": 0x8002355c,
		"CPolarSubCamera::ctrlGameCamera_": 0x800235a0,
		"ctrlGameCamera_": 0x800235a0,
		"CPolarSubCamera::calcFinalPosAndAt_": 0x80023a08,
		"calcFinalPosAndAt_": 0x80023a08,
		"CPolarSubCamera::calcPosAndAt_": 0x80023b98,
		"calcPosAndAt_": 0x80023b98,
		"CPolarSubCamera::calcSlopeAngleX_": 0x80024b3c,
		"calcSlopeAngleX_": 0x80024b3c,
		"TMario::checkStatusType": 0x80024e34,
		"checkStatusType": 0x80024e34,
		"CPolarSubCamera::isMomentDefinite_": 0x80024e50,
		"isMomentDefinite_": 0x80024e50,
		"CPolarSubCamera::execInvalidAutoChase_": 0x80024ed8,
		"execInvalidAutoChase_": 0x80024ed8,
		"CPolarSubCamera::isMarioCrabWalk_": 0x80024ee8,
		"isMarioCrabWalk_": 0x80024ee8,
		"CPolarSubCamera::isMarioAimWithGun_": 0x80024f88,
		"isMarioAimWithGun_": 0x80024f88,
		"CPolarSubCamera::onMoveApproach_": 0x80025028,
		"onMoveApproach_": 0x80025028,
		"CPolarSubCamera::offMoveApproach_": 0x800250e8,
		"offMoveApproach_": 0x800250e8,
		"CPolarSubCamera::rotateY_ByStickX_": 0x800250f8,
		"rotateY_ByStickX_": 0x800250f8,
		"CPolarSubCamera::rotateX_ByStickY_": 0x80025188,
		"rotateX_ByStickY_": 0x80025188,
		"CPolarSubCamera::calcNowTargetFromPosAndAt_": 0x8002524c,
		"calcNowTargetFromPosAndAt_": 0x8002524c,
		"CPolarSubCamera::calcDistFromXRotRatio_": 0x80025390,
		"calcDistFromXRotRatio_": 0x80025390,
		"CPolarSubCamera::calcAngleXFromXRotRatio_": 0x800253c0,
		"calcAngleXFromXRotRatio_": 0x800253c0,
		"CPolarSubCamera::getUsualLookat": 0x800253f0,
		"getUsualLookat": 0x800253f0,
		"CPolarSubCamera::getToroccoMtx_": 0x8002545c,
		"getToroccoMtx_": 0x8002545c,
		"CPolarSubCamera::isNowInbetween": 0x80025474,
		"isNowInbetween": 0x80025474,
		"CPolarSubCamera::loadAfter": 0x80025494,
		"Camera::JetCoasterDemoCallBack": 0x80025cc4,
		"JetCoasterDemoCallBack": 0x80025cc4,
		"CPolarSubCamera::CPolarSubCamera": 0x80025d3c,
		"CPolarSubCamera::killHeightPan_": 0x800264e8,
		"killHeightPan_": 0x800264e8,
		"CPolarSubCamera::execHeightPan_": 0x80026514,
		"execHeightPan_": 0x80026514,
		"CPolarSubCamera::isNotHeightPanCamMode_": 0x80026760,
		"isNotHeightPanCamMode_": 0x80026760,
		"CPolarSubCamera::killHeightPanWhenChangeCamMode_": 0x800267f0,
		"killHeightPanWhenChangeCamMode_": 0x800267f0,
		"TCameraInbetween::execCameraInbetween": 0x800268e4,
		"execCameraInbetween": 0x800268e4,
		"TCameraInbetween::initCameraInbetween": 0x80026c7c,
		"initCameraInbetween": 0x80026c7c,
		"TCameraInbetween::startCameraInbetween": 0x80026d1c,
		"startCameraInbetween": 0x80026d1c,
		"TCameraInbetween::addMoveCameraAndMario": 0x80026d84,
		"TCameraInbetween::warpPosAndAt": 0x80026e6c,
		"TCameraInbetween::TCameraInbetween": 0x80026ef4,
		"TCameraKindParam::inbetweenData": 0x80026f6c,
		"inbetweenData": 0x80026f6c,
		"TCameraKindParam::copySaveParam": 0x8002748c,
		"copySaveParam": 0x8002748c,
		"Camera::CLBCalcNearNinePos": 0x80027608,
		"CLBCalcNearNinePos": 0x80027608,
		"JGeometry::TRotation3<JGeometry::TMatrix33<JGeometry::SMatrix33C<float><float>>>::setRotate": 0x80027d34,
		"Camera::CLBCalcScaleTranslateMatrix": 0x80027e88,
		"CLBCalcScaleTranslateMatrix": 0x80027e88,
		"Camera::CLBCalcRotateZXYTranslateMatrix": 0x80027ed8,
		"CLBCalcRotateZXYTranslateMatrix": 0x80027ed8,
		"Camera::CLBCalcPointInCubeRatio": 0x80028028,
		"CLBCalcPointInCubeRatio": 0x80028028,
		"Camera::CLBIsPointInCube": 0x800281fc,
		"CLBIsPointInCube": 0x800281fc,
		"Camera::CLBRotatePosAndUp": 0x800283f8,
		"CLBRotatePosAndUp": 0x800283f8,
		"Camera::CLBRevisionLookatByAngleX": 0x800288a4,
		"CLBRevisionLookatByAngleX": 0x800288a4,
		"Camera::CLBPolarToCross": 0x80028a6c,
		"CLBPolarToCross": 0x80028a6c,
		"Camera::CLBCrossToPolar": 0x80028b04,
		"CLBCrossToPolar": 0x80028b04,
		"Camera::CLBChaseSpecialDecrease": 0x80028c0c,
		"CLBChaseSpecialDecrease": 0x80028c0c,
		"Camera::CLBChaseDecrease": 0x80028c8c,
		"CLBChaseDecrease": 0x80028c8c,
		"Camera::CLBChaseAngleDecrease": 0x80028d00,
		"CLBChaseAngleDecrease": 0x80028d00,
		"Camera::CLBCalc2DFPos": 0x80028d64,
		"CLBCalc2DFPos": 0x80028d64,
		"Camera::__sinit_cameralib_cpp": 0x80028ed4,
		"__sinit_cameralib_cpp": 0x80028ed4,
		"TCameraMarioData::isMarioClimb": 0x80028ef0,
		"isMarioClimb": 0x80028ef0,
		"TCameraMarioData::isMarioLeanMirror": 0x80028f2c,
		"isMarioLeanMirror": 0x80028f2c,
		"TCameraMarioData::isMarioSlider": 0x80028f88,
		"isMarioSlider": 0x80028f88,
		"TCameraMarioData::isMarioIndoor": 0x80028ff0,
		"isMarioIndoor": 0x80028ff0,
		"TCameraMarioData::isMarioRocketing": 0x80029060,
		"isMarioRocketing": 0x80029060,
		"TCameraMarioData::isMarioGoDown": 0x800290b4,
		"isMarioGoDown": 0x800290b4,
		"TCameraMarioData::calcAndSetMarioData": 0x800290f0,
		"calcAndSetMarioData": 0x800290f0,
		"TCameraMarioData::TCameraMarioData": 0x8002925c,
		"CPolarSubCamera::ctrlLButtonCamera_": 0x80029288,
		"ctrlLButtonCamera_": 0x80029288,
		"CPolarSubCamera::getNozzleTopPos_": 0x80029498,
		"getNozzleTopPos_": 0x80029498,
		"CPolarSubCamera::calcNoticeTargetYrot_": 0x800295a8,
		"calcNoticeTargetYrot_": 0x800295a8,
		"CPolarSubCamera::execNoticeOnOffProc_": 0x800297ac,
		"execNoticeOnOffProc_": 0x800297ac,
		"CPolarSubCamera::getNoticeActor_": 0x80029870,
		"getNoticeActor_": 0x80029870,
		"CPolarSubCamera::setNoticeInfo": 0x80029ba8,
		"setNoticeInfo": 0x80029ba8,
		"CPolarSubCamera::ctrlNormalOrTowerCamera_": 0x80029e14,
		"ctrlNormalOrTowerCamera_": 0x80029e14,
		"CPolarSubCamera::calcTowerCenterPos_": 0x8002a2c8,
		"calcTowerCenterPos_": 0x8002a2c8,
		"TCamSaveKindParam::TCamSaveKindParam": 0x8002a4a0,
		"TCamSaveEx::TCamSaveEx": 0x8002b880,
		"TCamSaveJetCoaster::TCamSaveJetCoaster": 0x8002bd70,
		"TCamSaveShake::TCamSaveShake": 0x8002becc,
		"TCamSaveNotice::TCamSaveNotice": 0x8002c064,
		"TCameraShake::execShake": 0x8002c278,
		"execShake": 0x8002c278,
		"TCameraShake::keepShake": 0x8002c7d0,
		"keepShake": 0x8002c7d0,
		"TCameraShake::startShake": 0x8002ca54,
		"startShake": 0x8002ca54,
		"TCameraShake::getUseShakeData_": 0x8002cb80,
		"getUseShakeData_": 0x8002cb80,
		"TCameraShake::TCameraShake": 0x8002ce44,
		"CPolarSubCamera::ctrlTalkCamera_": 0x8002cfd8,
		"ctrlTalkCamera_": 0x8002cfd8,
		"CPolarSubCamera::makeMtxForPrevTalk": 0x8002d020,
		"makeMtxForPrevTalk": 0x8002d020,
		"CPolarSubCamera::makeMtxForTalk": 0x8002d0b8,
		"makeMtxForTalk": 0x8002d0b8,
		"TLensFlare::~TLensFlare": 0x8002d198,
		"TLensFlare::perform": 0x8002d20c,
		"TLensFlare::TLensFlare": 0x8002d848,
		"Camera::CLBEaseOutInbetween": 0x8002d990,
		"TLensGlow::~TLensGlow": 0x8002d9b4,
		"TLensGlow::perform": 0x8002da54,
		"TLensGlow::TLensGlow": 0x8002df84,
		"TSunMgr::~TSunMgr": 0x8002e2ac,
		"TSunMgr::getAddColor": 0x8002e358,
		"getAddColor": 0x8002e358,
		"TSunMgr::perform": 0x8002e388,
		"TSunMgr::load": 0x8002e534,
		"TSunMgr::TSunMgr": 0x8002e6fc,
		"Camera::__sinit_sunmgr_cpp": 0x8002e7a4,
		"__sinit_sunmgr_cpp": 0x8002e7a4,
		"TSunModel::getZBufValue": 0x8002eb28,
		"getZBufValue": 0x8002eb28,
		"TSunModel::perform": 0x8002ebc4,
		"TSunModel::calcDispRatioAndScreenPos_": 0x8002efe4,
		"calcDispRatioAndScreenPos_": 0x8002efe4,
		"Camera::CLBScreenFPosToSPos": 0x8002f108,
		"CLBScreenFPosToSPos": 0x8002f108,
		"TSunModel::calcOtherFPosFromCenterAndRadius_": 0x8002f21c,
		"calcOtherFPosFromCenterAndRadius_": 0x8002f21c,
		"TSunModel::load": 0x8002f2d8,
		"TSunModel::TSunModel": 0x8002f628,
		"JGeometry::TVec2<short><short>::TVec2": 0x8002f880,
		"Camera::SMS_IsInSameCameraCube": 0x8002f960,
		"SMS_IsInSameCameraCube": 0x8002f960,
		"Camera::SMS_IsInOtherFastCube": 0x8002fa78,
		"SMS_IsInOtherFastCube": 0x8002fa78,
		"TCubeManagerArea::isInAreaCube": 0x8002fba0,
		"isInAreaCube": 0x8002fba0,
		"TCubeManagerBase::calcPointInCubeRatio": 0x8002fcec,
		"calcPointInCubeRatio": 0x8002fcec,
		"TCubeManagerBase::isInCube": 0x8002fd38,
		"isInCube": 0x8002fd38,
		"TCubeManagerBase::getInCubeNo": 0x8002fda8,
		"getInCubeNo": 0x8002fda8,
		"TCubeManagerBase::getDataNo": 0x8002fe40,
		"getDataNo": 0x8002fe40,
		"TCubeManagerBase::perform": 0x8002fe74,
		"TCubeManagerBase::load": 0x8002fe78,
		"TCameraMapTool::calcPosAndAt": 0x80030238,
		"calcPosAndAt": 0x80030238,
		"TCameraMapTool::load": 0x8003030c,
		"TCubeStreamInfo::~TCubeStreamInfo": 0x800303e8,
		"TCubeStreamInfo::load": 0x8003045c,
		"TCubeCameraInfo::load": 0x800305fc,
		"TCubeGeneralInfo::load": 0x80030760,
		"TCubeCameraInfo::~TCubeCameraInfo": 0x80030894,
		"CPolarSubCamera::ctrlMultiPlayerCamera_": 0x8003096c,
		"ctrlMultiPlayerCamera_": 0x8003096c,
		"CPolarSubCamera::removeMultiPlayer": 0x80030ce0,
		"removeMultiPlayer": 0x80030ce0,
		"CPolarSubCamera::addMultiPlayer": 0x80030d78,
		"addMultiPlayer": 0x80030d78,
		"CPolarSubCamera::createMultiPlayer": 0x80030dd4,
		"createMultiPlayer": 0x80030dd4,
		"TMultiPlayerData::TMultiPlayerData": 0x80030e6c,
		"TCameraJetCoaster::TCameraJetCoaster": 0x80030e84,
		"CPolarSubCamera::ctrlJetCoasterCamera_": 0x80030f2c,
		"ctrlJetCoasterCamera_": 0x80030f2c,
		"Camera::__sinit_CameraJetCoaster_cpp": 0x80031a0c,
		"__sinit_CameraJetCoaster_cpp": 0x80031a0c,
		"TCameraBck::setFrame": 0x80031d08,
		"setFrame": 0x80031d08,
		"TCameraBck::updateDemo": 0x80031d7c,
		"updateDemo": 0x80031d7c,
		"TCameraBck::endDemo": 0x80031f70,
		"endDemo": 0x80031f70,
		"TCameraBck::getTotalDemoFrames": 0x80031f98,
		"getTotalDemoFrames": 0x80031f98,
		"TCameraBck::startDemo": 0x80031ff8,
		"TCameraBck::isFileExist": 0x80032038,
		"isFileExist": 0x80032038,
		"TCameraBck::TCameraBck": 0x80032060,
		"TCameraOption::moveToDown": 0x80032164,
		"moveToDown": 0x80032164,
		"TCameraOption::moveToUp": 0x8003218c,
		"moveToUp": 0x8003218c,
		"TCameraOption::moveToLoadFromTitle": 0x800321b4,
		"moveToLoadFromTitle": 0x800321b4,
		"TCameraOption::TCameraOption": 0x800321e8,
		"CPolarSubCamera::ctrlOptionCamera_": 0x8003235c,
		"ctrlOptionCamera_": 0x8003235c,
		"CPolarSubCamera::isNormalDeadDemo": 0x800326e4,
		"isNormalDeadDemo": 0x800326e4,
		"CPolarSubCamera::isHellDeadDemo": 0x80032704,
		"isHellDeadDemo": 0x80032704,
		"CPolarSubCamera::execDeadDemoProc_": 0x80032724,
		"execDeadDemoProc_": 0x80032724,
		"CPolarSubCamera::ctrlNormalDeadDemo_": 0x800327f8,
		"ctrlNormalDeadDemo_": 0x800327f8,
		"CPolarSubCamera::getRestDemoFrames": 0x8003299c,
		"getRestDemoFrames": 0x8003299c,
		"CPolarSubCamera::isSimpleDemoCamera": 0x800329a8,
		"isSimpleDemoCamera": 0x800329a8,
		"CPolarSubCamera::endDemoCamera": 0x800329f4,
		"endDemoCamera": 0x800329f4,
		"CPolarSubCamera::startDemoCamera": 0x80032b3c,
		"startDemoCamera": 0x80032b3c,
		"CPolarSubCamera::startGateDemoCamera": 0x80032c94,
		"startGateDemoCamera": 0x80032c94,
		"CPolarSubCamera::updateGateDemoCamera_": 0x80032dac,
		"updateGateDemoCamera_": 0x80032dac,
		"CPolarSubCamera::updateDemoCamera_": 0x80032e90,
		"updateDemoCamera_": 0x80032e90,
		"CPolarSubCamera::addMoveCameraAndMario": 0x800331e4,
		"CPolarSubCamera::isSlopeCameraMode": 0x800337f0,
		"isSlopeCameraMode": 0x800337f0,
		"CPolarSubCamera::isOverHipAttackSpecifyMode": 0x80033820,
		"isOverHipAttackSpecifyMode": 0x80033820,
		"CPolarSubCamera::isDefiniteCameraSpecifyMode": 0x800338cc,
		"isDefiniteCameraSpecifyMode": 0x800338cc,
		"CPolarSubCamera::isFixCameraSpecifyMode": 0x80033900,
		"isFixCameraSpecifyMode": 0x80033900,
		"CPolarSubCamera::isRailCameraSpecifyMode": 0x80033928,
		"isRailCameraSpecifyMode": 0x80033928,
		"CPolarSubCamera::isFollowCameraSpecifyMode": 0x80033930,
		"isFollowCameraSpecifyMode": 0x80033930,
		"CPolarSubCamera::isTowerCameraSpecifyMode": 0x8003396c,
		"isTowerCameraSpecifyMode": 0x8003396c,
		"CPolarSubCamera::isNormalCameraCompletely": 0x800339a0,
		"isNormalCameraCompletely": 0x800339a0,
		"CPolarSubCamera::isNormalCameraSpecifyMode": 0x80033a30,
		"isNormalCameraSpecifyMode": 0x80033a30,
		"CPolarSubCamera::isTalkCameraInbetween": 0x80033a5c,
		"isTalkCameraInbetween": 0x80033a5c,
		"CPolarSubCamera::isTalkCameraSpecifyMode": 0x80033b54,
		"isTalkCameraSpecifyMode": 0x80033b54,
		"CPolarSubCamera::isJetCoaster1stCamera": 0x80033ba0,
		"isJetCoaster1stCamera": 0x80033ba0,
		"CPolarSubCamera::isLButtonCameraInbetween": 0x80033bd4,
		"isLButtonCameraInbetween": 0x80033bd4,
		"CPolarSubCamera::isLButtonCameraSpecifyMode": 0x80033c5c,
		"isLButtonCameraSpecifyMode": 0x80033c5c,
		"CPolarSubCamera::execSecureView_": 0x80033c70,
		"execSecureView_": 0x80033c70,
		"CPolarSubCamera::calcSecureViewTarget_": 0x80033e70,
		"calcSecureViewTarget_": 0x80033e70,
		"TBoidLeader::~TBoidLeader": 0x8000566c,
		"TBoidLeader::calcForces": 0x800056e0,
		"calcForces": 0x800056e0,
		"TBoidLeader::calcGoalForce": 0x80005ab0,
		"calcGoalForce": 0x80005ab0,
		"TBoidLeader::perform": 0x80005d14,
		"TBoidLeader::setGraph": 0x80005e7c,
		"setGraph": 0x80005e7c,
		"TBoidLeader::calcBoids": 0x80005f60,
		"calcBoids": 0x80005f60,
		"JGeometry::TVec3<float><float>::div": 0x80006890,
		"div": 0x80006890,
		"TBoidLeader::TBoidLeader": 0x800068c0,
		"TBoid::TBoid": 0x80006ad0,
		"TFishoidManager::~TFishoidManager": 0x80006b60,
		"TFishoidManager::createModelData": 0x80006bcc,
		"TFishoidManager::TFishoidManager": 0x80006c00,
		"TFishoid::createRealoidActor": 0x80006c3c,
		"TFishoid::load": 0x80006e7c,
		"TFishoid::init": 0x800070a4,
		"TFishoid::perform": 0x80007218,
		"TFishoid::TFishoid": 0x800073a0,
		"TFish::init": 0x80007490,
		"TRealoid::perform": 0x800074a0,
		"TRealoid::clipBoids": 0x80007618,
		"clipBoids": 0x80007618,
		"TRealoid::loadDefault": 0x800076ec,
		"loadDefault": 0x800076ec,
		"TRealoid::TRealoid": 0x80007898,
		"TRealoidActor::getTakingMtx": 0x800078f0,
		"TRealoidActor::checkHitActors": 0x800078f8,
		"TRealoidActor::calcRootMatrix": 0x800079ec,
		"TRealoidActor::perform": 0x80007c64,
		"TRealoidActor::TRealoidActor": 0x80007cdc,
		"TAnimalBase::execWalk": 0x80008080,
		"Animal::MsClamp": 0x80008490,
		"TAnimalBase::getRotationFlyToDir": 0x800084f8,
		"getRotationFlyToDir": 0x800084f8,
		"TAnimalBase::resetRandomCurPathNode": 0x800086e8,
		"resetRandomCurPathNode": 0x800086e8,
		"TAnimalBase::perform": 0x80008904,
		"TAnimalBase::receiveMessage": 0x80008c3c,
		"TAnimalBase::calcRootMatrix": 0x80008c44,
		"TAnimalBase::loadAfter": 0x80008c48,
		"TAnimalBase::load": 0x80008c90,
		"TAnimalBase::initNoLoad_": 0x80008d30,
		"initNoLoad_": 0x80008d30,
		"TAnimalBase::init": 0x80008fcc,
		"TAnimalBase::TAnimalBase": 0x8000925c,
		"Animal::SMS_Eular2Quat": 0x800092b4,
		"SMS_Eular2Quat": 0x800092b4,
		"Animal::__sinit_AnimalBase_cpp": 0x800094d8,
		"__sinit_AnimalBase_cpp": 0x800094d8,
		"TMewManager::~TMewManager": 0x80009d04,
		"TMewManager::createModelData": 0x80009d78,
		"TMewManager::loadAfter": 0x80009dac,
		"TMewManager::load": 0x80009de8,
		"TAnimalManagerBase::clipEnemies": 0x80009e64,
		"TAnimalManagerBase::TAnimalManagerBase": 0x80009f64,
		"Animal::__sinit_AnimalManager_cpp": 0x8000a018,
		"__sinit_AnimalManager_cpp": 0x8000a018,
		"TAnimalSaveIndividual::TAnimalSaveIndividual": 0x8000a314,
		"TNerveAnimalGraphWander::~TNerveAnimalGraphWander": 0x8000a524,
		"TNerveAnimalGraphWander::execute": 0x8000a580,
		"TNerveAnimalGraphWander::theNerve": 0x8000ab30,
		"TNerveAnimalBirdLanding::~TNerveAnimalBirdLanding": 0x8000ac20,
		"TNerveAnimalBirdLanding::execute": 0x8000ac7c,
		"TNerveAnimalBirdWaitOnGround::~TNerveAnimalBirdWaitOnGround": 0x8000af30,
		"TNerveAnimalBirdGraphWander::~TNerveAnimalBirdGraphWander": 0x8000af8c,
		"TNerveAnimalBirdPreLanding::execute": 0x8000afe8,
		"TNerveAnimalBirdPreLanding::theNerve": 0x8000b258,
		"TNerveAnimalBirdPreLanding::~TNerveAnimalBirdPreLanding": 0x8000b2bc,
		"TNerveAnimalBirdComeback::execute": 0x8000b318,
		"TNerveAnimalBirdComeback::theNerve": 0x8000b5d4,
		"TNerveAnimalBirdComeback::~TNerveAnimalBirdComeback": 0x8000b638,
		"TNerveAnimalBirdChangeToCoin::execute": 0x8000b694,
		"TNerveAnimalBirdChangeToCoin::theNerve": 0x8000b7f8,
		"TNerveAnimalBirdChangeToCoin::~TNerveAnimalBirdChangeToCoin": 0x8000b85c,
		"TNerveAnimalBirdGraphWander::execute": 0x8000b8b8,
		"TNerveAnimalBirdTakeoff::execute": 0x8000bbd8,
		"TNerveAnimalBirdTakeoff::~TNerveAnimalBirdTakeoff": 0x8000bd48,
		"TNerveAnimalBirdWalkOnGround::execute": 0x8000bda4,
		"TNerveAnimalBirdWalkOnGround::theNerve": 0x8000c17c,
		"TNerveAnimalBirdWalkOnGround::~TNerveAnimalBirdWalkOnGround": 0x8000c1e0,
		"TNerveAnimalBirdActionOnGround::execute": 0x8000c23c,
		"TNerveAnimalBirdActionOnGround::theNerve": 0x8000c4f8,
		"TNerveAnimalBirdActionOnGround::~TNerveAnimalBirdActionOnGround": 0x8000c55c,
		"TNerveAnimalBirdWaitOnGround::execute": 0x8000c5b8,
		"TNerveAnimalBirdWaitOnGround::theNerve": 0x8000c860,
		"TAnimalBirdManager::createModelData": 0x8000c8c4,
		"TAnimalBirdManager::loadAfter": 0x8000c8f8,
		"TAnimalBirdManager::load": 0x8000c944,
		"TAnimalBirdManager::TAnimalBirdManager": 0x8000c9b0,
		"TAnimalBirdParams::TAnimalBirdParams": 0x8000c9ec,
		"TAnimalBird::doLanding": 0x8000cd64,
		"doLanding": 0x8000cd64,
		"TAnimalBird::doFlyToCurPathNode": 0x8000d128,
		"doFlyToCurPathNode": 0x8000d128,
		"TAnimalBird::isFindMario": 0x8000d4c4,
		"TAnimalBird::getBasNameTable": 0x8000d5cc,
		"TAnimalBird::bind": 0x8000d5d8,
		"TAnimalBird::moveObject": 0x8000d6d4,
		"TAnimalBird::calcRootMatrix": 0x8000da90,
		"TAnimalBird::receiveMessage": 0x8000db1c,
		"TAnimalBird::loadAfter": 0x8000dec0,
		"TAnimalBird::load": 0x8000df04,
		"TAnimalBird::initParams": 0x8000e058,
		"initParams": 0x8000e058,
		"TAnimalBird::init": 0x8000e1a8,
		"TAnimalBird::TAnimalBird": 0x8000e2e0,
		"TAnimalBirdManager::~TAnimalBirdManager": 0x8000e330,
		"Animal::__sinit_Bird_cpp": 0x8000e480,
		"__sinit_Bird_cpp": 0x8000e480,
		"TNerveBeeHiveReset::~TNerveBeeHiveReset": 0x8000e784,
		"TNerveBeeHiveReset::execute": 0x8000e7e0,
		"TNerveBeeHiveWait::~TNerveBeeHiveWait": 0x8000e930,
		"TNerveBeeHiveMarioWaterIn::execute": 0x8000e98c,
		"TNerveBeeHiveAttack::~TNerveBeeHiveAttack": 0x8000ec78,
		"TNerveBeeHiveMarioWaterIn::~TNerveBeeHiveMarioWaterIn": 0x8000ed18,
		"TNerveBeeHiveAttack::execute": 0x8000ed74,
		"TNerveBeeHiveBreak::execute": 0x8000f104,
		"TNerveBeeHiveBreak::~TNerveBeeHiveBreak": 0x8000f398,
		"TNerveBeeHiveFall::execute": 0x8000f3f4,
		"TNerveBeeHiveFall::~TNerveBeeHiveFall": 0x8000f678,
		"TNerveBeeHiveWait::execute": 0x8000f6d4,
		"TBeeHiveManager::createModelData": 0x8000f954,
		"TBeeHiveManager::load": 0x8000f988,
		"TBeeHiveManager::TBeeHiveManager": 0x8000fba0,
		"TBeeHive::getCenterOfGravity": 0x8000fbdc,
		"getCenterOfGravity": 0x8000fbdc,
		"TBeeHive::appearBee": 0x8000ff08,
		"appearBee": 0x8000ff08,
		"TBeeHive::doWait": 0x8000ff6c,
		"doWait": 0x8000ff6c,
		"TBeeHive::calcRootMatrix": 0x80010660,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setSQ": 0x80010810,
		"setSQ": 0x80010810,
		"TBeeHive::controlSound": 0x80010910,
		"controlSound": 0x80010910,
		"TBeeHive::controlCollision": 0x800109dc,
		"TBeeHive::bind": 0x80010a9c,
		"TBeeHive::control": 0x80010d30,
		"TBeeHive::perform": 0x80010d6c,
		"TBeeHive::receiveMessage": 0x80010dc0,
		"TBeeHive::createRealoidActor": 0x80011310,
		"TBeeHive::load": 0x80011384,
		"TBeeHive::receiveMessageFromChild": 0x80011574,
		"receiveMessageFromChild": 0x80011574,
		"TBeeHive::reset": 0x8001166c,
		"TBeeHive::init": 0x80011a14,
		"TBeeHive::TBeeHive": 0x80011b10,
		"TBee::receiveMessage": 0x80011b5c,
		"TBee::init": 0x80011c10,
		"TBeeHiveManager::~TBeeHiveManager": 0x80011cf4,
		"Animal::__sinit_BeeHive_cpp": 0x80011e78,
		"__sinit_BeeHive_cpp": 0x80011e78,
		"TButterfloidManager::~TButterfloidManager": 0x8001218c,
		"TButterfloidManager::createModelData": 0x800121f0,
		"TButterfloidManager::TButterfloidManager": 0x80012224,
		"TButterfloid::createRealoidActor": 0x80012260,
		"TButterfloid::load": 0x800122d4,
		"TButterfloid::init": 0x80012554,
		"TButterfloid::TButterfloid": 0x80012620,
		"TButterfly::receiveMessage": 0x80012684,
		"TButterfly::init": 0x80012800,
		"Runtime.PPCEABI.H::__init_cpp_exceptions_reference": 0x8036b2e0,
		"__init_cpp_exceptions_reference": 0x8036b2e0,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions_reference": 0x8036b6a4,
		"__fini_cpp_exceptions_reference": 0x8036b6a4,
		"Animal::@2234": 0x8036b7ac,
		"Animal::@2235": 0x8036b7b8,
		"Animal::@2236": 0x8036b7c4,
		"Animal::entry$2324": 0x8036b7e0,
		"entry$2324": 0x8036b7e0,
		"Animal::@2463": 0x8036b81c,
		"Animal::@2693": 0x8036b828,
		"MSound::@3445": 0x8036c0c0,
		"MSound::@3446": 0x8036c0d8,
		"MSound::@3447": 0x8036c0f0,
		"MSound::@3448": 0x8036c104,
		"MSound::@3449": 0x8036c114,
		"MSound::@3305": 0x8036c5f4,
		"MSound::@3306": 0x8036c604,
		"MSound::@3307": 0x8036c620,
		"MSound::@3308": 0x8036c638,
		"Camera::@2163": 0x8036c968,
		"Camera::@2168": 0x8036c998,
		"Camera::@1852": 0x8036ca58,
		"@1852": 0x8036ca58,
		"Camera::@1853": 0x8036ca74,
		"@1853": 0x8036ca74,
		"Camera::@1849": 0x8036cad8,
		"@1849": 0x8036cad8,
		"Enemy::@2679": 0x8036f05c,
		"Enemy::@2622": 0x8036f108,
		"Enemy::@2781": 0x8036f39c,
		"Enemy::@2782": 0x8036f3a8,
		"Enemy::@2784": 0x8036f3c0,
		"Enemy::@6720": 0x8036fe08,
		"@6720": 0x8036fe08,
		"Enemy::@6721": 0x8036fe24,
		"@6721": 0x8036fe24,
		"Enemy::@6722": 0x8036fe3c,
		"@6722": 0x8036fe3c,
		"Enemy::@4996": 0x803701e8,
		"Enemy::@5219": 0x8037020c,
		"Enemy::@5243": 0x8037022c,
		"Enemy::@5344": 0x8037037c,
		"Enemy::@2239": 0x8037048c,
		"Enemy::@2451": 0x803704d0,
		"Enemy::@2452": 0x80370508,
		"Enemy::@2453": 0x8037053c,
		"Enemy::tevColorData$3142": 0x8037081c,
		"tevColorData$3142": 0x8037081c,
		"Enemy::@7550": 0x803708e0,
		"@7550": 0x803708e0,
		"Enemy::@7734": 0x80370930,
		"@7734": 0x80370930,
		"Enemy::@7743": 0x80370968,
		"@7743": 0x80370968,
		"Enemy::@7754": 0x80370974,
		"@7754": 0x80370974,
		"Enemy::@7776": 0x8037099c,
		"@7776": 0x8037099c,
		"Enemy::@7820": 0x803709dc,
		"@7820": 0x803709dc,
		"Enemy::@7824": 0x803709f4,
		"@7824": 0x803709f4,
		"Enemy::@7827": 0x80370a04,
		"@7827": 0x80370a04,
		"Enemy::@7837": 0x80370a20,
		"@7837": 0x80370a20,
		"Enemy::@7903": 0x80370a30,
		"@7903": 0x80370a30,
		"Enemy::@7925": 0x80370aa4,
		"@7925": 0x80370aa4,
		"Enemy::@8178": 0x80370aec,
		"@8178": 0x80370aec,
		"Enemy::@2432": 0x80370cec,
		"Enemy::@2463": 0x80370d7c,
		"Enemy::@2464": 0x80370da4,
		"Enemy::@2485": 0x80370e34,
		"Enemy::xzTable$2561": 0x80370e4c,
		"xzTable$2561": 0x80370e4c,
		"Enemy::@3813": 0x80370e6c,
		"Enemy::@3647": 0x80371148,
		"Enemy::@3649": 0x80371160,
		"Enemy::@4256": 0x8037121c,
		"Enemy::@4522": 0x80371238,
		"Enemy::@4523": 0x80371254,
		"Enemy::@4524": 0x80371260,
		"Enemy::@4677": 0x803712c8,
		"Enemy::@4856": 0x80371524,
		"Enemy::@5110": 0x80371540,
		"Enemy::@5111": 0x80371554,
		"Enemy::@5112": 0x80371564,
		"Enemy::idxarray$3678": 0x80371e20,
		"idxarray$3678": 0x80371e20,
		"Enemy::entry$3710": 0x80371ed0,
		"entry$3710": 0x80371ed0,
		"Enemy::@4701": 0x80371f64,
		"Enemy::@4702": 0x80371f78,
		"Enemy::@4703": 0x80371f8c,
		"Enemy::@4709": 0x80371fb8,
		"Enemy::@5588": 0x80371ff0,
		"@5588": 0x80371ff0,
		"Enemy::@5600": 0x803721c0,
		"@5600": 0x803721c0,
		"Enemy::@5601": 0x803721e4,
		"@5601": 0x803721e4,
		"Enemy::@5602": 0x80372208,
		"@5602": 0x80372208,
		"Enemy::@5603": 0x80372230,
		"@5603": 0x80372230,
		"Enemy::@5604": 0x80372254,
		"@5604": 0x80372254,
		"Enemy::@5605": 0x8037227c,
		"@5605": 0x8037227c,
		"Enemy::@5606": 0x803722a4,
		"@5606": 0x803722a4,
		"Enemy::@5607": 0x803722cc,
		"Enemy::@5608": 0x803722f4,
		"@5608": 0x803722f4,
		"Enemy::@5609": 0x80372318,
		"@5609": 0x80372318,
		"Enemy::@5610": 0x8037233c,
		"@5610": 0x8037233c,
		"Enemy::@5611": 0x80372360,
		"@5611": 0x80372360,
		"Enemy::@5612": 0x80372384,
		"@5612": 0x80372384,
		"Enemy::@8143": 0x803723b4,
		"@8143": 0x803723b4,
		"Enemy::@8144": 0x803723c8,
		"@8144": 0x803723c8,
		"Enemy::@8148": 0x803723d4,
		"@8148": 0x803723d4,
		"Enemy::@9198": 0x803724c0,
		"@9198": 0x803724c0,
		"Enemy::@9199": 0x803724d4,
		"@9199": 0x803724d4,
		"Enemy::@9201": 0x803724e8,
		"@9201": 0x803724e8,
		"Enemy::@9203": 0x803724fc,
		"@9203": 0x803724fc,
		"Enemy::@9204": 0x80372514,
		"@9204": 0x80372514,
		"Enemy::@9206": 0x8037252c,
		"@9206": 0x8037252c,
		"Enemy::@9208": 0x80372544,
		"@9208": 0x80372544,
		"Enemy::@9209": 0x8037255c,
		"@9209": 0x8037255c,
		"Enemy::@9211": 0x80372570,
		"@9211": 0x80372570,
		"Enemy::@9213": 0x80372584,
		"@9213": 0x80372584,
		"Enemy::@9214": 0x80372598,
		"@9214": 0x80372598,
		"Enemy::@9215": 0x803725ac,
		"@9215": 0x803725ac,
		"Enemy::@9216": 0x803725b8,
		"@9216": 0x803725b8,
		"Enemy::@9217": 0x803725cc,
		"@9217": 0x803725cc,
		"Enemy::@9219": 0x803725dc,
		"@9219": 0x803725dc,
		"Enemy::@9220": 0x803725f0,
		"@9220": 0x803725f0,
		"Enemy::@9221": 0x80372604,
		"@9221": 0x80372604,
		"Enemy::@9223": 0x80372614,
		"@9223": 0x80372614,
		"Enemy::@9224": 0x80372624,
		"@9224": 0x80372624,
		"Enemy::@9225": 0x80372634,
		"@9225": 0x80372634,
		"Enemy::@9226": 0x80372644,
		"@9226": 0x80372644,
		"Enemy::@9228": 0x80372654,
		"@9228": 0x80372654,
		"Enemy::@2142": 0x80372a1c,
		"Enemy::@2383": 0x80372a98,
		"Enemy::@3396": 0x80372b78,
		"Enemy::@5203": 0x80372d74,
		"Enemy::@5292": 0x80372d84,
		"Enemy::@5300": 0x80372d90,
		"Enemy::@5301": 0x80372da4,
		"Enemy::@5404": 0x80372dd0,
		"@5404": 0x80372dd0,
		"Enemy::@5405": 0x80372de0,
		"Enemy::@5406": 0x80372df0,
		"Enemy::@7291": 0x803730d4,
		"@7291": 0x803730d4,
		"Enemy::@7292": 0x80373100,
		"@7292": 0x80373100,
		"Enemy::@7431": 0x80373148,
		"@7431": 0x80373148,
		"Enemy::@7432": 0x80373154,
		"@7432": 0x80373154,
		"Enemy::@8403": 0x8037317c,
		"@8403": 0x8037317c,
		"Enemy::@8767": 0x8037319c,
		"@8767": 0x8037319c,
		"Enemy::@8952": 0x803731b0,
		"@8952": 0x803731b0,
		"Enemy::@9152": 0x803733e0,
		"@9152": 0x803733e0,
		"Enemy::entry$3613": 0x803738e4,
		"entry$3613": 0x803738e4,
		"Enemy::entry$3618": 0x80373964,
		"entry$3618": 0x80373964,
		"Enemy::@4135": 0x803739f0,
		"Enemy::@4136": 0x80373a00,
		"Enemy::@5868": 0x80373b70,
		"Enemy::@6558": 0x80373c6c,
		"Enemy::@6559": 0x80373c78,
		"Enemy::@6560": 0x80373c88,
		"Enemy::@7227": 0x80373d24,
		"@7227": 0x80373d24,
		"Enemy::@7228": 0x80373d30,
		"@7228": 0x80373d30,
		"Enemy::@7229": 0x80373d40,
		"@7229": 0x80373d40,
		"Enemy::@7231": 0x80373d5c,
		"@7231": 0x80373d5c,
		"Enemy::@8204": 0x80373d68,
		"@8204": 0x80373d68,
		"Enemy::@8339": 0x80373ed8,
		"@8339": 0x80373ed8,
		"Enemy::@8340": 0x80373ee8,
		"@8340": 0x80373ee8,
		"Enemy::@8341": 0x80373efc,
		"@8341": 0x80373efc,
		"Enemy::@8343": 0x80373f10,
		"@8343": 0x80373f10,
		"Enemy::@4823": 0x803741ec,
		"@4823": 0x803741ec,
		"Enemy::@4902": 0x80374268,
		"Enemy::@4991": 0x803742f8,
		"Enemy::@3482": 0x80374874,
		"Enemy::entry$3481": 0x80374888,
		"entry$3481": 0x80374888,
		"Enemy::@3525": 0x80374cb0,
		"Enemy::@5220": 0x80374d0c,
		"Enemy::@6086": 0x80374d90,
		"@6086": 0x80374d90,
		"Enemy::@2488": 0x8037503c,
		"Enemy::entry$3473": 0x803751dc,
		"entry$3473": 0x803751dc,
		"Enemy::@5001": 0x803752a8,
		"Enemy::@5002": 0x803752d4,
		"Enemy::@5003": 0x803752fc,
		"Enemy::@5004": 0x80375324,
		"Enemy::@5005": 0x8037534c,
		"Enemy::@5006": 0x80375374,
		"Enemy::@5007": 0x8037539c,
		"Enemy::@7578": 0x8037545c,
		"Enemy::@7583": 0x803754a0,
		"Enemy::@7584": 0x803754b4,
		"Enemy::@5626": 0x80375740,
		"@5626": 0x80375740,
		"Enemy::@5679": 0x8037574c,
		"Enemy::@3331": 0x80375b44,
		"Enemy::@4605": 0x80375bac,
		"Enemy::@4606": 0x80375bcc,
		"Enemy::@4639": 0x80375c10,
		"Enemy::@5388": 0x80375c9c,
		"@5388": 0x80375c9c,
		"Enemy::@4425": 0x80375fa8,
		"Enemy::@2420": 0x8037607c,
		"Enemy::@2632": 0x803760c0,
		"Enemy::@2634": 0x8037612c,
		"Enemy::@5041": 0x803763f4,
		"Enemy::@5042": 0x80376408,
		"Enemy::@5043": 0x80376418,
		"Enemy::@5044": 0x8037642c,
		"Enemy::xzTable$3483": 0x803766f0,
		"xzTable$3483": 0x803766f0,
		"Enemy::@3930": 0x80376710,
		"Enemy::@6147": 0x80376808,
		"Enemy::@8534": 0x80376da0,
		"@8534": 0x80376da0,
		"Enemy::@8537": 0x80376dac,
		"@8537": 0x80376dac,
		"Enemy::@8597": 0x80376dc4,
		"@8597": 0x80376dc4,
		"Enemy::@9057": 0x80376f34,
		"@9057": 0x80376f34,
		"Enemy::entry$2585": 0x80377090,
		"entry$2585": 0x80377090,
		"Enemy::@2748": 0x803770e0,
		"Enemy::@2750": 0x803770f0,
		"Enemy::@3194": 0x803772d4,
		"Enemy::xzTable$3109": 0x80377560,
		"xzTable$3109": 0x80377560,
		"Enemy::@5160": 0x80377608,
		"Enemy::@5161": 0x8037761c,
		"Enemy::@6075": 0x803777ac,
		"@6075": 0x803777ac,
		"Enemy::@6171": 0x803778d4,
		"Enemy::@2547": 0x80377908,
		"Enemy::@2548": 0x80377938,
		"Enemy::@2549": 0x80377970,
		"Enemy::@2550": 0x803779a4,
		"Enemy::@3087": 0x80377a54,
		"Enemy::entry$3303": 0x80377aa8,
		"entry$3303": 0x80377aa8,
		"Enemy::eyeTable$3618": 0x80377b34,
		"eyeTable$3618": 0x80377b34,
		"Enemy::@7887": 0x80377d04,
		"@7887": 0x80377d04,
		"Enemy::@7888": 0x80377d14,
		"@7888": 0x80377d14,
		"Enemy::@7946": 0x80377d2c,
		"Enemy::@7947": 0x80377d54,
		"Enemy::@7948": 0x80377d7c,
		"Enemy::@7949": 0x80377da4,
		"Enemy::@7950": 0x80377dd0,
		"@7950": 0x80377dd0,
		"Enemy::@7951": 0x80377dfc,
		"@7951": 0x80377dfc,
		"Enemy::@7952": 0x80377e24,
		"@7952": 0x80377e24,
		"Enemy::@7953": 0x80377e50,
		"@7953": 0x80377e50,
		"Enemy::@8066": 0x80377f4c,
		"@8066": 0x80377f4c,
		"Enemy::@8067": 0x80377f60,
		"@8067": 0x80377f60,
		"Enemy::@8068": 0x80377f74,
		"@8068": 0x80377f74,
		"Enemy::@8069": 0x80377f88,
		"@8069": 0x80377f88,
		"Enemy::@8904": 0x8037823c,
		"@8904": 0x8037823c,
		"Enemy::@9046": 0x80378280,
		"@9046": 0x80378280,
		"Enemy::@9047": 0x803782ac,
		"@9047": 0x803782ac,
		"Enemy::@9048": 0x803782d8,
		"Enemy::@9051": 0x80378300,
		"@9051": 0x80378300,
		"Enemy::@3806": 0x80378678,
		"Enemy::@3091": 0x80378ae0,
		"Enemy::@4303": 0x80378bdc,
		"Enemy::@4305": 0x80378bf0,
		"Enemy::@4306": 0x80378c04,
		"@4306": 0x80378c04,
		"Enemy::@5669": 0x80378d14,
		"Enemy::@5670": 0x80378d2c,
		"Enemy::@5676": 0x80378d44,
		"Enemy::@5682": 0x80378d54,
		"Enemy::@5683": 0x80378d6c,
		"Enemy::@5738": 0x80378e4c,
		"@5738": 0x80378e4c,
		"Enemy::@5739": 0x80378e5c,
		"@5739": 0x80378e5c,
		"Enemy::@5740": 0x80378e6c,
		"@5740": 0x80378e6c,
		"Enemy::@2260": 0x80378e8c,
		"Enemy::entry$2763": 0x803794f0,
		"entry$2763": 0x803794f0,
		"Enemy::entry$2766": 0x80379518,
		"entry$2766": 0x80379518,
		"Enemy::entry$2770": 0x80379540,
		"entry$2770": 0x80379540,
		"Enemy::entry$2991": 0x8037a4e0,
		"entry$2991": 0x8037a4e0,
		"Enemy::entry$2257": 0x8037aae4,
		"entry$2257": 0x8037aae4,
		"Enemy::@2268": 0x8037aafc,
		"Enemy::idx$3289": 0x8037add8,
		"idx$3289": 0x8037add8,
		"Enemy::zangle$3566": 0x8037ade8,
		"zangle$3566": 0x8037ade8,
		"Enemy::zangle$3571": 0x8037adf8,
		"zangle$3571": 0x8037adf8,
		"Enemy::zangle$3577": 0x8037ae18,
		"zangle$3577": 0x8037ae18,
		"Enemy::@6640": 0x8037ae90,
		"@6640": 0x8037ae90,
		"Enemy::@6641": 0x8037ae9c,
		"@6641": 0x8037ae9c,
		"Enemy::@6643": 0x8037aeac,
		"@6643": 0x8037aeac,
		"Enemy::tevColorData1$2783": 0x8037b0d8,
		"tevColorData1$2783": 0x8037b0d8,
		"Enemy::tevColorData2$2784": 0x8037b118,
		"tevColorData2$2784": 0x8037b118,
		"Enemy::entry$2671": 0x8037b2a0,
		"entry$2671": 0x8037b2a0,
		"Enemy::@2591": 0x8037ba08,
		"Enemy::entry$2840": 0x8037ba38,
		"entry$2840": 0x8037ba38,
		"Enemy::@2774": 0x8037c55c,
		"Enemy::entry$2876": 0x8037c59c,
		"entry$2876": 0x8037c59c,
		"Enemy::entry$3159": 0x8037c85c,
		"entry$3159": 0x8037c85c,
		"Enemy::entry$3343": 0x8037c8bc,
		"entry$3343": 0x8037c8bc,
		"Enemy::@4805": 0x8037c924,
		"@4805": 0x8037c924,
		"Enemy::@6031": 0x8037cb2c,
		"Enemy::@6035": 0x8037cb58,
		"Enemy::@6037": 0x8037cb68,
		"Enemy::@6038": 0x8037cb80,
		"Enemy::@6039": 0x8037cb98,
		"Enemy::@6040": 0x8037cbb0,
		"Enemy::entry$2662": 0x8037d0a4,
		"entry$2662": 0x8037d0a4,
		"Enemy::@3397": 0x8037d4c8,
		"Enemy::entry$3396": 0x8037d4d8,
		"entry$3396": 0x8037d4d8,
		"Enemy::entry$3100": 0x8037d9a0,
		"entry$3100": 0x8037d9a0,
		"Enemy::@4520": 0x8037dae4,
		"Enemy::@4521": 0x8037daf0,
		"Enemy::@4780": 0x8037db18,
		"Enemy::@2388": 0x8037dc48,
		"Enemy::@2394": 0x8037dcb8,
		"Enemy::entry$2529": 0x8037dce8,
		"entry$2529": 0x8037dce8,
		"Enemy::@4426": 0x8037de68,
		"Enemy::entry$2978": 0x8037dfb0,
		"entry$2978": 0x8037dfb0,
		"Enemy::@3230": 0x8037e160,
		"Enemy::@3254": 0x8037e180,
		"Enemy::@5689": 0x8037e1f8,
		"Enemy::@5690": 0x8037e214,
		"Enemy::@5692": 0x8037e22c,
		"Enemy::@5694": 0x8037e23c,
		"Enemy::@2623": 0x8037e780,
		"Enemy::entry$2837": 0x8037e7bc,
		"entry$2837": 0x8037e7bc,
		"Enemy::@2574": 0x8037e948,
		"Enemy::entry$2870": 0x8037e980,
		"entry$2870": 0x8037e980,
		"Enemy::@4864": 0x8037ea58,
		"GC2D::@6887": 0x8037ed08,
		"GC2D::@6888": 0x8037ed3c,
		"GC2D::@11040": 0x8037ed58,
		"@11040": 0x8037ed58,
		"GC2D::@11685": 0x8037ed68,
		"@11685": 0x8037ed68,
		"GC2D::@11689": 0x8037ed78,
		"@11689": 0x8037ed78,
		"GC2D::@11690": 0x8037ed84,
		"@11690": 0x8037ed84,
		"GC2D::@11691": 0x8037ed94,
		"@11691": 0x8037ed94,
		"GC2D::@11906": 0x8037eda0,
		"@11906": 0x8037eda0,
		"GC2D::@11907": 0x8037edb0,
		"@11907": 0x8037edb0,
		"GC2D::@11908": 0x8037edd0,
		"@11908": 0x8037edd0,
		"GC2D::@11909": 0x8037ede4,
		"@11909": 0x8037ede4,
		"GC2D::@2726": 0x8037f0f4,
		"GC2D::@2730": 0x8037f12c,
		"GC2D::@3588": 0x8037f154,
		"GC2D::@3589": 0x8037f164,
		"GC2D::@3590": 0x8037f174,
		"GC2D::@3591": 0x8037f184,
		"GC2D::@3696": 0x8037f194,
		"GC2D::@3697": 0x8037f1b0,
		"GC2D::@4256": 0x8037f1e4,
		"GC2D::@4257": 0x8037f224,
		"GC2D::@5044": 0x8037f264,
		"GC2D::@5045": 0x8037f274,
		"GC2D::@5046": 0x8037f294,
		"GC2D::@5047": 0x8037f2b0,
		"GC2D::@5048": 0x8037f2cc,
		"GC2D::@5049": 0x8037f2e8,
		"GC2D::@5050": 0x8037f304,
		"GC2D::@5051": 0x8037f320,
		"GC2D::@5052": 0x8037f338,
		"GC2D::@5053": 0x8037f350,
		"GC2D::@3352": 0x8037f398,
		"GC2D::@3353": 0x8037f3a4,
		"GC2D::@3354": 0x8037f3bc,
		"GC2D::@6781": 0x8037f408,
		"GC2D::@6782": 0x8037f42c,
		"GC2D::@7095": 0x8037f448,
		"@7095": 0x8037f448,
		"GC2D::@7097": 0x8037f458,
		"@7097": 0x8037f458,
		"GC2D::@7098": 0x8037f464,
		"@7098": 0x8037f464,
		"GC2D::@7099": 0x8037f488,
		"GC2D::@7100": 0x8037f4a8,
		"GC2D::@7101": 0x8037f4c0,
		"GC2D::@2359": 0x8037f4f0,
		"GC2D::@2360": 0x8037f520,
		"GC2D::@2361": 0x8037f558,
		"GC2D::@2362": 0x8037f58c,
		"GC2D::@2578": 0x8037f5b0,
		"GC2D::@2579": 0x8037f5c4,
		"GC2D::@2580": 0x8037f5d4,
		"GC2D::@2581": 0x8037f5e4,
		"GC2D::@2582": 0x8037f5f4,
		"GC2D::@2583": 0x8037f608,
		"GC2D::@2584": 0x8037f61c,
		"GC2D::@2585": 0x8037f62c,
		"GC2D::@2586": 0x8037f640,
		"GC2D::@2587": 0x8037f654,
		"GC2D::@2588": 0x8037f668,
		"GC2D::@2589": 0x8037f678,
		"GC2D::@2590": 0x8037f688,
		"GC2D::@2591": 0x8037f698,
		"GC2D::@2592": 0x8037f6ac,
		"GC2D::@2593": 0x8037f6bc,
		"GC2D::@2594": 0x8037f6cc,
		"GC2D::@2595": 0x8037f6e4,
		"GC2D::@2731": 0x8037f6f8,
		"GC2D::@2759": 0x8037f714,
		"GC2D::@2760": 0x8037f724,
		"GC2D::@2761": 0x8037f738,
		"GC2D::@2762": 0x8037f74c,
		"GC2D::@2763": 0x8037f760,
		"GC2D::@2764": 0x8037f774,
		"GC2D::@2830": 0x8037f788,
		"GC2D::@7946": 0x8037f7a4,
		"GC2D::@7947": 0x8037f7b8,
		"GC2D::@7948": 0x8037f7cc,
		"GC2D::@7949": 0x8037f7e0,
		"GC2D::@8282": 0x8037f7f0,
		"@8282": 0x8037f7f0,
		"GC2D::@8405": 0x8037f804,
		"@8405": 0x8037f804,
		"GC2D::@8769": 0x8037f81c,
		"@8769": 0x8037f81c,
		"GC2D::@8770": 0x8037f838,
		"@8770": 0x8037f838,
		"GC2D::@8771": 0x8037f854,
		"@8771": 0x8037f854,
		"GC2D::@8772": 0x8037f870,
		"@8772": 0x8037f870,
		"GC2D::@8773": 0x8037f88c,
		"@8773": 0x8037f88c,
		"GC2D::@8774": 0x8037f8a8,
		"@8774": 0x8037f8a8,
		"GC2D::@8775": 0x8037f8b4,
		"@8775": 0x8037f8b4,
		"GC2D::@8776": 0x8037f8c8,
		"@8776": 0x8037f8c8,
		"GC2D::@8777": 0x8037f8dc,
		"@8777": 0x8037f8dc,
		"GC2D::@8778": 0x8037f8f0,
		"@8778": 0x8037f8f0,
		"GC2D::@8779": 0x8037f904,
		"@8779": 0x8037f904,
		"GC2D::@8780": 0x8037f918,
		"@8780": 0x8037f918,
		"GC2D::@8781": 0x8037f924,
		"@8781": 0x8037f924,
		"GC2D::@8782": 0x8037f934,
		"@8782": 0x8037f934,
		"GC2D::@8783": 0x8037f944,
		"@8783": 0x8037f944,
		"GC2D::@8784": 0x8037f954,
		"@8784": 0x8037f954,
		"GC2D::@8785": 0x8037f964,
		"@8785": 0x8037f964,
		"GC2D::@8787": 0x8037f988,
		"@8787": 0x8037f988,
		"GC2D::@1929": 0x8037f9c8,
		"GC2D::@3509": 0x8037f9d4,
		"GC2D::@3510": 0x8037f9e4,
		"GC2D::@3511": 0x8037f9f8,
		"GC2D::@3512": 0x8037fa10,
		"GC2D::@3958": 0x8037facc,
		"GC2D::@3959": 0x8037fae4,
		"GC2D::@3960": 0x8037fb04,
		"GC2D::@3963": 0x8037fb24,
		"GC2D::@3964": 0x8037fb40,
		"GC2D::@3965": 0x8037fb5c,
		"GC2D::@3966": 0x8037fb74,
		"GC2D::@2209": 0x8037fbc4,
		"GC2D::@2211": 0x8037fbec,
		"GC2D::@3082": 0x8037fe74,
		"GC2D::@4086": 0x8037ff40,
		"GC2D::@4087": 0x8037ff4c,
		"GC2D::@4088": 0x8037ff6c,
		"GC2D::@1565": 0x80380098,
		"GC2D::@1566": 0x803800b8,
		"GC2D::@1567": 0x803800d8,
		"GC2D::@1568": 0x803800f8,
		"GC2D::@1569": 0x80380118,
		"GC2D::@1001": 0x80380138,
		"@1001": 0x80380138,
		"GC2D::@1193": 0x80380150,
		"@1193": 0x80380150,
		"GC2D::@1640": 0x80380188,
		"GC2D::@1733": 0x80380198,
		"@1733": 0x80380198,
		"GC2D::@1955": 0x803801dc,
		"GC2D::@1956": 0x803801e8,
		"GC2D::@1964": 0x803801f4,
		"@unnamed@::cLanguageToggleItems": 0x8038040c,
		"cLanguageToggleItems": 0x8038040c,
		"GC2D::@2077": 0x80380420,
		"GC2D::@2078": 0x80380430,
		"GC2D::@2181": 0x80380440,
		"GC2D::@2183": 0x80380464,
		"GC2D::@2856": 0x80380484,
		"GC2D::@2857": 0x803804cc,
		"GC2D::@3897": 0x80380514,
		"GC2D::@3898": 0x80380520,
		"GC2D::@3899": 0x8038053c,
		"GC2D::@3900": 0x80380558,
		"GC2D::@3901": 0x80380574,
		"GC2D::@3902": 0x80380590,
		"GC2D::@3903": 0x803805ac,
		"GC2D::@6319": 0x803805e4,
		"@6319": 0x803805e4,
		"GC2D::@7658": 0x803805f8,
		"GC2D::@8303": 0x80380610,
		"Map::@3230": 0x80380b54,
		"Map::@3312": 0x80380b7c,
		"Map::@3313": 0x80380b98,
		"Map::@3314": 0x80380ba8,
		"Map::point_name_table$2630": 0x80380d48,
		"point_name_table$2630": 0x80380d48,
		"Map::@3022": 0x80381898,
		"Map::@3330": 0x803818bc,
		"Map::@3331": 0x803818c8,
		"Map::@3332": 0x803818e0,
		"Map::@3358": 0x80381904,
		"Map::@3359": 0x8038191c,
		"Map::@3482": 0x80381934,
		"Map::@3483": 0x8038194c,
		"Map::@3034": 0x80381e8c,
		"Map::@2995": 0x80382088,
		"Map::@2996": 0x803820a0,
		"Map::@4206": 0x80382274,
		"Map::@4352": 0x80382280,
		"Map::@4353": 0x80382298,
		"Map::@4354": 0x803822b0,
		"Map::@4355": 0x803822cc,
		"Map::@4356": 0x803822ec,
		"Map::@4357": 0x8038230c,
		"Map::@4434": 0x8038233c,
		"Map::@4435": 0x8038234c,
		"Map::@4436": 0x80382358,
		"Map::@4733": 0x80382364,
		"Map::@4826": 0x80382440,
		"Map::@4827": 0x80382450,
		"Map::@4828": 0x80382460,
		"@4828": 0x80382460,
		"Map::@4829": 0x8038246c,
		"Map::@4830": 0x80382478,
		"Map::@4831": 0x80382484,
		"MoveBG::JuiceBlock_hit_data_table": 0x80384128,
		"JuiceBlock_hit_data_table": 0x80384128,
		"MoveBG::JuiceBlock_obj_hit_info": 0x80384138,
		"JuiceBlock_obj_hit_info": 0x80384138,
		"MoveBG::entry$3271": 0x80388028,
		"entry$3271": 0x80388028,
		"MoveBG::@3475": 0x80388034,
		"MoveBG::@3478": 0x80388050,
		"MoveBG::@3479": 0x8038805c,
		"MoveBG::@3480": 0x80388068,
		"MoveBG::@3481": 0x80388074,
		"MoveBG::@3482": 0x80388084,
		"MoveBG::@3483": 0x80388090,
		"MoveBG::@3762": 0x803880a0,
		"MoveBG::@3764": 0x803880b0,
		"MoveBG::@3765": 0x803880bc,
		"MoveBG::@4156": 0x80388444,
		"MoveBG::@4157": 0x80388450,
		"MoveBG::@4158": 0x8038846c,
		"MoveBG::@4159": 0x80388488,
		"MoveBG::@4096": 0x80388920,
		"MoveBG::@4097": 0x80388940,
		"MoveBG::@4098": 0x80388958,
		"MoveBG::@4099": 0x80388974,
		"MoveBG::@4304": 0x8038898c,
		"MoveBG::@4565": 0x803889ac,
		"@4565": 0x803889ac,
		"MoveBG::@4583": 0x803889d0,
		"MoveBG::@4746": 0x803889fc,
		"MoveBG::@2694": 0x80388a3c,
		"MoveBG::@2695": 0x80388a48,
		"MoveBG::@3683": 0x80388f6c,
		"@3683": 0x80388f6c,
		"MoveBG::@3684": 0x80388f80,
		"MoveBG::@4029": 0x80388f98,
		"MoveBG::@4239": 0x80388fec,
		"MoveBG::@4293": 0x8038900c,
		"MoveBG::@2226": 0x8038902c,
		"MoveBG::@2282": 0x80389040,
		"MoveBG::@2285": 0x803890dc,
		"MoveBG::@4019": 0x80389154,
		"MoveBG::@4151": 0x80389184,
		"MoveBG::@4200": 0x803891b0,
		"MoveBG::@4624": 0x803891c0,
		"MoveBG::@5221": 0x803891d4,
		"MoveBG::@3723": 0x80389604,
		"MoveBG::@3752": 0x80389618,
		"MoveBG::@3861": 0x80389670,
		"MoveBG::@3877": 0x80389680,
		"MoveBG::@3878": 0x803896a4,
		"MoveBG::@4111": 0x803896f0,
		"MoveBG::@4113": 0x80389720,
		"MoveBG::@4114": 0x80389740,
		"MoveBG::@4115": 0x80389760,
		"MoveBG::@4603": 0x80389834,
		"@4603": 0x80389834,
		"MoveBG::@4604": 0x80389848,
		"MoveBG::@4605": 0x8038985c,
		"MoveBG::@4814": 0x80389870,
		"@4814": 0x80389870,
		"MoveBG::@4824": 0x80389888,
		"MoveBG::@4839": 0x80389898,
		"MoveBG::@4995": 0x803898ac,
		"MoveBG::@5009": 0x80389918,
		"MoveBG::@5257": 0x80389924,
		"MoveBG::@3508": 0x80389a54,
		"MoveBG::@3509": 0x80389a6c,
		"MoveBG::@3588": 0x80389b90,
		"MoveBG::@3589": 0x80389bb4,
		"MoveBG::@3705": 0x80389bd8,
		"MoveBG::@3712": 0x80389c1c,
		"MoveBG::@3863": 0x80389c9c,
		"MoveBG::@4089": 0x80389ca8,
		"MoveBG::@4296": 0x80389cb4,
		"MoveBG::@4127": 0x80389ecc,
		"MoveBG::@4128": 0x80389edc,
		"MoveBG::@2502": 0x80389fe8,
		"MoveBG::@3554": 0x8038bb10,
		"MoveBG::@3555": 0x8038bb34,
		"MoveBG::@4464": 0x8038bbf4,
		"@4464": 0x8038bbf4,
		"MoveBG::@4466": 0x8038bc04,
		"@4466": 0x8038bc04,
		"MoveBG::@4467": 0x8038bc14,
		"@4467": 0x8038bc14,
		"MoveBG::@5406": 0x8038bc40,
		"MoveBG::@5407": 0x8038bc60,
		"MoveBG::@5408": 0x8038bc80,
		"MoveBG::@5409": 0x8038bca4,
		"MoveBG::@5836": 0x8038bcc8,
		"MoveBG::@5839": 0x8038bd04,
		"MoveBG::@5961": 0x8038bd6c,
		"MoveBG::@5962": 0x8038bd80,
		"MoveBG::@5963": 0x8038bd8c,
		"MoveBG::@5964": 0x8038bd9c,
		"@5964": 0x8038bd9c,
		"MoveBG::@5965": 0x8038bdac,
		"@5965": 0x8038bdac,
		"NPC::@2618": 0x8038d590,
		"NPC::@2619": 0x8038d5a0,
		"NPC::@2620": 0x8038d5b0,
		"NPC::@2621": 0x8038d5c0,
		"NPC::@2622": 0x8038d5d0,
		"NPC::@2671": 0x8038d5e0,
		"NPC::@2674": 0x8038d5ec,
		"NPC::@2675": 0x8038d600,
		"NPC::@2712": 0x8038d618,
		"NPC::@2713": 0x8038d634,
		"NPC::@2714": 0x8038d648,
		"NPC::@2715": 0x8038d660,
		"NPC::@2716": 0x8038d670,
		"NPC::@2717": 0x8038d684,
		"NPC::@2718": 0x8038d698,
		"NPC::@2719": 0x8038d6b4,
		"NPC::@2720": 0x8038d6c4,
		"NPC::@2766": 0x8038d784,
		"NPC::@2767": 0x8038d7a4,
		"NPC::@2768": 0x8038d7b0,
		"NPC::@3121": 0x8038d7cc,
		"Strategic::@2840": 0x80394b18,
		"Strategic::@2841": 0x80394b28,
		"Strategic::@2779": 0x80394c48,
		"Strategic::@2780": 0x80394c68,
		"Strategic::@2582": 0x8039527c,
		"Strategic::@2583": 0x80395298,
		"Player::@2307": 0x8039595c,
		"Player::@2470": 0x8039596c,
		"Player::@2471": 0x80395984,
		"Player::@2472": 0x8039599c,
		"Player::@2473": 0x803959c4,
		"Player::@2474": 0x803959e0,
		"Player::@2475": 0x803959f0,
		"Player::@2429": 0x80395a00,
		"Player::@5173": 0x80396490,
		"Player::@5174": 0x8039649c,
		"Player::@5175": 0x803964ac,
		"Player::@5651": 0x803964bc,
		"Player::@5653": 0x803964d4,
		"Player::@5654": 0x803964e0,
		"@5654": 0x803964e0,
		"Player::@5655": 0x803964ec,
		"@5655": 0x803964ec,
		"Player::@5656": 0x803964f8,
		"@5656": 0x803964f8,
		"Player::@5657": 0x80396504,
		"@5657": 0x80396504,
		"Player::@5658": 0x80396510,
		"@5658": 0x80396510,
		"Player::@5659": 0x8039651c,
		"Player::@2650": 0x80396924,
		"Player::@2651": 0x8039694c,
		"Player::@2652": 0x80396974,
		"Player::@3043": 0x80396a3c,
		"Player::@2685": 0x80396bbc,
		"Player::@2687": 0x80396bc8,
		"Player::@4118": 0x80396e30,
		"Player::@4119": 0x80396e48,
		"Player::@4429": 0x80396ea0,
		"Player::@4430": 0x80396eb0,
		"Player::@4431": 0x80396ec8,
		"Player::@4436": 0x80396f18,
		"Player::@4437": 0x80396f28,
		"Player::@4438": 0x80396f40,
		"Player::@4439": 0x80396f58,
		"Player::@4483": 0x80396f64,
		"Player::@4484": 0x80396f70,
		"Player::@4485": 0x80396f94,
		"Player::@4486": 0x80396fbc,
		"Player::@4487": 0x80396fe0,
		"Player::@4488": 0x80396fec,
		"Player::@4489": 0x80397010,
		"Player::@4490": 0x8039701c,
		"@4490": 0x8039701c,
		"Player::@6089": 0x8039708c,
		"Player::@6092": 0x80397098,
		"Player::@6094": 0x803970a4,
		"Player::@6096": 0x803970b0,
		"Player::@6097": 0x803970bc,
		"Player::@6099": 0x803970c8,
		"Player::@6101": 0x803970d8,
		"Player::@6102": 0x803970e4,
		"Player::@6103": 0x803970f4,
		"@6103": 0x803970f4,
		"Player::@6104": 0x80397100,
		"@6104": 0x80397100,
		"Player::@6105": 0x8039710c,
		"@6105": 0x8039710c,
		"Player::@6106": 0x8039711c,
		"@6106": 0x8039711c,
		"Player::@6107": 0x80397128,
		"@6107": 0x80397128,
		"Player::@6108": 0x80397134,
		"@6108": 0x80397134,
		"Player::@6110": 0x80397140,
		"@6110": 0x80397140,
		"Player::@6112": 0x8039714c,
		"@6112": 0x8039714c,
		"Player::@6113": 0x80397158,
		"@6113": 0x80397158,
		"Player::@6114": 0x80397168,
		"@6114": 0x80397168,
		"Player::@6115": 0x80397174,
		"@6115": 0x80397174,
		"Player::@6116": 0x80397180,
		"@6116": 0x80397180,
		"Player::@6117": 0x80397190,
		"@6117": 0x80397190,
		"Player::@6118": 0x803971a4,
		"@6118": 0x803971a4,
		"Player::@6120": 0x803971b8,
		"@6120": 0x803971b8,
		"Player::@6121": 0x803971c4,
		"@6121": 0x803971c4,
		"Player::@6122": 0x803971d4,
		"@6122": 0x803971d4,
		"Player::@6123": 0x803971e0,
		"@6123": 0x803971e0,
		"Player::@6124": 0x803971ec,
		"@6124": 0x803971ec,
		"Player::@6126": 0x803971fc,
		"@6126": 0x803971fc,
		"Player::@6128": 0x8039720c,
		"@6128": 0x8039720c,
		"Player::@6129": 0x8039721c,
		"Player::@6131": 0x80397230,
		"Player::@6133": 0x80397244,
		"Player::@6135": 0x80397254,
		"Player::@6136": 0x80397268,
		"Player::@6137": 0x8039727c,
		"Player::@6138": 0x80397290,
		"Player::@6140": 0x803972a0,
		"Player::@2177": 0x803972bc,
		"Player::@2233": 0x803972d0,
		"Player::@2234": 0x80397300,
		"Player::@2235": 0x80397338,
		"Player::@2236": 0x8039736c,
		"Player::@4689": 0x803973e4,
		"Player::@4957": 0x8039740c,
		"Player::@4961": 0x80397430,
		"Player::@4962": 0x8039744c,
		"Player::@4963": 0x80397468,
		"Player::@4964": 0x80397480,
		"Player::@4965": 0x8039749c,
		"Player::@4975": 0x803974a8,
		"Player::@4976": 0x803974b4,
		"Player::@4978": 0x803974c0,
		"Player::@4979": 0x803974dc,
		"Player::@4980": 0x803974f8,
		"Player::@4981": 0x8039751c,
		"Player::@4982": 0x80397538,
		"Player::@4983": 0x80397558,
		"Player::@4984": 0x80397574,
		"Player::@4985": 0x80397594,
		"Player::@4986": 0x803975b4,
		"Player::@4987": 0x803975d4,
		"Player::@4991": 0x80397648,
		"Player::@4992": 0x80397664,
		"Player::@4993": 0x80397684,
		"Player::@4994": 0x803976a4,
		"Player::@4995": 0x803976c4,
		"Player::@4996": 0x803976e0,
		"Player::@4997": 0x80397700,
		"Player::@4998": 0x8039771c,
		"Player::@2237": 0x8039774c,
		"Player::@2293": 0x80397760,
		"Player::@2294": 0x80397790,
		"Player::@2759": 0x80397878,
		"Player::@2358": 0x8039791c,
		"Player::@2546": 0x80397990,
		"Player::@2547": 0x803979a4,
		"Player::@2548": 0x803979bc,
		"Player::@2549": 0x803979d0,
		"Player::@2550": 0x803979e4,
		"Player::@2552": 0x803979f4,
		"Player::@2554": 0x80397a04,
		"Player::@2581": 0x80397a24,
		"Player::@2582": 0x80397a30,
		"Player::@2584": 0x80397a3c,
		"Player::@2588": 0x80397a48,
		"Player::@2607": 0x80397a58,
		"Player::@2609": 0x80397a64,
		"Player::@2611": 0x80397a74,
		"Player::@2613": 0x80397a80,
		"Player::@2626": 0x80397a8c,
		"Player::@2754": 0x80397b80,
		"Player::@2755": 0x80397b90,
		"Player::@3073": 0x80397fcc,
		"Player::@3074": 0x80397fdc,
		"Player::@3135": 0x8039817c,
		"Player::@3136": 0x80398190,
		"Player::@3137": 0x803981a4,
		"Player::@3138": 0x803981b8,
		"Player::@3235": 0x8039832c,
		"Player::@3236": 0x8039833c,
		"Player::@3238": 0x80398348,
		"Player::@3239": 0x80398354,
		"Player::@3313": 0x803983b8,
		"Player::@3314": 0x803983c8,
		"Player::@3317": 0x803983fc,
		"Player::@3318": 0x80398410,
		"Player::@3319": 0x80398420,
		"Player::@3320": 0x8039842c,
		"Player::@3321": 0x80398438,
		"Player::@3359": 0x803984ec,
		"Player::@3361": 0x80398500,
		"Player::@3363": 0x80398518,
		"Player::@3550": 0x803986c4,
		"Player::@3551": 0x803986d4,
		"Player::@3555": 0x803986f0,
		"Player::@3556": 0x803986fc,
		"Player::@3558": 0x80398708,
		"Player::@3962": 0x80398b38,
		"Player::@4075": 0x80398e64,
		"Player::@4076": 0x80398e80,
		"Player::@4077": 0x80398e98,
		"Player::@6512": 0x80398eac,
		"@6512": 0x80398eac,
		"Player::@6513": 0x80398eb8,
		"@6513": 0x80398eb8,
		"Player::@6514": 0x80398ed4,
		"@6514": 0x80398ed4,
		"Player::@6515": 0x80398ef4,
		"@6515": 0x80398ef4,
		"Player::@4262": 0x803998f0,
		"System::@3448": 0x80399a88,
		"System::@3462": 0x80399a98,
		"System::@3701": 0x80399aa8,
		"System::@3702": 0x80399ab8,
		"System::@3703": 0x80399ac8,
		"System::@3704": 0x80399adc,
		"System::@3705": 0x80399aec,
		"System::@3706": 0x80399af8,
		"System::@3707": 0x80399b0c,
		"System::@3854": 0x8039a104,
		"System::@4323": 0x8039a138,
		"System::@4847": 0x8039a14c,
		"System::@4869": 0x8039a158,
		"System::@5607": 0x8039a188,
		"System::@5797": 0x8039a194,
		"System::@2349": 0x8039a308,
		"System::@2350": 0x8039a338,
		"System::@2351": 0x8039a370,
		"System::@2352": 0x8039a3a4,
		"System::@2688": 0x8039a3c8,
		"System::@2690": 0x8039a3d4,
		"System::@3911": 0x8039a3f8,
		"System::@3913": 0x8039a40c,
		"System::@3914": 0x8039a424,
		"System::@4272": 0x8039a4c0,
		"System::sStrMapFile": 0x8039abe8,
		"sStrMapFile": 0x8039abe8,
		"System::@2951": 0x8039ad18,
		"System::@4625": 0x8039ad24,
		"System::@4626": 0x8039ad30,
		"System::@4627": 0x8039ad48,
		"System::@4628": 0x8039ad54,
		"System::@4629": 0x8039ad64,
		"System::@4630": 0x8039ad70,
		"System::@4631": 0x8039ad80,
		"System::@4632": 0x8039ad94,
		"System::@4633": 0x8039ada8,
		"System::@5540": 0x8039b78c,
		"System::@5823": 0x8039b7a0,
		"System::@2297": 0x8039bac0,
		"System::@2301": 0x8039bb10,
		"System::@2305": 0x8039bb24,
		"System::@2306": 0x8039bb38,
		"System::@2307": 0x8039bb4c,
		"System::@2308": 0x8039bb60,
		"System::@2309": 0x8039bb74,
		"System::@2311": 0x8039bb88,
		"System::@2312": 0x8039bb9c,
		"System::@2313": 0x8039bbb0,
		"System::@2314": 0x8039bbc4,
		"System::@2315": 0x8039bbd8,
		"System::@2492": 0x8039bbec,
		"System::@2493": 0x8039bc68,
		"System::@2494": 0x8039bcd4,
		"System::@2495": 0x8039bce8,
		"System::@2496": 0x8039bd34,
		"System::@2497": 0x8039bd64,
		"System::@2498": 0x8039bdbc,
		"System::@2499": 0x8039be4c,
		"System::@2500": 0x8039bed4,
		"System::@2516": 0x8039c38c,
		"System::@2517": 0x8039c40c,
		"System::@2518": 0x8039c480,
		"System::@2519": 0x8039c4a0,
		"System::@2520": 0x8039c500,
		"System::@2521": 0x8039c52c,
		"System::@5353": 0x8039f418,
		"System::@5354": 0x8039f428,
		"System::@5355": 0x8039f434,
		"System::@5356": 0x8039f444,
		"System::@5357": 0x8039f450,
		"System::@5358": 0x8039f464,
		"System::@5359": 0x8039f484,
		"System::@5360": 0x8039f490,
		"System::@5361": 0x8039f4a0,
		"System::@5362": 0x8039f4b0,
		"System::@5363": 0x8039f4c0,
		"System::@5364": 0x8039f4cc,
		"System::@5365": 0x8039f4dc,
		"System::@5366": 0x8039f4ec,
		"System::@5367": 0x8039f500,
		"@5367": 0x8039f500,
		"System::@5368": 0x8039f50c,
		"System::@3391": 0x803a0b90,
		"System::@3392": 0x803a0ba4,
		"System::@3393": 0x803a0bb4,
		"System::@3394": 0x803a0bc8,
		"System::@3395": 0x803a0bdc,
		"System::@3396": 0x803a0bf0,
		"System::@3397": 0x803a0c04,
		"System::@3398": 0x803a0c18,
		"System::@3399": 0x803a0c30,
		"System::@2060": 0x803a0e60,
		"System::@2061": 0x803a0e70,
		"System::@2062": 0x803a0e80,
		"System::@2063": 0x803a0e8c,
		"System::@2064": 0x803a0e9c,
		"@2064": 0x803a0e9c,
		"System::@2065": 0x803a0eac,
		"System::@2066": 0x803a0ec0,
		"System::@2067": 0x803a0ecc,
		"@2067": 0x803a0ecc,
		"System::@2068": 0x803a0edc,
		"@2068": 0x803a0edc,
		"System::@2070": 0x803a0ef8,
		"System::@2071": 0x803a0f08,
		"System::@2072": 0x803a0f14,
		"System::@2073": 0x803a0f24,
		"System::@2074": 0x803a0f34,
		"System::@2075": 0x803a0f44,
		"System::@2076": 0x803a0f54,
		"System::@2077": 0x803a0f60,
		"System::@2078": 0x803a0f6c,
		"System::@2079": 0x803a0f78,
		"System::@2954": 0x803a1084,
		"System::@2955": 0x803a1094,
		"System::@2957": 0x803a10a0,
		"System::@2959": 0x803a10c0,
		"System::@2961": 0x803a10dc,
		"System::@2962": 0x803a10ec,
		"System::@2964": 0x803a10fc,
		"System::@3011": 0x803a1108,
		"System::@3012": 0x803a1118,
		"System::@3036": 0x803a1124,
		"JSystem::@1727": 0x803a1690,
		"@1727": 0x803a1690,
		"JSystem::@1728": 0x803a16a4,
		"@1728": 0x803a16a4,
		"JSystem::@114": 0x803a16c0,
		"JSystem::@447": 0x803a16ec,
		"@447": 0x803a16ec,
		"JSystem::@548": 0x803a170c,
		"@548": 0x803a170c,
		"JSystem::@1809": 0x803a1778,
		"JSystem::@1810": 0x803a178c,
		"JSystem::@1811": 0x803a17ac,
		"JSystem::@438": 0x803a17c8,
		"@438": 0x803a17c8,
		"JSystem::@439": 0x803a17dc,
		"@439": 0x803a17dc,
		"JSystem::@302": 0x803a1820,
		"JSystem::@593": 0x803a18dc,
		"@593": 0x803a18dc,
		"JSystem::@594": 0x803a1908,
		"@594": 0x803a1908,
		"JSystem::@595": 0x803a1934,
		"@595": 0x803a1934,
		"JSystem::@596": 0x803a195c,
		"@596": 0x803a195c,
		"JSystem::@597": 0x803a198c,
		"@597": 0x803a198c,
		"JSystem::@606": 0x803a19b4,
		"JSystem::@607": 0x803a19c4,
		"JSystem::@688": 0x803a19e0,
		"JSystem::@689": 0x803a1a04,
		"JSystem::@720": 0x803a1a14,
		"@720": 0x803a1a14,
		"JSystem::@721": 0x803a1a4c,
		"@721": 0x803a1a4c,
		"JSystem::@723": 0x803a1a5c,
		"@723": 0x803a1a5c,
		"JSystem::@727": 0x803a1ac0,
		"@727": 0x803a1ac0,
		"JSystem::@729": 0x803a1ad0,
		"@729": 0x803a1ad0,
		"JSystem::@799": 0x803a1b18,
		"JSystem::@800": 0x803a1b48,
		"JSystem::@801": 0x803a1b5c,
		"JSystem::@802": 0x803a1b68,
		"JSystem::@803": 0x803a1b84,
		"JSystem::@805": 0x803a1bac,
		"JSystem::@806": 0x803a1bc0,
		"JSystem::@1643": 0x803a1c10,
		"JSystem::@1644": 0x803a1c24,
		"JSystem::@288": 0x803a1c40,
		"JSystem::@305": 0x803a1ca8,
		"JSystem::@365": 0x803a1d78,
		"@365": 0x803a1d78,
		"JSystem::@366": 0x803a1d90,
		"@366": 0x803a1d90,
		"JSystem::@367": 0x803a1da4,
		"@367": 0x803a1da4,
		"JSystem::@368": 0x803a1db8,
		"@368": 0x803a1db8,
		"JSystem::@1545": 0x803a1dd8,
		"JSystem::@1558": 0x803a1e04,
		"JSystem::@1560": 0x803a1e28,
		"JSystem::@1495": 0x803a1f10,
		"@1495": 0x803a1f10,
		"JSystem::@1496": 0x803a1f24,
		"@1496": 0x803a1f24,
		"JSystem::@1497": 0x803a1f30,
		"@1497": 0x803a1f30,
		"JSystem::@1498": 0x803a1f44,
		"@1498": 0x803a1f44,
		"JSystem::@1499": 0x803a1f58,
		"@1499": 0x803a1f58,
		"JSystem::@1566": 0x803a1f98,
		"JSystem::@1567": 0x803a1fac,
		"JSystem::@1628": 0x803a1fb8,
		"JSystem::@1701": 0x803a1fe0,
		"JSystem::@1702": 0x803a2008,
		"@1702": 0x803a2008,
		"JSystem::@1709": 0x803a2054,
		"JSystem::@1710": 0x803a2074,
		"JSystem::@1711": 0x803a2090,
		"JSystem::@1722": 0x803a20ac,
		"@1722": 0x803a20ac,
		"JSystem::@1723": 0x803a20d4,
		"JSystem::@1724": 0x803a20fc,
		"@1724": 0x803a20fc,
		"JSystem::@1757": 0x803a2118,
		"JSystem::@1775": 0x803a2130,
		"@1775": 0x803a2130,
		"JSystem::@1776": 0x803a215c,
		"@1776": 0x803a215c,
		"JSystem::@1777": 0x803a216c,
		"@1777": 0x803a216c,
		"JSystem::@1778": 0x803a2180,
		"JSystem::@1795": 0x803a21a8,
		"JSystem::@2006": 0x803a21c4,
		"JSystem::@2007": 0x803a21fc,
		"JSystem::@2193": 0x803a2220,
		"JSystem::@83": 0x803a2250,
		"JSystem::@84": 0x803a2260,
		"JSystem::@321": 0x803a2280,
		"JSystem::@1454": 0x803a22d8,
		"@1454": 0x803a22d8,
		"JSystem::@914": 0x803a22e8,
		"@914": 0x803a22e8,
		"JSystem::@1249": 0x803a22f4,
		"@1249": 0x803a22f4,
		"JSystem::@1251": 0x803a2300,
		"@1251": 0x803a2300,
		"JSystem::@329": 0x803a2310,
		"JSystem::@838": 0x803a2320,
		"@838": 0x803a2320,
		"JSystem::@839": 0x803a2330,
		"@839": 0x803a2330,
		"JSystem::@885": 0x803a2358,
		"@885": 0x803a2358,
		"JSystem::@813": 0x803a23c8,
		"@813": 0x803a23c8,
		"JSystem::@999": 0x803a2428,
		"@999": 0x803a2428,
		"JSystem::@95": 0x803a2438,
		"JSystem::@96": 0x803a2448,
		"JSystem::@97": 0x803a2458,
		"JSystem::@98": 0x803a246c,
		"JSystem::@99": 0x803a247c,
		"JSystem::@110": 0x803a2490,
		"JSystem::@272": 0x803a24a8,
		"@272": 0x803a24a8,
		"JSystem::@289": 0x803a24c8,
		"JSystem::halftofull$376": 0x803a24dc,
		"halftofull$376": 0x803a24dc,
		"JSystem::@258": 0x803a25a0,
		"@258": 0x803a25a0,
		"JSystem::@903": 0x803a25e8,
		"JSystem::@881": 0x803a25f8,
		"@881": 0x803a25f8,
		"JSystem::@882": 0x803a2608,
		"@882": 0x803a2608,
		"JSystem::@632": 0x803a2620,
		"@632": 0x803a2620,
		"JSystem::@753": 0x803a262c,
		"JSystem::@1461": 0x803a2644,
		"@1461": 0x803a2644,
		"JSystem::@1462": 0x803a2650,
		"@1462": 0x803a2650,
		"JSystem::@1463": 0x803a2664,
		"@1463": 0x803a2664,
		"JSystem::@1464": 0x803a2670,
		"@1464": 0x803a2670,
		"JSystem::@1465": 0x803a267c,
		"@1465": 0x803a267c,
		"JSystem::@1468": 0x803a2688,
		"@1468": 0x803a2688,
		"JSystem::@1473": 0x803a2698,
		"@1473": 0x803a2698,
		"JSystem::@1474": 0x803a26a4,
		"@1474": 0x803a26a4,
		"JSystem::@1475": 0x803a26b0,
		"@1475": 0x803a26b0,
		"JSystem::@1476": 0x803a26bc,
		"@1476": 0x803a26bc,
		"JSystem::@1480": 0x803a26cc,
		"@1480": 0x803a26cc,
		"JSystem::@1481": 0x803a26d8,
		"@1481": 0x803a26d8,
		"JSystem::@1482": 0x803a26e4,
		"@1482": 0x803a26e4,
		"JSystem::@49": 0x803a2780,
		"@49": 0x803a2780,
		"JSystem::@50": 0x803a2794,
		"@50": 0x803a2794,
		"JSystem::@61": 0x803a27ac,
		"JSystem::@293": 0x803a27c8,
		"JSystem::@1143": 0x803a27e8,
		"@1143": 0x803a27e8,
		"JSystem::@1144": 0x803a27f8,
		"@1144": 0x803a27f8,
		"JSystem::@1578": 0x803a2808,
		"JSystem::@395": 0x803a2818,
		"@395": 0x803a2818,
		"JSystem::@415": 0x803a2824,
		"@415": 0x803a2824,
		"JSystem::@416": 0x803a2860,
		"@416": 0x803a2860,
		"JSystem::@417": 0x803a2870,
		"@417": 0x803a2870,
		"JSystem::@463": 0x803a28d0,
		"JSystem::@530": 0x803a28e0,
		"@530": 0x803a28e0,
		"JSystem::@537": 0x803a2928,
		"@537": 0x803a2928,
		"JASystem::Driver::polys_table": 0x803a2948,
		"polys_table": 0x803a2948,
		"JSystem::@119": 0x803a2958,
		"@119": 0x803a2958,
		"JSystem::@211": 0x803a2964,
		"@211": 0x803a2964,
		"JASystem::Driver::relTableSampleCell": 0x803a2970,
		"relTableSampleCell": 0x803a2970,
		"JASystem::Driver::relTableSqRoot": 0x803a29b4,
		"relTableSqRoot": 0x803a29b4,
		"JASystem::Driver::relTableSquare": 0x803a29f8,
		"relTableSquare": 0x803a29f8,
		"JSystem::@197": 0x803a2a40,
		"JSystem::@216": 0x803a2a4c,
		"@216": 0x803a2a4c,
		"JASystem::Arglist": 0x803a2a58,
		"Arglist": 0x803a2a58,
		"JSystem::@351": 0x803a2b74,
		"@351": 0x803a2b74,
		"JSystem::@442": 0x803a2bb8,
		"@442": 0x803a2bb8,
		"JSystem::@444": 0x803a2be0,
		"@444": 0x803a2be0,
		"JSystem::@445": 0x803a2bf4,
		"@445": 0x803a2bf4,
		"JSystem::@451": 0x803a2c48,
		"@451": 0x803a2c48,
		"Runtime.PPCEABI.H::__ptmf_null": 0x803a2c58,
		"__ptmf_null": 0x803a2c58,
		"Runtime.PPCEABI.H::__constants": 0x803a2c68,
		"__constants": 0x803a2c68,
		"MSL_C.PPCEABI.bare.H::__ctype_map": 0x803a2d08,
		"__ctype_map": 0x803a2d08,
		"MSL_C.PPCEABI.bare.H::__lower_map": 0x803a2e08,
		"__lower_map": 0x803a2e08,
		"MSL_C.PPCEABI.bare.H::__upper_map": 0x803a2f08,
		"__upper_map": 0x803a2f08,
		"MSL_C.PPCEABI.bare.H::@stringBase0": 0x803a3008,
		"@stringBase0": 0x803a3008,
		"MSL_C.PPCEABI.bare.H::atan_coeff$96": 0x803a30b0,
		"atan_coeff$96": 0x803a30b0,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_hi$97": 0x803a30cc,
		"onep_one_over_xisqr_hi$97": 0x803a30cc,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_lo$98": 0x803a30e4,
		"onep_one_over_xisqr_lo$98": 0x803a30e4,
		"MSL_C.PPCEABI.bare.H::atan_xi_hi$99": 0x803a30fc,
		"atan_xi_hi$99": 0x803a30fc,
		"MSL_C.PPCEABI.bare.H::atan_xi_lo$100": 0x803a3118,
		"atan_xi_lo$100": 0x803a3118,
		"MSL_C.PPCEABI.bare.H::one_over_xi_hi$101": 0x803a3134,
		"one_over_xi_hi$101": 0x803a3134,
		"MSL_C.PPCEABI.bare.H::one_over_xi_lo$102": 0x803a314c,
		"one_over_xi_lo$102": 0x803a314c,
		"MSL_C.PPCEABI.bare.H::tmp_float": 0x803a3168,
		"tmp_float": 0x803a3168,
		"MSL_C.PPCEABI.bare.H::__two_to_log2e_m1_tI": 0x803a3178,
		"__two_to_log2e_m1_tI": 0x803a3178,
		"MSL_C.PPCEABI.bare.H::__one_over_F": 0x803a3440,
		"__one_over_F": 0x803a3440,
		"MSL_C.PPCEABI.bare.H::__sincos_on_quadrant": 0x803a3644,
		"__sincos_on_quadrant": 0x803a3644,
		"MSL_C.PPCEABI.bare.H::__sincos_poly": 0x803a3664,
		"__sincos_poly": 0x803a3664,
		"MSL_C.PPCEABI.bare.H::__log2_F": 0x803a3690,
		"__log2_F": 0x803a3690,
		"MSL_C.PPCEABI.bare.H::__two_to_x": 0x803a3894,
		"__two_to_x": 0x803a3894,
		"MSL_C.PPCEABI.bare.H::__exp_to_x$105": 0x803a38b8,
		"__exp_to_x$105": 0x803a38b8,
		"TRK_MINNOW_DOLPHIN::@40": 0x803a38d8,
		"TRK_MINNOW_DOLPHIN::gTRKMemMap": 0x803a38f8,
		"gTRKMemMap": 0x803a38f8,
		"TRK_MINNOW_DOLPHIN::@233": 0x803a3908,
		"@233": 0x803a3908,
		"TRK_MINNOW_DOLPHIN::@238": 0x803a391c,
		"@238": 0x803a391c,
		"TRK_MINNOW_DOLPHIN::@243": 0x803a3930,
		"@243": 0x803a3930,
		"thp::__THPJpegNaturalOrder": 0x803a3948,
		"__THPJpegNaturalOrder": 0x803a3948,
		"MarioUtil::@2036": 0x803952b8,
		"MarioUtil::@2195": 0x803952c4,
		"MarioUtil::@3559": 0x803952d4,
		"MarioUtil::lightName$1906": 0x80395304,
		"lightName$1906": 0x80395304,
		"MarioUtil::ambName$1907": 0x80395318,
		"ambName$1907": 0x80395318,
		"MarioUtil::lightName$1917": 0x80395338,
		"lightName$1917": 0x80395338,
		"MarioUtil::ambName$1918": 0x80395350,
		"ambName$1918": 0x80395350,
		"MarioUtil::lightName$1928": 0x80395374,
		"lightName$1928": 0x80395374,
		"MarioUtil::ambName$1929": 0x8039538c,
		"ambName$1929": 0x8039538c,
		"MarioUtil::@1931": 0x803953b0,
		"MarioUtil::@1932": 0x803953c4,
		"MarioUtil::lightName$1942": 0x803953d8,
		"lightName$1942": 0x803953d8,
		"MarioUtil::ambName$1943": 0x803953f0,
		"ambName$1943": 0x803953f0,
		"MarioUtil::@1945": 0x80395414,
		"MarioUtil::@1946": 0x80395428,
		"MarioUtil::@2007": 0x8039543c,
		"MarioUtil::@2223": 0x80395454,
		"MarioUtil::@2224": 0x80395468,
		"MarioUtil::@2225": 0x80395480,
		"MarioUtil::@2296": 0x803954bc,
		"MarioUtil::@2477": 0x803954cc,
		"MarioUtil::@2843": 0x803954dc,
		"MarioUtil::@1819": 0x803954fc,
		"MarioUtil::@1820": 0x80395508,
		"MarioUtil::@1846": 0x80395518,
		"@1846": 0x80395518,
		"MarioUtil::@2544": 0x80395524,
		"MarioUtil::@2545": 0x80395538,
		"MarioUtil::@2546": 0x80395544,
		"MarioUtil::@2547": 0x80395550,
		"MarioUtil::@2548": 0x8039555c,
		"MarioUtil::@2549": 0x80395568,
		"MarioUtil::@2556": 0x80395574,
		"MarioUtil::@1831": 0x80395580,
		"MarioUtil::@1809": 0x803955a4,
		"MarioUtil::@1974": 0x803955b8,
		"MarioUtil::@1975": 0x803955c8,
		"MarioUtil::@2149": 0x803955d8,
		"MarioUtil::@2150": 0x803955fc,
		"MarioUtil::calctablex$2412": 0x80395620,
		"calctablex$2412": 0x80395620,
		"MarioUtil::calctablez$2413": 0x80395630,
		"calctablez$2413": 0x80395630,
		"MarioUtil::@4135": 0x80395640,
		"MarioUtil::@4136": 0x8039565c,
		"MarioUtil::@4137": 0x80395678,
		"MarioUtil::@4138": 0x80395690,
		"MarioUtil::@17": 0x803956a8,
		"MarioUtil::@18": 0x80395778,
		"MarioUtil::@19": 0x80395788,
		"@19": 0x80395788,
		"MarioUtil::@20": 0x80395798,
		"@20": 0x80395798,
		"MarioUtil::@21": 0x803957a8,
		"@21": 0x803957a8,
		"MarioUtil::@22": 0x803957bc,
		"MarioUtil::@23": 0x803957d0,
		"@23": 0x803957d0,
		"MarioUtil::@24": 0x803957e0,
		"@24": 0x803957e0,
		"MarioUtil::@25": 0x803957f0,
		"MarioUtil::@26": 0x80395800,
		"@26": 0x80395800,
		"MarioUtil::@27": 0x80395810,
		"@27": 0x80395810,
		"MarioUtil::@28": 0x80395824,
		"MarioUtil::@29": 0x80395834,
		"@29": 0x80395834,
		"MarioUtil::@30": 0x80395844,
		"MarioUtil::@31": 0x80395854,
		"MarioUtil::@32": 0x80395864,
		"MarioUtil::@33": 0x80395874,
		"MarioUtil::@34": 0x80395884,
		"MarioUtil::@35": 0x80395894,
		"MarioUtil::@36": 0x803958a4,
		"MarioUtil::@37": 0x803958b4,
		"MarioUtil::@38": 0x803958c4,
		"MarioUtil::@39": 0x803958d0,
		"MarioUtil::@40": 0x803958dc,
		"MarioUtil::@66": 0x803958f4,
		"System::@1664": 0x80399900,
		"System::@1711": 0x8039990c,
		"System::prmarray$2214": 0x80399920,
		"prmarray$2214": 0x80399920,
		"System::envarray$2215": 0x80399938,
		"envarray$2215": 0x80399938,
		"System::@2200": 0x80399970,
		"System::@2201": 0x803999a0,
		"System::@2202": 0x803999d8,
		"System::@2203": 0x80399a0c,
		"System::@2728": 0x80399a30,
		"System::@3708": 0x80399b20,
		"System::@3709": 0x80399b30,
		"System::@3710": 0x80399b44,
		"System::@3711": 0x80399b54,
		"System::@3712": 0x80399b60,
		"System::@3713": 0x80399b70,
		"System::@3714": 0x80399b80,
		"System::@3715": 0x80399b8c,
		"System::@3716": 0x80399ba4,
		"System::@3717": 0x80399bbc,
		"System::@3718": 0x80399bcc,
		"System::@3719": 0x80399be0,
		"System::@3720": 0x80399bf4,
		"System::@3721": 0x80399c08,
		"System::@3722": 0x80399c1c,
		"System::@3723": 0x80399c30,
		"System::@3724": 0x80399c40,
		"System::@3725": 0x80399c54,
		"System::@3726": 0x80399c70,
		"System::@3727": 0x80399c7c,
		"System::@3728": 0x80399c90,
		"System::@3729": 0x80399ca0,
		"System::@3730": 0x80399cb0,
		"System::@3731": 0x80399cbc,
		"System::@3732": 0x80399cd0,
		"System::@3733": 0x80399ce8,
		"System::@3734": 0x80399cf8,
		"System::@3735": 0x80399d10,
		"System::@3736": 0x80399d28,
		"System::@3737": 0x80399d44,
		"System::@3738": 0x80399d58,
		"System::@3739": 0x80399d70,
		"System::@3740": 0x80399d88,
		"System::@3741": 0x80399d9c,
		"System::@3742": 0x80399db4,
		"System::@3743": 0x80399dc4,
		"System::@3744": 0x80399dd4,
		"System::@3745": 0x80399de0,
		"System::@3746": 0x80399dec,
		"System::@3747": 0x80399dfc,
		"System::@3748": 0x80399e08,
		"System::@3750": 0x80399e1c,
		"System::@3751": 0x80399e28,
		"System::@3752": 0x80399e38,
		"System::@2396": 0x8039a2b4,
		"System::@2397": 0x8039a2c0,
		"System::@2399": 0x8039a2cc,
		"System::@1701": 0x8039a504,
		"System::@1784": 0x8039a518,
		"System::@1785": 0x8039a548,
		"System::@1786": 0x8039a580,
		"System::@1787": 0x8039a5b4,
		"System::@2388": 0x8039a5f8,
		"System::@2732": 0x8039a610,
		"System::@2733": 0x8039a624,
		"System::@2734": 0x8039a638,
		"System::@2735": 0x8039a648,
		"System::@2736": 0x8039a654,
		"System::@2737": 0x8039a660,
		"System::@2743": 0x8039a670,
		"System::@2744": 0x8039a67c,
		"System::@2746": 0x8039a6a4,
		"System::@2747": 0x8039a6b8,
		"System::@2748": 0x8039a6c4,
		"System::@2749": 0x8039a6d4,
		"System::@2750": 0x8039a6e4,
		"System::@2751": 0x8039a6f4,
		"System::@2810": 0x8039a704,
		"System::@2811": 0x8039a714,
		"System::@2971": 0x8039a720,
		"System::@2972": 0x8039a730,
		"System::@2973": 0x8039a740,
		"System::@2974": 0x8039a750,
		"System::@1615": 0x8039a7b4,
		"System::@1616": 0x8039a7cc,
		"System::@1617": 0x8039a7e0,
		"System::@1620": 0x8039a80c,
		"System::@1621": 0x8039a81c,
		"System::@1622": 0x8039a828,
		"System::@1623": 0x8039a838,
		"System::@1624": 0x8039a848,
		"System::@1625": 0x8039a868,
		"System::@1627": 0x8039a888,
		"System::@1628": 0x8039a8a8,
		"System::@1629": 0x8039a8c8,
		"System::@1630": 0x8039a8dc,
		"System::@1631": 0x8039a8ec,
		"System::@1638": 0x8039a968,
		"System::@1639": 0x8039a97c,
		"System::@1640": 0x8039a994,
		"System::@1641": 0x8039a9ac,
		"System::@1642": 0x8039a9c0,
		"System::@2205": 0x8039a9f8,
		"System::@2206": 0x8039aa28,
		"System::@2207": 0x8039aa60,
		"System::@2208": 0x8039aa94,
		"System::@2694": 0x8039aab8,
		"@unnamed@::cDispExceptionCommand": 0x8039abd0,
		"cDispExceptionCommand": 0x8039abd0,
		"System::@2117": 0x8039ac04,
		"System::@2174": 0x8039ac48,
		"System::@2175": 0x8039ac80,
		"System::@2176": 0x8039acb4,
		"System::@4634": 0x8039adb4,
		"System::@4635": 0x8039adc4,
		"System::@4636": 0x8039add0,
		"System::@4637": 0x8039ade0,
		"System::@4638": 0x8039adec,
		"System::@4639": 0x8039adf8,
		"System::@4640": 0x8039ae10,
		"System::@4641": 0x8039ae1c,
		"System::@4642": 0x8039ae38,
		"System::@4643": 0x8039ae48,
		"System::@4644": 0x8039ae54,
		"System::@4645": 0x8039ae60,
		"System::@4646": 0x8039ae6c,
		"System::@4647": 0x8039ae7c,
		"System::@4648": 0x8039ae90,
		"System::@4649": 0x8039aea4,
		"System::@4650": 0x8039aeb0,
		"System::@4651": 0x8039aec0,
		"System::@4653": 0x8039aed0,
		"System::@4654": 0x8039aedc,
		"System::@4655": 0x8039aee8,
		"System::@4656": 0x8039aef4,
		"System::@4657": 0x8039af04,
		"System::@4658": 0x8039af18,
		"System::@4659": 0x8039af30,
		"System::@4660": 0x8039af40,
		"System::@4662": 0x8039af60,
		"System::@4663": 0x8039af70,
		"System::@4671": 0x8039afd4,
		"System::@4672": 0x8039afe4,
		"System::@4675": 0x8039affc,
		"System::@4676": 0x8039b008,
		"@4676": 0x8039b008,
		"System::@4677": 0x8039b018,
		"System::@4678": 0x8039b024,
		"System::@4679": 0x8039b034,
		"@4679": 0x8039b034,
		"System::@4680": 0x8039b040,
		"System::@4681": 0x8039b04c,
		"System::@4683": 0x8039b064,
		"System::@4684": 0x8039b074,
		"System::@4685": 0x8039b080,
		"System::@4686": 0x8039b090,
		"System::@4687": 0x8039b09c,
		"System::@4688": 0x8039b0b4,
		"System::@4689": 0x8039b0c0,
		"System::@4690": 0x8039b0d0,
		"System::@4691": 0x8039b0dc,
		"System::@4692": 0x8039b0ec,
		"System::@4693": 0x8039b0f8,
		"System::@4694": 0x8039b104,
		"System::@4695": 0x8039b110,
		"System::@4698": 0x8039b11c,
		"System::@4699": 0x8039b128,
		"System::@4700": 0x8039b134,
		"System::@4701": 0x8039b140,
		"System::@4702": 0x8039b14c,
		"System::@4704": 0x8039b158,
		"System::@4707": 0x8039b190,
		"System::@4708": 0x8039b19c,
		"System::@4709": 0x8039b1b8,
		"System::@4710": 0x8039b1c4,
		"@4710": 0x8039b1c4,
		"System::@4711": 0x8039b1dc,
		"@4711": 0x8039b1dc,
		"System::@4713": 0x8039b1fc,
		"@4713": 0x8039b1fc,
		"System::@4714": 0x8039b208,
		"@4714": 0x8039b208,
		"System::@4715": 0x8039b220,
		"@4715": 0x8039b220,
		"System::@4716": 0x8039b22c,
		"System::@4717": 0x8039b244,
		"System::@4718": 0x8039b250,
		"System::@4719": 0x8039b268,
		"System::@4720": 0x8039b274,
		"System::@4721": 0x8039b28c,
		"System::@4722": 0x8039b29c,
		"System::@4723": 0x8039b2c0,
		"System::@4724": 0x8039b2d0,
		"System::@4725": 0x8039b2f4,
		"System::@4726": 0x8039b30c,
		"System::@4727": 0x8039b320,
		"System::@4728": 0x8039b340,
		"System::@4729": 0x8039b35c,
		"System::@4730": 0x8039b374,
		"System::@4731": 0x8039b38c,
		"System::@4732": 0x8039b3a0,
		"System::@4733": 0x8039b3ac,
		"System::@4734": 0x8039b3c0,
		"System::@4735": 0x8039b3e0,
		"System::@4736": 0x8039b3f8,
		"System::@4737": 0x8039b414,
		"System::@4738": 0x8039b42c,
		"System::@4739": 0x8039b44c,
		"System::@4740": 0x8039b464,
		"System::@4742": 0x8039b478,
		"System::@4743": 0x8039b48c,
		"System::@4744": 0x8039b4a8,
		"System::@4745": 0x8039b4c0,
		"System::@4746": 0x8039b4d8,
		"System::@4747": 0x8039b4e8,
		"System::@4748": 0x8039b4fc,
		"System::@4749": 0x8039b508,
		"System::@4751": 0x8039b528,
		"System::@4752": 0x8039b53c,
		"System::@4753": 0x8039b550,
		"System::@4754": 0x8039b568,
		"System::@4755": 0x8039b57c,
		"System::@4756": 0x8039b58c,
		"System::@4759": 0x8039b5a0,
		"System::@4760": 0x8039b5b0,
		"System::@4761": 0x8039b5c4,
		"System::@4762": 0x8039b5dc,
		"System::@4763": 0x8039b5ec,
		"System::@4764": 0x8039b600,
		"System::@4765": 0x8039b61c,
		"System::@4768": 0x8039b650,
		"System::@4769": 0x8039b660,
		"System::@4770": 0x8039b674,
		"System::@4771": 0x8039b688,
		"System::@4772": 0x8039b694,
		"System::@4773": 0x8039b6a4,
		"System::@4774": 0x8039b6b8,
		"System::@4775": 0x8039b6c4,
		"System::@4776": 0x8039b6d0,
		"System::@4777": 0x8039b6e4,
		"System::@4778": 0x8039b6f8,
		"System::@4779": 0x8039b704,
		"System::@4780": 0x8039b714,
		"System::@4781": 0x8039b724,
		"System::@4782": 0x8039b734,
		"System::@4783": 0x8039b740,
		"System::@4784": 0x8039b750,
		"System::@4785": 0x8039b75c,
		"System::@4786": 0x8039b76c,
		"System::@2838": 0x8039b810,
		"System::@2842": 0x8039b81c,
		"System::@2843": 0x8039b828,
		"System::@2854": 0x8039b834,
		"System::@2857": 0x8039b850,
		"System::@2858": 0x8039b860,
		"System::SceneParamsDir": 0x8039b960,
		"SceneParamsDir": 0x8039b960,
		"System::@1525": 0x8039b97c,
		"System::@2003": 0x8039ba50,
		"System::@2004": 0x8039ba64,
		"System::@2005": 0x8039ba84,
		"System::@2006": 0x8039ba90,
		"System::@1726": 0x8039c674,
		"@1726": 0x8039c674,
		"System::@1958": 0x8039c724,
		"System::@1959": 0x8039c758,
		"System::@3922": 0x8039cd5c,
		"System::@3924": 0x8039cd68,
		"System::@3925": 0x8039cd7c,
		"System::@3926": 0x8039cd90,
		"System::@3927": 0x8039cda0,
		"System::@3928": 0x8039cdbc,
		"System::@3929": 0x8039cdc8,
		"System::@3930": 0x8039cdd8,
		"System::@3933": 0x8039cdfc,
		"System::@3934": 0x8039ce10,
		"System::@3935": 0x8039ce2c,
		"System::@3936": 0x8039ce40,
		"System::@3938": 0x8039ce68,
		"System::@3940": 0x8039ce74,
		"System::@3941": 0x8039ce80,
		"System::@3942": 0x8039ce8c,
		"System::@3943": 0x8039ce9c,
		"System::@3944": 0x8039ceb0,
		"System::@3945": 0x8039cecc,
		"System::@3946": 0x8039ced8,
		"System::@3947": 0x8039cee4,
		"System::@3948": 0x8039cef0,
		"System::@3949": 0x8039cefc,
		"System::@3950": 0x8039cf08,
		"System::@3951": 0x8039cf14,
		"System::@3952": 0x8039cf20,
		"System::@3956": 0x8039cf50,
		"System::@3957": 0x8039cf60,
		"System::@3959": 0x8039cf88,
		"System::@3961": 0x8039cf94,
		"System::@3963": 0x8039cfa0,
		"System::@3965": 0x8039cfac,
		"System::@3967": 0x8039cfc0,
		"System::@3968": 0x8039cfd0,
		"System::@3969": 0x8039cfe4,
		"System::@3970": 0x8039cff8,
		"System::@3971": 0x8039d008,
		"System::@3972": 0x8039d028,
		"System::@3973": 0x8039d040,
		"System::@3974": 0x8039d05c,
		"System::@3975": 0x8039d078,
		"System::@3976": 0x8039d098,
		"System::@3977": 0x8039d0b0,
		"System::@3978": 0x8039d0cc,
		"System::@3979": 0x8039d0e4,
		"System::@3980": 0x8039d100,
		"System::@3981": 0x8039d114,
		"System::@3982": 0x8039d130,
		"System::@3983": 0x8039d13c,
		"System::@3984": 0x8039d14c,
		"System::@3985": 0x8039d15c,
		"System::@3986": 0x8039d178,
		"System::@3987": 0x8039d188,
		"System::@3991": 0x8039d1cc,
		"System::@3992": 0x8039d1e8,
		"System::@3993": 0x8039d1f8,
		"System::@3994": 0x8039d208,
		"System::@3995": 0x8039d218,
		"System::@3996": 0x8039d228,
		"System::@3997": 0x8039d23c,
		"System::@3998": 0x8039d258,
		"System::@3999": 0x8039d268,
		"System::@4000": 0x8039d278,
		"System::@4001": 0x8039d290,
		"System::@4002": 0x8039d2ac,
		"System::@4003": 0x8039d2c8,
		"System::@4004": 0x8039d2e8,
		"System::@4005": 0x8039d2fc,
		"System::@4006": 0x8039d310,
		"System::@4007": 0x8039d324,
		"System::@4008": 0x8039d33c,
		"System::@4009": 0x8039d34c,
		"System::@4010": 0x8039d358,
		"System::@4014": 0x8039d3a8,
		"System::@4015": 0x8039d3b8,
		"System::@4016": 0x8039d3d0,
		"System::@4017": 0x8039d3dc,
		"System::@4018": 0x8039d3e8,
		"System::@4019": 0x8039d404,
		"System::@4021": 0x8039d430,
		"System::@4023": 0x8039d448,
		"System::@4024": 0x8039d454,
		"System::@4025": 0x8039d460,
		"System::@4026": 0x8039d470,
		"System::@4027": 0x8039d484,
		"System::@4028": 0x8039d49c,
		"System::@4029": 0x8039d4a8,
		"System::@4030": 0x8039d4b4,
		"System::@4031": 0x8039d4c8,
		"System::@4032": 0x8039d4e4,
		"System::@4033": 0x8039d4f0,
		"System::@4034": 0x8039d500,
		"System::@4035": 0x8039d510,
		"System::@4036": 0x8039d524,
		"System::@4037": 0x8039d538,
		"System::@4038": 0x8039d554,
		"System::@4039": 0x8039d560,
		"System::@4044": 0x8039d590,
		"System::@4045": 0x8039d5a0,
		"System::@4047": 0x8039d5c8,
		"System::@4049": 0x8039d5e0,
		"System::@4050": 0x8039d5ec,
		"System::@4051": 0x8039d5f8,
		"System::@4052": 0x8039d608,
		"System::@4054": 0x8039d624,
		"System::@4055": 0x8039d638,
		"System::@4056": 0x8039d654,
		"System::@4057": 0x8039d660,
		"System::@4058": 0x8039d670,
		"System::@4059": 0x8039d684,
		"System::@4060": 0x8039d6a0,
		"System::@4061": 0x8039d6b0,
		"System::@4066": 0x8039d6e4,
		"System::@4067": 0x8039d6f0,
		"System::@4068": 0x8039d6fc,
		"System::@4069": 0x8039d708,
		"@4069": 0x8039d708,
		"System::@4070": 0x8039d718,
		"System::@4071": 0x8039d724,
		"@4071": 0x8039d724,
		"System::@4072": 0x8039d730,
		"System::@4073": 0x8039d744,
		"System::@4074": 0x8039d758,
		"System::@4075": 0x8039d76c,
		"System::@4077": 0x8039d790,
		"System::@4079": 0x8039d7ac,
		"System::@4088": 0x8039d830,
		"System::@4089": 0x8039d844,
		"System::@4090": 0x8039d864,
		"System::@4091": 0x8039d870,
		"System::@4092": 0x8039d884,
		"System::@4093": 0x8039d8a0,
		"System::@4094": 0x8039d8bc,
		"System::@4095": 0x8039d8d0,
		"System::@4096": 0x8039d8e0,
		"System::@4097": 0x8039d8f8,
		"System::@4098": 0x8039d914,
		"System::@4099": 0x8039d928,
		"System::@4100": 0x8039d938,
		"System::@4101": 0x8039d948,
		"System::@4102": 0x8039d960,
		"System::@4103": 0x8039d970,
		"System::@4105": 0x8039d994,
		"System::@4107": 0x8039d9a0,
		"System::@4108": 0x8039d9ac,
		"System::@4109": 0x8039d9bc,
		"System::@4110": 0x8039d9e0,
		"System::@4111": 0x8039d9ec,
		"System::@4112": 0x8039da04,
		"System::@4113": 0x8039da14,
		"System::@4114": 0x8039da30,
		"System::@4115": 0x8039da3c,
		"System::@4117": 0x8039da5c,
		"@4117": 0x8039da5c,
		"System::@4135": 0x8039dafc,
		"System::@4137": 0x8039db14,
		"System::@4138": 0x8039db20,
		"System::@4139": 0x8039db38,
		"System::@4140": 0x8039db58,
		"System::@4141": 0x8039db68,
		"System::@4142": 0x8039db7c,
		"System::@4143": 0x8039db8c,
		"System::@4144": 0x8039dba0,
		"System::@4145": 0x8039dbb8,
		"System::@4146": 0x8039dbd8,
		"System::@4147": 0x8039dbe4,
		"System::@4148": 0x8039dbfc,
		"System::@4150": 0x8039dc2c,
		"System::@4152": 0x8039dc38,
		"System::@4153": 0x8039dc44,
		"System::@4154": 0x8039dc58,
		"System::@4155": 0x8039dc6c,
		"System::@4175": 0x8039ddd4,
		"System::@4177": 0x8039ddec,
		"System::@4179": 0x8039de08,
		"System::@1723": 0x8039decc,
		"System::@1779": 0x8039dee0,
		"System::@1780": 0x8039df10,
		"System::@1781": 0x8039df48,
		"System::@1782": 0x8039df7c,
		"System::@2095": 0x8039dfdc,
		"System::@2096": 0x8039dfe8,
		"System::@2097": 0x8039dff4,
		"@2097": 0x8039dff4,
		"System::@2098": 0x8039e000,
		"System::@2099": 0x8039e010,
		"System::@2105": 0x8039e050,
		"System::@2106": 0x8039e05c,
		"System::@2107": 0x8039e068,
		"System::@1752": 0x8039e08c,
		"System::@1808": 0x8039e0a0,
		"System::@1810": 0x8039e108,
		"System::@1811": 0x8039e13c,
		"System::@2364": 0x8039e160,
		"System::@2366": 0x8039e16c,
		"System::@4994": 0x8039e178,
		"System::@4995": 0x8039e184,
		"System::@4996": 0x8039e198,
		"System::@4997": 0x8039e1a8,
		"System::@4999": 0x8039e1bc,
		"System::@5001": 0x8039e1c8,
		"System::@5002": 0x8039e1d8,
		"System::@5003": 0x8039e1e4,
		"System::@5004": 0x8039e1f0,
		"System::@5005": 0x8039e204,
		"System::@5006": 0x8039e210,
		"System::@5007": 0x8039e220,
		"System::@5009": 0x8039e244,
		"System::@5010": 0x8039e258,
		"System::@5011": 0x8039e268,
		"System::@5012": 0x8039e278,
		"System::@5014": 0x8039e2a0,
		"System::@5016": 0x8039e2c4,
		"System::@5018": 0x8039e2e8,
		"System::@5020": 0x8039e30c,
		"System::@5021": 0x8039e31c,
		"System::@5023": 0x8039e330,
		"System::@5024": 0x8039e344,
		"System::@5025": 0x8039e350,
		"System::@5026": 0x8039e35c,
		"System::@5028": 0x8039e368,
		"System::@5030": 0x8039e374,
		"System::@5034": 0x8039e394,
		"System::@5035": 0x8039e3a8,
		"System::@5036": 0x8039e3bc,
		"@5036": 0x8039e3bc,
		"System::@5038": 0x8039e3e0,
		"System::@5040": 0x8039e410,
		"@5040": 0x8039e410,
		"System::@5041": 0x8039e434,
		"System::@5042": 0x8039e444,
		"System::@5047": 0x8039e484,
		"System::@5048": 0x8039e498,
		"System::@5049": 0x8039e4a8,
		"System::@5050": 0x8039e4b4,
		"System::@5054": 0x8039e4d4,
		"System::@5055": 0x8039e4e8,
		"System::@5056": 0x8039e4fc,
		"System::@5062": 0x8039e514,
		"@5062": 0x8039e514,
		"System::@5065": 0x8039e540,
		"@5065": 0x8039e540,
		"System::@5067": 0x8039e550,
		"@5067": 0x8039e550,
		"System::@5068": 0x8039e55c,
		"@5068": 0x8039e55c,
		"System::@5069": 0x8039e574,
		"@5069": 0x8039e574,
		"System::@5070": 0x8039e580,
		"System::@5071": 0x8039e598,
		"System::@5072": 0x8039e5a4,
		"System::@5073": 0x8039e5b4,
		"System::@5076": 0x8039e5c0,
		"System::@5079": 0x8039e5cc,
		"@5079": 0x8039e5cc,
		"System::@5080": 0x8039e5e4,
		"System::@5081": 0x8039e5f8,
		"System::@5082": 0x8039e608,
		"@5082": 0x8039e608,
		"System::@5083": 0x8039e61c,
		"System::@5084": 0x8039e62c,
		"System::@5085": 0x8039e640,
		"System::@5087": 0x8039e660,
		"System::@5090": 0x8039e688,
		"System::@5091": 0x8039e69c,
		"System::@5092": 0x8039e6b0,
		"System::@5093": 0x8039e6cc,
		"System::@5094": 0x8039e6d8,
		"System::@5095": 0x8039e6e8,
		"System::@5096": 0x8039e6f8,
		"System::@5097": 0x8039e704,
		"System::@5098": 0x8039e714,
		"System::@5099": 0x8039e720,
		"System::@5104": 0x8039e738,
		"System::@5105": 0x8039e744,
		"@5105": 0x8039e744,
		"System::@5106": 0x8039e750,
		"@5106": 0x8039e750,
		"System::@5107": 0x8039e75c,
		"@5107": 0x8039e75c,
		"System::@5109": 0x8039e778,
		"System::@5111": 0x8039e794,
		"System::@5112": 0x8039e7a0,
		"System::@5113": 0x8039e7b0,
		"System::@5114": 0x8039e7c0,
		"System::@5117": 0x8039e7cc,
		"System::@5118": 0x8039e7e0,
		"System::@5120": 0x8039e7fc,
		"System::@5121": 0x8039e808,
		"System::@5123": 0x8039e814,
		"System::@5124": 0x8039e824,
		"System::@5125": 0x8039e83c,
		"System::@5126": 0x8039e84c,
		"System::@5128": 0x8039e870,
		"System::@5129": 0x8039e880,
		"System::@5134": 0x8039e8cc,
		"System::@5135": 0x8039e8dc,
		"System::@5136": 0x8039e8f0,
		"System::@5137": 0x8039e8fc,
		"System::@5138": 0x8039e910,
		"System::@5139": 0x8039e91c,
		"System::@5140": 0x8039e92c,
		"@5140": 0x8039e92c,
		"System::@5142": 0x8039e938,
		"System::@5143": 0x8039e948,
		"System::@5144": 0x8039e954,
		"System::@5145": 0x8039e964,
		"System::@5146": 0x8039e974,
		"System::@5148": 0x8039e994,
		"System::@5149": 0x8039e9a0,
		"System::@5150": 0x8039e9ac,
		"@5150": 0x8039e9ac,
		"System::@5151": 0x8039e9b8,
		"System::@5152": 0x8039e9cc,
		"System::@5157": 0x8039ea18,
		"System::@5158": 0x8039ea2c,
		"System::@5159": 0x8039ea3c,
		"System::@5160": 0x8039ea50,
		"System::@5162": 0x8039ea64,
		"@5162": 0x8039ea64,
		"System::@5163": 0x8039ea70,
		"System::@5164": 0x8039ea80,
		"System::@5165": 0x8039ea94,
		"System::@5166": 0x8039eaa4,
		"System::@5167": 0x8039eabc,
		"System::@5168": 0x8039ead4,
		"System::@5169": 0x8039eae4,
		"@5169": 0x8039eae4,
		"System::@5170": 0x8039eaf0,
		"System::@5171": 0x8039eb00,
		"@5171": 0x8039eb00,
		"System::@5172": 0x8039eb10,
		"System::@5173": 0x8039eb24,
		"System::@5174": 0x8039eb34,
		"System::@5175": 0x8039eb44,
		"System::@5177": 0x8039eb68,
		"System::@5179": 0x8039eb80,
		"System::@5180": 0x8039eb90,
		"System::@5181": 0x8039eba4,
		"System::@5182": 0x8039ebb4,
		"System::@5183": 0x8039ebc8,
		"System::@5184": 0x8039ebd4,
		"System::@5186": 0x8039ebf0,
		"System::@5187": 0x8039ebfc,
		"System::@5188": 0x8039ec08,
		"System::@5189": 0x8039ec18,
		"System::@5193": 0x8039ec48,
		"System::@5195": 0x8039ec54,
		"System::@5196": 0x8039ec68,
		"System::@5197": 0x8039ec7c,
		"System::@5198": 0x8039ec8c,
		"System::@5199": 0x8039ec98,
		"System::@5200": 0x8039eca8,
		"@5200": 0x8039eca8,
		"System::@5202": 0x8039ecb8,
		"System::@5203": 0x8039ecc8,
		"System::@5204": 0x8039ecd8,
		"System::@5205": 0x8039ecec,
		"@5205": 0x8039ecec,
		"System::@5208": 0x8039ecf8,
		"System::@5209": 0x8039ed04,
		"System::@5210": 0x8039ed10,
		"System::@5211": 0x8039ed20,
		"@5211": 0x8039ed20,
		"System::@5213": 0x8039ed3c,
		"System::@5214": 0x8039ed4c,
		"System::@5215": 0x8039ed5c,
		"System::@5216": 0x8039ed70,
		"System::@5217": 0x8039ed7c,
		"System::@5218": 0x8039ed8c,
		"System::@5219": 0x8039ed98,
		"System::@5220": 0x8039eda8,
		"System::@5222": 0x8039edc4,
		"System::@5224": 0x8039edd4,
		"System::@5225": 0x8039ede0,
		"System::@5226": 0x8039edf0,
		"System::@5227": 0x8039edfc,
		"System::@5229": 0x8039ee08,
		"System::@5230": 0x8039ee1c,
		"System::@5231": 0x8039ee28,
		"System::@5232": 0x8039ee38,
		"System::@5233": 0x8039ee44,
		"System::@5234": 0x8039ee50,
		"System::@5235": 0x8039ee64,
		"System::@5236": 0x8039ee70,
		"System::@5238": 0x8039ee7c,
		"System::@5239": 0x8039ee88,
		"System::@5240": 0x8039ee94,
		"System::@5241": 0x8039eea8,
		"System::@5242": 0x8039eeb4,
		"System::@5243": 0x8039eec0,
		"System::@5244": 0x8039eecc,
		"System::@5246": 0x8039eeec,
		"System::@5248": 0x8039ef10,
		"System::@5249": 0x8039ef24,
		"System::@5250": 0x8039ef30,
		"System::@5251": 0x8039ef3c,
		"System::@5252": 0x8039ef48,
		"System::@5253": 0x8039ef5c,
		"System::@5254": 0x8039ef6c,
		"System::@5255": 0x8039ef78,
		"System::@5257": 0x8039ef94,
		"System::@5258": 0x8039efa8,
		"System::@5259": 0x8039efb4,
		"System::@5260": 0x8039efc4,
		"System::@5262": 0x8039efd0,
		"System::@5264": 0x8039efe0,
		"System::@5266": 0x8039effc,
		"System::@5267": 0x8039f008,
		"System::@5268": 0x8039f018,
		"System::@5270": 0x8039f040,
		"System::@5271": 0x8039f050,
		"System::@5273": 0x8039f060,
		"System::@5274": 0x8039f070,
		"System::@5276": 0x8039f08c,
		"System::@5277": 0x8039f098,
		"System::@5278": 0x8039f0a8,
		"System::@5279": 0x8039f0b4,
		"System::@5280": 0x8039f0c4,
		"System::@5282": 0x8039f0d0,
		"System::@5283": 0x8039f0e0,
		"System::@5288": 0x8039f118,
		"System::@5289": 0x8039f128,
		"System::@5290": 0x8039f138,
		"System::@5292": 0x8039f144,
		"System::@5293": 0x8039f150,
		"@5293": 0x8039f150,
		"System::@5294": 0x8039f160,
		"@5294": 0x8039f160,
		"System::@5295": 0x8039f17c,
		"System::@5296": 0x8039f18c,
		"System::@5297": 0x8039f19c,
		"@5297": 0x8039f19c,
		"System::@5298": 0x8039f1a8,
		"@5298": 0x8039f1a8,
		"System::@5301": 0x8039f1c4,
		"System::@5304": 0x8039f1d0,
		"System::@5306": 0x8039f1e8,
		"System::@5307": 0x8039f1f4,
		"System::@5308": 0x8039f200,
		"System::@5309": 0x8039f20c,
		"System::@5310": 0x8039f218,
		"System::@5314": 0x8039f248,
		"System::@5316": 0x8039f254,
		"System::@5318": 0x8039f26c,
		"System::@5319": 0x8039f278,
		"System::@5320": 0x8039f288,
		"System::@5322": 0x8039f294,
		"System::@5323": 0x8039f2a0,
		"System::@5324": 0x8039f2b8,
		"System::@5325": 0x8039f2c4,
		"System::@5326": 0x8039f2d4,
		"System::@5330": 0x8039f2e4,
		"System::@5331": 0x8039f2f0,
		"System::@5332": 0x8039f2fc,
		"System::@5334": 0x8039f308,
		"System::@5335": 0x8039f318,
		"System::@5336": 0x8039f328,
		"System::@5337": 0x8039f33c,
		"System::@5338": 0x8039f34c,
		"System::@5339": 0x8039f35c,
		"System::@5340": 0x8039f374,
		"System::@5341": 0x8039f388,
		"System::@5342": 0x8039f398,
		"System::@5343": 0x8039f3a4,
		"System::@5345": 0x8039f3b8,
		"@5345": 0x8039f3b8,
		"System::@5346": 0x8039f3c4,
		"System::@5347": 0x8039f3d0,
		"System::@5348": 0x8039f3e0,
		"System::@5350": 0x8039f3ec,
		"System::@5351": 0x8039f3f8,
		"System::@5352": 0x8039f408,
		"System::@2577": 0x8039f610,
		"System::@2578": 0x8039f61c,
		"System::@2594": 0x8039f6dc,
		"System::@2595": 0x8039f6e8,
		"System::@2596": 0x8039f6f4,
		"System::@2597": 0x8039f700,
		"System::CardFileName": 0x8039f940,
		"CardFileName": 0x8039f940,
		"System::@2155": 0x8039f9f4,
		"System::@2384": 0x8039fa08,
		"System::@3146": 0x8039fafc,
		"System::@3147": 0x8039fb10,
		"System::@3148": 0x8039fb24,
		"System::@3149": 0x8039fb38,
		"System::@3150": 0x8039fb4c,
		"System::@3151": 0x8039fb60,
		"System::@3152": 0x8039fb74,
		"System::@3153": 0x8039fb84,
		"System::@3154": 0x8039fb94,
		"System::@3159": 0x8039fbe8,
		"System::@3160": 0x8039fbfc,
		"System::@3161": 0x8039fc10,
		"System::@3162": 0x8039fc1c,
		"System::@3163": 0x8039fc30,
		"System::@3164": 0x8039fc44,
		"System::@3165": 0x8039fc58,
		"System::@3166": 0x8039fc6c,
		"System::@3167": 0x8039fc80,
		"System::@3168": 0x8039fc94,
		"System::@3169": 0x8039fca8,
		"System::@3170": 0x8039fcbc,
		"System::@3171": 0x8039fcd0,
		"System::@3172": 0x8039fce4,
		"System::@3173": 0x8039fcf8,
		"System::@3174": 0x8039fd0c,
		"System::@3175": 0x8039fd24,
		"System::@3176": 0x8039fd3c,
		"System::@3177": 0x8039fd50,
		"System::@3178": 0x8039fd68,
		"System::@3179": 0x8039fd7c,
		"System::@3180": 0x8039fd94,
		"System::@3181": 0x8039fdac,
		"System::@3182": 0x8039fdc0,
		"System::@3183": 0x8039fdd4,
		"System::@3184": 0x8039fde8,
		"System::@3189": 0x8039fe54,
		"System::@3190": 0x8039fe68,
		"System::@3191": 0x8039fe7c,
		"System::@3192": 0x8039fe90,
		"System::@3193": 0x8039fea4,
		"System::@3194": 0x8039feb8,
		"System::@3195": 0x8039fecc,
		"System::@3218": 0x803a00a4,
		"System::@3219": 0x803a00b8,
		"System::@3220": 0x803a00cc,
		"System::@3221": 0x803a00e0,
		"System::@3222": 0x803a00f4,
		"System::@3223": 0x803a0104,
		"System::@3224": 0x803a0114,
		"System::@3225": 0x803a0128,
		"System::@3226": 0x803a0138,
		"System::@3227": 0x803a014c,
		"System::@3228": 0x803a015c,
		"System::@3316": 0x803a05c0,
		"System::@3317": 0x803a05d4,
		"System::@3318": 0x803a05e8,
		"System::@3319": 0x803a05fc,
		"System::@3320": 0x803a0610,
		"System::@3321": 0x803a0624,
		"System::@3322": 0x803a0638,
		"System::@3323": 0x803a064c,
		"System::@3324": 0x803a0660,
		"System::@3325": 0x803a0674,
		"System::@3326": 0x803a0688,
		"System::@3327": 0x803a069c,
		"System::@3328": 0x803a06b4,
		"System::@3329": 0x803a06cc,
		"System::@3330": 0x803a06dc,
		"System::@3331": 0x803a06ec,
		"System::@3332": 0x803a06fc,
		"System::@3333": 0x803a0714,
		"System::@3334": 0x803a072c,
		"System::@3335": 0x803a0744,
		"System::@3336": 0x803a0754,
		"System::@3337": 0x803a0768,
		"System::@3338": 0x803a077c,
		"System::@3339": 0x803a0790,
		"System::@3340": 0x803a07a4,
		"System::@3341": 0x803a07b8,
		"System::@3342": 0x803a07cc,
		"System::@3343": 0x803a07e0,
		"System::@3344": 0x803a07f0,
		"System::@3345": 0x803a0808,
		"System::@3346": 0x803a081c,
		"System::@3347": 0x803a0830,
		"System::@3348": 0x803a0844,
		"System::@3349": 0x803a0854,
		"System::@3350": 0x803a0868,
		"System::@3351": 0x803a087c,
		"System::@3352": 0x803a0894,
		"System::@3353": 0x803a08a8,
		"System::@3354": 0x803a08c0,
		"System::@3355": 0x803a08d4,
		"System::@3356": 0x803a08e8,
		"System::@3357": 0x803a08fc,
		"System::@3358": 0x803a0910,
		"System::@3359": 0x803a0920,
		"System::@3360": 0x803a0934,
		"System::@3361": 0x803a0948,
		"System::@3362": 0x803a095c,
		"System::@3363": 0x803a0970,
		"System::@3364": 0x803a0984,
		"System::@3365": 0x803a099c,
		"System::@3366": 0x803a09b4,
		"System::@3367": 0x803a09c8,
		"System::@3368": 0x803a09dc,
		"System::@3369": 0x803a09f0,
		"System::@3370": 0x803a0a04,
		"System::@3371": 0x803a0a14,
		"System::@3372": 0x803a0a28,
		"System::@3373": 0x803a0a3c,
		"System::@3374": 0x803a0a4c,
		"System::@3375": 0x803a0a5c,
		"System::@3376": 0x803a0a70,
		"System::@3377": 0x803a0a80,
		"System::@3378": 0x803a0a94,
		"System::@3379": 0x803a0aa4,
		"System::@3381": 0x803a0acc,
		"System::@3382": 0x803a0ae4,
		"System::@3383": 0x803a0af8,
		"System::@3384": 0x803a0b0c,
		"System::@3385": 0x803a0b1c,
		"System::@3387": 0x803a0b44,
		"System::@3388": 0x803a0b58,
		"System::@3389": 0x803a0b68,
		"System::@3390": 0x803a0b7c,
		"System::@1816": 0x803a1140,
		"System::@2110": 0x803a1164,
		"System::@3796": 0x803a1458,
		"System::@3797": 0x803a1470,
		"System::@3798": 0x803a1488,
		"System::@3799": 0x803a14a0,
		"System::@3800": 0x803a14b0,
		"System::@3802": 0x803a14dc,
		"System::@3803": 0x803a14ec,
		"System::@3805": 0x803a14fc,
		"System::@3806": 0x803a1510,
		"System::@3807": 0x803a1520,
		"System::@3808": 0x803a1534,
		"System::@3809": 0x803a1544,
		"System::@1681": 0x803a1638,
		"System::@1708": 0x803a1664,
		"System::@1709": 0x803a167c,
		"Strategic::@1582": 0x80394b70,
		"Strategic::@1583": 0x80394ba0,
		"Strategic::@1584": 0x80394bd8,
		"Strategic::@1585": 0x80394c0c,
		"Strategic::@2148": 0x80394c88,
		"Strategic::@1598": 0x80394cb8,
		"Strategic::@1599": 0x80394ce8,
		"Strategic::@1600": 0x80394d20,
		"Strategic::@1601": 0x80394d54,
		"Strategic::@1735": 0x80394d78,
		"Strategic::entry$1734": 0x80394d84,
		"entry$1734": 0x80394d84,
		"Strategic::@1948": 0x80394da0,
		"Strategic::@514": 0x80394db0,
		"@514": 0x80394db0,
		"Strategic::@515": 0x80394dcc,
		"@515": 0x80394dcc,
		"Strategic::@559": 0x80394df0,
		"@559": 0x80394df0,
		"Strategic::@560": 0x80394e14,
		"@560": 0x80394e14,
		"Strategic::@561": 0x80394e3c,
		"@561": 0x80394e3c,
		"Strategic::@610": 0x80394e60,
		"Strategic::@611": 0x80394e84,
		"@611": 0x80394e84,
		"Strategic::@612": 0x80394eb4,
		"@612": 0x80394eb4,
		"Strategic::@654": 0x80394edc,
		"Strategic::@655": 0x80394ef8,
		"Strategic::@725": 0x80394f18,
		"Strategic::@834": 0x80394f48,
		"@834": 0x80394f48,
		"Strategic::@915": 0x80394f80,
		"@915": 0x80394f80,
		"Strategic::@916": 0x80394fa0,
		"@916": 0x80394fa0,
		"Strategic::@917": 0x80394fb0,
		"@917": 0x80394fb0,
		"Strategic::@918": 0x80394fc0,
		"@918": 0x80394fc0,
		"Strategic::@919": 0x80394fd0,
		"@919": 0x80394fd0,
		"Strategic::@920": 0x80394fe0,
		"Strategic::@921": 0x80394ff0,
		"@921": 0x80394ff0,
		"Strategic::@922": 0x80395004,
		"@922": 0x80395004,
		"Strategic::@923": 0x8039501c,
		"@923": 0x8039501c,
		"Strategic::@924": 0x80395034,
		"@924": 0x80395034,
		"Strategic::@925": 0x8039504c,
		"@925": 0x8039504c,
		"Strategic::@1000": 0x80395080,
		"@1000": 0x80395080,
		"Strategic::@1071": 0x8039509c,
		"@1071": 0x8039509c,
		"Strategic::@1072": 0x803950b8,
		"Strategic::@1078": 0x803950e4,
		"@1078": 0x803950e4,
		"Strategic::@2481": 0x80395104,
		"Strategic::@2541": 0x80395124,
		"Strategic::@2620": 0x8039514c,
		"Strategic::@1826": 0x80395170,
		"@1826": 0x80395170,
		"Strategic::@2112": 0x8039519c,
		"Strategic::@2302": 0x803951b0,
		"Strategic::@2303": 0x803951e0,
		"Strategic::@2304": 0x80395218,
		"Strategic::@2305": 0x8039524c,
		"Strategic::@2581": 0x80395270,
		"Player::@1763": 0x80395914,
		"Player::@1936": 0x80395a4c,
		"Player::@2446": 0x80395a90,
		"Player::@2447": 0x80395ac8,
		"Player::@2448": 0x80395afc,
		"Player::@2902": 0x80395c54,
		"Player::@2903": 0x80395c60,
		"Player::@2904": 0x80395c6c,
		"Player::@2911": 0x80395ca8,
		"Player::@2912": 0x80395cb4,
		"Player::@2913": 0x80395cc0,
		"Player::@2915": 0x80395cdc,
		"Player::@2916": 0x80395ce8,
		"Player::@2919": 0x80395d04,
		"Player::@2920": 0x80395d10,
		"Player::@2921": 0x80395d1c,
		"Player::@2922": 0x80395d2c,
		"Player::@2923": 0x80395d3c,
		"Player::@2924": 0x80395d48,
		"Player::@2925": 0x80395d58,
		"Player::@2926": 0x80395d64,
		"Player::@2928": 0x80395d84,
		"Player::@2929": 0x80395d94,
		"Player::@2931": 0x80395db0,
		"Player::@2932": 0x80395dc4,
		"Player::@2933": 0x80395dd4,
		"Player::@2934": 0x80395de8,
		"Player::@2935": 0x80395df8,
		"Player::@2936": 0x80395e04,
		"Player::@2937": 0x80395e10,
		"Player::@2940": 0x80395e30,
		"Player::@2941": 0x80395e3c,
		"Player::@2944": 0x80395e68,
		"Player::@2945": 0x80395e78,
		"Player::@2946": 0x80395e84,
		"Player::@2950": 0x80395ea8,
		"Player::@2960": 0x80395f00,
		"Player::@2961": 0x80395f0c,
		"Player::@2962": 0x80395f18,
		"Player::@5660": 0x80396528,
		"Player::@5662": 0x80396540,
		"@5662": 0x80396540,
		"Player::@5663": 0x8039654c,
		"@5663": 0x8039654c,
		"Player::@5665": 0x80396558,
		"Player::@5666": 0x80396570,
		"Player::@5667": 0x80396588,
		"Player::@5668": 0x803965a0,
		"Player::@5669": 0x803965b8,
		"Player::@5670": 0x803965d0,
		"Player::@5671": 0x803965e8,
		"@5671": 0x803965e8,
		"Player::@5672": 0x80396600,
		"@5672": 0x80396600,
		"Player::@5674": 0x80396618,
		"@5674": 0x80396618,
		"Player::@5675": 0x80396630,
		"@5675": 0x80396630,
		"Player::@5676": 0x80396654,
		"Player::@5677": 0x80396670,
		"@5677": 0x80396670,
		"Player::@5678": 0x8039669c,
		"@5678": 0x8039669c,
		"Player::@5679": 0x803966b8,
		"Player::cParticleIDs": 0x8039699c,
		"cParticleIDs": 0x8039699c,
		"Player::warpInEffectIDs": 0x803969a8,
		"warpInEffectIDs": 0x803969a8,
		"Player::@1937": 0x803969f4,
		"Player::@2386": 0x80396ab4,
		"Player::@2442": 0x80396ac8,
		"Player::@2443": 0x80396af8,
		"Player::@2444": 0x80396b30,
		"Player::bodyColor": 0x803973c4,
		"bodyColor": 0x803973c4,
		"Player::@2722": 0x80397adc,
		"Player::@2725": 0x80397afc,
		"Player::@3140": 0x803981c4,
		"Player::@3142": 0x803981d8,
		"Player::@3322": 0x80398444,
		"Player::@3324": 0x80398450,
		"Player::@3326": 0x8039845c,
		"Player::@3327": 0x80398474,
		"Player::@3328": 0x8039848c,
		"Player::@3329": 0x8039849c,
		"Player::@3330": 0x803984ac,
		"Player::@3337": 0x803984cc,
		"Player::@3338": 0x803984e0,
		"Player::@3468": 0x80398600,
		"Player::@3469": 0x80398610,
		"Player::@3470": 0x8039861c,
		"Player::@3472": 0x8039862c,
		"Player::@3477": 0x80398664,
		"Player::@3481": 0x803986a8,
		"Player::@3483": 0x803986b8,
		"Player::@3559": 0x80398718,
		"Player::@3560": 0x80398724,
		"Player::@3568": 0x8039878c,
		"Player::@3569": 0x80398798,
		"Player::@3570": 0x803987a8,
		"Player::@3572": 0x803987bc,
		"Player::@3573": 0x803987cc,
		"Player::@3575": 0x803987f0,
		"Player::@3736": 0x80398930,
		"Player::@3737": 0x80398940,
		"Player::@3739": 0x80398954,
		"Player::@3748": 0x803989f4,
		"Player::@3752": 0x80398a28,
		"Player::@3753": 0x80398a3c,
		"Player::@3755": 0x80398a4c,
		"Player::@3756": 0x80398a60,
		"Player::@3761": 0x80398aa4,
		"Player::@3762": 0x80398ab4,
		"Player::@3764": 0x80398ad4,
		"Player::@3765": 0x80398ae4,
		"Player::@3768": 0x80398b18,
		"Player::@3971": 0x80398b9c,
		"Player::@3973": 0x80398bc4,
		"Player::@3975": 0x80398be8,
		"Player::@3976": 0x80398bfc,
		"Player::@3977": 0x80398c10,
		"Player::@3978": 0x80398c1c,
		"Player::@3979": 0x80398c28,
		"Player::@3980": 0x80398c38,
		"Player::@3984": 0x80398c64,
		"Player::@3985": 0x80398c74,
		"Player::@3986": 0x80398c84,
		"Player::@3987": 0x80398c94,
		"Player::@3991": 0x80398cc4,
		"Player::@3993": 0x80398ce8,
		"Player::@3994": 0x80398cfc,
		"Player::@3995": 0x80398d10,
		"Player::@3996": 0x80398d20,
		"Player::@3997": 0x80398d2c,
		"Player::@3999": 0x80398d38,
		"Player::@4001": 0x80398d48,
		"Player::@4002": 0x80398d58,
		"Player::@4003": 0x80398d68,
		"Player::@4008": 0x80398db4,
		"Player::@4010": 0x80398dd8,
		"Player::@4011": 0x80398de8,
		"Player::@4012": 0x80398df8,
		"Player::@4016": 0x80398e50,
		"Player::@6516": 0x80398f10,
		"@6516": 0x80398f10,
		"Player::@6517": 0x80398f2c,
		"@6517": 0x80398f2c,
		"Player::@6518": 0x80398f48,
		"Player::@6519": 0x80398f68,
		"Player::@6520": 0x80398f94,
		"Player::@6521": 0x80398fb8,
		"Player::@6522": 0x80398fd4,
		"Player::@6523": 0x80398ff0,
		"Player::@6524": 0x80399010,
		"Player::@6525": 0x80399030,
		"@6525": 0x80399030,
		"Player::@6526": 0x80399050,
		"@6526": 0x80399050,
		"Player::@6527": 0x80399070,
		"@6527": 0x80399070,
		"Player::@6528": 0x80399084,
		"@6528": 0x80399084,
		"Player::@6529": 0x80399098,
		"@6529": 0x80399098,
		"Player::@6530": 0x803990b4,
		"@6530": 0x803990b4,
		"Player::@6531": 0x803990cc,
		"@6531": 0x803990cc,
		"Player::@6532": 0x803990e4,
		"@6532": 0x803990e4,
		"Player::@6533": 0x80399104,
		"@6533": 0x80399104,
		"Player::@6534": 0x8039911c,
		"@6534": 0x8039911c,
		"Player::@6535": 0x8039913c,
		"@6535": 0x8039913c,
		"Player::@6536": 0x8039915c,
		"@6536": 0x8039915c,
		"Player::@6537": 0x80399178,
		"@6537": 0x80399178,
		"Player::@6538": 0x80399190,
		"@6538": 0x80399190,
		"Player::@6539": 0x803991ac,
		"@6539": 0x803991ac,
		"Player::@6540": 0x803991c4,
		"@6540": 0x803991c4,
		"Player::@6541": 0x803991dc,
		"@6541": 0x803991dc,
		"Player::@6542": 0x803991f4,
		"@6542": 0x803991f4,
		"Player::@6543": 0x80399208,
		"@6543": 0x80399208,
		"Player::@6544": 0x80399224,
		"@6544": 0x80399224,
		"Player::@6545": 0x8039923c,
		"@6545": 0x8039923c,
		"Player::@6546": 0x80399258,
		"@6546": 0x80399258,
		"Player::@6547": 0x80399270,
		"@6547": 0x80399270,
		"Player::@6548": 0x80399288,
		"Player::@6549": 0x803992a4,
		"Player::@6550": 0x803992c0,
		"Player::@6551": 0x803992dc,
		"@6551": 0x803992dc,
		"Player::@6552": 0x803992f8,
		"Player::@6553": 0x80399314,
		"Player::@6554": 0x80399334,
		"Player::@6555": 0x80399350,
		"Player::@6556": 0x8039936c,
		"@6556": 0x8039936c,
		"Player::@6557": 0x80399390,
		"Player::@6558": 0x803993a8,
		"Player::@6559": 0x803993c0,
		"Player::@6560": 0x803993d8,
		"Player::@6561": 0x803993f0,
		"@6561": 0x803993f0,
		"Player::@6562": 0x80399408,
		"@6562": 0x80399408,
		"Player::@6563": 0x80399420,
		"@6563": 0x80399420,
		"Player::@6564": 0x80399438,
		"@6564": 0x80399438,
		"Player::@6565": 0x80399450,
		"@6565": 0x80399450,
		"Player::@6566": 0x80399468,
		"@6566": 0x80399468,
		"Player::@6567": 0x80399480,
		"@6567": 0x80399480,
		"Player::@2239": 0x803994a4,
		"Player::@2297": 0x80399520,
		"Player::@2298": 0x80399554,
		"Player::@2665": 0x80399578,
		"Player::@2666": 0x80399590,
		"Player::@2667": 0x803995a8,
		"Player::@2668": 0x803995c0,
		"Player::@2669": 0x803995dc,
		"Player::@2670": 0x803995f4,
		"Player::@2671": 0x8039960c,
		"Player::@2672": 0x80399624,
		"Player::@2673": 0x8039963c,
		"Player::@2674": 0x80399654,
		"Player::@2675": 0x80399670,
		"Player::@2676": 0x80399688,
		"Player::@2677": 0x803996a4,
		"Player::@2678": 0x803996c0,
		"Player::@2679": 0x803996d8,
		"Player::@2680": 0x803996f0,
		"Player::@2681": 0x80399708,
		"Player::@3162": 0x80399724,
		"Player::@4560": 0x80399730,
		"Player::@4628": 0x80399748,
		"Player::@4630": 0x80399780,
		"Player::@4635": 0x80399820,
		"Player::@4636": 0x80399844,
		"Player::@4645": 0x80399868,
		"Player::@4646": 0x80399874,
		"Player::@4647": 0x80399880,
		"Player::@4649": 0x8039988c,
		"Player::@4736": 0x80399898,
		"Player::@4738": 0x803998a4,
		"Player::@4741": 0x803998b0,
		"Player::@4742": 0x803998c0,
		"Player::@4743": 0x803998cc,
		"Player::@4746": 0x803998d8,
		"Player::@4876": 0x803998e4,
		"NPC::@2255": 0x8038c310,
		"NPC::@2256": 0x8038c340,
		"NPC::@2257": 0x8038c378,
		"NPC::@2258": 0x8038c3ac,
		"NPC::@2440": 0x8038c3d0,
		"NPC::sIndividualPeachBck$2896": 0x8038c3e0,
		"sIndividualPeachBck$2896": 0x8038c3e0,
		"NPC::sIndividualPeachBtp$2897": 0x8038c3f8,
		"sIndividualPeachBtp$2897": 0x8038c3f8,
		"NPC::sIndividualPeachBck$2904": 0x8038c408,
		"sIndividualPeachBck$2904": 0x8038c408,
		"NPC::sIndividualPeachBtp$2905": 0x8038c418,
		"sIndividualPeachBtp$2905": 0x8038c418,
		"NPC::sIndividualSunflowerBck$2906": 0x8038c428,
		"sIndividualSunflowerBck$2906": 0x8038c428,
		"NPC::sIndividualSunflowerBtp$2907": 0x8038c440,
		"sIndividualSunflowerBtp$2907": 0x8038c440,
		"NPC::@2053": 0x8038c514,
		"NPC::entry$2229": 0x8038c6e8,
		"entry$2229": 0x8038c6e8,
		"NPC::@2236": 0x8038c740,
		"NPC::@2237": 0x8038c750,
		"NPC::entry$2231": 0x8038c760,
		"entry$2231": 0x8038c760,
		"NPC::entry$2335": 0x8038c7c4,
		"entry$2335": 0x8038c7c4,
		"NPC::entry$2337": 0x8038c7ec,
		"entry$2337": 0x8038c7ec,
		"NPC::entry$2339": 0x8038c814,
		"entry$2339": 0x8038c814,
		"NPC::entry$2341": 0x8038c83c,
		"entry$2341": 0x8038c83c,
		"NPC::entry$2343": 0x8038c864,
		"entry$2343": 0x8038c864,
		"NPC::entry$2345": 0x8038c88c,
		"entry$2345": 0x8038c88c,
		"NPC::entry$2347": 0x8038c8a4,
		"entry$2347": 0x8038c8a4,
		"NPC::entry$2348": 0x8038c8bc,
		"entry$2348": 0x8038c8bc,
		"NPC::entry$2349": 0x8038c8d4,
		"entry$2349": 0x8038c8d4,
		"NPC::entry$2350": 0x8038c8fc,
		"entry$2350": 0x8038c8fc,
		"NPC::entry$2352": 0x8038c924,
		"entry$2352": 0x8038c924,
		"NPC::entry$2354": 0x8038c94c,
		"entry$2354": 0x8038c94c,
		"NPC::entry$2356": 0x8038c964,
		"entry$2356": 0x8038c964,
		"NPC::entry$2357": 0x8038c988,
		"entry$2357": 0x8038c988,
		"NPC::entry$2359": 0x8038c9ac,
		"entry$2359": 0x8038c9ac,
		"NPC::entry$2361": 0x8038c9d8,
		"entry$2361": 0x8038c9d8,
		"NPC::entry$2363": 0x8038ca00,
		"entry$2363": 0x8038ca00,
		"NPC::entry$2365": 0x8038ca28,
		"entry$2365": 0x8038ca28,
		"NPC::entry$2367": 0x8038ca4c,
		"entry$2367": 0x8038ca4c,
		"NPC::entry$2369": 0x8038ca74,
		"entry$2369": 0x8038ca74,
		"NPC::entry$2371": 0x8038ca9c,
		"entry$2371": 0x8038ca9c,
		"NPC::@2416": 0x8038cab4,
		"NPC::@2459": 0x8038cac4,
		"NPC::@2467": 0x8038cad4,
		"NPC::@2475": 0x8038cae4,
		"NPC::@1968": 0x8038cc64,
		"NPC::@1969": 0x8038cc78,
		"NPC::@1973": 0x8038ccc8,
		"NPC::@1974": 0x8038ccdc,
		"NPC::@1978": 0x8038cd2c,
		"NPC::@1979": 0x8038cd40,
		"NPC::@1982": 0x8038cd88,
		"NPC::@1983": 0x8038cd9c,
		"NPC::@2160": 0x8038cdb0,
		"NPC::@2162": 0x8038cdc0,
		"NPC::@2164": 0x8038cdd0,
		"NPC::@2166": 0x8038cde0,
		"NPC::@2168": 0x8038cdf4,
		"NPC::@2170": 0x8038ce0c,
		"NPC::@2172": 0x8038ce20,
		"NPC::@2174": 0x8038ce34,
		"NPC::@2176": 0x8038ce48,
		"NPC::@2178": 0x8038ce5c,
		"NPC::@2179": 0x8038ce6c,
		"NPC::@2181": 0x8038ce7c,
		"NPC::@2183": 0x8038ce88,
		"NPC::@2185": 0x8038ce94,
		"NPC::@2186": 0x8038cea4,
		"NPC::@2188": 0x8038ceb4,
		"NPC::@2190": 0x8038cec4,
		"NPC::@2191": 0x8038ced4,
		"NPC::@2192": 0x8038cee4,
		"NPC::@2193": 0x8038cef4,
		"NPC::@2195": 0x8038cf08,
		"NPC::@2203": 0x8038cf50,
		"NPC::@2205": 0x8038cf68,
		"NPC::@2209": 0x8038cf94,
		"NPC::@2228": 0x8038d058,
		"NPC::@2229": 0x8038d068,
		"NPC::@2231": 0x8038d080,
		"NPC::@2334": 0x8038d0d8,
		"NPC::@2335": 0x8038d0ec,
		"NPC::@2337": 0x8038d108,
		"NPC::@2339": 0x8038d12c,
		"NPC::@2343": 0x8038d170,
		"NPC::@2345": 0x8038d1a4,
		"NPC::@2357": 0x8038d274,
		"NPC::@2359": 0x8038d28c,
		"NPC::@2361": 0x8038d2b8,
		"NPC::@2363": 0x8038d2cc,
		"NPC::@2365": 0x8038d2dc,
		"NPC::@2367": 0x8038d2ec,
		"NPC::@2369": 0x8038d318,
		"NPC::@2371": 0x8038d348,
		"NPC::@2373": 0x8038d374,
		"NPC::@2417": 0x8038d398,
		"NPC::@2418": 0x8038d3ac,
		"NPC::@2420": 0x8038d3bc,
		"NPC::@2421": 0x8038d3d0,
		"NPC::@2422": 0x8038d3e4,
		"NPC::@2423": 0x8038d3f8,
		"NPC::@2424": 0x8038d40c,
		"NPC::@2426": 0x8038d434,
		"NPC::@2427": 0x8038d448,
		"NPC::@2431": 0x8038d49c,
		"NPC::@2721": 0x8038d6d8,
		"NPC::@2722": 0x8038d6f0,
		"NPC::@2723": 0x8038d708,
		"NPC::@2724": 0x8038d714,
		"NPC::@1530": 0x8038d800,
		"@1530": 0x8038d800,
		"NPC::@1535": 0x8038d810,
		"NPC::@1536": 0x8038d834,
		"NPC::sMonteM_HatAColorBuf0": 0x8038d848,
		"sMonteM_HatAColorBuf0": 0x8038d848,
		"NPC::sMonteM_HatAColorBuf1": 0x8038d880,
		"sMonteM_HatAColorBuf1": 0x8038d880,
		"NPC::@1537": 0x8038d8b8,
		"NPC::sMonteM_HatAColorChange": 0x8038d8c4,
		"sMonteM_HatAColorChange": 0x8038d8c4,
		"NPC::sMonteM_HatABeltColorBuf": 0x8038d8d4,
		"sMonteM_HatABeltColorBuf": 0x8038d8d4,
		"NPC::@1538": 0x8038d90c,
		"NPC::sMonteM_HatABeltColorChange": 0x8038d918,
		"sMonteM_HatABeltColorChange": 0x8038d918,
		"NPC::@1540": 0x8038d928,
		"NPC::sMonteM_HatAData": 0x8038d938,
		"sMonteM_HatAData": 0x8038d938,
		"NPC::sMonteM_HatBColorBuf": 0x8038d964,
		"sMonteM_HatBColorBuf": 0x8038d964,
		"NPC::sMonteM_HatBColorChange": 0x8038d97c,
		"sMonteM_HatBColorChange": 0x8038d97c,
		"NPC::sMonteM_HatBBeltColorBuf": 0x8038d98c,
		"sMonteM_HatBBeltColorBuf": 0x8038d98c,
		"NPC::sMonteM_HatBBeltColorChange": 0x8038d9a4,
		"sMonteM_HatBBeltColorChange": 0x8038d9a4,
		"NPC::@1541": 0x8038d9b4,
		"NPC::sMonteM_HatBData": 0x8038d9c4,
		"sMonteM_HatBData": 0x8038d9c4,
		"NPC::sMonteM_HatDColorBuf": 0x8038d9f0,
		"sMonteM_HatDColorBuf": 0x8038d9f0,
		"NPC::sMonteM_HatDColorChange": 0x8038da00,
		"sMonteM_HatDColorChange": 0x8038da00,
		"NPC::@1542": 0x8038da10,
		"NPC::sMonteM_HatDData": 0x8038da20,
		"sMonteM_HatDData": 0x8038da20,
		"NPC::sMonteM_HatEColorBuf0": 0x8038da4c,
		"sMonteM_HatEColorBuf0": 0x8038da4c,
		"NPC::sMonteM_HatEColorBuf1": 0x8038da5c,
		"sMonteM_HatEColorBuf1": 0x8038da5c,
		"NPC::sMonteM_HatEColorChange": 0x8038da6c,
		"sMonteM_HatEColorChange": 0x8038da6c,
		"NPC::@1543": 0x8038da7c,
		"NPC::sMonteM_HatEData": 0x8038da8c,
		"sMonteM_HatEData": 0x8038da8c,
		"NPC::sMonteM_HatFColorBuf0": 0x8038dab8,
		"sMonteM_HatFColorBuf0": 0x8038dab8,
		"NPC::sMonteM_HatFColorBuf1": 0x8038dac8,
		"sMonteM_HatFColorBuf1": 0x8038dac8,
		"NPC::sMonteM_HatFColorChange": 0x8038dad8,
		"sMonteM_HatFColorChange": 0x8038dad8,
		"NPC::@1544": 0x8038dae8,
		"NPC::sMonteM_HatFData": 0x8038daf8,
		"sMonteM_HatFData": 0x8038daf8,
		"NPC::sMonteM_HatGColorBuf0": 0x8038db24,
		"sMonteM_HatGColorBuf0": 0x8038db24,
		"NPC::sMonteM_HatGColorBuf1": 0x8038db4c,
		"sMonteM_HatGColorBuf1": 0x8038db4c,
		"NPC::sMonteM_HatGColorChange": 0x8038db74,
		"sMonteM_HatGColorChange": 0x8038db74,
		"NPC::@1545": 0x8038db84,
		"NPC::sMonteM_HatGData": 0x8038db94,
		"sMonteM_HatGData": 0x8038db94,
		"NPC::sMonteM_MustacheAColorBuf0": 0x8038dbc0,
		"sMonteM_MustacheAColorBuf0": 0x8038dbc0,
		"NPC::@1546": 0x8038dbe0,
		"NPC::sMonteM_MustacheAColorChange": 0x8038dbec,
		"sMonteM_MustacheAColorChange": 0x8038dbec,
		"NPC::@1547": 0x8038dbfc,
		"NPC::sMonteM_MustacheAData": 0x8038dc0c,
		"sMonteM_MustacheAData": 0x8038dc0c,
		"NPC::@1548": 0x8038dc38,
		"NPC::sMonteM_GlassesAData": 0x8038dc4c,
		"sMonteM_GlassesAData": 0x8038dc4c,
		"NPC::sMonteM_GlassesBColorBuf0": 0x8038dc78,
		"sMonteM_GlassesBColorBuf0": 0x8038dc78,
		"NPC::@1549": 0x8038dc90,
		"NPC::sMonteM_GlassesBColorChange": 0x8038dc9c,
		"sMonteM_GlassesBColorChange": 0x8038dc9c,
		"NPC::@1550": 0x8038dcac,
		"NPC::sMonteM_GlassesBData": 0x8038dcc0,
		"sMonteM_GlassesBData": 0x8038dcc0,
		"NPC::sMonteM_LapelAColorBuf0": 0x8038dcec,
		"sMonteM_LapelAColorBuf0": 0x8038dcec,
		"NPC::sMonteM_LapelAColorBuf1": 0x8038dcfc,
		"sMonteM_LapelAColorBuf1": 0x8038dcfc,
		"NPC::@1551": 0x8038dd0c,
		"NPC::sMonteM_LapelAColorChange": 0x8038dd18,
		"sMonteM_LapelAColorChange": 0x8038dd18,
		"NPC::@1552": 0x8038dd28,
		"NPC::@1553": 0x8038dd34,
		"NPC::sMonteM_LapelAData": 0x8038dd44,
		"sMonteM_LapelAData": 0x8038dd44,
		"NPC::@1554": 0x8038dd70,
		"NPC::sMonteM_TieBColorChange": 0x8038dd7c,
		"sMonteM_TieBColorChange": 0x8038dd7c,
		"NPC::@1555": 0x8038dd8c,
		"NPC::sMonteM_TieBData": 0x8038dd9c,
		"sMonteM_TieBData": 0x8038dd9c,
		"NPC::@1556": 0x8038ddc8,
		"NPC::sMonteM_LuggageData": 0x8038dddc,
		"sMonteM_LuggageData": 0x8038dddc,
		"NPC::@1557": 0x8038de08,
		"NPC::sMonteMF_TubeData": 0x8038de18,
		"sMonteMF_TubeData": 0x8038de18,
		"NPC::@1558": 0x8038de44,
		"NPC::@1559": 0x8038de50,
		"NPC::sMonteMG_MopData": 0x8038de60,
		"sMonteMG_MopData": 0x8038de60,
		"NPC::@1560": 0x8038de8c,
		"NPC::sMonteMH_UkleleData": 0x8038dea0,
		"sMonteMH_UkleleData": 0x8038dea0,
		"NPC::sMonteW_FlowerInColorBuf": 0x8038decc,
		"sMonteW_FlowerInColorBuf": 0x8038decc,
		"NPC::@1561": 0x8038dee4,
		"NPC::sMonteW_FlowerInColorChange": 0x8038def0,
		"sMonteW_FlowerInColorChange": 0x8038def0,
		"NPC::sMonteW_FlowerOutColorBuf": 0x8038df00,
		"sMonteW_FlowerOutColorBuf": 0x8038df00,
		"NPC::@1562": 0x8038df18,
		"NPC::sMonteW_FlowerOutColorChange": 0x8038df24,
		"sMonteW_FlowerOutColorChange": 0x8038df24,
		"NPC::@1563": 0x8038df34,
		"NPC::@1564": 0x8038df40,
		"NPC::sMonteW_FlowerData": 0x8038df54,
		"sMonteW_FlowerData": 0x8038df54,
		"NPC::sMonteW_HatAMainColorBuf0": 0x8038df80,
		"sMonteW_HatAMainColorBuf0": 0x8038df80,
		"NPC::sMonteW_HatAMainColorBuf1": 0x8038dfa0,
		"sMonteW_HatAMainColorBuf1": 0x8038dfa0,
		"NPC::sMonteW_HatAMainColorChange": 0x8038dfc0,
		"sMonteW_HatAMainColorChange": 0x8038dfc0,
		"NPC::sMonteW_HatABeltColorBuf": 0x8038dfd0,
		"sMonteW_HatABeltColorBuf": 0x8038dfd0,
		"NPC::sMonteW_HatABeltColorChange": 0x8038dff0,
		"sMonteW_HatABeltColorChange": 0x8038dff0,
		"NPC::@1565": 0x8038e000,
		"NPC::sMonteW_HatAData": 0x8038e010,
		"sMonteW_HatAData": 0x8038e010,
		"NPC::sMonteW_GlassBColorBuf": 0x8038e03c,
		"sMonteW_GlassBColorBuf": 0x8038e03c,
		"NPC::sMonteW_GlassBColorChange": 0x8038e054,
		"sMonteW_GlassBColorChange": 0x8038e054,
		"NPC::@1566": 0x8038e064,
		"NPC::sMonteW_GlassBData": 0x8038e074,
		"sMonteW_GlassBData": 0x8038e074,
		"NPC::@1567": 0x8038e0a0,
		"NPC::sMonteW_ArrowRData": 0x8038e0b4,
		"sMonteW_ArrowRData": 0x8038e0b4,
		"NPC::@1568": 0x8038e0e0,
		"NPC::sMonteW_ArrowLData": 0x8038e0f4,
		"sMonteW_ArrowLData": 0x8038e0f4,
		"NPC::@1569": 0x8038e120,
		"NPC::sMonteWC_HatCData": 0x8038e130,
		"sMonteWC_HatCData": 0x8038e130,
		"NPC::@1570": 0x8038e15c,
		"NPC::sMonteWC_BraceletRData": 0x8038e170,
		"sMonteWC_BraceletRData": 0x8038e170,
		"NPC::@1571": 0x8038e19c,
		"NPC::@1572": 0x8038e1a8,
		"NPC::sMonteWC_BraceletLData": 0x8038e1bc,
		"sMonteWC_BraceletLData": 0x8038e1bc,
		"NPC::sMareM_HatAColorBuf0": 0x8038e1e8,
		"sMareM_HatAColorBuf0": 0x8038e1e8,
		"NPC::sMareM_HatAColorBuf1": 0x8038e230,
		"sMareM_HatAColorBuf1": 0x8038e230,
		"NPC::sMareM_HatAColorChange": 0x8038e278,
		"sMareM_HatAColorChange": 0x8038e278,
		"NPC::@1574": 0x8038e288,
		"NPC::sMareM_HatAData": 0x8038e298,
		"sMareM_HatAData": 0x8038e298,
		"NPC::sMareM_HatBColorBuf0": 0x8038e2c4,
		"sMareM_HatBColorBuf0": 0x8038e2c4,
		"NPC::sMareM_HatBColorBuf1": 0x8038e2f4,
		"sMareM_HatBColorBuf1": 0x8038e2f4,
		"NPC::sMareM_HatBColorChange": 0x8038e324,
		"sMareM_HatBColorChange": 0x8038e324,
		"NPC::@1575": 0x8038e334,
		"NPC::sMareM_HatBData": 0x8038e344,
		"sMareM_HatBData": 0x8038e344,
		"NPC::sMareM_HatEColorBuf0": 0x8038e370,
		"sMareM_HatEColorBuf0": 0x8038e370,
		"NPC::sMareM_HatEColorBuf1": 0x8038e3c8,
		"sMareM_HatEColorBuf1": 0x8038e3c8,
		"NPC::sMareM_HatEColorChange": 0x8038e420,
		"sMareM_HatEColorChange": 0x8038e420,
		"NPC::@1576": 0x8038e430,
		"NPC::sMareM_HatEData": 0x8038e440,
		"sMareM_HatEData": 0x8038e440,
		"NPC::sMareM_ShellAColorBuf0": 0x8038e46c,
		"sMareM_ShellAColorBuf0": 0x8038e46c,
		"NPC::sMareM_ShellAColorBuf1": 0x8038e4bc,
		"sMareM_ShellAColorBuf1": 0x8038e4bc,
		"NPC::sMareM_ShellAColorChange": 0x8038e50c,
		"sMareM_ShellAColorChange": 0x8038e50c,
		"NPC::@1578": 0x8038e51c,
		"NPC::sMareM_ShellAData": 0x8038e530,
		"sMareM_ShellAData": 0x8038e530,
		"NPC::sMareM_ShellBColorBuf0": 0x8038e55c,
		"sMareM_ShellBColorBuf0": 0x8038e55c,
		"NPC::sMareM_ShellBColorBuf1": 0x8038e5ac,
		"sMareM_ShellBColorBuf1": 0x8038e5ac,
		"NPC::sMareM_ShellBColorChange": 0x8038e5fc,
		"sMareM_ShellBColorChange": 0x8038e5fc,
		"NPC::@1579": 0x8038e60c,
		"NPC::sMareM_ShellBData": 0x8038e620,
		"sMareM_ShellBData": 0x8038e620,
		"NPC::sMareM_BivalveBColorBuf0": 0x8038e64c,
		"sMareM_BivalveBColorBuf0": 0x8038e64c,
		"NPC::sMareM_BivalveBColorBuf1": 0x8038e67c,
		"sMareM_BivalveBColorBuf1": 0x8038e67c,
		"NPC::sMareM_BivalveBColorChange": 0x8038e6ac,
		"sMareM_BivalveBColorChange": 0x8038e6ac,
		"NPC::@1580": 0x8038e6bc,
		"NPC::sMareM_BivalveBData": 0x8038e6d0,
		"sMareM_BivalveBData": 0x8038e6d0,
		"NPC::sMareM_GlassColorBuf0": 0x8038e6fc,
		"sMareM_GlassColorBuf0": 0x8038e6fc,
		"NPC::sMareM_GlassColorBuf1": 0x8038e714,
		"sMareM_GlassColorBuf1": 0x8038e714,
		"NPC::@1581": 0x8038e72c,
		"NPC::sMareM_GlassColorChange": 0x8038e738,
		"sMareM_GlassColorChange": 0x8038e738,
		"NPC::@1582": 0x8038e748,
		"NPC::sMareM_GlassData": 0x8038e758,
		"sMareM_GlassData": 0x8038e758,
		"NPC::sMareMB_ElderMat1ColorChange": 0x8038e784,
		"sMareMB_ElderMat1ColorChange": 0x8038e784,
		"NPC::sMareMB_ElderMat2ColorChange": 0x8038e794,
		"sMareMB_ElderMat2ColorChange": 0x8038e794,
		"NPC::sMareMB_ElderMat3ColorChange": 0x8038e7a4,
		"sMareMB_ElderMat3ColorChange": 0x8038e7a4,
		"NPC::@1585": 0x8038e7b4,
		"NPC::sMareMB_ElderData": 0x8038e7c4,
		"sMareMB_ElderData": 0x8038e7c4,
		"NPC::sMareMB_FishingRodMat1ColorChange": 0x8038e7f0,
		"sMareMB_FishingRodMat1ColorChange": 0x8038e7f0,
		"NPC::sMareMB_FishingRodMat2ColorChange": 0x8038e800,
		"sMareMB_FishingRodMat2ColorChange": 0x8038e800,
		"NPC::sMareMB_FishingRodMat3ColorChange": 0x8038e810,
		"sMareMB_FishingRodMat3ColorChange": 0x8038e810,
		"NPC::@1586": 0x8038e820,
		"NPC::sMareMC_HatFColorChange": 0x8038e834,
		"sMareMC_HatFColorChange": 0x8038e834,
		"NPC::@1587": 0x8038e844,
		"NPC::sMareMC_HatFData": 0x8038e854,
		"sMareMC_HatFData": 0x8038e854,
		"NPC::sMareMC_BeardColorChange": 0x8038e880,
		"sMareMC_BeardColorChange": 0x8038e880,
		"NPC::@1588": 0x8038e890,
		"NPC::sMareMC_BeardData": 0x8038e8a4,
		"sMareMC_BeardData": 0x8038e8a4,
		"NPC::sMareMC_MustacheColorChange": 0x8038e8d0,
		"sMareMC_MustacheColorChange": 0x8038e8d0,
		"NPC::@1589": 0x8038e8e0,
		"NPC::sMareMC_MustacheData": 0x8038e8f4,
		"sMareMC_MustacheData": 0x8038e8f4,
		"NPC::sMareMD_PipeColorChange": 0x8038e920,
		"sMareMD_PipeColorChange": 0x8038e920,
		"NPC::@1591": 0x8038e930,
		"NPC::sMareMD_PipeData": 0x8038e944,
		"sMareMD_PipeData": 0x8038e944,
		"NPC::sMareW_PearlAColorBuf0": 0x8038e970,
		"sMareW_PearlAColorBuf0": 0x8038e970,
		"NPC::sMareW_PearlAColorBuf1": 0x8038e9a0,
		"sMareW_PearlAColorBuf1": 0x8038e9a0,
		"NPC::sMareW_PearlAColorChange": 0x8038e9d0,
		"sMareW_PearlAColorChange": 0x8038e9d0,
		"NPC::@1592": 0x8038e9e0,
		"NPC::sMareW_PearlAData": 0x8038e9f4,
		"sMareW_PearlAData": 0x8038e9f4,
		"NPC::sMareW_HatAColorBuf0": 0x8038ea20,
		"sMareW_HatAColorBuf0": 0x8038ea20,
		"NPC::sMareW_HatAColorBuf1": 0x8038ea50,
		"sMareW_HatAColorBuf1": 0x8038ea50,
		"NPC::sMareW_HatAColorChange": 0x8038ea80,
		"sMareW_HatAColorChange": 0x8038ea80,
		"NPC::@1593": 0x8038ea90,
		"NPC::sMareW_HatAData": 0x8038eaa0,
		"sMareW_HatAData": 0x8038eaa0,
		"NPC::sMareW_HatDColorBuf0": 0x8038eacc,
		"sMareW_HatDColorBuf0": 0x8038eacc,
		"NPC::sMareW_HatDColorBuf1": 0x8038eb24,
		"sMareW_HatDColorBuf1": 0x8038eb24,
		"NPC::sMareW_HatDColorChange": 0x8038eb7c,
		"sMareW_HatDColorChange": 0x8038eb7c,
		"NPC::@1594": 0x8038eb8c,
		"NPC::sMareW_HatDData": 0x8038eb9c,
		"sMareW_HatDData": 0x8038eb9c,
		"NPC::sMareW_ShellAColorBuf0": 0x8038ebc8,
		"sMareW_ShellAColorBuf0": 0x8038ebc8,
		"NPC::sMareW_ShellAColorBuf1": 0x8038ebf8,
		"sMareW_ShellAColorBuf1": 0x8038ebf8,
		"NPC::sMareW_ShellAColorChange": 0x8038ec28,
		"sMareW_ShellAColorChange": 0x8038ec28,
		"NPC::@1595": 0x8038ec38,
		"NPC::sMareW_ShellAData": 0x8038ec48,
		"sMareW_ShellAData": 0x8038ec48,
		"NPC::sMareW_ShellBColorBuf0": 0x8038ec74,
		"sMareW_ShellBColorBuf0": 0x8038ec74,
		"NPC::sMareW_ShellBColorBuf1": 0x8038ecbc,
		"sMareW_ShellBColorBuf1": 0x8038ecbc,
		"NPC::sMareW_ShellBColorChange": 0x8038ed04,
		"sMareW_ShellBColorChange": 0x8038ed04,
		"NPC::@1596": 0x8038ed14,
		"NPC::sMareW_ShellBData": 0x8038ed24,
		"sMareW_ShellBData": 0x8038ed24,
		"NPC::sMareW_BivalveAColorBuf0": 0x8038ed50,
		"sMareW_BivalveAColorBuf0": 0x8038ed50,
		"NPC::sMareW_BivalveAColorBuf1": 0x8038ed80,
		"sMareW_BivalveAColorBuf1": 0x8038ed80,
		"NPC::sMareW_BivalveAColorChange": 0x8038edb0,
		"sMareW_BivalveAColorChange": 0x8038edb0,
		"NPC::@1597": 0x8038edc0,
		"NPC::sMareW_BivalveAData": 0x8038edd4,
		"sMareW_BivalveAData": 0x8038edd4,
		"NPC::sMareWB_BabyBodyColorChange": 0x8038ee00,
		"sMareWB_BabyBodyColorChange": 0x8038ee00,
		"NPC::@1599": 0x8038ee10,
		"NPC::sMareWB_BabyHatColorChange": 0x8038ee1c,
		"sMareWB_BabyHatColorChange": 0x8038ee1c,
		"NPC::@1600": 0x8038ee2c,
		"NPC::sMareWB_BabyBedColorChange": 0x8038ee38,
		"sMareWB_BabyBedColorChange": 0x8038ee38,
		"NPC::@1601": 0x8038ee48,
		"NPC::@1602": 0x8038ee58,
		"NPC::sKinopio_SunGlassesData": 0x8038ee70,
		"sKinopio_SunGlassesData": 0x8038ee70,
		"NPC::@1603": 0x8038ee9c,
		"NPC::@1604": 0x8038eeac,
		"NPC::sKinojii_StickData": 0x8038eec0,
		"sKinojii_StickData": 0x8038eec0,
		"NPC::@1605": 0x8038eeec,
		"NPC::sPeach_HairNormalData": 0x8038ef04,
		"sPeach_HairNormalData": 0x8038ef04,
		"NPC::@1606": 0x8038ef30,
		"NPC::@1607": 0x8038ef3c,
		"NPC::sPeach_Hand1LData": 0x8038ef50,
		"sPeach_Hand1LData": 0x8038ef50,
		"NPC::@1608": 0x8038ef7c,
		"NPC::@1609": 0x8038ef88,
		"NPC::sPeach_Hand1RData": 0x8038ef9c,
		"sPeach_Hand1RData": 0x8038ef9c,
		"NPC::@1610": 0x8038efc8,
		"NPC::sPeach_HairPonytailData": 0x8038efe0,
		"sPeach_HairPonytailData": 0x8038efe0,
		"NPC::@1611": 0x8038f00c,
		"NPC::sPeach_ParasolData": 0x8038f020,
		"sPeach_ParasolData": 0x8038f020,
		"NPC::@1612": 0x8038f04c,
		"NPC::sPeach_Hand2LData": 0x8038f060,
		"sPeach_Hand2LData": 0x8038f060,
		"NPC::@1613": 0x8038f08c,
		"@1613": 0x8038f08c,
		"NPC::sPeach_Hand2RData": 0x8038f0a0,
		"sPeach_Hand2RData": 0x8038f0a0,
		"NPC::sRaccoonDog_TubeColorBuf0": 0x8038f0cc,
		"sRaccoonDog_TubeColorBuf0": 0x8038f0cc,
		"NPC::sRaccoonDog_TubeColorBuf1": 0x8038f0dc,
		"sRaccoonDog_TubeColorBuf1": 0x8038f0dc,
		"NPC::sRaccoonDog_TubeColorChange": 0x8038f0ec,
		"sRaccoonDog_TubeColorChange": 0x8038f0ec,
		"NPC::@1615": 0x8038f0fc,
		"NPC::@1616": 0x8038f108,
		"NPC::sRaccoonDog_TubeData": 0x8038f114,
		"sRaccoonDog_TubeData": 0x8038f114,
		"NPC::sMonteM_BodyColorBuf": 0x8038f140,
		"sMonteM_BodyColorBuf": 0x8038f140,
		"NPC::@1617": 0x8038f190,
		"NPC::sMonteM_BodyColor": 0x8038f19c,
		"sMonteM_BodyColor": 0x8038f19c,
		"NPC::sMonteMA_ClothColorBuf0": 0x8038f1ac,
		"sMonteMA_ClothColorBuf0": 0x8038f1ac,
		"NPC::sMonteMA_ClothColorBuf1": 0x8038f204,
		"sMonteMA_ClothColorBuf1": 0x8038f204,
		"NPC::@1618": 0x8038f25c,
		"NPC::sMonteMA_ClothColor": 0x8038f268,
		"sMonteMA_ClothColor": 0x8038f268,
		"NPC::sMonteMB_BodyColorBuf": 0x8038f278,
		"sMonteMB_BodyColorBuf": 0x8038f278,
		"NPC::sMonteMB_BodyColor": 0x8038f298,
		"sMonteMB_BodyColor": 0x8038f298,
		"NPC::sMonteMB_ClothColorBuf": 0x8038f2a8,
		"sMonteMB_ClothColorBuf": 0x8038f2a8,
		"NPC::sMonteMB_ClothColor": 0x8038f2d8,
		"sMonteMB_ClothColor": 0x8038f2d8,
		"NPC::sMonteMC_ClothColorBuf0": 0x8038f2e8,
		"sMonteMC_ClothColorBuf0": 0x8038f2e8,
		"NPC::sMonteMC_ClothColorBuf1": 0x8038f340,
		"sMonteMC_ClothColorBuf1": 0x8038f340,
		"NPC::sMonteMC_ClothColor": 0x8038f398,
		"sMonteMC_ClothColor": 0x8038f398,
		"NPC::sMonteMD_ClothColorBuf": 0x8038f3a8,
		"sMonteMD_ClothColorBuf": 0x8038f3a8,
		"NPC::sMonteMD_ClothColor": 0x8038f3d0,
		"sMonteMD_ClothColor": 0x8038f3d0,
		"NPC::sMonteW_ColorBuf": 0x8038f3e0,
		"sMonteW_ColorBuf": 0x8038f3e0,
		"NPC::sMonteW_BodyColor": 0x8038f410,
		"sMonteW_BodyColor": 0x8038f410,
		"NPC::sMonteWA_ClothColorBuf": 0x8038f420,
		"sMonteWA_ClothColorBuf": 0x8038f420,
		"NPC::sMonteWA_ClothColor": 0x8038f450,
		"sMonteWA_ClothColor": 0x8038f450,
		"NPC::sMonteWB_ClothColorBuf0": 0x8038f460,
		"sMonteWB_ClothColorBuf0": 0x8038f460,
		"NPC::sMonteWB_ClothColorBuf1": 0x8038f4a8,
		"sMonteWB_ClothColorBuf1": 0x8038f4a8,
		"NPC::sMonteWB_ClothColor": 0x8038f4f0,
		"sMonteWB_ClothColor": 0x8038f4f0,
		"NPC::sMareM_ColorBuf": 0x8038f500,
		"sMareM_ColorBuf": 0x8038f500,
		"NPC::sMareM_BodyColor": 0x8038f530,
		"sMareM_BodyColor": 0x8038f530,
		"NPC::sMareW_ColorBuf": 0x8038f540,
		"sMareW_ColorBuf": 0x8038f540,
		"NPC::sMareW_BodyColor": 0x8038f570,
		"sMareW_BodyColor": 0x8038f570,
		"NPC::sKinopio_BodyColorData0": 0x8038f580,
		"sKinopio_BodyColorData0": 0x8038f580,
		"NPC::sKinopio_BodyColorData1": 0x8038f5a8,
		"sKinopio_BodyColorData1": 0x8038f5a8,
		"NPC::@1619": 0x8038f5d0,
		"NPC::sKinopio_BodyColor": 0x8038f5dc,
		"sKinopio_BodyColor": 0x8038f5dc,
		"NPC::sKinopio_ClothColorData0": 0x8038f5ec,
		"sKinopio_ClothColorData0": 0x8038f5ec,
		"NPC::sKinopio_ClothColorData1": 0x8038f614,
		"sKinopio_ClothColorData1": 0x8038f614,
		"NPC::@1620": 0x8038f63c,
		"NPC::sKinopio_ClothColor": 0x8038f648,
		"sKinopio_ClothColor": 0x8038f648,
		"NPC::sRaccoonDog_ClothColorBuf0": 0x8038f658,
		"sRaccoonDog_ClothColorBuf0": 0x8038f658,
		"NPC::sRaccoonDog_ClothColorBuf1": 0x8038f668,
		"sRaccoonDog_ClothColorBuf1": 0x8038f668,
		"NPC::sRaccoonDog_ClothColor": 0x8038f678,
		"sRaccoonDog_ClothColor": 0x8038f678,
		"NPC::sMonteM_InitData": 0x8038f688,
		"sMonteM_InitData": 0x8038f688,
		"NPC::sMonteMA_InitData": 0x8038f6dc,
		"sMonteMA_InitData": 0x8038f6dc,
		"NPC::sMonteMB_InitData": 0x8038f730,
		"sMonteMB_InitData": 0x8038f730,
		"NPC::sMonteMC_InitData": 0x8038f784,
		"sMonteMC_InitData": 0x8038f784,
		"NPC::sMonteMD_InitData": 0x8038f7d8,
		"sMonteMD_InitData": 0x8038f7d8,
		"NPC::sMonteME_InitData": 0x8038f82c,
		"sMonteME_InitData": 0x8038f82c,
		"NPC::sMonteMF_InitData": 0x8038f880,
		"sMonteMF_InitData": 0x8038f880,
		"NPC::sMonteMG_InitData": 0x8038f8d4,
		"sMonteMG_InitData": 0x8038f8d4,
		"NPC::sMonteMH_InitData": 0x8038f928,
		"sMonteMH_InitData": 0x8038f928,
		"NPC::sMonteW_InitData": 0x8038f97c,
		"sMonteW_InitData": 0x8038f97c,
		"NPC::sMonteWA_InitData": 0x8038f9d0,
		"sMonteWA_InitData": 0x8038f9d0,
		"NPC::sMonteWB_InitData": 0x8038fa24,
		"sMonteWB_InitData": 0x8038fa24,
		"NPC::sMonteWC_InitData": 0x8038fa78,
		"sMonteWC_InitData": 0x8038fa78,
		"NPC::sMareM_InitData": 0x8038facc,
		"sMareM_InitData": 0x8038facc,
		"NPC::sMareMB_InitData": 0x8038fb20,
		"sMareMB_InitData": 0x8038fb20,
		"NPC::sMareMC_InitData": 0x8038fb74,
		"sMareMC_InitData": 0x8038fb74,
		"NPC::sMareMD_InitData": 0x8038fbc8,
		"sMareMD_InitData": 0x8038fbc8,
		"NPC::sMareW_InitData": 0x8038fc1c,
		"sMareW_InitData": 0x8038fc1c,
		"NPC::sMareWB_InitData": 0x8038fc70,
		"sMareWB_InitData": 0x8038fc70,
		"NPC::sKinopio_InitData": 0x8038fcc4,
		"sKinopio_InitData": 0x8038fcc4,
		"NPC::sKinojii_InitData": 0x8038fd18,
		"sKinojii_InitData": 0x8038fd18,
		"NPC::sPeach_InitData": 0x8038fd6c,
		"sPeach_InitData": 0x8038fd6c,
		"NPC::sRaccoonDog_InitData": 0x8038fdc0,
		"sRaccoonDog_InitData": 0x8038fdc0,
		"NPC::sSunflowerL_InitData": 0x8038fe14,
		"sSunflowerL_InitData": 0x8038fe14,
		"NPC::sSunflowerS_InitData": 0x8038fe68,
		"sSunflowerS_InitData": 0x8038fe68,
		"NPC::sBoardNpc_InitData": 0x8038febc,
		"sBoardNpc_InitData": 0x8038febc,
		"TBaseNPC::sMtxEffectInitData$localstatic1$setMtxEffect_": 0x80390080,
		"sMtxEffectInitData$localstatic1$setMtxEffect_": 0x80390080,
		"TBaseNPC::sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x80390160,
		"sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x80390160,
		"TBaseNPC::sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x80390170,
		"sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x80390170,
		"TBaseNPC::sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x803901a8,
		"sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x803901a8,
		"TBaseNPC::sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x803901c0,
		"sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x803901c0,
		"TBaseNPC::sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x803901f0,
		"sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x803901f0,
		"TBaseNPC::sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80390208,
		"sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80390208,
		"TBaseNPC::sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x80390218,
		"sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x80390218,
		"TBaseNPC::sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x80390228,
		"sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x80390228,
		"TBaseNPC::sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x80390238,
		"sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x80390238,
		"TBaseNPC::sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x80390248,
		"sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x80390248,
		"TBaseNPC::sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x80390258,
		"sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x80390258,
		"NPC::@2266": 0x80390348,
		"NPC::@2275": 0x80390358,
		"NPC::@2489": 0x80390380,
		"NPC::@1938": 0x80390480,
		"NPC::@1939": 0x803904a8,
		"NPC::@1940": 0x803904d0,
		"NPC::@1941": 0x803904f8,
		"NPC::@1942": 0x80390520,
		"NPC::@1943": 0x80390544,
		"NPC::@1944": 0x8039056c,
		"NPC::@1945": 0x80390594,
		"NPC::@1946": 0x803905b8,
		"NPC::@1947": 0x803905e0,
		"NPC::@1948": 0x80390608,
		"NPC::@1949": 0x80390634,
		"NPC::@1950": 0x8039065c,
		"NPC::@1951": 0x80390680,
		"NPC::@1952": 0x803906a8,
		"NPC::@1953": 0x803906d4,
		"NPC::@1954": 0x80390700,
		"NPC::@1955": 0x80390728,
		"NPC::@1956": 0x80390750,
		"NPC::@1957": 0x80390778,
		"NPC::@1958": 0x803907a0,
		"NPC::@1959": 0x803907cc,
		"NPC::@1960": 0x803907f8,
		"NPC::@1984": 0x80390a78,
		"NPC::@1985": 0x80390a9c,
		"NPC::@1986": 0x80390ac4,
		"NPC::@1989": 0x80390aec,
		"NPC::@1990": 0x80390b14,
		"NPC::@1991": 0x80390b3c,
		"NPC::@1992": 0x80390b64,
		"NPC::@1993": 0x80390b8c,
		"NPC::@1994": 0x80390bb0,
		"NPC::@1995": 0x80390bd8,
		"NPC::@1996": 0x80390bfc,
		"NPC::@1997": 0x80390c24,
		"NPC::@1998": 0x80390c4c,
		"NPC::@1999": 0x80390c78,
		"NPC::@2000": 0x80390ca4,
		"NPC::@2001": 0x80390ccc,
		"NPC::@2002": 0x80390cf0,
		"NPC::@2003": 0x80390d18,
		"NPC::@2004": 0x80390d44,
		"NPC::@2005": 0x80390d70,
		"NPC::@2006": 0x80390d98,
		"NPC::@2007": 0x80390dc0,
		"NPC::@2008": 0x80390de8,
		"NPC::@2009": 0x80390e10,
		"NPC::@2010": 0x80390e3c,
		"NPC::@2011": 0x80390e64,
		"NPC::@2012": 0x80390e90,
		"NPC::@2013": 0x80390eb8,
		"NPC::@2014": 0x80390ee8,
		"NPC::@2015": 0x80390f18,
		"NPC::@2016": 0x80390f40,
		"NPC::@2017": 0x80390f68,
		"NPC::@2018": 0x80390f90,
		"NPC::@2021": 0x80390fc0,
		"NPC::@2022": 0x80390fe0,
		"NPC::@2023": 0x80391000,
		"NPC::@2026": 0x80391024,
		"NPC::@2027": 0x80391048,
		"NPC::@2028": 0x8039106c,
		"NPC::@2029": 0x8039108c,
		"NPC::@2030": 0x803910b0,
		"NPC::@2031": 0x803910d0,
		"NPC::@2032": 0x803910f4,
		"NPC::@2033": 0x80391114,
		"NPC::@2034": 0x80391138,
		"NPC::@2035": 0x8039115c,
		"NPC::@2036": 0x80391184,
		"NPC::@2037": 0x803911a4,
		"NPC::@2038": 0x803911c4,
		"NPC::@2039": 0x803911e4,
		"NPC::@2040": 0x80391208,
		"NPC::@2041": 0x8039122c,
		"NPC::@2042": 0x80391250,
		"NPC::@2043": 0x80391274,
		"NPC::@2044": 0x80391298,
		"NPC::@2045": 0x803912bc,
		"NPC::@2046": 0x803912e4,
		"NPC::@2047": 0x80391308,
		"NPC::@2048": 0x8039132c,
		"NPC::@2049": 0x80391354,
		"NPC::@2057": 0x803913e4,
		"NPC::@2059": 0x80391408,
		"NPC::@2060": 0x8039142c,
		"NPC::@2061": 0x80391454,
		"NPC::@2062": 0x80391478,
		"NPC::@2065": 0x8039149c,
		"NPC::@2066": 0x803914c0,
		"NPC::@2073": 0x80391570,
		"NPC::@2074": 0x80391594,
		"NPC::@2075": 0x803915b4,
		"NPC::@2076": 0x803915d8,
		"NPC::@2077": 0x803915fc,
		"NPC::@2078": 0x80391624,
		"NPC::@2079": 0x80391644,
		"NPC::@2080": 0x80391664,
		"NPC::@2081": 0x80391684,
		"NPC::@2083": 0x803916cc,
		"NPC::@2084": 0x803916f0,
		"NPC::@2085": 0x80391714,
		"NPC::@2086": 0x80391738,
		"NPC::@2087": 0x80391760,
		"NPC::@2088": 0x80391784,
		"NPC::@2089": 0x803917a8,
		"NPC::@2090": 0x803917d0,
		"NPC::@2091": 0x803917f4,
		"NPC::@2092": 0x80391818,
		"NPC::@2093": 0x8039183c,
		"NPC::@2098": 0x80391860,
		"NPC::@2099": 0x80391888,
		"NPC::@2100": 0x803918b4,
		"NPC::@2101": 0x803918e0,
		"NPC::@2102": 0x80391908,
		"NPC::@2113": 0x80391a68,
		"NPC::@2117": 0x80391b04,
		"NPC::@2120": 0x80391b30,
		"NPC::@2121": 0x80391b54,
		"NPC::@2122": 0x80391b7c,
		"NPC::@2123": 0x80391ba4,
		"NPC::@2124": 0x80391bcc,
		"NPC::@2125": 0x80391bf4,
		"NPC::@2126": 0x80391c18,
		"NPC::@2127": 0x80391c3c,
		"NPC::@2130": 0x80391c60,
		"NPC::@2131": 0x80391c88,
		"NPC::@2132": 0x80391cac,
		"NPC::@2133": 0x80391cd4,
		"NPC::@2134": 0x80391cfc,
		"NPC::@2135": 0x80391d20,
		"NPC::@2136": 0x80391d48,
		"NPC::@2139": 0x80391d68,
		"NPC::@2140": 0x80391d90,
		"NPC::@2141": 0x80391db8,
		"NPC::@2144": 0x80391de0,
		"NPC::@2145": 0x80391e0c,
		"NPC::@2146": 0x80391e34,
		"NPC::@2150": 0x80391e60,
		"NPC::@2151": 0x80391e8c,
		"NPC::@2152": 0x80391eb8,
		"NPC::@1700": 0x80391ef4,
		"NPC::@2153": 0x80391f08,
		"NPC::@2154": 0x80391f38,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x80391fd8,
		"sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x80391fd8,
		"TBaseNPC::sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x80391ff4,
		"sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x80391ff4,
		"TBaseNPC::sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x80392000,
		"sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x80392000,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8039200c,
		"sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8039200c,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8039201c,
		"sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8039201c,
		"NPC::@2696": 0x8039202c,
		"NPC::sMonteM_AnmIndex": 0x80392098,
		"sMonteM_AnmIndex": 0x80392098,
		"NPC::sMonteME_AnmIndex": 0x80392268,
		"sMonteME_AnmIndex": 0x80392268,
		"NPC::sMonteMF_AnmIndex": 0x80392438,
		"sMonteMF_AnmIndex": 0x80392438,
		"NPC::sMonteMG_AnmIndex": 0x80392608,
		"sMonteMG_AnmIndex": 0x80392608,
		"NPC::sMonteMH_AnmIndex": 0x803927d8,
		"sMonteMH_AnmIndex": 0x803927d8,
		"NPC::sMonteW_AnmIndex": 0x803929a8,
		"sMonteW_AnmIndex": 0x803929a8,
		"NPC::sMonteWC_AnmIndex": 0x80392b78,
		"sMonteWC_AnmIndex": 0x80392b78,
		"NPC::sMareM_AnmIndex": 0x80392d48,
		"sMareM_AnmIndex": 0x80392d48,
		"NPC::sMareMA_AnmIndex": 0x80392f18,
		"sMareMA_AnmIndex": 0x80392f18,
		"NPC::sMareMB_AnmIndex": 0x803930e8,
		"sMareMB_AnmIndex": 0x803930e8,
		"NPC::sMareMC_AnmIndex": 0x803932b8,
		"sMareMC_AnmIndex": 0x803932b8,
		"NPC::sMareMD_AnmIndex": 0x80393488,
		"sMareMD_AnmIndex": 0x80393488,
		"NPC::sMareW_AnmIndex": 0x80393658,
		"sMareW_AnmIndex": 0x80393658,
		"NPC::sMareWA_AnmIndex": 0x80393828,
		"sMareWA_AnmIndex": 0x80393828,
		"NPC::sMareWB_AnmIndex": 0x803939f8,
		"sMareWB_AnmIndex": 0x803939f8,
		"NPC::sKinopio_AnmIndex": 0x80393bc8,
		"sKinopio_AnmIndex": 0x80393bc8,
		"NPC::sKinojii_AnmIndex": 0x80393d98,
		"sKinojii_AnmIndex": 0x80393d98,
		"NPC::sPeach_AnmIndex": 0x80393f68,
		"sPeach_AnmIndex": 0x80393f68,
		"NPC::sRaccoonDog_AnmIndex": 0x80394138,
		"sRaccoonDog_AnmIndex": 0x80394138,
		"NPC::sSunflowerL_AnmIndex": 0x80394308,
		"sSunflowerL_AnmIndex": 0x80394308,
		"NPC::sSunflowerS_AnmIndex": 0x803944d8,
		"sSunflowerS_AnmIndex": 0x803944d8,
		"NPC::sMonteMA_IndividualBtp": 0x803946a8,
		"sMonteMA_IndividualBtp": 0x803946a8,
		"NPC::sMonteMB_IndividualBtp": 0x80394718,
		"sMonteMB_IndividualBtp": 0x80394718,
		"NPC::sMonteMC_IndividualBtp": 0x80394788,
		"sMonteMC_IndividualBtp": 0x80394788,
		"NPC::sMonteMD_IndividualBtp": 0x803947f8,
		"sMonteMD_IndividualBtp": 0x803947f8,
		"NPC::sMonteWA_IndividualBtp": 0x80394868,
		"sMonteWA_IndividualBtp": 0x80394868,
		"NPC::sMonteWB_IndividualBtp": 0x803948d8,
		"sMonteWB_IndividualBtp": 0x803948d8,
		"NPC::sAllNpcInitAnmData$1577": 0x80394948,
		"sAllNpcInitAnmData$1577": 0x80394948,
		"NPC::sBaseActionFlagTable$1938": 0x80394a30,
		"sBaseActionFlagTable$1938": 0x80394a30,
		"NPC::sBaseActionFlagTable$1941": 0x80394a94,
		"sBaseActionFlagTable$1941": 0x80394a94,
		"NPC::sBaseActionFlagTable$1944": 0x80394ad8,
		"sBaseActionFlagTable$1944": 0x80394ad8,
		"MSound::@1912": 0x8036c0a0,
		"MSound::@1501": 0x8036c128,
		"@1501": 0x8036c128,
		"MSound::@2817": 0x8036c148,
		"MSound::@2822": 0x8036c164,
		"MSound::@2826": 0x8036c180,
		"MSound::@2832": 0x8036c194,
		"MSound::@2834": 0x8036c1ac,
		"MSound::@2835": 0x8036c1c0,
		"MSound::@2836": 0x8036c1d8,
		"MSound::@2841": 0x8036c1e4,
		"MSound::@2844": 0x8036c1f4,
		"MSound::@2846": 0x8036c20c,
		"MSound::@2862": 0x8036c244,
		"MSound::@2872": 0x8036c29c,
		"MSound::@2876": 0x8036c2c8,
		"MSound::@2882": 0x8036c2fc,
		"MSound::@2887": 0x8036c32c,
		"MSound::@2888": 0x8036c350,
		"MSound::@2894": 0x8036c3b0,
		"MSound::@2911": 0x8036c440,
		"MSound::@2932": 0x8036c4c0,
		"MSound::@2934": 0x8036c4d8,
		"MSound::@3292": 0x8036c508,
		"MSound::@3293": 0x8036c518,
		"MSound::@3294": 0x8036c528,
		"MSound::@3295": 0x8036c538,
		"MSound::@3296": 0x8036c544,
		"MSound::@3297": 0x8036c550,
		"MSound::@3298": 0x8036c560,
		"MSound::@3299": 0x8036c570,
		"MSound::@3300": 0x8036c580,
		"MSound::@3301": 0x8036c598,
		"MSound::@3302": 0x8036c5ac,
		"MSound::@3303": 0x8036c5bc,
		"MSound::@3304": 0x8036c5dc,
		"MSound::@1994": 0x8036c650,
		"MSound::@2024": 0x8036c680,
		"MSound::@2026": 0x8036c68c,
		"MSound::@2028": 0x8036c69c,
		"MSound::@2449": 0x8036c6ac,
		"MSound::@2450": 0x8036c6bc,
		"MSound::@2451": 0x8036c6cc,
		"MSound::@2452": 0x8036c6dc,
		"MSound::@2453": 0x8036c6e8,
		"MSound::@2454": 0x8036c6f4,
		"MSound::@2455": 0x8036c704,
		"MSound::@2456": 0x8036c714,
		"MSound::@2457": 0x8036c724,
		"MSound::@2458": 0x8036c73c,
		"MSound::@2461": 0x8036c780,
		"MSound::@2463": 0x8036c7a8,
		"MSound::@2464": 0x8036c7c4,
		"MSound::@2465": 0x8036c7dc,
		"MoveBG::@2192": 0x803825cc,
		"MoveBG::no_data_obj_hit_table": 0x80382608,
		"no_data_obj_hit_table": 0x80382608,
		"MoveBG::no_data_obj_hit_info": 0x80382618,
		"no_data_obj_hit_info": 0x80382618,
		"MoveBG::@2772": 0x80382644,
		"MoveBG::@2774": 0x80382668,
		"MoveBG::billboard_dolphin_anim_data": 0x80382678,
		"billboard_dolphin_anim_data": 0x80382678,
		"MoveBG::billboard_hit_data_table": 0x803826b4,
		"billboard_hit_data_table": 0x803826b4,
		"MoveBG::billboard_obj_hit_info": 0x803826c4,
		"billboard_obj_hit_info": 0x803826c4,
		"MoveBG::@2776": 0x803826e8,
		"MoveBG::@2777": 0x80382700,
		"MoveBG::billboard_sun_anim_data": 0x80382714,
		"billboard_sun_anim_data": 0x80382714,
		"MoveBG::billboard_restaurant_anim_data": 0x80382778,
		"billboard_restaurant_anim_data": 0x80382778,
		"MoveBG::billboard_fish_anim_data": 0x803827e0,
		"billboard_fish_anim_data": 0x803827e0,
		"MoveBG::HideObj_hit_data_table": 0x8038282c,
		"HideObj_hit_data_table": 0x8038282c,
		"MoveBG::HideObj_obj_hit_info": 0x8038283c,
		"HideObj_obj_hit_info": 0x8038283c,
		"MoveBG::WaterHitHideObj_hit_data_table": 0x8038284c,
		"WaterHitHideObj_hit_data_table": 0x8038284c,
		"MoveBG::WaterHitHideObj_obj_hit_info": 0x8038285c,
		"WaterHitHideObj_obj_hit_info": 0x8038285c,
		"MoveBG::FruitHitHideObj_hit_data_table": 0x8038287c,
		"FruitHitHideObj_hit_data_table": 0x8038287c,
		"MoveBG::FruitHitHideObj_obj_hit_info": 0x8038288c,
		"FruitHitHideObj_obj_hit_info": 0x8038288c,
		"MoveBG::HipDropHideObj_hit_data_table": 0x803828ac,
		"HipDropHideObj_hit_data_table": 0x803828ac,
		"MoveBG::HipDropHideObj_obj_hit_info": 0x803828bc,
		"HipDropHideObj_obj_hit_info": 0x803828bc,
		"MoveBG::MonteChair_anim_data": 0x803828f4,
		"MonteChair_anim_data": 0x803828f4,
		"MoveBG::@2797": 0x803829b0,
		"MoveBG::door_anim_data": 0x803829d0,
		"door_anim_data": 0x803829d0,
		"MoveBG::door_hit_data_table": 0x80382a34,
		"door_hit_data_table": 0x80382a34,
		"MoveBG::door_obj_hit_info": 0x80382a44,
		"door_obj_hit_info": 0x80382a44,
		"MoveBG::doorHotel_anim_data": 0x80382a64,
		"doorHotel_anim_data": 0x80382a64,
		"MoveBG::@2800": 0x80382ac8,
		"MoveBG::manhole_anim_data": 0x80382ae0,
		"manhole_anim_data": 0x80382ae0,
		"MoveBG::manhole_hit_data_table": 0x80382af4,
		"manhole_hit_data_table": 0x80382af4,
		"MoveBG::manhole_obj_hit_info": 0x80382b04,
		"manhole_obj_hit_info": 0x80382b04,
		"MoveBG::manhole_map_collision_data": 0x80382b14,
		"manhole_map_collision_data": 0x80382b14,
		"MoveBG::FruitBasket_anim_data": 0x80382b30,
		"FruitBasket_anim_data": 0x80382b30,
		"MoveBG::FruitBasket_hit_data_table": 0x80382b58,
		"FruitBasket_hit_data_table": 0x80382b58,
		"MoveBG::FruitBasket_obj_hit_info": 0x80382b68,
		"FruitBasket_obj_hit_info": 0x80382b68,
		"MoveBG::@2806": 0x80382b78,
		"MoveBG::BasketReverse_anim_data": 0x80382b84,
		"BasketReverse_anim_data": 0x80382b84,
		"MoveBG::BasketReverse_hit_data_table": 0x80382b98,
		"BasketReverse_hit_data_table": 0x80382b98,
		"MoveBG::BasketReverse_obj_hit_info": 0x80382ba8,
		"BasketReverse_obj_hit_info": 0x80382ba8,
		"MoveBG::CoconutJuice_hit_data_table": 0x80382bc8,
		"CoconutJuice_hit_data_table": 0x80382bc8,
		"MoveBG::CoconutJuice_obj_hit_info": 0x80382bd8,
		"CoconutJuice_obj_hit_info": 0x80382bd8,
		"MoveBG::Pile_hit_data_table": 0x80382bf8,
		"Pile_hit_data_table": 0x80382bf8,
		"MoveBG::Pile_obj_hit_info": 0x80382c08,
		"Pile_obj_hit_info": 0x80382c08,
		"MoveBG::ChangeStage_hit_data_table": 0x80382c38,
		"ChangeStage_hit_data_table": 0x80382c38,
		"MoveBG::ChangeStage_obj_hit_info": 0x80382c48,
		"ChangeStage_obj_hit_info": 0x80382c48,
		"MoveBG::StartDemo_hit_data_table": 0x80382c7c,
		"StartDemo_hit_data_table": 0x80382c7c,
		"MoveBG::StartDemo_obj_hit_info": 0x80382c8c,
		"StartDemo_obj_hit_info": 0x80382c8c,
		"MoveBG::ChipShine_anim_data": 0x80382cc0,
		"ChipShine_anim_data": 0x80382cc0,
		"MoveBG::ChipShine_hit_data_table": 0x80382cd4,
		"ChipShine_hit_data_table": 0x80382cd4,
		"MoveBG::ChipShine_obj_hit_info": 0x80382ce4,
		"ChipShine_obj_hit_info": 0x80382ce4,
		"MoveBG::KoopaJrSignM_anim_data": 0x80382d14,
		"KoopaJrSignM_anim_data": 0x80382d14,
		"MoveBG::KoopaJrSignM_hit_data_table": 0x80382d28,
		"KoopaJrSignM_hit_data_table": 0x80382d28,
		"MoveBG::KoopaJrSignM_obj_hit_info": 0x80382d38,
		"KoopaJrSignM_obj_hit_info": 0x80382d38,
		"MoveBG::SignCircle_anim_data": 0x80382d74,
		"SignCircle_anim_data": 0x80382d74,
		"MoveBG::SignCross_anim_data": 0x80382da4,
		"SignCross_anim_data": 0x80382da4,
		"MoveBG::SignTriangle_anim_data": 0x80382dd4,
		"SignTriangle_anim_data": 0x80382dd4,
		"MoveBG::ArrowBoardLR_hit_data_table": 0x80382df8,
		"ArrowBoardLR_hit_data_table": 0x80382df8,
		"MoveBG::ArrowBoardLR_obj_hit_info": 0x80382e08,
		"ArrowBoardLR_obj_hit_info": 0x80382e08,
		"MoveBG::ArrowBoardUp_hit_data_table": 0x80382e28,
		"ArrowBoardUp_hit_data_table": 0x80382e28,
		"MoveBG::ArrowBoardUp_obj_hit_info": 0x80382e38,
		"ArrowBoardUp_obj_hit_info": 0x80382e38,
		"MoveBG::@2826": 0x80382e48,
		"MoveBG::ArrowBoardDown_hit_data_table": 0x80382e58,
		"ArrowBoardDown_hit_data_table": 0x80382e58,
		"MoveBG::ArrowBoardDown_obj_hit_info": 0x80382e68,
		"ArrowBoardDown_obj_hit_info": 0x80382e68,
		"MoveBG::GeneralHitObj_hit_data_table": 0x80382ec8,
		"GeneralHitObj_hit_data_table": 0x80382ec8,
		"MoveBG::GeneralHitObj_obj_hit_info": 0x80382ed8,
		"GeneralHitObj_obj_hit_info": 0x80382ed8,
		"MoveBG::item_hit_data_table": 0x80382ef8,
		"item_hit_data_table": 0x80382ef8,
		"MoveBG::item_obj_hit_info": 0x80382f08,
		"item_obj_hit_info": 0x80382f08,
		"MoveBG::WaterRecoverObj_hit_data_table": 0x80382f64,
		"WaterRecoverObj_hit_data_table": 0x80382f64,
		"MoveBG::WaterRecoverObj_obj_hit_info": 0x80382f74,
		"WaterRecoverObj_obj_hit_info": 0x80382f74,
		"MoveBG::nozzle_item_hit_data_table": 0x80382fcc,
		"nozzle_item_hit_data_table": 0x80382fcc,
		"MoveBG::nozzle_item_obj_hit_info": 0x80382fdc,
		"nozzle_item_obj_hit_info": 0x80382fdc,
		"MoveBG::coin_hit_data_table": 0x80383014,
		"coin_hit_data_table": 0x80383014,
		"MoveBG::coin_obj_hit_info": 0x80383024,
		"coin_obj_hit_info": 0x80383024,
		"MoveBG::coin_sound_data": 0x80383034,
		"coin_sound_data": 0x80383034,
		"MoveBG::mario_cap_anim_data": 0x803830ac,
		"mario_cap_anim_data": 0x803830ac,
		"MoveBG::mario_cap_hit_data_table": 0x803830c0,
		"mario_cap_hit_data_table": 0x803830c0,
		"MoveBG::mario_cap_obj_hit_info": 0x803830d0,
		"mario_cap_obj_hit_info": 0x803830d0,
		"MoveBG::coin_anim_data": 0x803830f8,
		"coin_anim_data": 0x803830f8,
		"MoveBG::@2854": 0x80383118,
		"MoveBG::eggYoshi_anim_data": 0x80383180,
		"eggYoshi_anim_data": 0x80383180,
		"MoveBG::eggYoshi_hit_data_table": 0x803831d0,
		"eggYoshi_hit_data_table": 0x803831d0,
		"MoveBG::eggYoshi_obj_hit_info": 0x80383270,
		"eggYoshi_obj_hit_info": 0x80383270,
		"MoveBG::NozzleBox_anim_data": 0x803832e4,
		"NozzleBox_anim_data": 0x803832e4,
		"MoveBG::NozzleBox_hit_data_table": 0x80383334,
		"NozzleBox_hit_data_table": 0x80383334,
		"MoveBG::NozzleBox_obj_hit_info": 0x80383344,
		"NozzleBox_obj_hit_info": 0x80383344,
		"MoveBG::mushroom1up_anim_data": 0x80383370,
		"mushroom1up_anim_data": 0x80383370,
		"MoveBG::mushroom1up_hit_data_table": 0x80383384,
		"mushroom1up_hit_data_table": 0x80383384,
		"MoveBG::mushroom1up_obj_hit_info": 0x80383394,
		"mushroom1up_obj_hit_info": 0x80383394,
		"MoveBG::@2871": 0x803833d0,
		"MoveBG::jumpbase_anim_data": 0x803833e0,
		"jumpbase_anim_data": 0x803833e0,
		"MoveBG::jumpbase_hit_data_table": 0x803833f4,
		"jumpbase_hit_data_table": 0x803833f4,
		"MoveBG::jumpbase_obj_hit_info": 0x80383404,
		"jumpbase_obj_hit_info": 0x80383404,
		"MoveBG::@2872": 0x80383414,
		"MoveBG::fruit_hit_data_table": 0x80383420,
		"fruit_hit_data_table": 0x80383420,
		"MoveBG::fruit_obj_hit_info": 0x80383430,
		"fruit_obj_hit_info": 0x80383430,
		"MoveBG::coconut_hit_data_table": 0x80383440,
		"coconut_hit_data_table": 0x80383440,
		"MoveBG::coconut_obj_hit_info": 0x80383450,
		"coconut_obj_hit_info": 0x80383450,
		"MoveBG::fruit_sound_data": 0x80383460,
		"fruit_sound_data": 0x80383460,
		"MoveBG::@2873": 0x80383488,
		"MoveBG::@2874": 0x80383498,
		"MoveBG::papaya_hit_data_table": 0x803834a4,
		"papaya_hit_data_table": 0x803834a4,
		"MoveBG::papaya_obj_hit_info": 0x803834b4,
		"papaya_obj_hit_info": 0x803834b4,
		"MoveBG::@2875": 0x803834c4,
		"MoveBG::pine_hit_data_table": 0x803834d0,
		"pine_hit_data_table": 0x803834d0,
		"MoveBG::pine_obj_hit_info": 0x803834e0,
		"pine_obj_hit_info": 0x803834e0,
		"MoveBG::@2876": 0x803834f0,
		"MoveBG::@2877": 0x803834fc,
		"MoveBG::CoverPine_anim_data": 0x8038350c,
		"CoverPine_anim_data": 0x8038350c,
		"MoveBG::cover_pine_hit_data_table": 0x80383598,
		"cover_pine_hit_data_table": 0x80383598,
		"MoveBG::cover_pine_obj_hit_info": 0x803835a8,
		"cover_pine_obj_hit_info": 0x803835a8,
		"MoveBG::@2878": 0x803835b8,
		"MoveBG::durian_hit_data_table": 0x803835c8,
		"durian_hit_data_table": 0x803835c8,
		"MoveBG::durian_obj_hit_info": 0x803835d8,
		"durian_obj_hit_info": 0x803835d8,
		"MoveBG::durian_sound_data": 0x803835e8,
		"durian_sound_data": 0x803835e8,
		"MoveBG::@2879": 0x80383610,
		"MoveBG::banana_hit_data_table": 0x8038361c,
		"banana_hit_data_table": 0x8038361c,
		"MoveBG::banana_obj_hit_info": 0x8038362c,
		"banana_obj_hit_info": 0x8038362c,
		"MoveBG::@2881": 0x80383648,
		"MoveBG::@2882": 0x80383654,
		"MoveBG::@2883": 0x80383664,
		"MoveBG::fence3x3_anim_data": 0x80383674,
		"fence3x3_anim_data": 0x80383674,
		"MoveBG::@2885": 0x80383694,
		"MoveBG::fence_revolve_outer_anim_data": 0x803836ac,
		"fence_revolve_outer_anim_data": 0x803836ac,
		"MoveBG::@2886": 0x803836c0,
		"MoveBG::FenceInner_hit_data_table": 0x803836d0,
		"FenceInner_hit_data_table": 0x803836d0,
		"MoveBG::FenceInner_obj_hit_info": 0x803836e0,
		"FenceInner_obj_hit_info": 0x803836e0,
		"MoveBG::@2887": 0x803836f0,
		"MoveBG::FenceWaterH_map_collision_data": 0x80383740,
		"FenceWaterH_map_collision_data": 0x80383740,
		"MoveBG::RailFence_anim_data": 0x80383764,
		"RailFence_anim_data": 0x80383764,
		"MoveBG::RailFence_map_collision_data": 0x803837a0,
		"RailFence_map_collision_data": 0x803837a0,
		"MoveBG::BambooRailFence_anim_data": 0x80383820,
		"BambooRailFence_anim_data": 0x80383820,
		"MoveBG::wood_barrel_anim_data": 0x803838dc,
		"wood_barrel_anim_data": 0x803838dc,
		"MoveBG::wood_barrel_hit_data_table": 0x80383968,
		"wood_barrel_hit_data_table": 0x80383968,
		"MoveBG::wood_barrel_obj_hit_info": 0x80383998,
		"wood_barrel_obj_hit_info": 0x80383998,
		"MoveBG::wood_barrel_map_collision_data": 0x803839a8,
		"wood_barrel_map_collision_data": 0x803839a8,
		"MoveBG::wood_barrel_sound_data": 0x803839b8,
		"wood_barrel_sound_data": 0x803839b8,
		"MoveBG::barrel_float_hit_data_table": 0x80383a44,
		"barrel_float_hit_data_table": 0x80383a44,
		"MoveBG::barrel_float_obj_hit_info": 0x80383a54,
		"barrel_float_obj_hit_info": 0x80383a54,
		"MoveBG::@2914": 0x80383a88,
		"MoveBG::@2915": 0x80383aa4,
		"MoveBG::drum_can_anim_data": 0x80383ab4,
		"drum_can_anim_data": 0x80383ab4,
		"MoveBG::drum_can_hit_data_table": 0x80383af0,
		"drum_can_hit_data_table": 0x80383af0,
		"MoveBG::drum_can_obj_hit_info": 0x80383b00,
		"drum_can_obj_hit_info": 0x80383b00,
		"MoveBG::drum_can_map_collision_data": 0x80383b2c,
		"drum_can_map_collision_data": 0x80383b2c,
		"MoveBG::@2918": 0x80383b3c,
		"MoveBG::@2919": 0x80383b4c,
		"MoveBG::barrel_oil_anim_data": 0x80383b74,
		"barrel_oil_anim_data": 0x80383b74,
		"MoveBG::barrel_oil_hit_data_table": 0x80383c00,
		"barrel_oil_hit_data_table": 0x80383c00,
		"MoveBG::barrel_oil_obj_hit_info": 0x80383c10,
		"barrel_oil_obj_hit_info": 0x80383c10,
		"MoveBG::@2920": 0x80383c20,
		"MoveBG::@2925": 0x80383c7c,
		"MoveBG::breakable_block_anim_data": 0x80383c94,
		"breakable_block_anim_data": 0x80383c94,
		"MoveBG::breakable_block_hit_data_table": 0x80383cd0,
		"breakable_block_hit_data_table": 0x80383cd0,
		"MoveBG::breakable_block_obj_hit_info": 0x80383ce0,
		"breakable_block_obj_hit_info": 0x80383ce0,
		"MoveBG::supermario_block_obj_hit_info": 0x80383d00,
		"supermario_block_obj_hit_info": 0x80383d00,
		"MoveBG::@2928": 0x80383d24,
		"MoveBG::@2929": 0x80383d30,
		"MoveBG::expand_block_hit_data_table": 0x80383d40,
		"expand_block_hit_data_table": 0x80383d40,
		"MoveBG::expand_block_obj_hit_info": 0x80383d50,
		"expand_block_obj_hit_info": 0x80383d50,
		"MoveBG::spread_block_hit_data_table": 0x80383d70,
		"spread_block_hit_data_table": 0x80383d70,
		"MoveBG::spread_block_obj_hit_info": 0x80383d80,
		"spread_block_obj_hit_info": 0x80383d80,
		"MoveBG::@2931": 0x80383d90,
		"MoveBG::water_roll_block_anim_data": 0x80383db8,
		"water_roll_block_anim_data": 0x80383db8,
		"MoveBG::water_roll_block_obj_hit_info": 0x80383dcc,
		"water_roll_block_obj_hit_info": 0x80383dcc,
		"MoveBG::@2935": 0x80383e00,
		"MoveBG::sand_block_anim_data": 0x80383e0c,
		"sand_block_anim_data": 0x80383e0c,
		"MoveBG::sand_block_hit_data_table": 0x80383e48,
		"sand_block_hit_data_table": 0x80383e48,
		"MoveBG::sand_block_obj_hit_info": 0x80383e58,
		"sand_block_obj_hit_info": 0x80383e58,
		"MoveBG::sand_block_map_collision_data": 0x80383e68,
		"sand_block_map_collision_data": 0x80383e68,
		"MoveBG::@2937": 0x80383e84,
		"MoveBG::@2941": 0x80383edc,
		"MoveBG::skate_block_hit_data_table": 0x80383efc,
		"skate_block_hit_data_table": 0x80383efc,
		"MoveBG::skate_block_obj_hit_info": 0x80383f0c,
		"skate_block_obj_hit_info": 0x80383f0c,
		"MoveBG::@2944": 0x80383f28,
		"MoveBG::@2945": 0x80383f3c,
		"MoveBG::MoveCoin_anim_data": 0x80383f4c,
		"MoveCoin_anim_data": 0x80383f4c,
		"MoveBG::@2946": 0x80383f60,
		"MoveBG::cluster_block_anim_data": 0x80383f80,
		"cluster_block_anim_data": 0x80383f80,
		"MoveBG::@2949": 0x80383fa4,
		"MoveBG::ice_block_hit_data_table": 0x80383fb0,
		"ice_block_hit_data_table": 0x80383fb0,
		"MoveBG::ice_block_obj_hit_info": 0x80383fc0,
		"ice_block_obj_hit_info": 0x80383fc0,
		"MoveBG::@2950": 0x80383fd0,
		"MoveBG::@2951": 0x80383fdc,
		"MoveBG::@2952": 0x80383fec,
		"MoveBG::BrickBlock_anim_data": 0x80384010,
		"BrickBlock_anim_data": 0x80384010,
		"MoveBG::@2955": 0x80384058,
		"MoveBG::@2956": 0x8038406c,
		"MoveBG::WaterMelonBlock_anim_data": 0x803840a0,
		"WaterMelonBlock_anim_data": 0x803840a0,
		"MoveBG::WoodBlockPole_hit_data_table": 0x803840f8,
		"WoodBlockPole_hit_data_table": 0x803840f8,
		"MoveBG::WoodBlockPole_obj_hit_info": 0x80384108,
		"WoodBlockPole_obj_hit_info": 0x80384108,
		"MoveBG::@2963": 0x80384164,
		"MoveBG::@2964": 0x80384178,
		"MoveBG::@2965": 0x80384188,
		"MoveBG::SuperHipDropBlock_anim_data": 0x803841ac,
		"SuperHipDropBlock_anim_data": 0x803841ac,
		"MoveBG::@2966": 0x803841e8,
		"MoveBG::@2967": 0x803841f4,
		"MoveBG::tree_sound_data": 0x80384208,
		"tree_sound_data": 0x80384208,
		"MoveBG::@2968": 0x80384230,
		"MoveBG::PalmNormal_anim_data": 0x80384240,
		"PalmNormal_anim_data": 0x80384240,
		"MoveBG::palmNormal_hit_data_table": 0x80384254,
		"palmNormal_hit_data_table": 0x80384254,
		"MoveBG::palmNormal_obj_hit_info": 0x80384264,
		"palmNormal_obj_hit_info": 0x80384264,
		"MoveBG::@2969": 0x80384274,
		"MoveBG::palmOugi_hit_data_table": 0x80384290,
		"palmOugi_hit_data_table": 0x80384290,
		"MoveBG::palmOugi_obj_hit_info": 0x803842a0,
		"palmOugi_obj_hit_info": 0x803842a0,
		"MoveBG::palmSago_hit_data_table": 0x803842bc,
		"palmSago_hit_data_table": 0x803842bc,
		"MoveBG::palmSago_obj_hit_info": 0x803842cc,
		"palmSago_obj_hit_info": 0x803842cc,
		"MoveBG::palmNatume_hit_data_table": 0x803842e8,
		"palmNatume_hit_data_table": 0x803842e8,
		"MoveBG::palmNatume_obj_hit_info": 0x803842f8,
		"palmNatume_obj_hit_info": 0x803842f8,
		"MoveBG::PalmLeaf_anim_data": 0x80384324,
		"PalmLeaf_anim_data": 0x80384324,
		"MoveBG::palmLeaf_hit_data_table": 0x80384338,
		"palmLeaf_hit_data_table": 0x80384338,
		"MoveBG::palmLeaf_obj_hit_info": 0x80384348,
		"palmLeaf_obj_hit_info": 0x80384348,
		"MoveBG::BananaTree_anim_data": 0x80384374,
		"BananaTree_anim_data": 0x80384374,
		"MoveBG::BananaTree_hit_data_table": 0x80384388,
		"BananaTree_hit_data_table": 0x80384388,
		"MoveBG::BananaTree_obj_hit_info": 0x80384398,
		"BananaTree_obj_hit_info": 0x80384398,
		"MoveBG::FruitTree_hit_data_table": 0x803843b4,
		"FruitTree_hit_data_table": 0x803843b4,
		"MoveBG::FruitTree_obj_hit_info": 0x803843c4,
		"FruitTree_obj_hit_info": 0x803843c4,
		"MoveBG::flower_hit_data_table": 0x803843e0,
		"flower_hit_data_table": 0x803843e0,
		"MoveBG::flower_obj_hit_info": 0x803843f0,
		"flower_obj_hit_info": 0x803843f0,
		"MoveBG::flowerOrange_anim_data": 0x80384434,
		"flowerOrange_anim_data": 0x80384434,
		"MoveBG::flowerPink_anim_data": 0x8038448c,
		"flowerPink_anim_data": 0x8038448c,
		"MoveBG::flowerPurple_anim_data": 0x803844e8,
		"flowerPurple_anim_data": 0x803844e8,
		"MoveBG::@2991": 0x80384530,
		"MoveBG::flowerRed_anim_data": 0x80384540,
		"flowerRed_anim_data": 0x80384540,
		"MoveBG::flowerYellow_anim_data": 0x8038459c,
		"flowerYellow_anim_data": 0x8038459c,
		"MoveBG::flowerSunflower_anim_data": 0x80384600,
		"flowerSunflower_anim_data": 0x80384600,
		"MoveBG::pole_sound_data": 0x80384638,
		"pole_sound_data": 0x80384638,
		"MoveBG::telegraph_pole_l_hit_data_table": 0x80384660,
		"telegraph_pole_l_hit_data_table": 0x80384660,
		"MoveBG::telegraph_pole_l_obj_hit_info": 0x80384670,
		"telegraph_pole_l_obj_hit_info": 0x80384670,
		"MoveBG::telegraph_pole_s_hit_data_table": 0x80384694,
		"telegraph_pole_s_hit_data_table": 0x80384694,
		"MoveBG::telegraph_pole_s_obj_hit_info": 0x803846a4,
		"telegraph_pole_s_obj_hit_info": 0x803846a4,
		"MoveBG::dptlight_anim_data": 0x80384704,
		"dptlight_anim_data": 0x80384704,
		"MoveBG::streetlamp_hit_data_table": 0x80384790,
		"streetlamp_hit_data_table": 0x80384790,
		"MoveBG::streetlamp_obj_hit_info": 0x803847c0,
		"streetlamp_obj_hit_info": 0x803847c0,
		"MoveBG::streetlamp_map_collision_data": 0x803847ec,
		"streetlamp_map_collision_data": 0x803847ec,
		"MoveBG::PoleNormal_hit_data_table": 0x803847fc,
		"PoleNormal_hit_data_table": 0x803847fc,
		"MoveBG::PoleNormal_obj_hit_info": 0x8038480c,
		"PoleNormal_obj_hit_info": 0x8038480c,
		"MoveBG::football_anim_data": 0x80384838,
		"football_anim_data": 0x80384838,
		"MoveBG::football_hit_data_table": 0x8038484c,
		"football_hit_data_table": 0x8038484c,
		"MoveBG::football_obj_hit_info": 0x8038485c,
		"football_obj_hit_info": 0x8038485c,
		"MoveBG::football_sound_data": 0x8038486c,
		"football_sound_data": 0x8038486c,
		"MoveBG::football_goal_anim_data": 0x803848b8,
		"football_goal_anim_data": 0x803848b8,
		"MoveBG::football_goal_hit_data_table": 0x803848cc,
		"football_goal_hit_data_table": 0x803848cc,
		"MoveBG::football_goal_obj_hit_info": 0x803848dc,
		"football_goal_obj_hit_info": 0x803848dc,
		"MoveBG::football_goal_map_collision_data": 0x8038490c,
		"football_goal_map_collision_data": 0x8038490c,
		"MoveBG::@3013": 0x8038492c,
		"MoveBG::@3014": 0x80384938,
		"MoveBG::@3015": 0x80384948,
		"MoveBG::@3016": 0x80384958,
		"MoveBG::@3017": 0x8038496c,
		"MoveBG::Watermelon_anim_data": 0x80384990,
		"Watermelon_anim_data": 0x80384990,
		"MoveBG::watermelon_hit_data_table": 0x80384a30,
		"watermelon_hit_data_table": 0x80384a30,
		"MoveBG::watermelon_obj_hit_info": 0x80384a40,
		"watermelon_obj_hit_info": 0x80384a40,
		"MoveBG::watermelon_sound_data": 0x80384a50,
		"watermelon_sound_data": 0x80384a50,
		"MoveBG::@3018": 0x80384a78,
		"MoveBG::WatermelonStatic_anim_data": 0x80384a84,
		"WatermelonStatic_anim_data": 0x80384a84,
		"MoveBG::@3019": 0x80384a98,
		"MoveBG::@3020": 0x80384aac,
		"MoveBG::@3021": 0x80384ab8,
		"MoveBG::cloud_anim_data": 0x80384ac4,
		"cloud_anim_data": 0x80384ac4,
		"MoveBG::cloud_hit_data_table": 0x80384ad8,
		"cloud_hit_data_table": 0x80384ad8,
		"MoveBG::cloud_obj_hit_info": 0x80384ae8,
		"cloud_obj_hit_info": 0x80384ae8,
		"MoveBG::normallift_anim_data": 0x80384b08,
		"normallift_anim_data": 0x80384b08,
		"MoveBG::normallift_hit_data_table": 0x80384b1c,
		"normallift_hit_data_table": 0x80384b1c,
		"MoveBG::normallift_obj_hit_info": 0x80384b2c,
		"normallift_obj_hit_info": 0x80384b2c,
		"MoveBG::exrollcube_anim_data": 0x80384b58,
		"exrollcube_anim_data": 0x80384b58,
		"MoveBG::exrollcube_hit_data_table": 0x80384b6c,
		"exrollcube_hit_data_table": 0x80384b6c,
		"MoveBG::exrollcube_obj_hit_info": 0x80384b7c,
		"exrollcube_obj_hit_info": 0x80384b7c,
		"MoveBG::exkickboard_anim_data": 0x80384bb4,
		"exkickboard_anim_data": 0x80384bb4,
		"MoveBG::exkickboard_hit_data_table": 0x80384bc8,
		"exkickboard_hit_data_table": 0x80384bc8,
		"MoveBG::exkickboard_obj_hit_info": 0x80384bd8,
		"exkickboard_obj_hit_info": 0x80384bd8,
		"MoveBG::railblockr_anim_data": 0x80384c18,
		"railblockr_anim_data": 0x80384c18,
		"MoveBG::railblocky_anim_data": 0x80384c44,
		"railblocky_anim_data": 0x80384c44,
		"MoveBG::railblockb_anim_data": 0x80384c70,
		"railblockb_anim_data": 0x80384c70,
		"MoveBG::railblock_hit_data_table": 0x80384c84,
		"railblock_hit_data_table": 0x80384c84,
		"MoveBG::railblock_obj_hit_info": 0x80384c94,
		"railblock_obj_hit_info": 0x80384c94,
		"MoveBG::umaibou_anim_data": 0x80384d08,
		"umaibou_anim_data": 0x80384d08,
		"MoveBG::umaibou_hit_data_table": 0x80384d1c,
		"umaibou_hit_data_table": 0x80384d1c,
		"MoveBG::umaibou_obj_hit_info": 0x80384d2c,
		"umaibou_obj_hit_info": 0x80384d2c,
		"MoveBG::kamaboko_anim_data": 0x80384d4c,
		"kamaboko_anim_data": 0x80384d4c,
		"MoveBG::kamaboko_hit_data_table": 0x80384d60,
		"kamaboko_hit_data_table": 0x80384d60,
		"MoveBG::kamaboko_obj_hit_info": 0x80384d70,
		"kamaboko_obj_hit_info": 0x80384d70,
		"MoveBG::getag_anim_data": 0x80384d9c,
		"getag_anim_data": 0x80384d9c,
		"MoveBG::getao_anim_data": 0x80384dc0,
		"getao_anim_data": 0x80384dc0,
		"MoveBG::geta_hit_data_table": 0x80384dd4,
		"geta_hit_data_table": 0x80384dd4,
		"MoveBG::geta_obj_hit_info": 0x80384de4,
		"geta_obj_hit_info": 0x80384de4,
		"MoveBG::uirou_anim_data": 0x80384e00,
		"uirou_anim_data": 0x80384e00,
		"MoveBG::uirou_hit_data_table": 0x80384e14,
		"uirou_hit_data_table": 0x80384e14,
		"MoveBG::uirou_obj_hit_info": 0x80384e24,
		"uirou_obj_hit_info": 0x80384e24,
		"MoveBG::hikidashi_anim_data": 0x80384e44,
		"hikidashi_anim_data": 0x80384e44,
		"MoveBG::hikidashi_hit_data_table": 0x80384e58,
		"hikidashi_hit_data_table": 0x80384e58,
		"MoveBG::hikidashi_obj_hit_info": 0x80384e68,
		"hikidashi_obj_hit_info": 0x80384e68,
		"MoveBG::castella_anim_data": 0x80384e94,
		"castella_anim_data": 0x80384e94,
		"MoveBG::castella_hit_data_table": 0x80384ea8,
		"castella_hit_data_table": 0x80384ea8,
		"MoveBG::castella_obj_hit_info": 0x80384eb8,
		"castella_obj_hit_info": 0x80384eb8,
		"MoveBG::yoshiblock_anim_data": 0x80384ee4,
		"yoshiblock_anim_data": 0x80384ee4,
		"MoveBG::yoshiblock_hit_data_table": 0x80384ef8,
		"yoshiblock_hit_data_table": 0x80384ef8,
		"MoveBG::yoshiblock_obj_hit_info": 0x80384f08,
		"yoshiblock_obj_hit_info": 0x80384f08,
		"MoveBG::@3057": 0x80384f18,
		"MoveBG::@3058": 0x80384f24,
		"MoveBG::@3062": 0x80384f6c,
		"MoveBG::@3063": 0x80384f7c,
		"MoveBG::@3065": 0x80384f98,
		"MoveBG::normalvariant0_hit_data_table": 0x80384fa8,
		"normalvariant0_hit_data_table": 0x80384fa8,
		"MoveBG::normalvariant0_obj_hit_info": 0x80384fb8,
		"normalvariant0_obj_hit_info": 0x80384fb8,
		"MoveBG::normalvariant1_hit_data_table": 0x80384fd8,
		"normalvariant1_hit_data_table": 0x80384fd8,
		"MoveBG::normalvariant1_obj_hit_info": 0x80384fe8,
		"normalvariant1_obj_hit_info": 0x80384fe8,
		"MoveBG::@3067": 0x80384ff8,
		"MoveBG::normalvariant2_hit_data_table": 0x80385008,
		"normalvariant2_hit_data_table": 0x80385008,
		"MoveBG::normalvariant2_obj_hit_info": 0x80385018,
		"normalvariant2_obj_hit_info": 0x80385018,
		"MoveBG::normalvariant3_hit_data_table": 0x80385038,
		"normalvariant3_hit_data_table": 0x80385038,
		"MoveBG::normalvariant3_obj_hit_info": 0x80385048,
		"normalvariant3_obj_hit_info": 0x80385048,
		"MoveBG::@3069": 0x80385058,
		"MoveBG::normalvariant4_hit_data_table": 0x80385068,
		"normalvariant4_hit_data_table": 0x80385068,
		"MoveBG::normalvariant4_obj_hit_info": 0x80385078,
		"normalvariant4_obj_hit_info": 0x80385078,
		"MoveBG::railvariant0_hit_data_table": 0x80385098,
		"railvariant0_hit_data_table": 0x80385098,
		"MoveBG::railvariant0_obj_hit_info": 0x803850a8,
		"railvariant0_obj_hit_info": 0x803850a8,
		"MoveBG::railvariant1_hit_data_table": 0x803850c8,
		"railvariant1_hit_data_table": 0x803850c8,
		"MoveBG::railvariant1_obj_hit_info": 0x803850d8,
		"railvariant1_obj_hit_info": 0x803850d8,
		"MoveBG::@3072": 0x803850e8,
		"MoveBG::railvariant2_hit_data_table": 0x803850f8,
		"railvariant2_hit_data_table": 0x803850f8,
		"MoveBG::railvariant2_obj_hit_info": 0x80385108,
		"railvariant2_obj_hit_info": 0x80385108,
		"MoveBG::@3073": 0x80385118,
		"MoveBG::railvariant3_hit_data_table": 0x80385128,
		"railvariant3_hit_data_table": 0x80385128,
		"MoveBG::railvariant3_obj_hit_info": 0x80385138,
		"railvariant3_obj_hit_info": 0x80385138,
		"MoveBG::railvariant4_hit_data_table": 0x80385158,
		"railvariant4_hit_data_table": 0x80385158,
		"MoveBG::railvariant4_obj_hit_info": 0x80385168,
		"railvariant4_obj_hit_info": 0x80385168,
		"MoveBG::rollvariant0_hit_data_table": 0x80385188,
		"rollvariant0_hit_data_table": 0x80385188,
		"MoveBG::rollvariant0_obj_hit_info": 0x80385198,
		"rollvariant0_obj_hit_info": 0x80385198,
		"MoveBG::@3076": 0x803851a8,
		"MoveBG::rollvariant1_hit_data_table": 0x803851b8,
		"rollvariant1_hit_data_table": 0x803851b8,
		"MoveBG::rollvariant1_obj_hit_info": 0x803851c8,
		"rollvariant1_obj_hit_info": 0x803851c8,
		"MoveBG::@3077": 0x803851d8,
		"MoveBG::rollvariant2_hit_data_table": 0x803851e8,
		"rollvariant2_hit_data_table": 0x803851e8,
		"MoveBG::rollvariant2_obj_hit_info": 0x803851f8,
		"rollvariant2_obj_hit_info": 0x803851f8,
		"MoveBG::@3078": 0x80385208,
		"MoveBG::rollvariant3_hit_data_table": 0x80385218,
		"rollvariant3_hit_data_table": 0x80385218,
		"MoveBG::rollvariant3_obj_hit_info": 0x80385228,
		"rollvariant3_obj_hit_info": 0x80385228,
		"MoveBG::@3079": 0x80385238,
		"MoveBG::rollvariant4_hit_data_table": 0x80385248,
		"rollvariant4_hit_data_table": 0x80385248,
		"MoveBG::rollvariant4_obj_hit_info": 0x80385258,
		"rollvariant4_obj_hit_info": 0x80385258,
		"MoveBG::lamptrapspike_anim_data": 0x8038528c,
		"lamptrapspike_anim_data": 0x8038528c,
		"MoveBG::lamptrapiron_anim_data": 0x803852b4,
		"lamptrapiron_anim_data": 0x803852b4,
		"MoveBG::lamptrap_hit_data_table": 0x803852c8,
		"lamptrap_hit_data_table": 0x803852c8,
		"MoveBG::lamptrap_obj_hit_info": 0x803852d8,
		"lamptrap_obj_hit_info": 0x803852d8,
		"MoveBG::@3088": 0x8038532c,
		"MoveBG::WoodBox_anim_data": 0x80385350,
		"WoodBox_anim_data": 0x80385350,
		"MoveBG::WoodBox_sound_data": 0x8038538c,
		"WoodBox_sound_data": 0x8038538c,
		"MoveBG::AirportPole_hit_data_table": 0x803853b4,
		"AirportPole_hit_data_table": 0x803853b4,
		"MoveBG::AirportPole_obj_hit_info": 0x803853c4,
		"AirportPole_obj_hit_info": 0x803853c4,
		"MoveBG::@3093": 0x803853e0,
		"MoveBG::@3094": 0x803853ec,
		"MoveBG::ice_car_anim_data": 0x803853f8,
		"ice_car_anim_data": 0x803853f8,
		"MoveBG::ice_car_hit_data_table": 0x80385484,
		"ice_car_hit_data_table": 0x80385484,
		"MoveBG::ice_car_obj_hit_info": 0x80385494,
		"ice_car_obj_hit_info": 0x80385494,
		"MoveBG::AirportBuoy_hit_data_table": 0x803854b4,
		"AirportBuoy_hit_data_table": 0x803854b4,
		"MoveBG::AirportBuoy_obj_hit_info": 0x803854c4,
		"AirportBuoy_obj_hit_info": 0x803854c4,
		"MoveBG::dptKing_map_collision_data": 0x803854e0,
		"dptKing_map_collision_data": 0x803854e0,
		"MoveBG::monumentshine_anim_data": 0x80385518,
		"monumentshine_anim_data": 0x80385518,
		"MoveBG::monumentshine_hit_data_table": 0x8038552c,
		"monumentshine_hit_data_table": 0x8038552c,
		"MoveBG::monumentshine_obj_hit_info": 0x8038553c,
		"monumentshine_obj_hit_info": 0x8038553c,
		"MoveBG::belldolpic_anim_data": 0x8038556c,
		"belldolpic_anim_data": 0x8038556c,
		"MoveBG::belldolpic_hit_data_table": 0x80385580,
		"belldolpic_hit_data_table": 0x80385580,
		"MoveBG::belldolpic_obj_hit_info": 0x80385590,
		"belldolpic_obj_hit_info": 0x80385590,
		"MoveBG::DptWeathercock_anim_data": 0x803855d0,
		"DptWeathercock_anim_data": 0x803855d0,
		"MoveBG::DptWeathercock_hit_data_table": 0x803855e4,
		"DptWeathercock_hit_data_table": 0x803855e4,
		"MoveBG::DptWeathercock_obj_hit_info": 0x803855f4,
		"DptWeathercock_obj_hit_info": 0x803855f4,
		"MoveBG::DptMonteFence_hit_data_table": 0x80385614,
		"DptMonteFence_hit_data_table": 0x80385614,
		"MoveBG::DptMonteFence_obj_hit_info": 0x80385624,
		"DptMonteFence_obj_hit_info": 0x80385624,
		"MoveBG::MapSmoke_hit_data_table": 0x80385654,
		"MapSmoke_hit_data_table": 0x80385654,
		"MoveBG::MapSmoke_obj_hit_info": 0x80385664,
		"MapSmoke_obj_hit_info": 0x80385664,
		"MoveBG::@3112": 0x80385680,
		"MoveBG::MareGate_anim_data": 0x8038569c,
		"MareGate_anim_data": 0x8038569c,
		"MoveBG::NozzleDoor_anim_data": 0x803856d8,
		"NozzleDoor_anim_data": 0x803856d8,
		"MoveBG::NozzleDoor_hit_data_table": 0x80385700,
		"NozzleDoor_hit_data_table": 0x80385700,
		"MoveBG::NozzleDoor_obj_hit_info": 0x80385710,
		"NozzleDoor_obj_hit_info": 0x80385710,
		"MoveBG::DokanGate_anim_data": 0x80385748,
		"DokanGate_anim_data": 0x80385748,
		"MoveBG::Crane_hit_data_table": 0x80385768,
		"Crane_hit_data_table": 0x80385768,
		"MoveBG::Crane_obj_hit_info": 0x80385778,
		"Crane_obj_hit_info": 0x80385778,
		"MoveBG::CraneUpDown_hit_data_table": 0x803857a8,
		"CraneUpDown_hit_data_table": 0x803857a8,
		"MoveBG::CraneUpDown_obj_hit_info": 0x803857b8,
		"CraneUpDown_obj_hit_info": 0x803857b8,
		"MoveBG::crane_cargo_hit_data_table": 0x803857d4,
		"crane_cargo_hit_data_table": 0x803857d4,
		"MoveBG::crane_cargo_obj_hit_info": 0x803857e4,
		"crane_cargo_obj_hit_info": 0x803857e4,
		"MoveBG::Submarine_hit_data_table": 0x80385814,
		"Submarine_hit_data_table": 0x80385814,
		"MoveBG::Submarine_obj_hit_info": 0x80385824,
		"Submarine_obj_hit_info": 0x80385824,
		"MoveBG::submarine_map_collision_data": 0x80385840,
		"submarine_map_collision_data": 0x80385840,
		"MoveBG::ricco_ship_hit_data_table": 0x80385850,
		"ricco_ship_hit_data_table": 0x80385850,
		"MoveBG::ricco_ship_obj_hit_info": 0x80385860,
		"ricco_ship_obj_hit_info": 0x80385860,
		"MoveBG::ricco_pole_hit_data_table": 0x8038587c,
		"ricco_pole_hit_data_table": 0x8038587c,
		"MoveBG::ricco_pole_obj_hit_info": 0x8038588c,
		"ricco_pole_obj_hit_info": 0x8038588c,
		"MoveBG::riccoLog_hit_data_table": 0x803858a8,
		"riccoLog_hit_data_table": 0x803858a8,
		"MoveBG::riccoLog_obj_hit_info": 0x803858b8,
		"riccoLog_obj_hit_info": 0x803858b8,
		"MoveBG::gesoSurfboard_anim_data": 0x803858e4,
		"gesoSurfboard_anim_data": 0x803858e4,
		"MoveBG::gesoSurfboard_hit_data_table": 0x803858f8,
		"gesoSurfboard_hit_data_table": 0x803858f8,
		"MoveBG::gesoSurfboard_obj_hit_info": 0x80385908,
		"gesoSurfboard_obj_hit_info": 0x80385908,
		"MoveBG::riccoWatermill_hit_data_table": 0x8038593c,
		"riccoWatermill_hit_data_table": 0x8038593c,
		"MoveBG::riccoWatermill_obj_hit_info": 0x8038594c,
		"riccoWatermill_obj_hit_info": 0x8038594c,
		"MoveBG::riccoShipLog_hit_data_table": 0x8038596c,
		"riccoShipLog_hit_data_table": 0x8038596c,
		"MoveBG::riccoShipLog_obj_hit_info": 0x8038597c,
		"riccoShipLog_obj_hit_info": 0x8038597c,
		"MoveBG::riccoShipDol_hit_data_table": 0x8038599c,
		"riccoShipDol_hit_data_table": 0x8038599c,
		"MoveBG::riccoShipDol_obj_hit_info": 0x803859ac,
		"riccoShipDol_obj_hit_info": 0x803859ac,
		"MoveBG::riccoYachtL_hit_data_table": 0x803859cc,
		"riccoYachtL_hit_data_table": 0x803859cc,
		"MoveBG::riccoYachtL_obj_hit_info": 0x803859dc,
		"riccoYachtL_obj_hit_info": 0x803859dc,
		"MoveBG::riccoYachtS_hit_data_table": 0x803859f8,
		"riccoYachtS_hit_data_table": 0x803859f8,
		"MoveBG::riccoYachtS_obj_hit_info": 0x80385a08,
		"riccoYachtS_obj_hit_info": 0x80385a08,
		"MoveBG::riccoBoatL_hit_data_table": 0x80385a24,
		"riccoBoatL_hit_data_table": 0x80385a24,
		"MoveBG::riccoBoatL_obj_hit_info": 0x80385a34,
		"riccoBoatL_obj_hit_info": 0x80385a34,
		"MoveBG::riccoBoatS_hit_data_table": 0x80385a50,
		"riccoBoatS_hit_data_table": 0x80385a50,
		"MoveBG::riccoBoatS_obj_hit_info": 0x80385a60,
		"riccoBoatS_obj_hit_info": 0x80385a60,
		"MoveBG::surfgeso_hit_data_table": 0x80385b30,
		"surfgeso_hit_data_table": 0x80385b30,
		"MoveBG::surfgeso_obj_hit_info": 0x80385b40,
		"surfgeso_obj_hit_info": 0x80385b40,
		"MoveBG::surfgeso_anim_data": 0x80385b60,
		"surfgeso_anim_data": 0x80385b60,
		"MoveBG::@3157": 0x80385b90,
		"MoveBG::windmill_anim_data": 0x80385bb0,
		"windmill_anim_data": 0x80385bb0,
		"MoveBG::Windmill_hit_data_table": 0x80385bc4,
		"Windmill_hit_data_table": 0x80385bc4,
		"MoveBG::Windmill_obj_hit_info": 0x80385bd4,
		"Windmill_obj_hit_info": 0x80385bd4,
		"MoveBG::MiniWindmill_hit_data_table": 0x80385c00,
		"MiniWindmill_hit_data_table": 0x80385c00,
		"MoveBG::MiniWindmill_obj_hit_info": 0x80385c10,
		"MiniWindmill_obj_hit_info": 0x80385c10,
		"MoveBG::@3162": 0x80385c30,
		"MoveBG::@3163": 0x80385c40,
		"MoveBG::@3164": 0x80385c50,
		"MoveBG::lamp_bianco_anim_data": 0x80385c60,
		"lamp_bianco_anim_data": 0x80385c60,
		"MoveBG::lamp_bianco_hit_data_table": 0x80385cec,
		"lamp_bianco_hit_data_table": 0x80385cec,
		"MoveBG::lamp_bianco_obj_hit_info": 0x80385d1c,
		"lamp_bianco_obj_hit_info": 0x80385d1c,
		"MoveBG::@3165": 0x80385d2c,
		"MoveBG::lamp_bianco_map_collision_data": 0x80385d38,
		"lamp_bianco_map_collision_data": 0x80385d38,
		"MoveBG::WindmillBlock_hit_data_table": 0x80385d54,
		"WindmillBlock_hit_data_table": 0x80385d54,
		"MoveBG::WindmillBlock_obj_hit_info": 0x80385d64,
		"WindmillBlock_obj_hit_info": 0x80385d64,
		"MoveBG::PolluterPakkun_hit_data_table": 0x80385d88,
		"PolluterPakkun_hit_data_table": 0x80385d88,
		"MoveBG::PolluterPakkun_obj_hit_info": 0x80385d98,
		"PolluterPakkun_obj_hit_info": 0x80385d98,
		"MoveBG::@3168": 0x80385da8,
		"MoveBG::@3169": 0x80385db8,
		"MoveBG::BiaBell_anim_data": 0x80385df4,
		"BiaBell_anim_data": 0x80385df4,
		"MoveBG::BiaBell_hit_data_table": 0x80385e58,
		"BiaBell_hit_data_table": 0x80385e58,
		"MoveBG::BiaBell_obj_hit_info": 0x80385e68,
		"BiaBell_obj_hit_info": 0x80385e68,
		"MoveBG::watermill00_anim_data": 0x80385eb4,
		"watermill00_anim_data": 0x80385eb4,
		"MoveBG::BiaWatermill00_hit_data_table": 0x80385ec8,
		"BiaWatermill00_hit_data_table": 0x80385ec8,
		"MoveBG::BiaWatermill00_obj_hit_info": 0x80385ed8,
		"BiaWatermill00_obj_hit_info": 0x80385ed8,
		"MoveBG::@3177": 0x80385ee8,
		"MoveBG::BiaWatermill01_hit_data_table": 0x80385ef8,
		"BiaWatermill01_hit_data_table": 0x80385ef8,
		"MoveBG::BiaWatermill01_obj_hit_info": 0x80385f08,
		"BiaWatermill01_obj_hit_info": 0x80385f08,
		"MoveBG::@3178": 0x80385f18,
		"MoveBG::BiaWatermillVertical_hit_data_table": 0x80385f28,
		"BiaWatermillVertical_hit_data_table": 0x80385f28,
		"MoveBG::BiaWatermillVertical_obj_hit_info": 0x80385f38,
		"BiaWatermillVertical_obj_hit_info": 0x80385f38,
		"MoveBG::@3179": 0x80385f48,
		"MoveBG::BiaTurnBridge_hit_data_table": 0x80385f60,
		"BiaTurnBridge_hit_data_table": 0x80385f60,
		"MoveBG::BiaTurnBridge_obj_hit_info": 0x80385f70,
		"BiaTurnBridge_obj_hit_info": 0x80385f70,
		"MoveBG::@3180": 0x80385f80,
		"MoveBG::LeafBoat_hit_data_table": 0x80385f90,
		"LeafBoat_hit_data_table": 0x80385f90,
		"MoveBG::LeafBoat_obj_hit_info": 0x80385fa0,
		"LeafBoat_obj_hit_info": 0x80385fa0,
		"MoveBG::LampSeesaw_anim_data": 0x80385fcc,
		"LampSeesaw_anim_data": 0x80385fcc,
		"MoveBG::LampSeesaw_hit_data_table": 0x80385fe0,
		"LampSeesaw_hit_data_table": 0x80385fe0,
		"MoveBG::LampSeesaw_obj_hit_info": 0x80386010,
		"LampSeesaw_obj_hit_info": 0x80386010,
		"MoveBG::SandBird_anim_data": 0x80386054,
		"SandBird_anim_data": 0x80386054,
		"MoveBG::SandBirdBlock_hit_data_table": 0x80386074,
		"SandBirdBlock_hit_data_table": 0x80386074,
		"MoveBG::SandBirdBlock_obj_hit_info": 0x80386084,
		"SandBirdBlock_obj_hit_info": 0x80386084,
		"MoveBG::SandBirdBlock_map_collision_data": 0x803860a4,
		"SandBirdBlock_map_collision_data": 0x803860a4,
		"MoveBG::@3191": 0x803860c4,
		"MoveBG::SkyIsland_anim_data": 0x803860d0,
		"SkyIsland_anim_data": 0x803860d0,
		"MoveBG::@3192": 0x803860e4,
		"MoveBG::SandLeaf_anim_data": 0x80386140,
		"SandLeaf_anim_data": 0x80386140,
		"MoveBG::sand_leaf_hit_data_table": 0x803861a4,
		"sand_leaf_hit_data_table": 0x803861a4,
		"MoveBG::sand_leaf_obj_hit_info": 0x803861b4,
		"sand_leaf_obj_hit_info": 0x803861b4,
		"MoveBG::SandLeafBase00_anim_data": 0x803861e4,
		"SandLeafBase00_anim_data": 0x803861e4,
		"MoveBG::SandLeafBase00_map_collision_data": 0x80386208,
		"SandLeafBase00_map_collision_data": 0x80386208,
		"MoveBG::SandLeafBase01_anim_data": 0x8038622c,
		"SandLeafBase01_anim_data": 0x8038622c,
		"MoveBG::SandLeafBase01_map_collision_data": 0x80386250,
		"SandLeafBase01_map_collision_data": 0x80386250,
		"MoveBG::SandLeafBase02_anim_data": 0x80386274,
		"SandLeafBase02_anim_data": 0x80386274,
		"MoveBG::SandLeafBase02_map_collision_data": 0x80386298,
		"SandLeafBase02_map_collision_data": 0x80386298,
		"MoveBG::SandLeafBase03_anim_data": 0x803862bc,
		"SandLeafBase03_anim_data": 0x803862bc,
		"MoveBG::SandLeafBase03_map_collision_data": 0x803862e0,
		"SandLeafBase03_map_collision_data": 0x803862e0,
		"MoveBG::SandBomb_anim_data": 0x80386340,
		"SandBomb_anim_data": 0x80386340,
		"MoveBG::sand_bomb_hit_data_table": 0x803863cc,
		"sand_bomb_hit_data_table": 0x803863cc,
		"MoveBG::sand_bomb_obj_hit_info": 0x803863dc,
		"sand_bomb_obj_hit_info": 0x803863dc,
		"MoveBG::@3212": 0x803863ec,
		"MoveBG::mirror_L_hit_data_table": 0x803863f8,
		"mirror_L_hit_data_table": 0x803863f8,
		"MoveBG::mirror_L_obj_hit_info": 0x80386408,
		"mirror_L_obj_hit_info": 0x80386408,
		"MoveBG::mirror_L_map_collision_data": 0x80386418,
		"mirror_L_map_collision_data": 0x80386418,
		"MoveBG::mirror_M_hit_data_table": 0x80386428,
		"mirror_M_hit_data_table": 0x80386428,
		"MoveBG::mirror_M_obj_hit_info": 0x80386438,
		"mirror_M_obj_hit_info": 0x80386438,
		"MoveBG::mirror_M_map_collision_data": 0x80386448,
		"mirror_M_map_collision_data": 0x80386448,
		"MoveBG::mirrorS_hit_data_table": 0x80386458,
		"mirrorS_hit_data_table": 0x80386458,
		"MoveBG::mirrorS_obj_hit_info": 0x80386468,
		"mirrorS_obj_hit_info": 0x80386468,
		"MoveBG::mirrorS_map_collision_data": 0x80386478,
		"mirrorS_map_collision_data": 0x80386478,
		"MoveBG::@3218": 0x803864a8,
		"MoveBG::SandCastle_anim_data": 0x803864b8,
		"SandCastle_anim_data": 0x803864b8,
		"MoveBG::@3219": 0x80386508,
		"MoveBG::SandCastle_map_collision_data": 0x80386514,
		"SandCastle_map_collision_data": 0x80386514,
		"MoveBG::MammaBlockRotate_map_collision_data": 0x80386538,
		"MammaBlockRotate_map_collision_data": 0x80386538,
		"MoveBG::MammaSurfboard_hit_data_table": 0x80386578,
		"MammaSurfboard_hit_data_table": 0x80386578,
		"MoveBG::MammaSurfboard_obj_hit_info": 0x80386588,
		"MammaSurfboard_obj_hit_info": 0x80386588,
		"MoveBG::@3225": 0x803865ac,
		"MoveBG::@3226": 0x803865c0,
		"MoveBG::@3227": 0x803865d4,
		"MoveBG::@3228": 0x803865e8,
		"MoveBG::MammaYacht00_hit_data_table": 0x803865fc,
		"MammaYacht00_hit_data_table": 0x803865fc,
		"MoveBG::MammaYacht00_obj_hit_info": 0x8038660c,
		"MammaYacht00_obj_hit_info": 0x8038660c,
		"MoveBG::@3229": 0x8038661c,
		"MoveBG::SandBombBase00_anim_data": 0x80386670,
		"SandBombBase00_anim_data": 0x80386670,
		"MoveBG::SandBombBase00_map_collision_data": 0x803866a8,
		"SandBombBase00_map_collision_data": 0x803866a8,
		"MoveBG::SandBombBaseMushroom_anim_data": 0x803866d4,
		"SandBombBaseMushroom_anim_data": 0x803866d4,
		"MoveBG::SandBombBaseMushroom_map_collision_data": 0x80386714,
		"SandBombBaseMushroom_map_collision_data": 0x80386714,
		"MoveBG::SandBombBasePyramid_anim_data": 0x8038673c,
		"SandBombBasePyramid_anim_data": 0x8038673c,
		"MoveBG::SandBombBasePyramid_map_collision_data": 0x80386778,
		"SandBombBasePyramid_map_collision_data": 0x80386778,
		"MoveBG::SandBombBaseShit_anim_data": 0x803867a0,
		"SandBombBaseShit_anim_data": 0x803867a0,
		"MoveBG::SandBombBaseShit_map_collision_data": 0x803867dc,
		"SandBombBaseShit_map_collision_data": 0x803867dc,
		"MoveBG::SandBombBaseStar_anim_data": 0x80386804,
		"SandBombBaseStar_anim_data": 0x80386804,
		"MoveBG::SandBombBaseStar_map_collision_data": 0x80386840,
		"SandBombBaseStar_map_collision_data": 0x80386840,
		"MoveBG::SandBombBaseTurtle_anim_data": 0x80386868,
		"SandBombBaseTurtle_anim_data": 0x80386868,
		"MoveBG::SandBombBaseTurtle_map_collision_data": 0x803868a4,
		"SandBombBaseTurtle_map_collision_data": 0x803868a4,
		"MoveBG::SandBombBaseFoot_anim_data": 0x803868cc,
		"SandBombBaseFoot_anim_data": 0x803868cc,
		"MoveBG::SandBombBaseFoot_map_collision_data": 0x80386908,
		"SandBombBaseFoot_map_collision_data": 0x80386908,
		"MoveBG::SandBombBaseHand_anim_data": 0x80386930,
		"SandBombBaseHand_anim_data": 0x80386930,
		"MoveBG::SandBombBaseHand_map_collision_data": 0x8038696c,
		"SandBombBaseHand_map_collision_data": 0x8038696c,
		"MoveBG::SandBombBaseStairs_anim_data": 0x80386994,
		"SandBombBaseStairs_anim_data": 0x80386994,
		"MoveBG::SandBombBaseStairs_map_collision_data": 0x803869d0,
		"SandBombBaseStairs_map_collision_data": 0x803869d0,
		"MoveBG::GoalWatermelon_hit_data_table": 0x803869e0,
		"GoalWatermelon_hit_data_table": 0x803869e0,
		"MoveBG::GoalWatermelon_obj_hit_info": 0x803869f0,
		"GoalWatermelon_obj_hit_info": 0x803869f0,
		"MoveBG::TeethOfJuicer_anim_data": 0x80386a34,
		"TeethOfJuicer_anim_data": 0x80386a34,
		"MoveBG::TeethOfJuicer_hit_data_table": 0x80386a48,
		"TeethOfJuicer_hit_data_table": 0x80386a48,
		"MoveBG::TeethOfJuicer_obj_hit_info": 0x80386a58,
		"TeethOfJuicer_obj_hit_info": 0x80386a58,
		"MoveBG::merrygoround_anim_data": 0x80386a94,
		"merrygoround_anim_data": 0x80386a94,
		"MoveBG::merry_hit_data_table": 0x80386aa8,
		"merry_hit_data_table": 0x80386aa8,
		"MoveBG::merrygoround_obj_hit_info": 0x80386ab8,
		"merrygoround_obj_hit_info": 0x80386ab8,
		"MoveBG::merry_egg_hit_data_table": 0x80386ac8,
		"merry_egg_hit_data_table": 0x80386ac8,
		"MoveBG::merry_egg_obj_hit_info": 0x80386ad8,
		"merry_egg_obj_hit_info": 0x80386ad8,
		"MoveBG::merry_pole_hit_data_table": 0x80386af4,
		"merry_pole_hit_data_table": 0x80386af4,
		"MoveBG::merry_pole_obj_hit_info": 0x80386b04,
		"merry_pole_obj_hit_info": 0x80386b04,
		"MoveBG::FerrisWheel_anim_data": 0x80386b3c,
		"FerrisWheel_anim_data": 0x80386b3c,
		"MoveBG::FerrisWheel_hit_data_table": 0x80386b50,
		"FerrisWheel_hit_data_table": 0x80386b50,
		"MoveBG::FerrisWheel_obj_hit_info": 0x80386b60,
		"FerrisWheel_obj_hit_info": 0x80386b60,
		"MoveBG::FerrisWheelGondola_hit_data_table": 0x80386b8c,
		"FerrisWheelGondola_hit_data_table": 0x80386b8c,
		"MoveBG::FerrisWheelGondola_obj_hit_info": 0x80386b9c,
		"FerrisWheelGondola_obj_hit_info": 0x80386b9c,
		"MoveBG::FerrisLOD_anim_data": 0x80386bc8,
		"FerrisLOD_anim_data": 0x80386bc8,
		"MoveBG::Viking_hit_data_table": 0x80386be8,
		"Viking_hit_data_table": 0x80386be8,
		"MoveBG::Viking_obj_hit_info": 0x80386bf8,
		"Viking_obj_hit_info": 0x80386bf8,
		"MoveBG::balloon_koopajr_anim_data": 0x80386c58,
		"balloon_koopajr_anim_data": 0x80386c58,
		"MoveBG::balloon_koopajr_hit_data_table": 0x80386c94,
		"balloon_koopajr_hit_data_table": 0x80386c94,
		"MoveBG::balloon_koopajr_obj_hit_info": 0x80386ca4,
		"balloon_koopajr_obj_hit_info": 0x80386ca4,
		"MoveBG::@3276": 0x80386cc4,
		"MoveBG::@3277": 0x80386cd4,
		"MoveBG::ShellCup_anim_data": 0x80386ce0,
		"ShellCup_anim_data": 0x80386ce0,
		"MoveBG::@3278": 0x80386cf4,
		"MoveBG::ShellCup_hit_data_table": 0x80386d04,
		"ShellCup_hit_data_table": 0x80386d04,
		"MoveBG::ShellCup_obj_hit_info": 0x80386d14,
		"ShellCup_obj_hit_info": 0x80386d14,
		"MoveBG::Gateshell_anim_data": 0x80386d4c,
		"Gateshell_anim_data": 0x80386d4c,
		"MoveBG::PinnaHangingBridgeBoard_anim_data": 0x80386d7c,
		"PinnaHangingBridgeBoard_anim_data": 0x80386d7c,
		"MoveBG::PinnaHangingBridgeBoard_hit_data_table": 0x80386d90,
		"PinnaHangingBridgeBoard_hit_data_table": 0x80386d90,
		"MoveBG::PinnaHangingBridgeBoard_obj_hit_info": 0x80386da0,
		"PinnaHangingBridgeBoard_obj_hit_info": 0x80386da0,
		"MoveBG::GateManta_anim_data": 0x80386df0,
		"GateManta_anim_data": 0x80386df0,
		"MoveBG::@3289": 0x80386e10,
		"MoveBG::@3290": 0x80386e20,
		"MoveBG::AmiKing_anim_data": 0x80386e34,
		"AmiKing_anim_data": 0x80386e34,
		"MoveBG::AmiKing_hit_data_table": 0x80386e48,
		"AmiKing_hit_data_table": 0x80386e48,
		"MoveBG::AmiKing_obj_hit_info": 0x80386e58,
		"AmiKing_obj_hit_info": 0x80386e58,
		"MoveBG::PinnaCoaster_hit_data_table": 0x80386e68,
		"PinnaCoaster_hit_data_table": 0x80386e68,
		"MoveBG::PinnaCoaster_obj_hit_info": 0x80386e78,
		"PinnaCoaster_obj_hit_info": 0x80386e78,
		"MoveBG::roulette_anim_data": 0x80386ea0,
		"roulette_anim_data": 0x80386ea0,
		"MoveBG::slotdrum_hit_data_table": 0x80386eb4,
		"slotdrum_hit_data_table": 0x80386eb4,
		"MoveBG::slotdrum_obj_hit_info": 0x80386ec4,
		"slotdrum_obj_hit_info": 0x80386ec4,
		"MoveBG::telesaslot_hit_data_table": 0x80386eec,
		"telesaslot_hit_data_table": 0x80386eec,
		"MoveBG::telesaslot_obj_hit_info": 0x80386efc,
		"telesaslot_obj_hit_info": 0x80386efc,
		"MoveBG::@3300": 0x80386f0c,
		"MoveBG::donchou_anim_data": 0x80386f18,
		"donchou_anim_data": 0x80386f18,
		"MoveBG::donchou_hit_data_table": 0x80386f2c,
		"donchou_hit_data_table": 0x80386f2c,
		"MoveBG::donchou_obj_hit_info": 0x80386f3c,
		"donchou_obj_hit_info": 0x80386f3c,
		"MoveBG::casino_panel_gate_hit_data_table": 0x80386f4c,
		"casino_panel_gate_hit_data_table": 0x80386f4c,
		"MoveBG::casino_panel_gate_obj_hit_info": 0x80386f5c,
		"casino_panel_gate_obj_hit_info": 0x80386f5c,
		"MoveBG::bosswall_anim_data": 0x80386f88,
		"bosswall_anim_data": 0x80386f88,
		"MoveBG::casinoroof_anim_data": 0x80386fd0,
		"casinoroof_anim_data": 0x80386fd0,
		"MoveBG::GlassBreak_anim_data": 0x80387014,
		"GlassBreak_anim_data": 0x80387014,
		"MoveBG::GlassBreak_sound_data": 0x803870a0,
		"GlassBreak_sound_data": 0x803870a0,
		"MoveBG::closet_anim_data": 0x803870e0,
		"closet_anim_data": 0x803870e0,
		"MoveBG::closet_hit_data_table": 0x803870f4,
		"closet_hit_data_table": 0x803870f4,
		"MoveBG::closet_obj_hit_info": 0x80387104,
		"closet_obj_hit_info": 0x80387104,
		"MoveBG::ChestRevolve_anim_data": 0x80387158,
		"ChestRevolve_anim_data": 0x80387158,
		"MoveBG::ChestRevolve_map_collision_data": 0x80387190,
		"ChestRevolve_map_collision_data": 0x80387190,
		"MoveBG::PosterTeresa_anim_data": 0x803871c4,
		"PosterTeresa_anim_data": 0x803871c4,
		"MoveBG::PictureTeresa_anim_data": 0x8038720c,
		"PictureTeresa_anim_data": 0x8038720c,
		"MoveBG::PictureTeresa_hit_data_table": 0x80387220,
		"PictureTeresa_hit_data_table": 0x80387220,
		"MoveBG::PictureTeresa_obj_hit_info": 0x80387230,
		"PictureTeresa_obj_hit_info": 0x80387230,
		"MoveBG::PanelBreak_anim_data": 0x8038726c,
		"PanelBreak_anim_data": 0x8038726c,
		"MoveBG::PanelBreak_sound_data": 0x803872f8,
		"PanelBreak_sound_data": 0x803872f8,
		"MoveBG::PanelRevolve_anim_data": 0x80387344,
		"PanelRevolve_anim_data": 0x80387344,
		"MoveBG::cogwheel_anim_data": 0x803873bc,
		"cogwheel_anim_data": 0x803873bc,
		"MoveBG::Cogwheel_hit_data_table": 0x803873d0,
		"Cogwheel_hit_data_table": 0x803873d0,
		"MoveBG::Cogwheel_obj_hit_info": 0x803873e0,
		"Cogwheel_obj_hit_info": 0x803873e0,
		"MoveBG::CogwheelPlate_hit_data_table": 0x8038740c,
		"CogwheelPlate_hit_data_table": 0x8038740c,
		"MoveBG::CogwheelPlate_obj_hit_info": 0x8038741c,
		"CogwheelPlate_obj_hit_info": 0x8038741c,
		"MoveBG::@3336": 0x8038742c,
		"MoveBG::CogwheelPot_hit_data_table": 0x8038743c,
		"CogwheelPot_hit_data_table": 0x8038743c,
		"MoveBG::CogwheelPot_obj_hit_info": 0x8038744c,
		"CogwheelPot_obj_hit_info": 0x8038744c,
		"MoveBG::@3337": 0x8038745c,
		"MoveBG::mare_float_house_hit_data_table": 0x8038746c,
		"mare_float_house_hit_data_table": 0x8038746c,
		"MoveBG::mare_float_house_obj_hit_info": 0x8038747c,
		"mare_float_house_obj_hit_info": 0x8038747c,
		"MoveBG::StopRock_hit_data_table": 0x8038748c,
		"StopRock_hit_data_table": 0x8038748c,
		"MoveBG::StopRock_obj_hit_info": 0x8038749c,
		"StopRock_obj_hit_info": 0x8038749c,
		"MoveBG::@3339": 0x803874ac,
		"MoveBG::ElasticCode_hit_data_table": 0x803874b8,
		"ElasticCode_hit_data_table": 0x803874b8,
		"MoveBG::ElasticCode_obj_hit_info": 0x803874c8,
		"ElasticCode_obj_hit_info": 0x803874c8,
		"MoveBG::@3340": 0x803874d8,
		"MoveBG::@3343": 0x803874fc,
		"MoveBG::GrowthTree_anim_data": 0x8038750c,
		"GrowthTree_anim_data": 0x8038750c,
		"MoveBG::GrowthTree_hit_data_table": 0x80387534,
		"GrowthTree_hit_data_table": 0x80387534,
		"MoveBG::GrowthTree_obj_hit_info": 0x80387544,
		"GrowthTree_obj_hit_info": 0x80387544,
		"MoveBG::MuddyBoat_anim_data": 0x8038759c,
		"MuddyBoat_anim_data": 0x8038759c,
		"MoveBG::MuddyBoat_hit_data_table": 0x803875d8,
		"MuddyBoat_hit_data_table": 0x803875d8,
		"MoveBG::MuddyBoat_obj_hit_info": 0x803875e8,
		"MuddyBoat_obj_hit_info": 0x803875e8,
		"MoveBG::Puncher_anim_data": 0x8038764c,
		"Puncher_anim_data": 0x8038764c,
		"MoveBG::Puncher_hit_data_table": 0x80387674,
		"Puncher_hit_data_table": 0x80387674,
		"MoveBG::Puncher_obj_hit_info": 0x80387684,
		"Puncher_obj_hit_info": 0x80387684,
		"MoveBG::@3354": 0x80387694,
		"MoveBG::@3356": 0x803876b8,
		"MoveBG::HatoPop_anim_data": 0x803876dc,
		"HatoPop_anim_data": 0x803876dc,
		"MoveBG::HatoPop_hit_data_table": 0x80387704,
		"HatoPop_hit_data_table": 0x80387704,
		"MoveBG::HatoPop_obj_hit_info": 0x80387714,
		"HatoPop_obj_hit_info": 0x80387714,
		"MoveBG::MareWaterJump_hit_data_table": 0x80387724,
		"MareWaterJump_hit_data_table": 0x80387724,
		"MoveBG::MareWaterJump_obj_hit_info": 0x80387734,
		"MareWaterJump_obj_hit_info": 0x80387734,
		"MoveBG::@3358": 0x80387744,
		"MoveBG::@3359": 0x80387758,
		"MoveBG::BumpyWall_hit_data_table": 0x80387768,
		"BumpyWall_hit_data_table": 0x80387768,
		"MoveBG::BumpyWall_obj_hit_info": 0x80387778,
		"BumpyWall_obj_hit_info": 0x80387778,
		"MoveBG::@3360": 0x80387788,
		"MoveBG::ExBottle_hit_data_table": 0x8038779c,
		"ExBottle_hit_data_table": 0x8038779c,
		"MoveBG::ExBottle_obj_hit_info": 0x803877ac,
		"ExBottle_obj_hit_info": 0x803877ac,
		"MoveBG::@3362": 0x803877c8,
		"MoveBG::@3363": 0x803877d8,
		"MoveBG::CoinFish_anim_data": 0x803877e4,
		"CoinFish_anim_data": 0x803877e4,
		"MoveBG::@3365": 0x80387804,
		"MoveBG::@3366": 0x80387814,
		"MoveBG::MareFall_anim_data": 0x80387820,
		"MareFall_anim_data": 0x80387820,
		"MoveBG::@3367": 0x80387834,
		"MoveBG::MonteRoot_anim_data": 0x80387858,
		"MonteRoot_anim_data": 0x80387858,
		"MoveBG::MonteRoot_hit_data_table": 0x8038786c,
		"MonteRoot_hit_data_table": 0x8038786c,
		"MoveBG::MonteRoot_obj_hit_info": 0x8038787c,
		"MonteRoot_obj_hit_info": 0x8038787c,
		"MoveBG::@3370": 0x8038788c,
		"MoveBG::@3371": 0x80387898,
		"MoveBG::@3372": 0x803878a8,
		"MoveBG::JumpMushroom_anim_data": 0x803878bc,
		"JumpMushroom_anim_data": 0x803878bc,
		"MoveBG::@3373": 0x803878e4,
		"MoveBG::@3374": 0x803878f0,
		"MoveBG::MonteGoalFlag_anim_data": 0x80387920,
		"MonteGoalFlag_anim_data": 0x80387920,
		"MoveBG::MonteGoalFlag_hit_data_table": 0x80387934,
		"MonteGoalFlag_hit_data_table": 0x80387934,
		"MoveBG::MonteGoalFlag_obj_hit_info": 0x80387944,
		"MonteGoalFlag_obj_hit_info": 0x80387944,
		"MoveBG::HangingBridgeBoard_anim_data": 0x80387970,
		"HangingBridgeBoard_anim_data": 0x80387970,
		"MoveBG::HangingBridgeBoard_hit_data_table": 0x80387984,
		"HangingBridgeBoard_hit_data_table": 0x80387984,
		"MoveBG::HangingBridgeBoard_obj_hit_info": 0x80387994,
		"HangingBridgeBoard_obj_hit_info": 0x80387994,
		"MoveBG::SwingBoard_hit_data_table": 0x803879c8,
		"SwingBoard_hit_data_table": 0x803879c8,
		"MoveBG::SwingBoard_obj_hit_info": 0x803879d8,
		"SwingBoard_obj_hit_info": 0x803879d8,
		"MoveBG::Fluff_anim_data": 0x80387a00,
		"Fluff_anim_data": 0x80387a00,
		"MoveBG::Fluff_hit_data_table": 0x80387a14,
		"Fluff_hit_data_table": 0x80387a14,
		"MoveBG::Fluff_obj_hit_info": 0x80387a24,
		"Fluff_obj_hit_info": 0x80387a24,
		"MoveBG::Bathtub_anim_data": 0x80387a60,
		"Bathtub_anim_data": 0x80387a60,
		"MoveBG::BathtubStandBreaking_anim_data": 0x80387b08,
		"BathtubStandBreaking_anim_data": 0x80387b08,
		"MoveBG::ex1_turn_lift_anim_data": 0x80387b88,
		"ex1_turn_lift_anim_data": 0x80387b88,
		"MoveBG::y_turn_lift_anim_data": 0x80387c0c,
		"y_turn_lift_anim_data": 0x80387c0c,
		"MoveBG::Nail_anim_data": 0x80387c78,
		"Nail_anim_data": 0x80387c78,
		"MoveBG::Nail_hit_data_table": 0x80387c8c,
		"Nail_hit_data_table": 0x80387c8c,
		"MoveBG::Nail_obj_hit_info": 0x80387c9c,
		"Nail_obj_hit_info": 0x80387c9c,
		"MoveBG::PachinkoNail_anim_data": 0x80387ccc,
		"PachinkoNail_anim_data": 0x80387ccc,
		"MoveBG::FileLoadBlockA_anim_data": 0x80387d58,
		"FileLoadBlockA_anim_data": 0x80387d58,
		"MoveBG::FileLoadBlock_hit_data_table": 0x80387d94,
		"FileLoadBlock_hit_data_table": 0x80387d94,
		"MoveBG::FileLoadBlock_obj_hit_info": 0x80387da4,
		"FileLoadBlock_obj_hit_info": 0x80387da4,
		"MoveBG::FileLoadBlockB_anim_data": 0x80387df0,
		"FileLoadBlockB_anim_data": 0x80387df0,
		"MoveBG::FileLoadBlockC_anim_data": 0x80387e68,
		"FileLoadBlockC_anim_data": 0x80387e68,
		"MoveBG::@3728": 0x80387eb4,
		"MoveBG::@2183": 0x80387f30,
		"MoveBG::@2184": 0x80387f68,
		"MoveBG::@2185": 0x80387f9c,
		"MoveBG::@3779": 0x80388190,
		"MoveBG::@3786": 0x803881f8,
		"MoveBG::@3806": 0x80388304,
		"MoveBG::@3807": 0x80388320,
		"MoveBG::@3808": 0x8038832c,
		"MoveBG::@3809": 0x80388338,
		"MoveBG::@3810": 0x80388354,
		"MoveBG::@4173": 0x80388628,
		"MoveBG::@4174": 0x80388644,
		"MoveBG::@4175": 0x80388660,
		"MoveBG::@4176": 0x8038867c,
		"MoveBG::@4177": 0x8038869c,
		"MoveBG::@4178": 0x803886b8,
		"MoveBG::@4179": 0x803886d8,
		"MoveBG::@2409": 0x80388c80,
		"MoveBG::@2410": 0x80388cb0,
		"MoveBG::@2411": 0x80388ce8,
		"MoveBG::@2412": 0x80388d1c,
		"MoveBG::@4241": 0x80388ffc,
		"MoveBG::@3440": 0x8038940c,
		"MoveBG::@2724": 0x803894f8,
		"MoveBG::@4109": 0x803896c4,
		"MoveBG::@2211": 0x80389ce8,
		"MoveBG::@2212": 0x80389d18,
		"MoveBG::@2213": 0x80389d50,
		"MoveBG::@2214": 0x80389d84,
		"MoveBG::@2692": 0x80389db4,
		"MoveBG::@2498": 0x80389fac,
		"MoveBG::@2499": 0x80389fb8,
		"MoveBG::@2500": 0x80389fc8,
		"MoveBG::@2501": 0x80389fd8,
		"MoveBG::@2464": 0x8038a0f0,
		"MoveBG::@2467": 0x8038a0fc,
		"MoveBG::@2468": 0x8038a108,
		"@2468": 0x8038a108,
		"MoveBG::@2469": 0x8038a114,
		"@2469": 0x8038a114,
		"MoveBG::@2470": 0x8038a120,
		"MoveBG::@2471": 0x8038a12c,
		"MoveBG::@2473": 0x8038a148,
		"MoveBG::param_table": 0x8038a168,
		"param_table": 0x8038a168,
		"MoveBG::@2539": 0x8038a378,
		"MoveBG::@2540": 0x8038a39c,
		"MoveBG::@2634": 0x8038a3c0,
		"MoveBG::@2639": 0x8038a420,
		"MoveBG::@2371": 0x8038a460,
		"MoveBG::@2372": 0x8038a490,
		"MoveBG::@2373": 0x8038a4c8,
		"MoveBG::@2374": 0x8038a4fc,
		"MoveBG::@2600": 0x8038aa48,
		"MoveBG::@2188": 0x8038aab8,
		"MoveBG::@2520": 0x8038ab78,
		"MoveBG::@2522": 0x8038ab84,
		"MoveBG::@2397": 0x8038ac18,
		"MoveBG::@2398": 0x8038ac48,
		"MoveBG::@2399": 0x8038ac80,
		"MoveBG::@2400": 0x8038acb4,
		"MoveBG::@2575": 0x8038ad24,
		"MoveBG::@2576": 0x8038ad30,
		"MoveBG::@2577": 0x8038ad3c,
		"MoveBG::@2578": 0x8038ad48,
		"MoveBG::cDirtyFileName": 0x8038b160,
		"MoveBG::cDirtyTexName": 0x8038b184,
		"MoveBG::@3679": 0x8038b218,
		"MoveBG::@3680": 0x8038b238,
		"MoveBG::@3715": 0x8038b2d8,
		"MoveBG::@3755": 0x8038b300,
		"MoveBG::@3758": 0x8038b338,
		"MoveBG::@2753": 0x8038b458,
		"MoveBG::@2605": 0x8038b8e0,
		"MoveBG::@2659": 0x8038b924,
		"MoveBG::@2660": 0x8038b934,
		"MoveBG::@2661": 0x8038b954,
		"MoveBG::@5842": 0x8038bd4c,
		"MoveBG::@5966": 0x8038bdbc,
		"@5966": 0x8038bdbc,
		"MoveBG::@5967": 0x8038bdcc,
		"@5967": 0x8038bdcc,
		"MoveBG::@5968": 0x8038bddc,
		"@5968": 0x8038bddc,
		"MoveBG::@5969": 0x8038bdec,
		"@5969": 0x8038bdec,
		"MoveBG::@5970": 0x8038bdf8,
		"@5970": 0x8038bdf8,
		"MoveBG::@5971": 0x8038be04,
		"@5971": 0x8038be04,
		"MoveBG::@5972": 0x8038be10,
		"@5972": 0x8038be10,
		"MoveBG::@5973": 0x8038be1c,
		"@5973": 0x8038be1c,
		"MoveBG::@5976": 0x8038be38,
		"@5976": 0x8038be38,
		"MoveBG::@5977": 0x8038be44,
		"@5977": 0x8038be44,
		"MoveBG::@5978": 0x8038be50,
		"@5978": 0x8038be50,
		"MoveBG::@5991": 0x8038be9c,
		"MoveBG::@2546": 0x8038bf00,
		"MoveBG::@2547": 0x8038bf30,
		"MoveBG::@2548": 0x8038bf68,
		"MoveBG::@2549": 0x8038bf9c,
		"MoveBG::@2327": 0x8038c1c0,
		"MoveBG::@2328": 0x8038c1f0,
		"MoveBG::@2329": 0x8038c228,
		"MoveBG::@2330": 0x8038c25c,
		"Map::@2324": 0x80380680,
		"Map::@2514": 0x80380770,
		"Map::@2516": 0x8038077c,
		"Map::@2972": 0x80380788,
		"Map::@3338": 0x80380798,
		"Map::@3339": 0x803807b4,
		"Map::@3340": 0x803807c4,
		"Map::@3506": 0x803807d4,
		"Map::@3507": 0x803807ec,
		"Map::@3509": 0x803807f8,
		"Map::@3510": 0x8038080c,
		"Map::@3511": 0x80380818,
		"Map::@3512": 0x8038082c,
		"Map::@3566": 0x80380848,
		"Map::@3567": 0x80380860,
		"Map::@3701": 0x8038086c,
		"Map::@3702": 0x80380880,
		"Map::@3703": 0x8038088c,
		"Map::@3704": 0x803808b0,
		"Map::@3705": 0x803808d4,
		"Map::@3799": 0x803808f0,
		"Map::@3800": 0x80380904,
		"Map::@3801": 0x8038092c,
		"Map::@3802": 0x80380954,
		"Map::@1526": 0x80380984,
		"Map::@1766": 0x80380998,
		"@1766": 0x80380998,
		"Map::@1768": 0x803809a4,
		"Map::@2018": 0x803809b0,
		"Map::@2019": 0x803809c0,
		"Map::@2020": 0x803809d0,
		"Map::@2272": 0x80380a18,
		"Map::@2273": 0x80380a48,
		"Map::@2274": 0x80380a80,
		"Map::@2275": 0x80380ab4,
		"Map::@2604": 0x80380ad8,
		"Map::@3076": 0x80380af0,
		"Map::@3151": 0x80380b38,
		"Map::@3154": 0x80380b44,
		"Map::@2513": 0x80380ca0,
		"Map::@2515": 0x80380cac,
		"Map::@2517": 0x80380cb8,
		"Map::@2667": 0x80380d08,
		"Map::@2502": 0x80380d18,
		"Map::@2503": 0x80380d28,
		"Map::@2197": 0x80380e00,
		"Map::@2198": 0x80380e30,
		"Map::@2199": 0x80380e68,
		"Map::@2200": 0x80380e9c,
		"Map::@2882": 0x80380f9c,
		"Map::@2883": 0x80380fa8,
		"Map::@2884": 0x80380fc0,
		"Map::@2885": 0x80380fe4,
		"Map::@2886": 0x80380ff8,
		"Map::@2887": 0x80381004,
		"Map::@2888": 0x80381018,
		"Map::@2889": 0x8038102c,
		"Map::@2890": 0x80381040,
		"Map::@2891": 0x80381054,
		"Map::@2892": 0x80381068,
		"Map::@2893": 0x80381074,
		"Map::@2894": 0x80381088,
		"Map::@2895": 0x8038109c,
		"Map::@2896": 0x803810b4,
		"Map::@2897": 0x803810c0,
		"Map::@2898": 0x803810cc,
		"Map::@2899": 0x803810d8,
		"Map::actor_data_table": 0x803810e4,
		"actor_data_table": 0x803810e4,
		"Map::sound_info": 0x803818a4,
		"sound_info": 0x803818a4,
		"Map::@1937": 0x80381974,
		"Map::@2174": 0x80381988,
		"Map::@2176": 0x80381994,
		"Map::@2579": 0x803819a0,
		"Map::@2178": 0x80381a20,
		"Map::@2179": 0x80381a50,
		"Map::@2180": 0x80381a88,
		"Map::@2181": 0x80381abc,
		"Map::@2829": 0x80381bf4,
		"Map::@2986": 0x80381c00,
		"Map::@2987": 0x80381c14,
		"Map::@2988": 0x80381c28,
		"Map::@2771": 0x80381db0,
		"Map::@2772": 0x80381dd4,
		"Map::@2784": 0x80381df8,
		"Map::@1974": 0x80381ea8,
		"Map::@2925": 0x80381fd0,
		"Map::@3396": 0x803820b8,
		"Map::@3403": 0x803820d8,
		"Map::@3688": 0x803820fc,
		"Map::@3699": 0x8038210c,
		"Map::@3735": 0x8038211c,
		"Map::@1900": 0x80382138,
		"Map::@1907": 0x8038214c,
		"Map::@1996": 0x80382158,
		"Map::@1997": 0x80382188,
		"Map::@1998": 0x803821c0,
		"Map::@1999": 0x803821f4,
		"Map::@4358": 0x80382324,
		"Map::@4748": 0x803823c8,
		"Map::@4749": 0x803823d4,
		"Map::@4752": 0x803823e0,
		"Map::@4755": 0x803823f0,
		"Map::@4758": 0x8038241c,
		"Map::@4762": 0x80382434,
		"Map::@4832": 0x80382490,
		"Map::@4834": 0x8038249c,
		"Map::@4835": 0x803824a8,
		"Map::@4837": 0x803824b4,
		"Map::@4838": 0x803824c0,
		"Map::@4844": 0x803824d8,
		"GC2D::@1772": 0x8037eb68,
		"GC2D::@1953": 0x8037eb84,
		"GC2D::@2082": 0x8037eb98,
		"GC2D::@2084": 0x8037ebb8,
		"GC2D::@2086": 0x8037ebd8,
		"GC2D::scNozzleSoundList": 0x8037ec18,
		"scNozzleSoundList": 0x8037ec18,
		"GC2D::@1937": 0x8037ee04,
		"GC2D::scTalkSoundList": 0x8037eed8,
		"scTalkSoundList": 0x8037eed8,
		"GC2D::@1991": 0x8037f3d8,
		"GC2D::@2112": 0x8037f4dc,
		"GC2D::@1705": 0x8037f9b4,
		"GC2D::@2421": 0x8037fa74,
		"GC2D::@2422": 0x8037faa0,
		"GC2D::@3045": 0x8037fc14,
		"GC2D::@3046": 0x8037fc24,
		"GC2D::@3047": 0x8037fc34,
		"GC2D::@3048": 0x8037fc40,
		"GC2D::@3049": 0x8037fc50,
		"GC2D::@3050": 0x8037fc64,
		"GC2D::@3051": 0x8037fc74,
		"GC2D::@3052": 0x8037fc80,
		"GC2D::@3053": 0x8037fc8c,
		"GC2D::@3054": 0x8037fc98,
		"GC2D::@3055": 0x8037fcac,
		"GC2D::@3056": 0x8037fcd4,
		"GC2D::@3057": 0x8037fcfc,
		"GC2D::@3058": 0x8037fd24,
		"GC2D::@3059": 0x8037fd50,
		"GC2D::@3060": 0x8037fd78,
		"GC2D::@3066": 0x8037fe3c,
		"GC2D::@1752": 0x8037fe9c,
		"GC2D::@2482": 0x8037feb0,
		"GC2D::@2483": 0x8037fec8,
		"GC2D::@1942": 0x8037ff2c,
		"GC2D::@4089": 0x8037ff8c,
		"GC2D::@4090": 0x8037ffa4,
		"GC2D::@4091": 0x8037ffc8,
		"GC2D::@4092": 0x8037ffec,
		"GC2D::@4093": 0x80380014,
		"GC2D::@4094": 0x8038003c,
		"GC2D::@4095": 0x80380060,
		"GC2D::@1938": 0x8038020c,
		"@unnamed@::cRumbleAnm": 0x80380220,
		"cRumbleAnm": 0x80380220,
		"@unnamed@::cSurMonteAnm": 0x80380270,
		"cSurMonteAnm": 0x80380270,
		"@unnamed@::cSurLTSpeakerAnm": 0x803802b0,
		"cSurLTSpeakerAnm": 0x803802b0,
		"@unnamed@::cSurRTSpeakerAnm": 0x803802d8,
		"cSurRTSpeakerAnm": 0x803802d8,
		"@unnamed@::cSurLBSpeakerAnm": 0x80380300,
		"cSurLBSpeakerAnm": 0x80380300,
		"@unnamed@::cSurRBSpeakerAnm": 0x80380328,
		"cSurRBSpeakerAnm": 0x80380328,
		"@unnamed@::cSteMonteAnm": 0x80380350,
		"cSteMonteAnm": 0x80380350,
		"@unnamed@::cSteLSpeakerAnm": 0x80380390,
		"cSteLSpeakerAnm": 0x80380390,
		"@unnamed@::cSteRSpeakerAnm": 0x803803b8,
		"cSteRSpeakerAnm": 0x803803b8,
		"@unnamed@::cMonoMonteAnm": 0x803803e0,
		"cMonoMonteAnm": 0x803803e0,
		"@unnamed@::cMonoSpeakerAnm": 0x803803f0,
		"cMonoSpeakerAnm": 0x803803f0,
		"@unnamed@::cSoundToggleItems": 0x80380400,
		"cSoundToggleItems": 0x80380400,
		"GC2D::@1557": 0x80380648,
		"GC2D::@1578": 0x8038065c,
		"GC2D::@1579": 0x80380668,
		"Enemy::@4571": 0x8036eaf0,
		"@4571": 0x8036eaf0,
		"Enemy::@2141": 0x8036eb74,
		"Enemy::@2673": 0x8036ec48,
		"Enemy::@2685": 0x8036ec60,
		"Enemy::@1973": 0x8036ef68,
		"Enemy::@1974": 0x8036ef98,
		"Enemy::@1975": 0x8036efd0,
		"Enemy::@1976": 0x8036f004,
		"Enemy::@2270": 0x8036f168,
		"Enemy::@2272": 0x8036f1d4,
		"Enemy::@2281": 0x8036f2d8,
		"Enemy::@2283": 0x8036f344,
		"Enemy::replayLinkMonteMan": 0x8036f9ac,
		"replayLinkMonteMan": 0x8036f9ac,
		"Enemy::@6434": 0x8036fa94,
		"@6434": 0x8036fa94,
		"Enemy::@6435": 0x8036fabc,
		"@6435": 0x8036fabc,
		"Enemy::@6437": 0x8036fb20,
		"@6437": 0x8036fb20,
		"Enemy::@6438": 0x8036fb48,
		"@6438": 0x8036fb48,
		"Enemy::@6439": 0x8036fb70,
		"@6439": 0x8036fb70,
		"Enemy::@6440": 0x8036fb98,
		"@6440": 0x8036fb98,
		"Enemy::@6441": 0x8036fbb0,
		"@6441": 0x8036fbb0,
		"Enemy::@6442": 0x8036fbbc,
		"@6442": 0x8036fbbc,
		"Enemy::@6444": 0x8036fbcc,
		"@6444": 0x8036fbcc,
		"Enemy::@6445": 0x8036fbd8,
		"@6445": 0x8036fbd8,
		"Enemy::@6446": 0x8036fbe4,
		"@6446": 0x8036fbe4,
		"Enemy::@6448": 0x8036fbfc,
		"@6448": 0x8036fbfc,
		"Enemy::@6449": 0x8036fc08,
		"@6449": 0x8036fc08,
		"Enemy::@6450": 0x8036fc18,
		"@6450": 0x8036fc18,
		"Enemy::@6451": 0x8036fc24,
		"@6451": 0x8036fc24,
		"Enemy::@6455": 0x8036fc50,
		"@6455": 0x8036fc50,
		"Enemy::@6456": 0x8036fc6c,
		"@6456": 0x8036fc6c,
		"Enemy::@6457": 0x8036fc88,
		"@6457": 0x8036fc88,
		"Enemy::@6458": 0x8036fca8,
		"@6458": 0x8036fca8,
		"Enemy::@6461": 0x8036fccc,
		"@6461": 0x8036fccc,
		"Enemy::@6462": 0x8036fcdc,
		"@6462": 0x8036fcdc,
		"Enemy::@6463": 0x8036fd00,
		"@6463": 0x8036fd00,
		"Enemy::@6464": 0x8036fd24,
		"@6464": 0x8036fd24,
		"Enemy::@6465": 0x8036fd48,
		"@6465": 0x8036fd48,
		"Enemy::@6466": 0x8036fd54,
		"@6466": 0x8036fd54,
		"Enemy::@6467": 0x8036fd60,
		"@6467": 0x8036fd60,
		"Enemy::@5330": 0x803702a0,
		"Enemy::@5331": 0x803702b4,
		"Enemy::@5332": 0x803702cc,
		"Enemy::@5333": 0x803702e4,
		"Enemy::@5334": 0x803702f8,
		"Enemy::@5336": 0x80370324,
		"Enemy::@5338": 0x80370334,
		"Enemy::@5340": 0x80370344,
		"Enemy::@1961": 0x803703b0,
		"Enemy::@1962": 0x803703e0,
		"Enemy::@1963": 0x80370418,
		"Enemy::@1964": 0x8037044c,
		"Enemy::@7735": 0x80370944,
		"@7735": 0x80370944,
		"Enemy::@7736": 0x80370950,
		"@7736": 0x80370950,
		"Enemy::@7737": 0x8037095c,
		"@7737": 0x8037095c,
		"Enemy::@7755": 0x8037098c,
		"@7755": 0x8037098c,
		"Enemy::@7788": 0x803709d0,
		"@7788": 0x803709d0,
		"Enemy::@7904": 0x80370a48,
		"@7904": 0x80370a48,
		"Enemy::@7905": 0x80370a58,
		"Enemy::@7906": 0x80370a68,
		"@7906": 0x80370a68,
		"Enemy::@7907": 0x80370a7c,
		"@7907": 0x80370a7c,
		"Enemy::@7908": 0x80370a90,
		"@7908": 0x80370a90,
		"Enemy::@8294": 0x80370b10,
		"@8294": 0x80370b10,
		"Enemy::@8297": 0x80370b38,
		"Enemy::@8298": 0x80370b48,
		"@8298": 0x80370b48,
		"Enemy::@8299": 0x80370b54,
		"@8299": 0x80370b54,
		"Enemy::@8300": 0x80370b68,
		"@8300": 0x80370b68,
		"Enemy::@8301": 0x80370b7c,
		"@8301": 0x80370b7c,
		"Enemy::@8302": 0x80370b90,
		"@8302": 0x80370b90,
		"Enemy::@8303": 0x80370ba8,
		"Enemy::@8304": 0x80370bb4,
		"@8304": 0x80370bb4,
		"Enemy::@8305": 0x80370bc8,
		"@8305": 0x80370bc8,
		"Enemy::@8306": 0x80370bdc,
		"@8306": 0x80370bdc,
		"Enemy::@8307": 0x80370bf0,
		"@8307": 0x80370bf0,
		"Enemy::@2430": 0x80370ce0,
		"Enemy::@2478": 0x80370de0,
		"@2478": 0x80370de0,
		"Enemy::@2479": 0x80370dec,
		"Enemy::@2480": 0x80370df8,
		"Enemy::@2481": 0x80370e04,
		"Enemy::@2482": 0x80370e10,
		"Enemy::@2483": 0x80370e1c,
		"Enemy::@2484": 0x80370e28,
		"Enemy::@2121": 0x80370fb4,
		"Enemy::nameKuriTevColorData": 0x803710b4,
		"nameKuriTevColorData": 0x803710b4,
		"Enemy::@4531": 0x803712a4,
		"Enemy::@2325": 0x803712ec,
		"Enemy::@2565": 0x80371330,
		"Enemy::@5123": 0x803715d4,
		"Enemy::@5125": 0x803715e0,
		"Enemy::@5127": 0x80371608,
		"Enemy::@2396": 0x80371688,
		"Enemy::@2398": 0x80371694,
		"Enemy::@4947": 0x803717c4,
		"Enemy::@4961": 0x80371854,
		"Enemy::@4964": 0x80371884,
		"Enemy::@4966": 0x80371898,
		"Enemy::@4968": 0x803718a8,
		"Enemy::@1604": 0x80371980,
		"Enemy::@1605": 0x803719b0,
		"Enemy::@1606": 0x803719e8,
		"Enemy::@2252": 0x80371a40,
		"Enemy::@2253": 0x80371a54,
		"Enemy::@2370": 0x80371a88,
		"Enemy::@2373": 0x80371b24,
		"Enemy::@2112": 0x80371b9c,
		"Enemy::@3712": 0x80371e40,
		"Enemy::@9188": 0x80372434,
		"@9188": 0x80372434,
		"Enemy::@9189": 0x80372444,
		"@9189": 0x80372444,
		"Enemy::@9191": 0x80372464,
		"@9191": 0x80372464,
		"Enemy::@9192": 0x80372474,
		"@9192": 0x80372474,
		"Enemy::@9193": 0x80372484,
		"@9193": 0x80372484,
		"Enemy::@9194": 0x80372494,
		"@9194": 0x80372494,
		"Enemy::@9196": 0x803724ac,
		"@9196": 0x803724ac,
		"Enemy::@2346": 0x80372674,
		"Enemy::@5269": 0x80372990,
		"Enemy::@5271": 0x803729c0,
		"Enemy::cTelesaColor": 0x80372b5c,
		"cTelesaColor": 0x80372b5c,
		"Enemy::@5411": 0x80372e4c,
		"Enemy::@5414": 0x80372e88,
		"Enemy::@5415": 0x80372ea0,
		"@5415": 0x80372ea0,
		"Enemy::@5417": 0x80372eb8,
		"Enemy::@2255": 0x80372f48,
		"Enemy::@2256": 0x80372f80,
		"Enemy::@2257": 0x80372fb4,
		"Enemy::@7290": 0x803730ac,
		"@7290": 0x803730ac,
		"Enemy::@7429": 0x80373128,
		"@7429": 0x80373128,
		"Enemy::@8401": 0x80373160,
		"@8401": 0x80373160,
		"Enemy::@9114": 0x803731d4,
		"@9114": 0x803731d4,
		"Enemy::@9116": 0x803731e8,
		"@9116": 0x803731e8,
		"Enemy::@9117": 0x803731f8,
		"@9117": 0x803731f8,
		"Enemy::@9118": 0x8037320c,
		"@9118": 0x8037320c,
		"Enemy::@9120": 0x8037322c,
		"@9120": 0x8037322c,
		"Enemy::@9122": 0x8037323c,
		"@9122": 0x8037323c,
		"Enemy::@9124": 0x80373248,
		"@9124": 0x80373248,
		"Enemy::@9125": 0x80373254,
		"@9125": 0x80373254,
		"Enemy::@9126": 0x80373260,
		"@9126": 0x80373260,
		"Enemy::@9127": 0x80373274,
		"@9127": 0x80373274,
		"Enemy::@9129": 0x8037329c,
		"@9129": 0x8037329c,
		"Enemy::@9131": 0x803732ac,
		"@9131": 0x803732ac,
		"Enemy::@9133": 0x803732bc,
		"@9133": 0x803732bc,
		"Enemy::@9134": 0x803732d0,
		"@9134": 0x803732d0,
		"Enemy::@9135": 0x803732e8,
		"@9135": 0x803732e8,
		"Enemy::@9136": 0x803732fc,
		"@9136": 0x803732fc,
		"Enemy::@9137": 0x8037330c,
		"@9137": 0x8037330c,
		"Enemy::@9139": 0x80373334,
		"@9139": 0x80373334,
		"Enemy::@9141": 0x80373344,
		"@9141": 0x80373344,
		"Enemy::@9142": 0x80373358,
		"@9142": 0x80373358,
		"Enemy::@9144": 0x80373380,
		"@9144": 0x80373380,
		"Enemy::@9146": 0x80373394,
		"@9146": 0x80373394,
		"Enemy::@9148": 0x803733bc,
		"@9148": 0x803733bc,
		"Enemy::@9150": 0x803733cc,
		"@9150": 0x803733cc,
		"Enemy::@2233": 0x803733f0,
		"Enemy::@2154": 0x8037340c,
		"Enemy::@2210": 0x80373420,
		"Enemy::@2211": 0x80373450,
		"Enemy::@2212": 0x80373488,
		"Enemy::@2213": 0x803734bc,
		"Enemy::@3113": 0x803737f4,
		"Enemy::@5869": 0x80373b98,
		"Enemy::@5870": 0x80373bc0,
		"Enemy::@5871": 0x80373be8,
		"Enemy::@5872": 0x80373c14,
		"Enemy::@5873": 0x80373c40,
		"Enemy::@7218": 0x80373ca4,
		"@7218": 0x80373ca4,
		"Enemy::@7220": 0x80373cb8,
		"@7220": 0x80373cb8,
		"Enemy::@7222": 0x80373ccc,
		"@7222": 0x80373ccc,
		"Enemy::@7223": 0x80373ce0,
		"@7223": 0x80373ce0,
		"Enemy::@7224": 0x80373cf0,
		"@7224": 0x80373cf0,
		"Enemy::@8315": 0x80373d7c,
		"@8315": 0x80373d7c,
		"Enemy::@8316": 0x80373d90,
		"@8316": 0x80373d90,
		"Enemy::@8317": 0x80373da4,
		"@8317": 0x80373da4,
		"Enemy::@8318": 0x80373db4,
		"@8318": 0x80373db4,
		"Enemy::@8320": 0x80373ddc,
		"@8320": 0x80373ddc,
		"Enemy::@8322": 0x80373dfc,
		"Enemy::@8325": 0x80373e20,
		"Enemy::@8327": 0x80373e30,
		"Enemy::@8329": 0x80373e44,
		"@8329": 0x80373e44,
		"Enemy::@8331": 0x80373e64,
		"Enemy::@8334": 0x80373e88,
		"Enemy::@8335": 0x80373e9c,
		"Enemy::@8336": 0x80373eb0,
		"Enemy::@8338": 0x80373ec4,
		"Enemy::@6087": 0x80374da8,
		"@6087": 0x80374da8,
		"Enemy::@6088": 0x80374dc0,
		"@6088": 0x80374dc0,
		"Enemy::@6089": 0x80374dd0,
		"Enemy::@6091": 0x80374de4,
		"Enemy::@6093": 0x80374e0c,
		"Enemy::entry$2906": 0x80374f90,
		"entry$2906": 0x80374f90,
		"Enemy::@2110": 0x8037501c,
		"Enemy::@7585": 0x803754cc,
		"Enemy::@7586": 0x803754dc,
		"@7586": 0x803754dc,
		"Enemy::@7587": 0x803754ec,
		"@7587": 0x803754ec,
		"Enemy::@7589": 0x8037550c,
		"@7589": 0x8037550c,
		"Enemy::@7590": 0x8037551c,
		"@7590": 0x8037551c,
		"Enemy::@7593": 0x8037553c,
		"@7593": 0x8037553c,
		"Enemy::@7595": 0x80375550,
		"@7595": 0x80375550,
		"Enemy::@2150": 0x8037595c,
		"Enemy::@4484": 0x8037601c,
		"Enemy::@4485": 0x80376030,
		"Enemy::@5050": 0x8037646c,
		"Enemy::@5053": 0x8037648c,
		"Enemy::@2315": 0x803764ac,
		"Enemy::@2554": 0x803764c0,
		"Enemy::@2555": 0x803764f0,
		"Enemy::@3934": 0x80376768,
		"Enemy::@3936": 0x8037679c,
		"Enemy::@7630": 0x80376858,
		"@7630": 0x80376858,
		"Enemy::@7633": 0x8037687c,
		"@7633": 0x8037687c,
		"Enemy::@7634": 0x80376888,
		"@7634": 0x80376888,
		"Enemy::@7635": 0x80376894,
		"@7635": 0x80376894,
		"Enemy::@7636": 0x803768a0,
		"Enemy::@7637": 0x803768ac,
		"Enemy::@7638": 0x803768b8,
		"Enemy::@7639": 0x803768c4,
		"Enemy::@7640": 0x803768d0,
		"Enemy::@7641": 0x803768dc,
		"Enemy::@7642": 0x803768e8,
		"Enemy::@7643": 0x803768f4,
		"Enemy::@7644": 0x80376900,
		"Enemy::@7645": 0x8037690c,
		"Enemy::@7646": 0x80376918,
		"Enemy::@7647": 0x80376924,
		"Enemy::@7648": 0x80376930,
		"Enemy::@7649": 0x8037693c,
		"Enemy::@7650": 0x80376948,
		"Enemy::@7651": 0x80376954,
		"Enemy::@7652": 0x80376964,
		"@7652": 0x80376964,
		"Enemy::@7677": 0x80376d04,
		"@7677": 0x80376d04,
		"Enemy::@8598": 0x80376dd4,
		"@8598": 0x80376dd4,
		"Enemy::@8599": 0x80376de4,
		"@8599": 0x80376de4,
		"Enemy::@8600": 0x80376df4,
		"@8600": 0x80376df4,
		"Enemy::@8601": 0x80376e04,
		"@8601": 0x80376e04,
		"Enemy::@8602": 0x80376e18,
		"@8602": 0x80376e18,
		"Enemy::@8603": 0x80376e2c,
		"@8603": 0x80376e2c,
		"Enemy::@8604": 0x80376e38,
		"@8604": 0x80376e38,
		"Enemy::@8605": 0x80376e48,
		"@8605": 0x80376e48,
		"Enemy::@8606": 0x80376e58,
		"@8606": 0x80376e58,
		"Enemy::@8607": 0x80376e6c,
		"@8607": 0x80376e6c,
		"Enemy::@8608": 0x80376e7c,
		"@8608": 0x80376e7c,
		"Enemy::@8609": 0x80376e8c,
		"@8609": 0x80376e8c,
		"Enemy::@8610": 0x80376ea8,
		"@8610": 0x80376ea8,
		"Enemy::@8611": 0x80376ec0,
		"@8611": 0x80376ec0,
		"Enemy::@8612": 0x80376ed0,
		"@8612": 0x80376ed0,
		"Enemy::@8613": 0x80376ee4,
		"@8613": 0x80376ee4,
		"Enemy::@8614": 0x80376ef8,
		"@8614": 0x80376ef8,
		"Enemy::@8615": 0x80376f0c,
		"@8615": 0x80376f0c,
		"Enemy::@9058": 0x80376f48,
		"@9058": 0x80376f48,
		"Enemy::@9060": 0x80376f64,
		"@9060": 0x80376f64,
		"Enemy::@9061": 0x80376f70,
		"@9061": 0x80376f70,
		"Enemy::@9062": 0x80376f80,
		"@9062": 0x80376f80,
		"Enemy::@5159": 0x803775f4,
		"Enemy::@5780": 0x80377634,
		"@5780": 0x80377634,
		"Enemy::@5782": 0x80377660,
		"@5782": 0x80377660,
		"Enemy::@5784": 0x8037766c,
		"@5784": 0x8037766c,
		"Enemy::@6156": 0x803777f0,
		"Enemy::@6158": 0x803777fc,
		"@6158": 0x803777fc,
		"Enemy::@6161": 0x8037781c,
		"@6161": 0x8037781c,
		"Enemy::@6169": 0x803778bc,
		"Enemy::@7954": 0x80377e78,
		"@7954": 0x80377e78,
		"Enemy::@7955": 0x80377ea0,
		"@7955": 0x80377ea0,
		"Enemy::@8097": 0x803780d4,
		"@8097": 0x803780d4,
		"Enemy::@8102": 0x80378118,
		"@8102": 0x80378118,
		"Enemy::@8104": 0x8037813c,
		"@8104": 0x8037813c,
		"Enemy::@8105": 0x80378154,
		"@8105": 0x80378154,
		"Enemy::@8106": 0x8037816c,
		"@8106": 0x8037816c,
		"Enemy::@8107": 0x80378184,
		"@8107": 0x80378184,
		"Enemy::@8109": 0x803781b0,
		"@8109": 0x803781b0,
		"Enemy::@8110": 0x803781c4,
		"@8110": 0x803781c4,
		"Enemy::@8111": 0x803781d4,
		"@8111": 0x803781d4,
		"Enemy::@8112": 0x803781e8,
		"@8112": 0x803781e8,
		"Enemy::@9004": 0x80378270,
		"@9004": 0x80378270,
		"Enemy::@2118": 0x8037873c,
		"Enemy::@2359": 0x803787b8,
		"Enemy::@2701": 0x803789b0,
		"Enemy::@4297": 0x80378b88,
		"@4297": 0x80378b88,
		"Enemy::@5348": 0x80379034,
		"Enemy::@5349": 0x80379040,
		"Enemy::@5350": 0x80379050,
		"Enemy::@5351": 0x80379060,
		"Enemy::@5353": 0x80379084,
		"Enemy::@5354": 0x80379094,
		"Enemy::@2261": 0x80379244,
		"Enemy::entry$2260": 0x8037925c,
		"entry$2260": 0x8037925c,
		"Enemy::@1597": 0x803792d8,
		"Enemy::@2029": 0x80379398,
		"Enemy::@2031": 0x803793a8,
		"Enemy::@2004": 0x80379670,
		"Enemy::@2005": 0x803796a0,
		"Enemy::@2006": 0x803796d8,
		"Enemy::@2007": 0x8037970c,
		"Enemy::@2353": 0x8037973c,
		"Enemy::@2715": 0x803797b0,
		"Enemy::@4364": 0x803797f4,
		"Enemy::@4365": 0x80379808,
		"Enemy::@4833": 0x8037981c,
		"Enemy::@4834": 0x80379830,
		"Enemy::@2220": 0x80379890,
		"Enemy::@2221": 0x803798c0,
		"Enemy::@2222": 0x803798f8,
		"Enemy::@2223": 0x8037992c,
		"Enemy::sBodyBckIndex$2891": 0x803799b8,
		"sBodyBckIndex$2891": 0x803799b8,
		"Enemy::sHeadBckIndex$2906": 0x80379a00,
		"sHeadBckIndex$2906": 0x80379a00,
		"Enemy::sHeadBtpIndex$2907": 0x80379a48,
		"sHeadBtpIndex$2907": 0x80379a48,
		"Enemy::sHeadBtkIndex$2908": 0x80379a90,
		"sHeadBtkIndex$2908": 0x80379a90,
		"Enemy::@1637": 0x80379b28,
		"Enemy::@1639": 0x80379b40,
		"Enemy::@1641": 0x80379b54,
		"Enemy::@1643": 0x80379b6c,
		"Enemy::@1645": 0x80379b80,
		"@1645": 0x80379b80,
		"Enemy::@1646": 0x80379b94,
		"@1646": 0x80379b94,
		"Enemy::@1648": 0x80379ba4,
		"@1648": 0x80379ba4,
		"Enemy::@1650": 0x80379bb8,
		"Enemy::@1652": 0x80379bcc,
		"Enemy::@1654": 0x80379be4,
		"@1654": 0x80379be4,
		"Enemy::@1656": 0x80379bfc,
		"@1656": 0x80379bfc,
		"Enemy::@1657": 0x80379c14,
		"Enemy::@1658": 0x80379c28,
		"Enemy::@1660": 0x80379c40,
		"Enemy::@1661": 0x80379c54,
		"Enemy::@1662": 0x80379c70,
		"Enemy::@1666": 0x80379c98,
		"Enemy::@1667": 0x80379cac,
		"Enemy::@1669": 0x80379cbc,
		"Enemy::@1671": 0x80379ccc,
		"Enemy::@1673": 0x80379cec,
		"Enemy::@1674": 0x80379d04,
		"Enemy::@1675": 0x80379d1c,
		"Enemy::@1676": 0x80379d30,
		"Enemy::@1677": 0x80379d44,
		"@1677": 0x80379d44,
		"Enemy::@1678": 0x80379d58,
		"@1678": 0x80379d58,
		"Enemy::@1679": 0x80379d6c,
		"@1679": 0x80379d6c,
		"Enemy::@1681": 0x80379d84,
		"Enemy::@1682": 0x80379d98,
		"Enemy::@1684": 0x80379dac,
		"Enemy::@1686": 0x80379dc0,
		"Enemy::@1687": 0x80379dd8,
		"Enemy::@1778": 0x80379de8,
		"Enemy::@1780": 0x80379df8,
		"Enemy::@1786": 0x80379e34,
		"Enemy::@1788": 0x80379e48,
		"@1788": 0x80379e48,
		"Enemy::@1792": 0x80379e70,
		"@1792": 0x80379e70,
		"Enemy::@1793": 0x80379e84,
		"@1793": 0x80379e84,
		"Enemy::@1802": 0x80379efc,
		"Enemy::@1803": 0x80379f10,
		"Enemy::@1805": 0x80379f24,
		"@1805": 0x80379f24,
		"Enemy::@1806": 0x80379f38,
		"Enemy::@1808": 0x80379f48,
		"Enemy::@1810": 0x80379f58,
		"Enemy::@1812": 0x80379f6c,
		"@1812": 0x80379f6c,
		"Enemy::@1814": 0x80379f80,
		"@1814": 0x80379f80,
		"Enemy::@1816": 0x80379f98,
		"Enemy::@1818": 0x80379fb0,
		"Enemy::@1820": 0x80379fc8,
		"Enemy::@1821": 0x80379fe0,
		"@1821": 0x80379fe0,
		"Enemy::@1822": 0x80379ff8,
		"@1822": 0x80379ff8,
		"Enemy::@1824": 0x8037a00c,
		"@1824": 0x8037a00c,
		"Enemy::@1825": 0x8037a020,
		"Enemy::@2560": 0x8037a0f4,
		"Enemy::@2434": 0x8037a7c0,
		"@2434": 0x8037a7c0,
		"Enemy::@2435": 0x8037a7f0,
		"@2435": 0x8037a7f0,
		"Enemy::@2436": 0x8037a828,
		"@2436": 0x8037a828,
		"Enemy::@2437": 0x8037a85c,
		"Enemy::sSnortStepFrames": 0x8037a880,
		"sSnortStepFrames": 0x8037a880,
		"Enemy::entry$2836": 0x8037ac20,
		"entry$2836": 0x8037ac20,
		"Enemy::@3211": 0x8037ac50,
		"Enemy::@2444": 0x8037ac88,
		"Enemy::zangle$3575": 0x8037ae08,
		"zangle$3575": 0x8037ae08,
		"Enemy::@2122": 0x8037b004,
		"Enemy::@2363": 0x8037b048,
		"Enemy::@2365": 0x8037b0b4,
		"Enemy::@1755": 0x8037b370,
		"Enemy::@1756": 0x8037b3a0,
		"Enemy::@1757": 0x8037b3d8,
		"Enemy::@1758": 0x8037b40c,
		"Enemy::@1941": 0x8037b45c,
		"Enemy::@1942": 0x8037b48c,
		"Enemy::@1943": 0x8037b4bc,
		"Enemy::@1948": 0x8037b5b4,
		"Enemy::@1949": 0x8037b5e4,
		"Enemy::@1950": 0x8037b610,
		"Enemy::@1951": 0x8037b63c,
		"Enemy::@1952": 0x8037b668,
		"Enemy::@1953": 0x8037b694,
		"Enemy::@1954": 0x8037b6cc,
		"Enemy::@1956": 0x8037b728,
		"Enemy::@2588": 0x8037b990,
		"Enemy::@2589": 0x8037b9b8,
		"Enemy::@3742": 0x8037baf4,
		"Enemy::entry$3295": 0x8037c0b0,
		"entry$3295": 0x8037c0b0,
		"Enemy::@3477": 0x8037c210,
		"Enemy::@2766": 0x8037c404,
		"Enemy::@3287": 0x8037c5c0,
		"Enemy::@1529": 0x8037cc54,
		"@1529": 0x8037cc54,
		"Enemy::@1608": 0x8037cc98,
		"Enemy::@1609": 0x8037ccd0,
		"Enemy::@1610": 0x8037cd04,
		"Enemy::@2183": 0x8037cd78,
		"Enemy::@2184": 0x8037cda0,
		"Enemy::@2185": 0x8037cdc4,
		"Enemy::@2186": 0x8037cdec,
		"Enemy::@2187": 0x8037ce14,
		"Enemy::@2188": 0x8037ce3c,
		"Enemy::@2189": 0x8037ce64,
		"Enemy::@2190": 0x8037ce8c,
		"Enemy::@2191": 0x8037ceb4,
		"Enemy::@2192": 0x8037ced8,
		"Enemy::@2193": 0x8037cefc,
		"Enemy::@3773": 0x8037d1c4,
		"Enemy::@3555": 0x8037d660,
		"Enemy::@3573": 0x8037d720,
		"@unnamed@::cDropCoinNumTable": 0x8037d984,
		"cDropCoinNumTable": 0x8037d984,
		"Enemy::@3632": 0x8037da60,
		"Enemy::@4779": 0x8037db0c,
		"Enemy::@1586": 0x8037dba0,
		"Enemy::@1587": 0x8037dbd8,
		"Enemy::@1588": 0x8037dc0c,
		"Enemy::@2369": 0x8037dc30,
		"Enemy::@2389": 0x8037dc70,
		"@unnamed@::cJointNames": 0x8037dcc4,
		"cJointNames": 0x8037dcc4,
		"Enemy::@5696": 0x8037e250,
		"@5696": 0x8037e250,
		"Enemy::@5697": 0x8037e260,
		"@5697": 0x8037e260,
		"Enemy::@5699": 0x8037e294,
		"@5699": 0x8037e294,
		"Enemy::@5703": 0x8037e2dc,
		"@5703": 0x8037e2dc,
		"Enemy::@5706": 0x8037e324,
		"Enemy::@2015": 0x8037e6a8,
		"Enemy::@2016": 0x8037e6d8,
		"Enemy::@2017": 0x8037e710,
		"Enemy::@1525": 0x8037ea74,
		"Enemy::@1582": 0x8037ea88,
		"Enemy::@1583": 0x8037eab8,
		"Enemy::@1584": 0x8037eaf0,
		"Enemy::@2160": 0x8037eb48,
		"Enemy::@2161": 0x8037eb54,
		"Camera::@1873": 0x8036c818,
		"@1873": 0x8036c818,
		"Camera::@1874": 0x8036c848,
		"@1874": 0x8036c848,
		"Camera::@1875": 0x8036c880,
		"Camera::@1876": 0x8036c8b4,
		"@1876": 0x8036c8b4,
		"Camera::cDirtyFileName": 0x8036c8d8,
		"Camera::cDirtyTexName": 0x8036c8fc,
		"Camera::@1901": 0x8036cbf0,
		"@1901": 0x8036cbf0,
		"Camera::@1903": 0x8036cbfc,
		"@1903": 0x8036cbfc,
		"Camera::@1905": 0x8036cc0c,
		"@1905": 0x8036cc0c,
		"Camera::@1912": 0x8036cc70,
		"Camera::@1915": 0x8036cc9c,
		"@1915": 0x8036cc9c,
		"Camera::@1917": 0x8036ccb4,
		"Camera::@1919": 0x8036cccc,
		"@1919": 0x8036cccc,
		"Camera::@1921": 0x8036cce4,
		"@1921": 0x8036cce4,
		"Camera::@1941": 0x8036ce68,
		"Camera::@1943": 0x8036ce80,
		"Camera::@1944": 0x8036ce98,
		"Camera::@1946": 0x8036ceb0,
		"Camera::@1948": 0x8036cec8,
		"Camera::@1957": 0x8036cf3c,
		"Camera::@1959": 0x8036cf50,
		"Camera::@1961": 0x8036cf64,
		"Camera::@1962": 0x8036cf78,
		"Camera::@1964": 0x8036cf8c,
		"Camera::@1966": 0x8036cf9c,
		"Camera::@1967": 0x8036cfac,
		"Camera::@1968": 0x8036cfc0,
		"Camera::@1969": 0x8036cfd4,
		"Camera::@1970": 0x8036cfe8,
		"Camera::@1971": 0x8036cffc,
		"Camera::@1972": 0x8036d010,
		"Camera::@1973": 0x8036d020,
		"Camera::@1974": 0x8036d030,
		"Camera::@1975": 0x8036d048,
		"Camera::@1976": 0x8036d05c,
		"Camera::@1977": 0x8036d06c,
		"Camera::@1988": 0x8036d134,
		"@1988": 0x8036d134,
		"Camera::@1989": 0x8036d144,
		"Camera::@1994": 0x8036d194,
		"Camera::@1995": 0x8036d1a4,
		"Camera::@2003": 0x8036d240,
		"Camera::@2004": 0x8036d254,
		"Camera::@2005": 0x8036d264,
		"Camera::@2006": 0x8036d274,
		"Camera::@2007": 0x8036d284,
		"Camera::@2008": 0x8036d294,
		"Camera::@2009": 0x8036d2a4,
		"Camera::@2012": 0x8036d2d4,
		"Camera::@2013": 0x8036d2e8,
		"Camera::@2014": 0x8036d2fc,
		"Camera::@2015": 0x8036d30c,
		"Camera::@2016": 0x8036d320,
		"Camera::@2017": 0x8036d334,
		"Camera::@2021": 0x8036d37c,
		"Camera::@2022": 0x8036d38c,
		"Camera::@2023": 0x8036d3a4,
		"Camera::@2029": 0x8036d414,
		"Camera::@2030": 0x8036d424,
		"Camera::@2031": 0x8036d434,
		"Camera::@2032": 0x8036d444,
		"Camera::@2033": 0x8036d458,
		"Camera::@2034": 0x8036d468,
		"Camera::@2035": 0x8036d480,
		"Camera::@2036": 0x8036d490,
		"Camera::@2037": 0x8036d4a0,
		"Camera::@2038": 0x8036d4b4,
		"Camera::@2119": 0x8036d4c8,
		"Camera::@2120": 0x8036d4e4,
		"Camera::@2122": 0x8036d4f0,
		"Camera::@2123": 0x8036d500,
		"Camera::@2127": 0x8036d534,
		"Camera::@2129": 0x8036d548,
		"Camera::@2130": 0x8036d560,
		"Camera::@2131": 0x8036d570,
		"Camera::@2135": 0x8036d5a0,
		"Camera::@2136": 0x8036d5b0,
		"Camera::@2138": 0x8036d5c0,
		"Camera::@2139": 0x8036d5d4,
		"Camera::@2141": 0x8036d5fc,
		"Camera::@2142": 0x8036d610,
		"Camera::@2143": 0x8036d62c,
		"Camera::@2144": 0x8036d640,
		"Camera::@2146": 0x8036d654,
		"Camera::@2147": 0x8036d66c,
		"Camera::@2148": 0x8036d684,
		"Camera::@2150": 0x8036d6ac,
		"Camera::@2151": 0x8036d6c0,
		"Camera::@2152": 0x8036d6d4,
		"Camera::@2174": 0x8036d70c,
		"Camera::@2175": 0x8036d724,
		"Camera::@2203": 0x8036d7a4,
		"Camera::@2204": 0x8036d7b0,
		"Camera::@2206": 0x8036d7bc,
		"Camera::@2207": 0x8036d7c8,
		"Camera::@2208": 0x8036d7d4,
		"Camera::@1632": 0x8036d910,
		"Camera::@2078": 0x8036d970,
		"Camera::@2079": 0x8036d97c,
		"Camera::@2223": 0x8036d9a0,
		"Camera::@2224": 0x8036d9ac,
		"CPolarSubCamera::sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x8036da78,
		"sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x8036da78,
		"Camera::@1681": 0x8036db68,
		"Camera::@1682": 0x8036db94,
		"Camera::@1683": 0x8036dbc4,
		"Camera::@1684": 0x8036dbe8,
		"Camera::@1685": 0x8036dbf8,
		"Camera::@1686": 0x8036dc08,
		"Camera::@1687": 0x8036dc1c,
		"Camera::@1688": 0x8036dc4c,
		"Camera::@1689": 0x8036dc80,
		"Camera::@1650": 0x8036dce8,
		"Camera::@1535": 0x8036dd30,
		"Camera::@1578": 0x8036e190,
		"Camera::@1579": 0x8036e1a8,
		"Camera::@1580": 0x8036e1c0,
		"Camera::@1581": 0x8036e1d8,
		"Camera::@1582": 0x8036e1f4,
		"Camera::@1583": 0x8036e210,
		"Camera::@1584": 0x8036e228,
		"Camera::@1585": 0x8036e244,
		"Camera::@1586": 0x8036e260,
		"Camera::@1587": 0x8036e27c,
		"Camera::@1588": 0x8036e298,
		"Camera::@1589": 0x8036e2b0,
		"Camera::@1590": 0x8036e2c8,
		"Camera::@1591": 0x8036e2e0,
		"Camera::@1592": 0x8036e300,
		"Camera::@1597": 0x8036e384,
		"Camera::@1598": 0x8036e3a0,
		"Camera::@1599": 0x8036e3b8,
		"Camera::@1600": 0x8036e3d0,
		"Camera::@1601": 0x8036e3e8,
		"Camera::@1602": 0x8036e404,
		"Camera::@1603": 0x8036e41c,
		"Camera::@1604": 0x8036e43c,
		"Camera::@1605": 0x8036e454,
		"Camera::@1606": 0x8036e46c,
		"Camera::@1607": 0x8036e488,
		"Animal::@2233": 0x8036b7a0,
		"@unnamed@::cFishoidMdlNames": 0x8036b7d0,
		"cFishoidMdlNames": 0x8036b7d0,
		"Animal::@3202": 0x8036b838,
		"Animal::@2337": 0x8036b868,
		"Animal::@2338": 0x8036b898,
		"Animal::@2340": 0x8036b904,
		"Animal::@2543": 0x8036b928,
		"Animal::entry$2542": 0x8036b938,
		"entry$2542": 0x8036b938,
		"Animal::@2573": 0x8036b950,
		"Animal::@1562": 0x8036b980,
		"Animal::@1563": 0x8036b990,
		"Animal::@1565": 0x8036b9a0,
		"Animal::@1567": 0x8036b9b0,
		"Animal::@1569": 0x8036b9c4,
		"Animal::@1571": 0x8036b9d8,
		"Animal::@1573": 0x8036b9e8,
		"Animal::@1575": 0x8036b9fc,
		"Animal::@1577": 0x8036ba10,
		"Animal::@1940": 0x8036ba34,
		"Animal::@2018": 0x8036ba48,
		"Animal::@2019": 0x8036ba78,
		"Animal::@2020": 0x8036bab0,
		"Animal::@2021": 0x8036bae4,
		"Animal::@2904": 0x8036bb08,
		"Animal::@2905": 0x8036bb28,
		"Animal::@2906": 0x8036bb48,
		"Animal::@2907": 0x8036bb68,
		"@unnamed@::cRandomAnims": 0x8036bb88,
		"cRandomAnims": 0x8036bb88,
		"Animal::@2909": 0x8036bb9c,
		"@unnamed@::cColorTable": 0x8036bba8,
		"Animal::entry$3023": 0x8036bbd8,
		"entry$3023": 0x8036bbd8,
		"Animal::@3452": 0x8036bbf0,
		"Animal::@3871": 0x8036bc04,
		"Animal::@3928": 0x8036bc18,
		"Animal::@3929": 0x8036bc24,
		"Animal::@3931": 0x8036bc30,
		"Animal::@3932": 0x8036bc40,
		"Animal::@3934": 0x8036bc50,
		"Animal::@3936": 0x8036bc60,
		"Animal::@3938": 0x8036bc70,
		"Animal::@3940": 0x8036bc80,
		"Animal::@3941": 0x8036bc90,
		"Animal::@3942": 0x8036bca4,
		"Animal::@3943": 0x8036bcb8,
		"Animal::@3945": 0x8036bccc,
		"Animal::@3947": 0x8036bcdc,
		"Animal::@3948": 0x8036bcec,
		"Animal::@3949": 0x8036bcfc,
		"Animal::@3950": 0x8036bd08,
		"Animal::@3952": 0x8036bd18,
		"Animal::@3953": 0x8036bd28,
		"Animal::@1996": 0x8036bd58,
		"Animal::@1997": 0x8036bd88,
		"Animal::@1998": 0x8036bdc0,
		"Animal::@1999": 0x8036bdf4,
		"Animal::@2986": 0x8036be18,
		"Animal::@2987": 0x8036be28,
		"Animal::@2988": 0x8036be38,
		"Animal::entry$2985": 0x8036be4c,
		"Animal::@3447": 0x8036be7c,
		"Animal::@3661": 0x8036be8c,
		"Animal::@3662": 0x8036bea0,
		"Animal::@3663": 0x8036beb0,
		"Animal::@3665": 0x8036bec0,
		"Animal::@3666": 0x8036bed0,
		"Animal::@3670": 0x8036bedc,
		"Animal::@3672": 0x8036beec,
		"Animal::@3674": 0x8036bef8,
		"Animal::@3675": 0x8036bf08,
		"Animal::@5081": 0x8036bf18,
		"Animal::@2393": 0x8036c008,
		"Animal::@2394": 0x8036c018,
		"Animal::@2395": 0x8036c028,
		"@unnamed@::cButterflyMdlNames": 0x8036c038,
		"cButterflyMdlNames": 0x8036c038,
		"Animal::entry$2459": 0x8036c044,
		"entry$2459": 0x8036c044,
		"Animal::@2493": 0x8036c074,
		"Animal::@2594": 0x8036c084,
		"Animal::@2711": 0x8036c094,
		"MAnmSoundMario::__vt": 0x803a47d0,
		"Camera::@3715": 0x803a4f78,
		"Camera::@3891": 0x803a5044,
		"Enemy::names$3265": 0x803a7274,
		"names$3265": 0x803a7274,
		"Enemy::bmdFileNames$3278": 0x803a7288,
		"bmdFileNames$3278": 0x803a7288,
		"Enemy::entry$2959": 0x803a7634,
		"entry$2959": 0x803a7634,
		"Enemy::entry$3041": 0x803a7f54,
		"entry$3041": 0x803a7f54,
		"Enemy::entry$3108": 0x803a7f6c,
		"entry$3108": 0x803a7f6c,
		"Enemy::entry$3118": 0x803a7f84,
		"entry$3118": 0x803a7f84,
		"Enemy::entry$3161": 0x803a7fb4,
		"entry$3161": 0x803a7fb4,
		"Enemy::entry$2940": 0x803a9598,
		"entry$2940": 0x803a9598,
		"Enemy::@6300": 0x803aa808,
		"@6300": 0x803aa808,
		"Enemy::entry$2985": 0x803ab0ec,
		"Enemy::entry$3395": 0x803ab104,
		"entry$3395": 0x803ab104,
		"Enemy::entry$3029": 0x803abcd0,
		"entry$3029": 0x803abcd0,
		"Enemy::table$3022": 0x803ad488,
		"table$3022": 0x803ad488,
		"Enemy::table$3034": 0x803ad4b8,
		"table$3034": 0x803ad4b8,
		"Enemy::table$3035": 0x803ad4d0,
		"table$3035": 0x803ad4d0,
		"Enemy::table$3037": 0x803ad4fc,
		"table$3037": 0x803ad4fc,
		"Enemy::table$3038": 0x803ad510,
		"table$3038": 0x803ad510,
		"Enemy::table$3039": 0x803ad524,
		"table$3039": 0x803ad524,
		"Enemy::table$3040": 0x803ad538,
		"table$3040": 0x803ad538,
		"Enemy::onetimeFilenames$3486": 0x803ad59c,
		"onetimeFilenames$3486": 0x803ad59c,
		"Enemy::loopFilenames$3500": 0x803ad5b8,
		"loopFilenames$3500": 0x803ad5b8,
		"Enemy::graphlist$2864": 0x803ae354,
		"graphlist$2864": 0x803ae354,
		"Enemy::entry$3103": 0x803ae670,
		"entry$3103": 0x803ae670,
		"Enemy::entry$3330": 0x803ae688,
		"entry$3330": 0x803ae688,
		"Enemy::entry$3142": 0x803af494,
		"entry$3142": 0x803af494,
		"Enemy::entry$3269": 0x803af7bc,
		"entry$3269": 0x803af7bc,
		"Enemy::manNameTable$3929": 0x803af7d4,
		"manNameTable$3929": 0x803af7d4,
		"Enemy::sCannonDomPartsJointTable$3045": 0x803b06b8,
		"sCannonDomPartsJointTable$3045": 0x803b06b8,
		"Enemy::entry$3117": 0x803b0ab4,
		"entry$3117": 0x803b0ab4,
		"Enemy::sEyePartsJointTable$3526": 0x803b0ad8,
		"sEyePartsJointTable$3526": 0x803b0ad8,
		"Enemy::sToothPartsJointTable$3537": 0x803b0ae8,
		"sToothPartsJointTable$3537": 0x803b0ae8,
		"Enemy::sCollisionJointTable$3569": 0x803b0b08,
		"sCollisionJointTable$3569": 0x803b0b08,
		"Enemy::sCollisionFileTable$3573": 0x803b0b18,
		"sCollisionFileTable$3573": 0x803b0b18,
		"Enemy::entry$3038": 0x803b166c,
		"entry$3038": 0x803b166c,
		"Enemy::entry$2762": 0x803b1b68,
		"entry$2762": 0x803b1b68,
		"Enemy::entry$2896": 0x803b1b80,
		"entry$2896": 0x803b1b80,
		"Enemy::jIndexTable$3048": 0x803b1ba4,
		"jIndexTable$3048": 0x803b1ba4,
		"Enemy::entry$3090": 0x803b1bb4,
		"entry$3090": 0x803b1bb4,
		"Enemy::entry$2822": 0x803b3098,
		"entry$2822": 0x803b3098,
		"Enemy::jntidx$3419": 0x803b3cac,
		"jntidx$3419": 0x803b3cac,
		"Enemy::@4439": 0x803b3d0c,
		"Enemy::@4829": 0x803b3d38,
		"Enemy::entry$2800": 0x803b42ac,
		"entry$2800": 0x803b42ac,
		"Enemy::entry$2814": 0x803b4978,
		"entry$2814": 0x803b4978,
		"Enemy::entry$3228": 0x803b68d4,
		"entry$3228": 0x803b68d4,
		"Enemy::entry$2932": 0x803b6b6c,
		"entry$2932": 0x803b6b6c,
		"GC2D::scDolpicNewsDolpic8_Aa1": 0x803b75d0,
		"scDolpicNewsDolpic8_Aa1": 0x803b75d0,
		"GC2D::scDolpicNewsDolpic8_Aa2": 0x803b75e0,
		"scDolpicNewsDolpic8_Aa2": 0x803b75e0,
		"GC2D::scDolpicNewsDolpic8_Aa3": 0x803b75f4,
		"scDolpicNewsDolpic8_Aa3": 0x803b75f4,
		"GC2D::scDolpicNewsDolpic8_Aa4": 0x803b7604,
		"scDolpicNewsDolpic8_Aa4": 0x803b7604,
		"GC2D::scDolpicNewsDolpic8_Ab1": 0x803b7610,
		"scDolpicNewsDolpic8_Ab1": 0x803b7610,
		"GC2D::scDolpicNewsDolpic8_Ab2": 0x803b7620,
		"scDolpicNewsDolpic8_Ab2": 0x803b7620,
		"GC2D::scDolpicNewsDolpic8_Ab3": 0x803b7634,
		"scDolpicNewsDolpic8_Ab3": 0x803b7634,
		"GC2D::scDolpicNewsDolpic8_Ab4": 0x803b7644,
		"scDolpicNewsDolpic8_Ab4": 0x803b7644,
		"GC2D::scDolpicNewsDolpic8_Ac1": 0x803b7650,
		"scDolpicNewsDolpic8_Ac1": 0x803b7650,
		"GC2D::scDolpicNewsDolpic8_Ac2": 0x803b765c,
		"scDolpicNewsDolpic8_Ac2": 0x803b765c,
		"GC2D::scDolpicNewsDolpic8_Ac3": 0x803b766c,
		"scDolpicNewsDolpic8_Ac3": 0x803b766c,
		"GC2D::scDolpicNewsDolpic8_Ba1": 0x803b7678,
		"scDolpicNewsDolpic8_Ba1": 0x803b7678,
		"GC2D::scDolpicNewsDolpic8_Ba2": 0x803b768c,
		"scDolpicNewsDolpic8_Ba2": 0x803b768c,
		"GC2D::scDolpicNewsDolpic8_Ba3": 0x803b76a4,
		"scDolpicNewsDolpic8_Ba3": 0x803b76a4,
		"GC2D::scDolpicNewsDolpic8_Ba4": 0x803b76b8,
		"scDolpicNewsDolpic8_Ba4": 0x803b76b8,
		"GC2D::scDolpicNewsDolpic8_Bb1": 0x803b76c8,
		"scDolpicNewsDolpic8_Bb1": 0x803b76c8,
		"GC2D::scDolpicNewsDolpic8_Bb2": 0x803b76dc,
		"scDolpicNewsDolpic8_Bb2": 0x803b76dc,
		"GC2D::scDolpicNewsDolpic8_Bb3": 0x803b76f4,
		"scDolpicNewsDolpic8_Bb3": 0x803b76f4,
		"GC2D::scDolpicNewsDolpic8_Bb4": 0x803b7708,
		"scDolpicNewsDolpic8_Bb4": 0x803b7708,
		"GC2D::scDolpicNewsDolpic8_Bc1": 0x803b7718,
		"scDolpicNewsDolpic8_Bc1": 0x803b7718,
		"GC2D::scDolpicNewsDolpic8_Bc2": 0x803b7728,
		"scDolpicNewsDolpic8_Bc2": 0x803b7728,
		"GC2D::scDolpicNewsDolpic8_Bc3": 0x803b773c,
		"scDolpicNewsDolpic8_Bc3": 0x803b773c,
		"GC2D::scDolpicNewsDolpic8_Bc4": 0x803b774c,
		"scDolpicNewsDolpic8_Bc4": 0x803b774c,
		"GC2D::scDolpicNewsDolpic8_Ca1": 0x803b7758,
		"scDolpicNewsDolpic8_Ca1": 0x803b7758,
		"GC2D::scDolpicNewsDolpic8_Ca2": 0x803b7768,
		"scDolpicNewsDolpic8_Ca2": 0x803b7768,
		"GC2D::scDolpicNewsDolpic8_Ca3": 0x803b777c,
		"scDolpicNewsDolpic8_Ca3": 0x803b777c,
		"GC2D::scDolpicNewsDolpic8_Ca4": 0x803b778c,
		"scDolpicNewsDolpic8_Ca4": 0x803b778c,
		"GC2D::scDolpicNewsDolpic8_Cb1": 0x803b7798,
		"scDolpicNewsDolpic8_Cb1": 0x803b7798,
		"GC2D::scDolpicNewsDolpic8_Cb2": 0x803b77a8,
		"scDolpicNewsDolpic8_Cb2": 0x803b77a8,
		"GC2D::scDolpicNewsDolpic8_Cb3": 0x803b77bc,
		"scDolpicNewsDolpic8_Cb3": 0x803b77bc,
		"GC2D::scDolpicNewsDolpic8_Cb4": 0x803b77cc,
		"scDolpicNewsDolpic8_Cb4": 0x803b77cc,
		"GC2D::scDolpicNewsDolpic8_Cc1": 0x803b77d8,
		"scDolpicNewsDolpic8_Cc1": 0x803b77d8,
		"GC2D::scDolpicNewsDolpic8_Cc2": 0x803b77e4,
		"scDolpicNewsDolpic8_Cc2": 0x803b77e4,
		"GC2D::scDolpicNewsDolpic8_Cc3": 0x803b77f4,
		"scDolpicNewsDolpic8_Cc3": 0x803b77f4,
		"GC2D::scDolpicNewsDolpic8_Da1": 0x803b7800,
		"scDolpicNewsDolpic8_Da1": 0x803b7800,
		"GC2D::scDolpicNewsDolpic8_Da2": 0x803b780c,
		"scDolpicNewsDolpic8_Da2": 0x803b780c,
		"GC2D::scDolpicNewsDolpic8_Da3": 0x803b781c,
		"scDolpicNewsDolpic8_Da3": 0x803b781c,
		"GC2D::scDolpicNewsDolpic8_Db1": 0x803b7828,
		"scDolpicNewsDolpic8_Db1": 0x803b7828,
		"GC2D::scDolpicNewsDolpic8_Db2": 0x803b7834,
		"scDolpicNewsDolpic8_Db2": 0x803b7834,
		"GC2D::scDolpicNewsDolpic8_Db3": 0x803b7844,
		"scDolpicNewsDolpic8_Db3": 0x803b7844,
		"GC2D::scDolpicNewsDolpic8_Dc2": 0x803b7850,
		"scDolpicNewsDolpic8_Dc2": 0x803b7850,
		"GC2D::@7455": 0x803b78d4,
		"GC2D::@3942": 0x803b796c,
		"GC2D::@4236": 0x803b7d44,
		"TCardLoad::cBMarkMenuFileName": 0x803b7fe8,
		"cBMarkMenuFileName": 0x803b7fe8,
		"TCardLoad::cScoreStageFileName": 0x803b7ff8,
		"cScoreStageFileName": 0x803b7ff8,
		"GC2D::langArray$2782": 0x803b80f4,
		"langArray$2782": 0x803b80f4,
		"GC2D::@4683": 0x803b812c,
		"GC2D::@7463": 0x803b8204,
		"GC2D::@7905": 0x803b8224,
		"GC2D::@7902": 0x803b824c,
		"@7902": 0x803b824c,
		"GC2D::selectNames$2207": 0x803b8660,
		"selectNames$2207": 0x803b8660,
		"GC2D::@2647": 0x803b87f4,
		"GC2D::filename$1564": 0x803b88d0,
		"filename$1564": 0x803b88d0,
		"GC2D::boundtable$268": 0x803b8978,
		"boundtable$268": 0x803b8978,
		"GC2D::drawpath_table_NTSC": 0x803b89b0,
		"drawpath_table_NTSC": 0x803b89b0,
		"GC2D::drawpath_table_PAL": 0x803b8af4,
		"drawpath_table_PAL": 0x803b8af4,
		"GC2D::@1004": 0x803b8c38,
		"@1004": 0x803b8c38,
		"GC2D::langArray$2026": 0x803b8cb0,
		"langArray$2026": 0x803b8cb0,
		"GC2D::@2274": 0x803b8d24,
		"GC2D::@2276": 0x803b8d30,
		"GC2D::@2278": 0x803b8d3c,
		"GC2D::@2280": 0x803b8d48,
		"GC2D::@2283": 0x803b8d54,
		"GC2D::@2285": 0x803b8d60,
		"GC2D::@2287": 0x803b8d6c,
		"GC2D::@2289": 0x803b8d78,
		"Map::@3484": 0x803b933c,
		"MoveBG::item_names$2995": 0x803c0520,
		"item_names$2995": 0x803c0520,
		"MoveBG::@4305": 0x803c0bd0,
		"MoveBG::@5101": 0x803c6794,
		"TWatermelonStatic::__vt": 0x803c6940,
		"NPC::sCameraNames$2617": 0x803d0c58,
		"sCameraNames$2617": 0x803d0c58,
		"Strategic::@3446": 0x803d15a8,
		"Player::@5864": 0x803d4880,
		"Player::@5723": 0x803d4948,
		"Player::@6690": 0x803d4970,
		"@6690": 0x803d4970,
		"Player::@6689": 0x803d4994,
		"@6689": 0x803d4994,
		"Player::param$3386": 0x803d49f8,
		"param$3386": 0x803d49f8,
		"Player::param$3389": 0x803d4a0c,
		"param$3389": 0x803d4a0c,
		"Player::param$3392": 0x803d4a20,
		"param$3392": 0x803d4a20,
		"Player::param$3395": 0x803d4a34,
		"param$3395": 0x803d4a34,
		"Player::param$3400": 0x803d4a48,
		"param$3400": 0x803d4a48,
		"Player::param$3403": 0x803d4a5c,
		"param$3403": 0x803d4a5c,
		"System::@2085": 0x803d65c4,
		"System::@2151": 0x803d6618,
		"System::@2184": 0x803d6644,
		"System::@3617": 0x803d67b8,
		"System::@4380": 0x803d680c,
		"System::@2823": 0x803d6870,
		"System::cmn2dNames$2296": 0x803d6bf8,
		"cmn2dNames$2296": 0x803d6bf8,
		"System::game_6Names$2304": 0x803d6c0c,
		"game_6Names$2304": 0x803d6c0c,
		"System::guideNames$2310": 0x803d6c20,
		"guideNames$2310": 0x803d6c20,
		"System::sDvdErrMsgs": 0x803d6c34,
		"sDvdErrMsgs": 0x803d6c34,
		"System::@2683": 0x803d6cac,
		"System::movies$2059": 0x803d7340,
		"movies$2059": 0x803d7340,
		"System::subtitleNames$2087": 0x803d7390,
		"subtitleNames$2087": 0x803d7390,
		"System::endsaveNames$2099": 0x803d73a4,
		"endsaveNames$2099": 0x803d73a4,
		"TEndingString::__vt": 0x803d7474,
		"MSStageCubeFadeDouble::__vt": 0x803d769c,
		"JKRFile::__vt": 0x803d7728,
		"JKRAramArchive::__vt": 0x803d7748,
		"JKRAramHeap::__vt": 0x803d7790,
		"JKRAram::sMessageBuffer": 0x803d77a0,
		"JKRAram::sMessageQueue": 0x803d77b0,
		"JKRAram::__vt": 0x803d77d0,
		"JKRArchive::__vt": 0x803d77e0,
		"JKRCompArchive::__vt": 0x803d7828,
		"JKRDisposer::__vt": 0x803d7870,
		"JKRDvdArchive::__vt": 0x803d7880,
		"JKRDvdFile::__vt": 0x803d78c8,
		"JKRExpHeap::__vt": 0x803d78f0,
		"JKRArcFinder::__vt": 0x803d7940,
		"JKRFileLoader::__vt": 0x803d7950,
		"JKRHeap::__vt": 0x803d7990,
		"JKRMemArchive::__vt": 0x803d79e0,
		"JKRSolidHeap::__vt": 0x803d7a28,
		"JKRStdHeap::__vt": 0x803d7a78,
		"JKRThread::__vt": 0x803d7ac8,
		"JSURandomOutputStream::__vt": 0x803d7ad8,
		"JSUOutputStream::__vt": 0x803d7b00,
		"JSURandomInputStream::__vt": 0x803d7b18,
		"JSUInputStream::__vt": 0x803d7b3c,
		"JSUMemoryOutputStream::__vt": 0x803d7b58,
		"JSUMemoryInputStream::__vt": 0x803d7b80,
		"JSUFileInputStream::__vt": 0x803d7ba8,
		"JUTException::sMessageQueue": 0x803d7bd0,
		"JUTException::sCpuExpName": 0x803d7bf0,
		"sCpuExpName": 0x803d7bf0,
		"JUTException::__vt": 0x803d7c30,
		"JUTDirectPrint::sAsciiTable": 0x803d7c40,
		"sAsciiTable": 0x803d7c40,
		"JUTDirectPrint::sFontData": 0x803d7cc0,
		"sFontData": 0x803d7cc0,
		"JUTDirectPrint::sFontData2": 0x803d7dc0,
		"sFontData2": 0x803d7dc0,
		"JUTFont::__vt": 0x803d7ef8,
		"JSystem::channel_mask": 0x803d7f30,
		"channel_mask": 0x803d7f30,
		"JUTGamePad::__vt": 0x803d7f40,
		"J2DPane::__vt": 0x803d7f50,
		"J2DPicture::__vt": 0x803d7f80,
		"J2DPrint::__vt": 0x803d8010,
		"J2DSetScreen::__vt": 0x803d8070,
		"J2DScreen::__vt": 0x803d80a4,
		"J2DTextBox::__vt": 0x803d80d8,
		"J2DWindow::__vt": 0x803d8108,
		"J2DWindow::Texture::__vt": 0x803d8134,
		"JSystem::j3dDefaultTransformInfo": 0x803d8140,
		"j3dDefaultTransformInfo": 0x803d8140,
		"JSystem::j3dDefaultMtx": 0x803d8160,
		"j3dDefaultMtx": 0x803d8160,
		"JSystem::PSMulUnit01": 0x803d8190,
		"PSMulUnit01": 0x803d8190,
		"J3DSkinDeform::__vt": 0x803d8198,
		"J3DJoint::__vt": 0x803d81a8,
		"J3DMtxCalcMayaAnm::__vt": 0x803d81d0,
		"J3DMtxCalcMaya::__vt": 0x803d8224,
		"J3DMtxCalcSoftimage::__vt": 0x803d8268,
		"J3DMtxCalcBasic::__vt": 0x803d82ac,
		"J3DMtxCalcAnm::__vt": 0x803d82f0,
		"J3DPEBlockFull::__vt": 0x803d8320,
		"J3DIndBlockFull::__vt": 0x803d8384,
		"J3DTevBlock16::__vt": 0x803d83cc,
		"J3DTevBlock4::__vt": 0x803d8468,
		"J3DTevBlock2::__vt": 0x803d8504,
		"J3DTevBlock1::__vt": 0x803d85a0,
		"J3DTexGenBlockBasic::__vt": 0x803d863c,
		"J3DColorBlockLightOn::__vt": 0x803d868c,
		"J3DColorBlockLightOff::__vt": 0x803d86f0,
		"J3DPEBlockXlu::__vt": 0x803d8754,
		"J3DPEBlockTexEdge::__vt": 0x803d87b8,
		"J3DPEBlockOpa::__vt": 0x803d881c,
		"J3DPEBlock::__vt": 0x803d8880,
		"J3DIndBlockNull::__vt": 0x803d88e4,
		"J3DIndBlock::__vt": 0x803d892c,
		"J3DTevBlock::__vt": 0x803d8974,
		"J3DTexGenBlock::__vt": 0x803d8a10,
		"J3DColorBlock::__vt": 0x803d8a60,
		"J3DModel::__vt": 0x803d8b14,
		"J3DModelData::__vt": 0x803d8b30,
		"J3DNode::__vt": 0x803d8b40,
		"JSystem::@952": 0x803d8b68,
		"@952": 0x803d8b68,
		"JSystem::@953": 0x803d8b74,
		"@953": 0x803d8b74,
		"JSystem::@954": 0x803d8b80,
		"@954": 0x803d8b80,
		"J3DShapeMtx::mtxLoadPipeline": 0x803d8b98,
		"mtxLoadPipeline": 0x803d8b98,
		"J3DShapeDraw::__vt": 0x803d8bc8,
		"J3DShapeMtxMulti::__vt": 0x803d8bd4,
		"J3DShapeMtxDL::__vt": 0x803d8bf4,
		"J3DShapeMtx::__vt": 0x803d8c14,
		"J3DAnmColorKey::__vt": 0x803d8c50,
		"J3DAnmColor::__vt": 0x803d8c60,
		"J3DAnmColorFull::__vt": 0x803d8c70,
		"J3DAnmVtxColorKey::__vt": 0x803d8c80,
		"J3DAnmVtxColor::__vt": 0x803d8c90,
		"J3DAnmVtxColorFull::__vt": 0x803d8ca0,
		"J3DAnmClusterKey::__vt": 0x803d8cb0,
		"J3DAnmCluster::__vt": 0x803d8cc0,
		"J3DAnmClusterFull::__vt": 0x803d8cd0,
		"J3DAnmTransformKey::__vt": 0x803d8ce0,
		"J3DAnmTransform::__vt": 0x803d8cf4,
		"J3DAnmTransformFull::__vt": 0x803d8d04,
		"J3DAnmBase::__vt": 0x803d8d14,
		"J3DModelLoader_v21::__vt": 0x803d8d20,
		"J3DModelLoader_v26::__vt": 0x803d8d48,
		"J3DTexture::__vt": 0x803d8d70,
		"J3DModelLoader::__vt": 0x803d8d7c,
		"J3DAnmKeyLoader_v15::__vt": 0x803d8da8,
		"J3DAnmFullLoader_v15::__vt": 0x803d8db8,
		"J3DAnmLoader::__vt": 0x803d8dc8,
		"J3DAnmVisibilityFull::__vt": 0x803d8dd8,
		"J3DAnmTexPattern::__vt": 0x803d8de4,
		"J3DAnmTevRegKey::__vt": 0x803d8df0,
		"J3DAnmTextureSRTKey::__vt": 0x803d8dfc,
		"J2DGrafContext::__vt": 0x803d8e08,
		"JKRDecomp::sMessageBuffer": 0x803d8e30,
		"JKRDecomp::sMessageQueue": 0x803d8e40,
		"JKRDecomp::__vt": 0x803d8e60,
		"J2DOrthoGraph::__vt": 0x803d8e70,
		"J3DVertexBuffer::__vt": 0x803d8e98,
		"J3DShapePacket::__vt": 0x803d8ea8,
		"J3DMatPacket::__vt": 0x803d8ec0,
		"J3DDrawPacket::__vt": 0x803d8ed8,
		"J3DCallBackPacket::__vt": 0x803d8ef0,
		"J3DPacket::__vt": 0x803d8f08,
		"JSystem::j3dDefaultLightInfo": 0x803d8f64,
		"j3dDefaultLightInfo": 0x803d8f64,
		"JSystem::j3dDefaultTexCoordInfo": 0x803d8f98,
		"j3dDefaultTexCoordInfo": 0x803d8f98,
		"JSystem::j3dDefaultTexMtxInfo": 0x803d8fb8,
		"j3dDefaultTexMtxInfo": 0x803d8fb8,
		"JSystem::j3dDefaultIndTexMtxInfo": 0x803d901c,
		"j3dDefaultIndTexMtxInfo": 0x803d901c,
		"JSystem::j3dDefaultTevStageInfo": 0x803d9038,
		"j3dDefaultTevStageInfo": 0x803d9038,
		"JSystem::j3dDefaultIndTevStageInfo": 0x803d904c,
		"j3dDefaultIndTevStageInfo": 0x803d904c,
		"JSystem::j3dDefaultFogInfo": 0x803d9058,
		"j3dDefaultFogInfo": 0x803d9058,
		"JSystem::j3dDefaultNBTScaleInfo": 0x803d9084,
		"j3dDefaultNBTScaleInfo": 0x803d9084,
		"JSystem::@815": 0x803d90a4,
		"@815": 0x803d90a4,
		"JSystem::@816": 0x803d90b0,
		"@816": 0x803d90b0,
		"JSystem::@817": 0x803d90bc,
		"@817": 0x803d90bc,
		"JSystem::@818": 0x803d90c8,
		"@818": 0x803d90c8,
		"JSystem::@819": 0x803d90d4,
		"@819": 0x803d90d4,
		"J3DDrawBuffer::sortFuncTable": 0x803d90e0,
		"sortFuncTable": 0x803d90e0,
		"JSystem::@820": 0x803d9128,
		"@820": 0x803d9128,
		"JSystem::@821": 0x803d9134,
		"@821": 0x803d9134,
		"J3DDrawBuffer::drawFuncTable": 0x803d9140,
		"drawFuncTable": 0x803d9140,
		"J3DMaterialAnm::__vt": 0x803d9158,
		"J3DTexNoAnm::__vt": 0x803d9168,
		"JKRAramBlock::__vt": 0x803d9178,
		"JKRAramStream::sMessageBuffer": 0x803d9188,
		"JKRAramStream::sMessageQueue": 0x803d9198,
		"JKRAramStream::__vt": 0x803d91b8,
		"JUTResFont::saoAboutEncoding_": 0x803d91c8,
		"JUTResFont::__vt": 0x803d91d4,
		"JUTRomFont::saoAboutEncoding_": 0x803d9210,
		"JUTRomFont::__vt": 0x803d9228,
		"JSystem::@320": 0x803d9268,
		"JSystem::c2r$795": 0x803d92bc,
		"c2r$795": 0x803d92bc,
		"JUTConsole::__vt": 0x803d92d0,
		"JDrama::TActor::__vt": 0x803d92e0,
		"JDrama::TOrthoProj::__vt": 0x803d9380,
		"JDrama::TLookAtCamera::__vt": 0x803d9454,
		"JDrama::TPolarCamera::__vt": 0x803d9548,
		"JDrama::TCamera::__vt": 0x803d9624,
		"JDrama::TSmplChara::__vt": 0x803d96e8,
		"JDrama::TDirector::__vt": 0x803d9710,
		"JDrama::TDisplay::__vt": 0x803d9780,
		"JDrama::TDrawBufObj::__vt": 0x803d9790,
		"JDrama::TDStageDisp::__vt": 0x803d97b8,
		"JDrama::TDStageGroup::__vt": 0x803d97e0,
		"JDrama::TEfbCtrlTex::__vt": 0x803d9810,
		"JDrama::TEfbCtrlDisp::__vt": 0x803d9834,
		"JDrama::TEfbCtrl::__vt": 0x803d9858,
		"JDrama::TFrmGXSet::__vt": 0x803d9880,
		"JDrama::TLightMap::__vt": 0x803d98a8,
		"JDrama::TAmbAry::__vt": 0x803d98cc,
		"JDrama::TAmbColor::__vt": 0x803d98f0,
		"JDrama::TIdxLight::__vt": 0x803d9954,
		"JDrama::TLightAry::__vt": 0x803d99f0,
		"JDrama::TLight::__vt": 0x803d9a14,
		"JDrama::TNameRef::__vt": 0x803d9ab0,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::__vt": 0x803d9ad0,
		"JDrama::TNameRefGen::__vt": 0x803d9af0,
		"JDrama::TPlacement::__vt": 0x803d9b00,
		"JDrama::TScreen::__vt": 0x803d9b28,
		"TCamConnecter::__vt": 0x803d9b4c,
		"JDrama::TSmJ3DAct::__vt": 0x803d9b70,
		"JDrama::TSmJ3DScn::__vt": 0x803d9c10,
		"JDrama::TViewConnecter::__vt": 0x803d9c40,
		"JDrama::TViewport::__vt": 0x803d9c68,
		"JALSeModData<JALSeModVolFunk>::__vt": 0x803d9c90,
		"JALSeModData<JALSeModPitFunk>::__vt": 0x803d9ca0,
		"JALSeModData<JALSeModEffFunk>::__vt": 0x803d9cb0,
		"JALSeModData<JALSeModVolDist>::__vt": 0x803d9cc0,
		"JALSeModData<JALSeModEffDist>::__vt": 0x803d9cd0,
		"JALSeModData<JALSeModPitDist>::__vt": 0x803d9ce0,
		"JALSeModData<JALSeModVolFGrp>::__vt": 0x803d9cf0,
		"JALSeModData<JALSeModPitFGrp>::__vt": 0x803d9d00,
		"JALSeModData<JALSeModEffFGrp>::__vt": 0x803d9d10,
		"JALSeModData<JALSeModVolDGrp>::__vt": 0x803d9d20,
		"JALSeModData<JALSeModEffDGrp>::__vt": 0x803d9d30,
		"JALSeModData<JALSeModPitDGrp>::__vt": 0x803d9d40,
		"JALSeModPitDGrp::__vt": 0x803d9d50,
		"JALSeModDataGrp<JALSeModPitDGrp>::__vt": 0x803d9d60,
		"JALSeModEffDGrp::__vt": 0x803d9d70,
		"JALSeModDataGrp<JALSeModEffDGrp>::__vt": 0x803d9d80,
		"JALSeModVolDGrp::__vt": 0x803d9d90,
		"JALSeModDataGrp<JALSeModVolDGrp>::__vt": 0x803d9da0,
		"JALSeModEffFGrp::__vt": 0x803d9db0,
		"JALSeModDataGrp<JALSeModEffFGrp>::__vt": 0x803d9dc0,
		"JALSeModPitFGrp::__vt": 0x803d9dd0,
		"JALSeModDataGrp<JALSeModPitFGrp>::__vt": 0x803d9de0,
		"JALSeModVolFGrp::__vt": 0x803d9df0,
		"JALSeModDataGrp<JALSeModVolFGrp>::__vt": 0x803d9e00,
		"JALSeModPitDist::__vt": 0x803d9e10,
		"JALSeModEffDist::__vt": 0x803d9e20,
		"JALSeModVolDist::__vt": 0x803d9e30,
		"JALSeModEffFunk::__vt": 0x803d9e40,
		"JALSeModPitFunk::__vt": 0x803d9e50,
		"JALSeModVolFunk::__vt": 0x803d9e60,
		"JAIAnimeSound::__vt": 0x803d9e70,
		"JSystem::@547": 0x803d9e80,
		"@547": 0x803d9e80,
		"JAIBasic::__vt": 0x803d9ea4,
		"JAIConst::dummyZeroVec": 0x803d9ee0,
		"dummyZeroVec": 0x803d9ee0,
		"JAIConst::nullInfoData2": 0x803d9eec,
		"nullInfoData2": 0x803d9eec,
		"JAIConst::sCInfos_0": 0x803d9f0c,
		"sCInfos_0": 0x803d9f0c,
		"JAInter::StreamLib::filter_table": 0x803d9f30,
		"filter_table": 0x803d9f30,
		"JAInter::StreamLib::table4": 0x803d9f70,
		"table4": 0x803d9f70,
		"JAISound::__vt": 0x803d9f90,
		"JASystem::BankMgr::OSC_RELEASE_TABLE": 0x803d9fc8,
		"OSC_RELEASE_TABLE": 0x803d9fc8,
		"JASystem::BankMgr::OSC_ENV": 0x803d9fd4,
		"OSC_ENV": 0x803d9fd4,
		"JASystem::TBasicBank::__vt": 0x803d9ff0,
		"JASystem::TBank::__vt": 0x803da004,
		"JASystem::TBasicInst::__vt": 0x803da018,
		"JASystem::TInst::__vt": 0x803da030,
		"JASystem::TWaveHandle::__vt": 0x803da048,
		"JASystem::TBasicWaveBank::TWaveHandle::__vt": 0x803da05c,
		"JASystem::TBasicWaveBank::TWaveGroup::__vt": 0x803da070,
		"JASystem::WaveArcLoader::TObject::__vt": 0x803da084,
		"JASystem::TBasicWaveBank::__vt": 0x803da098,
		"JASystem::TWaveBank::__vt": 0x803da0ac,
		"JASystem::TInstEffect::__vt": 0x803da0c0,
		"JASystem::TDrumSet::__vt": 0x803da0d0,
		"JASystem::TInstRand::__vt": 0x803da0e8,
		"JASystem::TInstSense::__vt": 0x803da0f8,
		"JASystem::TSimpleWaveBank::TWaveHandle::__vt": 0x803da108,
		"JASystem::TSimpleWaveBank::__vt": 0x803da11c,
		"JASystem::WaveArcLoader::sCurrentDir": 0x803da150,
		"sCurrentDir": 0x803da150,
		"JASystem::Driver::calc_sw_table": 0x803da190,
		"calc_sw_table": 0x803da190,
		"JSystem::@325": 0x803da204,
		"@325": 0x803da204,
		"JASystem::Driver::C5BASE_PITCHTABLE": 0x803da240,
		"C5BASE_PITCHTABLE": 0x803da240,
		"JASystem::history": 0x803da980,
		"history": 0x803da980,
		"JASystem::DSPInterface::SEND_TABLE": 0x803da9a8,
		"SEND_TABLE": 0x803da9a8,
		"JSystem::connect_table$341": 0x803da9c0,
		"connect_table$341": 0x803da9c0,
		"JASystem::Driver::FORCE_STOP_TABLE": 0x803da9d8,
		"FORCE_STOP_TABLE": 0x803da9d8,
		"JASystem::Dvd::audioRootPath": 0x803da9e8,
		"audioRootPath": 0x803da9e8,
		"JASystem::HardStream::rootDir": 0x803daa08,
		"rootDir": 0x803daa08,
		"JSystem::@550": 0x803daa28,
		"@550": 0x803daa28,
		"JASystem::Player::CUTOFF_TO_IIR_TABLE": 0x803daa48,
		"CUTOFF_TO_IIR_TABLE": 0x803daa48,
		"JASystem::Player::s_key_table": 0x803dae48,
		"s_key_table": 0x803dae48,
		"JASystem::Player::sAdsrDef": 0x803daf48,
		"sAdsrDef": 0x803daf48,
		"JASystem::Player::sEnvelopeDef": 0x803daf60,
		"sEnvelopeDef": 0x803daf60,
		"JASystem::Player::sVibratoDef": 0x803daf78,
		"sVibratoDef": 0x803daf78,
		"JASystem::Player::sTremoroDef": 0x803daf90,
		"sTremoroDef": 0x803daf90,
		"JASystem::Player::sAdsTable": 0x803dafa8,
		"sAdsTable": 0x803dafa8,
		"JASystem::Player::sRelTable": 0x803dafc0,
		"sRelTable": 0x803dafc0,
		"JASystem::Player::sVibTable": 0x803dafcc,
		"sVibTable": 0x803dafcc,
		"JASystem::Player::sTreTable": 0x803daff0,
		"sTreTable": 0x803daff0,
		"JASystem::TTrack::sOscTable": 0x803db018,
		"sOscTable": 0x803db018,
		"JSystem::@982": 0x803db020,
		"@982": 0x803db020,
		"JSystem::@1324": 0x803db098,
		"@1324": 0x803db098,
		"JSystem::@139": 0x803db0f8,
		"@139": 0x803db0f8,
		"JSystem::@140": 0x803db104,
		"@140": 0x803db104,
		"JSystem::@141": 0x803db110,
		"@141": 0x803db110,
		"JSystem::@142": 0x803db11c,
		"@142": 0x803db11c,
		"JSystem::@143": 0x803db128,
		"@143": 0x803db128,
		"JSystem::@146": 0x803db14c,
		"@146": 0x803db14c,
		"JSystem::@147": 0x803db158,
		"@147": 0x803db158,
		"JSystem::@152": 0x803db194,
		"JSystem::@153": 0x803db1a0,
		"JSystem::@154": 0x803db1ac,
		"@154": 0x803db1ac,
		"JSystem::@155": 0x803db1b8,
		"@155": 0x803db1b8,
		"JSystem::@156": 0x803db1c4,
		"JSystem::@157": 0x803db1d0,
		"JSystem::@158": 0x803db1dc,
		"JSystem::@159": 0x803db1e8,
		"JSystem::@161": 0x803db200,
		"@161": 0x803db200,
		"JSystem::@162": 0x803db20c,
		"@162": 0x803db20c,
		"JSystem::@163": 0x803db218,
		"@163": 0x803db218,
		"JSystem::@168": 0x803db254,
		"JSystem::@169": 0x803db260,
		"JSystem::@170": 0x803db26c,
		"JSystem::@171": 0x803db278,
		"@171": 0x803db278,
		"JSystem::@172": 0x803db284,
		"@172": 0x803db284,
		"JSystem::@173": 0x803db290,
		"@173": 0x803db290,
		"JSystem::@174": 0x803db29c,
		"JSystem::@175": 0x803db2a8,
		"JSystem::@176": 0x803db2b4,
		"@176": 0x803db2b4,
		"JSystem::@180": 0x803db2e4,
		"@180": 0x803db2e4,
		"JSystem::@181": 0x803db2f0,
		"@181": 0x803db2f0,
		"JSystem::@182": 0x803db2fc,
		"JSystem::@183": 0x803db308,
		"JSystem::@184": 0x803db314,
		"@184": 0x803db314,
		"JSystem::@185": 0x803db320,
		"@185": 0x803db320,
		"JASystem::TSeqParser::sCmdPList": 0x803db35c,
		"sCmdPList": 0x803db35c,
		"J3DMaterialTable::__vt": 0x803db660,
		"JSystem::@2833": 0x803db670,
		"JSystem::@3104": 0x803db68c,
		"JSystem::@2535": 0x803db6b8,
		"JPADragField::__vt": 0x803db6d8,
		"JPARandomField::__vt": 0x803db6f0,
		"JPAConvectionField::__vt": 0x803db708,
		"JPAVortexField::__vt": 0x803db720,
		"JPANewtonField::__vt": 0x803db738,
		"JPAMagnetField::__vt": 0x803db750,
		"JPAAirField::__vt": 0x803db768,
		"JPAGravityField::__vt": 0x803db780,
		"JPABaseField::__vt": 0x803db798,
		"JPAParticle::__vt": 0x803db7b0,
		"JPABaseParticle::__vt": 0x803db808,
		"JSystem::@2383": 0x803db860,
		"JSystem::@2382": 0x803db88c,
		"JPADrawCalcEmitterVisitor::__vt": 0x803db8b8,
		"JPADrawCalcParticleVisitor::__vt": 0x803db8c8,
		"JPADrawExecParticleVisitor::__vt": 0x803db8d8,
		"JPADrawExecEmitterVisitor::__vt": 0x803db8e8,
		"JPADrawCalcChildScaleOut::__vt": 0x803db8f8,
		"JPADrawCalcChildAlphaOut::__vt": 0x803db908,
		"JPADrawCalcAlphaFlickMultSin::__vt": 0x803db918,
		"JPADrawCalcAlphaFlickAddSin::__vt": 0x803db928,
		"JPADrawCalcAlphaFlickNrmSin::__vt": 0x803db938,
		"JPADrawCalcAlpha::__vt": 0x803db948,
		"JPADrawCalcColorCopyFromEmitter::__vt": 0x803db958,
		"JPADrawCalcScaleAnmTimingReverseY::__vt": 0x803db968,
		"JPADrawCalcScaleAnmTimingReverseX::__vt": 0x803db978,
		"JPADrawCalcScaleAnmTimingRepeatY::__vt": 0x803db988,
		"JPADrawCalcScaleAnmTimingRepeatX::__vt": 0x803db998,
		"JPADrawCalcScaleAnmTimingNormal::__vt": 0x803db9a8,
		"JPADrawCalcScaleCopyX2Y::__vt": 0x803db9b8,
		"JPADrawCalcScaleYBySpeed::__vt": 0x803db9c8,
		"JPADrawCalcScaleXBySpeed::__vt": 0x803db9d8,
		"JPADrawCalcScaleY::__vt": 0x803db9e8,
		"JPADrawCalcScaleX::__vt": 0x803db9f8,
		"JPADrawExecCallBack::__vt": 0x803dba08,
		"JPADrawCalcTextureAnmIndexRandom::__vt": 0x803dba2c,
		"JPADrawCalcTextureAnmIndexMerge::__vt": 0x803dba50,
		"JPADrawCalcTextureAnmIndexReverse::__vt": 0x803dba74,
		"JPADrawCalcTextureAnmIndexRepeat::__vt": 0x803dba98,
		"JPADrawCalcTextureAnmIndexNormal::__vt": 0x803dbabc,
		"JPADrawCalcColorAnmFrameRandom::__vt": 0x803dbae0,
		"JPADrawCalcColorAnmFrameMerge::__vt": 0x803dbb04,
		"JPADrawCalcColorAnmFrameReverse::__vt": 0x803dbb28,
		"JPADrawCalcColorAnmFrameRepeat::__vt": 0x803dbb4c,
		"JPADrawCalcColorAnmFrameNormal::__vt": 0x803dbb70,
		"JPADrawCalcColorEnv::__vt": 0x803dbb94,
		"JPADrawCalcColorPrm::__vt": 0x803dbbb8,
		"JPADrawExecRegisterColorChildPE::__vt": 0x803dbbdc,
		"JPADrawExecRegisterColorEmitterE::__vt": 0x803dbbec,
		"JPADrawExecRegisterColorEmitterP::__vt": 0x803dbbfc,
		"JPADrawExecRegisterColorEmitterPE::__vt": 0x803dbc0c,
		"JPADrawExecStripeCross::__vt": 0x803dbc1c,
		"JPADrawExecStripe::__vt": 0x803dbc2c,
		"JPADrawExecLine::__vt": 0x803dbc3c,
		"JPADrawExecPoint::__vt": 0x803dbc4c,
		"JPADrawExecRotationCross::__vt": 0x803dbc5c,
		"JPADrawExecRotation::__vt": 0x803dbc6c,
		"JPADrawExecDirBillBoard::__vt": 0x803dbc7c,
		"JPADrawExecRotDirectionalCross::__vt": 0x803dbc8c,
		"JPADrawExecDirectionalCross::__vt": 0x803dbc9c,
		"JPADrawExecRotDirectional::__vt": 0x803dbcac,
		"JPADrawExecDirectional::__vt": 0x803dbcbc,
		"JPADrawExecRotYBillBoard::__vt": 0x803dbccc,
		"JPADrawExecYBillBoard::__vt": 0x803dbcdc,
		"JPADrawExecRotBillBoard::__vt": 0x803dbcec,
		"JPADrawExecBillBoard::__vt": 0x803dbcfc,
		"JPADrawExecRegisterPrmAEnv::__vt": 0x803dbd0c,
		"JPADrawExecRegisterPrmCEnv::__vt": 0x803dbd1c,
		"JPADrawExecRegisterEnvColorAnm::__vt": 0x803dbd2c,
		"JPADrawExecRegisterPrmAlphaAnm::__vt": 0x803dbd3c,
		"JPADrawExecRegisterPrmColorAnm::__vt": 0x803dbd4c,
		"JPADrawExecSetLineWidth::__vt": 0x803dbd5c,
		"JPADrawExecSetPointSize::__vt": 0x803dbd6c,
		"JPADrawExecLoadTexture::__vt": 0x803dbd7c,
		"JPADrawExecLoadDefaultTexture::__vt": 0x803dbda0,
		"JPADrawExecSetTexMtx::__vt": 0x803dbdb0,
		"JPADrawExecGenIdtMtx::__vt": 0x803dbdd4,
		"JPADrawExecGenTexMtx0::__vt": 0x803dbde4,
		"JPADrawExecGenPrjTexMtx::__vt": 0x803dbdf4,
		"JPADrawExecGenPrjMtx::__vt": 0x803dbe04,
		"JPADrawExecLoadExTex::__vt": 0x803dbe14,
		"JPAExTexShape::__vt": 0x803dbe28,
		"JPADataBlock::__vt": 0x803dbe34,
		"JPAKeyFrameAnime::__vt": 0x803dbe40,
		"JPAEmitterLoader::__vt": 0x803dbe4c,
		"JPAEmitterLoader_v10::__vt": 0x803dbe58,
		"JPABaseShape::stBlendMode": 0x803dbe68,
		"stBlendMode": 0x803dbe68,
		"JPABaseShape::stBlendFactor": 0x803dbe78,
		"stBlendFactor": 0x803dbe78,
		"JPABaseShape::stLogicOp": 0x803dbea0,
		"stLogicOp": 0x803dbea0,
		"JPABaseShape::stCompare": 0x803dbee0,
		"stCompare": 0x803dbee0,
		"JPABaseShape::stAlphaOp": 0x803dbf00,
		"stAlphaOp": 0x803dbf00,
		"JPABaseShape::__vt": 0x803dbf10,
		"JPAExtraShape::__vt": 0x803dbf20,
		"JPASweepShape::__vt": 0x803dbf30,
		"JPATexture::__vt": 0x803dbf40,
		"JStage::TAmbientLight::__vt": 0x803dbf50,
		"JStage::TCamera::__vt": 0x803dbf88,
		"JStage::TActor::__vt": 0x803dc010,
		"JStage::TLight::__vt": 0x803dc078,
		"JStage::TObject::__vt": 0x803dc0d8,
		"JStage::TSystem::__vt": 0x803dc108,
		"MSL_C.PPCEABI.bare.H::__files": 0x803dde40,
		"__files": 0x803dde40,
		"MSL_C.PPCEABI.bare.H::@1009": 0x803ddf18,
		"@1009": 0x803ddf18,
		"MSL_C.PPCEABI.bare.H::@1066": 0x803ddf9c,
		"@1066": 0x803ddf9c,
		"MSL_C.PPCEABI.bare.H::@1186": 0x803de020,
		"@1186": 0x803de020,
		"MSL_C.PPCEABI.bare.H::@1185": 0x803de0f0,
		"@1185": 0x803de0f0,
		"MSL_C.PPCEABI.bare.H::@410": 0x803de138,
		"@410": 0x803de138,
		"MSL_C.PPCEABI.bare.H::__float_nan": 0x803de180,
		"__float_nan": 0x803de180,
		"MSL_C.PPCEABI.bare.H::__float_huge": 0x803de184,
		"__float_huge": 0x803de184,
		"MSL_C.PPCEABI.bare.H::__four_over_pi_m1": 0x803de188,
		"__four_over_pi_m1": 0x803de188,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTable": 0x803de198,
		"gTRKDispatchTable": 0x803de198,
		"TRK_MINNOW_DOLPHIN::@175": 0x803de220,
		"TRK_MINNOW_DOLPHIN::@214": 0x803de23c,
		"TRK_MINNOW_DOLPHIN::gTRKRestoreFlags": 0x803de258,
		"gTRKRestoreFlags": 0x803de258,
		"TRK_MINNOW_DOLPHIN::gTRKExceptionStatus": 0x803de264,
		"gTRKExceptionStatus": 0x803de264,
		"TRK_MINNOW_DOLPHIN::gTRKStepStatus": 0x803de274,
		"gTRKStepStatus": 0x803de274,
		"TRK_MINNOW_DOLPHIN::TRK_ISR_OFFSETS": 0x803de288,
		"TRK_ISR_OFFSETS": 0x803de288,
		"TRK_MINNOW_DOLPHIN::gDBCommTable": 0x803de2c8,
		"gDBCommTable": 0x803de2c8,
		"db::@7": 0x803de2e8,
		"@7": 0x803de2e8,
		"os::@84": 0x803de300,
		"os::@85": 0x803de320,
		"@85": 0x803de320,
		"os::@86": 0x803de338,
		"@86": 0x803de338,
		"os::@87": 0x803de344,
		"@87": 0x803de344,
		"os::@88": 0x803de350,
		"@88": 0x803de350,
		"os::@89": 0x803de360,
		"@89": 0x803de360,
		"os::__OSExceptionLocations": 0x803de3e8,
		"__OSExceptionLocations": 0x803de3e8,
		"os::@130": 0x803de424,
		"os::@131": 0x803de440,
		"@131": 0x803de440,
		"os::@132": 0x803de470,
		"@132": 0x803de470,
		"os::@133": 0x803de4a0,
		"os::@352": 0x803de4c0,
		"@352": 0x803de4c0,
		"os::@353": 0x803de4e4,
		"@353": 0x803de4e4,
		"os::@354": 0x803de51c,
		"os::@355": 0x803de544,
		"os::@356": 0x803de594,
		"@356": 0x803de594,
		"os::@357": 0x803de5d4,
		"os::@358": 0x803de60c,
		"os::@359": 0x803de658,
		"@359": 0x803de658,
		"os::@360": 0x803de68c,
		"os::@361": 0x803de6cc,
		"@361": 0x803de6cc,
		"os::@362": 0x803de708,
		"@362": 0x803de708,
		"os::@363": 0x803de750,
		"os::@364": 0x803de7b0,
		"os::@383": 0x803de7dc,
		"@383": 0x803de7dc,
		"os::@384": 0x803de7f0,
		"@384": 0x803de7f0,
		"os::@385": 0x803de804,
		"os::@386": 0x803de820,
		"os::@387": 0x803de834,
		"@387": 0x803de834,
		"os::@388": 0x803de844,
		"os::DSPInitCode": 0x803de858,
		"DSPInitCode": 0x803de858,
		"os::@97": 0x803dea48,
		"os::@98": 0x803dea68,
		"os::@110": 0x803dea84,
		"os::@111": 0x803deaa0,
		"os::@112": 0x803deabc,
		"@112": 0x803deabc,
		"os::@113": 0x803dead4,
		"@113": 0x803dead4,
		"os::@59": 0x803deb08,
		"@59": 0x803deb08,
		"os::@60": 0x803deb4c,
		"os::@61": 0x803deb7c,
		"os::@62": 0x803debac,
		"@62": 0x803debac,
		"os::@63": 0x803debdc,
		"os::@64": 0x803debf0,
		"os::@65": 0x803dec14,
		"@65": 0x803dec14,
		"os::@66": 0x803dec28,
		"os::@67": 0x803dec44,
		"@67": 0x803dec44,
		"os::@68": 0x803dec58,
		"@68": 0x803dec58,
		"os::@70": 0x803deca0,
		"@70": 0x803deca0,
		"os::@74": 0x803decbc,
		"@74": 0x803decbc,
		"os::@10": 0x803dece0,
		"@10": 0x803dece0,
		"os::@11": 0x803decf8,
		"@11": 0x803decf8,
		"os::@12": 0x803ded20,
		"@12": 0x803ded20,
		"os::@30": 0x803ded3c,
		"os::@31": 0x803ded5c,
		"os::@33": 0x803ded74,
		"os::@34": 0x803deda8,
		"os::@35": 0x803dedb8,
		"os::@36": 0x803dee18,
		"os::@37": 0x803dee64,
		"os::@38": 0x803deec8,
		"os::@39": 0x803def28,
		"os::@40": 0x803def48,
		"os::@41": 0x803def68,
		"os::@42": 0x803def84,
		"os::@43": 0x803defbc,
		"@43": 0x803defbc,
		"os::HankakuToCode": 0x803df000,
		"HankakuToCode": 0x803df000,
		"os::Zenkaku2Code": 0x803df180,
		"Zenkaku2Code": 0x803df180,
		"os::InterruptPrioTable": 0x803dfb10,
		"InterruptPrioTable": 0x803dfb10,
		"os::ResetFunctionInfo": 0x803dfb40,
		"os::YearDays": 0x803dfb50,
		"YearDays": 0x803dfb50,
		"os::LeapYearDays": 0x803dfb80,
		"LeapYearDays": 0x803dfb80,
		"dvd::@117": 0x803dfbb0,
		"dvd::@138": 0x803dfc78,
		"dvd::@237": 0x803dfcb0,
		"dvd::@263": 0x803dfce4,
		"@263": 0x803dfce4,
		"dvd::@269": 0x803dfd14,
		"dvd::@309": 0x803dfd3c,
		"dvd::@340": 0x803dfd78,
		"dvd::@341": 0x803dfde0,
		"dvd::@342": 0x803dfe38,
		"@342": 0x803dfe38,
		"dvd::@373": 0x803dfe94,
		"@373": 0x803dfe94,
		"dvd::@374": 0x803dfef8,
		"@374": 0x803dfef8,
		"dvd::@375": 0x803dff48,
		"@375": 0x803dff48,
		"dvd::@13": 0x803dffa0,
		"@13": 0x803dffa0,
		"dvd::@14": 0x803dffb8,
		"dvd::@15": 0x803dffc4,
		"dvd::@16": 0x803dffe0,
		"dvd::@293": 0x803dffec,
		"dvd::@331": 0x803e000c,
		"@331": 0x803e000c,
		"dvd::@835": 0x803e004c,
		"@835": 0x803e004c,
		"dvd::@936": 0x803e0080,
		"@936": 0x803e0080,
		"dvd::ErrorTable": 0x803e00b8,
		"ErrorTable": 0x803e00b8,
		"dvd::@36": 0x803e0100,
		"dvd::@37": 0x803e011c,
		"dvd::@38": 0x803e0134,
		"dvd::@39": 0x803e0148,
		"dvd::@42": 0x803e015c,
		"vi::timing": 0x803e0170,
		"timing": 0x803e0170,
		"vi::taps": 0x803e02a0,
		"taps": 0x803e02a0,
		"vi::@92": 0x803e02d4,
		"vi::@336": 0x803e032c,
		"@336": 0x803e032c,
		"vi::@337": 0x803e0358,
		"@337": 0x803e0358,
		"vi::@338": 0x803e0384,
		"@338": 0x803e0384,
		"vi::@339": 0x803e03b0,
		"vi::@340": 0x803e03dc,
		"vi::@341": 0x803e0408,
		"pad::ResetFunctionInfo": 0x803e0438,
		"dsp::@16": 0x803e0448,
		"dsp::@17": 0x803e0468,
		"dsp::@18": 0x803e0474,
		"dsp::@264": 0x803e0480,
		"@264": 0x803e0480,
		"dsp::@265": 0x803e04a0,
		"@265": 0x803e04a0,
		"dsp::@266": 0x803e04d0,
		"@266": 0x803e04d0,
		"dsp::@267": 0x803e0500,
		"@267": 0x803e0500,
		"dsp::@268": 0x803e0530,
		"@268": 0x803e0530,
		"dsp::@269": 0x803e0560,
		"dsp::@292": 0x803e0590,
		"card::ResetFunctionInfo": 0x803e05c0,
		"card::SectorSizeTable": 0x803e0740,
		"SectorSizeTable": 0x803e0740,
		"card::LatencyTable": 0x803e0760,
		"LatencyTable": 0x803e0760,
		"gx::@189": 0x803e07e8,
		"gx::@256": 0x803e0850,
		"gx::@302": 0x803e08b8,
		"gx::@329": 0x803e08fc,
		"gx::@393": 0x803e0940,
		"@393": 0x803e0940,
		"gx::@499": 0x803e0984,
		"@499": 0x803e0984,
		"gx::@498": 0x803e09a0,
		"@498": 0x803e09a0,
		"gx::GXNtsc480IntDf": 0x803e09f8,
		"GXNtsc480IntDf": 0x803e09f8,
		"gx::GXNtsc480Int": 0x803e0a34,
		"GXNtsc480Int": 0x803e0a34,
		"gx::GXMpal480IntDf": 0x803e0a70,
		"GXMpal480IntDf": 0x803e0a70,
		"gx::GXPal528IntDf": 0x803e0aac,
		"GXPal528IntDf": 0x803e0aac,
		"gx::GXEurgb60Hz480IntDf": 0x803e0ae8,
		"GXEurgb60Hz480IntDf": 0x803e0ae8,
		"gx::@92": 0x803e0b28,
		"gx::@168": 0x803e0d10,
		"gx::c2r$71": 0x803e0d50,
		"c2r$71": 0x803e0d50,
		"gx::p2f$194": 0x803e0d78,
		"p2f$194": 0x803e0d78,
		"gx::@242": 0x803e0d98,
		"@242": 0x803e0d98,
		"gx::@241": 0x803e0df4,
		"gd::@121": 0x803e0e88,
		"gd::@207": 0x803e0ef0,
		"@207": 0x803e0ef0,
		"gd::c2r$382": 0x803e0f38,
		"c2r$382": 0x803e0f38,
		"si::Si": 0x803e0f48,
		"Si": 0x803e0f48,
		"si::Type": 0x803e0f5c,
		"si::@456": 0x803e0f6c,
		"@456": 0x803e0f6c,
		"si::@458": 0x803e0f78,
		"@458": 0x803e0f78,
		"si::@459": 0x803e0f88,
		"@459": 0x803e0f88,
		"si::@460": 0x803e0f98,
		"@460": 0x803e0f98,
		"si::@461": 0x803e0fa8,
		"si::@462": 0x803e0fb4,
		"@462": 0x803e0fb4,
		"si::@463": 0x803e0fc4,
		"si::@464": 0x803e0fd8,
		"@464": 0x803e0fd8,
		"si::@465": 0x803e0fec,
		"@465": 0x803e0fec,
		"si::@466": 0x803e1000,
		"@466": 0x803e1000,
		"si::@467": 0x803e100c,
		"@467": 0x803e100c,
		"si::XYNTSC": 0x803e1018,
		"XYNTSC": 0x803e1018,
		"si::XYPAL": 0x803e1048,
		"XYPAL": 0x803e1048,
		"si::@16": 0x803e1078,
		"THPPlayer::VolumeTable": 0x803a4e78,
		"VolumeTable": 0x803a4e78,
		"TDLColorTexQuad::__vt": 0x803d1de8,
		"TDLTexQuad::__vt": 0x803d1e08,
		"TSilhouette::__vt": 0x803d1e28,
		"TLightWithDBSetManager::__vt": 0x803d1e50,
		"TIndirectLightWithDBSet::__vt": 0x803d1e74,
		"TMapObjectLightWithDBSet::__vt": 0x803d1e9c,
		"TObjectLightWithDBSet::__vt": 0x803d1ec4,
		"TPlayerLightWithDBSet::__vt": 0x803d1eec,
		"TLightWithDBSet::__vt": 0x803d1f14,
		"TLightDrawBuffer::__vt": 0x803d1f3c,
		"TLightMario::__vt": 0x803d1f64,
		"TLightShadow::__vt": 0x803d1f98,
		"TLightCommon::__vt": 0x803d1fcc,
		"MarioUtil::@1431": 0x803d2000,
		"MarioUtil::@1210": 0x803d2018,
		"MarioUtil::atntable": 0x803d2028,
		"atntable": 0x803d2028,
		"TParamT<JGeometry::TVec3<float><float>>::__vt": 0x803d2830,
		"TMtxSwingRZReverseXZ::__vt": 0x803d283c,
		"TParamVec::__vt": 0x803d2848,
		"TMtxSwingRZ::__vt": 0x803d2854,
		"TMtxTimeLag::__vt": 0x803d2860,
		"TMtxEffectBase::__vt": 0x803d286c,
		"TScreenTexture::__vt": 0x803d2878,
		"TAfterEffect::__vt": 0x803d289c,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::vl$localstatic0$makeDL": 0x803d28cc,
		"vl$localstatic0$makeDL": 0x803d28cc,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::fl$localstatic1$makeDL": 0x803d28dc,
		"fl$localstatic1$makeDL": 0x803d28dc,
		"TMBindShadowManager::__vt": 0x803d28fc,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::__vt": 0x803d2974,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::__vt": 0x803d2984,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::__vt": 0x803d2994,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::__vt": 0x803d29a4,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::__vt": 0x803d29b4,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::__vt": 0x803d29c4,
		"MarioUtil::IdentityMtx": 0x803d29f0,
		"IdentityMtx": 0x803d29f0,
		"MarioUtil::rumbleFrame_00": 0x803d2a20,
		"rumbleFrame_00": 0x803d2a20,
		"MarioUtil::rumblePower_00": 0x803d2a4c,
		"rumblePower_00": 0x803d2a4c,
		"MarioUtil::rumbleFrame_01": 0x803d2a78,
		"rumbleFrame_01": 0x803d2a78,
		"MarioUtil::rumblePower_01": 0x803d2ad8,
		"rumblePower_01": 0x803d2ad8,
		"MarioUtil::rumbleFrame_04": 0x803d2b38,
		"rumbleFrame_04": 0x803d2b38,
		"MarioUtil::rumblePower_04": 0x803d2b54,
		"rumblePower_04": 0x803d2b54,
		"MarioUtil::rumbleFrame_05": 0x803d2b70,
		"rumbleFrame_05": 0x803d2b70,
		"MarioUtil::rumblePower_05": 0x803d2bc4,
		"rumblePower_05": 0x803d2bc4,
		"MarioUtil::rumbleFrame_06": 0x803d2c18,
		"rumbleFrame_06": 0x803d2c18,
		"MarioUtil::rumblePower_06": 0x803d2c40,
		"rumblePower_06": 0x803d2c40,
		"MarioUtil::rumbleFrame_07": 0x803d2c68,
		"rumbleFrame_07": 0x803d2c68,
		"MarioUtil::rumblePower_07": 0x803d2cb8,
		"rumblePower_07": 0x803d2cb8,
		"MarioUtil::rumbleFrame_08": 0x803d2d08,
		"rumbleFrame_08": 0x803d2d08,
		"MarioUtil::rumblePower_08": 0x803d2d1c,
		"rumblePower_08": 0x803d2d1c,
		"MarioUtil::rumbleFrame_09": 0x803d2d30,
		"rumbleFrame_09": 0x803d2d30,
		"MarioUtil::rumblePower_09": 0x803d2d40,
		"rumblePower_09": 0x803d2d40,
		"MarioUtil::rumbleFrame_19": 0x803d2d50,
		"rumbleFrame_19": 0x803d2d50,
		"MarioUtil::rumblePower_19": 0x803d2d64,
		"rumblePower_19": 0x803d2d64,
		"MarioUtil::rumbleFrame_23": 0x803d2d78,
		"rumbleFrame_23": 0x803d2d78,
		"MarioUtil::rumblePower_23": 0x803d2eac,
		"rumblePower_23": 0x803d2eac,
		"MarioUtil::rumbleFrame_24": 0x803d2fe0,
		"rumbleFrame_24": 0x803d2fe0,
		"MarioUtil::rumblePower_24": 0x803d3074,
		"rumblePower_24": 0x803d3074,
		"MarioUtil::channelDataTbl": 0x803d3108,
		"channelDataTbl": 0x803d3108,
		"MarioUtil::_info": 0x803d3238,
		"_info": 0x803d3238,
		"TGDLStatic::__vt": 0x803d3320,
		"TGDLStatic::TGDLSentinel::__vt": 0x803d3330,
		"Koga::ToolData::__vt": 0x803d3340,
		"M3DUtil::@1411": 0x803d3350,
		"M3UMtxCalcSIAnmBlendQuat::__vt": 0x803d335c,
		"M3UModel::__vt": 0x803d33a0,
		"M3UModelCommon::__vt": 0x803d33c4,
		"MActorAnmEach<J3DAnmClusterKey>::__vt": 0x803d33d0,
		"MActorAnmMatEach<J3DAnmTevRegKey>::__vt": 0x803d33f8,
		"MActorAnmEach<J3DAnmTevRegKey>::__vt": 0x803d3420,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::__vt": 0x803d3448,
		"MActorAnmEach<J3DAnmTextureSRTKey>::__vt": 0x803d3470,
		"MActorAnmMatEach<J3DAnmTexPattern>::__vt": 0x803d3498,
		"MActorAnmEach<J3DAnmTexPattern>::__vt": 0x803d34c0,
		"MActorAnmMatEach<J3DAnmColorKey>::__vt": 0x803d34e8,
		"MActorAnmEach<J3DAnmColorKey>::__vt": 0x803d3510,
		"MActorAnmEach<J3DAnmTransformKey>::__vt": 0x803d3538,
		"MActorAnmBlk::__vt": 0x803d3560,
		"MActorAnmBrk::__vt": 0x803d3588,
		"MActorAnmBpk::__vt": 0x803d35b0,
		"MActorAnmBtk::__vt": 0x803d35d8,
		"MActorAnmBtp::__vt": 0x803d3600,
		"MActorAnmBck::__vt": 0x803d3628,
		"MActorAnmBase::__vt": 0x803d3650,
		"SDLModel::__vt": 0x803d3688,
		"SDLMatPacket::__vt": 0x803d36a8,
		"SampleCtrlJoint::__vt": 0x803d36c0,
		"SampleCtrlMaterial::__vt": 0x803d36cc,
		"SampleCtrlShape::__vt": 0x803d36d8,
		"SampleCtrlModelData::__vt": 0x803d36e8,
		"TBaseParam::__vt": 0x803d6430,
		"TMarioParticleManager::__vt": 0x803d6468,
		"TMarioEmitterCallBackBindToSRTMtxPtr::__vt": 0x803d64b0,
		"TMarioEmitterCallBackBindToMtxPtr::__vt": 0x803d64c4,
		"TMarioEmitterCallBackBindToPosPtr::__vt": 0x803d64d8,
		"TEmitterIndirectViewObj::__vt": 0x803d64ec,
		"TEmitterViewObj::__vt": 0x803d6510,
		"JPACallBackBase<JPABaseEmitter*>::__vt": 0x803d6534,
		"TEventWatcher::__vt": 0x803d6548,
		"TSpcTypedInterp<TEventWatcher>::__vt": 0x803d6570,
		"TSpcTypedBinary<TEventWatcher>::__vt": 0x803d6584,
		"TGCLogoDir::__vt": 0x803d6670,
		"TNintendo2D::__vt": 0x803d66dc,
		"TGXAlphaUpdate::__vt": 0x803d6700,
		"TReInitGX::__vt": 0x803d6724,
		"TSMSDrawInit::__vt": 0x803d6748,
		"TJ3DSysSetViewMtx::__vt": 0x803d676c,
		"TJ3DSysFlag::__vt": 0x803d6790,
		"TMarDirector::__vt": 0x803d68a8,
		"TMarNameRefGen::__vt": 0x803d6918,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::__vt": 0x803d6928,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::__vt": 0x803d6948,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::__vt": 0x803d6968,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::__vt": 0x803d6988,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::__vt": 0x803d69a8,
		"TCubeManagerFast::__vt": 0x803d69c8,
		"TCubeManagerArea::__vt": 0x803d69ec,
		"TCubeManagerMarioIn::__vt": 0x803d6a10,
		"TMenuDirector::__vt": 0x803d6a38,
		"TPerformList::__vt": 0x803d6aa8,
		"System::SMSAASamplePattern_non": 0x803d6af8,
		"SMSAASamplePattern_non": 0x803d6af8,
		"System::SMSAASamplePattern_aa": 0x803d6b10,
		"SMSAASamplePattern_aa": 0x803d6b10,
		"System::SMSVFilter_non": 0x803d6b28,
		"SMSVFilter_non": 0x803d6b28,
		"System::SMSVFilter_flicker": 0x803d6b30,
		"SMSVFilter_flicker": 0x803d6b30,
		"TSnapTimeObj::__vt": 0x803d6b38,
		"TTalkCursor::__vt": 0x803d6b60,
		"TAlphaCatch::__vt": 0x803d6b88,
		"TZBufferCatch::__vt": 0x803d6bac,
		"TMarioGamePad::__vt": 0x803d6d58,
		"TScenarioArchiveName::__vt": 0x803d6d70,
		"TStageEventInfo::__vt": 0x803d6d90,
		"System::shineStageTable": 0x803d6db0,
		"shineStageTable": 0x803d6db0,
		"System::exShineTable": 0x803d6df0,
		"exShineTable": 0x803d6df0,
		"TStagePositionInfo::__vt": 0x803d6e10,
		"TTimeRec::__vt": 0x803d6e30,
		"TTHPRender::__vt": 0x803d6e40,
		"TNameKuriLauncherManager::__vt": 0x803d6e68,
		"THamuKuriLauncherManager::__vt": 0x803d6ebc,
		"TCasinoRoulette::__vt": 0x803d6f10,
		"TSirenaGate::__vt": 0x803d7078,
		"TMareWManager::__vt": 0x803d71e0,
		"TMareMManager::__vt": 0x803d7238,
		"System::titles": 0x803d72b8,
		"titles": 0x803d72b8,
		"System::comments": 0x803d72cc,
		"comments": 0x803d72cc,
		"System::@1818": 0x803d72e0,
		"TMovieDirector::__vt": 0x803d73b8,
		"System::@3810": 0x803d7498,
		"System::@3898": 0x803d74c0,
		"System::@3897": 0x803d74e8,
		"MSSTageSimpleEnvironment::__vt": 0x803d7660,
		"MSStageCubeSwitch::__vt": 0x803d7674,
		"MSStageCubeFadeMonte::__vt": 0x803d7688,
		"MSStageCubeFade::__vt": 0x803d76b0,
		"MSStageDistFadeMonte::__vt": 0x803d76c4,
		"MSStageDistFade::__vt": 0x803d76d8,
		"MSStage::__vt": 0x803d76ec,
		"TTargetArrow::__vt": 0x803d7700,
		"TLiveActor::__vt": 0x803d14a8,
		"TLiveManager::__vt": 0x803d1758,
		"TObjManager::__vt": 0x803d1798,
		"TObjChara::__vt": 0x803d17ec,
		"Strategic::@285": 0x803d1810,
		"@285": 0x803d1810,
		"Strategic::@286": 0x803d181c,
		"@286": 0x803d181c,
		"Strategic::@287": 0x803d1828,
		"@287": 0x803d1828,
		"Strategic::@288": 0x803d1834,
		"Strategic::@289": 0x803d1840,
		"Strategic::@290": 0x803d184c,
		"@290": 0x803d184c,
		"Strategic::@291": 0x803d1858,
		"@291": 0x803d1858,
		"Strategic::@292": 0x803d1864,
		"Strategic::@293": 0x803d1870,
		"Strategic::@294": 0x803d187c,
		"Strategic::@295": 0x803d1888,
		"Strategic::@296": 0x803d1894,
		"@296": 0x803d1894,
		"Strategic::@297": 0x803d18a0,
		"Strategic::@298": 0x803d18ac,
		"@298": 0x803d18ac,
		"Strategic::@299": 0x803d18b8,
		"@299": 0x803d18b8,
		"Strategic::@300": 0x803d18c4,
		"@300": 0x803d18c4,
		"Strategic::@301": 0x803d18d0,
		"Strategic::@302": 0x803d18dc,
		"Strategic::@303": 0x803d18e8,
		"Strategic::@304": 0x803d18f4,
		"Strategic::@305": 0x803d1900,
		"Strategic::@306": 0x803d190c,
		"@306": 0x803d190c,
		"Strategic::@307": 0x803d1918,
		"@307": 0x803d1918,
		"Strategic::@308": 0x803d1924,
		"@308": 0x803d1924,
		"Strategic::@309": 0x803d1930,
		"Strategic::@310": 0x803d193c,
		"@310": 0x803d193c,
		"Strategic::@311": 0x803d1948,
		"@311": 0x803d1948,
		"Strategic::@312": 0x803d1954,
		"@312": 0x803d1954,
		"Strategic::@313": 0x803d1960,
		"@313": 0x803d1960,
		"Strategic::@314": 0x803d196c,
		"@314": 0x803d196c,
		"Strategic::@315": 0x803d1978,
		"@315": 0x803d1978,
		"Strategic::@316": 0x803d1984,
		"@316": 0x803d1984,
		"Strategic::@317": 0x803d1990,
		"@317": 0x803d1990,
		"Strategic::@318": 0x803d199c,
		"@318": 0x803d199c,
		"Strategic::@319": 0x803d19a8,
		"@319": 0x803d19a8,
		"Strategic::@320": 0x803d19b4,
		"Strategic::@321": 0x803d19c0,
		"Strategic::@322": 0x803d19cc,
		"Strategic::@323": 0x803d19d8,
		"Strategic::@324": 0x803d19e4,
		"Strategic::table$284": 0x803d19f0,
		"table$284": 0x803d19f0,
		"TSpcInterp::__vt": 0x803d1bd0,
		"TSpcStack<TSpcSlice>::__vt": 0x803d1be4,
		"TSpcStack<unsigned_long><unsigned_long>::__vt": 0x803d1bf0,
		"TSpcBinary::__vt": 0x803d1bfc,
		"TStrategy::__vt": 0x803d1c10,
		"TIdxGroupObj::__vt": 0x803d1c34,
		"TQuestionManager::__vt": 0x803d1c90,
		"TSMSSmplChara::__vt": 0x803d1cb8,
		"THitActor::__vt": 0x803d1ce0,
		"TBinder::__vt": 0x803d1d88,
		"TSharedParts::__vt": 0x803d1d98,
		"TMirrorActor::__vt": 0x803d1dc0,
		"M3UModelMario::__vt": 0x803d36f8,
		"TMarioCap::__vt": 0x803d3720,
		"Player::marioAnimeFiles": 0x803d3768,
		"Player::gMarioAnimeData": 0x803d3da0,
		"gMarioAnimeData": 0x803d3da0,
		"Player::marioAnimeTexPatternFilenames": 0x803d4820,
		"marioAnimeTexPatternFilenames": 0x803d4820,
		"Player::cParticleFileNames": 0x803d4a70,
		"cParticleFileNames": 0x803d4a70,
		"TWarpInCallBack::__vt": 0x803d4a7c,
		"TBubbleCallBack::__vt": 0x803d4ab4,
		"TSplashManager::__vt": 0x803d4ac8,
		"TYoshiTongue::__vt": 0x803d4af0,
		"Player::nozzleBmdData": 0x803d4bd8,
		"nozzleBmdData": 0x803d4bd8,
		"TWaterGun::__vt": 0x803d4c80,
		"TNozzleDeform::__vt": 0x803d4cb0,
		"TNozzleTrigger::__vt": 0x803d4cd8,
		"TNozzleBase::__vt": 0x803d4d00,
		"TMarioEffect::__vt": 0x803d4d70,
		"TMario::__vt": 0x803d4e40,
		"Player::gModelWaterManagerWaterColor": 0x803d5078,
		"gModelWaterManagerWaterColor": 0x803d5078,
		"Player::prmNames": 0x803d5088,
		"prmNames": 0x803d5088,
		"Player::gWaterManagerPlaneInfo": 0x803d50cc,
		"gWaterManagerPlaneInfo": 0x803d50cc,
		"TModelWaterManager::__vt": 0x803d61cc,
		"TMarioPositionObj::__vt": 0x803d6318,
		"NPC::@3884": 0x803cfae0,
		"NPC::@3883": 0x803cfb34,
		"NPC::@3880": 0x803cfb84,
		"NPC::@4719": 0x803cfbe0,
		"TBaseNPC::__vt": 0x803cfc38,
		"NPC::@3445": 0x803cfd4c,
		"NPC::@3991": 0x803cfda4,
		"NPC::@3990": 0x803cfdcc,
		"NPC::@4128": 0x803cfe28,
		"NPC::@4190": 0x803cfe84,
		"TSunflowerSManager::__vt": 0x803cfee0,
		"NPC::@2899": 0x803cff38,
		"TMareWBaseManager::__vt": 0x803cff70,
		"TMareMBaseManager::__vt": 0x803cffc8,
		"TMonteWBManager::__vt": 0x803d0020,
		"TMonteWAManager::__vt": 0x803d0078,
		"TMonteWManager::__vt": 0x803d00d0,
		"TMonteMEManager::__vt": 0x803d0128,
		"TMonteMDManager::__vt": 0x803d0180,
		"TMonteMCManager::__vt": 0x803d01d8,
		"TMonteMBManager::__vt": 0x803d0230,
		"TMonteMAManager::__vt": 0x803d0288,
		"TMonteMManager::__vt": 0x803d02e0,
		"TSunflowerLManager::__vt": 0x803d0338,
		"TRaccoonDogManager::__vt": 0x803d0390,
		"TPeachManager::__vt": 0x803d03e8,
		"TKinojiiManager::__vt": 0x803d0440,
		"TKinopioManager::__vt": 0x803d0498,
		"TMareWBManager::__vt": 0x803d04f0,
		"TMareWAManager::__vt": 0x803d0548,
		"TMareMDManager::__vt": 0x803d05a0,
		"TMareMCManager::__vt": 0x803d05f8,
		"TMareMBManager::__vt": 0x803d0650,
		"TMareMAManager::__vt": 0x803d06a8,
		"TMonteWCManager::__vt": 0x803d0700,
		"TMonteMHManager::__vt": 0x803d0758,
		"TMonteMGManager::__vt": 0x803d07b0,
		"TMonteMFManager::__vt": 0x803d0808,
		"TMonteWSpecialManager::__vt": 0x803d0860,
		"TMonteMSpecialManager::__vt": 0x803d08b8,
		"TMonteWBaseManager::__vt": 0x803d0910,
		"TMonteMBaseManager::__vt": 0x803d0968,
		"TMareBaseManager::__vt": 0x803d09c0,
		"TNPCManager::__vt": 0x803d0a18,
		"TMareJellyFishManager::__vt": 0x803d0a70,
		"TBoardNpcManager::__vt": 0x803d0aa0,
		"TNerveNPCMareStand::__vt": 0x803d0ae0,
		"TNerveNPCBlown::__vt": 0x803d0af0,
		"TNerveNPCMad::__vt": 0x803d0b00,
		"TNerveNPCThrow::__vt": 0x803d0b10,
		"TNerveNPCTalk::__vt": 0x803d0b20,
		"TNerveNPCSetPosAfterSinkBottom::__vt": 0x803d0b30,
		"TNerveNPCRecoverAfter::__vt": 0x803d0b40,
		"TNerveNPCRecoverFromSink::__vt": 0x803d0b50,
		"TNerveNPCSink::__vt": 0x803d0b60,
		"TNerveNPCWet::__vt": 0x803d0b70,
		"TNerveNPCTurnToMario::__vt": 0x803d0b80,
		"TNerveNPCWaitMarioApproach::__vt": 0x803d0b90,
		"TNerveNPCWaitContinue::__vt": 0x803d0ba0,
		"TNerveNPCGraphWait::__vt": 0x803d0bb0,
		"TNerveNPCUTurn::__vt": 0x803d0bc0,
		"TNerveNPCGraphWander::__vt": 0x803d0bd0,
		"NPC::sSaveFileName$1960": 0x803d0be0,
		"sSaveFileName$1960": 0x803d0be0,
		"NPC::sMareMB_FishingRodData": 0x803d0c98,
		"sMareMB_FishingRodData": 0x803d0c98,
		"NPC::sMareWB_BabyData": 0x803d0cc4,
		"sMareWB_BabyData": 0x803d0cc4,
		"NPC::sAllNpcInitData$1622": 0x803d0cf0,
		"sAllNpcInitData$1622": 0x803d0cf0,
		"NPC::MtxCalcTypeName": 0x803d0d90,
		"NPC::monteMCommon_bastable": 0x803d0da0,
		"monteMCommon_bastable": 0x803d0da0,
		"NPC::monteMCommon_bas_c_table": 0x803d0dfc,
		"monteMCommon_bas_c_table": 0x803d0dfc,
		"NPC::monteME_bastable": 0x803d0e58,
		"monteME_bastable": 0x803d0e58,
		"NPC::monteME_bas_c_table": 0x803d0e74,
		"monteME_bas_c_table": 0x803d0e74,
		"NPC::monteMF_bastable": 0x803d0e90,
		"monteMF_bastable": 0x803d0e90,
		"NPC::monteMF_bas_c_table": 0x803d0e9c,
		"monteMF_bas_c_table": 0x803d0e9c,
		"NPC::monteMH_bastable": 0x803d0ea8,
		"monteMH_bastable": 0x803d0ea8,
		"NPC::monteMH_bas_c_table": 0x803d0eb8,
		"monteMH_bas_c_table": 0x803d0eb8,
		"NPC::monteWCommon_bastable": 0x803d0ec8,
		"monteWCommon_bastable": 0x803d0ec8,
		"NPC::monteWCommon_bas_c_table": 0x803d0f28,
		"monteWCommon_bas_c_table": 0x803d0f28,
		"NPC::monteWC_bastable": 0x803d0f88,
		"monteWC_bastable": 0x803d0f88,
		"NPC::monteWC_bas_c_table": 0x803d0f9c,
		"monteWC_bas_c_table": 0x803d0f9c,
		"NPC::mareM_bastable": 0x803d0fb0,
		"mareM_bastable": 0x803d0fb0,
		"NPC::mareM_bas_c_table": 0x803d1004,
		"mareM_bas_c_table": 0x803d1004,
		"NPC::mareMA_bastable": 0x803d1058,
		"mareMA_bastable": 0x803d1058,
		"NPC::mareMA_bas_c_table": 0x803d106c,
		"mareMA_bas_c_table": 0x803d106c,
		"NPC::mareMB_bastable": 0x803d1080,
		"mareMB_bastable": 0x803d1080,
		"NPC::mareMB_bas_c_table": 0x803d1098,
		"mareMB_bas_c_table": 0x803d1098,
		"NPC::mareMC_bastable": 0x803d10b0,
		"mareMC_bastable": 0x803d10b0,
		"NPC::mareMC_bas_c_table": 0x803d10c4,
		"mareMC_bas_c_table": 0x803d10c4,
		"NPC::mareW_bastable": 0x803d10d8,
		"mareW_bastable": 0x803d10d8,
		"NPC::mareW_bas_c_table": 0x803d1128,
		"mareW_bas_c_table": 0x803d1128,
		"NPC::mareWA_bastable": 0x803d1178,
		"mareWA_bastable": 0x803d1178,
		"NPC::mareWA_bas_c_table": 0x803d1188,
		"mareWA_bas_c_table": 0x803d1188,
		"NPC::mareWB_bastable": 0x803d1198,
		"mareWB_bastable": 0x803d1198,
		"NPC::mareWB_bas_c_table": 0x803d11b0,
		"mareWB_bas_c_table": 0x803d11b0,
		"NPC::kinopio_bastable": 0x803d11c8,
		"kinopio_bastable": 0x803d11c8,
		"NPC::kinopio_bas_c_table": 0x803d122c,
		"kinopio_bas_c_table": 0x803d122c,
		"NPC::kinojii_bastable": 0x803d1290,
		"kinojii_bastable": 0x803d1290,
		"NPC::kinojii_bas_c_table": 0x803d12d8,
		"kinojii_bas_c_table": 0x803d12d8,
		"NPC::peach_bastable": 0x803d1320,
		"peach_bastable": 0x803d1320,
		"NPC::peach_bas_c_table": 0x803d137c,
		"peach_bas_c_table": 0x803d137c,
		"NPC::raccoonDog_bastable": 0x803d13d8,
		"raccoonDog_bastable": 0x803d13d8,
		"NPC::raccoonDog_bas_c_table": 0x803d13e8,
		"raccoonDog_bas_c_table": 0x803d13e8,
		"NPC::sunflowerL_bastable": 0x803d13f8,
		"sunflowerL_bastable": 0x803d13f8,
		"NPC::sunflowerL_bas_c_table": 0x803d140c,
		"sunflowerL_bas_c_table": 0x803d140c,
		"NPC::sunflowerS_bastable": 0x803d1420,
		"sunflowerS_bastable": 0x803d1420,
		"NPC::sunflowerS_bas_c_table": 0x803d1434,
		"sunflowerS_bas_c_table": 0x803d1434,
		"MAnmSoundNPC::__vt": 0x803a47c0,
		"MAnmSound::__vt": 0x803a47e0,
		"MSSeCallBack::smTrackCategory": 0x803a47f0,
		"smTrackCategory": 0x803a47f0,
		"MSSeCallBack::smPolifonic": 0x803a4830,
		"smPolifonic": 0x803a4830,
		"MSound::__vt": 0x803a4840,
		"MSound::@2331": 0x803a48d0,
		"MSoundSESystem::MSRandPlay::__vt": 0x803a4990,
		"MSound::@2334": 0x803a499c,
		"MSSetSoundTL<MSSetSoundGrp>::__vt": 0x803a4a28,
		"MSSetSoundGrp::__vt": 0x803a4a40,
		"MSoundSESystem::MSRandVol::__vt": 0x803a4a58,
		"JALListFrameLoop<MSSetSoundGrp>::__vt": 0x803a4a64,
		"MSSetSoundTL<MSSetSound>::__vt": 0x803a4a70,
		"MSSetSound::__vt": 0x803a4a88,
		"JALListFrameLoop<MSSetSound>::__vt": 0x803a4aa0,
		"MSHandle::smACosPrm": 0x803a4ad8,
		"smACosPrm": 0x803a4ad8,
		"MSHandle::smSeCategory": 0x803a4c6c,
		"smSeCategory": 0x803a4c6c,
		"MSHandle::__vt": 0x803a4d6c,
		"MSBgmXFade::scTiming": 0x803a4de8,
		"scTiming": 0x803a4de8,
		"MSBgmXFade::scExp": 0x803a4e30,
		"scExp": 0x803a4e30,
		"TWoodBarrel::__vt": 0x803ba0c8,
		"TMapObjBase::__vt": 0x803ba2a8,
		"TMapObjGeneral::mDefaultSound": 0x803ba448,
		"mDefaultSound": 0x803ba448,
		"MoveBG::normal_sound_data": 0x803ba470,
		"normal_sound_data": 0x803ba470,
		"MoveBG::end_data": 0x803ba498,
		"end_data": 0x803ba498,
		"MoveBG::no_data": 0x803ba4d4,
		"no_data": 0x803ba4d4,
		"MoveBG::billboard_dolphin_data": 0x803ba510,
		"billboard_dolphin_data": 0x803ba510,
		"MoveBG::billboard_sun_data": 0x803ba54c,
		"billboard_sun_data": 0x803ba54c,
		"MoveBG::billboard_restaurant_data": 0x803ba588,
		"billboard_restaurant_data": 0x803ba588,
		"MoveBG::billboard_fish_data": 0x803ba5c4,
		"billboard_fish_data": 0x803ba5c4,
		"MoveBG::HideObj_data": 0x803ba600,
		"HideObj_data": 0x803ba600,
		"MoveBG::WaterHitHideObj_data": 0x803ba63c,
		"WaterHitHideObj_data": 0x803ba63c,
		"MoveBG::FruitHitHideObj_data": 0x803ba678,
		"FruitHitHideObj_data": 0x803ba678,
		"MoveBG::HipDropHideObj_data": 0x803ba6b4,
		"HipDropHideObj_data": 0x803ba6b4,
		"MoveBG::MonteChair_data": 0x803ba6f0,
		"MonteChair_data": 0x803ba6f0,
		"MoveBG::door_data": 0x803ba72c,
		"door_data": 0x803ba72c,
		"MoveBG::doorHotel_data": 0x803ba768,
		"doorHotel_data": 0x803ba768,
		"MoveBG::manhole_data": 0x803ba7a4,
		"manhole_data": 0x803ba7a4,
		"MoveBG::FruitBasket_data": 0x803ba7e0,
		"FruitBasket_data": 0x803ba7e0,
		"MoveBG::BasketReverse_data": 0x803ba81c,
		"BasketReverse_data": 0x803ba81c,
		"MoveBG::CoconutJuice_data": 0x803ba858,
		"CoconutJuice_data": 0x803ba858,
		"MoveBG::Pile_data": 0x803ba894,
		"Pile_data": 0x803ba894,
		"MoveBG::ChangeStage_data": 0x803ba8d0,
		"ChangeStage_data": 0x803ba8d0,
		"MoveBG::ChangeStageMerrygoround_data": 0x803ba90c,
		"ChangeStageMerrygoround_data": 0x803ba90c,
		"MoveBG::StartDemo_data": 0x803ba948,
		"StartDemo_data": 0x803ba948,
		"MoveBG::ChipShine_data": 0x803ba984,
		"ChipShine_data": 0x803ba984,
		"MoveBG::KoopaJrSignM_data": 0x803ba9c0,
		"KoopaJrSignM_data": 0x803ba9c0,
		"MoveBG::StarSign_data": 0x803ba9fc,
		"StarSign_data": 0x803ba9fc,
		"MoveBG::SignCircle_data": 0x803baa38,
		"SignCircle_data": 0x803baa38,
		"MoveBG::SignCross_data": 0x803baa74,
		"SignCross_data": 0x803baa74,
		"MoveBG::SignTriangle_data": 0x803baab0,
		"SignTriangle_data": 0x803baab0,
		"MoveBG::ArrowBoardLR_data": 0x803baaec,
		"ArrowBoardLR_data": 0x803baaec,
		"MoveBG::ArrowBoardUp_data": 0x803bab28,
		"ArrowBoardUp_data": 0x803bab28,
		"MoveBG::ArrowBoardDown_data": 0x803bab64,
		"ArrowBoardDown_data": 0x803bab64,
		"MoveBG::WaterSprayCylinder_data": 0x803baba0,
		"WaterSprayCylinder_data": 0x803baba0,
		"MoveBG::WaterSprayBox_data": 0x803babdc,
		"WaterSprayBox_data": 0x803babdc,
		"MoveBG::ObjSwitch_data": 0x803bac18,
		"ObjSwitch_data": 0x803bac18,
		"MoveBG::RedCoinSwitch_data": 0x803bac54,
		"RedCoinSwitch_data": 0x803bac54,
		"MoveBG::bucket_data": 0x803bac90,
		"bucket_data": 0x803bac90,
		"MoveBG::GeneralHitObj_data": 0x803baccc,
		"GeneralHitObj_data": 0x803baccc,
		"MoveBG::bottle_large_data": 0x803bad08,
		"bottle_large_data": 0x803bad08,
		"MoveBG::bottle_short_data": 0x803bad44,
		"bottle_short_data": 0x803bad44,
		"MoveBG::WaterRecoverObj_data": 0x803bad80,
		"WaterRecoverObj_data": 0x803bad80,
		"MoveBG::watergun_item_data": 0x803badbc,
		"watergun_item_data": 0x803badbc,
		"MoveBG::nozzle_normal_physical_data": 0x803badf8,
		"nozzle_normal_physical_data": 0x803badf8,
		"MoveBG::nozzle_normal_physical_info": 0x803bae2c,
		"nozzle_normal_physical_info": 0x803bae2c,
		"MoveBG::nozzle_normal_item_data": 0x803bae38,
		"nozzle_normal_item_data": 0x803bae38,
		"MoveBG::yoshi_whistle_item_data": 0x803bae74,
		"yoshi_whistle_item_data": 0x803bae74,
		"MoveBG::nozzle_rocket_item_data": 0x803baeb0,
		"nozzle_rocket_item_data": 0x803baeb0,
		"MoveBG::nozzle_back_item_data": 0x803baeec,
		"nozzle_back_item_data": 0x803baeec,
		"MoveBG::coin_physical_data": 0x803baf28,
		"coin_physical_data": 0x803baf28,
		"MoveBG::coin_physical_info": 0x803baf5c,
		"coin_physical_info": 0x803baf5c,
		"MoveBG::coin_data": 0x803baf68,
		"coin_data": 0x803baf68,
		"MoveBG::invisible_coin_data": 0x803bafa4,
		"invisible_coin_data": 0x803bafa4,
		"MoveBG::coin_red_data": 0x803bafe0,
		"coin_red_data": 0x803bafe0,
		"MoveBG::coin_blue_data": 0x803bb01c,
		"coin_blue_data": 0x803bb01c,
		"MoveBG::shine_data": 0x803bb058,
		"shine_data": 0x803bb058,
		"MoveBG::mario_cap_data": 0x803bb094,
		"mario_cap_data": 0x803bb094,
		"MoveBG::joint_coin_data": 0x803bb0d0,
		"joint_coin_data": 0x803bb0d0,
		"MoveBG::eggYoshi_data": 0x803bb10c,
		"eggYoshi_data": 0x803bb10c,
		"MoveBG::EggYoshi_physical_data": 0x803bb148,
		"EggYoshi_physical_data": 0x803bb148,
		"MoveBG::EggYoshi_physical_info": 0x803bb17c,
		"EggYoshi_physical_info": 0x803bb17c,
		"MoveBG::eggYoshiEvent_data": 0x803bb188,
		"eggYoshiEvent_data": 0x803bb188,
		"MoveBG::NozzleBox_data": 0x803bb1c4,
		"NozzleBox_data": 0x803bb1c4,
		"MoveBG::mushroom1up_data": 0x803bb200,
		"mushroom1up_data": 0x803bb200,
		"MoveBG::mushroom1upR_data": 0x803bb23c,
		"mushroom1upR_data": 0x803bb23c,
		"MoveBG::mushroom1upX_data": 0x803bb278,
		"mushroom1upX_data": 0x803bb278,
		"MoveBG::jumpbase_data": 0x803bb2b4,
		"jumpbase_data": 0x803bb2b4,
		"MoveBG::coconut_physical_data": 0x803bb2f0,
		"coconut_physical_data": 0x803bb2f0,
		"MoveBG::coconut_physical_info": 0x803bb324,
		"coconut_physical_info": 0x803bb324,
		"MoveBG::coconut_data": 0x803bb330,
		"coconut_data": 0x803bb330,
		"MoveBG::papaya_physical_data": 0x803bb36c,
		"papaya_physical_data": 0x803bb36c,
		"MoveBG::papaya_physical_info": 0x803bb3a0,
		"papaya_physical_info": 0x803bb3a0,
		"MoveBG::papaya_data": 0x803bb3ac,
		"papaya_data": 0x803bb3ac,
		"MoveBG::pine_physical_data": 0x803bb3e8,
		"pine_physical_data": 0x803bb3e8,
		"MoveBG::pine_physical_info": 0x803bb41c,
		"pine_physical_info": 0x803bb41c,
		"MoveBG::pine_data": 0x803bb428,
		"pine_data": 0x803bb428,
		"MoveBG::CoverPine_data": 0x803bb464,
		"CoverPine_data": 0x803bb464,
		"MoveBG::durian_physical_data": 0x803bb4a0,
		"durian_physical_data": 0x803bb4a0,
		"MoveBG::durian_physical_info": 0x803bb4d4,
		"durian_physical_info": 0x803bb4d4,
		"MoveBG::durian_data": 0x803bb4e0,
		"durian_data": 0x803bb4e0,
		"MoveBG::banana_physical_data": 0x803bb51c,
		"banana_physical_data": 0x803bb51c,
		"MoveBG::banana_physical_info": 0x803bb550,
		"banana_physical_info": 0x803bb550,
		"MoveBG::banana_data": 0x803bb55c,
		"banana_data": 0x803bb55c,
		"MoveBG::red_pepper_physical_data": 0x803bb598,
		"red_pepper_physical_data": 0x803bb598,
		"MoveBG::red_pepper_physical_info": 0x803bb5cc,
		"red_pepper_physical_info": 0x803bb5cc,
		"MoveBG::RedPepper_data": 0x803bb5d8,
		"RedPepper_data": 0x803bb5d8,
		"MoveBG::fence_normal_data": 0x803bb614,
		"fence_normal_data": 0x803bb614,
		"MoveBG::fence3x3_data": 0x803bb650,
		"fence3x3_data": 0x803bb650,
		"MoveBG::fence_revolve_data": 0x803bb68c,
		"fence_revolve_data": 0x803bb68c,
		"MoveBG::fence_revolve_inner_data": 0x803bb6c8,
		"fence_revolve_inner_data": 0x803bb6c8,
		"MoveBG::fenceInnerGreen_data": 0x803bb704,
		"fenceInnerGreen_data": 0x803bb704,
		"MoveBG::FenceWaterV_data": 0x803bb740,
		"FenceWaterV_data": 0x803bb740,
		"MoveBG::FenceWaterH_data": 0x803bb77c,
		"FenceWaterH_data": 0x803bb77c,
		"MoveBG::RailFence_data": 0x803bb7b8,
		"RailFence_data": 0x803bb7b8,
		"MoveBG::bambooFenceRevolveInner_data": 0x803bb7f4,
		"bambooFenceRevolveInner_data": 0x803bb7f4,
		"MoveBG::bambooFenceRevolveOuter_data": 0x803bb830,
		"bambooFenceRevolveOuter_data": 0x803bb830,
		"MoveBG::bambooRailFence_data": 0x803bb86c,
		"bambooRailFence_data": 0x803bb86c,
		"MoveBG::wood_barrel_physical_data": 0x803bb8a8,
		"wood_barrel_physical_data": 0x803bb8a8,
		"MoveBG::wood_barrel_physical_info": 0x803bb8dc,
		"wood_barrel_physical_info": 0x803bb8dc,
		"MoveBG::wood_barrel_hold_data": 0x803bb8e8,
		"wood_barrel_hold_data": 0x803bb8e8,
		"MoveBG::wood_barrel_data": 0x803bb8fc,
		"wood_barrel_data": 0x803bb8fc,
		"MoveBG::wood_barrel_once_data": 0x803bb938,
		"wood_barrel_once_data": 0x803bb938,
		"MoveBG::barrel_float_data": 0x803bb974,
		"barrel_float_data": 0x803bb974,
		"MoveBG::drum_can_data": 0x803bb9b0,
		"drum_can_data": 0x803bb9b0,
		"MoveBG::barrel_oil_data": 0x803bb9ec,
		"barrel_oil_data": 0x803bb9ec,
		"MoveBG::breakable_block_data": 0x803bba28,
		"breakable_block_data": 0x803bba28,
		"MoveBG::supermario_block_data": 0x803bba64,
		"supermario_block_data": 0x803bba64,
		"MoveBG::move_block_data": 0x803bbaa0,
		"move_block_data": 0x803bbaa0,
		"MoveBG::fall_slow_block_data": 0x803bbadc,
		"fall_slow_block_data": 0x803bbadc,
		"MoveBG::expand_block_data": 0x803bbb18,
		"expand_block_data": 0x803bbb18,
		"MoveBG::spread_block_data": 0x803bbb54,
		"spread_block_data": 0x803bbb54,
		"MoveBG::water_roll_block_data": 0x803bbb90,
		"water_roll_block_data": 0x803bbb90,
		"MoveBG::sand_block_data": 0x803bbbcc,
		"sand_block_data": 0x803bbbcc,
		"MoveBG::water_power_lift_data": 0x803bbc08,
		"water_power_lift_data": 0x803bbc08,
		"MoveBG::water_power_inertial_lift_data": 0x803bbc44,
		"water_power_inertial_lift_data": 0x803bbc44,
		"MoveBG::water_power_ship_data": 0x803bbc80,
		"water_power_ship_data": 0x803bbc80,
		"MoveBG::lean_direct_block_data": 0x803bbcbc,
		"lean_direct_block_data": 0x803bbcbc,
		"MoveBG::lean_indirect_block_data": 0x803bbcf8,
		"lean_indirect_block_data": 0x803bbcf8,
		"MoveBG::lean_block_data": 0x803bbd34,
		"lean_block_data": 0x803bbd34,
		"MoveBG::skate_block_data": 0x803bbd70,
		"skate_block_data": 0x803bbd70,
		"MoveBG::MoveCoin_data": 0x803bbdac,
		"MoveCoin_data": 0x803bbdac,
		"MoveBG::cluster_block_data": 0x803bbde8,
		"cluster_block_data": 0x803bbde8,
		"MoveBG::NormalBlock_data": 0x803bbe24,
		"NormalBlock_data": 0x803bbe24,
		"MoveBG::IceBlock_data": 0x803bbe60,
		"IceBlock_data": 0x803bbe60,
		"MoveBG::BrickBlock_data": 0x803bbe9c,
		"BrickBlock_data": 0x803bbe9c,
		"MoveBG::WaterMelonBlock_data": 0x803bbed8,
		"WaterMelonBlock_data": 0x803bbed8,
		"MoveBG::TelesaBlock_data": 0x803bbf14,
		"TelesaBlock_data": 0x803bbf14,
		"MoveBG::WoodBlockPole_data": 0x803bbf50,
		"WoodBlockPole_data": 0x803bbf50,
		"MoveBG::JuiceBlock_data": 0x803bbf8c,
		"JuiceBlock_data": 0x803bbf8c,
		"MoveBG::SuperHipDropBlock_data": 0x803bbfc8,
		"SuperHipDropBlock_data": 0x803bbfc8,
		"MoveBG::palmNormal_data": 0x803bc004,
		"palmNormal_data": 0x803bc004,
		"MoveBG::palmOugi_data": 0x803bc040,
		"palmOugi_data": 0x803bc040,
		"MoveBG::palmSago_data": 0x803bc07c,
		"palmSago_data": 0x803bc07c,
		"MoveBG::palmNatume_data": 0x803bc0b8,
		"palmNatume_data": 0x803bc0b8,
		"MoveBG::palmLeaf_data": 0x803bc0f4,
		"palmLeaf_data": 0x803bc0f4,
		"MoveBG::BananaTree_data": 0x803bc130,
		"BananaTree_data": 0x803bc130,
		"MoveBG::FruitTree_data": 0x803bc16c,
		"FruitTree_data": 0x803bc16c,
		"MoveBG::flower_data": 0x803bc1a8,
		"flower_data": 0x803bc1a8,
		"MoveBG::flowerOrange_data": 0x803bc1e4,
		"flowerOrange_data": 0x803bc1e4,
		"MoveBG::flowerPink_data": 0x803bc220,
		"flowerPink_data": 0x803bc220,
		"MoveBG::flowerPurple_data": 0x803bc25c,
		"flowerPurple_data": 0x803bc25c,
		"MoveBG::flowerRed_data": 0x803bc298,
		"flowerRed_data": 0x803bc298,
		"MoveBG::flowerYellow_data": 0x803bc2d4,
		"flowerYellow_data": 0x803bc2d4,
		"MoveBG::flowerSunflower_data": 0x803bc310,
		"flowerSunflower_data": 0x803bc310,
		"MoveBG::telegraph_pole_l_data": 0x803bc34c,
		"telegraph_pole_l_data": 0x803bc34c,
		"MoveBG::telegraph_pole_s_data": 0x803bc388,
		"telegraph_pole_s_data": 0x803bc388,
		"MoveBG::streetlamp_data": 0x803bc3c4,
		"streetlamp_data": 0x803bc3c4,
		"MoveBG::PoleNormal_data": 0x803bc400,
		"PoleNormal_data": 0x803bc400,
		"MoveBG::football_physical_data": 0x803bc43c,
		"football_physical_data": 0x803bc43c,
		"MoveBG::football_physical_info": 0x803bc470,
		"football_physical_info": 0x803bc470,
		"MoveBG::football_data": 0x803bc47c,
		"football_data": 0x803bc47c,
		"MoveBG::football_goal_data": 0x803bc4b8,
		"football_goal_data": 0x803bc4b8,
		"MoveBG::baloonball_physical_data": 0x803bc4f4,
		"baloonball_physical_data": 0x803bc4f4,
		"MoveBG::baloonball_physical_info": 0x803bc528,
		"baloonball_physical_info": 0x803bc528,
		"MoveBG::baloonball_data": 0x803bc534,
		"baloonball_data": 0x803bc534,
		"MoveBG::coconutball_data": 0x803bc570,
		"coconutball_data": 0x803bc570,
		"MoveBG::watermelon_physical_data": 0x803bc5ac,
		"watermelon_physical_data": 0x803bc5ac,
		"MoveBG::watermelon_physical_info": 0x803bc5e0,
		"watermelon_physical_info": 0x803bc5e0,
		"MoveBG::watermelon_data": 0x803bc5ec,
		"watermelon_data": 0x803bc5ec,
		"MoveBG::WatermelonStatic_data": 0x803bc628,
		"WatermelonStatic_data": 0x803bc628,
		"MoveBG::cloud_data": 0x803bc664,
		"cloud_data": 0x803bc664,
		"MoveBG::normallift_data": 0x803bc6a0,
		"normallift_data": 0x803bc6a0,
		"MoveBG::exrollcube_data": 0x803bc6dc,
		"exrollcube_data": 0x803bc6dc,
		"MoveBG::exkickboard_data": 0x803bc718,
		"exkickboard_data": 0x803bc718,
		"MoveBG::railblockr_data": 0x803bc754,
		"railblockr_data": 0x803bc754,
		"MoveBG::railblocky_data": 0x803bc790,
		"railblocky_data": 0x803bc790,
		"MoveBG::railblockb_data": 0x803bc7cc,
		"railblockb_data": 0x803bc7cc,
		"MoveBG::rollblockr_data": 0x803bc808,
		"rollblockr_data": 0x803bc808,
		"MoveBG::rollblocky_data": 0x803bc844,
		"rollblocky_data": 0x803bc844,
		"MoveBG::rollblockb_data": 0x803bc880,
		"rollblockb_data": 0x803bc880,
		"MoveBG::umaibou_data": 0x803bc8bc,
		"umaibou_data": 0x803bc8bc,
		"MoveBG::kamaboko_data": 0x803bc8f8,
		"kamaboko_data": 0x803bc8f8,
		"MoveBG::getag_data": 0x803bc934,
		"getag_data": 0x803bc934,
		"MoveBG::getao_data": 0x803bc970,
		"getao_data": 0x803bc970,
		"MoveBG::uirou_data": 0x803bc9ac,
		"uirou_data": 0x803bc9ac,
		"MoveBG::hikidashi_data": 0x803bc9e8,
		"hikidashi_data": 0x803bc9e8,
		"MoveBG::castella_data": 0x803bca24,
		"castella_data": 0x803bca24,
		"MoveBG::yoshiblock_data": 0x803bca60,
		"yoshiblock_data": 0x803bca60,
		"MoveBG::WoodBlockTriangle_data": 0x803bca9c,
		"WoodBlockTriangle_data": 0x803bca9c,
		"MoveBG::WoodBlockPyramid_data": 0x803bcad8,
		"WoodBlockPyramid_data": 0x803bcad8,
		"MoveBG::WoodBlockLong_data": 0x803bcb14,
		"WoodBlockLong_data": 0x803bcb14,
		"MoveBG::WoodBlockLarge_data": 0x803bcb50,
		"WoodBlockLarge_data": 0x803bcb50,
		"MoveBG::WoodBlockCone_data": 0x803bcb8c,
		"WoodBlockCone_data": 0x803bcb8c,
		"MoveBG::WoodBlockL_data": 0x803bcbc8,
		"WoodBlockL_data": 0x803bcbc8,
		"MoveBG::WoodBlockBridge_data": 0x803bcc04,
		"WoodBlockBridge_data": 0x803bcc04,
		"MoveBG::WoodBlockCube_data": 0x803bcc40,
		"WoodBlockCube_data": 0x803bcc40,
		"MoveBG::normalvariant0_data": 0x803bcc7c,
		"normalvariant0_data": 0x803bcc7c,
		"MoveBG::normalvariant1_data": 0x803bccb8,
		"normalvariant1_data": 0x803bccb8,
		"MoveBG::normalvariant2_data": 0x803bccf4,
		"normalvariant2_data": 0x803bccf4,
		"MoveBG::normalvariant3_data": 0x803bcd30,
		"normalvariant3_data": 0x803bcd30,
		"MoveBG::normalvariant4_data": 0x803bcd6c,
		"normalvariant4_data": 0x803bcd6c,
		"MoveBG::railvariant0_data": 0x803bcda8,
		"railvariant0_data": 0x803bcda8,
		"MoveBG::railvariant1_data": 0x803bcde4,
		"railvariant1_data": 0x803bcde4,
		"MoveBG::railvariant2_data": 0x803bce20,
		"railvariant2_data": 0x803bce20,
		"MoveBG::railvariant3_data": 0x803bce5c,
		"railvariant3_data": 0x803bce5c,
		"MoveBG::railvariant4_data": 0x803bce98,
		"railvariant4_data": 0x803bce98,
		"MoveBG::rollvariant0_data": 0x803bced4,
		"rollvariant0_data": 0x803bced4,
		"MoveBG::rollvariant1_data": 0x803bcf10,
		"rollvariant1_data": 0x803bcf10,
		"MoveBG::rollvariant2_data": 0x803bcf4c,
		"rollvariant2_data": 0x803bcf4c,
		"MoveBG::rollvariant3_data": 0x803bcf88,
		"rollvariant3_data": 0x803bcf88,
		"MoveBG::rollvariant4_data": 0x803bcfc4,
		"rollvariant4_data": 0x803bcfc4,
		"MoveBG::lamptrapspike_data": 0x803bd000,
		"lamptrapspike_data": 0x803bd000,
		"MoveBG::lamptrapiron_data": 0x803bd03c,
		"lamptrapiron_data": 0x803bd03c,
		"MoveBG::airplane_data": 0x803bd078,
		"airplane_data": 0x803bd078,
		"MoveBG::WoodBox_data": 0x803bd0b4,
		"WoodBox_data": 0x803bd0b4,
		"MoveBG::AirportPole_data": 0x803bd0f0,
		"AirportPole_data": 0x803bd0f0,
		"MoveBG::ice_car_data": 0x803bd12c,
		"ice_car_data": 0x803bd12c,
		"MoveBG::move_ice_car_data": 0x803bd168,
		"move_ice_car_data": 0x803bd168,
		"MoveBG::AirportBuoy_data": 0x803bd1a4,
		"AirportBuoy_data": 0x803bd1a4,
		"MoveBG::dptCannon_data": 0x803bd1e0,
		"dptCannon_data": 0x803bd1e0,
		"MoveBG::dptKing_data": 0x803bd21c,
		"dptKing_data": 0x803bd21c,
		"MoveBG::KoopaJrSubmarine_data": 0x803bd258,
		"KoopaJrSubmarine_data": 0x803bd258,
		"MoveBG::monumentshine_data": 0x803bd294,
		"monumentshine_data": 0x803bd294,
		"MoveBG::belldolpic_data": 0x803bd2d0,
		"belldolpic_data": 0x803bd2d0,
		"MoveBG::dptWeathercock_data": 0x803bd30c,
		"dptWeathercock_data": 0x803bd30c,
		"MoveBG::dptMonteFence_data": 0x803bd348,
		"dptMonteFence_data": 0x803bd348,
		"MoveBG::dptCoronaFence_data": 0x803bd384,
		"dptCoronaFence_data": 0x803bd384,
		"MoveBG::MapSmoke_data": 0x803bd3c0,
		"MapSmoke_data": 0x803bd3c0,
		"MoveBG::MareGate_data": 0x803bd3fc,
		"MareGate_data": 0x803bd3fc,
		"MoveBG::DemoCannon_data": 0x803bd438,
		"DemoCannon_data": 0x803bd438,
		"MoveBG::NozzleDoor_data": 0x803bd474,
		"NozzleDoor_data": 0x803bd474,
		"MoveBG::DokanGate_data": 0x803bd4b0,
		"DokanGate_data": 0x803bd4b0,
		"MoveBG::crane_data": 0x803bd4ec,
		"crane_data": 0x803bd4ec,
		"MoveBG::crane90Scene2_data": 0x803bd528,
		"crane90Scene2_data": 0x803bd528,
		"MoveBG::crane180Scene1_data": 0x803bd564,
		"crane180Scene1_data": 0x803bd564,
		"MoveBG::craneUpDown_data": 0x803bd5a0,
		"craneUpDown_data": 0x803bd5a0,
		"MoveBG::craneCargoUpDown_data": 0x803bd5dc,
		"craneCargoUpDown_data": 0x803bd5dc,
		"MoveBG::tank_data": 0x803bd618,
		"tank_data": 0x803bd618,
		"MoveBG::container_data": 0x803bd654,
		"container_data": 0x803bd654,
		"MoveBG::submarine_data": 0x803bd690,
		"submarine_data": 0x803bd690,
		"MoveBG::riccoShip_data": 0x803bd6cc,
		"riccoShip_data": 0x803bd6cc,
		"MoveBG::riccoPole_data": 0x803bd708,
		"riccoPole_data": 0x803bd708,
		"MoveBG::riccoLog_data": 0x803bd744,
		"riccoLog_data": 0x803bd744,
		"MoveBG::gesoSurfboard_data": 0x803bd780,
		"gesoSurfboard_data": 0x803bd780,
		"MoveBG::gesoSurfboardStatic_data": 0x803bd7bc,
		"gesoSurfboardStatic_data": 0x803bd7bc,
		"MoveBG::riccoWatermill_data": 0x803bd7f8,
		"riccoWatermill_data": 0x803bd7f8,
		"MoveBG::riccoShipLog_data": 0x803bd834,
		"riccoShipLog_data": 0x803bd834,
		"MoveBG::riccoShipDol_data": 0x803bd870,
		"riccoShipDol_data": 0x803bd870,
		"MoveBG::riccoYachtL_data": 0x803bd8ac,
		"riccoYachtL_data": 0x803bd8ac,
		"MoveBG::riccoYachtS_data": 0x803bd8e8,
		"riccoYachtS_data": 0x803bd8e8,
		"MoveBG::riccoBoatL_data": 0x803bd924,
		"riccoBoatL_data": 0x803bd924,
		"MoveBG::riccoBoatS_data": 0x803bd960,
		"riccoBoatS_data": 0x803bd960,
		"MoveBG::riccoBasket_data": 0x803bd99c,
		"riccoBasket_data": 0x803bd99c,
		"MoveBG::riccoGangway_data": 0x803bd9d8,
		"riccoGangway_data": 0x803bd9d8,
		"MoveBG::riccoShipFish_data": 0x803bda14,
		"riccoShipFish_data": 0x803bda14,
		"MoveBG::riccoShipGeso_data": 0x803bda50,
		"riccoShipGeso_data": 0x803bda50,
		"MoveBG::riccoSwitch_data": 0x803bda8c,
		"riccoSwitch_data": 0x803bda8c,
		"MoveBG::riccoSwitchShine_data": 0x803bdac8,
		"riccoSwitchShine_data": 0x803bdac8,
		"MoveBG::riccoFenceMaze_data": 0x803bdb04,
		"riccoFenceMaze_data": 0x803bdb04,
		"MoveBG::riccoStand_data": 0x803bdb40,
		"riccoStand_data": 0x803bdb40,
		"MoveBG::riccoGrille_data": 0x803bdb7c,
		"riccoGrille_data": 0x803bdb7c,
		"MoveBG::riccoArrow_data": 0x803bdbb8,
		"riccoArrow_data": 0x803bdbb8,
		"MoveBG::riccoStreetStall_data": 0x803bdbf4,
		"riccoStreetStall_data": 0x803bdbf4,
		"MoveBG::riccoHericopter_data": 0x803bdc30,
		"riccoHericopter_data": 0x803bdc30,
		"MoveBG::surfgeso_red_data": 0x803bdc6c,
		"surfgeso_red_data": 0x803bdc6c,
		"MoveBG::surfgeso_yellow_data": 0x803bdca8,
		"surfgeso_yellow_data": 0x803bdca8,
		"MoveBG::surfgeso_green_data": 0x803bdce4,
		"surfgeso_green_data": 0x803bdce4,
		"MoveBG::big_windmill_data": 0x803bdd20,
		"big_windmill_data": 0x803bdd20,
		"MoveBG::windmill_far_data": 0x803bdd5c,
		"windmill_far_data": 0x803bdd5c,
		"MoveBG::MiniWindmillL_data": 0x803bdd98,
		"MiniWindmillL_data": 0x803bdd98,
		"MoveBG::MiniWindmillS_data": 0x803bddd4,
		"MiniWindmillS_data": 0x803bddd4,
		"MoveBG::WindmillRoof_data": 0x803bde10,
		"WindmillRoof_data": 0x803bde10,
		"MoveBG::lamp_bianco_data": 0x803bde4c,
		"lamp_bianco_data": 0x803bde4c,
		"MoveBG::root_pakkun_data": 0x803bde88,
		"root_pakkun_data": 0x803bde88,
		"MoveBG::windmill_block_data": 0x803bdec4,
		"windmill_block_data": 0x803bdec4,
		"MoveBG::PolluterPakkun_data": 0x803bdf00,
		"PolluterPakkun_data": 0x803bdf00,
		"MoveBG::BiaBell_data": 0x803bdf3c,
		"BiaBell_data": 0x803bdf3c,
		"MoveBG::BiaWatermill00_data": 0x803bdf78,
		"BiaWatermill00_data": 0x803bdf78,
		"MoveBG::BiaWatermill01_data": 0x803bdfb4,
		"BiaWatermill01_data": 0x803bdfb4,
		"MoveBG::BiaWatermillVertical_data": 0x803bdff0,
		"BiaWatermillVertical_data": 0x803bdff0,
		"MoveBG::BiaTurnBridge_data": 0x803be02c,
		"BiaTurnBridge_data": 0x803be02c,
		"MoveBG::LeafBoat_data": 0x803be068,
		"LeafBoat_data": 0x803be068,
		"MoveBG::LeafBoatRotten_data": 0x803be0a4,
		"LeafBoatRotten_data": 0x803be0a4,
		"MoveBG::LampSeesaw_data": 0x803be0e0,
		"LampSeesaw_data": 0x803be0e0,
		"MoveBG::BiancoDoor_data": 0x803be11c,
		"BiancoDoor_data": 0x803be11c,
		"MoveBG::BiaBridge_data": 0x803be158,
		"BiaBridge_data": 0x803be158,
		"MoveBG::SandBird_data": 0x803be194,
		"SandBird_data": 0x803be194,
		"MoveBG::SandBirdBlock_data": 0x803be1d0,
		"SandBirdBlock_data": 0x803be1d0,
		"MoveBG::SkyIsland_data": 0x803be20c,
		"SkyIsland_data": 0x803be20c,
		"MoveBG::SandLeaf_data": 0x803be248,
		"SandLeaf_data": 0x803be248,
		"MoveBG::SandLeafBase00_data": 0x803be284,
		"SandLeafBase00_data": 0x803be284,
		"MoveBG::SandLeafBase01_data": 0x803be2c0,
		"SandLeafBase01_data": 0x803be2c0,
		"MoveBG::SandLeafBase02_data": 0x803be2fc,
		"SandLeafBase02_data": 0x803be2fc,
		"MoveBG::SandLeafBase03_data": 0x803be338,
		"SandLeafBase03_data": 0x803be338,
		"MoveBG::SandBomb_data": 0x803be374,
		"SandBomb_data": 0x803be374,
		"MoveBG::MirrorL_data": 0x803be3b0,
		"MirrorL_data": 0x803be3b0,
		"MoveBG::MirrorM_data": 0x803be3ec,
		"MirrorM_data": 0x803be3ec,
		"MoveBG::MirrorS_data": 0x803be428,
		"MirrorS_data": 0x803be428,
		"MoveBG::SandCastle_data": 0x803be464,
		"SandCastle_data": 0x803be464,
		"MoveBG::MammaBlockRotate_data": 0x803be4a0,
		"MammaBlockRotate_data": 0x803be4a0,
		"MoveBG::SandEgg_data": 0x803be4dc,
		"SandEgg_data": 0x803be4dc,
		"MoveBG::SandEggBroken_data": 0x803be518,
		"SandEggBroken_data": 0x803be518,
		"MoveBG::ShiningStone_data": 0x803be554,
		"ShiningStone_data": 0x803be554,
		"MoveBG::MammaSurfboard00_data": 0x803be590,
		"MammaSurfboard00_data": 0x803be590,
		"MoveBG::MammaSurfboard01_data": 0x803be5cc,
		"MammaSurfboard01_data": 0x803be5cc,
		"MoveBG::MammaSurfboard02_data": 0x803be608,
		"MammaSurfboard02_data": 0x803be608,
		"MoveBG::MammaSurfboard03_data": 0x803be644,
		"MammaSurfboard03_data": 0x803be644,
		"MoveBG::MammaSurfboardStand_data": 0x803be680,
		"MammaSurfboardStand_data": 0x803be680,
		"MoveBG::MammaYacht00_data": 0x803be6bc,
		"MammaYacht00_data": 0x803be6bc,
		"MoveBG::MammaYacht01_data": 0x803be6f8,
		"MammaYacht01_data": 0x803be6f8,
		"MoveBG::MammaYacht02_data": 0x803be734,
		"MammaYacht02_data": 0x803be734,
		"MoveBG::SandBombBase00_data": 0x803be770,
		"SandBombBase00_data": 0x803be770,
		"MoveBG::SandBombBaseMushroom_data": 0x803be7ac,
		"SandBombBaseMushroom_data": 0x803be7ac,
		"MoveBG::SandBombBasePyramid_data": 0x803be7e8,
		"SandBombBasePyramid_data": 0x803be7e8,
		"MoveBG::SandBombBaseShit_data": 0x803be824,
		"SandBombBaseShit_data": 0x803be824,
		"MoveBG::SandBombBaseStar_data": 0x803be860,
		"SandBombBaseStar_data": 0x803be860,
		"MoveBG::SandBombBaseTurtle_data": 0x803be89c,
		"SandBombBaseTurtle_data": 0x803be89c,
		"MoveBG::SandBombBaseFoot_data": 0x803be8d8,
		"SandBombBaseFoot_data": 0x803be8d8,
		"MoveBG::SandBombBaseHand_data": 0x803be914,
		"SandBombBaseHand_data": 0x803be914,
		"MoveBG::SandBombBaseStairs_data": 0x803be950,
		"SandBombBaseStairs_data": 0x803be950,
		"MoveBG::coral00_data": 0x803be98c,
		"coral00_data": 0x803be98c,
		"MoveBG::coral01_data": 0x803be9c8,
		"coral01_data": 0x803be9c8,
		"MoveBG::GoalWatermelon_data": 0x803bea04,
		"GoalWatermelon_data": 0x803bea04,
		"MoveBG::TeethOfJuicer_data": 0x803bea40,
		"TeethOfJuicer_data": 0x803bea40,
		"MoveBG::SandEggRepair_data": 0x803bea7c,
		"SandEggRepair_data": 0x803bea7c,
		"MoveBG::merrygoround_data": 0x803beab8,
		"merrygoround_data": 0x803beab8,
		"MoveBG::merry_egg_data": 0x803beaf4,
		"merry_egg_data": 0x803beaf4,
		"MoveBG::merry_pole_data": 0x803beb30,
		"merry_pole_data": 0x803beb30,
		"MoveBG::FerrisWheel_data": 0x803beb6c,
		"FerrisWheel_data": 0x803beb6c,
		"MoveBG::gondola_data": 0x803beba8,
		"gondola_data": 0x803beba8,
		"MoveBG::FerrisLOD_data": 0x803bebe4,
		"FerrisLOD_data": 0x803bebe4,
		"MoveBG::viking_data": 0x803bec20,
		"viking_data": 0x803bec20,
		"MoveBG::PinnaEntrance_data": 0x803bec5c,
		"PinnaEntrance_data": 0x803bec5c,
		"MoveBG::PinnaEntranceOpen_data": 0x803bec98,
		"PinnaEntranceOpen_data": 0x803bec98,
		"MoveBG::SirenaGate_data": 0x803becd4,
		"SirenaGate_data": 0x803becd4,
		"MoveBG::BalloonKoopaJr_data": 0x803bed10,
		"BalloonKoopaJr_data": 0x803bed10,
		"MoveBG::ShellCup_data": 0x803bed4c,
		"ShellCup_data": 0x803bed4c,
		"MoveBG::Gateshell_data": 0x803bed88,
		"Gateshell_data": 0x803bed88,
		"MoveBG::PinnaHangingBridgeBoard_data": 0x803bedc4,
		"PinnaHangingBridgeBoard_data": 0x803bedc4,
		"MoveBG::GateManta_data": 0x803bee00,
		"GateManta_data": 0x803bee00,
		"MoveBG::PinnaSunFlower_data": 0x803bee3c,
		"PinnaSunFlower_data": 0x803bee3c,
		"MoveBG::AmiKing_data": 0x803bee78,
		"AmiKing_data": 0x803bee78,
		"MoveBG::PinnaCoaster_data": 0x803beeb4,
		"PinnaCoaster_data": 0x803beeb4,
		"MoveBG::casinoroulette_data": 0x803beef0,
		"casinoroulette_data": 0x803beef0,
		"MoveBG::roulette00_data": 0x803bef2c,
		"roulette00_data": 0x803bef2c,
		"MoveBG::roulette01_data": 0x803bef68,
		"roulette01_data": 0x803bef68,
		"MoveBG::roulette02_data": 0x803befa4,
		"roulette02_data": 0x803befa4,
		"MoveBG::slotdrum_data": 0x803befe0,
		"slotdrum_data": 0x803befe0,
		"MoveBG::telesaslot_data": 0x803bf01c,
		"telesaslot_data": 0x803bf01c,
		"MoveBG::donchou_data": 0x803bf058,
		"donchou_data": 0x803bf058,
		"MoveBG::casino_panel_gate_data": 0x803bf094,
		"casino_panel_gate_data": 0x803bf094,
		"MoveBG::SakuCasino_data": 0x803bf0d0,
		"SakuCasino_data": 0x803bf0d0,
		"MoveBG::SirenabossWall_data": 0x803bf10c,
		"SirenabossWall_data": 0x803bf10c,
		"MoveBG::SirenaCasinoRoof_data": 0x803bf148,
		"SirenaCasinoRoof_data": 0x803bf148,
		"MoveBG::GlassBreak_data": 0x803bf184,
		"GlassBreak_data": 0x803bf184,
		"MoveBG::Closet_data": 0x803bf1c0,
		"Closet_data": 0x803bf1c0,
		"MoveBG::ChestRevolve_data": 0x803bf1fc,
		"ChestRevolve_data": 0x803bf1fc,
		"MoveBG::PosterTeresa_data": 0x803bf238,
		"PosterTeresa_data": 0x803bf238,
		"MoveBG::PictureTeresa_data": 0x803bf274,
		"PictureTeresa_data": 0x803bf274,
		"MoveBG::PanelBreak_data": 0x803bf2b0,
		"PanelBreak_data": 0x803bf2b0,
		"MoveBG::PanelRevolve_data": 0x803bf2ec,
		"PanelRevolve_data": 0x803bf2ec,
		"MoveBG::SirenaBlockBreak_data": 0x803bf328,
		"SirenaBlockBreak_data": 0x803bf328,
		"MoveBG::SirenaShop_data": 0x803bf364,
		"SirenaShop_data": 0x803bf364,
		"MoveBG::StainHotel_data": 0x803bf3a0,
		"StainHotel_data": 0x803bf3a0,
		"MoveBG::cogwheel_data": 0x803bf3dc,
		"cogwheel_data": 0x803bf3dc,
		"MoveBG::CogwheelPlate_data": 0x803bf418,
		"CogwheelPlate_data": 0x803bf418,
		"MoveBG::CogwheelPot_data": 0x803bf454,
		"CogwheelPot_data": 0x803bf454,
		"MoveBG::mare_float_house_data": 0x803bf490,
		"mare_float_house_data": 0x803bf490,
		"MoveBG::StopRock_physical_data": 0x803bf4cc,
		"StopRock_physical_data": 0x803bf4cc,
		"MoveBG::StopRock_physical_info": 0x803bf500,
		"StopRock_physical_info": 0x803bf500,
		"MoveBG::StopRock_data": 0x803bf50c,
		"StopRock_data": 0x803bf50c,
		"MoveBG::ElasticCode_data": 0x803bf548,
		"ElasticCode_data": 0x803bf548,
		"MoveBG::GrowthTree_data": 0x803bf584,
		"GrowthTree_data": 0x803bf584,
		"MoveBG::WireBellPurple_data": 0x803bf5c0,
		"WireBellPurple_data": 0x803bf5c0,
		"MoveBG::MuddyBoat_data": 0x803bf5fc,
		"MuddyBoat_data": 0x803bf5fc,
		"MoveBG::Puncher_data": 0x803bf638,
		"Puncher_data": 0x803bf638,
		"MoveBG::HatoPop_data": 0x803bf674,
		"HatoPop_data": 0x803bf674,
		"MoveBG::MareWaterJump_data": 0x803bf6b0,
		"MareWaterJump_data": 0x803bf6b0,
		"MoveBG::BumpyWall_data": 0x803bf6ec,
		"BumpyWall_data": 0x803bf6ec,
		"MoveBG::ExBottle_data": 0x803bf728,
		"ExBottle_data": 0x803bf728,
		"MoveBG::CoinFish_data": 0x803bf764,
		"CoinFish_data": 0x803bf764,
		"MoveBG::MareFall_data": 0x803bf7a0,
		"MareFall_data": 0x803bf7a0,
		"MoveBG::MareCork_data": 0x803bf7dc,
		"MareCork_data": 0x803bf7dc,
		"MoveBG::MonteRoot_data": 0x803bf818,
		"MonteRoot_data": 0x803bf818,
		"MoveBG::JumpMushroom_data": 0x803bf854,
		"JumpMushroom_data": 0x803bf854,
		"MoveBG::MonteGoalFlag_data": 0x803bf890,
		"MonteGoalFlag_data": 0x803bf890,
		"MoveBG::HangingBridgeBoard_data": 0x803bf8cc,
		"HangingBridgeBoard_data": 0x803bf8cc,
		"MoveBG::HangingBridge_data": 0x803bf908,
		"HangingBridge_data": 0x803bf908,
		"MoveBG::SwingBoard_data": 0x803bf944,
		"SwingBoard_data": 0x803bf944,
		"MoveBG::Fluff_data": 0x803bf980,
		"Fluff_data": 0x803bf980,
		"MoveBG::FluffManager_data": 0x803bf9bc,
		"FluffManager_data": 0x803bf9bc,
		"MoveBG::Bathtub_data": 0x803bf9f8,
		"Bathtub_data": 0x803bf9f8,
		"MoveBG::BathtubStand_data": 0x803bfa34,
		"BathtubStand_data": 0x803bfa34,
		"MoveBG::BathtubStandBreaking_animation": 0x803bfa70,
		"BathtubStandBreaking_animation": 0x803bfa70,
		"MoveBG::BathtubStandBreaking_data": 0x803bfa7c,
		"BathtubStandBreaking_data": 0x803bfa7c,
		"MoveBG::ex1_turn_lift_move_data": 0x803bfab8,
		"ex1_turn_lift_move_data": 0x803bfab8,
		"MoveBG::ex1_turn_lift_data": 0x803bfac4,
		"ex1_turn_lift_data": 0x803bfac4,
		"MoveBG::z_turn_disk_move_data": 0x803bfb00,
		"z_turn_disk_move_data": 0x803bfb00,
		"MoveBG::z_turn_disk_data": 0x803bfb0c,
		"z_turn_disk_data": 0x803bfb0c,
		"MoveBG::y_turn_lift_move_data": 0x803bfb48,
		"y_turn_lift_move_data": 0x803bfb48,
		"MoveBG::y_turn_lift_data": 0x803bfb54,
		"y_turn_lift_data": 0x803bfb54,
		"MoveBG::EXskyTumiki_data": 0x803bfb90,
		"EXskyTumiki_data": 0x803bfb90,
		"MoveBG::EXskyWindow_data": 0x803bfbcc,
		"EXskyWindow_data": 0x803bfbcc,
		"MoveBG::EXskySenro_data": 0x803bfc08,
		"EXskySenro_data": 0x803bfc08,
		"MoveBG::Nail_data": 0x803bfc44,
		"Nail_data": 0x803bfc44,
		"MoveBG::PachinkoNail_data": 0x803bfc80,
		"PachinkoNail_data": 0x803bfc80,
		"MoveBG::FileLoadBlockA_data": 0x803bfcbc,
		"FileLoadBlockA_data": 0x803bfcbc,
		"MoveBG::FileLoadBlockB_data": 0x803bfcf8,
		"FileLoadBlockB_data": 0x803bfcf8,
		"MoveBG::FileLoadBlockC_data": 0x803bfd34,
		"FileLoadBlockC_data": 0x803bfd34,
		"MoveBG::sObjDataTable": 0x803bfd70,
		"sObjDataTable": 0x803bfd70,
		"TMapObjGeneral::__vt": 0x803c0310,
		"TMapObjBaseManager::__vt": 0x803c0538,
		"TMerryPole::__vt": 0x803c0578,
		"TMapObjManager::__vt": 0x803c06dc,
		"TMapObjTurn::__vt": 0x803c0720,
		"TMapObjMessenger::__vt": 0x803c0894,
		"TShine::mPromiLife": 0x803c0970,
		"mPromiLife": 0x803c0970,
		"TShine::mSenkoRate": 0x803c0980,
		"mSenkoRate": 0x803c0980,
		"TShine::mKiraRate": 0x803c0990,
		"mKiraRate": 0x803c0990,
		"TShine::mBowRate": 0x803c09a0,
		"mBowRate": 0x803c09a0,
		"TNozzleBox::__vt": 0x803c09b0,
		"TItemNozzle::__vt": 0x803c0c1c,
		"TEggYoshi::__vt": 0x803c0e00,
		"TShine::__vt": 0x803c0fdc,
		"TCoinBlue::__vt": 0x803c11c0,
		"TCoinRed::__vt": 0x803c13a4,
		"TCoinEmpty::__vt": 0x803c1588,
		"TFlowerCoin::__vt": 0x803c176c,
		"TCoin::__vt": 0x803c1950,
		"TItem::__vt": 0x803c1b34,
		"TItemManager::__vt": 0x803c1d18,
		"TBasketReverse::__vt": 0x803c1d58,
		"TRedCoinSwitch::__vt": 0x803c1ebc,
		"TMapObjSwitch::__vt": 0x803c2020,
		"THideObjInfo::__vt": 0x803c2184,
		"TMapObjWaterSpray::__vt": 0x803c2228,
		"TDamageObj::__vt": 0x803c238c,
		"TMapObjStartDemo::__vt": 0x803c2430,
		"TMapObjChangeStageHipDrop::__vt": 0x803c2594,
		"TMapObjChangeStage::__vt": 0x803c26f8,
		"TMapObjBillboard::__vt": 0x803c285c,
		"TManhole::__vt": 0x803c29cc,
		"TDoor::__vt": 0x803c2ba8,
		"TSuperHipDropBlock::__vt": 0x803c2d10,
		"TTelesaBlock::__vt": 0x803c2e80,
		"TJuiceBlock::__vt": 0x803c2fe4,
		"TBrickBlock::__vt": 0x803c3148,
		"TIceBlock::__vt": 0x803c32b8,
		"TLeanBlock::__vt": 0x803c341c,
		"TSandBlock::__vt": 0x803c3584,
		"TBreakableBlock::__vt": 0x803c36e8,
		"TWoodLog::__vt": 0x803c38c8,
		"TBellWatermill::__vt": 0x803c3a30,
		"TBiancoBell::__vt": 0x803c3ba4,
		"TLampSeesawMain::__vt": 0x803c3d08,
		"TLampSeesaw::__vt": 0x803c3e70,
		"TLeafBoatRotten::__vt": 0x803c3fd8,
		"TLeafBoat::__vt": 0x803c413c,
		"TBiancoMiniWindmill::__vt": 0x803c42a0,
		"TBiancoWatermillVertical::__vt": 0x803c4410,
		"TBiancoWatermill::__vt": 0x803c4574,
		"TMapObjRootPakkun::__vt": 0x803c46d8,
		"TBigWindmill::__vt": 0x803c483c,
		"TPictureTelesa::__vt": 0x803c49a0,
		"TPanelRevolve::__vt": 0x803c4b1c,
		"TChestRevolve::__vt": 0x803c4c80,
		"TWarpAreaActor::__vt": 0x803c4de4,
		"TSirenaCasinoRoof::__vt": 0x803c4e88,
		"TSirenabossWall::__vt": 0x803c4fec,
		"TSakuCasino::__vt": 0x803c5150,
		"TCloset::__vt": 0x803c52b4,
		"TDonchou::__vt": 0x803c5424,
		"TCasinoPanelGate::__vt": 0x803c5588,
		"TItemSlotDrum::__vt": 0x803c56f8,
		"TSlotDrum::__vt": 0x803c586c,
		"TRoulette::__vt": 0x803c59e0,
		"TRouletteSw::__vt": 0x803c5b48,
		"TFruitLauncher::__vt": 0x803c5bf0,
		"TFruitSwitch::__vt": 0x803c5d54,
		"TSurfGesoObj::__vt": 0x803c5eb8,
		"TRiccoWatermill::__vt": 0x803c609c,
		"TCraneCargo::__vt": 0x803c6200,
		"TCraneUpDown::__vt": 0x803c6368,
		"TCraneRotY::__vt": 0x803c64cc,
		"TSandEgg::__vt": 0x803c6630,
		"TMammaMirrorMapOperator::__vt": 0x803c67b8,
		"TGoalWatermelon::__vt": 0x803c67dc,
		"TSandBird::__vt": 0x803c6aa4,
		"TMammaYacht::__vt": 0x803c6c14,
		"TMammaBlockRotate::__vt": 0x803c6d78,
		"TShiningStone::__vt": 0x803c6edc,
		"TLeanMirror::__vt": 0x803c6f80,
		"TSandCastle::__vt": 0x803c70e4,
		"TSandBombBase::__vt": 0x803c7268,
		"TSandBomb::__vt": 0x803c73ec,
		"TSandLeafBase::__vt": 0x803c7550,
		"TSandBase::__vt": 0x803c76bc,
		"TSandLeaf::__vt": 0x803c7828,
		"TPinnaCoaster::__vt": 0x803c7990,
		"TAmiKing::__vt": 0x803c7af4,
		"TWaterRecoverObj::__vt": 0x803c7c58,
		"TPinnaEntrance::__vt": 0x803c7dbc,
		"TBalloonKoopaJr::__vt": 0x803c7f20,
		"TChangeStageMerrygoround::__vt": 0x803c80fc,
		"TMerrygoround::__vt": 0x803c8260,
		"TShellCup::__vt": 0x803c83c4,
		"TPinnaShell::__vt": 0x803c8528,
		"TViking::__vt": 0x803c85cc,
		"THorizontalViking::__vt": 0x803c8734,
		"TFerrisWheel::__vt": 0x803c889c,
		"TGateShadow::__vt": 0x803c8a00,
		"TMareEventPoint::__vt": 0x803c8a28,
		"TMareCork::__vt": 0x803c8acc,
		"TMareFall::__vt": 0x803c8c30,
		"TMuddyBoat::__vt": 0x803c8d94,
		"TMapObjPuncher::__vt": 0x803c8ef8,
		"TWireBell::__vt": 0x803c905c,
		"TMapObjGrowTree::__vt": 0x803c91c0,
		"TMapObjElasticCode::__vt": 0x803c9324,
		"TCogwheel::__vt": 0x803c9488,
		"TCogwheelScale::__vt": 0x803c95ec,
		"TMapObjFlagManager::__vt": 0x803c9750,
		"TMapObjFlag::__vt": 0x803c9774,
		"TMapObjWave::__vt": 0x803c9820,
		"TMapObjFloatOnSea::__vt": 0x803c9848,
		"TSandPlane::__vt": 0x803c99b0,
		"TRockPlane::__vt": 0x803c9aac,
		"TMapObjPlane::__vt": 0x803c9ba8,
		"TRideCloud::__vt": 0x803c9ca8,
		"TBigWatermelon::__vt": 0x803c9e18,
		"TCoverFruit::__vt": 0x803ca040,
		"TRandomFruit::__vt": 0x803ca1a4,
		"TResetFruit::__vt": 0x803ca394,
		"TMapObjBall::__vt": 0x803ca584,
		"TAirportEventSink::__vt": 0x803ca778,
		"TAirportSwitch::__vt": 0x803ca7cc,
		"TTurboNozzleDoor::__vt": 0x803ca9a8,
		"TDemoCannon::__vt": 0x803cab0c,
		"TMareGate::__vt": 0x803cac70,
		"TMapObjSmoke::__vt": 0x803cadd4,
		"TDptMonteFence::__vt": 0x803caf44,
		"TBellDolpic::__vt": 0x803cb0a8,
		"TMonumentShine::__vt": 0x803cb20c,
		"TMapObjRevivalPollution::__vt": 0x803cb370,
		"TPolluterBase::__vt": 0x803cb394,
		"TMapObjGrassManager::__vt": 0x803cb4f8,
		"TMapObjGrassGroup::__vt": 0x803cb51c,
		"TMapObjPoleManager::__vt": 0x803cb5c0,
		"TMapObjWaterFilter::__vt": 0x803cb5e8,
		"TMapObjSeaIndirect::__vt": 0x803cb688,
		"MoveBG::gateMActorNames": 0x803cb760,
		"gateMActorNames": 0x803cb760,
		"MoveBG::gateNames$2573": 0x803cb774,
		"gateNames$2573": 0x803cb774,
		"TModelGate::__vt": 0x803cb78c,
		"TRailFence::__vt": 0x803cb918,
		"TFenceWaterH::__vt": 0x803cba7c,
		"TFenceWater::__vt": 0x803cbbe8,
		"TRevolvingFenceInner::__vt": 0x803cbd54,
		"TRevolvingFenceOuter::__vt": 0x803cbeb8,
		"TFence::__vt": 0x803cc01c,
		"TFileLoadBlock::__vt": 0x803cc180,
		"TMapObjOptionWall::__vt": 0x803cc2e4,
		"TWoodBlock::__vt": 0x803cc388,
		"TRollBlock::__vt": 0x803cc4f8,
		"TRailBlock::__vt": 0x803cc65c,
		"TNormalLift::__vt": 0x803cc7cc,
		"TRailMapObj::__vt": 0x803cc93c,
		"TFluffManager::__vt": 0x803ccab0,
		"TFluff::__vt": 0x803ccc14,
		"TGoalFlag::__vt": 0x803ccd78,
		"TSwingBoard::__vt": 0x803ccedc,
		"THangingBridge::__vt": 0x803cd040,
		"THangingBridgeBoard::__vt": 0x803cd064,
		"TJumpMushroom::__vt": 0x803cd1cc,
		"TMapObjMonteRoot::__vt": 0x803cd330,
		"TMapObjTreeScale::__vt": 0x803cd498,
		"TMapObjTree::__vt": 0x803cd674,
		"TMapObjSteam::__vt": 0x803cd850,
		"TJointCoin::__vt": 0x803cd9c0,
		"TMapObjNail::__vt": 0x803cdb30,
		"TPool::__vt": 0x803cdca0,
		"TPoolManager::__vt": 0x803cde04,
		"TBathtub::__vt": 0x803cde48,
		"TBathtubGrip::__vt": 0x803cdfac,
		"TBathtubGripPartsHard::__vt": 0x803ce110,
		"TBathtubGripPartsFragile::__vt": 0x803ce20c,
		"TBathtubGripParts::__vt": 0x803ce308,
		"TJumpBase::__vt": 0x803ce408,
		"TMushroom1up::__vt": 0x803ce56c,
		"TWoodBox::__vt": 0x803ce6d0,
		"TBreakHideObj::__vt": 0x803ce840,
		"THideObjPictureTwin::__vt": 0x803ce9b0,
		"TWaterHitPictureHideObj::__vt": 0x803ceb2c,
		"THipDropHideObj::__vt": 0x803ceca8,
		"TFruitBasketEvent::__vt": 0x803cee18,
		"TFruitBasket::__vt": 0x803cef90,
		"TFruitHitHideObj::__vt": 0x803cf108,
		"TWaterHitHideObj::__vt": 0x803cf27c,
		"THideObj::__vt": 0x803cf3ec,
		"THideObjBase::__vt": 0x803cf55c,
		"TLampTrapIron::__vt": 0x803cf6d0,
		"TLampTrapIronHit::__vt": 0x803cf834,
		"TLampTrapSpike::__vt": 0x803cf8d8,
		"TLampTrapSpikeHit::__vt": 0x803cfa3c,
		"TJointModel::__vt": 0x803b8db8,
		"TJointModelManager::__vt": 0x803b8df0,
		"TJointObj::__vt": 0x803b8e18,
		"TMap::__vt": 0x803b8e40,
		"Map::@3341": 0x803b8e64,
		"TBGCheckListWarp::__vt": 0x803b8ea8,
		"TBGCheckList::__vt": 0x803b8eb4,
		"TMapCollisionWarp::__vt": 0x803b8ec0,
		"TMapCollisionMove::__vt": 0x803b8ee4,
		"TMapCollisionStatic::__vt": 0x803b8f08,
		"TMapCollisionBase::__vt": 0x803b8f2c,
		"TMapDrawWall::__vt": 0x803b8f50,
		"TMapEvent::__vt": 0x803b8f78,
		"TMapEventSinkShadowMario::__vt": 0x803b8fb8,
		"TMapEventSinkBianco::__vt": 0x803b900c,
		"TMapEventSinkInPollutionReset::__vt": 0x803b9060,
		"TMapEventSinkInPollution::__vt": 0x803b90b4,
		"TMapEventSink::__vt": 0x803b9108,
		"TMirrorMapDrawBuf::__vt": 0x803b9160,
		"TMirrorModelManager::__vt": 0x803b9184,
		"TMirrorModelObj::__vt": 0x803b91a8,
		"TMirrorModel::__vt": 0x803b91c4,
		"TMirrorCamera::__vt": 0x803b91e0,
		"Map::name_table$2428": 0x803b92a8,
		"name_table$2428": 0x803b92a8,
		"TMapModel::__vt": 0x803b92bc,
		"TMapModelManager::__vt": 0x803b92f0,
		"TMapObjSoundGroup::__vt": 0x803b9318,
		"TMapModelActor::__vt": 0x803b9358,
		"TMapStaticObj::__vt": 0x803b93fc,
		"TMapWireManager::__vt": 0x803b94a0,
		"TMapWireActor::__vt": 0x803b94c4,
		"TPollutionCounterBase::__vt": 0x803b9578,
		"TPollutionCounterObj::__vt": 0x803b958c,
		"TPollutionCounterLayer::__vt": 0x803b95a0,
		"Map::mare_name_table$2805": 0x803b95b8,
		"mare_name_table$2805": 0x803b95b8,
		"Map::name_table$2816": 0x803b95e0,
		"name_table$2816": 0x803b95e0,
		"TPollutionManager::__vt": 0x803b9634,
		"Map::@3043": 0x803b965c,
		"TPollutionLayerWallMinusX::__vt": 0x803b9678,
		"TPollutionLayerWallMinusZ::__vt": 0x803b96d4,
		"TPollutionObj::__vt": 0x803b9730,
		"TShimmer::__vt": 0x803b9758,
		"TSky::__vt": 0x803b97f8,
		"TMapEventSirenaSink::__vt": 0x803b9898,
		"Map::x_offset_table$2432": 0x803b98f8,
		"x_offset_table$2432": 0x803b98f8,
		"Map::z_offset_table$2433": 0x803b9920,
		"z_offset_table$2433": 0x803b9920,
		"TPollutionLayer::__vt": 0x803b9948,
		"TPollutionLayerWallBase::__vt": 0x803b99a4,
		"TPollutionLayerWallPlusX::__vt": 0x803b9a00,
		"TPollutionLayerWallPlusZ::__vt": 0x803b9a5c,
		"TPollutionLayerWave::__vt": 0x803b9ab8,
		"TPollutionTest::__vt": 0x803b9b18,
		"TMarineSnow::__vt": 0x803b9b40,
		"TDolpicEventRiccoMammaGate::__vt": 0x803b9be0,
		"TDolpicEventBiancoGate::__vt": 0x803b9c20,
		"TMareEventBumpyWall::__vt": 0x803b9c60,
		"Map::@3790": 0x803b9dc4,
		"TMareEventDepressWall::__vt": 0x803b9de4,
		"TMareEventWallRock::__vt": 0x803b9e08,
		"TMareWallRock::__vt": 0x803b9e2c,
		"TBathWaterManager::fileNames": 0x803b9f80,
		"fileNames": 0x803b9f80,
		"TBathWaterManager::__vt": 0x803b9f88,
		"TBathWater::__vt": 0x803b9fac,
		"TBathWaterMeshRenderer::__vt": 0x803ba050,
		"TBathWaterRenderer::__vt": 0x803ba064,
		"TBathWaterPreprocessor::__vt": 0x803ba078,
		"TStickyStainManager::__vt": 0x803ba0a0,
		"TFlashPane::__vt": 0x803b74d8,
		"TMenuPlane::__vt": 0x803b74fc,
		"TMenuBase::__vt": 0x803b7520,
		"TSMSFader::__vt": 0x803b7548,
		"GC2D::scDolpicNewsDolpic5_1": 0x803b75a0,
		"scDolpicNewsDolpic5_1": 0x803b75a0,
		"GC2D::scDolpicNewsDolpic5_4": 0x803b75ac,
		"scDolpicNewsDolpic5_4": 0x803b75ac,
		"GC2D::scDolpicNewsDolpic6": 0x803b75b8,
		"scDolpicNewsDolpic6": 0x803b75b8,
		"GC2D::scDolpicNewsDolpic7": 0x803b75c4,
		"scDolpicNewsDolpic7": 0x803b75c4,
		"GC2D::scDolpicNewsDolpic9": 0x803b785c,
		"scDolpicNewsDolpic9": 0x803b785c,
		"GC2D::scDolpicNewsDolpic10": 0x803b7868,
		"scDolpicNewsDolpic10": 0x803b7868,
		"TGCConsole2::__vt": 0x803b7884,
		"TTalk2D2::cColorTable": 0x803b7930,
		"TTalk2D2::__vt": 0x803b7948,
		"TPauseMenu2::__vt": 0x803b7ad0,
		"TSwitchHelpActor::__vt": 0x803b7af8,
		"THelpActor::__vt": 0x803b7ba0,
		"TCardSave::cMessageID": 0x803b7c48,
		"TCardSave::__vt": 0x803b7d20,
		"TCardLoad::cMessageID": 0x803b801c,
		"TCardLoad::__vt": 0x803b8108,
		"TConsoleStr::__vt": 0x803b83e8,
		"TSelectMenu::__vt": 0x803b85c8,
		"TSelectGrad::__vt": 0x803b8638,
		"TSelectDir::__vt": 0x803b8674,
		"TSelectShine::__vt": 0x803b8710,
		"TSelectShineManager::__vt": 0x803b8720,
		"TBlendPane::__vt": 0x803b8748,
		"TGuide::__vt": 0x803b87d0,
		"TSunShine::__vt": 0x803b8828,
		"TSunGlass::__vt": 0x803b8850,
		"TShineFader::__vt": 0x803b8878,
		"TProgSelect::__vt": 0x803b88e4,
		"GC2D::camLoc$96": 0x803b8908,
		"camLoc$96": 0x803b8908,
		"GC2D::objPt$97": 0x803b8914,
		"objPt$97": 0x803b8914,
		"GC2D::up$98": 0x803b8920,
		"up$98": 0x803b8920,
		"GC2D::handle_table": 0x803b892c,
		"handle_table": 0x803b892c,
		"GC2D::handle_type": 0x803b8968,
		"handle_type": 0x803b8968,
		"TMovieSubTitle::__vt": 0x803b8c60,
		"TOptionSoundUnit::cSoundSettings": 0x803b8cc4,
		"cSoundSettings": 0x803b8cc4,
		"TOptionSoundUnit::cFlagInfos": 0x803b8cdc,
		"cFlagInfos": 0x803b8cdc,
		"TMovieRumble::__vt": 0x803b8d90,
		"TConductor::__vt": 0x803a5cd8,
		"Enemy::entry$2672": 0x803a5d00,
		"entry$2672": 0x803a5d00,
		"Enemy::entry$2684": 0x803a5d18,
		"entry$2684": 0x803a5d18,
		"Enemy::entry$2697": 0x803a5d30,
		"entry$2697": 0x803a5d30,
		"Enemy::entry$2706": 0x803a5d48,
		"entry$2706": 0x803a5d48,
		"TEffectExplosion::__vt": 0x803a5d60,
		"TEffectModelManager::__vt": 0x803a5e74,
		"TEffectExplosionManager::__vt": 0x803a5ec8,
		"TEffectColumSand::__vt": 0x803a5f1c,
		"TEffectColumSandManager::__vt": 0x803a6030,
		"TEffectBombColumWater::__vt": 0x803a6084,
		"TEffectBombColumWaterManager::__vt": 0x803a6198,
		"TEffectColumWater::__vt": 0x803a61ec,
		"TEffectColumWaterManager::__vt": 0x803a6300,
		"TEffectModel::__vt": 0x803a6354,
		"TEffectObjManager::__vt": 0x803a6468,
		"TEffectObjBase::__vt": 0x803a648c,
		"TEffectBiancoFunsui::__vt": 0x803a6540,
		"TEffectPinnaFunsui::__vt": 0x803a65e4,
		"TSimpleEffect::__vt": 0x803a6688,
		"TEMarioManager::__vt": 0x803a6730,
		"TEMario::__vt": 0x803a6784,
		"TSpineEnemy::__vt": 0x803a6898,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::__vt": 0x803a69ac,
		"TSpineBase<TLiveActor>::__vt": 0x803a69b8,
		"TSolidStack<TPathNode>::__vt": 0x803a69c8,
		"TEnemyPolluteModel::__vt": 0x803a69d8,
		"TEnemyPolluteModelManager::__vt": 0x803a6a00,
		"TEnemyAttachment::__vt": 0x803a6a28,
		"TEnemyManager::__vt": 0x803a6b80,
		"Enemy::marioAnimeFiles": 0x803a6c10,
		"Enemy::recordFileNamesDolpic1": 0x803a7248,
		"recordFileNamesDolpic1": 0x803a7248,
		"Enemy::recordFileNamesMonteMan": 0x803a7268,
		"recordFileNamesMonteMan": 0x803a7268,
		"TEnemyMario::__vt": 0x803a72a4,
		"Enemy::rikuGesso_bastable": 0x803a75d8,
		"rikuGesso_bastable": 0x803a75d8,
		"TNerveGessoTurn::__vt": 0x803a764c,
		"TNerveGessoLand::__vt": 0x803a765c,
		"TNerveGessoFindMario::__vt": 0x803a766c,
		"TNerveGessoRolling::__vt": 0x803a767c,
		"TNerveGessoFall::__vt": 0x803a768c,
		"TNerveGessoPollute::__vt": 0x803a769c,
		"TNerveGessoPunch::__vt": 0x803a76ac,
		"TNerveGessoFreeze::__vt": 0x803a76bc,
		"TNerveGessoStay::__vt": 0x803a76cc,
		"TGessoPolluteObj::__vt": 0x803a76dc,
		"TLandGesso::__vt": 0x803a7824,
		"TSurfGesso::__vt": 0x803a79dc,
		"TGesso::__vt": 0x803a7b94,
		"TGessoManager::__vt": 0x803a7d4c,
		"TGessoPolluteModel::__vt": 0x803a7da4,
		"TGessoPolluteModelManager::__vt": 0x803a7dcc,
		"Enemy::grDummyRail": 0x803a7e30,
		"grDummyRail": 0x803a7e30,
		"TGraphWeb::__vt": 0x803a7efc,
		"Enemy::hanekuri_bastable": 0x803a7f08,
		"hanekuri_bastable": 0x803a7f08,
		"Enemy::hamukurianm_bastable": 0x803a7f18,
		"hamukurianm_bastable": 0x803a7f18,
		"TNerveDoroHanePrepareAttack::__vt": 0x803a7fcc,
		"TNerveDoroHaneHitWater::__vt": 0x803a7fdc,
		"TNerveDoroHaneRise::__vt": 0x803a7fec,
		"TNerveFireHamuKuriRecover::__vt": 0x803a7ffc,
		"TNerveDoroHamuKuriRobCap::__vt": 0x803a800c,
		"TNerveHaneHamuKuriMoveOnGraph::__vt": 0x803a801c,
		"TNerveHaneHamuKuriUpWait::__vt": 0x803a802c,
		"TNerveDangoHamuKuriWait::__vt": 0x803a803c,
		"TNerveHamuKuriJitabata::__vt": 0x803a804c,
		"TNerveHamuKuriLand::__vt": 0x803a805c,
		"TNerveHamuKuriWallDie::__vt": 0x803a806c,
		"TNerveHamuKuriBoundFreeze::__vt": 0x803a807c,
		"TNerveHamuKuriGoForSearchActor::__vt": 0x803a808c,
		"TDoroHamuKuri::__vt": 0x803a809c,
		"TFireHamuKuri::__vt": 0x803a8264,
		"TBossDangoHamuKuri::__vt": 0x803a842c,
		"TDangoHamuKuri::__vt": 0x803a85f4,
		"THaneHamuKuri2::__vt": 0x803a87bc,
		"TDoroHaneKuri::__vt": 0x803a8984,
		"THaneHamuKuri::__vt": 0x803a8b4c,
		"THamuKuri::__vt": 0x803a8d14,
		"TDoroHamuKuriManager::__vt": 0x803a8edc,
		"TDoroHige::__vt": 0x803a8f34,
		"TFireHamuKuriManager::__vt": 0x803a8f58,
		"TBossDangoHamuKuriManager::__vt": 0x803a8fb0,
		"TDangoHamuKuriManager::__vt": 0x803a9008,
		"TDoroHaneKuriManager::__vt": 0x803a9060,
		"THaneHamuKuriManager::__vt": 0x803a90b8,
		"THamuKuriManager::__vt": 0x803a9110,
		"THamuKuriLauncher::__vt": 0x803a9168,
		"Enemy::mameGesso_bastable": 0x803a9298,
		"mameGesso_bastable": 0x803a9298,
		"TNerveMameGessoWait::__vt": 0x803a92e4,
		"TNerveMameGessoObject::__vt": 0x803a92f4,
		"TNerveMameGessoThrown::__vt": 0x803a9304,
		"TNerveMameGessoPickUp::__vt": 0x803a9314,
		"TNerveMameGessoTrample::__vt": 0x803a9324,
		"TNerveMameGessoJitabata::__vt": 0x803a9334,
		"TNerveMameGessoDamage::__vt": 0x803a9344,
		"TNerveMameGessoGraphJumpWander::__vt": 0x803a9354,
		"TMameGesso::__vt": 0x803a9364,
		"TMameGessoManager::__vt": 0x803a951c,
		"Enemy::namekuri2_bastable": 0x803a9578,
		"namekuri2_bastable": 0x803a9578,
		"TNerveNKFollowMario::__vt": 0x803a95b0,
		"TDiffusionNameKuri::__vt": 0x803a95d0,
		"TNerveNameKuriDrawPollute::__vt": 0x803a9788,
		"TNerveNameKuriDiffuse::__vt": 0x803a9798,
		"TNerveNameKuriExplosion::__vt": 0x803a97a8,
		"TNerveNameKuriJumpAttackPrepare::__vt": 0x803a97b8,
		"TNerveNameKuriJumpAttack::__vt": 0x803a97c8,
		"TNerveNameKuriLand::__vt": 0x803a97d8,
		"TDiffusionNameKuriManager::__vt": 0x803a97e8,
		"TNameKuri::__vt": 0x803a9840,
		"TNameIndParCallback::__vt": 0x803a99f8,
		"TNameKuriManager::__vt": 0x803a9a08,
		"TNameKuriLauncher::__vt": 0x803a9a60,
		"Enemy::pakkun_bastable": 0x803a9b90,
		"pakkun_bastable": 0x803a9b90,
		"TNerveStayPakkunAppear::__vt": 0x803a9bd0,
		"TNerveStayPakkunHide::__vt": 0x803a9be0,
		"TNervePakkunFreeze::__vt": 0x803a9bf0,
		"TNervePakkunShoot::__vt": 0x803a9c00,
		"TNervePakkunHide::__vt": 0x803a9c10,
		"TNervePakkunAppear::__vt": 0x803a9c20,
		"TNervePakkunStay::__vt": 0x803a9c30,
		"TNervePakkunGenerate::__vt": 0x803a9c40,
		"TStayPakkun::__vt": 0x803a9c50,
		"TPakkunSeed::__vt": 0x803a9e00,
		"TPakkun::__vt": 0x803a9f48,
		"TPakkunManager::__vt": 0x803aa0f8,
		"TNerveSmallEnemyChange::__vt": 0x803aa168,
		"TNerveSmallEnemyWait::__vt": 0x803aa178,
		"TNerveSmallEnemyHitWaterJump::__vt": 0x803aa188,
		"TNerveSmallEnemyJump::__vt": 0x803aa198,
		"TNerveSmallEnemyFreeze::__vt": 0x803aa1a8,
		"TNerveSmallEnemyDie::__vt": 0x803aa1b8,
		"TSmallEnemy::__vt": 0x803aa1c8,
		"TSmallEnemyManager::__vt": 0x803aa370,
		"TSpider::__vt": 0x803aa3c8,
		"TNerveTypicalGraphWander::__vt": 0x803aa3d8,
		"TTypicalManager::__vt": 0x803aa3e8,
		"TTypicalEnemy::__vt": 0x803aa43c,
		"TWalker::__vt": 0x803aa550,
		"TSolidStack<TBGCheckData_const*>::__vt": 0x803aa560,
		"TNerveWalkerTraceMario::__vt": 0x803aa570,
		"TNerveWalkerEscape::__vt": 0x803aa580,
		"TNerveWalkerPostAttack::__vt": 0x803aa590,
		"TNerveWalkerAttack::__vt": 0x803aa5a0,
		"TNerveWalkerGraphWander::__vt": 0x803aa5b0,
		"TNerveWalkerGenerate::__vt": 0x803aa5c0,
		"TWalkerEnemy::__vt": 0x803aa5d0,
		"Enemy::bgeso_bastable": 0x803aa788,
		"bgeso_bastable": 0x803aa788,
		"TNerveBGRoll::__vt": 0x803aa7f8,
		"TNerveBGPolDrop::__vt": 0x803aa848,
		"TNerveBGPollute::__vt": 0x803aa858,
		"TNerveBGDie::__vt": 0x803aa868,
		"TNerveBGTug::__vt": 0x803aa878,
		"TNerveBGTentacleDamage::__vt": 0x803aa888,
		"TNerveBGBeakDamage::__vt": 0x803aa898,
		"TNerveBGEyeDamage::__vt": 0x803aa8a8,
		"TNerveBGWait::__vt": 0x803aa8b8,
		"TBossGessoManager::__vt": 0x803aa8c8,
		"TBossGesso::__vt": 0x803aa91c,
		"TBGBinder::__vt": 0x803aaa30,
		"TBossGessoMtxCalc::__vt": 0x803aaa40,
		"TBGBodyHit::__vt": 0x803aaa84,
		"TBGEyeHit::__vt": 0x803aab28,
		"TBGBeakHit::__vt": 0x803aabcc,
		"Enemy::dennoko_bastable": 0x803aac80,
		"dennoko_bastable": 0x803aac80,
		"TNerveElecCarapaceReturn::__vt": 0x803aace0,
		"TNerveElecCarapaceWait::__vt": 0x803aacf0,
		"TNerveElecCarapaceMove::__vt": 0x803aad00,
		"TNerveElecNokonokoAttack::__vt": 0x803aad10,
		"TNerveElecNokonokoRebirth::__vt": 0x803aad20,
		"TNerveElecNokonokoFreeze::__vt": 0x803aad30,
		"TNerveElecNokonokoTurn::__vt": 0x803aad40,
		"TNerveElecNokonokoCollect::__vt": 0x803aad50,
		"TNerveElecNokonokoShoot::__vt": 0x803aad60,
		"TElecCarapace::__vt": 0x803aad70,
		"TElecNokonoko::__vt": 0x803aaeb8,
		"TElecNokonokoManager::__vt": 0x803ab074,
		"Enemy::telesa_bastable": 0x803ab0d0,
		"telesa_bastable": 0x803ab0d0,
		"TNerveKageMarioModokiWait::__vt": 0x803ab11c,
		"TKageMarioModoki::__vt": 0x803ab160,
		"TKageMarioModokiManager::__vt": 0x803ab318,
		"TNerveTelesaTrample::__vt": 0x803ab370,
		"TNerveTelesaAttackMario::__vt": 0x803ab380,
		"TNerveTelesaFreeze::__vt": 0x803ab390,
		"TNerveTelesaDie::__vt": 0x803ab3a0,
		"TNerveTelesaImitate::__vt": 0x803ab3b0,
		"TMarioModokiTelesa::__vt": 0x803ab3c0,
		"TBoxTelesa::__vt": 0x803ab578,
		"TLoopTelesa::__vt": 0x803ab730,
		"TSeeTelesa::__vt": 0x803ab8e8,
		"TTelesa::__vt": 0x803abaa0,
		"TTelesaManager::__vt": 0x803abc58,
		"Enemy::fireWanwan_bastable": 0x803abcb0,
		"fireWanwan_bastable": 0x803abcb0,
		"TNerveFireWanwanEscape::__vt": 0x803abce8,
		"TNerveFireWanwanFreeze::__vt": 0x803abcf8,
		"TNerveFireWanwanFly::__vt": 0x803abd08,
		"TNerveFireWanwanHungTail::__vt": 0x803abd18,
		"TNerveFireWanwanDie::__vt": 0x803abd28,
		"TNerveFireWanwanRecover::__vt": 0x803abd38,
		"TNerveFireWanwanRecoverGraph::__vt": 0x803abd48,
		"TNerveFireWanwanTired::__vt": 0x803abd58,
		"TNerveFireWanwanAttack::__vt": 0x803abd68,
		"TNerveFireWanwanFindMario::__vt": 0x803abd78,
		"TNerveFireWanwanTurn::__vt": 0x803abd88,
		"TNerveFireWanwanGraphWander::__vt": 0x803abd98,
		"TFireWanwan::__vt": 0x803abda8,
		"TFireWanwanTailHit::__vt": 0x803abf50,
		"TFireWanwanManager::__vt": 0x803ac004,
		"TStageEnemyInfo::__vt": 0x803ac060,
		"TStageEnemyInfoTable::__vt": 0x803ac080,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::__vt": 0x803ac0a0,
		"TOneShotGenerator::__vt": 0x803ac0c0,
		"TGenerator::__vt": 0x803ac164,
		"Enemy::bosspakkun_bastable": 0x803ac188,
		"bosspakkun_bastable": 0x803ac188,
		"TNerveBPCannonL::__vt": 0x803ac200,
		"TNerveBPWaitL::__vt": 0x803ac210,
		"TNerveBPBreakSleep::__vt": 0x803ac220,
		"TNerveBPSleep::__vt": 0x803ac230,
		"TNerveBPFall::__vt": 0x803ac240,
		"TNerveBPHover::__vt": 0x803ac250,
		"TNerveBPFlyPivot::__vt": 0x803ac260,
		"TNerveBPFlyCannon::__vt": 0x803ac270,
		"TNerveBPTouchDown::__vt": 0x803ac280,
		"TNerveBPFly::__vt": 0x803ac290,
		"TNerveBPTakeOff::__vt": 0x803ac2a0,
		"TNerveBPDie::__vt": 0x803ac2b0,
		"TNerveBPPreDie::__vt": 0x803ac2c0,
		"TNerveBPJumpReact::__vt": 0x803ac2d0,
		"TNerveBPStompReact::__vt": 0x803ac2e0,
		"TNerveBPSwing::__vt": 0x803ac2f0,
		"TNerveBPGetUp::__vt": 0x803ac300,
		"TNerveBPTumbleOut::__vt": 0x803ac310,
		"TNerveBPTumble::__vt": 0x803ac320,
		"TNerveBPTumbleIn::__vt": 0x803ac330,
		"TNerveBPSwallow::__vt": 0x803ac340,
		"TNerveBPPivot::__vt": 0x803ac350,
		"TNerveBPTornado::__vt": 0x803ac360,
		"TNerveBPVomit::__vt": 0x803ac370,
		"TNerveBPCannon::__vt": 0x803ac380,
		"TNerveBPWait::__vt": 0x803ac390,
		"TBossPakkunManager::__vt": 0x803ac3a0,
		"TBossPakkun::__vt": 0x803ac3f4,
		"TBossPakkunMtxCalc::__vt": 0x803ac508,
		"TBPNavel::__vt": 0x803ac54c,
		"TBPHeadHit::__vt": 0x803ac5f0,
		"TBPTornado::__vt": 0x803ac694,
		"TBPVomit::__vt": 0x803ac738,
		"TBPPolDrop::__vt": 0x803ac75c,
		"Enemy::pukupuku_bastable": 0x803ac800,
		"pukupuku_bastable": 0x803ac800,
		"Enemy::moepuku_bastable": 0x803ac82c,
		"moepuku_bastable": 0x803ac82c,
		"TNerveTobiPukuSwimWander::__vt": 0x803ac858,
		"TNerveTobiPukuReturnLaunch::__vt": 0x803ac868,
		"TNerveTobiPukuPrepareFly::__vt": 0x803ac878,
		"TNerveTobiPukuBound::__vt": 0x803ac888,
		"TNerveTobiPukuLand::__vt": 0x803ac898,
		"TNerveTobiPukuDie::__vt": 0x803ac8a8,
		"TNerveTobiPukuPitiPiti::__vt": 0x803ac8b8,
		"TNerveTobiPukuFall::__vt": 0x803ac8c8,
		"TNerveTobiPukuHitWater::__vt": 0x803ac8d8,
		"TNerveTobiPukuAttack::__vt": 0x803ac8e8,
		"TNerveTobiPukuFly::__vt": 0x803ac8f8,
		"TNerveTobiPukuGenerate::__vt": 0x803ac908,
		"TMoePuku::__vt": 0x803ac918,
		"TPukuPuku::__vt": 0x803acb18,
		"TTobiPuku::__vt": 0x803acd18,
		"TMoePukuLaunchPad::__vt": 0x803acf18,
		"TTobiPukuLaunchPad::__vt": 0x803ad0c4,
		"TMoePukuManager::__vt": 0x803ad270,
		"TTobiPukuManager::__vt": 0x803ad2c8,
		"TMoePukuLaunchPadManager::__vt": 0x803ad320,
		"TTobiPukuLaunchPadManager::__vt": 0x803ad378,
		"Enemy::tinkoopa_bastable": 0x803ad408,
		"tinkoopa_bastable": 0x803ad408,
		"Enemy::TTinKoopa_jointNameTable": 0x803ad44c,
		"TTinKoopa_jointNameTable": 0x803ad44c,
		"Enemy::table$3029": 0x803ad4a0,
		"table$3029": 0x803ad4a0,
		"Enemy::table$3036": 0x803ad4e8,
		"table$3036": 0x803ad4e8,
		"Enemy::breastTrackJointNameTable": 0x803ad54c,
		"breastTrackJointNameTable": 0x803ad54c,
		"Enemy::bellyTrackJointNameTable": 0x803ad564,
		"bellyTrackJointNameTable": 0x803ad564,
		"Enemy::rightArmTrackJointNameTable": 0x803ad57c,
		"rightArmTrackJointNameTable": 0x803ad57c,
		"Enemy::leftArmTrackJointNameTable": 0x803ad58c,
		"leftArmTrackJointNameTable": 0x803ad58c,
		"TNerveTinKoopaBreak::__vt": 0x803ad5fc,
		"TNerveTinKoopaDamage::__vt": 0x803ad66c,
		"TNerveTinKoopaWait::__vt": 0x803ad67c,
		"TTinKoopaManager::__vt": 0x803ad68c,
		"TTinKoopaMtxCalc::__vt": 0x803ad6e0,
		"TTinKoopaPartsBase::__vt": 0x803ad724,
		"TTinKoopaFlame::__vt": 0x803ad824,
		"TTinKoopa::__vt": 0x803ad8c8,
		"Enemy::clauncher_bastable": 0x803ad9e0,
		"clauncher_bastable": 0x803ad9e0,
		"TCommonLauncherManager::__vt": 0x803ad9f0,
		"TCommonLauncher::__vt": 0x803ada44,
		"TLauncherManager::__vt": 0x803adb70,
		"TLauncher::__vt": 0x803adbc4,
		"Enemy::bwanwan_bastable": 0x803add28,
		"bwanwan_bastable": 0x803add28,
		"TNerveBWFall::__vt": 0x803add44,
		"TNerveBWShake::__vt": 0x803adea4,
		"TNerveBWJumpAway::__vt": 0x803adeb4,
		"TNerveBWDie::__vt": 0x803adec4,
		"TNerveBWJumpToBath::__vt": 0x803aded4,
		"TNerveBWWakeup::__vt": 0x803adee4,
		"TNerveBWStun::__vt": 0x803adef4,
		"TNerveBWJump::__vt": 0x803adf04,
		"TNerveBWBark::__vt": 0x803adf14,
		"TNerveBWRoll::__vt": 0x803adf24,
		"TNerveBWGraphWander::__vt": 0x803adf34,
		"TBossWanwanManager::__vt": 0x803adf44,
		"TBossWanwan::__vt": 0x803adf98,
		"TBossWanwanMtxCalc::__vt": 0x803ae0ac,
		"TBWBinder::__vt": 0x803ae0f0,
		"TBWHit::__vt": 0x803ae100,
		"TBWPicket::__vt": 0x803ae1a4,
		"TBWLeash::__vt": 0x803ae258,
		"TBWLeashNode::__vt": 0x803ae27c,
		"Enemy::tyuhana_bastable": 0x803ae320,
		"tyuhana_bastable": 0x803ae320,
		"TNerveChuuHanaWait::__vt": 0x803ae36c,
		"TNerveChuuHanaJumpPrepare::__vt": 0x803ae37c,
		"TNerveChuuHanaAttack::__vt": 0x803ae38c,
		"TNerveChuuHanaObject::__vt": 0x803ae39c,
		"TNerveChuuHanaFall2::__vt": 0x803ae3ac,
		"TNerveChuuHanaFall::__vt": 0x803ae3bc,
		"TNerveChuuHanaRoll::__vt": 0x803ae3cc,
		"TNerveChuuHanaStick::__vt": 0x803ae3dc,
		"TNerveChuuHanaKeepBalance::__vt": 0x803ae3ec,
		"TNerveChuuHanaForceJumped::__vt": 0x803ae3fc,
		"TNerveChuuHanaWalkOnPanel::__vt": 0x803ae40c,
		"TChuuHana::__vt": 0x803ae41c,
		"TChuuHanaAseParCallback::__vt": 0x803ae5d4,
		"TChuuHanaManager::__vt": 0x803ae5e4,
		"Enemy::igaiga_bastable": 0x803ae640,
		"igaiga_bastable": 0x803ae640,
		"Enemy::gorogoro_bastable": 0x803ae660,
		"gorogoro_bastable": 0x803ae660,
		"TNerveGorogoroDie::__vt": 0x803ae6a0,
		"TNerveGorogoroRollOnGraph::__vt": 0x803ae6b0,
		"TGorogoro::__vt": 0x803ae6c0,
		"TGorogoroManager::__vt": 0x803ae890,
		"TGorogoroPolluteModel::__vt": 0x803ae8e8,
		"TGorogoroPolluteModelManager::__vt": 0x803ae910,
		"TNerveIgaigaShootFromCannon::__vt": 0x803ae938,
		"TNerveIgaigaWaterHit::__vt": 0x803ae948,
		"TNerveIgaigaRollOnGraph::__vt": 0x803ae958,
		"TIgaiga::__vt": 0x803ae968,
		"TIgaigaManager::__vt": 0x803aeb38,
		"TIgaigaPolluteModel::__vt": 0x803aeb90,
		"TIgaigaPolluteModelManager::__vt": 0x803aebb8,
		"TRollEnemy::__vt": 0x803aebe0,
		"Enemy::poihana_bastable": 0x803aedb0,
		"poihana_bastable": 0x803aedb0,
		"TNervePoihanaTrapped::__vt": 0x803aede8,
		"TNervePoihanaThrow::__vt": 0x803aedf8,
		"TNervePoihanaFreeze::__vt": 0x803aee08,
		"TNervePoihanaSleep::__vt": 0x803aee18,
		"TSleepPoiHana::__vt": 0x803aee28,
		"TPoiHanaRed::__vt": 0x803aefe0,
		"TPoiHana::__vt": 0x803af198,
		"TPoiHanaCollision::__vt": 0x803af350,
		"TPoiHanaManager::__vt": 0x803af3f4,
		"Enemy::tamaNoko_bastable": 0x803af450,
		"tamaNoko_bastable": 0x803af450,
		"TNerveTamaNokoWait::__vt": 0x803af4ac,
		"TNerveTamaNokoHitWater::__vt": 0x803af4bc,
		"TNerveTamaNokoSink::__vt": 0x803af4cc,
		"TNerveTamaNokoThrown::__vt": 0x803af4dc,
		"TNerveTamaNokoPickUp::__vt": 0x803af4ec,
		"TNerveTamaNokoDown::__vt": 0x803af4fc,
		"TNerveTamaNokoAttack::__vt": 0x803af50c,
		"TNerveTamaNokoSleep::__vt": 0x803af51c,
		"TTamaNoko::__vt": 0x803af52c,
		"TTamaNokoManager::__vt": 0x803af6e4,
		"TTamaNokoFlower::__vt": 0x803af73c,
		"Enemy::btelesa_bastable": 0x803af760,
		"btelesa_bastable": 0x803af760,
		"TNerveBossTelesaFallDemo::__vt": 0x803af7f8,
		"TBossTelesaKillSmallEnemy::__vt": 0x803af808,
		"TNerveBossTelesaFreeze::__vt": 0x803af8ac,
		"TNerveBossTelesaPrepareSlot::__vt": 0x803af8bc,
		"TNerveBossTelesaSpitSlotItem::__vt": 0x803af8cc,
		"TNerveBossTelesaSlotStart::__vt": 0x803af8dc,
		"TNerveBossTelesaAppear::__vt": 0x803af8ec,
		"TNerveBossTelesaHideWait::__vt": 0x803af8fc,
		"TNerveBossTelesaHide::__vt": 0x803af90c,
		"TNerveBossTelesaSpit::__vt": 0x803af91c,
		"TNerveBossTelesaDie::__vt": 0x803af92c,
		"TBossTelesa::__vt": 0x803af93c,
		"TTelesaSlot::__vt": 0x803afa50,
		"TBossTelesaTongue::__vt": 0x803afd34,
		"TBossTelesaBody::__vt": 0x803afdd8,
		"TBossTelesaManager::__vt": 0x803afe7c,
		"TNerveBubbleSplit::__vt": 0x803afed0,
		"TNerveBubbleLive::__vt": 0x803afee0,
		"TBubble::__vt": 0x803afef0,
		"TBubbleManager::__vt": 0x803b00a8,
		"TNerveRHGraphWander::__vt": 0x803b0100,
		"TRiccoHookManager::__vt": 0x803b0110,
		"TRiccoHook::__vt": 0x803b0164,
		"THookTake::__vt": 0x803b0278,
		"Enemy::bombhei_bastable": 0x803b0368,
		"bombhei_bastable": 0x803b0368,
		"TNerveBombHeiExplosion::__vt": 0x803b03a8,
		"TNerveBombHeiThrown::__vt": 0x803b03f8,
		"TNerveBombHeiPickUp::__vt": 0x803b0408,
		"TNerveBombHeiWaitExplosion::__vt": 0x803b0418,
		"TNerveBombHeiWalkExplosion::__vt": 0x803b0428,
		"TNerveBombHeiAttack::__vt": 0x803b0438,
		"TNerveBombHeiGenerate::__vt": 0x803b0448,
		"TBombHei::__vt": 0x803b0458,
		"TBombHeiManager::__vt": 0x803b0610,
		"Enemy::cannon_bastable": 0x803b0668,
		"cannon_bastable": 0x803b0668,
		"TNerveCannonObject::__vt": 0x803b06c4,
		"TNerveCannonDamageDemo::__vt": 0x803b06d4,
		"TNerveCannonDamage::__vt": 0x803b06e4,
		"TNerveCannonClose::__vt": 0x803b06f4,
		"TNerveCannonForceBombShoot::__vt": 0x803b0704,
		"TNerveCannonShoot::__vt": 0x803b0714,
		"TNerveCannonSearch::__vt": 0x803b0724,
		"TNerveCannonOpen::__vt": 0x803b0734,
		"TCannon::__vt": 0x803b0744,
		"TCannonDom::__vt": 0x803b08f0,
		"TChorobei::__vt": 0x803b0914,
		"TCannonManager::__vt": 0x803b09b8,
		"Enemy::bosseel_bastable": 0x803b0a48,
		"bosseel_bastable": 0x803b0a48,
		"Enemy::bossEelTears_bastable": 0x803b0aa4,
		"bossEelTears_bastable": 0x803b0aa4,
		"TNerveBossEelSleepOnBottom::__vt": 0x803b0b28,
		"TNerveBossEelMouthOpenWait::__vt": 0x803b0b9c,
		"TNerveBossEelDie::__vt": 0x803b0bac,
		"TNerveBossEelEat::__vt": 0x803b0bbc,
		"TNerveBossEelQuickBack::__vt": 0x803b0bcc,
		"TNerveBossEelSlowBack::__vt": 0x803b0bdc,
		"TNerveBossEelOutWait::__vt": 0x803b0bec,
		"TNerveBossEelAppear::__vt": 0x803b0bfc,
		"TNerveBossEelSecondSpin::__vt": 0x803b0c0c,
		"TNerveBossEelFirstSpin::__vt": 0x803b0c1c,
		"TNerveBossEelWaitAppear::__vt": 0x803b0c2c,
		"TBossEel::__vt": 0x803b0c3c,
		"TBossEelTearsRecoverCollision::__vt": 0x803b0d50,
		"TBossEelBarrierCollision::__vt": 0x803b0dfc,
		"TBossEelAwaCollision::__vt": 0x803b0ea8,
		"TBossEelBodyCollision::__vt": 0x803b0f54,
		"TBossEelCollision::__vt": 0x803b1000,
		"TBossEelHeartCoin::__vt": 0x803b10ac,
		"TBossEelEye::__vt": 0x803b10d0,
		"TBossEelVortex::__vt": 0x803b10f4,
		"TBossEelTooth::__vt": 0x803b119c,
		"TBossEelManager::__vt": 0x803b1240,
		"TNerveOilBallStay::__vt": 0x803b1294,
		"TOilBall::__vt": 0x803b12a4,
		"TNerveBEelTearsSplit::__vt": 0x803b13bc,
		"TNerveBEelTearsMarioRecover::__vt": 0x803b13cc,
		"TNerveBEelTearsWaterHit::__vt": 0x803b13dc,
		"TNerveBEelTearsMoveUp::__vt": 0x803b13ec,
		"TNerveBEelTearsGenerate::__vt": 0x803b13fc,
		"TBEelTears::__vt": 0x803b140c,
		"TBEelTearsManager::__vt": 0x803b1524,
		"TBEelTearsDrop::__vt": 0x803b1578,
		"TNerveKillerExplosion::__vt": 0x803b1690,
		"TKiller::__vt": 0x803b16e0,
		"TKillerManager::__vt": 0x803b18a4,
		"TNerveFlyEnemyChaseFly::__vt": 0x803b18fc,
		"TNerveFlyEnemyNormalFly::__vt": 0x803b190c,
		"TFlyEnemy::__vt": 0x803b191c,
		"TBeamManager::__vt": 0x803b1ae0,
		"Enemy::sambo_bastable": 0x803b1b08,
		"sambo_bastable": 0x803b1b08,
		"TNerveSamboHeadHitWall::__vt": 0x803b1bcc,
		"TNerveSamboHeadRecoverWater::__vt": 0x803b1bdc,
		"TNerveSamboHeadHitWater::__vt": 0x803b1bec,
		"TNerveSamboHeadHide::__vt": 0x803b1bfc,
		"TNerveSamboHeadAttack::__vt": 0x803b1c0c,
		"TNerveSamboHeadAppear::__vt": 0x803b1c1c,
		"TSamboHead::__vt": 0x803b1c2c,
		"TSamboHeadManager::__vt": 0x803b1de4,
		"TNerveHanaSamboFreeze::__vt": 0x803b1e3c,
		"TNerveHanaSamboDie::__vt": 0x803b1e4c,
		"TNerveHanaSamboHide::__vt": 0x803b1e5c,
		"TNerveHanaSamboAttack::__vt": 0x803b1e6c,
		"TNerveHanaSamboWait::__vt": 0x803b1e7c,
		"TNerveHanaSamboAppear::__vt": 0x803b1e8c,
		"THanaSambo::__vt": 0x803b1e9c,
		"THanaSamboHead::__vt": 0x803b2044,
		"THanaSamboManager::__vt": 0x803b20e8,
		"TSamboFlower::__vt": 0x803b2140,
		"TSamboFlowerManager::__vt": 0x803b2258,
		"TSamboLeaf::__vt": 0x803b22b0,
		"Enemy::popo_bastable": 0x803b22d8,
		"popo_bastable": 0x803b22d8,
		"TNervePopoThrown::__vt": 0x803b2318,
		"TNervePopoWait::__vt": 0x803b2328,
		"TNervePopoExplosion::__vt": 0x803b2338,
		"TNervePopoFly::__vt": 0x803b2348,
		"TNervePopoAttack::__vt": 0x803b2358,
		"TNervePopoPossessedNozzle::__vt": 0x803b2368,
		"TPopo::__vt": 0x803b2378,
		"TPopoCollision::__vt": 0x803b2530,
		"TPopoManager::__vt": 0x803b25d4,
		"TNerveSBH_Fall::__vt": 0x803b2630,
		"TNerveSBH_SleepContinue::__vt": 0x803b2640,
		"TSleepBossHanachan::__vt": 0x803b2650,
		"TSleepBossHanachanManager::__vt": 0x803b2764,
		"TDemoBossHanachan::__vt": 0x803b27b8,
		"TDemoBossHanachanManager::__vt": 0x803b28cc,
		"TNerveFruitsBoatBckTrace::__vt": 0x803b2920,
		"TNerveFruitsBoatGraphWander::__vt": 0x803b2930,
		"TFruitsBoatManager::__vt": 0x803b2940,
		"TFruitsBoat::__vt": 0x803b2994,
		"TWaterHitActor::__vt": 0x803b2aa8,
		"Enemy::sChangeSaveFileName$2712": 0x803b2b50,
		"sChangeSaveFileName$2712": 0x803b2b50,
		"Enemy::entry$2725": 0x803b2b5c,
		"entry$2725": 0x803b2b5c,
		"TBossHanachan::__vt": 0x803b2b8c,
		"TBossHanachanManager::__vt": 0x803b2ca0,
		"TNerveBossHanachanDead::__vt": 0x803b2cf8,
		"TNerveBossHanachanSnort::__vt": 0x803b2d08,
		"TNerveBossHanachanDamage::__vt": 0x803b2d18,
		"TNerveBossHanachanGetUp::__vt": 0x803b2d28,
		"TNerveBossHanachanDown::__vt": 0x803b2d38,
		"TNerveBossHanachanTumble::__vt": 0x803b2d48,
		"TNerveBossHanachanGraphWander::__vt": 0x803b2d58,
		"TBossHanachanPartsHead::__vt": 0x803b2d68,
		"TFootHitActor::__vt": 0x803b2eb0,
		"TBossHanachanPartsBody::__vt": 0x803b2f54,
		"Enemy::amiNoko_bastable": 0x803b3058,
		"amiNoko_bastable": 0x803b3058,
		"TNerveAmiNokoFreeze::__vt": 0x803b30b0,
		"TNerveAmiNokoDie::__vt": 0x803b30c0,
		"TNerveAmiNokoTurn::__vt": 0x803b30d0,
		"TNerveAmiNokoWalkOnFence::__vt": 0x803b30e0,
		"TAmiNoko::__vt": 0x803b30f0,
		"TAmiHit::__vt": 0x803b32a8,
		"TAmiNokoManager::__vt": 0x803b334c,
		"Enemy::gatekeeper_bastable": 0x803b33a8,
		"gatekeeper_bastable": 0x803b33a8,
		"TNerveBGKLaunchName::__vt": 0x803b33f8,
		"TBGKObstacle::__vt": 0x803b3408,
		"TNerveBGKLaunchGoro::__vt": 0x803b34ac,
		"TNerveBGKDive::__vt": 0x803b34bc,
		"TNerveBGKDie::__vt": 0x803b34cc,
		"TNerveBGKAwakeDamage::__vt": 0x803b34dc,
		"TNerveBGKSleepDamage::__vt": 0x803b34ec,
		"TNerveBGKWait2::__vt": 0x803b34fc,
		"TNerveBGKWait::__vt": 0x803b350c,
		"TNerveBGKAppear::__vt": 0x803b351c,
		"TNerveBGKSleep::__vt": 0x803b352c,
		"TBiancoGateKeeper::__vt": 0x803b353c,
		"TBGKMtxCalc::__vt": 0x803b3650,
		"TBiancoGateKeeperManager::__vt": 0x803b3694,
		"TGateKeeperBase::__vt": 0x803b36ec,
		"TGKHitObj::__vt": 0x803b3800,
		"TEggGenManager::__vt": 0x803b38a8,
		"TEggGenerator::__vt": 0x803b38fc,
		"TNerveSealDie::__vt": 0x803b3a10,
		"TNerveSealWait::__vt": 0x803b3a20,
		"TNerveSealSleep::__vt": 0x803b3a30,
		"TSealManager::__vt": 0x803b3a40,
		"TSeal::__vt": 0x803b3a94,
		"TBGPolDrop::__vt": 0x803b3ba8,
		"Enemy::tstatestr": 0x803b3c80,
		"tstatestr": 0x803b3c80,
		"TBGTentacle::__vt": 0x803b3cbc,
		"TBGAttackHit::__vt": 0x803b3ee0,
		"TBGTakeHit::__vt": 0x803b3f84,
		"TBGTentacleMtxCalc::__vt": 0x803b4038,
		"TEffectEnemy::__vt": 0x803b4090,
		"TEffectEnemyManager::__vt": 0x803b4248,
		"Enemy::hauntleg_bastable": 0x803b42a0,
		"hauntleg_bastable": 0x803b42a0,
		"TNerveHauntLegHaunt::__vt": 0x803b42b8,
		"THauntLeg::__vt": 0x803b42c8,
		"THauntedObject::__vt": 0x803b4480,
		"THauntLegManager::__vt": 0x803b4524,
		"TAreaCylinderManager::__vt": 0x803b4580,
		"TAreaCylinder::__vt": 0x803b45a4,
		"TNerveWireTrapGoWait::__vt": 0x803b45c8,
		"TNerveWireTrapWait::__vt": 0x803b4608,
		"TNerveWireTrapSearch::__vt": 0x803b4618,
		"TNerveWireTrapOnewayMoveEnd::__vt": 0x803b4628,
		"TNerveWireTrapOnewayMove::__vt": 0x803b4638,
		"TNerveWireTrapOnewayMoveStart::__vt": 0x803b4648,
		"TNerveWireTrapReturnMove::__vt": 0x803b4658,
		"TWireTrapManager::__vt": 0x803b4668,
		"TWireTrap::__vt": 0x803b46bc,
		"Enemy::bosshanachan_bastable": 0x803b47d0,
		"bosshanachan_bastable": 0x803b47d0,
		"TBossHanachanPartsBase::__vt": 0x803b4868,
		"Enemy::rocket_bastable": 0x803b4968,
		"rocket_bastable": 0x803b4968,
		"TNerveRocketWait::__vt": 0x803b4990,
		"TNerveRocketFly::__vt": 0x803b49a0,
		"TNerveRocketPossessedNozzle::__vt": 0x803b49b0,
		"TRocket::__vt": 0x803b49c0,
		"TRocketManager::__vt": 0x803b4b68,
		"Enemy::Kazekun_bastable": 0x803b4bc0,
		"Kazekun_bastable": 0x803b4bc0,
		"TNerveKazekunHitWater::__vt": 0x803b4bd4,
		"TNerveKazekunWait::__vt": 0x803b4be4,
		"TNerveKazekunDisappear::__vt": 0x803b4bf4,
		"TNerveKazekunAttack::__vt": 0x803b4c04,
		"TNerveKazekunPreAttack::__vt": 0x803b4c14,
		"TNerveKazekunTurn::__vt": 0x803b4c24,
		"TNerveKazekunAppear::__vt": 0x803b4c34,
		"TNerveKazekunSearch::__vt": 0x803b4c44,
		"TKazekunManager::__vt": 0x803b4c54,
		"TKazekun::__vt": 0x803b4cac,
		"TBossManta::sFrameRate": 0x803b4e58,
		"sFrameRate": 0x803b4e58,
		"TBossManta::sScale": 0x803b4e70,
		"sScale": 0x803b4e70,
		"Enemy::onetimeFilenames$3261": 0x803b4e88,
		"onetimeFilenames$3261": 0x803b4e88,
		"Enemy::loopFilenames$3273": 0x803b4e9c,
		"loopFilenames$3273": 0x803b4e9c,
		"TBossMantaManager::__vt": 0x803b4ec4,
		"TBossMantaAdditionalCollision::__vt": 0x803b4f18,
		"TBossManta::__vt": 0x803b4fbc,
		"TNerveMantaAppearDemo::__vt": 0x803b50d0,
		"TNerveMantaDeath::__vt": 0x803b50e0,
		"TNerveMantaSpawn::__vt": 0x803b50f0,
		"TNerveMantaHitWater::__vt": 0x803b5100,
		"TNerveMantaMove::__vt": 0x803b5110,
		"TWireBinder::__vt": 0x803b5120,
		"TNerveYumboFreeze::__vt": 0x803b5164,
		"TNerveYumboAttack::__vt": 0x803b5174,
		"TNerveYumboAppearing::__vt": 0x803b5184,
		"TNerveYumboHiding::__vt": 0x803b5194,
		"TNerveYumboDancing::__vt": 0x803b51a4,
		"TYumbo::__vt": 0x803b51b4,
		"TYumboManager::__vt": 0x803b535c,
		"TYumboSeed::__vt": 0x803b53b4,
		"Enemy::TKoopaJr_jointNameTable": 0x803b5470,
		"TKoopaJr_jointNameTable": 0x803b5470,
		"TKoopaJrSubmarineManager::__vt": 0x803b5484,
		"TNerveKoopaJrSubmarineLaunchKiller::__vt": 0x803b54d8,
		"TNerveKoopaJrSubmarineCannonOpenClose::__vt": 0x803b54e8,
		"TNerveKoopaJrSubmarineWait::__vt": 0x803b54f8,
		"TKoopaJrSubmarine::__vt": 0x803b5508,
		"TKoopaJrManager::__vt": 0x803b561c,
		"TNerveKoopaJrYahoo::__vt": 0x803b5670,
		"TNerveKoopaJrLaunch::__vt": 0x803b5680,
		"TNerveKoopaJrDemo::__vt": 0x803b5690,
		"TNerveKoopaJrDamage::__vt": 0x803b56a0,
		"TNerveKoopaJrWait::__vt": 0x803b56b0,
		"TKoopaJr::__vt": 0x803b56c0,
		"TCallbackHitActor::__vt": 0x803b57d4,
		"Enemy::kumokun_bastable": 0x803b5878,
		"kumokun_bastable": 0x803b5878,
		"Enemy::kumokun_bas_c_table": 0x803b58ac,
		"kumokun_bas_c_table": 0x803b58ac,
		"TNerveKumokunPreFly::__vt": 0x803b58e0,
		"TSolidStack<char_const*>::__vt": 0x803b58f0,
		"TNerveKumokunFly::__vt": 0x803b58fc,
		"TNerveKumokunPostFreeze::__vt": 0x803b590c,
		"TNerveKumokunFreeze::__vt": 0x803b591c,
		"TNerveKumokunWait::__vt": 0x803b592c,
		"TNerveKumokunSearch::__vt": 0x803b593c,
		"TNerveKumokunPostWalk::__vt": 0x803b594c,
		"TNerveKumokunWalk::__vt": 0x803b595c,
		"TNerveKumokunPreWalk::__vt": 0x803b596c,
		"TKumokunManager::__vt": 0x803b597c,
		"TKumokun::__vt": 0x803b59d4,
		"Enemy::koopa_bastable": 0x803b5b80,
		"koopa_bastable": 0x803b5b80,
		"TKoopaManager::__vt": 0x803b5bbc,
		"TNerveKoopaTurnR::__vt": 0x803b5c4c,
		"TNerveKoopaTurnL::__vt": 0x803b5c5c,
		"TNerveKoopaTurn::__vt": 0x803b5c6c,
		"TKoopa::__vt": 0x803b5c7c,
		"TKoopaBody::__vt": 0x803b5d90,
		"TKoopaHead::__vt": 0x803b5e3c,
		"TKoopaHand::__vt": 0x803b5ee8,
		"TKoopaFlame::__vt": 0x803b5f94,
		"TKoopaParts::__vt": 0x803b6040,
		"TNerveKoopaGetDown::__vt": 0x803b60ec,
		"TNerveKoopaGetShowered::__vt": 0x803b60fc,
		"TNerveKoopaStagger::__vt": 0x803b610c,
		"TNerveKoopaProvoke::__vt": 0x803b611c,
		"TNerveKoopaFlame::__vt": 0x803b612c,
		"TNerveKoopaFall::__vt": 0x803b613c,
		"TNerveKoopaTumble::__vt": 0x803b614c,
		"TNerveKoopaWait::__vt": 0x803b615c,
		"Enemy::tori_bastable": 0x803b6170,
		"tori_bastable": 0x803b6170,
		"TNerveKukkuRecoverGraph::__vt": 0x803b6188,
		"TNerveKukkuPostFall::__vt": 0x803b6198,
		"TNerveKukkuFall::__vt": 0x803b61a8,
		"TNerveKukkuGraphWander::__vt": 0x803b61b8,
		"TKukku::__vt": 0x803b61c8,
		"TKukkuManager::__vt": 0x803b6370,
		"TKukkuBall::__vt": 0x803b63c8,
		"Enemy::amenbo_bastable": 0x803b6470,
		"amenbo_bastable": 0x803b6470,
		"TNerveAmenboHitWater::__vt": 0x803b648c,
		"TNerveAmenboWalk::__vt": 0x803b649c,
		"TNerveAmenboPreAttack::__vt": 0x803b64ac,
		"TNerveAmenboTurn::__vt": 0x803b64bc,
		"TNerveAmenboSearch::__vt": 0x803b64cc,
		"TAmenbo::__vt": 0x803b64dc,
		"TAmenboManager::__vt": 0x803b6684,
		"Enemy::bathtubpeach_bastable": 0x803b66e0,
		"bathtubpeach_bastable": 0x803b66e0,
		"TBathtubPeachManager::__vt": 0x803b673c,
		"TNervePeachEscape::__vt": 0x803b6790,
		"TNervePeachStagger::__vt": 0x803b67a0,
		"TBathtubPeach::__vt": 0x803b67b0,
		"Enemy::bathtubkiller_bastable": 0x803b68c8,
		"bathtubkiller_bastable": 0x803b68c8,
		"TBathtubKillerManager::__vt": 0x803b68f8,
		"TNerveBathtubKillerExplosion::__vt": 0x803b6950,
		"TNerveBathtubKillerBreak::__vt": 0x803b6960,
		"TNerveBathtubKillerStraight::__vt": 0x803b6970,
		"TNerveBathtubKillerChaseStraight::__vt": 0x803b6980,
		"TNerveBathtubKillerChase::__vt": 0x803b6990,
		"TNerveBathtubKillerWander::__vt": 0x803b69a0,
		"TBathtubKiller::__vt": 0x803b69b0,
		"TCoasterKillerManager::__vt": 0x803b6b90,
		"TNerveCoasterKillerExplosion::__vt": 0x803b6be8,
		"TCoasterKiller::__vt": 0x803b6bf8,
		"TNerveCoasterEnemyWander::__vt": 0x803b6dbc,
		"TCoasterEnemy::__vt": 0x803b6dcc,
		"TNerveDebuTelesaWait::__vt": 0x803b6f90,
		"TDebuTelesaManager::__vt": 0x803b6fa0,
		"TDebuTelesa::__vt": 0x803b6ff8,
		"Enemy::tabepuku_bastable": 0x803b71a0,
		"tabepuku_bastable": 0x803b71a0,
		"TNerveTabePukuDrag::__vt": 0x803b71ac,
		"TNerveTabePukuDive::__vt": 0x803b71bc,
		"TNerveTabePukuBite::__vt": 0x803b71cc,
		"TNerveTabePukuAttack::__vt": 0x803b71dc,
		"TNerveTabePukuRecoverGraph::__vt": 0x803b71ec,
		"TNerveTabePukuFound::__vt": 0x803b71fc,
		"TNerveTabePukuGraphWander::__vt": 0x803b720c,
		"TTabePukuManager::__vt": 0x803b721c,
		"TTabePuku::__vt": 0x803b7274,
		"TTPHitActor::__vt": 0x803b741c,
		"TBathtubBinder::__vt": 0x803b74c8,
		"CPolarSubCamera::__vt": 0x803a5168,
		"Camera::@1790": 0x803a5348,
		"Camera::sNoticeActorManagerName": 0x803a5430,
		"sNoticeActorManagerName": 0x803a5430,
		"CPolarSubCamera::sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803a5440,
		"sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803a5440,
		"TLensFlare::__vt": 0x803a5488,
		"TLensGlow::__vt": 0x803a54b0,
		"TSunMgr::__vt": 0x803a54e0,
		"TSunModel::__vt": 0x803a5520,
		"TCubeManagerBase::__vt": 0x803a55c0,
		"TCameraMapTool::__vt": 0x803a5608,
		"TCubeStreamInfo::__vt": 0x803a5628,
		"TCubeCameraInfo::__vt": 0x803a5648,
		"TCubeGeneralInfo::__vt": 0x803a5668,
		"Camera::sAddBckFileNameTable": 0x803a5688,
		"sAddBckFileNameTable": 0x803a5688,
		"CPolarSubCamera::mCamKindNameSaveFile": 0x803a5698,
		"mCamKindNameSaveFile": 0x803a5698,
		"Camera::@1781": 0x803a57bc,
		"TCameraShake::mCamShakeNameSave": 0x803a5c30,
		"mCamShakeNameSave": 0x803a5c30,
		"TBoidLeader::__vt": 0x803a39e0,
		"TFishoidManager::__vt": 0x803a3a28,
		"TFishoid::__vt": 0x803a3b50,
		"TFish::__vt": 0x803a3c68,
		"TRealoid::__vt": 0x803a3d20,
		"TRealoidActor::__vt": 0x803a3e38,
		"TAnimalBase::__vt": 0x803a3ef0,
		"TMewManager::__vt": 0x803a4008,
		"TAnimalManagerBase::__vt": 0x803a405c,
		"TNerveAnimalGraphWander::__vt": 0x803a40e0,
		"Animal::bird_bastable": 0x803a40f0,
		"bird_bastable": 0x803a40f0,
		"TNerveAnimalBirdLanding::__vt": 0x803a4114,
		"TNerveAnimalBirdPreLanding::__vt": 0x803a4124,
		"TNerveAnimalBirdComeback::__vt": 0x803a4134,
		"TNerveAnimalBirdChangeToCoin::__vt": 0x803a4144,
		"TNerveAnimalBirdGraphWander::__vt": 0x803a4154,
		"TNerveAnimalBirdTakeoff::__vt": 0x803a4164,
		"TNerveAnimalBirdWalkOnGround::__vt": 0x803a4174,
		"TNerveAnimalBirdActionOnGround::__vt": 0x803a4184,
		"TNerveAnimalBirdWaitOnGround::__vt": 0x803a4194,
		"TAnimalBirdManager::__vt": 0x803a41a4,
		"TAnimalBird::__vt": 0x803a41f8,
		"TNerveBeeHiveReset::__vt": 0x803a4310,
		"TNerveBeeHiveMarioWaterIn::__vt": 0x803a4320,
		"TNerveBeeHiveAttack::__vt": 0x803a4330,
		"TNerveBeeHiveBreak::__vt": 0x803a4340,
		"TNerveBeeHiveFall::__vt": 0x803a4350,
		"TNerveBeeHiveWait::__vt": 0x803a4360,
		"TBeeHiveManager::__vt": 0x803a4370,
		"TBeeHive::__vt": 0x803a43c4,
		"TBee::__vt": 0x803a44dc,
		"TButterfloidManager::__vt": 0x803a4598,
		"TButterfloid::__vt": 0x803a45ec,
		"TButterfly::__vt": 0x803a4704,
		"main::gpApplication": 0x803e10c0,
		"gpApplication": 0x803e10c0,
		"Animal::@2305": 0x803e1110,
		"MSound::@2063": 0x803e1578,
		"MSound::@3781": 0x803e1588,
		"MSound::@3782": 0x803e1594,
		"MSound::@3783": 0x803e15a0,
		"MSound::@3784": 0x803e15ac,
		"MSound::@3785": 0x803e15b8,
		"MSound::@3786": 0x803e15c4,
		"MSound::@3787": 0x803e15d0,
		"MSound::@3788": 0x803e15dc,
		"MSound::@3789": 0x803e15e8,
		"MSound::@3790": 0x803e15f4,
		"MSound::@3791": 0x803e1600,
		"MSound::@3792": 0x803e160c,
		"MSound::@3793": 0x803e1618,
		"MSound::@3794": 0x803e1624,
		"MSound::@3795": 0x803e1630,
		"MSound::@3200": 0x803e2524,
		"MSound::@3201": 0x803e2530,
		"MSound::@3202": 0x803e253c,
		"MSound::@3203": 0x803e2548,
		"Camera::@3184": 0x803e7670,
		"Camera::@3185": 0x803e767c,
		"Camera::@2275": 0x803e77f0,
		"Camera::@2276": 0x803e77fc,
		"Camera::@2277": 0x803e7808,
		"Camera::@2278": 0x803e7814,
		"Camera::@2279": 0x803e7820,
		"Camera::@2280": 0x803e782c,
		"Camera::@2281": 0x803e7838,
		"Camera::@2282": 0x803e7844,
		"Camera::@2283": 0x803e7850,
		"Enemy::@3173": 0x803e79b4,
		"Enemy::@3231": 0x803e7c4c,
		"Enemy::@3868": 0x803e7dcc,
		"@3868": 0x803e7dcc,
		"Enemy::@8476": 0x803e7e08,
		"@8476": 0x803e7e08,
		"Enemy::@2575": 0x803e8028,
		"Enemy::@2676": 0x803e804c,
		"Enemy::@2728": 0x803e8070,
		"Enemy::@2755": 0x803e807c,
		"Enemy::@4067": 0x803e8100,
		"Enemy::@4068": 0x803e810c,
		"Enemy::@4756": 0x803e8178,
		"Enemy::@4757": 0x803e8184,
		"Enemy::@3256": 0x803e8344,
		"Enemy::@2617": 0x803e8448,
		"Enemy::@2628": 0x803e8454,
		"Enemy::@9293": 0x803e85b4,
		"@9293": 0x803e85b4,
		"Enemy::@9294": 0x803e85c0,
		"@9294": 0x803e85c0,
		"Enemy::@9295": 0x803e85cc,
		"@9295": 0x803e85cc,
		"Enemy::@9296": 0x803e85d8,
		"@9296": 0x803e85d8,
		"Enemy::@9297": 0x803e85e4,
		"@9297": 0x803e85e4,
		"Enemy::@9298": 0x803e85f0,
		"@9298": 0x803e85f0,
		"Enemy::@9299": 0x803e85fc,
		"@9299": 0x803e85fc,
		"Enemy::@9300": 0x803e8608,
		"@9300": 0x803e8608,
		"Enemy::@9301": 0x803e8614,
		"@9301": 0x803e8614,
		"Enemy::@9302": 0x803e8620,
		"@9302": 0x803e8620,
		"Enemy::@9303": 0x803e862c,
		"@9303": 0x803e862c,
		"Enemy::@9304": 0x803e8638,
		"@9304": 0x803e8638,
		"Enemy::@9305": 0x803e8644,
		"@9305": 0x803e8644,
		"Enemy::@9306": 0x803e8650,
		"@9306": 0x803e8650,
		"Enemy::@9307": 0x803e865c,
		"@9307": 0x803e865c,
		"Enemy::@5542": 0x803e8800,
		"@5542": 0x803e8800,
		"Enemy::@9741": 0x803e89b4,
		"@9741": 0x803e89b4,
		"Enemy::@9742": 0x803e89c0,
		"@9742": 0x803e89c0,
		"Enemy::up$3221": 0x803e89d0,
		"up$3221": 0x803e89d0,
		"Enemy::up$3267": 0x803e89dc,
		"up$3267": 0x803e89dc,
		"Enemy::goal$3320": 0x803e89e8,
		"goal$3320": 0x803e89e8,
		"Enemy::start$3323": 0x803e89f4,
		"start$3323": 0x803e89f4,
		"Enemy::goal$3327": 0x803e8a00,
		"goal$3327": 0x803e8a00,
		"Enemy::start$3330": 0x803e8a0c,
		"start$3330": 0x803e8a0c,
		"Enemy::s$3577": 0x803e8a18,
		"s$3577": 0x803e8a18,
		"Enemy::@3720": 0x803e8a54,
		"Enemy::@8446": 0x803e8bd4,
		"@8446": 0x803e8bd4,
		"Enemy::@8447": 0x803e8be0,
		"@8447": 0x803e8be0,
		"Enemy::@8448": 0x803e8bec,
		"@8448": 0x803e8bec,
		"Enemy::@8449": 0x803e8bf8,
		"@8449": 0x803e8bf8,
		"Enemy::@8450": 0x803e8c04,
		"@8450": 0x803e8c04,
		"Enemy::@3201": 0x803e90c0,
		"Enemy::@3222": 0x803e90d8,
		"Enemy::@5936": 0x803e9114,
		"Enemy::@5937": 0x803e9120,
		"Enemy::@5938": 0x803e912c,
		"Enemy::@5939": 0x803e9138,
		"Enemy::@5940": 0x803e9144,
		"Enemy::@5941": 0x803e9150,
		"@5941": 0x803e9150,
		"Enemy::@5942": 0x803e915c,
		"@5942": 0x803e915c,
		"Enemy::@5943": 0x803e9168,
		"@5943": 0x803e9168,
		"Enemy::@5944": 0x803e9174,
		"@5944": 0x803e9174,
		"Enemy::@5945": 0x803e9180,
		"@5945": 0x803e9180,
		"Enemy::@5946": 0x803e918c,
		"@5946": 0x803e918c,
		"Enemy::@5947": 0x803e9198,
		"@5947": 0x803e9198,
		"Enemy::@5948": 0x803e91a4,
		"@5948": 0x803e91a4,
		"Enemy::@5949": 0x803e91b0,
		"@5949": 0x803e91b0,
		"Enemy::@5950": 0x803e91bc,
		"@5950": 0x803e91bc,
		"Enemy::@3164": 0x803e92d0,
		"Enemy::@4636": 0x803e9378,
		"Enemy::@5302": 0x803e9400,
		"Enemy::@5304": 0x803e9418,
		"Enemy::@5305": 0x803e9424,
		"Enemy::@5306": 0x803e9430,
		"Enemy::@4084": 0x803e94e8,
		"Enemy::@4129": 0x803e950c,
		"Enemy::@4196": 0x803e9530,
		"Enemy::@9251": 0x803e95f0,
		"@9251": 0x803e95f0,
		"Enemy::@3080": 0x803e96f0,
		"Enemy::@3090": 0x803e96fc,
		"Enemy::@6278": 0x803e98ac,
		"@6278": 0x803e98ac,
		"Enemy::@6279": 0x803e98b8,
		"@6279": 0x803e98b8,
		"Enemy::@3227": 0x803e98ec,
		"Enemy::@3801": 0x803e9934,
		"Enemy::@3814": 0x803e9940,
		"Enemy::@9455": 0x803e99ac,
		"@9455": 0x803e99ac,
		"Enemy::@9456": 0x803e99b8,
		"@9456": 0x803e99b8,
		"Enemy::@9457": 0x803e99c4,
		"@9457": 0x803e99c4,
		"Enemy::@9458": 0x803e99d0,
		"@9458": 0x803e99d0,
		"Enemy::@9459": 0x803e99dc,
		"@9459": 0x803e99dc,
		"Enemy::@9460": 0x803e99e8,
		"@9460": 0x803e99e8,
		"Enemy::@9461": 0x803e99f4,
		"@9461": 0x803e99f4,
		"Enemy::@9462": 0x803e9a00,
		"@9462": 0x803e9a00,
		"Enemy::@2775": 0x803e9db0,
		"Enemy::@3707": 0x803e9e70,
		"Enemy::@3079": 0x803ea128,
		"Enemy::@4585": 0x803ea164,
		"@4585": 0x803ea164,
		"Enemy::@4587": 0x803ea17c,
		"@4587": 0x803ea17c,
		"Enemy::@4591": 0x803ea1ac,
		"Enemy::@4592": 0x803ea1b8,
		"Enemy::@4593": 0x803ea1c4,
		"Enemy::@4594": 0x803ea1d0,
		"Enemy::@3418": 0x803ea224,
		"Enemy::@5811": 0x803ea260,
		"Enemy::@5812": 0x803ea26c,
		"@5812": 0x803ea26c,
		"Enemy::@5813": 0x803ea278,
		"@5813": 0x803ea278,
		"Enemy::@5814": 0x803ea284,
		"@5814": 0x803ea284,
		"Enemy::@5815": 0x803ea290,
		"@5815": 0x803ea290,
		"Enemy::@5816": 0x803ea29c,
		"@5816": 0x803ea29c,
		"Enemy::@5817": 0x803ea2a8,
		"@5817": 0x803ea2a8,
		"Enemy::@5818": 0x803ea2b4,
		"@5818": 0x803ea2b4,
		"Enemy::@6694": 0x803ea560,
		"@6694": 0x803ea560,
		"Enemy::@6695": 0x803ea56c,
		"@6695": 0x803ea56c,
		"Enemy::@6696": 0x803ea578,
		"@6696": 0x803ea578,
		"Enemy::@6697": 0x803ea584,
		"@6697": 0x803ea584,
		"Enemy::@2686": 0x803ea7a8,
		"Enemy::@2723": 0x803ea7d8,
		"Enemy::@4174": 0x803eabdc,
		"Enemy::@4175": 0x803eabe8,
		"Enemy::@4176": 0x803eabf4,
		"Enemy::@4182": 0x803eac3c,
		"Enemy::@4183": 0x803eac48,
		"Enemy::@4184": 0x803eac54,
		"Enemy::@4185": 0x803eac60,
		"Enemy::@3322": 0x803eacd4,
		"Enemy::@6243": 0x803eacf8,
		"@6243": 0x803eacf8,
		"Enemy::@6244": 0x803ead04,
		"@6244": 0x803ead04,
		"Enemy::@6245": 0x803ead10,
		"@6245": 0x803ead10,
		"Enemy::@6250": 0x803ead4c,
		"@6250": 0x803ead4c,
		"Enemy::@2665": 0x803eada0,
		"Enemy::@2677": 0x803eadac,
		"Enemy::@2716": 0x803eadd0,
		"Enemy::@2756": 0x803eadf4,
		"Enemy::@4852": 0x803eb000,
		"Enemy::@4853": 0x803eb00c,
		"Enemy::@2532": 0x803eb030,
		"Enemy::@2544": 0x803eb03c,
		"Enemy::@2578": 0x803eb060,
		"Enemy::@3906": 0x803eb2e8,
		"@3906": 0x803eb2e8,
		"Enemy::@3907": 0x803eb2f4,
		"GC2D::@11981": 0x803eb590,
		"@11981": 0x803eb590,
		"GC2D::@11982": 0x803eb59c,
		"@11982": 0x803eb59c,
		"GC2D::@11983": 0x803eb5a8,
		"@11983": 0x803eb5a8,
		"GC2D::@11984": 0x803eb5b4,
		"@11984": 0x803eb5b4,
		"GC2D::@11985": 0x803eb5c0,
		"@11985": 0x803eb5c0,
		"GC2D::@11986": 0x803eb5cc,
		"@11986": 0x803eb5cc,
		"GC2D::@11987": 0x803eb5d8,
		"@11987": 0x803eb5d8,
		"GC2D::@11988": 0x803eb5e4,
		"@11988": 0x803eb5e4,
		"GC2D::@11989": 0x803eb5f0,
		"@11989": 0x803eb5f0,
		"GC2D::@11990": 0x803eb5fc,
		"@11990": 0x803eb5fc,
		"GC2D::@11991": 0x803eb608,
		"@11991": 0x803eb608,
		"GC2D::@11992": 0x803eb614,
		"@11992": 0x803eb614,
		"GC2D::@11993": 0x803eb620,
		"@11993": 0x803eb620,
		"GC2D::@11994": 0x803eb62c,
		"@11994": 0x803eb62c,
		"GC2D::@11995": 0x803eb638,
		"@11995": 0x803eb638,
		"GC2D::@5084": 0x803eb648,
		"GC2D::@5085": 0x803eb654,
		"GC2D::@5086": 0x803eb660,
		"GC2D::@5087": 0x803eb66c,
		"GC2D::@5088": 0x803eb678,
		"GC2D::@5089": 0x803eb684,
		"GC2D::@5090": 0x803eb690,
		"GC2D::@5091": 0x803eb69c,
		"GC2D::@5092": 0x803eb6a8,
		"GC2D::@5093": 0x803eb6b4,
		"GC2D::@5094": 0x803eb6c0,
		"GC2D::@5095": 0x803eb6cc,
		"GC2D::@5096": 0x803eb6d8,
		"GC2D::@5097": 0x803eb6e4,
		"GC2D::@5098": 0x803eb6f0,
		"GC2D::@3390": 0x803eb718,
		"GC2D::@3391": 0x803eb724,
		"GC2D::@3392": 0x803eb730,
		"GC2D::@3400": 0x803eb790,
		"GC2D::@3401": 0x803eb79c,
		"GC2D::@3402": 0x803eb7a8,
		"GC2D::@7149": 0x803eb7b8,
		"@7149": 0x803eb7b8,
		"GC2D::@7150": 0x803eb7c4,
		"@7150": 0x803eb7c4,
		"GC2D::@7151": 0x803eb7d0,
		"@7151": 0x803eb7d0,
		"GC2D::@7152": 0x803eb7dc,
		"@7152": 0x803eb7dc,
		"GC2D::@7153": 0x803eb7e8,
		"@7153": 0x803eb7e8,
		"GC2D::@7154": 0x803eb7f4,
		"@7154": 0x803eb7f4,
		"GC2D::@7155": 0x803eb800,
		"@7155": 0x803eb800,
		"GC2D::@7156": 0x803eb80c,
		"@7156": 0x803eb80c,
		"GC2D::@7157": 0x803eb818,
		"@7157": 0x803eb818,
		"GC2D::@7158": 0x803eb824,
		"@7158": 0x803eb824,
		"GC2D::@7159": 0x803eb830,
		"@7159": 0x803eb830,
		"GC2D::@7160": 0x803eb83c,
		"GC2D::@7161": 0x803eb848,
		"GC2D::@7162": 0x803eb854,
		"@7162": 0x803eb854,
		"GC2D::@7163": 0x803eb860,
		"@7163": 0x803eb860,
		"GC2D::@8877": 0x803eb870,
		"@8877": 0x803eb870,
		"GC2D::@8878": 0x803eb87c,
		"@8878": 0x803eb87c,
		"GC2D::@8879": 0x803eb888,
		"@8879": 0x803eb888,
		"GC2D::@8880": 0x803eb894,
		"@8880": 0x803eb894,
		"GC2D::@8881": 0x803eb8a0,
		"@8881": 0x803eb8a0,
		"GC2D::@8882": 0x803eb8ac,
		"@8882": 0x803eb8ac,
		"GC2D::@8883": 0x803eb8b8,
		"@8883": 0x803eb8b8,
		"GC2D::@8884": 0x803eb8c4,
		"@8884": 0x803eb8c4,
		"GC2D::@8885": 0x803eb8d0,
		"@8885": 0x803eb8d0,
		"GC2D::@8886": 0x803eb8dc,
		"@8886": 0x803eb8dc,
		"GC2D::@8887": 0x803eb8e8,
		"@8887": 0x803eb8e8,
		"GC2D::@8888": 0x803eb8f4,
		"@8888": 0x803eb8f4,
		"GC2D::@8889": 0x803eb900,
		"@8889": 0x803eb900,
		"GC2D::@8890": 0x803eb90c,
		"@8890": 0x803eb90c,
		"GC2D::@8891": 0x803eb918,
		"@8891": 0x803eb918,
		"GC2D::@3146": 0x803eba4c,
		"GC2D::@3147": 0x803eba58,
		"GC2D::@3148": 0x803eba64,
		"GC2D::@3149": 0x803eba70,
		"GC2D::@3150": 0x803eba7c,
		"GC2D::@3151": 0x803eba88,
		"GC2D::@4130": 0x803ebaa8,
		"GC2D::@2395": 0x803eeee0,
		"GC2D::@2396": 0x803eeeec,
		"GC2D::@2397": 0x803eeef8,
		"GC2D::@2402": 0x803eef34,
		"GC2D::@2403": 0x803eef40,
		"GC2D::@2404": 0x803eef4c,
		"Map::@3827": 0x803ef620,
		"Map::@3828": 0x803ef62c,
		"Map::@3829": 0x803ef638,
		"Map::@3830": 0x803ef644,
		"Map::@3831": 0x803ef650,
		"Map::@2683": 0x803ef8e8,
		"Map::@3658": 0x803ef940,
		"Map::@3659": 0x803ef94c,
		"Map::@3660": 0x803ef958,
		"Map::@3661": 0x803ef964,
		"Map::@3662": 0x803ef970,
		"Map::@3663": 0x803ef97c,
		"Map::@3664": 0x803ef988,
		"Map::@3665": 0x803ef994,
		"Map::@3666": 0x803ef9a0,
		"Map::@3667": 0x803ef9ac,
		"Map::@3672": 0x803ef9e8,
		"Map::@2937": 0x803efb10,
		"Map::@2800": 0x803effb8,
		"Map::@2801": 0x803effc4,
		"Map::@2802": 0x803effd0,
		"Map::@2804": 0x803effe8,
		"Map::@2805": 0x803efff4,
		"Map::@3117": 0x803f05a4,
		"Map::@3118": 0x803f05b0,
		"Map::@3119": 0x803f05bc,
		"Map::@3120": 0x803f05c8,
		"Map::@3121": 0x803f05d4,
		"Map::@3122": 0x803f05e0,
		"Map::@5861": 0x803f06a8,
		"Map::@5862": 0x803f06b4,
		"Map::@5863": 0x803f06c0,
		"Map::@5864": 0x803f06cc,
		"Map::@5865": 0x803f06d8,
		"Map::@5866": 0x803f06e4,
		"Map::@5867": 0x803f06f0,
		"Map::@5868": 0x803f06fc,
		"Map::@5869": 0x803f0708,
		"Map::@5870": 0x803f0714,
		"Map::@5871": 0x803f0720,
		"Map::@5872": 0x803f072c,
		"Map::@5873": 0x803f0738,
		"Map::@5874": 0x803f0744,
		"Map::@5875": 0x803f0750,
		"MoveBG::@4334": 0x803f0a40,
		"MoveBG::@4339": 0x803f0a7c,
		"MoveBG::@4340": 0x803f0a88,
		"MoveBG::@4341": 0x803f0a94,
		"MoveBG::@4342": 0x803f0aa0,
		"MoveBG::@4926": 0x803f0bb0,
		"MoveBG::@4927": 0x803f0bbc,
		"MoveBG::@4928": 0x803f0bc8,
		"MoveBG::@4929": 0x803f0bd4,
		"MoveBG::@4930": 0x803f0be0,
		"MoveBG::@4931": 0x803f0bec,
		"MoveBG::@4932": 0x803f0bf8,
		"MoveBG::@4933": 0x803f0c04,
		"MoveBG::@4934": 0x803f0c10,
		"MoveBG::@4935": 0x803f0c1c,
		"MoveBG::@4936": 0x803f0c28,
		"MoveBG::@4937": 0x803f0c34,
		"MoveBG::@4938": 0x803f0c40,
		"MoveBG::@4939": 0x803f0c4c,
		"MoveBG::@4940": 0x803f0c58,
		"MoveBG::@2756": 0x803f0c68,
		"MoveBG::@2757": 0x803f0c74,
		"MoveBG::@2758": 0x803f0c80,
		"MoveBG::@2759": 0x803f0c8c,
		"MoveBG::@2761": 0x803f0ca4,
		"MoveBG::@2763": 0x803f0cbc,
		"MoveBG::@2764": 0x803f0cc8,
		"MoveBG::@2765": 0x803f0cd4,
		"MoveBG::@2766": 0x803f0ce0,
		"MoveBG::@5315": 0x803f0f48,
		"MoveBG::@5316": 0x803f0f54,
		"MoveBG::@5317": 0x803f0f60,
		"MoveBG::@5318": 0x803f0f6c,
		"MoveBG::@5319": 0x803f0f78,
		"MoveBG::@5320": 0x803f0f84,
		"MoveBG::@5321": 0x803f0f90,
		"MoveBG::@5322": 0x803f0f9c,
		"MoveBG::@5323": 0x803f0fa8,
		"MoveBG::@5324": 0x803f0fb4,
		"MoveBG::@5325": 0x803f0fc0,
		"MoveBG::@5326": 0x803f0fcc,
		"MoveBG::@5327": 0x803f0fd8,
		"MoveBG::@5328": 0x803f0fe4,
		"MoveBG::@5329": 0x803f0ff0,
		"MoveBG::@5446": 0x803f10d0,
		"MoveBG::@5447": 0x803f10dc,
		"MoveBG::@5448": 0x803f10e8,
		"MoveBG::@5449": 0x803f10f4,
		"MoveBG::@5450": 0x803f1100,
		"MoveBG::@5451": 0x803f110c,
		"MoveBG::@5452": 0x803f1118,
		"MoveBG::@5453": 0x803f1124,
		"MoveBG::@5454": 0x803f1130,
		"MoveBG::@5455": 0x803f113c,
		"MoveBG::@5456": 0x803f1148,
		"MoveBG::@5457": 0x803f1154,
		"MoveBG::@5458": 0x803f1160,
		"MoveBG::@5459": 0x803f116c,
		"MoveBG::@5460": 0x803f1178,
		"MoveBG::@4428": 0x803f1218,
		"MoveBG::@4429": 0x803f1224,
		"MoveBG::@4430": 0x803f1230,
		"MoveBG::@5466": 0x803f1750,
		"MoveBG::@5467": 0x803f175c,
		"MoveBG::@5468": 0x803f1768,
		"MoveBG::@5469": 0x803f1774,
		"MoveBG::@5470": 0x803f1780,
		"MoveBG::@5471": 0x803f178c,
		"MoveBG::@5472": 0x803f1798,
		"MoveBG::@5473": 0x803f17a4,
		"MoveBG::@5474": 0x803f17b0,
		"MoveBG::@5475": 0x803f17bc,
		"MoveBG::@5476": 0x803f17c8,
		"MoveBG::@5477": 0x803f17d4,
		"MoveBG::@4518": 0x803f1ea0,
		"MoveBG::@4519": 0x803f1eac,
		"MoveBG::@4520": 0x803f1eb8,
		"MoveBG::@4521": 0x803f1ec4,
		"MoveBG::@4522": 0x803f1ed0,
		"MoveBG::@4527": 0x803f1f0c,
		"MoveBG::@4528": 0x803f1f18,
		"MoveBG::@4529": 0x803f1f24,
		"MoveBG::yDown$3084": 0x803f2180,
		"yDown$3084": 0x803f2180,
		"MoveBG::y$3281": 0x803f218c,
		"y$3281": 0x803f218c,
		"MoveBG::@6024": 0x803f2198,
		"MoveBG::@6025": 0x803f21a4,
		"MoveBG::@6026": 0x803f21b0,
		"MoveBG::@6027": 0x803f21bc,
		"MoveBG::@6028": 0x803f21c8,
		"NPC::@2634": 0x803f26cc,
		"NPC::@2635": 0x803f26d8,
		"NPC::@2636": 0x803f26e4,
		"NPC::@2637": 0x803f26f0,
		"NPC::@2638": 0x803f26fc,
		"NPC::@2639": 0x803f2708,
		"Strategic::@3371": 0x803f28d0,
		"Strategic::@3372": 0x803f28dc,
		"Strategic::@3373": 0x803f28e8,
		"Strategic::@3374": 0x803f28f4,
		"Strategic::@3375": 0x803f2900,
		"Strategic::@3376": 0x803f290c,
		"Strategic::@3377": 0x803f2918,
		"Strategic::@3378": 0x803f2924,
		"Strategic::@3379": 0x803f2930,
		"Strategic::@3380": 0x803f293c,
		"Strategic::@3381": 0x803f2948,
		"Strategic::@3382": 0x803f2954,
		"Strategic::@3383": 0x803f2960,
		"Strategic::@3384": 0x803f296c,
		"Strategic::@3385": 0x803f2978,
		"Strategic::@2743": 0x803f2a00,
		"Strategic::@2744": 0x803f2a0c,
		"Strategic::@2745": 0x803f2a18,
		"Strategic::@2746": 0x803f2a24,
		"Strategic::@2747": 0x803f2a30,
		"Player::@2099": 0x803f2bc0,
		"Player::@2100": 0x803f2bcc,
		"Player::@2101": 0x803f2bd8,
		"Player::@2102": 0x803f2be4,
		"Player::@2103": 0x803f2bf0,
		"Player::@2104": 0x803f2bfc,
		"Player::@2105": 0x803f2c08,
		"Player::@2106": 0x803f2c14,
		"Player::@2107": 0x803f2c20,
		"Player::@2515": 0x803f2d30,
		"Player::@2516": 0x803f2d3c,
		"Player::@2517": 0x803f2d48,
		"Player::@3712": 0x803f2de8,
		"Player::@3713": 0x803f2df4,
		"Player::@3714": 0x803f2e00,
		"Player::@3715": 0x803f2e0c,
		"Player::@3716": 0x803f2e18,
		"Player::@3114": 0x803f2ea0,
		"Player::@3117": 0x803f2ec4,
		"Player::@3118": 0x803f2ed0,
		"Player::@3119": 0x803f2edc,
		"Player::@2769": 0x803f2fac,
		"Player::@2770": 0x803f2fb8,
		"Player::@2771": 0x803f2fc4,
		"Player::@4086": 0x803f3018,
		"Player::@4087": 0x803f3024,
		"Player::@4088": 0x803f3030,
		"Player::@4089": 0x803f303c,
		"Player::@4090": 0x803f3048,
		"Player::@4091": 0x803f3054,
		"Player::@4092": 0x803f3060,
		"Player::@2787": 0x803f3118,
		"Player::@2788": 0x803f3124,
		"Player::@2789": 0x803f3130,
		"Player::@3447": 0x803f3194,
		"Player::@3448": 0x803f31a0,
		"Player::@3449": 0x803f31ac,
		"Player::@3205": 0x803f3240,
		"Player::@3207": 0x803f3258,
		"Player::@2150": 0x803f334c,
		"Player::@2151": 0x803f3358,
		"Player::scale$2683": 0x803f33b0,
		"scale$2683": 0x803f33b0,
		"Player::scale$2734": 0x803f33bc,
		"scale$2734": 0x803f33bc,
		"Player::@3602": 0x803f33ec,
		"Player::@3603": 0x803f33f8,
		"Player::@3605": 0x803f3410,
		"Player::@3606": 0x803f341c,
		"Player::@3607": 0x803f3428,
		"Player::@6203": 0x803f36a8,
		"@6203": 0x803f36a8,
		"Player::@6204": 0x803f36b4,
		"@6204": 0x803f36b4,
		"Player::@6205": 0x803f36c0,
		"@6205": 0x803f36c0,
		"Player::@6206": 0x803f36cc,
		"@6206": 0x803f36cc,
		"Player::@6207": 0x803f36d8,
		"Player::@6208": 0x803f36e4,
		"@6208": 0x803f36e4,
		"Player::@6209": 0x803f36f0,
		"@6209": 0x803f36f0,
		"Player::@6210": 0x803f36fc,
		"@6210": 0x803f36fc,
		"Player::@6211": 0x803f3708,
		"@6211": 0x803f3708,
		"Player::@6212": 0x803f3714,
		"@6212": 0x803f3714,
		"Player::@6213": 0x803f3720,
		"@6213": 0x803f3720,
		"Player::@6214": 0x803f372c,
		"@6214": 0x803f372c,
		"Player::@6215": 0x803f3738,
		"@6215": 0x803f3738,
		"Player::@6216": 0x803f3744,
		"@6216": 0x803f3744,
		"Player::@6217": 0x803f3750,
		"@6217": 0x803f3750,
		"Player::@6583": 0x803f3994,
		"@6583": 0x803f3994,
		"Player::@6584": 0x803f39a0,
		"@6584": 0x803f39a0,
		"Player::@6585": 0x803f39ac,
		"@6585": 0x803f39ac,
		"Player::@3254": 0x803f3ca0,
		"Player::@3255": 0x803f3cac,
		"Player::@3256": 0x803f3cb8,
		"System::@7659": 0x803f3dc8,
		"System::@7660": 0x803f3dd4,
		"System::@7661": 0x803f3de0,
		"System::@7662": 0x803f3dec,
		"System::@7663": 0x803f3df8,
		"System::@7664": 0x803f3e04,
		"System::@7665": 0x803f3e10,
		"System::@7666": 0x803f3e1c,
		"System::@7667": 0x803f3e28,
		"System::@7668": 0x803f3e34,
		"System::@7669": 0x803f3e40,
		"System::@7670": 0x803f3e4c,
		"System::@7671": 0x803f3e58,
		"System::@7672": 0x803f3e64,
		"System::@7673": 0x803f3e70,
		"System::@2695": 0x803f3e80,
		"System::@2698": 0x803f3ea4,
		"System::@2700": 0x803f3ebc,
		"System::@2701": 0x803f3ec8,
		"System::@2702": 0x803f3ed4,
		"System::@2703": 0x803f3ee0,
		"System::@2704": 0x803f3eec,
		"System::@2757": 0x803f40a8,
		"System::@2758": 0x803f40b4,
		"System::@2759": 0x803f40c0,
		"System::@2760": 0x803f40cc,
		"System::@2761": 0x803f40d8,
		"System::@2762": 0x803f40e4,
		"System::@2763": 0x803f40f0,
		"System::@3425": 0x803f41a8,
		"System::@3426": 0x803f41b4,
		"System::@3427": 0x803f41c0,
		"System::@6129": 0x803f4218,
		"System::@6130": 0x803f4224,
		"System::@6131": 0x803f4230,
		"System::@6132": 0x803f423c,
		"System::@6133": 0x803f4248,
		"System::@6134": 0x803f4254,
		"System::@6135": 0x803f4260,
		"System::@6136": 0x803f426c,
		"System::@6137": 0x803f4278,
		"System::@2557": 0x803f46a4,
		"System::@3016": 0x803f4750,
		"System::@3017": 0x803f475c,
		"System::@3018": 0x803f4768,
		"System::@3019": 0x803f4774,
		"System::@3021": 0x803f478c,
		"System::@3022": 0x803f4798,
		"System::@3023": 0x803f47a4,
		"System::@3024": 0x803f47b0,
		"System::@3025": 0x803f47bc,
		"System::@3026": 0x803f47c8,
		"System::@3027": 0x803f47d4,
		"System::@3028": 0x803f47e0,
		"System::@3029": 0x803f47ec,
		"System::@3030": 0x803f47f8,
		"System::@2649": 0x803f4a3c,
		"System::@2650": 0x803f4a48,
		"System::@2651": 0x803f4a54,
		"System::@2652": 0x803f4a60,
		"System::@3114": 0x803f4ac0,
		"System::@3115": 0x803f4acc,
		"System::@3116": 0x803f4ad8,
		"System::@4190": 0x803f4c9c,
		"System::@4191": 0x803f4ca8,
		"System::@4192": 0x803f4cb4,
		"@4192": 0x803f4cb4,
		"System::@4193": 0x803f4cc0,
		"@4193": 0x803f4cc0,
		"System::@4194": 0x803f4ccc,
		"@4194": 0x803f4ccc,
		"System::@4195": 0x803f4cd8,
		"@4195": 0x803f4cd8,
		"JSystem::@25": 0x803f4d28,
		"JSystem::exCallbackObject": 0x803f4d38,
		"exCallbackObject": 0x803f4d38,
		"JSystem::@301": 0x803f4d58,
		"JUTAssertion::@unnamed@::sMessageFileLine": 0x803f4d98,
		"sMessageFileLine": 0x803f4d98,
		"JUTAssertion::@unnamed@::sMessageString": 0x803f4dd8,
		"sMessageString": 0x803f4dd8,
		"JSystem::@1661": 0x803f4e38,
		"JSystem::@1662": 0x803f4e44,
		"JSystem::@1663": 0x803f4e50,
		"JSystem::@1664": 0x803f4e5c,
		"JSystem::@1665": 0x803f4e68,
		"JSystem::@1666": 0x803f4e74,
		"JSystem::@1667": 0x803f4e80,
		"JSystem::@1668": 0x803f4e8c,
		"JAInter::StreamLib::finfo": 0x803f4ec8,
		"finfo": 0x803f4ec8,
		"JAInter::StreamLib::header": 0x803f4f04,
		"header": 0x803f4f04,
		"JAInter::StreamLib::Filename": 0x803f4f24,
		"Filename": 0x803f4f24,
		"JSystem::@557": 0x803f4f98,
		"@557": 0x803f4f98,
		"JSystem::osc$294": 0x803f4fa8,
		"osc$294": 0x803f4fa8,
		"JSystem::@257": 0x803f4fc0,
		"@257": 0x803f4fc0,
		"JASystem::WaveArcLoader::sAramHeap": 0x803f4fcc,
		"sAramHeap": 0x803f4fcc,
		"JASystem::AudioThread::audioproc_mq": 0x803f4ff8,
		"audioproc_mq": 0x803f4ff8,
		"JASystem::AudioThread::msgbuf": 0x803f5018,
		"msgbuf": 0x803f5018,
		"JASystem::DSPBuf::dsp_buf": 0x803f5058,
		"dsp_buf": 0x803f5058,
		"JASystem::Kernel::dac": 0x803f5068,
		"dac": 0x803f5068,
		"JASystem::Dvd::mq": 0x803f5078,
		"mq": 0x803f5078,
		"JSystem::finfo$314": 0x803f5098,
		"finfo$314": 0x803f5098,
		"JSystem::req$315": 0x803f50d4,
		"req$315": 0x803f50d4,
		"JSystem::finfo$361": 0x803f5154,
		"finfo$361": 0x803f5154,
		"JSystem::req$362": 0x803f5190,
		"req$362": 0x803f5190,
		"JSystem::finfo$369": 0x803f51b0,
		"finfo$369": 0x803f51b0,
		"JSystem::req$370": 0x803f51ec,
		"req$370": 0x803f51ec,
		"JSystem::finfo$393": 0x803f520c,
		"finfo$393": 0x803f520c,
		"JSystem::finfo$422": 0x803f5248,
		"finfo$422": 0x803f5248,
		"JSystem::finfo$426": 0x803f5284,
		"finfo$426": 0x803f5284,
		"JASystem::HardStream::strCtrl": 0x803f52cc,
		"strCtrl": 0x803f52cc,
		"JSystem::finfo$425": 0x803f531c,
		"finfo$425": 0x803f531c,
		"JSystem::get_addr_cmd$429": 0x803f53d0,
		"get_addr_cmd$429": 0x803f53d0,
		"JSystem::stop_cmd$430": 0x803f56d0,
		"stop_cmd$430": 0x803f56d0,
		"JSystem::finish_cmd$431": 0x803f5700,
		"finish_cmd$431": 0x803f5700,
		"JSystem::@241": 0x803f5730,
		"JASystem::Kernel::audioAramHeap": 0x803f573c,
		"audioAramHeap": 0x803f573c,
		"JASystem::Player::oRandom": 0x803f5750,
		"oRandom": 0x803f5750,
		"JASystem::TrackMgr::sTrackList": 0x803f57d8,
		"sTrackList": 0x803f57d8,
		"JSystem::JPAEmitterInfoObj": 0x803f58d8,
		"JPAEmitterInfoObj": 0x803f58d8,
		"JSystem::@1657": 0x803f5a58,
		"JSystem::@1658": 0x803f5a64,
		"JSystem::taskwork": 0x803f7ae0,
		"taskwork": 0x803f7ae0,
		"JSystem::sync_stack": 0x803f7b60,
		"sync_stack": 0x803f7b60,
		"Runtime.PPCEABI.H::fragmentinfo": 0x803f7b70,
		"fragmentinfo": 0x803f7b70,
		"MSL_C.PPCEABI.bare.H::atexit_funcs": 0x803f7b80,
		"atexit_funcs": 0x803f7b80,
		"MSL_C.PPCEABI.bare.H::__atexit_funcs": 0x803f7c80,
		"__atexit_funcs": 0x803f7c80,
		"TRK_MINNOW_DOLPHIN::gTRKEventQueue": 0x803f7d80,
		"gTRKEventQueue": 0x803f7d80,
		"TRK_MINNOW_DOLPHIN::gTRKBigEndian": 0x803f7da8,
		"gTRKBigEndian": 0x803f7da8,
		"TRK_MINNOW_DOLPHIN::gTRKMsgBufs": 0x803f7db0,
		"gTRKMsgBufs": 0x803f7db0,
		"TRK_MINNOW_DOLPHIN::gTRKFramingState": 0x803f9760,
		"gTRKFramingState": 0x803f9760,
		"TRK_MINNOW_DOLPHIN::gTRKInputPendingPtr": 0x803f9774,
		"gTRKInputPendingPtr": 0x803f9774,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTableSize": 0x803f9778,
		"gTRKDispatchTableSize": 0x803f9778,
		"TRK_MINNOW_DOLPHIN::gTRKSaveState": 0x803f9784,
		"gTRKSaveState": 0x803f9784,
		"TRK_MINNOW_DOLPHIN::TRKvalue128_temp": 0x803f9818,
		"TRKvalue128_temp": 0x803f9818,
		"TRK_MINNOW_DOLPHIN::gTRKState": 0x803f9828,
		"gTRKState": 0x803f9828,
		"TRK_MINNOW_DOLPHIN::lc_base": 0x803f9d00,
		"lc_base": 0x803f9d00,
		"TRK_MINNOW_DOLPHIN::TRK_mainError": 0x803f9d08,
		"TRK_mainError": 0x803f9d08,
		"os::DriveBlock": 0x803f9d40,
		"DriveBlock": 0x803f9d40,
		"os::__OSErrorTable": 0x803f9d70,
		"__OSErrorTable": 0x803f9d70,
		"os::RunQueue": 0x803f9e38,
		"RunQueue": 0x803f9e38,
		"dvd::CommandList": 0x803fa820,
		"CommandList": 0x803fa820,
		"dvd::Prev": 0x803fa8d8,
		"Prev": 0x803fa8d8,
		"dvd::Curr": 0x803fa8e4,
		"Curr": 0x803fa8e4,
		"dvd::DummyCommandBlock": 0x803fa980,
		"DummyCommandBlock": 0x803fa980,
		"dvd::WaitingQueue": 0x803fa9d8,
		"WaitingQueue": 0x803fa9d8,
		"dvd::bb2Buf": 0x803fa9f8,
		"bb2Buf": 0x803fa9f8,
		"dvd::block$16": 0x803faa38,
		"block$16": 0x803faa38,
		"vi::regs": 0x803faa68,
		"regs": 0x803faa68,
		"vi::shdwRegs": 0x803faae0,
		"shdwRegs": 0x803faae0,
		"vi::HorVer": 0x803fab58,
		"HorVer": 0x803fab58,
		"pad::Type": 0x803fabb0,
		"pad::Origin": 0x803fabc0,
		"Origin": 0x803fabc0,
		"pad::CmdProbeDevice": 0x803fabf0,
		"CmdProbeDevice": 0x803fabf0,
		"card::__CARDDiskNone": 0x803fae20,
		"__CARDDiskNone": 0x803fae20,
		"gx::gxData": 0x803fae40,
		"gxData": 0x803fae40,
		"gx::FifoObj": 0x803fb338,
		"FifoObj": 0x803fb338,
		"gx::vcd": 0x803fb3b8,
		"vcd": 0x803fb3b8,
		"gx::vat": 0x803fb490,
		"vat": 0x803fb490,
		"si::TypeCallback": 0x803fb7a0,
		"TypeCallback": 0x803fb7a0,
		"si::RDSTHandler": 0x803fb7e0,
		"RDSTHandler": 0x803fb7e0,
		"si::InputBufferValid": 0x803fb7f0,
		"InputBufferValid": 0x803fb7f0,
		"si::InputBuffer": 0x803fb800,
		"InputBuffer": 0x803fb800,
		"si::InputBufferVcount": 0x803fb820,
		"InputBufferVcount": 0x803fb820,
		"si::cmdFixDevice$326": 0x803fb830,
		"cmdFixDevice$326": 0x803fb830,
		"exi::Ecb": 0x803fb840,
		"Ecb": 0x803fb840,
		"thp::__THPLCWork512": 0x803fba00,
		"__THPLCWork512": 0x803fba00,
		"thp::__THPLCWork640": 0x803fba0c,
		"__THPLCWork640": 0x803fba0c,
		"thp::__THPMCUBuffer": 0x803fba18,
		"__THPMCUBuffer": 0x803fba18,
		"THPPlayer::AudioDecodeThreadStack": 0x803e2ab0,
		"AudioDecodeThreadStack": 0x803e2ab0,
		"THPPlayer::FreeAudioBufferQueue": 0x803e3ab0,
		"FreeAudioBufferQueue": 0x803e3ab0,
		"THPPlayer::DecodedAudioBufferQueue": 0x803e3ad0,
		"DecodedAudioBufferQueue": 0x803e3ad0,
		"THPPlayer::FreeAudioBufferMessage": 0x803e3af0,
		"FreeAudioBufferMessage": 0x803e3af0,
		"THPPlayer::DecodedAudioBufferMessage": 0x803e3afc,
		"DecodedAudioBufferMessage": 0x803e3afc,
		"THPPlayer::PrepareReadyQueue": 0x803e3d40,
		"PrepareReadyQueue": 0x803e3d40,
		"THPPlayer::UsedTextureSetQueue": 0x803e3d60,
		"UsedTextureSetQueue": 0x803e3d60,
		"THPPlayer::UsedTextureSetMessage": 0x803e3d80,
		"UsedTextureSetMessage": 0x803e3d80,
		"THPPlayer::FreeReadBufferQueue": 0x803e4f20,
		"FreeReadBufferQueue": 0x803e4f20,
		"THPPlayer::ReadedBufferQueue": 0x803e4f40,
		"ReadedBufferQueue": 0x803e4f40,
		"THPPlayer::ReadedBufferQueue2": 0x803e4f60,
		"ReadedBufferQueue2": 0x803e4f60,
		"THPPlayer::FreeReadBufferMessage": 0x803e4f80,
		"FreeReadBufferMessage": 0x803e4f80,
		"THPPlayer::ReadedBufferMessage": 0x803e4fa8,
		"ReadedBufferMessage": 0x803e4fa8,
		"THPPlayer::ReadedBufferMessage2": 0x803e4fd0,
		"ReadedBufferMessage2": 0x803e4fd0,
		"THPPlayer::ReadThreadStack": 0x803e5308,
		"ReadThreadStack": 0x803e5308,
		"THPPlayer::VideoDecodeThreadStack": 0x803e6618,
		"VideoDecodeThreadStack": 0x803e6618,
		"THPPlayer::FreeTextureSetQueue": 0x803e7618,
		"FreeTextureSetQueue": 0x803e7618,
		"THPPlayer::DecodedTextureSetQueue": 0x803e7638,
		"DecodedTextureSetQueue": 0x803e7638,
		"THPPlayer::FreeTextureSetMessage": 0x803e7658,
		"FreeTextureSetMessage": 0x803e7658,
		"THPPlayer::DecodedTextureSetMessage": 0x803e7664,
		"DecodedTextureSetMessage": 0x803e7664,
		"MarioUtil::sViewPlane": 0x803f2a40,
		"sViewPlane": 0x803f2a40,
		"MarioUtil::@2174": 0x803f2aa0,
		"MarioUtil::setup1$2173": 0x803f2aac,
		"setup1$2173": 0x803f2aac,
		"MarioUtil::@2178": 0x803f2ad0,
		"MarioUtil::cylinder$2177": 0x803f2adc,
		"cylinder$2177": 0x803f2adc,
		"MarioUtil::@2192": 0x803f2b00,
		"MarioUtil::setup2$2191": 0x803f2b0c,
		"setup2$2191": 0x803f2b0c,
		"MarioUtil::@2197": 0x803f2b30,
		"MarioUtil::setup3$2196": 0x803f2b3c,
		"setup3$2196": 0x803f2b3c,
		"MarioUtil::@2209": 0x803f2b60,
		"MarioUtil::setup4$2208": 0x803f2b6c,
		"setup4$2208": 0x803f2b6c,
		"MarioUtil::@2218": 0x803f2b90,
		"MarioUtil::setup5$2217": 0x803f2b9c,
		"setup5$2217": 0x803f2b9c,
		"System::@2705": 0x803f3ef8,
		"System::@2706": 0x803f3f04,
		"System::@2707": 0x803f3f10,
		"System::@2708": 0x803f3f1c,
		"System::@2709": 0x803f3f28,
		"System::@2272": 0x803f3f5c,
		"System::@2273": 0x803f3f68,
		"System::@2274": 0x803f3f74,
		"System::@2275": 0x803f3f80,
		"System::@2276": 0x803f3f8c,
		"System::@2277": 0x803f3f98,
		"System::@2278": 0x803f3fa4,
		"System::@2279": 0x803f3fb0,
		"System::@2280": 0x803f3fbc,
		"System::@2281": 0x803f3fc8,
		"System::@2282": 0x803f3fd4,
		"System::@2283": 0x803f3fe0,
		"System::@2764": 0x803f40fc,
		"System::@2765": 0x803f4108,
		"System::@2766": 0x803f4114,
		"System::@2767": 0x803f4120,
		"System::@2768": 0x803f412c,
		"System::@2769": 0x803f4138,
		"System::@2770": 0x803f4144,
		"System::@2771": 0x803f4150,
		"System::@3428": 0x803f41cc,
		"System::@3431": 0x803f41f0,
		"System::@6138": 0x803f4284,
		"System::@6139": 0x803f4290,
		"System::@6140": 0x803f429c,
		"System::@6141": 0x803f42a8,
		"@6141": 0x803f42a8,
		"System::@6142": 0x803f42b4,
		"@6142": 0x803f42b4,
		"System::@6143": 0x803f42c0,
		"@6143": 0x803f42c0,
		"System::gParticleFlagLoaded": 0x803f4808,
		"gParticleFlagLoaded": 0x803f4808,
		"System::@2645": 0x803f4a0c,
		"System::@2646": 0x803f4a18,
		"System::@2647": 0x803f4a24,
		"System::@2648": 0x803f4a30,
		"Strategic::@2737": 0x803f29b8,
		"Strategic::@2738": 0x803f29c4,
		"Strategic::@2739": 0x803f29d0,
		"Strategic::@2740": 0x803f29dc,
		"Strategic::@2741": 0x803f29e8,
		"Strategic::@2742": 0x803f29f4,
		"Player::@2108": 0x803f2c2c,
		"Player::@2109": 0x803f2c38,
		"Player::@2112": 0x803f2c5c,
		"Player::@2113": 0x803f2c68,
		"Player::@2524": 0x803f2d9c,
		"Player::@2525": 0x803f2da8,
		"Player::@2526": 0x803f2db4,
		"Player::@2527": 0x803f2dc0,
		"Player::@2528": 0x803f2dcc,
		"Player::@3120": 0x803f2ee8,
		"Player::@3121": 0x803f2ef4,
		"Player::@3122": 0x803f2f00,
		"Player::@3123": 0x803f2f0c,
		"Player::@3126": 0x803f2f30,
		"Player::@3127": 0x803f2f3c,
		"Player::@3128": 0x803f2f48,
		"Player::@2772": 0x803f2fd0,
		"Player::@2773": 0x803f2fdc,
		"Player::@2774": 0x803f2fe8,
		"Player::@2775": 0x803f2ff4,
		"Player::@2776": 0x803f3000,
		"Player::@2777": 0x803f300c,
		"Player::@2790": 0x803f313c,
		"Player::@2791": 0x803f3148,
		"Player::@2792": 0x803f3154,
		"Player::@2793": 0x803f3160,
		"Player::@3455": 0x803f31f4,
		"Player::@3608": 0x803f3434,
		"Player::@6586": 0x803f39b8,
		"@6586": 0x803f39b8,
		"Player::@6587": 0x803f39c4,
		"@6587": 0x803f39c4,
		"Player::@6588": 0x803f39d0,
		"@6588": 0x803f39d0,
		"Player::@6589": 0x803f39dc,
		"Player::@6590": 0x803f39e8,
		"@6590": 0x803f39e8,
		"Player::@6591": 0x803f39f4,
		"@6591": 0x803f39f4,
		"Player::@6592": 0x803f3a00,
		"@6592": 0x803f3a00,
		"Player::@6593": 0x803f3a0c,
		"@6593": 0x803f3a0c,
		"Player::@6594": 0x803f3a18,
		"@6594": 0x803f3a18,
		"Player::@6595": 0x803f3a24,
		"@6595": 0x803f3a24,
		"Player::@6596": 0x803f3a30,
		"@6596": 0x803f3a30,
		"Player::@6597": 0x803f3a3c,
		"@6597": 0x803f3a3c,
		"Player::@2664": 0x803f3a48,
		"TModelWaterManager::mStaticHitActor": 0x803f3a54,
		"mStaticHitActor": 0x803f3a54,
		"Player::wcheck$2854": 0x803f3ac0,
		"wcheck$2854": 0x803f3ac0,
		"Player::@4749": 0x803f3aec,
		"Player::@4750": 0x803f3af8,
		"Player::@4751": 0x803f3b04,
		"Player::@4752": 0x803f3b10,
		"Player::@4753": 0x803f3b1c,
		"Player::@4754": 0x803f3b28,
		"Player::@4755": 0x803f3b34,
		"Player::@4756": 0x803f3b40,
		"Player::@4757": 0x803f3b4c,
		"Player::@4758": 0x803f3b58,
		"Player::@4759": 0x803f3b64,
		"Player::@4760": 0x803f3b70,
		"Player::@4761": 0x803f3b7c,
		"Player::@4762": 0x803f3b88,
		"Player::@4763": 0x803f3b94,
		"NPC::@2936": 0x803f2478,
		"NPC::@2937": 0x803f2484,
		"NPC::@2938": 0x803f2490,
		"NPC::@2939": 0x803f249c,
		"NPC::@2940": 0x803f24a8,
		"NPC::@2941": 0x803f24b4,
		"NPC::@2942": 0x803f24c0,
		"NPC::@2943": 0x803f24cc,
		"NPC::@2944": 0x803f24d8,
		"NPC::@2945": 0x803f24e4,
		"NPC::@2946": 0x803f24f0,
		"NPC::@2947": 0x803f24fc,
		"NPC::@2948": 0x803f2508,
		"NPC::@2949": 0x803f2514,
		"NPC::@2950": 0x803f2520,
		"NPC::@4339": 0x803f2530,
		"NPC::@4340": 0x803f253c,
		"NPC::@4341": 0x803f2548,
		"NPC::@4342": 0x803f2554,
		"NPC::@4343": 0x803f2560,
		"NPC::@4344": 0x803f256c,
		"NPC::@4345": 0x803f2578,
		"NPC::@4346": 0x803f2584,
		"NPC::@4347": 0x803f2590,
		"NPC::@4348": 0x803f259c,
		"NPC::@4349": 0x803f25a8,
		"NPC::@4350": 0x803f25b4,
		"NPC::@4351": 0x803f25c0,
		"NPC::@4352": 0x803f25cc,
		"NPC::@4353": 0x803f25d8,
		"NPC::@2244": 0x803f25f4,
		"NPC::@2252": 0x803f2600,
		"NPC::@2265": 0x803f260c,
		"NPC::@2304": 0x803f2624,
		"NPC::@2405": 0x803f2678,
		"NPC::@2415": 0x803f2684,
		"NPC::@2437": 0x803f269c,
		"NPC::@2640": 0x803f2714,
		"NPC::@2641": 0x803f2720,
		"NPC::@2642": 0x803f272c,
		"NPC::@2643": 0x803f2738,
		"NPC::@2644": 0x803f2744,
		"NPC::@2645": 0x803f2750,
		"NPC::@3044": 0x803f2760,
		"NPC::@3045": 0x803f276c,
		"NPC::@3046": 0x803f2778,
		"NPC::@3047": 0x803f2784,
		"NPC::@3048": 0x803f2790,
		"NPC::@3049": 0x803f279c,
		"NPC::@3050": 0x803f27a8,
		"NPC::@3051": 0x803f27b4,
		"NPC::@3052": 0x803f27c0,
		"NPC::@3053": 0x803f27cc,
		"NPC::@3054": 0x803f27d8,
		"NPC::@3055": 0x803f27e4,
		"NPC::@3056": 0x803f27f0,
		"NPC::@3057": 0x803f27fc,
		"NPC::@3058": 0x803f2808,
		"NPC::@2377": 0x803f2818,
		"NPC::@2378": 0x803f2824,
		"NPC::@2379": 0x803f2830,
		"NPC::@2380": 0x803f283c,
		"NPC::@2381": 0x803f2848,
		"NPC::@2382": 0x803f2854,
		"NPC::@2383": 0x803f2860,
		"NPC::@2384": 0x803f286c,
		"NPC::@2386": 0x803f2884,
		"NPC::@2387": 0x803f2890,
		"NPC::@2388": 0x803f289c,
		"NPC::@2389": 0x803f28a8,
		"NPC::@2390": 0x803f28b4,
		"MSBgm::smBgmInTrack": 0x803e1640,
		"smBgmInTrack": 0x803e1640,
		"MSound::@1961": 0x803e1778,
		"MSound::@1962": 0x803e1784,
		"MSound::@1963": 0x803e1790,
		"MSound::@1964": 0x803e179c,
		"MSound::@1965": 0x803e17a8,
		"MSound::_posByCamera": 0x803e17b8,
		"_posByCamera": 0x803e17b8,
		"MSound::@1969": 0x803e2470,
		"MSoundSESystem::MSRandVol::smList": 0x803e247c,
		"MSoundSESystem::MSRandPlay::smList": 0x803e2494,
		"MSound::@3189": 0x803e24a0,
		"MSound::@3190": 0x803e24ac,
		"MSound::@3191": 0x803e24b8,
		"MSound::@3192": 0x803e24c4,
		"MSound::@3193": 0x803e24d0,
		"MSound::@3194": 0x803e24dc,
		"MSound::@3195": 0x803e24e8,
		"MSound::@3196": 0x803e24f4,
		"MSound::@3197": 0x803e2500,
		"MSound::@3198": 0x803e250c,
		"MSound::@3199": 0x803e2518,
		"MSSetSound::smSetSound": 0x803e2558,
		"smSetSound": 0x803e2558,
		"MSound::@1932": 0x803e257c,
		"MSound::@1933": 0x803e2588,
		"MSound::@1934": 0x803e2594,
		"MSound::@1935": 0x803e25a0,
		"MSound::@1936": 0x803e25ac,
		"MSound::@1937": 0x803e25b8,
		"MSound::@1938": 0x803e25c4,
		"MSound::@1939": 0x803e25d0,
		"MSound::@1940": 0x803e25dc,
		"MSound::@1941": 0x803e25e8,
		"MSound::@1942": 0x803e25f4,
		"MSound::@1943": 0x803e2600,
		"MSound::@1944": 0x803e260c,
		"MSound::@2082": 0x803e2630,
		"MSound::@2083": 0x803e263c,
		"MSound::@2084": 0x803e2648,
		"MSound::@2085": 0x803e2654,
		"MSound::@2086": 0x803e2660,
		"MSound::@2087": 0x803e266c,
		"MSound::@2088": 0x803e2678,
		"MSound::@2089": 0x803e2684,
		"MSound::@2090": 0x803e2690,
		"MSound::@2091": 0x803e269c,
		"MSound::@2092": 0x803e26a8,
		"MSound::@2093": 0x803e26b4,
		"MSound::@2094": 0x803e26c0,
		"MSound::@2095": 0x803e26cc,
		"MSound::@2096": 0x803e26d8,
		"MSound::@1947": 0x803e2700,
		"MSound::@1948": 0x803e270c,
		"MSound::@1949": 0x803e2718,
		"MSound::@1950": 0x803e2724,
		"MoveBG::@4343": 0x803f0aac,
		"MoveBG::@4344": 0x803f0ab8,
		"MoveBG::@4345": 0x803f0ac4,
		"MoveBG::@4346": 0x803f0ad0,
		"MoveBG::@4347": 0x803f0adc,
		"MoveBG::@4348": 0x803f0ae8,
		"MoveBG::@4274": 0x803f0af8,
		"MoveBG::@4278": 0x803f0b28,
		"MoveBG::@4279": 0x803f0b34,
		"MoveBG::@4280": 0x803f0b40,
		"MoveBG::@4281": 0x803f0b4c,
		"MoveBG::@4282": 0x803f0b58,
		"MoveBG::@4286": 0x803f0b88,
		"MoveBG::submarineCranePos_forSound": 0x803f1000,
		"submarineCranePos_forSound": 0x803f1000,
		"MoveBG::submarineSetWtPos_forSound": 0x803f100c,
		"submarineSetWtPos_forSound": 0x803f100c,
		"MoveBG::@3531": 0x803f1030,
		"MoveBG::@3532": 0x803f103c,
		"MoveBG::@3533": 0x803f1048,
		"MoveBG::@3534": 0x803f1054,
		"MoveBG::@3535": 0x803f1060,
		"MoveBG::@3540": 0x803f109c,
		"MoveBG::@3541": 0x803f10a8,
		"MoveBG::@3542": 0x803f10b4,
		"MoveBG::@2483": 0x803f1240,
		"MoveBG::@2484": 0x803f124c,
		"MoveBG::@2485": 0x803f1258,
		"MoveBG::fall_upper_pos": 0x803f12f8,
		"fall_upper_pos": 0x803f12f8,
		"MoveBG::@4408": 0x803f13ac,
		"MoveBG::@2557": 0x803f1528,
		"MoveBG::@2558": 0x803f1534,
		"MoveBG::@2562": 0x803f1564,
		"MoveBG::@2563": 0x803f1570,
		"MoveBG::@2564": 0x803f157c,
		"MoveBG::@2565": 0x803f1588,
		"MoveBG::@2566": 0x803f1594,
		"MoveBG::@2567": 0x803f15a0,
		"MoveBG::@5478": 0x803f17e0,
		"MoveBG::@5479": 0x803f17ec,
		"MoveBG::@5480": 0x803f17f8,
		"MoveBG::up$2645": 0x803f18c0,
		"up$2645": 0x803f18c0,
		"MoveBG::up$2710": 0x803f18cc,
		"up$2710": 0x803f18cc,
		"MoveBG::@2741": 0x803f19c0,
		"MoveBG::@2743": 0x803f19d8,
		"MoveBG::@2745": 0x803f19f0,
		"MoveBG::@2746": 0x803f19fc,
		"MoveBG::@2747": 0x803f1a08,
		"MoveBG::@2751": 0x803f1a38,
		"TMapObjGrassManager::mDrawVec": 0x803f1a48,
		"mDrawVec": 0x803f1a48,
		"MoveBG::@2728": 0x803f1a6c,
		"MoveBG::@2729": 0x803f1a78,
		"MoveBG::@2731": 0x803f1a90,
		"MoveBG::@2732": 0x803f1a9c,
		"MoveBG::@2736": 0x803f1acc,
		"MoveBG::@2311": 0x803f1b08,
		"MoveBG::@2312": 0x803f1b14,
		"MoveBG::@2313": 0x803f1b20,
		"MoveBG::@2314": 0x803f1b2c,
		"MoveBG::@2315": 0x803f1b38,
		"MoveBG::@2316": 0x803f1b44,
		"MoveBG::@2317": 0x803f1b50,
		"MoveBG::@2318": 0x803f1b5c,
		"@2318": 0x803f1b5c,
		"MoveBG::@2319": 0x803f1b68,
		"MoveBG::@2320": 0x803f1b74,
		"MoveBG::@2321": 0x803f1b80,
		"MoveBG::@2322": 0x803f1b8c,
		"MoveBG::@2323": 0x803f1b98,
		"MoveBG::@2324": 0x803f1ba4,
		"MoveBG::@2325": 0x803f1bb0,
		"MoveBG::@3437": 0x803f1d20,
		"MoveBG::@6029": 0x803f21d4,
		"MoveBG::@6030": 0x803f21e0,
		"MoveBG::@6031": 0x803f21ec,
		"MoveBG::@6032": 0x803f21f8,
		"MoveBG::@6033": 0x803f2204,
		"MoveBG::@6034": 0x803f2210,
		"MoveBG::@6035": 0x803f221c,
		"MoveBG::@6036": 0x803f2228,
		"MoveBG::@6037": 0x803f2234,
		"MoveBG::@6038": 0x803f2240,
		"Map::@2345": 0x803ef040,
		"Map::@2417": 0x803ef0e0,
		"Map::@2418": 0x803ef0ec,
		"Map::@2419": 0x803ef0f8,
		"Map::@2519": 0x803ef108,
		"Map::@2520": 0x803ef114,
		"Map::@2522": 0x803ef12c,
		"Map::@2524": 0x803ef144,
		"Map::@2525": 0x803ef150,
		"Map::@2526": 0x803ef15c,
		"Map::@2527": 0x803ef168,
		"Map::pos$2895": 0x803ef1c0,
		"pos$2895": 0x803ef1c0,
		"Map::@2534": 0x803ef2b0,
		"Map::@2535": 0x803ef2bc,
		"Map::@2536": 0x803ef2c8,
		"Map::@2540": 0x803ef2f8,
		"Map::@2541": 0x803ef304,
		"Map::@2542": 0x803ef310,
		"Map::@2543": 0x803ef31c,
		"Map::@2544": 0x803ef328,
		"TMapCollisionData::mIllegalCheckData": 0x803ef338,
		"mIllegalCheckData": 0x803ef338,
		"Map::@2159": 0x803ef380,
		"Map::@2160": 0x803ef38c,
		"Map::@2161": 0x803ef398,
		"Map::@2162": 0x803ef3a4,
		"Map::@2163": 0x803ef3b0,
		"Map::@2164": 0x803ef3bc,
		"Map::@2165": 0x803ef3c8,
		"Map::@2166": 0x803ef3d4,
		"Map::@2171": 0x803ef410,
		"Map::@2172": 0x803ef41c,
		"Map::@2173": 0x803ef428,
		"Map::@2402": 0x803ef438,
		"Map::@2403": 0x803ef444,
		"Map::@2404": 0x803ef450,
		"Map::@2701": 0x803ef4fc,
		"Map::@2702": 0x803ef508,
		"Map::@2708": 0x803ef550,
		"Map::@2709": 0x803ef55c,
		"Map::@2710": 0x803ef568,
		"Map::@2712": 0x803ef580,
		"Map::@2713": 0x803ef58c,
		"Map::@2749": 0x803ef69c,
		"Map::@2750": 0x803ef6a8,
		"Map::@2751": 0x803ef6b4,
		"Map::@2752": 0x803ef6c0,
		"Map::@2753": 0x803ef6cc,
		"Map::@2754": 0x803ef6d8,
		"Map::@2755": 0x803ef6e4,
		"Map::@2756": 0x803ef6f0,
		"Map::@2757": 0x803ef6fc,
		"Map::@2758": 0x803ef708,
		"Map::@3295": 0x803ef730,
		"Map::@3296": 0x803ef73c,
		"Map::@3297": 0x803ef748,
		"Map::@3298": 0x803ef754,
		"Map::@3299": 0x803ef760,
		"Map::@3300": 0x803ef76c,
		"Map::@3301": 0x803ef778,
		"Map::@3302": 0x803ef784,
		"Map::@3303": 0x803ef790,
		"Map::@3304": 0x803ef79c,
		"Map::@3305": 0x803ef7a8,
		"Map::@2668": 0x803ef7d0,
		"Map::@2669": 0x803ef7dc,
		"Map::@2671": 0x803ef7f4,
		"Map::@2672": 0x803ef800,
		"Map::@2673": 0x803ef80c,
		"Map::@2684": 0x803ef8f4,
		"Map::@2688": 0x803ef924,
		"Map::@2689": 0x803ef930,
		"Map::@2358": 0x803ef9f8,
		"Map::@2359": 0x803efa04,
		"Map::@2360": 0x803efa10,
		"Map::@2361": 0x803efa1c,
		"Map::@2362": 0x803efa28,
		"Map::@2363": 0x803efa34,
		"Map::@2365": 0x803efa4c,
		"Map::@2366": 0x803efa58,
		"Map::@2367": 0x803efa64,
		"Map::@2369": 0x803efa7c,
		"Map::@2370": 0x803efa88,
		"Map::@2371": 0x803efa94,
		"Map::@2372": 0x803efaa0,
		"Map::@2938": 0x803efb1c,
		"Map::@2939": 0x803efb28,
		"Map::@2940": 0x803efb34,
		"Map::@2941": 0x803efb40,
		"Map::@2942": 0x803efb4c,
		"Map::@2943": 0x803efb58,
		"Map::@2584": 0x803efb8c,
		"Map::@2586": 0x803efba4,
		"Map::@2588": 0x803efbbc,
		"Map::@2589": 0x803efbc8,
		"Map::@2590": 0x803efbd4,
		"Map::@2591": 0x803efbe0,
		"Map::@2592": 0x803efbec,
		"Map::@2593": 0x803efbf8,
		"Map::@2594": 0x803efc04,
		"Map::@2615": 0x803efc20,
		"Map::@2616": 0x803efc2c,
		"Map::@2617": 0x803efc38,
		"Map::@2621": 0x803efc68,
		"Map::@2622": 0x803efc74,
		"Map::@2623": 0x803efc80,
		"Map::@2624": 0x803efc8c,
		"Map::@2625": 0x803efc98,
		"Map::@2626": 0x803efca4,
		"Map::@2627": 0x803efcb0,
		"Map::@2628": 0x803efcbc,
		"Map::@2629": 0x803efcc8,
		"Map::@3519": 0x803efcd8,
		"Map::@3520": 0x803efce4,
		"Map::@3521": 0x803efcf0,
		"Map::@3522": 0x803efcfc,
		"Map::@3523": 0x803efd08,
		"Map::@3524": 0x803efd14,
		"Map::@3525": 0x803efd20,
		"Map::@3526": 0x803efd2c,
		"Map::@3527": 0x803efd38,
		"Map::@3528": 0x803efd44,
		"Map::@3529": 0x803efd50,
		"Map::@3530": 0x803efd5c,
		"Map::@3531": 0x803efd68,
		"Map::@3532": 0x803efd74,
		"Map::@3533": 0x803efd80,
		"Map::@3240": 0x803efd9c,
		"Map::@3241": 0x803efda8,
		"Map::@3242": 0x803efdb4,
		"Map::@3243": 0x803efdc0,
		"Map::@3244": 0x803efdcc,
		"Map::@3245": 0x803efdd8,
		"Map::@3246": 0x803efde4,
		"Map::@3247": 0x803efdf0,
		"Map::@3248": 0x803efdfc,
		"Map::@3249": 0x803efe08,
		"Map::@3250": 0x803efe14,
		"Map::@3251": 0x803efe20,
		"Map::@3252": 0x803efe2c,
		"Map::@3253": 0x803efe38,
		"Map::@2743": 0x803efeb4,
		"Map::@2374": 0x803eff00,
		"Map::@2379": 0x803eff3c,
		"Map::@2380": 0x803eff48,
		"Map::@2381": 0x803eff54,
		"Map::@2382": 0x803eff60,
		"Map::@2383": 0x803eff6c,
		"Map::@2386": 0x803eff90,
		"Map::@2387": 0x803eff9c,
		"Map::@2388": 0x803effa8,
		"Map::@2867": 0x803f0070,
		"Map::pos$2426": 0x803f01e0,
		"pos$2426": 0x803f01e0,
		"Map::@3094": 0x803f0258,
		"Map::@3095": 0x803f0264,
		"Map::@3096": 0x803f0270,
		"Map::@3098": 0x803f0288,
		"Map::@3099": 0x803f0294,
		"Map::@3100": 0x803f02a0,
		"Map::@3101": 0x803f02ac,
		"Map::@2727": 0x803f0310,
		"Map::@2728": 0x803f031c,
		"Map::@2729": 0x803f0328,
		"Map::@2730": 0x803f0334,
		"Map::@2731": 0x803f0340,
		"Map::@2732": 0x803f034c,
		"Map::@2733": 0x803f0358,
		"Map::@2330": 0x803f03c8,
		"Map::@2658": 0x803f04e0,
		"Map::@2659": 0x803f04ec,
		"Map::@2660": 0x803f04f8,
		"Map::@2661": 0x803f0504,
		"Map::@2662": 0x803f0510,
		"Map::@2663": 0x803f051c,
		"Map::@2664": 0x803f0528,
		"Map::@3109": 0x803f0544,
		"Map::@3110": 0x803f0550,
		"Map::@3111": 0x803f055c,
		"Map::@3112": 0x803f0568,
		"Map::@3113": 0x803f0574,
		"Map::@3114": 0x803f0580,
		"Map::@3115": 0x803f058c,
		"Map::@3116": 0x803f0598,
		"Map::@3971": 0x803f05f0,
		"Map::@3972": 0x803f05fc,
		"Map::@3973": 0x803f0608,
		"Map::@3974": 0x803f0614,
		"Map::@3975": 0x803f0620,
		"Map::@3976": 0x803f062c,
		"Map::@3977": 0x803f0638,
		"Map::@3978": 0x803f0644,
		"Map::@3979": 0x803f0650,
		"Map::@3980": 0x803f065c,
		"Map::@3981": 0x803f0668,
		"Map::@3982": 0x803f0674,
		"Map::@3983": 0x803f0680,
		"Map::@3984": 0x803f068c,
		"Map::@3985": 0x803f0698,
		"GC2D::@2410": 0x803eb514,
		"GC2D::@2411": 0x803eb520,
		"GC2D::@2412": 0x803eb52c,
		"GC2D::@2413": 0x803eb538,
		"GC2D::@2414": 0x803eb544,
		"GC2D::@3388": 0x803eb700,
		"GC2D::@3389": 0x803eb70c,
		"GC2D::@3137": 0x803eb9e0,
		"GC2D::@3138": 0x803eb9ec,
		"GC2D::@3139": 0x803eb9f8,
		"GC2D::@3140": 0x803eba04,
		"GC2D::@3141": 0x803eba10,
		"GC2D::@3142": 0x803eba1c,
		"GC2D::@3143": 0x803eba28,
		"GC2D::@3144": 0x803eba34,
		"GC2D::@3145": 0x803eba40,
		"TSelectShineManager::cCenter": 0x803eba98,
		"cCenter": 0x803eba98,
		"GC2D::hx": 0x803ebb60,
		"hx": 0x803ebb60,
		"Enemy::@3176": 0x803e79d8,
		"Enemy::@3178": 0x803e79f0,
		"Enemy::@4335": 0x803e7a9c,
		"Enemy::@4336": 0x803e7aa8,
		"Enemy::@3909": 0x803e7adc,
		"Enemy::@3918": 0x803e7b48,
		"Enemy::@8477": 0x803e7e14,
		"@8477": 0x803e7e14,
		"Enemy::@8478": 0x803e7e20,
		"@8478": 0x803e7e20,
		"Enemy::@8479": 0x803e7e2c,
		"@8479": 0x803e7e2c,
		"Enemy::@8480": 0x803e7e38,
		"@8480": 0x803e7e38,
		"Enemy::@8481": 0x803e7e44,
		"@8481": 0x803e7e44,
		"Enemy::@8482": 0x803e7e50,
		"@8482": 0x803e7e50,
		"Enemy::@8483": 0x803e7e5c,
		"@8483": 0x803e7e5c,
		"Enemy::@8484": 0x803e7e68,
		"@8484": 0x803e7e68,
		"Enemy::@8485": 0x803e7e74,
		"@8485": 0x803e7e74,
		"Enemy::@8486": 0x803e7e80,
		"@8486": 0x803e7e80,
		"Enemy::@8487": 0x803e7e8c,
		"@8487": 0x803e7e8c,
		"Enemy::@8488": 0x803e7e98,
		"@8488": 0x803e7e98,
		"Enemy::@8489": 0x803e7ea4,
		"@8489": 0x803e7ea4,
		"Enemy::@8490": 0x803e7eb0,
		"@8490": 0x803e7eb0,
		"Enemy::@6476": 0x803e7f74,
		"@6476": 0x803e7f74,
		"Enemy::@6477": 0x803e7f80,
		"@6477": 0x803e7f80,
		"Enemy::@6480": 0x803e7fa4,
		"@6480": 0x803e7fa4,
		"Enemy::@6481": 0x803e7fb0,
		"@6481": 0x803e7fb0,
		"Enemy::@6482": 0x803e7fbc,
		"@6482": 0x803e7fbc,
		"Enemy::@6485": 0x803e7fe0,
		"@6485": 0x803e7fe0,
		"Enemy::@6486": 0x803e7fec,
		"@6486": 0x803e7fec,
		"Enemy::@6487": 0x803e7ff8,
		"@6487": 0x803e7ff8,
		"Enemy::@6488": 0x803e8004,
		"@6488": 0x803e8004,
		"Enemy::@6489": 0x803e8010,
		"@6489": 0x803e8010,
		"Enemy::@6490": 0x803e801c,
		"@6490": 0x803e801c,
		"Enemy::@4766": 0x803e81f0,
		"Enemy::@4767": 0x803e81fc,
		"Enemy::@4769": 0x803e8214,
		"Enemy::@2167": 0x803e8438,
		"Enemy::@5543": 0x803e880c,
		"@5543": 0x803e880c,
		"Enemy::@5544": 0x803e8818,
		"@5544": 0x803e8818,
		"Enemy::@5545": 0x803e8824,
		"@5545": 0x803e8824,
		"Enemy::@5546": 0x803e8830,
		"@5546": 0x803e8830,
		"Enemy::@5552": 0x803e8878,
		"@5552": 0x803e8878,
		"Enemy::@9728": 0x803e8918,
		"@9728": 0x803e8918,
		"Enemy::@9729": 0x803e8924,
		"@9729": 0x803e8924,
		"Enemy::@9730": 0x803e8930,
		"@9730": 0x803e8930,
		"Enemy::@9731": 0x803e893c,
		"@9731": 0x803e893c,
		"Enemy::@9732": 0x803e8948,
		"@9732": 0x803e8948,
		"Enemy::@9733": 0x803e8954,
		"@9733": 0x803e8954,
		"Enemy::@9734": 0x803e8960,
		"@9734": 0x803e8960,
		"Enemy::@9735": 0x803e896c,
		"@9735": 0x803e896c,
		"Enemy::@9736": 0x803e8978,
		"@9736": 0x803e8978,
		"Enemy::@9737": 0x803e8984,
		"@9737": 0x803e8984,
		"Enemy::@9738": 0x803e8990,
		"@9738": 0x803e8990,
		"Enemy::@9739": 0x803e899c,
		"@9739": 0x803e899c,
		"Enemy::@9740": 0x803e89a8,
		"@9740": 0x803e89a8,
		"Enemy::@8436": 0x803e8b5c,
		"Enemy::@8437": 0x803e8b68,
		"Enemy::@8438": 0x803e8b74,
		"Enemy::@8439": 0x803e8b80,
		"Enemy::@8440": 0x803e8b8c,
		"Enemy::@8441": 0x803e8b98,
		"Enemy::@8442": 0x803e8ba4,
		"Enemy::@8443": 0x803e8bb0,
		"@8443": 0x803e8bb0,
		"Enemy::@8444": 0x803e8bbc,
		"@8444": 0x803e8bbc,
		"Enemy::@8445": 0x803e8bc8,
		"@8445": 0x803e8bc8,
		"Enemy::@5229": 0x803e8cb8,
		"Enemy::@5235": 0x803e8d00,
		"Enemy::@5236": 0x803e8d0c,
		"Enemy::@5237": 0x803e8d18,
		"Enemy::TTinKoopa_jointIndexTable": 0x803e8d58,
		"TTinKoopa_jointIndexTable": 0x803e8d58,
		"Enemy::BW_BATH_POS": 0x803e8f30,
		"BW_BATH_POS": 0x803e8f30,
		"Enemy::BW_PICKET_START": 0x803e8f3c,
		"BW_PICKET_START": 0x803e8f3c,
		"Enemy::BW_HEAD_START": 0x803e8f48,
		"BW_HEAD_START": 0x803e8f48,
		"Enemy::@3239": 0x803e90f0,
		"Enemy::@4624": 0x803e92e8,
		"Enemy::@4625": 0x803e92f4,
		"Enemy::@4626": 0x803e9300,
		"Enemy::@4627": 0x803e930c,
		"Enemy::@4628": 0x803e9318,
		"Enemy::@4629": 0x803e9324,
		"Enemy::@4630": 0x803e9330,
		"Enemy::@4631": 0x803e933c,
		"Enemy::@4632": 0x803e9348,
		"Enemy::@4633": 0x803e9354,
		"Enemy::@4634": 0x803e9360,
		"Enemy::@5309": 0x803e9454,
		"Enemy::@5310": 0x803e9460,
		"Enemy::@5311": 0x803e946c,
		"Enemy::@5312": 0x803e9478,
		"Enemy::@5313": 0x803e9484,
		"Enemy::@5314": 0x803e9490,
		"Enemy::@9237": 0x803e9548,
		"@9237": 0x803e9548,
		"Enemy::@9238": 0x803e9554,
		"@9238": 0x803e9554,
		"Enemy::@9239": 0x803e9560,
		"@9239": 0x803e9560,
		"Enemy::@9240": 0x803e956c,
		"@9240": 0x803e956c,
		"Enemy::@9241": 0x803e9578,
		"@9241": 0x803e9578,
		"Enemy::@9242": 0x803e9584,
		"@9242": 0x803e9584,
		"Enemy::@9243": 0x803e9590,
		"@9243": 0x803e9590,
		"Enemy::@9244": 0x803e959c,
		"@9244": 0x803e959c,
		"Enemy::@9245": 0x803e95a8,
		"@9245": 0x803e95a8,
		"Enemy::@9246": 0x803e95b4,
		"@9246": 0x803e95b4,
		"Enemy::@9247": 0x803e95c0,
		"@9247": 0x803e95c0,
		"Enemy::@9248": 0x803e95cc,
		"@9248": 0x803e95cc,
		"Enemy::@9249": 0x803e95d8,
		"@9249": 0x803e95d8,
		"Enemy::@9250": 0x803e95e4,
		"@9250": 0x803e95e4,
		"Enemy::@4274": 0x803e9714,
		"Enemy::@4275": 0x803e9720,
		"Enemy::@4280": 0x803e975c,
		"Enemy::@6269": 0x803e9840,
		"@6269": 0x803e9840,
		"Enemy::@6270": 0x803e984c,
		"@6270": 0x803e984c,
		"Enemy::@6271": 0x803e9858,
		"@6271": 0x803e9858,
		"Enemy::@6272": 0x803e9864,
		"@6272": 0x803e9864,
		"Enemy::@6273": 0x803e9870,
		"@6273": 0x803e9870,
		"Enemy::@6274": 0x803e987c,
		"@6274": 0x803e987c,
		"Enemy::@6275": 0x803e9888,
		"@6275": 0x803e9888,
		"Enemy::@6276": 0x803e9894,
		"@6276": 0x803e9894,
		"Enemy::@6277": 0x803e98a0,
		"@6277": 0x803e98a0,
		"Enemy::@9463": 0x803e9a0c,
		"@9463": 0x803e9a0c,
		"Enemy::@9464": 0x803e9a18,
		"@9464": 0x803e9a18,
		"Enemy::@9465": 0x803e9a24,
		"@9465": 0x803e9a24,
		"Enemy::@9466": 0x803e9a30,
		"@9466": 0x803e9a30,
		"Enemy::@9467": 0x803e9a3c,
		"@9467": 0x803e9a3c,
		"Enemy::@9468": 0x803e9a48,
		"@9468": 0x803e9a48,
		"Enemy::@9469": 0x803e9a54,
		"@9469": 0x803e9a54,
		"Enemy::@4652": 0x803e9acc,
		"Enemy::@4654": 0x803e9ae4,
		"Enemy::@5453": 0x803e9d04,
		"Enemy::@5454": 0x803e9d10,
		"Enemy::@5455": 0x803e9d1c,
		"Enemy::@2265": 0x803e9d80,
		"Enemy::up$2718": 0x803e9d98,
		"up$2718": 0x803e9d98,
		"Enemy::up$2732": 0x803e9da4,
		"up$2732": 0x803e9da4,
		"Enemy::@4906": 0x803e9e80,
		"Enemy::@2400": 0x803e9f68,
		"Enemy::@2409": 0x803e9f74,
		"Enemy::@2647": 0x803e9f8c,
		"Enemy::@2648": 0x803e9f98,
		"Enemy::@2649": 0x803e9fa4,
		"Enemy::@2650": 0x803e9fb0,
		"Enemy::@2651": 0x803e9fbc,
		"Enemy::@2652": 0x803e9fc8,
		"Enemy::@2653": 0x803e9fd4,
		"Enemy::@3818": 0x803ea058,
		"Enemy::@3819": 0x803ea064,
		"Enemy::@3820": 0x803ea070,
		"Enemy::@2732": 0x803ea324,
		"Enemy::@2733": 0x803ea330,
		"Enemy::@2734": 0x803ea33c,
		"Enemy::@2735": 0x803ea348,
		"Enemy::@2736": 0x803ea354,
		"Enemy::@2737": 0x803ea360,
		"Enemy::@2738": 0x803ea36c,
		"Enemy::@2739": 0x803ea378,
		"Enemy::@2742": 0x803ea39c,
		"Enemy::@3272": 0x803ea424,
		"Enemy::@3273": 0x803ea430,
		"Enemy::@6698": 0x803ea590,
		"@6698": 0x803ea590,
		"Enemy::@6699": 0x803ea59c,
		"@6699": 0x803ea59c,
		"Enemy::@6700": 0x803ea5a8,
		"@6700": 0x803ea5a8,
		"Enemy::@6701": 0x803ea5b4,
		"@6701": 0x803ea5b4,
		"Enemy::@6702": 0x803ea5c0,
		"@6702": 0x803ea5c0,
		"Enemy::@6703": 0x803ea5cc,
		"@6703": 0x803ea5cc,
		"Enemy::@6704": 0x803ea5d8,
		"@6704": 0x803ea5d8,
		"Enemy::@6705": 0x803ea5e4,
		"Enemy::@6706": 0x803ea5f0,
		"Enemy::@6707": 0x803ea5fc,
		"@6707": 0x803ea5fc,
		"Enemy::@6708": 0x803ea608,
		"@6708": 0x803ea608,
		"Enemy::@4140": 0x803ea7f0,
		"Enemy::@5909": 0x803eaad4,
		"Enemy::@5910": 0x803eaae0,
		"Enemy::@5911": 0x803eaaec,
		"Enemy::@5912": 0x803eaaf8,
		"Enemy::@5913": 0x803eab04,
		"Enemy::@5914": 0x803eab10,
		"Enemy::@5916": 0x803eab28,
		"Enemy::@5917": 0x803eab34,
		"Enemy::TKoopaJr_jointIndexTable": 0x803eac78,
		"TKoopaJr_jointIndexTable": 0x803eac78,
		"Enemy::@4842": 0x803eaf88,
		"Enemy::@4845": 0x803eafac,
		"Enemy::@4846": 0x803eafb8,
		"Enemy::@4847": 0x803eafc4,
		"Enemy::@4850": 0x803eafe8,
		"Enemy::@4851": 0x803eaff4,
		"Enemy::@4981": 0x803eb46c,
		"Camera::@3186": 0x803e7688,
		"Camera::@3187": 0x803e7694,
		"Camera::@3188": 0x803e76a0,
		"Camera::@3189": 0x803e76ac,
		"Camera::@3190": 0x803e76b8,
		"Camera::@3191": 0x803e76c4,
		"Camera::@3192": 0x803e76d0,
		"Camera::@3193": 0x803e76dc,
		"Camera::@3194": 0x803e76e8,
		"Camera::@3195": 0x803e76f4,
		"Camera::@3196": 0x803e7700,
		"Camera::@3197": 0x803e770c,
		"Camera::@3198": 0x803e7718,
		"Camera::CLBConstUpVec": 0x803e7728,
		"CLBConstUpVec": 0x803e7728,
		"Camera::@2254": 0x803e77e0,
		"Camera::@2284": 0x803e785c,
		"Camera::@2285": 0x803e7868,
		"Camera::@2286": 0x803e7874,
		"@2286": 0x803e7874,
		"Camera::@2287": 0x803e7880,
		"Camera::@2288": 0x803e788c,
		"@2288": 0x803e788c,
		"Camera::@2289": 0x803e7898,
		"Animal::@3346": 0x803e1120,
		"Animal::@3348": 0x803e1138,
		"Animal::@3349": 0x803e1144,
		"Animal::@3350": 0x803e1150,
		"Animal::@3351": 0x803e115c,
		"Animal::@3352": 0x803e1168,
		"Animal::@3353": 0x803e1174,
		"Animal::@3354": 0x803e1180,
		"Animal::@3355": 0x803e118c,
		"Animal::@3356": 0x803e1198,
		"Animal::@3357": 0x803e11a4,
		"Animal::@3358": 0x803e11b0,
		"Animal::@3359": 0x803e11bc,
		"Animal::@3360": 0x803e11c8,
		"Animal::@2617": 0x803e11e4,
		"Animal::@2618": 0x803e11f0,
		"Animal::@2619": 0x803e11fc,
		"Animal::@2620": 0x803e1208,
		"Animal::@2621": 0x803e1214,
		"Animal::@2622": 0x803e1220,
		"Animal::@2623": 0x803e122c,
		"Animal::@2624": 0x803e1238,
		"Animal::@2625": 0x803e1244,
		"Animal::@2626": 0x803e1250,
		"Animal::@2629": 0x803e1274,
		"Animal::@2630": 0x803e1280,
		"Animal::@2001": 0x803e1290,
		"Animal::@3026": 0x803e12a0,
		"Animal::@3041": 0x803e12ac,
		"Animal::@3056": 0x803e12b8,
		"Animal::@3068": 0x803e12c4,
		"Animal::@3078": 0x803e12d0,
		"Animal::@3097": 0x803e12dc,
		"Animal::@3105": 0x803e12e8,
		"Animal::@3117": 0x803e12f4,
		"Animal::@3129": 0x803e1300,
		"Animal::@4981": 0x803e130c,
		"Animal::@4982": 0x803e1318,
		"Animal::@4983": 0x803e1324,
		"Animal::@4984": 0x803e1330,
		"Animal::@4985": 0x803e133c,
		"Animal::@4986": 0x803e1348,
		"Animal::@4987": 0x803e1354,
		"Animal::@4988": 0x803e1360,
		"Animal::@4989": 0x803e136c,
		"Animal::@4990": 0x803e1378,
		"Animal::@4991": 0x803e1384,
		"Animal::@4992": 0x803e1390,
		"Animal::@4994": 0x803e13a8,
		"Animal::@4995": 0x803e13b4,
		"Animal::@2990": 0x803e13c0,
		"Animal::@3004": 0x803e13cc,
		"Animal::@3014": 0x803e13d8,
		"Animal::@3036": 0x803e13f0,
		"Animal::@3048": 0x803e13fc,
		"Animal::@5213": 0x803e1408,
		"Animal::@5214": 0x803e1414,
		"Animal::@5215": 0x803e1420,
		"Animal::@5216": 0x803e142c,
		"Animal::@5217": 0x803e1438,
		"Animal::@5218": 0x803e1444,
		"Animal::@5219": 0x803e1450,
		"Animal::@5220": 0x803e145c,
		"Animal::@5221": 0x803e1468,
		"Animal::@5222": 0x803e1474,
		"Animal::@5223": 0x803e1480,
		"Animal::@5224": 0x803e148c,
		"Animal::@5225": 0x803e1498,
		"Animal::@5226": 0x803e14a4,
		"Animal::@5227": 0x803e14b0,
		"Animal::@2422": 0x803e14c0,
		"JKRAramHeap::sAramList": 0x803fba30,
		"sAramList": 0x803fba30,
		"JKRAram::sAramCommandList": 0x803fba3c,
		"sAramCommandList": 0x803fba3c,
		"JKRDvdFile::sDvdList": 0x803fba48,
		"sDvdList": 0x803fba48,
		"JKRFileLoader::sVolumeList": 0x803fba54,
		"sVolumeList": 0x803fba54,
		"JKRThread::sThreadList": 0x803fba60,
		"sThreadList": 0x803fba60,
		"JUTException::sMapFileList": 0x803fba6c,
		"sMapFileList": 0x803fba6c,
		"JUTGamePad::mPadList": 0x803fba78,
		"mPadList": 0x803fba78,
		"JUTGamePad::mPadStatus": 0x803fbbf4,
		"mPadStatus": 0x803fbbf4,
		"JUTGamePad::mPadButton": 0x803fbc24,
		"mPadButton": 0x803fbc24,
		"JUTGamePad::mPadMStick": 0x803fbce4,
		"mPadMStick": 0x803fbce4,
		"JUTGamePad::mPadSStick": 0x803fbd24,
		"mPadSStick": 0x803fbd24,
		"J2DPrint::mMutex": 0x803fbd64,
		"JSystem::j3dSys": 0x803fbd7c,
		"j3dSys": 0x803fbd7c,
		"J3DSys::mCurrentMtx": 0x803fbf28,
		"mCurrentMtx": 0x803fbf28,
		"J3DSys::mCurrentS": 0x803fbf58,
		"mCurrentS": 0x803fbf58,
		"J3DSys::mParentS": 0x803fbf64,
		"mParentS": 0x803fbf64,
		"J3DSys::sTexCoordScaleTable": 0x803fbf70,
		"sTexCoordScaleTable": 0x803fbf70,
		"JKRDvdRipper::sDvdAsyncList": 0x803fbfb0,
		"sDvdAsyncList": 0x803fbfb0,
		"JKRDvdAramRipper::sDvdAramAsyncList": 0x803fbfbc,
		"sDvdAramAsyncList": 0x803fbfbc,
		"JSystem::j3dTexCoordTable": 0x803fbfc8,
		"j3dTexCoordTable": 0x803fbfc8,
		"JSystem::j3dTevSwapTableTable": 0x803fe4f0,
		"j3dTevSwapTableTable": 0x803fe4f0,
		"JSystem::j3dAlphaCmpTable": 0x803fe8f0,
		"j3dAlphaCmpTable": 0x803fe8f0,
		"JSystem::j3dZModeTable": 0x803febf0,
		"j3dZModeTable": 0x803febf0,
		"JKRAramPiece::sAramPieceCommandList": 0x803fec50,
		"sAramPieceCommandList": 0x803fec50,
		"JKRAramPiece::mMutex": 0x803fec74,
		"JSystem::JAInullCamera": 0x803fec8c,
		"JAInullCamera": 0x803fec8c,
		"JAIConst::nullActor": 0x803fec98,
		"nullActor": 0x803fec98,
		"JAIConst::camMtx": 0x803fecf0,
		"camMtx": 0x803fecf0,
		"JAIConst::camTrans": 0x803fed20,
		"camTrans": 0x803fed20,
		"JAIConst::camPreTrans": 0x803fed2c,
		"camPreTrans": 0x803fed2c,
		"JAInter::StreamLib::streamHeap": 0x803fed38,
		"streamHeap": 0x803fed38,
		"JAISystemInterface::systemPortCmd": 0x803fed4c,
		"systemPortCmd": 0x803fed4c,
		"JASystem::TTrack::sParser": 0x804036c0,
		"sParser": 0x804036c0,
		"JPADraw::vc": 0x804036c4,
		"vc": 0x804036c4,
		"JPADraw::cb": 0x804038b0,
		"Camera::cCameraBckNameShineGetInside": 0x80403988,
		"Camera::cCameraBckNameShineGetOutside": 0x8040398c,
		"Camera::cCameraBckNameGate": 0x80403990,
		"Camera::cSunVolumeName": 0x804039b8,
		"Camera::cSunsetVolumeName": 0x804039bc,
		"Enemy::idx$3338": 0x80403a60,
		"idx$3338": 0x80403a60,
		"Enemy::loopIndirectFilenames$3524": 0x80403acc,
		"loopIndirectFilenames$3524": 0x80403acc,
		"Enemy::anmlist$3310": 0x80403af8,
		"anmlist$3310": 0x80403af8,
		"Enemy::graphlist$3316": 0x80403b00,
		"graphlist$3316": 0x80403b00,
		"Enemy::onetimeFilenames$3164": 0x80403c9c,
		"onetimeFilenames$3164": 0x80403c9c,
		"Enemy::@2526": 0x80403cd4,
		"Enemy::@2527": 0x80403cd8,
		"Enemy::loopFilenames$3194": 0x80403d70,
		"loopFilenames$3194": 0x80403d70,
		"GC2D::scDolpicNewsDolpic8_Ac4": 0x80403db8,
		"scDolpicNewsDolpic8_Ac4": 0x80403db8,
		"GC2D::scDolpicNewsDolpic8_Cc4": 0x80403dc0,
		"scDolpicNewsDolpic8_Cc4": 0x80403dc0,
		"GC2D::scDolpicNewsDolpic8_Da4": 0x80403dc8,
		"scDolpicNewsDolpic8_Da4": 0x80403dc8,
		"GC2D::scDolpicNewsDolpic8_Db4": 0x80403dd0,
		"scDolpicNewsDolpic8_Db4": 0x80403dd0,
		"GC2D::scDolpicNewsDolpic8_Dc1": 0x80403dd8,
		"scDolpicNewsDolpic8_Dc1": 0x80403dd8,
		"GC2D::scDolpicNewsDolpic8_Dc3": 0x80403de0,
		"scDolpicNewsDolpic8_Dc3": 0x80403de0,
		"TCardLoad::cToOptionFileName": 0x80403de8,
		"cToOptionFileName": 0x80403de8,
		"TCardLoad::cBMarkNewFileName": 0x80403dec,
		"cBMarkNewFileName": 0x80403dec,
		"TCardLoad::cWindowYesFileName": 0x80403df0,
		"cWindowYesFileName": 0x80403df0,
		"TCardLoad::cWindowNoFileName": 0x80403df4,
		"cWindowNoFileName": 0x80403df4,
		"TCardLoad::cScoreTotalFileName": 0x80403df8,
		"cScoreTotalFileName": 0x80403df8,
		"GC2D::mag$265": 0x80403e1c,
		"mag$265": 0x80403e1c,
		"MoveBG::rotate_frame_rate": 0x80404010,
		"rotate_frame_rate": 0x80404010,
		"System::sShineViewObjName$3422": 0x80404348,
		"sShineViewObjName$3422": 0x80404348,
		"System::stages$3013": 0x80404350,
		"stages$3013": 0x80404350,
		"JSystem::rootPath$1763": 0x80404360,
		"rootPath$1763": 0x80404360,
		"JUTException::sMessageBuffer": 0x80404368,
		"JUTGamePad::mStickMode": 0x80404370,
		"mStickMode": 0x80404370,
		"JUTGamePad::C3ButtonReset::sResetPattern": 0x80404374,
		"sResetPattern": 0x80404374,
		"JSystem::Unit01": 0x80404378,
		"JSystem::J3DUnit01": 0x80404380,
		"J3DUnit01": 0x80404380,
		"JKRDvdRipper::szpBufferSize": 0x8040438c,
		"JKRDvdAramRipper::szpBufferSize": 0x80404394,
		"JSystem::GXTexMode0Ids": 0x80404398,
		"GXTexMode0Ids": 0x80404398,
		"JSystem::GXTexMode1Ids": 0x804043a0,
		"GXTexMode1Ids": 0x804043a0,
		"JSystem::GXTexImage0Ids": 0x804043a8,
		"GXTexImage0Ids": 0x804043a8,
		"JSystem::GXTexImage1Ids": 0x804043b0,
		"GXTexImage1Ids": 0x804043b0,
		"JSystem::GXTexImage2Ids": 0x804043b8,
		"GXTexImage2Ids": 0x804043b8,
		"JSystem::GXTexImage3Ids": 0x804043c0,
		"GXTexImage3Ids": 0x804043c0,
		"JSystem::GXTexTlutIds": 0x804043c8,
		"GXTexTlutIds": 0x804043c8,
		"JSystem::GX2HWFiltConv": 0x804043d0,
		"JSystem::j3dDefaultColInfo": 0x804043d8,
		"j3dDefaultColInfo": 0x804043d8,
		"JSystem::j3dDefaultAmbInfo": 0x804043dc,
		"j3dDefaultAmbInfo": 0x804043dc,
		"JSystem::j3dDefaultTevOrderInfoNull": 0x804043e4,
		"j3dDefaultTevOrderInfoNull": 0x804043e4,
		"JSystem::j3dDefaultIndTexOrderNull": 0x804043e8,
		"j3dDefaultIndTexOrderNull": 0x804043e8,
		"JSystem::j3dDefaultTevColor": 0x804043ec,
		"j3dDefaultTevColor": 0x804043ec,
		"JSystem::j3dDefaultIndTexCoordScaleInfo": 0x804043f4,
		"j3dDefaultIndTexCoordScaleInfo": 0x804043f4,
		"JSystem::j3dDefaultTevKColor": 0x804043f8,
		"j3dDefaultTevKColor": 0x804043f8,
		"JSystem::j3dDefaultTevSwapMode": 0x804043fc,
		"j3dDefaultTevSwapMode": 0x804043fc,
		"JSystem::j3dDefaultTevSwapModeTable": 0x80404400,
		"j3dDefaultTevSwapModeTable": 0x80404400,
		"JSystem::j3dDefaultBlendInfo": 0x80404404,
		"j3dDefaultBlendInfo": 0x80404404,
		"JSystem::j3dDefaultColorChanInfo": 0x80404408,
		"j3dDefaultColorChanInfo": 0x80404408,
		"JSystem::JRNTexImage1Ids": 0x80404420,
		"JRNTexImage1Ids": 0x80404420,
		"JSystem::JRNTexImage2Ids": 0x80404428,
		"JRNTexImage2Ids": 0x80404428,
		"JALCalc::cEqualCSlope": 0x80404430,
		"cEqualCSlope": 0x80404430,
		"JALCalc::cPlusPSlope": 0x80404434,
		"cPlusPSlope": 0x80404434,
		"JAInter::TAsnData::asnFileName": 0x80404438,
		"asnFileName": 0x80404438,
		"JAInter::StreamLib::LOOP_BLOCKS": 0x80404440,
		"LOOP_BLOCKS": 0x80404440,
		"JAInter::StreamLib::LOOP_SAMPLESIZE": 0x80404444,
		"LOOP_SAMPLESIZE": 0x80404444,
		"JAInter::StreamLib::outputmode": 0x80404448,
		"outputmode": 0x80404448,
		"JAIGlobalParameter::soundSceneMax": 0x80404458,
		"soundSceneMax": 0x80404458,
		"JAIGlobalParameter::seRegistMax": 0x8040445c,
		"seRegistMax": 0x8040445c,
		"JAIGlobalParameter::seTrackMax": 0x80404460,
		"seTrackMax": 0x80404460,
		"JAIGlobalParameter::seqTrackMax": 0x80404464,
		"seqTrackMax": 0x80404464,
		"JAIGlobalParameter::seqPlayTrackMax": 0x80404468,
		"seqPlayTrackMax": 0x80404468,
		"JAIGlobalParameter::seqControlBufferMax": 0x8040446c,
		"seqControlBufferMax": 0x8040446c,
		"JAIGlobalParameter::streamControlBufferMax": 0x80404470,
		"streamControlBufferMax": 0x80404470,
		"JAIGlobalParameter::streamParameterBufferMax": 0x80404474,
		"streamParameterBufferMax": 0x80404474,
		"JAIGlobalParameter::autoHeapMax": 0x80404478,
		"autoHeapMax": 0x80404478,
		"JAIGlobalParameter::stayHeapMax": 0x8040447c,
		"stayHeapMax": 0x8040447c,
		"JAIGlobalParameter::autoHeapRoomSize": 0x80404480,
		"autoHeapRoomSize": 0x80404480,
		"JAIGlobalParameter::stayHeapSize": 0x80404484,
		"stayHeapSize": 0x80404484,
		"JAIGlobalParameter::seInfoFileName": 0x80404488,
		"seInfoFileName": 0x80404488,
		"JAIGlobalParameter::seqInfoFileName": 0x8040448c,
		"seqInfoFileName": 0x8040448c,
		"JAIGlobalParameter::streamInfoFileName": 0x80404490,
		"streamInfoFileName": 0x80404490,
		"JAIGlobalParameter::initDataFileName": 0x80404494,
		"initDataFileName": 0x80404494,
		"JAIGlobalParameter::wavePath": 0x80404498,
		"wavePath": 0x80404498,
		"JAIGlobalParameter::sequenceArchivesPath": 0x8040449c,
		"sequenceArchivesPath": 0x8040449c,
		"JAIGlobalParameter::streamPath": 0x804044a0,
		"streamPath": 0x804044a0,
		"JAIGlobalParameter::sequenceArchivesFileName": 0x804044a4,
		"sequenceArchivesFileName": 0x804044a4,
		"JAIGlobalParameter::inputGainDown": 0x804044a8,
		"inputGainDown": 0x804044a8,
		"JAIGlobalParameter::outputGainUp": 0x804044ac,
		"outputGainUp": 0x804044ac,
		"JAIGlobalParameter::distanceMax": 0x804044b0,
		"distanceMax": 0x804044b0,
		"JAIGlobalParameter::maxVolumeDistance": 0x804044b4,
		"maxVolumeDistance": 0x804044b4,
		"JAIGlobalParameter::seDolbyCenterValue": 0x804044b8,
		"seDolbyCenterValue": 0x804044b8,
		"JAIGlobalParameter::seDolbyFrontDistanceMax": 0x804044bc,
		"seDolbyFrontDistanceMax": 0x804044bc,
		"JAIGlobalParameter::seDolbyBehindDistanceMax": 0x804044c0,
		"seDolbyBehindDistanceMax": 0x804044c0,
		"JAIGlobalParameter::dopplarMoveTime": 0x804044c4,
		"dopplarMoveTime": 0x804044c4,
		"JAIGlobalParameter::dummyPositionMax": 0x804044c8,
		"dummyPositionMax": 0x804044c8,
		"JAIGlobalParameter::seqMuteMoveSpeedSePlay": 0x804044cc,
		"seqMuteMoveSpeedSePlay": 0x804044cc,
		"JAIGlobalParameter::audioCameraMax": 0x804044d0,
		"audioCameraMax": 0x804044d0,
		"JAIGlobalParameter::systemTrackMax": 0x804044d4,
		"systemTrackMax": 0x804044d4,
		"JAIGlobalParameter::systemRootTrackMax": 0x804044d8,
		"systemRootTrackMax": 0x804044d8,
		"JAIGlobalParameter::panDistanceMax": 0x804044dc,
		"panDistanceMax": 0x804044dc,
		"JAIGlobalParameter::panDistance2Max": 0x804044e0,
		"panDistance2Max": 0x804044e0,
		"JAIGlobalParameter::panAngleParameter": 0x804044e4,
		"panAngleParameter": 0x804044e4,
		"JAIGlobalParameter::panAngleParameter2": 0x804044e8,
		"panAngleParameter2": 0x804044e8,
		"JAIGlobalParameter::dopplarParameter": 0x804044ec,
		"dopplarParameter": 0x804044ec,
		"JAIGlobalParameter::seDistancepitchMax": 0x804044f4,
		"seDistancepitchMax": 0x804044f4,
		"JASystem::Driver::DSPQueue::waitMax": 0x804044f8,
		"waitMax": 0x804044f8,
		"JASystem::Driver::JAS_SYSTEM_OUTPUT_MODE": 0x80404504,
		"JAS_SYSTEM_OUTPUT_MODE": 0x80404504,
		"JASystem::Driver::DSP_VOICE_WAITS_MAX": 0x8040450c,
		"DSP_VOICE_WAITS_MAX": 0x8040450c,
		"JASystem::TDSPChannel::smnFree": 0x80404510,
		"smnFree": 0x80404510,
		"JASystem::DSP_LIMIT_RATIO": 0x80404514,
		"DSP_LIMIT_RATIO": 0x80404514,
		"JSystem::COMP_BLOCKSAMPLES$234": 0x8040451c,
		"COMP_BLOCKSAMPLES$234": 0x8040451c,
		"JSystem::COMP_BLOCKBYTES$235": 0x80404524,
		"COMP_BLOCKBYTES$235": 0x80404524,
		"JASystem::Kernel::maxCallbacksUser": 0x80404530,
		"maxCallbacksUser": 0x80404530,
		"JASystem::Dvd::dvdMsgsSize": 0x80404538,
		"dvdMsgsSize": 0x80404538,
		"JASystem::Dvd::dvdBufSize": 0x8040453c,
		"dvdBufSize": 0x8040453c,
		"JASystem::Dvd::maxDics": 0x80404540,
		"maxDics": 0x80404540,
		"JASystem::HardStream::playListMax": 0x80404548,
		"playListMax": 0x80404548,
		"JASystem::Kernel::gDacRate": 0x80404550,
		"gDacRate": 0x80404550,
		"JASystem::Kernel::gSubFrames": 0x80404554,
		"gSubFrames": 0x80404554,
		"JASystem::Kernel::gFrameSamples": 0x80404558,
		"gFrameSamples": 0x80404558,
		"JASystem::Kernel::gDacSize": 0x8040455c,
		"gDacSize": 0x8040455c,
		"JASystem::Kernel::audioDramSize": 0x80404560,
		"audioDramSize": 0x80404560,
		"JASystem::Kernel::audioAramSize": 0x80404564,
		"audioAramSize": 0x80404564,
		"JASystem::Vload::vlMaxArcs": 0x80404568,
		"vlMaxArcs": 0x80404568,
		"JASystem::Player::sV0": 0x80404570,
		"sV0": 0x80404570,
		"JASystem::Player::sV1": 0x80404574,
		"sV1": 0x80404574,
		"Runtime.PPCEABI.H::fragmentID": 0x80404580,
		"fragmentID": 0x80404580,
		"MSL_C.PPCEABI.bare.H::@wstringBase0": 0x80404588,
		"@wstringBase0": 0x80404588,
		"MSL_C.PPCEABI.bare.H::next": 0x80404590,
		"MSL_C.PPCEABI.bare.H::K1": 0x80404598,
		"K1": 0x80404598,
		"MSL_C.PPCEABI.bare.H::K2": 0x8040459c,
		"K2": 0x8040459c,
		"os::__OSCurrHeap": 0x804045a0,
		"__OSCurrHeap": 0x804045a0,
		"os::__OSArenaLo": 0x804045a8,
		"__OSArenaLo": 0x804045a8,
		"os::@32": 0x804045b0,
		"mtx::Unit01": 0x804045c0,
		"dvd::FirstRead": 0x804045c8,
		"FirstRead": 0x804045c8,
		"dvd::@116": 0x804045d0,
		"dvd::autoInvalidation": 0x804045d8,
		"autoInvalidation": 0x804045d8,
		"dvd::@35": 0x804045e0,
		"dvd::@40": 0x804045e4,
		"dvd::@41": 0x804045e8,
		"pad::ClampRegion": 0x804045f0,
		"ClampRegion": 0x804045f0,
		"pad::ResettingChan": 0x804045f8,
		"ResettingChan": 0x804045f8,
		"pad::XPatchBits": 0x804045fc,
		"XPatchBits": 0x804045fc,
		"pad::AnalogMode": 0x80404600,
		"AnalogMode": 0x80404600,
		"pad::Spec": 0x80404604,
		"Spec": 0x80404604,
		"pad::MakeStatus": 0x80404608,
		"MakeStatus": 0x80404608,
		"pad::CmdReadOrigin": 0x8040460c,
		"CmdReadOrigin": 0x8040460c,
		"pad::CmdCalibrate": 0x80404610,
		"CmdCalibrate": 0x80404610,
		"card::next": 0x80404618,
		"gx::gx": 0x80404628,
		"gx::tbl1$215": 0x80404630,
		"tbl1$215": 0x80404630,
		"gx::tbl2$216": 0x80404634,
		"tbl2$216": 0x80404634,
		"gx::tbl3$217": 0x80404638,
		"tbl3$217": 0x80404638,
		"gx::GX2HWFiltConv": 0x80404640,
		"gd::cm2hw$400": 0x80404650,
		"cm2hw$400": 0x80404650,
		"gd::cm2hw$515": 0x80404654,
		"cm2hw$515": 0x80404654,
		"MarioUtil::className$1930": 0x80404208,
		"className$1930": 0x80404208,
		"MarioUtil::className$1944": 0x80404210,
		"className$1944": 0x80404210,
		"TMBindShadowManager::mSquareShadowHeight": 0x80404218,
		"mSquareShadowHeight": 0x80404218,
		"TMBindShadowManager::mTreeScale": 0x8040421c,
		"mTreeScale": 0x8040421c,
		"TMBindShadowManager::mYScalePlus": 0x80404220,
		"mYScalePlus": 0x80404220,
		"MarioUtil::ColorBlack": 0x80404228,
		"ColorBlack": 0x80404228,
		"MarioUtil::ColorWhite": 0x8040422c,
		"ColorWhite": 0x8040422c,
		"RumbleMgr::mMotorCountLimit": 0x80404230,
		"mMotorCountLimit": 0x80404230,
		"RumbleMgr::mPowerThreshold": 0x80404238,
		"mPowerThreshold": 0x80404238,
		"MarioUtil::rumblePoint_00": 0x80404240,
		"rumblePoint_00": 0x80404240,
		"MarioUtil::rumblePoint_01": 0x80404244,
		"rumblePoint_01": 0x80404244,
		"MarioUtil::rumblePoint_02": 0x80404248,
		"rumblePoint_02": 0x80404248,
		"MarioUtil::rumbleFrame_02": 0x8040424c,
		"rumbleFrame_02": 0x8040424c,
		"MarioUtil::rumblePower_02": 0x80404254,
		"rumblePower_02": 0x80404254,
		"MarioUtil::rumblePoint_03": 0x8040425c,
		"rumblePoint_03": 0x8040425c,
		"MarioUtil::rumbleFrame_03": 0x80404260,
		"rumbleFrame_03": 0x80404260,
		"MarioUtil::rumblePower_03": 0x80404268,
		"rumblePower_03": 0x80404268,
		"MarioUtil::rumblePoint_04": 0x80404270,
		"rumblePoint_04": 0x80404270,
		"MarioUtil::rumblePoint_05": 0x80404274,
		"rumblePoint_05": 0x80404274,
		"MarioUtil::rumblePoint_06": 0x80404278,
		"rumblePoint_06": 0x80404278,
		"MarioUtil::rumblePoint_07": 0x8040427c,
		"rumblePoint_07": 0x8040427c,
		"MarioUtil::rumblePoint_08": 0x80404280,
		"rumblePoint_08": 0x80404280,
		"MarioUtil::rumblePoint_09": 0x80404284,
		"rumblePoint_09": 0x80404284,
		"MarioUtil::rumblePoint_10": 0x80404288,
		"rumblePoint_10": 0x80404288,
		"MarioUtil::rumbleFrame_10": 0x8040428c,
		"rumbleFrame_10": 0x8040428c,
		"MarioUtil::rumblePower_10": 0x80404290,
		"rumblePower_10": 0x80404290,
		"MarioUtil::rumblePoint_11": 0x80404294,
		"rumblePoint_11": 0x80404294,
		"MarioUtil::rumbleFrame_11": 0x80404298,
		"rumbleFrame_11": 0x80404298,
		"MarioUtil::rumblePower_11": 0x8040429c,
		"rumblePower_11": 0x8040429c,
		"MarioUtil::rumblePoint_12": 0x804042a0,
		"rumblePoint_12": 0x804042a0,
		"MarioUtil::rumbleFrame_12": 0x804042a4,
		"rumbleFrame_12": 0x804042a4,
		"MarioUtil::rumblePower_12": 0x804042a8,
		"rumblePower_12": 0x804042a8,
		"MarioUtil::rumblePoint_13": 0x804042ac,
		"rumblePoint_13": 0x804042ac,
		"MarioUtil::rumbleFrame_13": 0x804042b0,
		"rumbleFrame_13": 0x804042b0,
		"MarioUtil::rumblePower_13": 0x804042b4,
		"rumblePower_13": 0x804042b4,
		"MarioUtil::rumblePoint_14": 0x804042b8,
		"rumblePoint_14": 0x804042b8,
		"MarioUtil::rumbleFrame_14": 0x804042bc,
		"rumbleFrame_14": 0x804042bc,
		"MarioUtil::rumblePower_14": 0x804042c0,
		"rumblePower_14": 0x804042c0,
		"MarioUtil::rumblePoint_15": 0x804042c4,
		"rumblePoint_15": 0x804042c4,
		"MarioUtil::rumbleFrame_15": 0x804042c8,
		"rumbleFrame_15": 0x804042c8,
		"MarioUtil::rumblePower_15": 0x804042cc,
		"rumblePower_15": 0x804042cc,
		"MarioUtil::rumblePoint_16": 0x804042d0,
		"rumblePoint_16": 0x804042d0,
		"MarioUtil::rumbleFrame_16": 0x804042d4,
		"rumbleFrame_16": 0x804042d4,
		"MarioUtil::rumblePower_16": 0x804042d8,
		"rumblePower_16": 0x804042d8,
		"MarioUtil::rumblePoint_17": 0x804042dc,
		"rumblePoint_17": 0x804042dc,
		"MarioUtil::rumbleFrame_17": 0x804042e0,
		"rumbleFrame_17": 0x804042e0,
		"MarioUtil::rumblePower_17": 0x804042e4,
		"rumblePower_17": 0x804042e4,
		"MarioUtil::rumblePoint_18": 0x804042e8,
		"rumblePoint_18": 0x804042e8,
		"MarioUtil::rumbleFrame_18": 0x804042ec,
		"rumbleFrame_18": 0x804042ec,
		"MarioUtil::rumblePower_18": 0x804042f0,
		"rumblePower_18": 0x804042f0,
		"MarioUtil::rumblePoint_19": 0x804042f4,
		"rumblePoint_19": 0x804042f4,
		"MarioUtil::rumblePoint_20": 0x804042f8,
		"rumblePoint_20": 0x804042f8,
		"MarioUtil::rumbleFrame_20": 0x804042fc,
		"rumbleFrame_20": 0x804042fc,
		"MarioUtil::rumblePower_20": 0x80404304,
		"rumblePower_20": 0x80404304,
		"MarioUtil::rumblePoint_21": 0x8040430c,
		"rumblePoint_21": 0x8040430c,
		"MarioUtil::rumbleFrame_21": 0x80404310,
		"rumbleFrame_21": 0x80404310,
		"MarioUtil::rumblePower_21": 0x80404318,
		"rumblePower_21": 0x80404318,
		"MarioUtil::rumblePoint_22": 0x80404320,
		"rumblePoint_22": 0x80404320,
		"MarioUtil::rumbleFrame_22": 0x80404324,
		"rumbleFrame_22": 0x80404324,
		"MarioUtil::rumblePower_22": 0x8040432c,
		"rumblePower_22": 0x8040432c,
		"MarioUtil::rumblePoint_23": 0x80404334,
		"rumblePoint_23": 0x80404334,
		"MarioUtil::rumblePoint_24": 0x80404338,
		"rumblePoint_24": 0x80404338,
		"MarioUtil::channelNum": 0x8040433c,
		"channelNum": 0x8040433c,
		"M3DUtil::@1211": 0x80404340,
		"@1211": 0x80404340,
		"System::cTargetArrowBmdFileName": 0x80404358,
		"cTargetArrowBmdFileName": 0x80404358,
		"TLiveActor::mVelocityMinY": 0x804041e8,
		"mVelocityMinY": 0x804041e8,
		"NPC::cNpcPartsNameRootJoint": 0x80404168,
		"cNpcPartsNameRootJoint": 0x80404168,
		"NPC::cDummyPollutionTexName": 0x80404170,
		"cDummyPollutionTexName": 0x80404170,
		"NPC::cRealPollutionTexName": 0x80404174,
		"cRealPollutionTexName": 0x80404174,
		"NPC::cMonteMDummyStrawTexName": 0x80404178,
		"cMonteMDummyStrawTexName": 0x80404178,
		"NPC::cMonteWDummyStrawTexName": 0x8040417c,
		"cMonteWDummyStrawTexName": 0x8040417c,
		"NPC::cMonteMRealStrawTexName": 0x80404180,
		"cMonteMRealStrawTexName": 0x80404180,
		"NPC::cMonteWRealStrawTexName": 0x80404184,
		"cMonteWRealStrawTexName": 0x80404184,
		"NPC::cScreenTexViewObjName": 0x80404188,
		"cScreenTexViewObjName": 0x80404188,
		"NPC::cJellyFishDummyScreenTexName": 0x8040418c,
		"cJellyFishDummyScreenTexName": 0x8040418c,
		"NPC::cJellyFishDummyTexName": 0x80404190,
		"cJellyFishDummyTexName": 0x80404190,
		"NPC::cJellyFishRealTexName": 0x80404194,
		"cJellyFishRealTexName": 0x80404194,
		"NPC::cMonteMCommonVolumeName": 0x80404198,
		"cMonteMCommonVolumeName": 0x80404198,
		"NPC::cMonteWCommonVolumeName": 0x8040419c,
		"cMonteWCommonVolumeName": 0x8040419c,
		"NPC::cMareMCommonVolumeName": 0x804041a0,
		"cMareMCommonVolumeName": 0x804041a0,
		"NPC::cMareWCommonVolumeName": 0x804041a4,
		"cMareWCommonVolumeName": 0x804041a4,
		"NPC::cMareCommonNormalBmtName": 0x804041a8,
		"cMareCommonNormalBmtName": 0x804041a8,
		"NPC::cMareCommonPollutionBmtName": 0x804041ac,
		"cMareCommonPollutionBmtName": 0x804041ac,
		"NPC::cManiyaParentViewObjName": 0x804041b0,
		"cManiyaParentViewObjName": 0x804041b0,
		"NPC::cManiyaChildViewObjName": 0x804041b4,
		"cManiyaChildViewObjName": 0x804041b4,
		"NPC::cNotUseFastCubeViewObjName0": 0x804041b8,
		"cNotUseFastCubeViewObjName0": 0x804041b8,
		"NPC::cNotUseFastCubeViewObjName1": 0x804041bc,
		"cNotUseFastCubeViewObjName1": 0x804041bc,
		"NPC::cEyeMaterialName": 0x804041c0,
		"cEyeMaterialName": 0x804041c0,
		"NPC::cNeckJointName": 0x804041c4,
		"cNeckJointName": 0x804041c4,
		"TBaseNPC::sWaistJointName$localstatic0$setMtxEffect_": 0x804041c8,
		"sWaistJointName$localstatic0$setMtxEffect_": 0x804041c8,
		"NPC::cPeachPartsTextureName": 0x804041d0,
		"cPeachPartsTextureName": 0x804041d0,
		"NPC::cPeachHostTextureName": 0x804041d4,
		"cPeachHostTextureName": 0x804041d4,
		"NPC::monteMG_bastable": 0x804041d8,
		"monteMG_bastable": 0x804041d8,
		"NPC::mareMD_bastable": 0x804041e0,
		"mareMD_bastable": 0x804041e0,
		"MSBgm::smMainVolume": 0x80403960,
		"smMainVolume": 0x80403960,
		"MSHandle::cPan_MaxAmp": 0x80403968,
		"cPan_MaxAmp": 0x80403968,
		"MSHandle::cPan_CAdjust": 0x8040396c,
		"cPan_CAdjust": 0x8040396c,
		"MSHandle::cPan_CShift": 0x80403970,
		"cPan_CShift": 0x80403970,
		"MSHandle::cPan_HiSence_Dist": 0x80403974,
		"cPan_HiSence_Dist": 0x80403974,
		"MSHandle::cMS_DistanceMax_Sence": 0x80403978,
		"cMS_DistanceMax_Sence": 0x80403978,
		"MSHandle::cDol_0Rad": 0x8040397c,
		"cDol_0Rad": 0x8040397c,
		"MSHandle::cDol_HalfRad": 0x80403980,
		"cDol_HalfRad": 0x80403980,
		"MSHandle::cDol_FullRad": 0x80403984,
		"cDol_FullRad": 0x80403984,
		"TWoodBarrel::mWaitAppearTime": 0x80403eb8,
		"mWaitAppearTime": 0x80403eb8,
		"TWoodBarrel::mBreakTime": 0x80403ebc,
		"mBreakTime": 0x80403ebc,
		"TWoodBarrel::mOilBarrelFlushTime": 0x80403ec0,
		"mOilBarrelFlushTime": 0x80403ec0,
		"MoveBG::streetlamp_sink_data": 0x80403ec8,
		"streetlamp_sink_data": 0x80403ec8,
		"MoveBG::lamp_bianco_sink_data": 0x80403ed0,
		"lamp_bianco_sink_data": 0x80403ed0,
		"TMapObjGeneral::mNormalLivingTime": 0x80403ed8,
		"mNormalLivingTime": 0x80403ed8,
		"TMapObjGeneral::mNormalFlushTime": 0x80403edc,
		"mNormalFlushTime": 0x80403edc,
		"TMapObjGeneral::mNormalFlushInterval": 0x80403ee0,
		"mNormalFlushInterval": 0x80403ee0,
		"TMapObjGeneral::mNormalWaitToAppearTime": 0x80403ee4,
		"mNormalWaitToAppearTime": 0x80403ee4,
		"TMapObjGeneral::mNormalAppearingScaleUp": 0x80403ee8,
		"mNormalAppearingScaleUp": 0x80403ee8,
		"TMapObjGeneral::mNormalThrowSpeedRate": 0x80403eec,
		"mNormalThrowSpeedRate": 0x80403eec,
		"TMapObjLibWave::mWaveSpeed": 0x80403ef0,
		"mWaveSpeed": 0x80403ef0,
		"TItem::mAppearedScaleSpeed": 0x80403ef8,
		"mAppearedScaleSpeed": 0x80403ef8,
		"TShine::mCircleRateY": 0x80403efc,
		"mCircleRateY": 0x80403efc,
		"TShine::mUpSpeed": 0x80403f00,
		"mUpSpeed": 0x80403f00,
		"TShine::mSpeedDownRate": 0x80403f04,
		"TManhole::mDownHeight": 0x80403f08,
		"TManhole::mDownSpeed": 0x80403f0c,
		"mDownSpeed": 0x80403f0c,
		"TManhole::mVibrationSpeed": 0x80403f10,
		"mVibrationSpeed": 0x80403f10,
		"TManhole::mVibrationEndHeight": 0x80403f14,
		"mVibrationEndHeight": 0x80403f14,
		"TManhole::mVibrationDecreaseRate": 0x80403f18,
		"mVibrationDecreaseRate": 0x80403f18,
		"TSandBlock::mSandScaleUp": 0x80403f20,
		"mSandScaleUp": 0x80403f20,
		"TSandBlock::mSandScaleDown": 0x80403f24,
		"mSandScaleDown": 0x80403f24,
		"TSandBlock::mSandScaleMin": 0x80403f28,
		"mSandScaleMin": 0x80403f28,
		"TSandBlock::mWaitTimeToFall": 0x80403f2c,
		"mWaitTimeToFall": 0x80403f2c,
		"TSandBlock::mSandWaitTime": 0x80403f30,
		"mSandWaitTime": 0x80403f30,
		"TIceBlock::mMeltSpeedWater": 0x80403f34,
		"mMeltSpeedWater": 0x80403f34,
		"TIceBlock::mMeltSpeedAuto": 0x80403f38,
		"mMeltSpeedAuto": 0x80403f38,
		"TIceBlock::mAutoMeltScale": 0x80403f3c,
		"mAutoMeltScale": 0x80403f3c,
		"MoveBG::sSubZ": 0x80403f44,
		"sSubZ": 0x80403f44,
		"MoveBG::sSpeed": 0x80403f48,
		"sSpeed": 0x80403f48,
		"TMapObjRootPakkun::mTremblePower": 0x80403f4c,
		"mTremblePower": 0x80403f4c,
		"TMapObjRootPakkun::mTrembleAccel": 0x80403f50,
		"mTrembleAccel": 0x80403f50,
		"TMapObjRootPakkun::mTrembleBrake": 0x80403f54,
		"mTrembleBrake": 0x80403f54,
		"TMapObjRootPakkun::mTrembleTime": 0x80403f58,
		"mTrembleTime": 0x80403f58,
		"TBiancoWatermillVertical::mRotAccel": 0x80403f5c,
		"TBiancoWatermillVertical::mRotSpeedDownRate": 0x80403f60,
		"mRotSpeedDownRate": 0x80403f60,
		"TBiancoWatermillVertical::mRotSpeedMax": 0x80403f64,
		"TBiancoWatermillVertical::mBridgeRotRate": 0x80403f68,
		"mBridgeRotRate": 0x80403f68,
		"TBiancoMiniWindmill::mRotWaterAccel": 0x80403f6c,
		"mRotWaterAccel": 0x80403f6c,
		"TBiancoMiniWindmill::mFriction": 0x80403f70,
		"mFriction": 0x80403f70,
		"TBiancoMiniWindmill::mRotSpeedMax": 0x80403f74,
		"MoveBG::sMessengerPosZ": 0x80403f78,
		"sMessengerPosZ": 0x80403f78,
		"MoveBG::sMessengerPosY": 0x80403f7c,
		"sMessengerPosY": 0x80403f7c,
		"TLeafBoatRotten::mAlphaDownSpeed": 0x80403f80,
		"mAlphaDownSpeed": 0x80403f80,
		"TLeafBoatRotten::mCollisionRemoveAlpha": 0x80403f84,
		"mCollisionRemoveAlpha": 0x80403f84,
		"TLeafBoatRotten::mRottenColor": 0x80403f88,
		"mRottenColor": 0x80403f88,
		"TCraneRotY::mWaitTime": 0x80403f90,
		"TCraneUpDown::mRotSpeed": 0x80403f94,
		"TCraneUpDown::mWaitTime": 0x80403f98,
		"TRiccoWatermill::mRotAccel": 0x80403f9c,
		"TRiccoWatermill::mRotSpeedMaxUp": 0x80403fa0,
		"mRotSpeedMaxUp": 0x80403fa0,
		"TRiccoWatermill::mRotSpeedMaxDown": 0x80403fa4,
		"mRotSpeedMaxDown": 0x80403fa4,
		"TRiccoWatermill::mRotDown": 0x80403fa8,
		"mRotDown": 0x80403fa8,
		"TRiccoWatermill::mSubmarineMoveRate": 0x80403fac,
		"mSubmarineMoveRate": 0x80403fac,
		"TRiccoWatermill::mSubmarineMaxTransY": 0x80403fb0,
		"mSubmarineMaxTransY": 0x80403fb0,
		"TRiccoWatermill::mSubmarineBottomTransY": 0x80403fb4,
		"mSubmarineBottomTransY": 0x80403fb4,
		"TRiccoWatermill::mWaitTime": 0x80403fb8,
		"TFruitLauncher::mObjSpeedXZ": 0x80403fbc,
		"mObjSpeedXZ": 0x80403fbc,
		"TFruitLauncher::mObjSpeedY": 0x80403fc0,
		"mObjSpeedY": 0x80403fc0,
		"TFruitLauncher::mFruitLiveTime": 0x80403fc4,
		"mFruitLiveTime": 0x80403fc4,
		"TSandBase::mWitherTime": 0x80403fc8,
		"mWitherTime": 0x80403fc8,
		"TSandBase::mScaleMin": 0x80403fcc,
		"TSandBombBase::mFiringFrameSpeed": 0x80403fd0,
		"mFiringFrameSpeed": 0x80403fd0,
		"TSandBombBase::mFiringFrameDownSpeed": 0x80403fd4,
		"mFiringFrameDownSpeed": 0x80403fd4,
		"TSandBombBase::mExplodeFrameSpeed": 0x80403fd8,
		"mExplodeFrameSpeed": 0x80403fd8,
		"TSandBombBase::mMarioJumpRate": 0x80403fdc,
		"mMarioJumpRate": 0x80403fdc,
		"TSandBombBase::mExlodingRumbleTime": 0x80403fe0,
		"mExlodingRumbleTime": 0x80403fe0,
		"TSandCastle::mCollisionRate": 0x80403fe4,
		"mCollisionRate": 0x80403fe4,
		"TLeanMirror::mGoTargetTime": 0x80403fe8,
		"mGoTargetTime": 0x80403fe8,
		"TLeanMirror::mDemoWaitTime": 0x80403fec,
		"mDemoWaitTime": 0x80403fec,
		"TLeanMirror::mDemoLightTime": 0x80403ff0,
		"mDemoLightTime": 0x80403ff0,
		"TMammaBlockRotate::mRotSpeed": 0x80403ff4,
		"TMammaBlockRotate::mRotReturnSpeed": 0x80403ff8,
		"mRotReturnSpeed": 0x80403ff8,
		"TMammaBlockRotate::mRotEnd": 0x80403ffc,
		"mRotEnd": 0x80403ffc,
		"TMammaBlockRotate::mMapGoSpeed": 0x80404000,
		"mMapGoSpeed": 0x80404000,
		"TMammaBlockRotate::mMapBackSpeed": 0x80404004,
		"mMapBackSpeed": 0x80404004,
		"TMammaBlockRotate::mWaitTime": 0x80404008,
		"TShellCup::mOpenRotMax": 0x80404014,
		"mOpenRotMax": 0x80404014,
		"TShellCup::mShellDamageRot": 0x80404018,
		"mShellDamageRot": 0x80404018,
		"TShellCup::mWaterOpenAccel": 0x8040401c,
		"mWaterOpenAccel": 0x8040401c,
		"TShellCup::mCloseAccel": 0x80404020,
		"mCloseAccel": 0x80404020,
		"TMerrygoround::mRotSpeed": 0x80404024,
		"TCogwheelScale::mWaterLeakSpeed": 0x80404028,
		"mWaterLeakSpeed": 0x80404028,
		"TCogwheel::mRopeWidthX": 0x80404030,
		"TCogwheel::mRopeWidthZ": 0x80404034,
		"TCogwheel::mTexPosRate": 0x80404038,
		"TCogwheel::mMinSpeed": 0x8040403c,
		"mMinSpeed": 0x8040403c,
		"MoveBG::mGrowStartFrame": 0x80404040,
		"mGrowStartFrame": 0x80404040,
		"MoveBG::mGrowEndFrame": 0x80404044,
		"mGrowEndFrame": 0x80404044,
		"TMapObjFlag::mFlutterSpeed": 0x80404048,
		"mFlutterSpeed": 0x80404048,
		"TMapObjPlane::mHipDropDownRate": 0x80404058,
		"mHipDropDownRate": 0x80404058,
		"TMapObjPlane::mWaterDownRate": 0x8040405c,
		"mWaterDownRate": 0x8040405c,
		"TMapObjPlane::mTexScale": 0x80404060,
		"mTexScale": 0x80404060,
		"TRideCloud::mMoveSpeedDefault": 0x80404068,
		"mMoveSpeedDefault": 0x80404068,
		"TRideCloud::mCushionLen": 0x8040406c,
		"mCushionLen": 0x8040406c,
		"TRideCloud::mCushionSpeed": 0x80404070,
		"mCushionSpeed": 0x80404070,
		"TRideCloud::mScaleSpeed": 0x80404074,
		"mScaleSpeed": 0x80404074,
		"TResetFruit::mFruitLivingTime": 0x80404078,
		"mFruitLivingTime": 0x80404078,
		"TResetFruit::mScaleUpSpeed": 0x8040407c,
		"TResetFruit::mBreakingScaleSpeed": 0x80404080,
		"mBreakingScaleSpeed": 0x80404080,
		"TResetFruit::mFruitWaitTimeToAppear": 0x80404084,
		"mFruitWaitTimeToAppear": 0x80404084,
		"TMapObjGrassManager::mWidth": 0x804040a0,
		"mWidth": 0x804040a0,
		"TMapObjGrassManager::mSwingWidth": 0x804040a4,
		"mSwingWidth": 0x804040a4,
		"TMapObjGrassManager::mSwingSpeed": 0x804040a8,
		"mSwingSpeed": 0x804040a8,
		"TMapObjGrassManager::mDistNear": 0x804040ac,
		"mDistNear": 0x804040ac,
		"TMapObjGrassManager::mDistFar": 0x804040b0,
		"mDistFar": 0x804040b0,
		"MoveBG::sGrassAddTime": 0x804040b4,
		"sGrassAddTime": 0x804040b4,
		"TRevolvingFenceInner::mSpeed": 0x804040c8,
		"mSpeed": 0x804040c8,
		"TFenceWater::mWaterAccel": 0x804040cc,
		"mWaterAccel": 0x804040cc,
		"TFenceWater::mBackSpeed": 0x804040d0,
		"mBackSpeed": 0x804040d0,
		"TFenceWater::mTurnedWaitTime": 0x804040d4,
		"mTurnedWaitTime": 0x804040d4,
		"TRailFence::mFallHeight": 0x804040d8,
		"mFallHeight": 0x804040d8,
		"TRailFence::mWaitTime": 0x804040dc,
		"MoveBG::sRumbleTime": 0x804040e0,
		"sRumbleTime": 0x804040e0,
		"THangingBridgeBoard::mMarioAccelY": 0x804040e8,
		"mMarioAccelY": 0x804040e8,
		"THangingBridgeBoard::mMarioHipDropAccelY": 0x804040ec,
		"mMarioHipDropAccelY": 0x804040ec,
		"THangingBridgeBoard::mReturnAccelRate": 0x804040f0,
		"THangingBridgeBoard::mSpeedDownRate": 0x804040f4,
		"THangingBridgeBoard::mRopeWidthX": 0x804040f8,
		"THangingBridgeBoard::mRopeWidthZ": 0x804040fc,
		"THangingBridgeBoard::mTexPosRate": 0x80404100,
		"THangingBridge::mRopeWidthBetweenBoards": 0x80404104,
		"mRopeWidthBetweenBoards": 0x80404104,
		"THangingBridge::mRopeWidthBetweenBoardsY": 0x80404108,
		"mRopeWidthBetweenBoardsY": 0x80404108,
		"THangingBridge::mPointNumBetweenBoards": 0x8040410c,
		"mPointNumBetweenBoards": 0x8040410c,
		"THangingBridge::mBetweenBoardsTexPosRate": 0x80404110,
		"mBetweenBoardsTexPosRate": 0x80404110,
		"TSwingBoard::mBoardWidth": 0x80404114,
		"mBoardWidth": 0x80404114,
		"TSwingBoard::mRopeWidthX": 0x80404118,
		"TSwingBoard::mRopeWidthZ": 0x8040411c,
		"TSwingBoard::mTexPosRate": 0x80404120,
		"TSwingBoard::mReturnAccelRate": 0x80404124,
		"TSwingBoard::mSpeedDownRate": 0x80404128,
		"TFluff::mScaleUpSpeed": 0x8040412c,
		"TFluff::mScaleDownSpeed": 0x80404130,
		"mScaleDownSpeed": 0x80404130,
		"TFluffManager::mWindMin": 0x80404134,
		"mWindMin": 0x80404134,
		"TMapObjTree::mBananaTreeJumpPower": 0x80404138,
		"mBananaTreeJumpPower": 0x80404138,
		"TMapObjTreeScale::mScaleSpeedY": 0x8040413c,
		"mScaleSpeedY": 0x8040413c,
		"TMapObjTreeScale::mStatusChangeScaleY": 0x80404140,
		"mStatusChangeScaleY": 0x80404140,
		"TMapObjTreeScale::mScaleSpeedXZ": 0x80404144,
		"mScaleSpeedXZ": 0x80404144,
		"TMapObjTreeScale::mScaleMin": 0x80404148,
		"MoveBG::sWaitTime": 0x8040414c,
		"sWaitTime": 0x8040414c,
		"TMapObjNail::mDownHeight": 0x80404150,
		"TLampTrapIron::mHitPointMax": 0x80404160,
		"mHitPointMax": 0x80404160,
		"TLampTrapIron::mFireTimerMax": 0x80404164,
		"mFireTimerMax": 0x80404164,
		"TMapEventSink::mCleanedDegree": 0x80403e20,
		"Map::table$2575": 0x80403e28,
		"table$2575": 0x80403e28,
		"TMapWire::mMoveTimerSpeed": 0x80403e30,
		"mMoveTimerSpeed": 0x80403e30,
		"TMapWire::mDownRateMax": 0x80403e34,
		"mDownRateMax": 0x80403e34,
		"TMapWire::mEndRate": 0x80403e38,
		"mEndRate": 0x80403e38,
		"TMapWire::mStretchRate": 0x80403e3c,
		"mStretchRate": 0x80403e3c,
		"TMapWire::mHeightRate": 0x80403e40,
		"mHeightRate": 0x80403e40,
		"TMapWire::mReleaseHeight": 0x80403e44,
		"mReleaseHeight": 0x80403e44,
		"TMapWire::mFootLength": 0x80403e48,
		"mFootLength": 0x80403e48,
		"TMapWire::mDrawWidth": 0x80403e4c,
		"mDrawWidth": 0x80403e4c,
		"TMapWire::mDrawHeight": 0x80403e50,
		"mDrawHeight": 0x80403e50,
		"TMapWireActor::mCommonAttackRadius": 0x80403e58,
		"mCommonAttackRadius": 0x80403e58,
		"TMapWireActor::mCommonAttackHeight": 0x80403e5c,
		"mCommonAttackHeight": 0x80403e5c,
		"TPollutionLayer::mAreaMinRate": 0x80403e60,
		"mAreaMinRate": 0x80403e60,
		"TPollutionLayer::mSpreadArea": 0x80403e64,
		"mSpreadArea": 0x80403e64,
		"TPollutionLayer::mSpreadFrequency": 0x80403e68,
		"mSpreadFrequency": 0x80403e68,
		"TPollutionLayer::mFireArea": 0x80403e6c,
		"mFireArea": 0x80403e6c,
		"TPollutionLayer::mFireEffectWaitTime": 0x80403e70,
		"mFireEffectWaitTime": 0x80403e70,
		"TPollutionLayer::mThunderArea": 0x80403e74,
		"mThunderArea": 0x80403e74,
		"TPollutionLayer::mGlassWallArea": 0x80403e78,
		"mGlassWallArea": 0x80403e78,
		"TPollutionLayer::mGlassWallEffectTime": 0x80403e7c,
		"mGlassWallEffectTime": 0x80403e7c,
		"TPollutionManager::mFlushTime": 0x80403e80,
		"mFlushTime": 0x80403e80,
		"TPollutionLayerWave::mInterval": 0x80403e88,
		"mInterval": 0x80403e88,
		"TPollutionLayer::mEffectTime": 0x80403e90,
		"mEffectTime": 0x80403e90,
		"TMareWallRock::mAppearSpeed": 0x80403e98,
		"mAppearSpeed": 0x80403e98,
		"TMareWallRock::mDepressSpeed": 0x80403e9c,
		"TMareWallRock::mCleanedDegree": 0x80403ea0,
		"TMareWallRock::mWaitTimeToAppear": 0x80403ea4,
		"mWaitTimeToAppear": 0x80403ea4,
		"TMareWallRock::mWaitTimeToDepress": 0x80403ea8,
		"mWaitTimeToDepress": 0x80403ea8,
		"TMareEventDepressWall::mDepressSpeed": 0x80403eac,
		"TMareEventDepressWall::mRiseSpeed": 0x80403eb0,
		"mRiseSpeed": 0x80403eb0,
		"TMareEventDepressWall::mWaitTimeToWatch": 0x80403eb4,
		"mWaitTimeToWatch": 0x80403eb4,
		"GC2D::scDolpicNewsDolpic0": 0x80403d98,
		"scDolpicNewsDolpic0": 0x80403d98,
		"GC2D::scDolpicNewsDolpic1": 0x80403da0,
		"scDolpicNewsDolpic1": 0x80403da0,
		"GC2D::scDolpicNewsDolpic5_2": 0x80403da8,
		"scDolpicNewsDolpic5_2": 0x80403da8,
		"GC2D::scDolpicNewsDolpic5_3": 0x80403db0,
		"scDolpicNewsDolpic5_3": 0x80403db0,
		"GC2D::fbuf": 0x80403e00,
		"fbuf": 0x80403e00,
		"GC2D::vtable_org": 0x80403e04,
		"vtable_org": 0x80403e04,
		"GC2D::dec_step": 0x80403e0c,
		"dec_step": 0x80403e0c,
		"GC2D::inc_step": 0x80403e10,
		"inc_step": 0x80403e10,
		"GC2D::fbuf2": 0x80403e14,
		"fbuf2": 0x80403e14,
		"GC2D::gmover_tex_buffer": 0x80403e18,
		"gmover_tex_buffer": 0x80403e18,
		"TGesso::mBodyRotSpeed": 0x804039ec,
		"mBodyRotSpeed": 0x804039ec,
		"TGesso::mPollRange": 0x804039f0,
		"mPollRange": 0x804039f0,
		"TGesso::mThroughHoseiDistY": 0x804039f4,
		"mThroughHoseiDistY": 0x804039f4,
		"THamuKuri::mCapGravityY": 0x804039f8,
		"mCapGravityY": 0x804039f8,
		"THamuKuri::mCapSpeed": 0x804039fc,
		"mCapSpeed": 0x804039fc,
		"THamuKuri::mVGenerateGravityY": 0x80403a00,
		"mVGenerateGravityY": 0x80403a00,
		"THamuKuri::mLandAnmFrameNum": 0x80403a04,
		"mLandAnmFrameNum": 0x80403a04,
		"Enemy::mFireHamNoseColorDiff": 0x80403a0c,
		"mFireHamNoseColorDiff": 0x80403a0c,
		"Enemy::mFireHamOtherColorDiff": 0x80403a14,
		"mFireHamOtherColorDiff": 0x80403a14,
		"TMameGesso::mBaseHoseiTransY": 0x80403a20,
		"mBaseHoseiTransY": 0x80403a20,
		"TNameKuriManager::mExplosionSpeed": 0x80403a28,
		"mExplosionSpeed": 0x80403a28,
		"TNameKuriManager::mStopMinScaleFrame": 0x80403a2c,
		"mStopMinScaleFrame": 0x80403a2c,
		"TPakkunManager::mRootExplosionScaleRate": 0x80403a30,
		"mRootExplosionScaleRate": 0x80403a30,
		"TPakkunManager::mTestFlyAngX": 0x80403a34,
		"mTestFlyAngX": 0x80403a34,
		"TPakkunManager::mIgnoreHitWaterY": 0x80403a38,
		"mIgnoreHitWaterY": 0x80403a38,
		"TSmallEnemyManager::mBlockWaitTime": 0x80403a40,
		"mBlockWaitTime": 0x80403a40,
		"TSmallEnemyManager::mBlockMoveSpeed": 0x80403a44,
		"mBlockMoveSpeed": 0x80403a44,
		"TSmallEnemyManager::mBlockWaitMoveY": 0x80403a48,
		"mBlockWaitMoveY": 0x80403a48,
		"TSmallEnemyManager::mChangeBlockTime": 0x80403a4c,
		"mChangeBlockTime": 0x80403a4c,
		"TSmallEnemyManager::mBlockXZScale": 0x80403a50,
		"mBlockXZScale": 0x80403a50,
		"TSmallEnemyManager::mBlockYScale": 0x80403a54,
		"mBlockYScale": 0x80403a54,
		"TTelesa::mFlyAngMax": 0x80403a70,
		"mFlyAngMax": 0x80403a70,
		"TTobiPuku::mLandAngle": 0x80403a88,
		"mLandAngle": 0x80403a88,
		"TTobiPuku::mBoundVelocityY": 0x80403a90,
		"mBoundVelocityY": 0x80403a90,
		"TChuuHana::mCheckOnPanelTimeRoll": 0x80403ad0,
		"mCheckOnPanelTimeRoll": 0x80403ad0,
		"TChuuHana::mCheckOnPanelTime": 0x80403ad4,
		"mCheckOnPanelTime": 0x80403ad4,
		"TChuuHana::mSmallMirrorR": 0x80403ae0,
		"mSmallMirrorR": 0x80403ae0,
		"TChuuHana::mMediumMirrorR": 0x80403ae4,
		"mMediumMirrorR": 0x80403ae4,
		"TChuuHana::mLargeMirrorR": 0x80403ae8,
		"mLargeMirrorR": 0x80403ae8,
		"TRollEnemy::mBoundVal": 0x80403af0,
		"mBoundVal": 0x80403af0,
		"TIgaiga::mReachNodeDist": 0x80403af4,
		"mReachNodeDist": 0x80403af4,
		"TTamaNoko::mStopOnAirTimeMax": 0x80403b10,
		"mStopOnAirTimeMax": 0x80403b10,
		"TTamaNoko::mRollOnAirTimeMax": 0x80403b14,
		"mRollOnAirTimeMax": 0x80403b14,
		"TTamaNoko::mRollOnAirAngle": 0x80403b18,
		"mRollOnAirAngle": 0x80403b18,
		"TTamaNoko::mDropVelocityY": 0x80403b1c,
		"mDropVelocityY": 0x80403b1c,
		"TBossTelesa::mEnemyGenRate": 0x80403b20,
		"mEnemyGenRate": 0x80403b20,
		"TBossTelesa::mItemGenRate": 0x80403b24,
		"mItemGenRate": 0x80403b24,
		"TBossTelesa::mBaseHoseiPosY": 0x80403b2c,
		"mBaseHoseiPosY": 0x80403b2c,
		"TBossTelesa::mRouletteUpRate": 0x80403b30,
		"mRouletteUpRate": 0x80403b30,
		"TBossTelesa::mTelesaGenerateInterval": 0x80403b34,
		"mTelesaGenerateInterval": 0x80403b34,
		"TBossTelesa::mCameraMoveLimit": 0x80403b38,
		"mCameraMoveLimit": 0x80403b38,
		"TBossTelesa::mCameraMoveSp": 0x80403b3c,
		"mCameraMoveSp": 0x80403b3c,
		"TCannon::mVelocityRate": 0x80403b4c,
		"mVelocityRate": 0x80403b4c,
		"TCannon::mSearchRate": 0x80403b50,
		"mSearchRate": 0x80403b50,
		"TBossEel::mOpenRollSpeed": 0x80403b58,
		"mOpenRollSpeed": 0x80403b58,
		"TBossEel::mForcePow": 0x80403b60,
		"mForcePow": 0x80403b60,
		"TFlyEnemy::mTestSp": 0x80403b6c,
		"mTestSp": 0x80403b6c,
		"TFlyEnemy::mInvalidTime": 0x80403b70,
		"mInvalidTime": 0x80403b70,
		"TFlyEnemy::mTestMarioSpMax": 0x80403b74,
		"mTestMarioSpMax": 0x80403b74,
		"TPopo::mTestAng_x": 0x80403b84,
		"TPopo::mTestAng_y": 0x80403b88,
		"TPopo::mNozzleOffsetZ": 0x80403b8c,
		"TPopo::mTestBodyScale": 0x80403b98,
		"mTestBodyScale": 0x80403b98,
		"TPopo::mColOffsetY": 0x80403ba0,
		"TPopo::mColMinVal": 0x80403ba4,
		"mColMinVal": 0x80403ba4,
		"Enemy::sleepBossHanachan_bastable": 0x80403bb0,
		"sleepBossHanachan_bastable": 0x80403bb0,
		"Enemy::cSandPillarModelName": 0x80403bc0,
		"cSandPillarModelName": 0x80403bc0,
		"Enemy::cHitPoint1_RailName": 0x80403bc4,
		"cHitPoint1_RailName": 0x80403bc4,
		"Enemy::cHitPoint2_RailName": 0x80403bc8,
		"cHitPoint2_RailName": 0x80403bc8,
		"Enemy::cSandTextureName": 0x80403bcc,
		"cSandTextureName": 0x80403bcc,
		"Enemy::cDummyTextureName": 0x80403bd0,
		"cDummyTextureName": 0x80403bd0,
		"Enemy::cMapCollisionJointName": 0x80403bd8,
		"cMapCollisionJointName": 0x80403bd8,
		"Enemy::cBodyMapCollisionFileName": 0x80403bdc,
		"cBodyMapCollisionFileName": 0x80403bdc,
		"Enemy::cHeadMapCollisionFileName": 0x80403be0,
		"cHeadMapCollisionFileName": 0x80403be0,
		"Enemy::cLegJointName_L3": 0x80403be4,
		"cLegJointName_L3": 0x80403be4,
		"Enemy::cLegJointName_R3": 0x80403be8,
		"cLegJointName_R3": 0x80403be8,
		"Enemy::cNoseHallJointName_L": 0x80403bec,
		"cNoseHallJointName_L": 0x80403bec,
		"Enemy::cNoseHallJointName_R": 0x80403bf0,
		"cNoseHallJointName_R": 0x80403bf0,
		"Enemy::sFootJointName$2739": 0x80403bf4,
		"sFootJointName$2739": 0x80403bf4,
		"TRocket::mTestAng_y": 0x80403c08,
		"TRocket::mNozzleOffsetZ": 0x80403c0c,
		"TRocket::mColOffsetY": 0x80403c10,
		"Enemy::koopajrsubmarine_bastable": 0x80403c38,
		"koopajrsubmarine_bastable": 0x80403c38,
		"Enemy::@2523": 0x80403cc8,
		"Enemy::@2524": 0x80403ccc,
		"Enemy::@2525": 0x80403cd0,
		"Enemy::DebuTelesa_bastable": 0x80403d80,
		"DebuTelesa_bastable": 0x80403d80,
		"Camera::cStartCamName": 0x80403994,
		"cStartCamName": 0x80403994,
		"Camera::cStartAfterCamName": 0x80403998,
		"cStartAfterCamName": 0x80403998,
		"Camera::cJetCoasterCam0BckName": 0x8040399c,
		"cJetCoasterCam0BckName": 0x8040399c,
		"Camera::cJetCoasterCam1BckName": 0x804039a0,
		"cJetCoasterCam1BckName": 0x804039a0,
		"Camera::cJetCoasterDemoBckName": 0x804039a4,
		"cJetCoasterDemoBckName": 0x804039a4,
		"Camera::cStartCamBckFileName": 0x804039a8,
		"cStartCamBckFileName": 0x804039a8,
		"Camera::bossGesoViewObjName": 0x804039b0,
		"bossGesoViewObjName": 0x804039b0,
		"Camera::cSunWarpPointName": 0x804039c0,
		"cSunWarpPointName": 0x804039c0,
		"Camera::cPositionJointName": 0x804039c8,
		"cPositionJointName": 0x804039c8,
		"Camera::cLookatJointName": 0x804039cc,
		"cLookatJointName": 0x804039cc,
		"Camera::cCameraBckVolumeName": 0x804039d0,
		"cCameraBckVolumeName": 0x804039d0,
		"Camera::cLoadCamName": 0x804039d8,
		"cLoadCamName": 0x804039d8,
		"TNerveWaitForever<TLiveActor>::instance$localstatic0$theNerve": 0x80404664,
		"Enemy::instance$3230": 0x80404890,
		"instance$3230": 0x80404890,
		"Enemy::instance$3275": 0x804048a0,
		"instance$3275": 0x804048a0,
		"Enemy::instance$3358": 0x804048b0,
		"instance$3358": 0x804048b0,
		"Enemy::instance$3372": 0x804048b8,
		"instance$3372": 0x804048b8,
		"Enemy::instance$3382": 0x804048c0,
		"instance$3382": 0x804048c0,
		"Enemy::instance$3392": 0x804048c8,
		"instance$3392": 0x804048c8,
		"Enemy::instance$3749": 0x804048d4,
		"instance$3749": 0x804048d4,
		"Enemy::instance$3763": 0x804048dc,
		"instance$3763": 0x804048dc,
		"Enemy::instance$3792": 0x804048ec,
		"instance$3792": 0x804048ec,
		"Enemy::instance$3836": 0x80404904,
		"instance$3836": 0x80404904,
		"Enemy::instance$3847": 0x8040490c,
		"instance$3847": 0x8040490c,
		"Enemy::instance$3867": 0x80404914,
		"instance$3867": 0x80404914,
		"Enemy::instance$3881": 0x8040491c,
		"instance$3881": 0x8040491c,
		"Enemy::instance$3892": 0x80404924,
		"instance$3892": 0x80404924,
		"Enemy::instance$3915": 0x80404934,
		"instance$3915": 0x80404934,
		"Enemy::instance$2574": 0x8040493c,
		"instance$2574": 0x8040493c,
		"Enemy::instance$2632": 0x80404944,
		"instance$2632": 0x80404944,
		"Enemy::instance$2655": 0x8040494c,
		"instance$2655": 0x8040494c,
		"Enemy::instance$2675": 0x80404954,
		"instance$2675": 0x80404954,
		"Enemy::instance$2695": 0x8040495c,
		"instance$2695": 0x8040495c,
		"Enemy::instance$2709": 0x80404964,
		"instance$2709": 0x80404964,
		"Enemy::instance$2727": 0x8040496c,
		"instance$2727": 0x8040496c,
		"Enemy::instance$2754": 0x80404974,
		"instance$2754": 0x80404974,
		"Enemy::instance$3061": 0x80404980,
		"instance$3061": 0x80404980,
		"Enemy::instance$3074": 0x80404988,
		"instance$3074": 0x80404988,
		"Enemy::instance$3150": 0x804049a0,
		"instance$3150": 0x804049a0,
		"Enemy::instance$3164": 0x804049b0,
		"instance$3164": 0x804049b0,
		"Enemy::instance$3245": 0x804049cc,
		"instance$3245": 0x804049cc,
		"Enemy::instance$3288": 0x804049d4,
		"instance$3288": 0x804049d4,
		"Enemy::instance$3301": 0x804049dc,
		"instance$3301": 0x804049dc,
		"Enemy::instance$3349": 0x804049f4,
		"instance$3349": 0x804049f4,
		"Enemy::instance$3227": 0x80404a04,
		"instance$3227": 0x80404a04,
		"Enemy::instance$3255": 0x80404a0c,
		"instance$3255": 0x80404a0c,
		"Enemy::instance$3297": 0x80404a24,
		"instance$3297": 0x80404a24,
		"Enemy::instance$3309": 0x80404a2c,
		"instance$3309": 0x80404a2c,
		"Enemy::instance$2616": 0x80404a3c,
		"instance$2616": 0x80404a3c,
		"Enemy::instance$2627": 0x80404a44,
		"instance$2627": 0x80404a44,
		"Enemy::instance$2639": 0x80404a4c,
		"instance$2639": 0x80404a4c,
		"Enemy::instance$2658": 0x80404a54,
		"instance$2658": 0x80404a54,
		"Enemy::instance$2669": 0x80404a5c,
		"instance$2669": 0x80404a5c,
		"Enemy::instance$3721": 0x80404a6c,
		"instance$3721": 0x80404a6c,
		"Enemy::instance$3739": 0x80404a74,
		"instance$3739": 0x80404a74,
		"Enemy::instance$3754": 0x80404a7c,
		"instance$3754": 0x80404a7c,
		"Enemy::instance$3794": 0x80404a84,
		"instance$3794": 0x80404a84,
		"Enemy::instance$3814": 0x80404a8c,
		"instance$3814": 0x80404a8c,
		"Enemy::instance$3833": 0x80404a94,
		"instance$3833": 0x80404a94,
		"Enemy::instance$3896": 0x80404aa4,
		"instance$3896": 0x80404aa4,
		"Enemy::instance$3913": 0x80404aac,
		"instance$3913": 0x80404aac,
		"Enemy::instance$3160": 0x80404ab4,
		"instance$3160": 0x80404ab4,
		"Enemy::instance$3264": 0x80404ad4,
		"instance$3264": 0x80404ad4,
		"Enemy::instance$3314": 0x80404af4,
		"instance$3314": 0x80404af4,
		"Enemy::instance$3299": 0x80404afc,
		"instance$3299": 0x80404afc,
		"Enemy::instance$3325": 0x80404b04,
		"instance$3325": 0x80404b04,
		"Enemy::instance$3346": 0x80404b0c,
		"instance$3346": 0x80404b0c,
		"Enemy::instance$3485": 0x80404b2c,
		"instance$3485": 0x80404b2c,
		"Enemy::instance$3499": 0x80404b34,
		"instance$3499": 0x80404b34,
		"Enemy::instance$3511": 0x80404b3c,
		"instance$3511": 0x80404b3c,
		"Enemy::instance$3521": 0x80404b44,
		"instance$3521": 0x80404b44,
		"Enemy::instance$3534": 0x80404b4c,
		"instance$3534": 0x80404b4c,
		"Enemy::instance$3549": 0x80404b54,
		"instance$3549": 0x80404b54,
		"Enemy::instance$3565": 0x80404b5c,
		"instance$3565": 0x80404b5c,
		"Enemy::instance$3575": 0x80404b64,
		"instance$3575": 0x80404b64,
		"Enemy::instance$3584": 0x80404b6c,
		"instance$3584": 0x80404b6c,
		"Enemy::instance$3594": 0x80404b74,
		"instance$3594": 0x80404b74,
		"Enemy::instance$3609": 0x80404b7c,
		"instance$3609": 0x80404b7c,
		"Enemy::instance$3620": 0x80404b84,
		"instance$3620": 0x80404b84,
		"Enemy::instance$3625": 0x80404b90,
		"instance$3625": 0x80404b90,
		"Enemy::instance$3665": 0x80404b98,
		"instance$3665": 0x80404b98,
		"Enemy::instance$3678": 0x80404ba0,
		"instance$3678": 0x80404ba0,
		"Enemy::instance$3707": 0x80404ba8,
		"instance$3707": 0x80404ba8,
		"Enemy::instance$3719": 0x80404bb0,
		"instance$3719": 0x80404bb0,
		"Enemy::instance$3732": 0x80404bb8,
		"instance$3732": 0x80404bb8,
		"Enemy::instance$3745": 0x80404bc0,
		"instance$3745": 0x80404bc0,
		"Enemy::instance$3759": 0x80404bc8,
		"instance$3759": 0x80404bc8,
		"Enemy::instance$3795": 0x80404bd8,
		"instance$3795": 0x80404bd8,
		"Enemy::instance$3808": 0x80404be0,
		"instance$3808": 0x80404be0,
		"Enemy::instance$3834": 0x80404bf0,
		"instance$3834": 0x80404bf0,
		"Enemy::instance$3871": 0x80404c08,
		"instance$3871": 0x80404c08,
		"Enemy::instance$3918": 0x80404c20,
		"instance$3918": 0x80404c20,
		"Enemy::instance$3930": 0x80404c28,
		"instance$3930": 0x80404c28,
		"Enemy::instance$3940": 0x80404c30,
		"instance$3940": 0x80404c30,
		"Enemy::instance$3954": 0x80404c38,
		"instance$3954": 0x80404c38,
		"Enemy::instance$3991": 0x80404c40,
		"instance$3991": 0x80404c40,
		"Enemy::instance$4009": 0x80404c50,
		"instance$4009": 0x80404c50,
		"Enemy::instance$4025": 0x80404c58,
		"instance$4025": 0x80404c58,
		"Enemy::instance$3115": 0x80404c78,
		"instance$3115": 0x80404c78,
		"Enemy::instance$3130": 0x80404c80,
		"instance$3130": 0x80404c80,
		"Enemy::instance$3155": 0x80404c88,
		"instance$3155": 0x80404c88,
		"Enemy::instance$3180": 0x80404c98,
		"instance$3180": 0x80404c98,
		"Enemy::instance$3197": 0x80404ca0,
		"instance$3197": 0x80404ca0,
		"Enemy::instance$3248": 0x80404cb0,
		"instance$3248": 0x80404cb0,
		"Enemy::instance$3270": 0x80404cb8,
		"instance$3270": 0x80404cb8,
		"Enemy::instance$3282": 0x80404cc0,
		"instance$3282": 0x80404cc0,
		"Enemy::instance$3531": 0x80404ccc,
		"instance$3531": 0x80404ccc,
		"Enemy::instance$3543": 0x80404cd4,
		"instance$3543": 0x80404cd4,
		"Enemy::instance$3556": 0x80404cdc,
		"instance$3556": 0x80404cdc,
		"Enemy::instance$3479": 0x80404ce4,
		"instance$3479": 0x80404ce4,
		"Enemy::instance$3526": 0x80404cec,
		"instance$3526": 0x80404cec,
		"Enemy::instance$3539": 0x80404cf4,
		"instance$3539": 0x80404cf4,
		"Enemy::instance$3553": 0x80404cfc,
		"instance$3553": 0x80404cfc,
		"Enemy::instance$3564": 0x80404d04,
		"instance$3564": 0x80404d04,
		"Enemy::instance$3581": 0x80404d0c,
		"instance$3581": 0x80404d0c,
		"Enemy::instance$3591": 0x80404d14,
		"instance$3591": 0x80404d14,
		"Enemy::instance$3610": 0x80404d1c,
		"instance$3610": 0x80404d1c,
		"Enemy::instance$3629": 0x80404d24,
		"instance$3629": 0x80404d24,
		"Enemy::instance$3643": 0x80404d2c,
		"instance$3643": 0x80404d2c,
		"Enemy::instance$3653": 0x80404d34,
		"instance$3653": 0x80404d34,
		"Enemy::instance$3110": 0x80404d40,
		"instance$3110": 0x80404d40,
		"Enemy::instance$3148": 0x80404d50,
		"instance$3148": 0x80404d50,
		"Enemy::instance$3176": 0x80404d58,
		"instance$3176": 0x80404d58,
		"Enemy::instance$3200": 0x80404d60,
		"instance$3200": 0x80404d60,
		"Enemy::instance$3221": 0x80404d70,
		"instance$3221": 0x80404d70,
		"Enemy::instance$3254": 0x80404d88,
		"instance$3254": 0x80404d88,
		"Enemy::instance$3267": 0x80404d90,
		"instance$3267": 0x80404d90,
		"Enemy::instance$3457": 0x80404dbc,
		"instance$3457": 0x80404dbc,
		"Enemy::instance$3470": 0x80404dc4,
		"instance$3470": 0x80404dc4,
		"Enemy::instance$3137": 0x80404dd4,
		"instance$3137": 0x80404dd4,
		"Enemy::instance$3163": 0x80404ddc,
		"instance$3163": 0x80404ddc,
		"Enemy::instance$3344": 0x80404df4,
		"instance$3344": 0x80404df4,
		"Enemy::instance$3407": 0x80404dfc,
		"instance$3407": 0x80404dfc,
		"Enemy::instance$3425": 0x80404e04,
		"instance$3425": 0x80404e04,
		"Enemy::instance$3439": 0x80404e0c,
		"instance$3439": 0x80404e0c,
		"Enemy::instance$3449": 0x80404e14,
		"instance$3449": 0x80404e14,
		"Enemy::instance$3473": 0x80404e1c,
		"instance$3473": 0x80404e1c,
		"Enemy::instance$3500": 0x80404e24,
		"instance$3500": 0x80404e24,
		"Enemy::instance$3199": 0x80404e2c,
		"instance$3199": 0x80404e2c,
		"Enemy::instance$4027": 0x80404e3c,
		"instance$4027": 0x80404e3c,
		"Enemy::instance$4069": 0x80404e44,
		"instance$4069": 0x80404e44,
		"Enemy::instance$4083": 0x80404e4c,
		"instance$4083": 0x80404e4c,
		"Enemy::instance$4093": 0x80404e54,
		"instance$4093": 0x80404e54,
		"Enemy::instance$4106": 0x80404e5c,
		"instance$4106": 0x80404e5c,
		"Enemy::instance$4128": 0x80404e64,
		"instance$4128": 0x80404e64,
		"Enemy::instance$4144": 0x80404e6c,
		"instance$4144": 0x80404e6c,
		"Enemy::instance$4160": 0x80404e74,
		"instance$4160": 0x80404e74,
		"Enemy::instance$4195": 0x80404e7c,
		"instance$4195": 0x80404e7c,
		"Enemy::instance$4206": 0x80404e84,
		"instance$4206": 0x80404e84,
		"Enemy::instance$2589": 0x80404e8c,
		"instance$2589": 0x80404e8c,
		"Enemy::instance$3010": 0x80404e94,
		"instance$3010": 0x80404e94,
		"Enemy::instance$3033": 0x80404e9c,
		"instance$3033": 0x80404e9c,
		"Enemy::instance$3042": 0x80404ea4,
		"instance$3042": 0x80404ea4,
		"Enemy::instance$3055": 0x80404eac,
		"Enemy::instance$3079": 0x80404eb4,
		"instance$3079": 0x80404eb4,
		"Enemy::instance$3089": 0x80404ebc,
		"instance$3089": 0x80404ebc,
		"Enemy::instance$3101": 0x80404ec4,
		"instance$3101": 0x80404ec4,
		"Enemy::instance$3283": 0x80404ecc,
		"instance$3283": 0x80404ecc,
		"Enemy::instance$3296": 0x80404ed4,
		"instance$3296": 0x80404ed4,
		"Enemy::instance$3333": 0x80404edc,
		"instance$3333": 0x80404edc,
		"Enemy::instance$3366": 0x80404ee4,
		"instance$3366": 0x80404ee4,
		"Enemy::instance$3410": 0x80404ef4,
		"instance$3410": 0x80404ef4,
		"Enemy::instance$3462": 0x80404f04,
		"instance$3462": 0x80404f04,
		"Enemy::instance$3226": 0x80404f14,
		"instance$3226": 0x80404f14,
		"Enemy::instance$3800": 0x80404f44,
		"instance$3800": 0x80404f44,
		"Enemy::instance$3813": 0x80404f4c,
		"instance$3813": 0x80404f4c,
		"Enemy::instance$3826": 0x80404f54,
		"instance$3826": 0x80404f54,
		"Enemy::instance$3886": 0x80404f70,
		"instance$3886": 0x80404f70,
		"Enemy::instance$3894": 0x80404f78,
		"instance$3894": 0x80404f78,
		"Enemy::instance$3925": 0x80404f80,
		"instance$3925": 0x80404f80,
		"Enemy::instance$3944": 0x80404f88,
		"instance$3944": 0x80404f88,
		"Enemy::instance$3971": 0x80404f90,
		"instance$3971": 0x80404f90,
		"Enemy::instance$2972": 0x80404fa0,
		"instance$2972": 0x80404fa0,
		"Enemy::instance$2969": 0x80404fcc,
		"instance$2969": 0x80404fcc,
		"Enemy::instance$2983": 0x80404fd4,
		"instance$2983": 0x80404fd4,
		"Enemy::instance$3022": 0x80404fe4,
		"instance$3022": 0x80404fe4,
		"Enemy::instance$3036": 0x80404fec,
		"instance$3036": 0x80404fec,
		"Enemy::instance$3058": 0x80404ff4,
		"instance$3058": 0x80404ff4,
		"Enemy::instance$3212": 0x8040500c,
		"instance$3212": 0x8040500c,
		"Enemy::instance$3179": 0x80405034,
		"instance$3179": 0x80405034,
		"Enemy::instance$3196": 0x8040503c,
		"instance$3196": 0x8040503c,
		"Enemy::instance$3250": 0x80405054,
		"instance$3250": 0x80405054,
		"Enemy::instance$2774": 0x80405074,
		"instance$2774": 0x80405074,
		"Enemy::instance$2796": 0x8040507c,
		"instance$2796": 0x8040507c,
		"Enemy::instance$2974": 0x804050c4,
		"instance$2974": 0x804050c4,
		"Enemy::instance$3004": 0x804050cc,
		"instance$3004": 0x804050cc,
		"Enemy::instance$3078": 0x804050dc,
		"instance$3078": 0x804050dc,
		"Enemy::instance$3403": 0x80405104,
		"instance$3403": 0x80405104,
		"Enemy::instance$3417": 0x8040510c,
		"instance$3417": 0x8040510c,
		"Enemy::instance$3430": 0x80405114,
		"instance$3430": 0x80405114,
		"Enemy::instance$3458": 0x8040511c,
		"instance$3458": 0x8040511c,
		"Enemy::instance$3472": 0x80405124,
		"instance$3472": 0x80405124,
		"Enemy::instance$3486": 0x8040512c,
		"instance$3486": 0x8040512c,
		"Enemy::instance$2859": 0x80405150,
		"instance$2859": 0x80405150,
		"Enemy::instance$2685": 0x80405164,
		"instance$2685": 0x80405164,
		"Enemy::instance$2704": 0x80405174,
		"instance$2704": 0x80405174,
		"Enemy::instance$2712": 0x8040517c,
		"instance$2712": 0x8040517c,
		"Enemy::instance$2722": 0x80405184,
		"instance$2722": 0x80405184,
		"Enemy::instance$2730": 0x8040518c,
		"instance$2730": 0x8040518c,
		"Enemy::instance$2890": 0x8040519c,
		"instance$2890": 0x8040519c,
		"Enemy::instance$2842": 0x804051b4,
		"instance$2842": 0x804051b4,
		"Enemy::instance$2854": 0x804051bc,
		"instance$2854": 0x804051bc,
		"Enemy::instance$2864": 0x804051c4,
		"instance$2864": 0x804051c4,
		"Enemy::instance$2876": 0x804051cc,
		"instance$2876": 0x804051cc,
		"Enemy::instance$2889": 0x804051d4,
		"instance$2889": 0x804051d4,
		"Enemy::instance$2911": 0x804051e4,
		"instance$2911": 0x804051e4,
		"Enemy::instance$2879": 0x80405234,
		"instance$2879": 0x80405234,
		"Enemy::instance$2891": 0x8040523c,
		"instance$2891": 0x8040523c,
		"Enemy::instance$3111": 0x8040525c,
		"instance$3111": 0x8040525c,
		"Enemy::instance$3131": 0x8040526c,
		"instance$3131": 0x8040526c,
		"Enemy::instance$3149": 0x8040527c,
		"instance$3149": 0x8040527c,
		"Enemy::instance$3321": 0x8040528c,
		"instance$3321": 0x8040528c,
		"Enemy::instance$2664": 0x8040529c,
		"instance$2664": 0x8040529c,
		"Enemy::instance$2676": 0x804052a4,
		"instance$2676": 0x804052a4,
		"Enemy::instance$2688": 0x804052ac,
		"instance$2688": 0x804052ac,
		"Enemy::instance$2698": 0x804052b4,
		"instance$2698": 0x804052b4,
		"Enemy::instance$2715": 0x804052bc,
		"instance$2715": 0x804052bc,
		"Enemy::instance$2745": 0x804052cc,
		"instance$2745": 0x804052cc,
		"Enemy::instance$2755": 0x804052d4,
		"instance$2755": 0x804052d4,
		"Enemy::instance$2766": 0x804052dc,
		"instance$2766": 0x804052dc,
		"Enemy::instance$3102": 0x80405334,
		"instance$3102": 0x80405334,
		"Enemy::instance$3144": 0x80405344,
		"instance$3144": 0x80405344,
		"Enemy::instance$2531": 0x80405354,
		"instance$2531": 0x80405354,
		"Enemy::instance$2543": 0x8040535c,
		"instance$2543": 0x8040535c,
		"Enemy::instance$2557": 0x80405364,
		"instance$2557": 0x80405364,
		"Enemy::instance$2567": 0x8040536c,
		"instance$2567": 0x8040536c,
		"Enemy::instance$2577": 0x80405374,
		"instance$2577": 0x80405374,
		"Enemy::instance$3132": 0x80405394,
		"instance$3132": 0x80405394,
		"Enemy::instance$2851": 0x804053cc,
		"instance$2851": 0x804053cc,
		"Enemy::instance$2897": 0x804053e8,
		"instance$2897": 0x804053e8,
		"Enemy::instance$2923": 0x804053f8,
		"instance$2923": 0x804053f8,
		"Enemy::instance$2929": 0x80405400,
		"instance$2929": 0x80405400,
		"Enemy::instance$2939": 0x80405408,
		"instance$2939": 0x80405408,
		"GC2D::HX_CIRCLE_STATE1_TIME": 0x804054ac,
		"HX_CIRCLE_STATE1_TIME": 0x804054ac,
		"GC2D::HX_CIRCLE_STATE1_TIME2": 0x804054b0,
		"HX_CIRCLE_STATE1_TIME2": 0x804054b0,
		"GC2D::r$184": 0x804054b4,
		"r$184": 0x804054b4,
		"GC2D::p1$185": 0x804054b8,
		"p1$185": 0x804054b8,
		"GC2D::p2$186": 0x804054bc,
		"p2$186": 0x804054bc,
		"GC2D::p3$187": 0x804054c0,
		"p3$187": 0x804054c0,
		"GC2D::boke$191": 0x804054cc,
		"boke$191": 0x804054cc,
		"GC2D::STATE1_TIME": 0x804054d0,
		"STATE1_TIME": 0x804054d0,
		"GC2D::STATE1_TIME1": 0x804054d4,
		"STATE1_TIME1": 0x804054d4,
		"GC2D::STATE1_TIME2": 0x804054d8,
		"STATE1_TIME2": 0x804054d8,
		"GC2D::STATE1_TIME3": 0x804054dc,
		"STATE1_TIME3": 0x804054dc,
		"GC2D::STATE2_TIME": 0x804054e0,
		"STATE2_TIME": 0x804054e0,
		"GC2D::STATE3_TIME": 0x804054e4,
		"STATE3_TIME": 0x804054e4,
		"GC2D::rot$266": 0x804054e8,
		"rot$266": 0x804054e8,
		"GC2D::fade$267": 0x804054ec,
		"fade$267": 0x804054ec,
		"GC2D::boundstate$269": 0x804054f0,
		"boundstate$269": 0x804054f0,
		"GC2D::boundtimer$270": 0x804054f4,
		"boundtimer$270": 0x804054f4,
		"GC2D::bounddelta$271": 0x804054f8,
		"bounddelta$271": 0x804054f8,
		"GC2D::HX_LOGO_TIMER1": 0x80405500,
		"HX_LOGO_TIMER1": 0x80405500,
		"GC2D::HX_LOGO_TIMER2": 0x80405504,
		"HX_LOGO_TIMER2": 0x80405504,
		"GC2D::dp$329": 0x80405514,
		"dp$329": 0x80405514,
		"GC2D::bx$330": 0x80405518,
		"bx$330": 0x80405518,
		"GC2D::by$331": 0x8040551c,
		"by$331": 0x8040551c,
		"GC2D::count$332": 0x80405520,
		"count$332": 0x80405520,
		"GC2D::HX_TEST1_TIMER": 0x80405524,
		"HX_TEST1_TIMER": 0x80405524,
		"GC2D::HX_TEST1_TIMER2": 0x80405528,
		"HX_TEST1_TIMER2": 0x80405528,
		"GC2D::r$410": 0x8040552c,
		"r$410": 0x8040552c,
		"GC2D::HX_Test2_STATE1_TIME": 0x80405530,
		"HX_Test2_STATE1_TIME": 0x80405530,
		"GC2D::HX_Test2_STATE2_TIME": 0x80405534,
		"HX_Test2_STATE2_TIME": 0x80405534,
		"GC2D::HX_Test2_STATE3_TIME": 0x80405538,
		"HX_Test2_STATE3_TIME": 0x80405538,
		"GC2D::HX_Test2_STATE4_TIME": 0x8040553c,
		"HX_Test2_STATE4_TIME": 0x8040553c,
		"GC2D::r$436": 0x80405540,
		"r$436": 0x80405540,
		"GC2D::r$455": 0x80405544,
		"r$455": 0x80405544,
		"GC2D::HX_TEST4_TIME": 0x80405548,
		"HX_TEST4_TIME": 0x80405548,
		"GC2D::thin$495": 0x8040554c,
		"thin$495": 0x8040554c,
		"GC2D::rstep$496": 0x80405550,
		"rstep$496": 0x80405550,
		"GC2D::thin_d$497": 0x80405554,
		"thin_d$497": 0x80405554,
		"GC2D::rstep_d$498": 0x80405558,
		"rstep_d$498": 0x80405558,
		"GC2D::HX_TEST5_FADETIME": 0x8040555c,
		"HX_TEST5_FADETIME": 0x8040555c,
		"MoveBG::total_use_size$2279": 0x8040560c,
		"total_use_size$2279": 0x8040560c,
		"NPC::sViewObjName$2623": 0x8040571c,
		"sViewObjName$2623": 0x8040571c,
		"System::sCmn2DArc": 0x80405880,
		"sCmn2DArc": 0x80405880,
		"System::sCmn2DArcBuf": 0x80405884,
		"sCmn2DArcBuf": 0x80405884,
		"MSStageCubeFade::smInstance": 0x804058f0,
		"MSStageCubeFadeDouble::smInstance": 0x804058f4,
		"JKRArchive::sCurrentDirID": 0x80405900,
		"sCurrentDirID": 0x80405900,
		"JKRAram::sAramObject": 0x80405908,
		"sAramObject": 0x80405908,
		"JSystem::srcAddress": 0x8040592c,
		"srcAddress": 0x8040592c,
		"JSystem::whatdo": 0x80405940,
		"whatdo": 0x80405940,
		"JSystem::whatdo2": 0x80405944,
		"whatdo2": 0x80405944,
		"JSystem::DBfoundSize": 0x80405948,
		"DBfoundSize": 0x80405948,
		"JSystem::DBfoundOffset": 0x8040594c,
		"DBfoundOffset": 0x8040594c,
		"JSystem::DBfoundBlock": 0x80405950,
		"DBfoundBlock": 0x80405950,
		"JSystem::DBnewFreeBlock": 0x80405954,
		"DBnewFreeBlock": 0x80405954,
		"JSystem::DBnewUsedBlock": 0x80405958,
		"DBnewUsedBlock": 0x80405958,
		"JKRFileLoader::sCurrentVolume": 0x80405960,
		"sCurrentVolume": 0x80405960,
		"JKRHeap::sSystemHeap": 0x80405968,
		"sSystemHeap": 0x80405968,
		"JKRHeap::sCurrentHeap": 0x8040596c,
		"JKRHeap::sRootHeap": 0x80405970,
		"sRootHeap": 0x80405970,
		"JKRHeap::mErrorHandler": 0x80405974,
		"mErrorHandler": 0x80405974,
		"JKRHeap::mCodeStart": 0x80405978,
		"mCodeStart": 0x80405978,
		"JKRHeap::mCodeEnd": 0x8040597c,
		"mCodeEnd": 0x8040597c,
		"JKRHeap::mUserRamStart": 0x80405980,
		"mUserRamStart": 0x80405980,
		"JKRHeap::mUserRamEnd": 0x80405984,
		"mUserRamEnd": 0x80405984,
		"JKRHeap::mMemorySize": 0x80405988,
		"mMemorySize": 0x80405988,
		"JUTException::sErrorManager": 0x80405990,
		"sErrorManager": 0x80405990,
		"JUTException::sPreUserCallback": 0x80405994,
		"sPreUserCallback": 0x80405994,
		"JUTException::sPostUserCallback": 0x80405998,
		"sPostUserCallback": 0x80405998,
		"JUTException::sConsoleBuffer": 0x8040599c,
		"sConsoleBuffer": 0x8040599c,
		"JUTException::sConsoleBufferSize": 0x804059a0,
		"sConsoleBufferSize": 0x804059a0,
		"JUTException::sConsole": 0x804059a4,
		"sConsole": 0x804059a4,
		"JUTException::msr": 0x804059a8,
		"msr": 0x804059a8,
		"JUTException::fpscr": 0x804059ac,
		"fpscr": 0x804059ac,
		"JUTDirectPrint::sDirectPrint": 0x804059b0,
		"sDirectPrint": 0x804059b0,
		"JUTGamePad::mPadAssign": 0x804059bc,
		"mPadAssign": 0x804059bc,
		"JUTGamePad::mSuppressPadReset": 0x804059c0,
		"mSuppressPadReset": 0x804059c0,
		"JUTGamePad::sAnalogMode": 0x804059c4,
		"sAnalogMode": 0x804059c4,
		"JUTGamePad::CRumble::mStatus": 0x804059c8,
		"mStatus": 0x804059c8,
		"JUTGamePad::CRumble::mEnable": 0x804059cc,
		"mEnable": 0x804059cc,
		"JUTGamePad::C3ButtonReset::sCallback": 0x804059d0,
		"sCallback": 0x804059d0,
		"JUTGamePad::C3ButtonReset::sCallbackArg": 0x804059d4,
		"sCallbackArg": 0x804059d4,
		"JUTGamePad::C3ButtonReset::sResetOccurredPort": 0x804059e4,
		"sResetOccurredPort": 0x804059e4,
		"JSystem::jmaSinShift": 0x804059ec,
		"jmaSinShift": 0x804059ec,
		"JSystem::jmaSinTable": 0x804059f0,
		"jmaSinTable": 0x804059f0,
		"JSystem::jmaCosTable": 0x804059f4,
		"jmaCosTable": 0x804059f4,
		"J2DPrint::mStrBuff": 0x804059f8,
		"mStrBuff": 0x804059f8,
		"J2DPrint::mStrBuffSize": 0x80405a00,
		"mStrBuffSize": 0x80405a00,
		"J3DShapeMtx::currentPipeline": 0x80405a08,
		"currentPipeline": 0x80405a08,
		"JSystem::j3dDefaultViewNo": 0x80405a10,
		"j3dDefaultViewNo": 0x80405a10,
		"JSystem::dmaBuf": 0x80405a5c,
		"dmaBuf": 0x80405a5c,
		"JSystem::dmaEnd": 0x80405a60,
		"dmaEnd": 0x80405a60,
		"JSystem::dmaCurrent": 0x80405a64,
		"dmaCurrent": 0x80405a64,
		"JKRDecomp::sDecompObject": 0x80405a88,
		"sDecompObject": 0x80405a88,
		"J3DDrawPacket::sInterruptFlag": 0x80405a90,
		"sInterruptFlag": 0x80405a90,
		"J3DDrawBuffer::entryNum": 0x80405a98,
		"entryNum": 0x80405a98,
		"JKRAramStream::sAramStreamObject": 0x80405aa0,
		"sAramStreamObject": 0x80405aa0,
		"JKRAramStream::transBuffer": 0x80405aa4,
		"transBuffer": 0x80405aa4,
		"JKRAramStream::transSize": 0x80405aa8,
		"transSize": 0x80405aa8,
		"JKRAramStream::transHeap": 0x80405aac,
		"transHeap": 0x80405aac,
		"JUTAssertion::@unnamed@::sMessageLife": 0x80405ab0,
		"sMessageLife": 0x80405ab0,
		"JUTVideo::sManager": 0x80405ab8,
		"JUTRomFont::spAboutEncoding_": 0x80405ac0,
		"spAboutEncoding_": 0x80405ac0,
		"JUTRomFont::spFontHeader_": 0x80405ac4,
		"spFontHeader_": 0x80405ac4,
		"JUTRomFont::suFontHeaderRefered_": 0x80405ac8,
		"suFontHeaderRefered_": 0x80405ac8,
		"JUTConsoleManager::sManager": 0x80405ad0,
		"JSystem::sReportConsole": 0x80405ad4,
		"sReportConsole": 0x80405ad4,
		"JSystem::sWarningConsole": 0x80405ad8,
		"sWarningConsole": 0x80405ad8,
		"JDrama::TNameRefGen::instance": 0x80405ae0,
		"instance": 0x80405ae0,
		"JADHioNode::smCurrentHeap": 0x80405ae8,
		"smCurrentHeap": 0x80405ae8,
		"JSystem::oRandom$356": 0x80405af4,
		"oRandom$356": 0x80405af4,
		"JALSystem::spFManager": 0x80405af8,
		"spFManager": 0x80405af8,
		"JAInter::TAsnData::asnData": 0x80405b00,
		"asnData": 0x80405b00,
		"JAIBasic::basic": 0x80405b08,
		"basic": 0x80405b08,
		"JSystem::_dinfo$1264": 0x80405b0c,
		"_dinfo$1264": 0x80405b0c,
		"JSystem::_info$1317": 0x80405b10,
		"_info$1317": 0x80405b10,
		"JAIConst::random": 0x80405b18,
		"random": 0x80405b18,
		"JAInter::TDebugHeap::currentHeap": 0x80405b20,
		"currentHeap": 0x80405b20,
		"JAInter::StreamLib::adpcm_remain": 0x80405b28,
		"adpcm_remain": 0x80405b28,
		"JAInter::StreamLib::adpcm_loadpoint": 0x80405b2c,
		"adpcm_loadpoint": 0x80405b2c,
		"JAInter::StreamLib::loadsize": 0x80405b30,
		"loadsize": 0x80405b30,
		"JAInter::StreamLib::adpcm_buffer": 0x80405b34,
		"adpcm_buffer": 0x80405b34,
		"JAInter::StreamLib::loop_buffer": 0x80405b38,
		"loop_buffer": 0x80405b38,
		"JAInter::StreamLib::store_buffer": 0x80405b3c,
		"store_buffer": 0x80405b3c,
		"JAInter::StreamLib::assign_ch": 0x80405b40,
		"assign_ch": 0x80405b40,
		"JAInter::StreamLib::playside": 0x80405b48,
		"playside": 0x80405b48,
		"JAInter::StreamLib::playback_samples": 0x80405b4c,
		"playback_samples": 0x80405b4c,
		"JAInter::StreamLib::loadup_samples": 0x80405b50,
		"loadup_samples": 0x80405b50,
		"JAInter::StreamLib::adpcmbuf_state": 0x80405b54,
		"adpcmbuf_state": 0x80405b54,
		"JAInter::StreamLib::movieframe": 0x80405b58,
		"movieframe": 0x80405b58,
		"JAInter::StreamLib::outvolume": 0x80405b64,
		"outvolume": 0x80405b64,
		"JAInter::StreamLib::outpitch": 0x80405b68,
		"outpitch": 0x80405b68,
		"JAInter::StreamLib::outpan": 0x80405b6c,
		"outpan": 0x80405b6c,
		"JAInter::StreamLib::stackvolume": 0x80405b70,
		"stackvolume": 0x80405b70,
		"JAInter::StreamLib::stackpitch": 0x80405b74,
		"stackpitch": 0x80405b74,
		"JAInter::StreamLib::stackpan": 0x80405b78,
		"stackpan": 0x80405b78,
		"JAInter::StreamLib::loop_start_flag": 0x80405b80,
		"loop_start_flag": 0x80405b80,
		"JAInter::StreamLib::outpause": 0x80405b84,
		"outpause": 0x80405b84,
		"JAInter::StreamLib::playmode": 0x80405b88,
		"playmode": 0x80405b88,
		"JAInter::StreamLib::shift_sample": 0x80405b8c,
		"shift_sample": 0x80405b8c,
		"JAInter::StreamLib::extra_sample": 0x80405b90,
		"extra_sample": 0x80405b90,
		"JAInter::StreamLib::DvdLoadFlag": 0x80405b94,
		"DvdLoadFlag": 0x80405b94,
		"JAInter::StreamLib::startInitFlag": 0x80405b98,
		"startInitFlag": 0x80405b98,
		"JAInter::StreamLib::Mode": 0x80405b9c,
		"Mode": 0x80405b9c,
		"JAInter::StreamLib::Head": 0x80405ba0,
		"Head": 0x80405ba0,
		"JSystem::before$612": 0x80405ba8,
		"before$612": 0x80405ba8,
		"JSystem::oldstat$823": 0x80405bb8,
		"oldstat$823": 0x80405bb8,
		"JSystem::old_dspside$839": 0x80405bc0,
		"old_dspside$839": 0x80405bc0,
		"JAIGlobalParameter::interfaceHeapSize": 0x80405bcc,
		"interfaceHeapSize": 0x80405bcc,
		"JAIGlobalParameter::audioResPath": 0x80405bd0,
		"audioResPath": 0x80405bd0,
		"JAIGlobalParameter::minDistanceVolume": 0x80405bd4,
		"minDistanceVolume": 0x80405bd4,
		"JAISound::interPointer": 0x80405bd8,
		"interPointer": 0x80405bd8,
		"JASystem::TBank::sCurrentHeap": 0x80405be0,
		"JASystem::BankMgr::sTableSize": 0x80405be8,
		"JASystem::BankMgr::sBankArray": 0x80405bec,
		"sBankArray": 0x80405bec,
		"JASystem::BankMgr::sVir2PhyTable": 0x80405bf0,
		"sVir2PhyTable": 0x80405bf0,
		"JASystem::BNKParser::sUsedHeapSize": 0x80405bf8,
		"JSystem::oscp$295": 0x80405c00,
		"oscp$295": 0x80405c00,
		"JSystem::oRandom$331": 0x80405c0c,
		"oRandom$331": 0x80405c0c,
		"JASystem::TWaveBank::sCurrentHeap": 0x80405c10,
		"JASystem::WaveBankMgr::sTableSize": 0x80405c18,
		"JASystem::WaveBankMgr::sWaveBank": 0x80405c1c,
		"sWaveBank": 0x80405c1c,
		"JASystem::WSParser::sUsedHeapSize": 0x80405c20,
		"JASystem::AudioThread::isDSPBoot": 0x80405c28,
		"isDSPBoot": 0x80405c28,
		"JASystem::AudioThread::audioproc_mq_init": 0x80405c2c,
		"audioproc_mq_init": 0x80405c2c,
		"JASystem::AudioThread::intcount": 0x80405c30,
		"intcount": 0x80405c30,
		"JASystem::AudioThread::priority_set": 0x80405c34,
		"priority_set": 0x80405c34,
		"JASystem::AudioThread::jac_pri": 0x80405c38,
		"jac_pri": 0x80405c38,
		"JASystem::AudioThread::dvd_pri": 0x80405c3c,
		"dvd_pri": 0x80405c3c,
		"JSystem::first$120": 0x80405c40,
		"first$120": 0x80405c40,
		"JASystem::Driver::DSPQueue::waitp": 0x80405c48,
		"waitp": 0x80405c48,
		"JASystem::Driver::DSPQueue::waittime": 0x80405c4c,
		"waittime": 0x80405c4c,
		"JASystem::Driver::DSPQueue::cur_waits": 0x80405c50,
		"cur_waits": 0x80405c50,
		"JASystem::Driver::DSPQueue::cur_top": 0x80405c54,
		"cur_top": 0x80405c54,
		"JASystem::Driver::DSPQueue::cur_tail": 0x80405c58,
		"cur_tail": 0x80405c58,
		"JASystem::ChGlobal::GLOBAL_CHANNEL": 0x80405c60,
		"GLOBAL_CHANNEL": 0x80405c60,
		"JASystem::ChGlobal::CHANNEL": 0x80405c64,
		"CHANNEL": 0x80405c64,
		"JASystem::ChGlobal::OSCILLATOR": 0x80405c68,
		"OSCILLATOR": 0x80405c68,
		"JASystem::DSPBuf::dac_sync_counter": 0x80405c74,
		"dac_sync_counter": 0x80405c74,
		"JASystem::TDSPChannel::DSPCH": 0x80405c78,
		"DSPCH": 0x80405c78,
		"JASystem::TDSPChannel::smnUse": 0x80405c7c,
		"smnUse": 0x80405c7c,
		"JSystem::first$144": 0x80405c80,
		"first$144": 0x80405c80,
		"JASystem::old_time": 0x80405c88,
		"old_time": 0x80405c88,
		"JASystem::DSPInterface::CH_BUF": 0x80405c90,
		"CH_BUF": 0x80405c90,
		"JASystem::DSPInterface::FX_BUF": 0x80405c94,
		"FX_BUF": 0x80405c94,
		"JASystem::Kernel::JASUniversalDacCounter": 0x80405c98,
		"JASUniversalDacCounter": 0x80405c98,
		"JASystem::Kernel::lastRspMadep": 0x80405c9c,
		"lastRspMadep": 0x80405c9c,
		"JASystem::Kernel::useRspMadep": 0x80405ca0,
		"useRspMadep": 0x80405ca0,
		"JASystem::Kernel::vframeWorkRunning": 0x80405ca4,
		"vframeWorkRunning": 0x80405ca4,
		"JASystem::Kernel::dacCallbackFunc": 0x80405ca8,
		"dacCallbackFunc": 0x80405ca8,
		"JASystem::Kernel::JASVframeCounter": 0x80405cac,
		"JASVframeCounter": 0x80405cac,
		"JASystem::Kernel::extMixCallback": 0x80405cb0,
		"extMixCallback": 0x80405cb0,
		"JSystem::dacp$140": 0x80405cb8,
		"dacp$140": 0x80405cb8,
		"JASystem::Calc::JASC_SINTABLE": 0x80405cc0,
		"JASC_SINTABLE": 0x80405cc0,
		"JASystem::Calc::JASC_DOL2TABLE": 0x80405cc4,
		"JASC_DOL2TABLE": 0x80405cc4,
		"JASystem::Kernel::callList": 0x80405cc8,
		"callList": 0x80405cc8,
		"JSystem::cmd_once": 0x80405cd0,
		"cmd_once": 0x80405cd0,
		"JSystem::cmd_stay": 0x80405cd8,
		"cmd_stay": 0x80405cd8,
		"JASystem::Dvd::mqInit": 0x80405ce0,
		"mqInit": 0x80405ce0,
		"JASystem::Dvd::buffersize": 0x80405ce4,
		"buffersize": 0x80405ce4,
		"JASystem::Dvd::buffers": 0x80405ce8,
		"buffers": 0x80405ce8,
		"JASystem::Dvd::nextBufferSize": 0x80405cec,
		"nextBufferSize": 0x80405cec,
		"JASystem::Dvd::nextBufferTop": 0x80405cf0,
		"nextBufferTop": 0x80405cf0,
		"JASystem::Dvd::nextBuffers": 0x80405cf4,
		"nextBuffers": 0x80405cf4,
		"JASystem::Dvd::audioDvdBuffer": 0x80405cf8,
		"audioDvdBuffer": 0x80405cf8,
		"JASystem::Dvd::bufferLoad": 0x80405d00,
		"bufferLoad": 0x80405d00,
		"JASystem::Dvd::bufferFull": 0x80405d04,
		"bufferFull": 0x80405d04,
		"JASystem::Dvd::callStackArray": 0x80405d08,
		"callStackArray": 0x80405d08,
		"JASystem::Dvd::msgBuf": 0x80405d0c,
		"msgBuf": 0x80405d0c,
		"JASystem::Dvd::curQ": 0x80405d10,
		"curQ": 0x80405d10,
		"JASystem::Dvd::dvdtSleep": 0x80405d14,
		"dvdtSleep": 0x80405d14,
		"JASystem::Dvd::dvdThreadPauseFlag": 0x80405d1c,
		"dvdThreadPauseFlag": 0x80405d1c,
		"JASystem::Dvd::errorCallback": 0x80405d20,
		"errorCallback": 0x80405d20,
		"JASystem::Dvd::dvdFileDics": 0x80405d24,
		"dvdFileDics": 0x80405d24,
		"JASystem::Dvd::dvdFile": 0x80405d28,
		"dvdFile": 0x80405d28,
		"JASystem::Dvd::dvdEntryNum": 0x80405d2c,
		"dvdEntryNum": 0x80405d2c,
		"JSystem::arq_index$316": 0x80405d30,
		"arq_index$316": 0x80405d30,
		"JASystem::HardStream::streamFiles": 0x80405d3c,
		"streamFiles": 0x80405d3c,
		"JASystem::HardStream::playList": 0x80405d40,
		"playList": 0x80405d40,
		"JSystem::cur_finfo$426": 0x80405d44,
		"cur_finfo$426": 0x80405d44,
		"JSystem::last_frame$577": 0x80405d4c,
		"last_frame$577": 0x80405d4c,
		"JASystem::Kernel::global_id": 0x80405d58,
		"global_id": 0x80405d58,
		"JASystem::Kernel::gOutputRate": 0x80405d60,
		"gOutputRate": 0x80405d60,
		"JASystem::Kernel::gAiSetting": 0x80405d64,
		"gAiSetting": 0x80405d64,
		"JSystem::JASDram": 0x80405d68,
		"JASDram": 0x80405d68,
		"JASystem::Kernel::JASAramDmaBufferTop": 0x80405d6c,
		"JASAramDmaBufferTop": 0x80405d6c,
		"JASystem::Kernel::audioAramTop": 0x80405d70,
		"audioAramTop": 0x80405d70,
		"JASystem::Kernel::CARD_SECURITY_BUFFER": 0x80405d74,
		"CARD_SECURITY_BUFFER": 0x80405d74,
		"JASystem::Vload::vlDirName": 0x80405d78,
		"vlDirName": 0x80405d78,
		"JASystem::Vload::vlArcName": 0x80405d7c,
		"vlArcName": 0x80405d7c,
		"JASystem::Vload::vlArc": 0x80405d80,
		"vlArc": 0x80405d80,
		"JASystem::Vload::vlCurrentArcs": 0x80405d84,
		"vlCurrentArcs": 0x80405d84,
		"JASystem::TTrack::sCallBackFunc": 0x80405d8c,
		"sCallBackFunc": 0x80405d8c,
		"JASystem::TrackMgr::sTrackPool": 0x80405d90,
		"sTrackPool": 0x80405d90,
		"JASystem::TrackMgr::sSeqOuter": 0x80405d94,
		"sSeqOuter": 0x80405d94,
		"JASystem::TrackMgr::sRootTrack": 0x80405d98,
		"sRootTrack": 0x80405d98,
		"JASystem::TrackMgr::sFreeSeqpQueue": 0x80405d9c,
		"sFreeSeqpQueue": 0x80405d9c,
		"JASystem::TrackMgr::sRootSeqCount": 0x80405da0,
		"sRootSeqCount": 0x80405da0,
		"JASystem::TrackMgr::sTrackCount": 0x80405da4,
		"sTrackCount": 0x80405da4,
		"JASystem::TrackMgr::sTLists": 0x80405da8,
		"sTLists": 0x80405da8,
		"JASystem::TrackMgr::seqRemain": 0x80405dac,
		"seqRemain": 0x80405dac,
		"JASystem::TrackMgr::getP": 0x80405db0,
		"getP": 0x80405db0,
		"JASystem::TrackMgr::backP": 0x80405db4,
		"backP": 0x80405db4,
		"JSystem::FieldRand": 0x80405db8,
		"FieldRand": 0x80405db8,
		"JPADrawContext::pcb": 0x80405dc0,
		"pcb": 0x80405dc0,
		"JSystem::flag": 0x80405dc8,
		"flag": 0x80405dc8,
		"JSystem::taskreadp": 0x80405dd0,
		"taskreadp": 0x80405dd0,
		"JSystem::taskwritep": 0x80405dd4,
		"taskwritep": 0x80405dd4,
		"JSystem::__DSP_tmp_task": 0x80405dd8,
		"__DSP_tmp_task": 0x80405dd8,
		"JSystem::AUDIO_UPDATE_REQUEST": 0x80405de4,
		"AUDIO_UPDATE_REQUEST": 0x80405de4,
		"JSystem::DSP_prior_task": 0x80405de8,
		"DSP_prior_task": 0x80405de8,
		"Runtime.PPCEABI.H::__global_destructor_chain": 0x80405df0,
		"__global_destructor_chain": 0x80405df0,
		"MSL_C.PPCEABI.bare.H::__aborting": 0x80405df8,
		"__aborting": 0x80405df8,
		"MSL_C.PPCEABI.bare.H::atexit_curr_func": 0x80405dfc,
		"atexit_curr_func": 0x80405dfc,
		"MSL_C.PPCEABI.bare.H::__atexit_curr_func": 0x80405e00,
		"__atexit_curr_func": 0x80405e00,
		"MSL_C.PPCEABI.bare.H::__stdio_exit": 0x80405e04,
		"__stdio_exit": 0x80405e04,
		"MSL_C.PPCEABI.bare.H::__console_exit": 0x80405e08,
		"__console_exit": 0x80405e08,
		"MSL_C.PPCEABI.bare.H::errno": 0x80405e10,
		"errno": 0x80405e10,
		"MSL_C.PPCEABI.bare.H::initialized$16": 0x80405e18,
		"initialized$16": 0x80405e18,
		"db::__DBInterface": 0x80405e20,
		"__DBInterface": 0x80405e20,
		"db::DBVerbose": 0x80405e24,
		"DBVerbose": 0x80405e24,
		"os::BootInfo": 0x80405e28,
		"os::BI2DebugFlag": 0x80405e2c,
		"BI2DebugFlag": 0x80405e2c,
		"os::BI2DebugFlagHolder": 0x80405e30,
		"BI2DebugFlagHolder": 0x80405e30,
		"os::__OSIsGcam": 0x80405e34,
		"__OSIsGcam": 0x80405e34,
		"os::AreWeInitialized": 0x80405e38,
		"AreWeInitialized": 0x80405e38,
		"os::OSExceptionTable": 0x80405e3c,
		"OSExceptionTable": 0x80405e3c,
		"os::__OSSavedRegionEnd": 0x80405e40,
		"__OSSavedRegionEnd": 0x80405e40,
		"os::__OSSavedRegionStart": 0x80405e44,
		"__OSSavedRegionStart": 0x80405e44,
		"os::__OSInIPL": 0x80405e48,
		"__OSInIPL": 0x80405e48,
		"os::AlarmQueue": 0x80405e58,
		"AlarmQueue": 0x80405e58,
		"os::HeapArray": 0x80405e60,
		"HeapArray": 0x80405e60,
		"os::NumHeaps": 0x80405e64,
		"NumHeaps": 0x80405e64,
		"os::ArenaStart": 0x80405e68,
		"ArenaStart": 0x80405e68,
		"os::ArenaEnd": 0x80405e6c,
		"ArenaEnd": 0x80405e6c,
		"os::__OSArenaHi": 0x80405e70,
		"__OSArenaHi": 0x80405e70,
		"os::FontData": 0x80405e78,
		"FontData": 0x80405e78,
		"os::SheetImage": 0x80405e7c,
		"SheetImage": 0x80405e7c,
		"os::WidthTable": 0x80405e80,
		"WidthTable": 0x80405e80,
		"os::CharsInSheet": 0x80405e84,
		"CharsInSheet": 0x80405e84,
		"os::InterruptHandlerTable": 0x80405e88,
		"InterruptHandlerTable": 0x80405e88,
		"os::__OSLastInterruptSrr0": 0x80405e8c,
		"__OSLastInterruptSrr0": 0x80405e8c,
		"os::SaveStart": 0x80405ea0,
		"SaveStart": 0x80405ea0,
		"os::SaveEnd": 0x80405ea4,
		"SaveEnd": 0x80405ea4,
		"os::Prepared": 0x80405ea8,
		"Prepared": 0x80405ea8,
		"os::ResetFunctionQueue": 0x80405eb0,
		"ResetFunctionQueue": 0x80405eb0,
		"os::ResetCallback": 0x80405eb8,
		"ResetCallback": 0x80405eb8,
		"os::Down": 0x80405ebc,
		"Down": 0x80405ebc,
		"os::LastState": 0x80405ec0,
		"os::RunQueueBits": 0x80405ed8,
		"RunQueueBits": 0x80405ed8,
		"os::RunQueueHint": 0x80405edc,
		"RunQueueHint": 0x80405edc,
		"os::Reschedule": 0x80405ee0,
		"Reschedule": 0x80405ee0,
		"dvd::StopAtNextInt": 0x80405ee8,
		"StopAtNextInt": 0x80405ee8,
		"dvd::LastLength": 0x80405eec,
		"LastLength": 0x80405eec,
		"dvd::Callback": 0x80405ef0,
		"dvd::ResetCoverCallback": 0x80405ef4,
		"ResetCoverCallback": 0x80405ef4,
		"dvd::ResetOccurred": 0x80405f00,
		"ResetOccurred": 0x80405f00,
		"dvd::WaitingCoverClose": 0x80405f04,
		"WaitingCoverClose": 0x80405f04,
		"dvd::Breaking": 0x80405f08,
		"Breaking": 0x80405f08,
		"dvd::WorkAroundType": 0x80405f0c,
		"WorkAroundType": 0x80405f0c,
		"dvd::WorkAroundSeekLocation": 0x80405f10,
		"WorkAroundSeekLocation": 0x80405f10,
		"dvd::LastCommandWasRead": 0x80405f28,
		"LastCommandWasRead": 0x80405f28,
		"dvd::NextCommandNumber": 0x80405f2c,
		"NextCommandNumber": 0x80405f2c,
		"dvd::BootInfo": 0x80405f30,
		"dvd::FstStart": 0x80405f34,
		"FstStart": 0x80405f34,
		"dvd::FstStringStart": 0x80405f38,
		"FstStringStart": 0x80405f38,
		"dvd::MaxEntryNum": 0x80405f3c,
		"MaxEntryNum": 0x80405f3c,
		"dvd::currentDirectory": 0x80405f40,
		"currentDirectory": 0x80405f40,
		"dvd::__DVDLongFileNameFlag": 0x80405f44,
		"__DVDLongFileNameFlag": 0x80405f44,
		"dvd::__DVDThreadQueue": 0x80405f48,
		"__DVDThreadQueue": 0x80405f48,
		"dvd::executing": 0x80405f50,
		"executing": 0x80405f50,
		"dvd::currID": 0x80405f54,
		"currID": 0x80405f54,
		"dvd::bootInfo": 0x80405f58,
		"bootInfo": 0x80405f58,
		"dvd::PauseFlag": 0x80405f5c,
		"PauseFlag": 0x80405f5c,
		"dvd::PausingFlag": 0x80405f60,
		"PausingFlag": 0x80405f60,
		"dvd::AutoFinishing": 0x80405f64,
		"AutoFinishing": 0x80405f64,
		"dvd::FatalErrorFlag": 0x80405f68,
		"FatalErrorFlag": 0x80405f68,
		"dvd::CurrCommand": 0x80405f6c,
		"CurrCommand": 0x80405f6c,
		"dvd::Canceling": 0x80405f70,
		"Canceling": 0x80405f70,
		"dvd::CancelCallback": 0x80405f74,
		"CancelCallback": 0x80405f74,
		"dvd::ResumeFromHere": 0x80405f78,
		"ResumeFromHere": 0x80405f78,
		"dvd::CancelLastError": 0x80405f7c,
		"CancelLastError": 0x80405f7c,
		"dvd::LastError": 0x80405f80,
		"LastError": 0x80405f80,
		"dvd::NumInternalRetry": 0x80405f84,
		"NumInternalRetry": 0x80405f84,
		"dvd::ResetRequired": 0x80405f88,
		"ResetRequired": 0x80405f88,
		"dvd::FirstTimeInBootrom": 0x80405f8c,
		"FirstTimeInBootrom": 0x80405f8c,
		"dvd::DVDInitialized": 0x80405f90,
		"DVDInitialized": 0x80405f90,
		"dvd::LastState": 0x80405f94,
		"dvd::status": 0x80405f98,
		"status": 0x80405f98,
		"dvd::bb2": 0x80405f9c,
		"bb2": 0x80405f9c,
		"dvd::idTmp": 0x80405fa0,
		"idTmp": 0x80405fa0,
		"vi::retraceCount": 0x80405fa8,
		"retraceCount": 0x80405fa8,
		"vi::flushFlag": 0x80405fac,
		"flushFlag": 0x80405fac,
		"vi::retraceQueue": 0x80405fb0,
		"retraceQueue": 0x80405fb0,
		"vi::PreCB": 0x80405fb8,
		"PreCB": 0x80405fb8,
		"vi::PostCB": 0x80405fbc,
		"PostCB": 0x80405fbc,
		"vi::encoderType": 0x80405fc0,
		"encoderType": 0x80405fc0,
		"vi::changeMode": 0x80405fc8,
		"vi::shdwChangeMode": 0x80405fd8,
		"shdwChangeMode": 0x80405fd8,
		"vi::CurrTiming": 0x80405fe8,
		"CurrTiming": 0x80405fe8,
		"vi::CurrTvMode": 0x80405fec,
		"CurrTvMode": 0x80405fec,
		"vi::FBSet": 0x80405ff0,
		"FBSet": 0x80405ff0,
		"vi::message$332": 0x80405ff4,
		"message$332": 0x80405ff4,
		"pad::Initialized": 0x80405ff8,
		"pad::EnabledBits": 0x80405ffc,
		"EnabledBits": 0x80405ffc,
		"pad::ResettingBits": 0x80406000,
		"ResettingBits": 0x80406000,
		"pad::RecalibrateBits": 0x80406004,
		"RecalibrateBits": 0x80406004,
		"pad::WaitingBits": 0x80406008,
		"WaitingBits": 0x80406008,
		"pad::CheckingBits": 0x8040600c,
		"CheckingBits": 0x8040600c,
		"pad::PendingBits": 0x80406010,
		"PendingBits": 0x80406010,
		"pad::SamplingCallback": 0x80406014,
		"SamplingCallback": 0x80406014,
		"pad::recalibrated$396": 0x80406018,
		"recalibrated$396": 0x80406018,
		"pad::__PADSpec": 0x8040601c,
		"__PADSpec": 0x8040601c,
		"ai::__AIS_Callback": 0x80406020,
		"__AIS_Callback": 0x80406020,
		"ai::__AID_Callback": 0x80406024,
		"__AID_Callback": 0x80406024,
		"ai::__CallbackStack": 0x80406028,
		"__CallbackStack": 0x80406028,
		"ai::__OldStack": 0x8040602c,
		"__OldStack": 0x8040602c,
		"ai::__AI_init_flag": 0x80406030,
		"__AI_init_flag": 0x80406030,
		"ar::__AR_Callback": 0x80406060,
		"__AR_Callback": 0x80406060,
		"ar::__AR_Size": 0x80406064,
		"__AR_Size": 0x80406064,
		"ar::__AR_InternalSize": 0x80406068,
		"__AR_InternalSize": 0x80406068,
		"ar::__AR_ExpansionSize": 0x8040606c,
		"__AR_ExpansionSize": 0x8040606c,
		"ar::__AR_StackPointer": 0x80406070,
		"__AR_StackPointer": 0x80406070,
		"ar::__AR_FreeBlocks": 0x80406074,
		"__AR_FreeBlocks": 0x80406074,
		"ar::__AR_BlockLength": 0x80406078,
		"__AR_BlockLength": 0x80406078,
		"ar::__AR_init_flag": 0x8040607c,
		"__AR_init_flag": 0x8040607c,
		"ar::__ARQRequestQueueHi": 0x80406080,
		"__ARQRequestQueueHi": 0x80406080,
		"ar::__ARQRequestTailHi": 0x80406084,
		"__ARQRequestTailHi": 0x80406084,
		"ar::__ARQRequestQueueLo": 0x80406088,
		"__ARQRequestQueueLo": 0x80406088,
		"ar::__ARQRequestTailLo": 0x8040608c,
		"__ARQRequestTailLo": 0x8040608c,
		"ar::__ARQRequestPendingHi": 0x80406090,
		"__ARQRequestPendingHi": 0x80406090,
		"ar::__ARQRequestPendingLo": 0x80406094,
		"__ARQRequestPendingLo": 0x80406094,
		"ar::__ARQCallbackHi": 0x80406098,
		"__ARQCallbackHi": 0x80406098,
		"ar::__ARQCallbackLo": 0x8040609c,
		"__ARQCallbackLo": 0x8040609c,
		"ar::__ARQChunkSize": 0x804060a0,
		"__ARQChunkSize": 0x804060a0,
		"ar::__ARQ_init_flag": 0x804060a4,
		"__ARQ_init_flag": 0x804060a4,
		"dsp::__DSP_init_flag": 0x804060a8,
		"__DSP_init_flag": 0x804060a8,
		"dsp::__DSP_last_task": 0x804060b0,
		"__DSP_last_task": 0x804060b0,
		"dsp::__DSP_first_task": 0x804060b4,
		"__DSP_first_task": 0x804060b4,
		"dsp::__DSP_curr_task": 0x804060b8,
		"__DSP_curr_task": 0x804060b8,
		"gx::__piReg": 0x804060c0,
		"__piReg": 0x804060c0,
		"gx::__cpReg": 0x804060c4,
		"__cpReg": 0x804060c4,
		"gx::__peReg": 0x804060c8,
		"__peReg": 0x804060c8,
		"gx::__memReg": 0x804060cc,
		"__memReg": 0x804060cc,
		"gx::CPUFifo": 0x804060d0,
		"CPUFifo": 0x804060d0,
		"gx::GPFifo": 0x804060d4,
		"GPFifo": 0x804060d4,
		"gx::__GXCurrentThread": 0x804060d8,
		"__GXCurrentThread": 0x804060d8,
		"gx::GXOverflowSuspendInProgress": 0x804060e0,
		"GXOverflowSuspendInProgress": 0x804060e0,
		"gx::BreakPointCB": 0x804060e4,
		"BreakPointCB": 0x804060e4,
		"gx::__GXOverflowCount": 0x804060e8,
		"__GXOverflowCount": 0x804060e8,
		"gx::__GXCurrentBP": 0x804060ec,
		"__GXCurrentBP": 0x804060ec,
		"gx::TokenCB": 0x804060f0,
		"TokenCB": 0x804060f0,
		"gx::DrawDoneCB": 0x804060f4,
		"DrawDoneCB": 0x804060f4,
		"gx::FinishQueue": 0x804060fc,
		"FinishQueue": 0x804060fc,
		"OdemuExi2::MTRCallback": 0x80406108,
		"MTRCallback": 0x80406108,
		"OdemuExi2::DBGCallback": 0x8040610c,
		"DBGCallback": 0x8040610c,
		"OdemuExi2::SendMailData": 0x80406110,
		"SendMailData": 0x80406110,
		"OdemuExi2::RecvDataLeng": 0x80406114,
		"RecvDataLeng": 0x80406114,
		"OdemuExi2::pEXIInputFlag": 0x80406118,
		"pEXIInputFlag": 0x80406118,
		"gd::__GDCurrentDL": 0x80406120,
		"__GDCurrentDL": 0x80406120,
		"gd::overflowcb": 0x80406124,
		"overflowcb": 0x80406124,
		"si::cmdTypeAndStatus$77": 0x80406128,
		"cmdTypeAndStatus$77": 0x80406128,
		"si::cmdTypeAndStatus$371": 0x8040612c,
		"cmdTypeAndStatus$371": 0x8040612c,
		"si::__PADFixBits": 0x80406130,
		"__PADFixBits": 0x80406130,
		"si::SamplingRate": 0x80406138,
		"SamplingRate": 0x80406138,
		"exi::Chan": 0x80406140,
		"Chan": 0x80406140,
		"exi::Dev": 0x80406144,
		"Dev": 0x80406144,
		"exi::Enabled": 0x80406148,
		"Enabled": 0x80406148,
		"exi::BarnacleEnabled": 0x8040614c,
		"BarnacleEnabled": 0x8040614c,
		"thp::__THPHuffmanBits": 0x80406204,
		"__THPHuffmanBits": 0x80406204,
		"thp::__THPHuffmanSizeTab": 0x80406208,
		"__THPHuffmanSizeTab": 0x80406208,
		"thp::__THPHuffmanCodeTab": 0x8040620c,
		"__THPHuffmanCodeTab": 0x8040620c,
		"thp::__THPOldGQR5": 0x80406264,
		"__THPOldGQR5": 0x80406264,
		"thp::__THPOldGQR6": 0x80406268,
		"__THPOldGQR6": 0x80406268,
		"thp::__THPWorkArea": 0x8040626c,
		"__THPWorkArea": 0x8040626c,
		"thp::__THPInfo": 0x80406270,
		"__THPInfo": 0x80406270,
		"thp::__THPInitFlag": 0x80406274,
		"__THPInitFlag": 0x80406274,
		"THPPlayer::AudioDecodeThreadCreated": 0x804047d8,
		"AudioDecodeThreadCreated": 0x804047d8,
		"THPPlayer::Initialized": 0x804047e0,
		"THPPlayer::PrepareReadyMessage": 0x804047e4,
		"PrepareReadyMessage": 0x804047e4,
		"THPPlayer::OldVIPostCallback": 0x804047e8,
		"OldVIPostCallback": 0x804047e8,
		"THPPlayer::SoundBufferIndex": 0x804047ec,
		"SoundBufferIndex": 0x804047ec,
		"THPPlayer::LastAudioBuffer": 0x804047f0,
		"LastAudioBuffer": 0x804047f0,
		"THPPlayer::CurAudioBuffer": 0x804047f4,
		"CurAudioBuffer": 0x804047f4,
		"THPPlayer::ReadThreadCreated": 0x804047f8,
		"ReadThreadCreated": 0x804047f8,
		"THPPlayer::VideoDecodeThreadCreated": 0x80404800,
		"VideoDecodeThreadCreated": 0x80404800,
		"THPPlayer::First": 0x80404804,
		"First": 0x80404804,
		"MarioUtil::gpSilhouetteManager": 0x80405758,
		"gpSilhouetteManager": 0x80405758,
		"MarioUtil::sKeepViewClipFovy": 0x8040575c,
		"sKeepViewClipFovy": 0x8040575c,
		"MarioUtil::sKeepViewClipAspect": 0x80405760,
		"sKeepViewClipAspect": 0x80405760,
		"MarioUtil::sKeepViewClipNear": 0x80405764,
		"sKeepViewClipNear": 0x80405764,
		"MarioUtil::sKeepViewClipFar": 0x80405768,
		"sKeepViewClipFar": 0x80405768,
		"TLightCommon::mAmbAry": 0x80405770,
		"mAmbAry": 0x80405770,
		"TLightCommon::mLightAry": 0x80405774,
		"mLightAry": 0x80405774,
		"TLightCommon::mLightPos": 0x80405778,
		"mLightPos": 0x80405778,
		"MarioUtil::gpLightManager": 0x8040577c,
		"gpLightManager": 0x8040577c,
		"MarioUtil::gpAfterEffect": 0x80405780,
		"gpAfterEffect": 0x80405780,
		"MarioUtil::gpScreenTexture": 0x80405784,
		"gpScreenTexture": 0x80405784,
		"MarioUtil::gpBindShadowManager": 0x80405788,
		"gpBindShadowManager": 0x80405788,
		"TMBindShadowManager::mJoinDist": 0x8040578c,
		"mJoinDist": 0x8040578c,
		"MarioUtil::SMSRumbleMgr": 0x80405798,
		"SMSRumbleMgr": 0x80405798,
		"MarioUtil::currentTGDLStatic": 0x804057a0,
		"currentTGDLStatic": 0x804057a0,
		"System::gpMarioParticleManager": 0x80405818,
		"gpMarioParticleManager": 0x80405818,
		"System::emitterCallBackBindToPosPtr": 0x8040581c,
		"emitterCallBackBindToPosPtr": 0x8040581c,
		"System::emitterCallBackBindToMtxPtr": 0x80405820,
		"emitterCallBackBindToMtxPtr": 0x80405820,
		"System::emitterCallBackBindToSRTMtxPtr": 0x80405824,
		"emitterCallBackBindToSRTMtxPtr": 0x80405824,
		"TFlagManager::smInstance": 0x80405828,
		"System::gpSceneCmnDat": 0x80405830,
		"gpSceneCmnDat": 0x80405830,
		"System::gpSceneCmnDatSize": 0x80405834,
		"gpSceneCmnDatSize": 0x80405834,
		"TParams::mArc": 0x80405838,
		"mArc": 0x80405838,
		"TParams::mSceneArc": 0x8040583c,
		"mSceneArc": 0x8040583c,
		"System::gpMarDirector": 0x80405840,
		"gpMarDirector": 0x80405840,
		"System::gpMSound": 0x80405844,
		"gpMSound": 0x80405844,
		"System::gpSetupThreadStack": 0x80405848,
		"gpSetupThreadStack": 0x80405848,
		"System::gpCardManager": 0x8040584c,
		"gpCardManager": 0x8040584c,
		"System::gpSystemFont": 0x80405850,
		"gpSystemFont": 0x80405850,
		"System::gpRomFont": 0x80405854,
		"gpRomFont": 0x80405854,
		"System::sGameInit": 0x80405858,
		"sGameInit": 0x80405858,
		"System::arcBufNLogo": 0x8040585c,
		"arcBufNLogo": 0x8040585c,
		"System::arcBufMario": 0x80405860,
		"arcBufMario": 0x80405860,
		"System::arcBufCmn": 0x80405864,
		"arcBufCmn": 0x80405864,
		"System::bufStageArcBin": 0x80405868,
		"bufStageArcBin": 0x80405868,
		"System::spGameHeapBlock": 0x8040586c,
		"spGameHeapBlock": 0x8040586c,
		"System::gArBkConsole": 0x80405870,
		"gArBkConsole": 0x80405870,
		"System::gArBkGuide": 0x80405878,
		"gArBkGuide": 0x80405878,
		"TMarioGamePad::mResetFlag": 0x80405890,
		"mResetFlag": 0x80405890,
		"System::gpPositionHolder": 0x80405898,
		"gpPositionHolder": 0x80405898,
		"TTimeRec::_instance": 0x804058a0,
		"_instance": 0x804058a0,
		"TDrawSyncManager::smInstance": 0x804058a8,
		"System::sDetach": 0x804058b0,
		"sDetach": 0x804058b0,
		"System::gpResourceManager": 0x804058b8,
		"gpResourceManager": 0x804058b8,
		"System::gpEmitterManager4D2": 0x804058bc,
		"gpEmitterManager4D2": 0x804058bc,
		"MSMainProc::MSStageInfo::msStg": 0x804058c0,
		"msStg": 0x804058c0,
		"MSMainProc::MSStageInfo::demoBgm": 0x804058c4,
		"demoBgm": 0x804058c4,
		"MSMainProc::MSStageInfo::stageBgm": 0x804058c8,
		"stageBgm": 0x804058c8,
		"MSMainProc::MSStageInfo::stageBgmSilent": 0x804058cc,
		"stageBgmSilent": 0x804058cc,
		"MSMainProc::MSStageInfo::switchBgm": 0x804058d8,
		"switchBgm": 0x804058d8,
		"MSMainProc::MSStageInfo::switchBgm2": 0x804058dc,
		"switchBgm2": 0x804058dc,
		"MSMainProc::MSStageInfo::cubeFadeRatio": 0x804058e0,
		"cubeFadeRatio": 0x804058e0,
		"MSStage::smMSStage": 0x804058ec,
		"smMSStage": 0x804058ec,
		"System::gpTargetArrow": 0x804058f8,
		"gpTargetArrow": 0x804058f8,
		"Strategic::gpObjHitCheck": 0x80405738,
		"gpObjHitCheck": 0x80405738,
		"Strategic::gpStrategy": 0x80405748,
		"gpStrategy": 0x80405748,
		"Strategic::gpQuestionManager": 0x80405750,
		"gpQuestionManager": 0x80405750,
		"Player::gpMarioForCallBack": 0x804057a8,
		"gpMarioForCallBack": 0x804057a8,
		"Player::gpMarioOriginal": 0x804057b0,
		"gpMarioOriginal": 0x804057b0,
		"Player::bubbleCallBack": 0x804057bc,
		"bubbleCallBack": 0x804057bc,
		"Player::warpInCallBack": 0x804057c4,
		"warpInCallBack": 0x804057c4,
		"Player::gpSplashManager": 0x804057c8,
		"gpSplashManager": 0x804057c8,
		"Player::gpMarioAddress": 0x804057d0,
		"gpMarioAddress": 0x804057d0,
		"Player::gpMarioPos": 0x804057d4,
		"gpMarioPos": 0x804057d4,
		"Player::gpMarioAngleX": 0x804057d8,
		"gpMarioAngleX": 0x804057d8,
		"Player::gpMarioAngleY": 0x804057dc,
		"gpMarioAngleY": 0x804057dc,
		"Player::gpMarioAngleZ": 0x804057e0,
		"gpMarioAngleZ": 0x804057e0,
		"Player::gpMarioSpeedX": 0x804057e4,
		"gpMarioSpeedX": 0x804057e4,
		"Player::gpMarioSpeedY": 0x804057e8,
		"gpMarioSpeedY": 0x804057e8,
		"Player::gpMarioSpeedZ": 0x804057ec,
		"gpMarioSpeedZ": 0x804057ec,
		"Player::gpMarioLightID": 0x804057f0,
		"gpMarioLightID": 0x804057f0,
		"Player::gpMarioFlag": 0x804057f4,
		"gpMarioFlag": 0x804057f4,
		"Player::gpMarioThrowPower": 0x804057f8,
		"gpMarioThrowPower": 0x804057f8,
		"Player::gpMarioGroundPlane": 0x804057fc,
		"gpMarioGroundPlane": 0x804057fc,
		"Player::gpModelWaterManager": 0x80405800,
		"gpModelWaterManager": 0x80405800,
		"Player::sphere_glist_p": 0x80405808,
		"sphere_glist_p": 0x80405808,
		"Player::sphere_pos_t": 0x8040580c,
		"sphere_pos_t": 0x8040580c,
		"TBaseNPC::mPtrSaveNormal": 0x80405668,
		"mPtrSaveNormal": 0x80405668,
		"NPC::gpCurrentNpc": 0x80405670,
		"gpCurrentNpc": 0x80405670,
		"TMonteMBaseManager::mStaticCommonKeeper": 0x80405678,
		"TMonteWBaseManager::mStaticCommonKeeper": 0x8040567c,
		"TMareMBaseManager::mStaticCommonKeeper": 0x80405680,
		"TMareWBaseManager::mStaticCommonKeeper": 0x80405684,
		"TMareBaseManager::mStaticBmtNormal": 0x80405688,
		"mStaticBmtNormal": 0x80405688,
		"TMareBaseManager::mStaticBmtPollution": 0x8040568c,
		"mStaticBmtPollution": 0x8040568c,
		"NPC::gpMareJellyFishManager": 0x80405690,
		"gpMareJellyFishManager": 0x80405690,
		"NPC::instance$2212": 0x8040569c,
		"instance$2212": 0x8040569c,
		"NPC::instance$2243": 0x804056a4,
		"instance$2243": 0x804056a4,
		"NPC::instance$2251": 0x804056ac,
		"instance$2251": 0x804056ac,
		"NPC::instance$2264": 0x804056b4,
		"NPC::instance$2275": 0x804056bc,
		"instance$2275": 0x804056bc,
		"NPC::instance$2303": 0x804056c4,
		"instance$2303": 0x804056c4,
		"NPC::instance$2349": 0x804056cc,
		"instance$2349": 0x804056cc,
		"NPC::instance$2359": 0x804056d4,
		"NPC::instance$2365": 0x804056dc,
		"instance$2365": 0x804056dc,
		"NPC::instance$2373": 0x804056e4,
		"instance$2373": 0x804056e4,
		"NPC::instance$2384": 0x804056ec,
		"instance$2384": 0x804056ec,
		"NPC::instance$2390": 0x804056f4,
		"instance$2390": 0x804056f4,
		"NPC::instance$2404": 0x804056fc,
		"instance$2404": 0x804056fc,
		"NPC::instance$2414": 0x80405704,
		"instance$2414": 0x80405704,
		"NPC::instance$2424": 0x8040570c,
		"instance$2424": 0x8040570c,
		"NPC::instance$2436": 0x80405714,
		"instance$2436": 0x80405714,
		"TNpcEvent::mDownSunflowerNum": 0x80405718,
		"mDownSunflowerNum": 0x80405718,
		"TBaseNPC::sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x80405728,
		"sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x80405728,
		"TNpcTrample::msAmpDecrease": 0x80405730,
		"msAmpDecrease": 0x80405730,
		"MSound::MSGMSound": 0x804047bc,
		"MSGMSound": 0x804047bc,
		"MSound::MSGBasic": 0x804047c0,
		"MSGBasic": 0x804047c0,
		"MSoundSESystem::MSoundSE::mObj": 0x804047c8,
		"mObj": 0x804047c8,
		"MSoundSESystem::SeInfo::smSeSetting": 0x804047cc,
		"smSeSetting": 0x804047cc,
		"MoveBG::gpMapObjManager": 0x804055d0,
		"gpMapObjManager": 0x804055d0,
		"MoveBG::gpItemManager": 0x804055d8,
		"gpItemManager": 0x804055d8,
		"MoveBG::gpMapObjSwitch": 0x804055e0,
		"gpMapObjSwitch": 0x804055e0,
		"MoveBG::sAngleAdd": 0x804055e8,
		"sAngleAdd": 0x804055e8,
		"MoveBG::gpCurObject": 0x804055f0,
		"gpCurObject": 0x804055f0,
		"TRiccoWatermill::mSubmarineSurfaceTransY": 0x804055f8,
		"mSubmarineSurfaceTransY": 0x804055f8,
		"MoveBG::switchSnd": 0x80405600,
		"switchSnd": 0x80405600,
		"MoveBG::gpMapObjFlagManager": 0x80405608,
		"gpMapObjFlagManager": 0x80405608,
		"MoveBG::sColor": 0x80405618,
		"sColor": 0x80405618,
		"MoveBG::gpMapObjWave": 0x8040561c,
		"gpMapObjWave": 0x8040561c,
		"MoveBG::timer$2477": 0x80405620,
		"timer$2477": 0x80405620,
		"TMapObjGrassManager::mColorUpper": 0x80405630,
		"TMapObjGrassManager::mColorLower": 0x80405634,
		"TMapObjGrassManager::mColorFar": 0x80405638,
		"mColorFar": 0x80405638,
		"TMapObjGrassManager::mDrawVecS16": 0x8040563c,
		"mDrawVecS16": 0x8040563c,
		"MoveBG::gpMapObjGrassManager": 0x80405644,
		"gpMapObjGrassManager": 0x80405644,
		"MoveBG::gpMapObjPoleManager": 0x80405648,
		"gpMapObjPoleManager": 0x80405648,
		"THangingBridge::mRopeHeight": 0x80405650,
		"mRopeHeight": 0x80405650,
		"MoveBG::gpPoolManager": 0x80405658,
		"gpPoolManager": 0x80405658,
		"Map::gpMap": 0x80405560,
		"gpMap": 0x80405560,
		"Map::gpMapCollisionData": 0x80405568,
		"gpMapCollisionData": 0x80405568,
		"Map::gpMirrorModelManager": 0x80405570,
		"gpMirrorModelManager": 0x80405570,
		"TMapStaticObj::mEffectCoronaScale": 0x80405578,
		"mEffectCoronaScale": 0x80405578,
		"Map::gpMapWireManager": 0x80405580,
		"gpMapWireManager": 0x80405580,
		"TMapWireManager::mUpperSurface": 0x80405584,
		"mUpperSurface": 0x80405584,
		"TMapWireManager::mLowerSurface": 0x80405588,
		"mLowerSurface": 0x80405588,
		"Map::counter$2576": 0x80405590,
		"counter$2576": 0x80405590,
		"Map::gpPollution": 0x80405598,
		"gpPollution": 0x80405598,
		"Map::effect_counter$2421": 0x804055a0,
		"effect_counter$2421": 0x804055a0,
		"Map::now_pos_no$2429": 0x804055a8,
		"now_pos_no$2429": 0x804055a8,
		"Map::counter_x$2434": 0x804055b0,
		"counter_x$2434": 0x804055b0,
		"Map::counter_z$2437": 0x804055b8,
		"counter_z$2437": 0x804055b8,
		"Map::effect_timer$2449": 0x804055c0,
		"effect_timer$2449": 0x804055c0,
		"Map::delta$2349": 0x804055c8,
		"delta$2349": 0x804055c8,
		"TGCConsole2::cDownTopPoint": 0x80405410,
		"cDownTopPoint": 0x80405410,
		"TGCConsole2::cDownMidPoint": 0x80405418,
		"cDownMidPoint": 0x80405418,
		"TGCConsole2::cDownBotPoint": 0x80405420,
		"cDownBotPoint": 0x80405420,
		"TGCConsole2::cUpTopPoint": 0x80405428,
		"cUpTopPoint": 0x80405428,
		"TGCConsole2::cUpMidPoint": 0x80405430,
		"cUpMidPoint": 0x80405430,
		"TGCConsole2::cUpBotPoint": 0x80405438,
		"cUpBotPoint": 0x80405438,
		"TGCConsole2::cCoinTopPoint": 0x80405440,
		"cCoinTopPoint": 0x80405440,
		"TGCConsole2::cCoinMidPoint": 0x80405448,
		"cCoinMidPoint": 0x80405448,
		"TGCConsole2::cCoinBotPoint": 0x80405450,
		"cCoinBotPoint": 0x80405450,
		"GC2D::gpTalk2D": 0x80405458,
		"gpTalk2D": 0x80405458,
		"GC2D::gpCardLoad": 0x80405460,
		"gpCardLoad": 0x80405460,
		"TConsoleStr::cShineGetRight1": 0x80405468,
		"cShineGetRight1": 0x80405468,
		"TConsoleStr::cShineGetLeft1": 0x80405470,
		"cShineGetLeft1": 0x80405470,
		"TConsoleStr::cShineGetRight2": 0x80405478,
		"cShineGetRight2": 0x80405478,
		"TConsoleStr::cShineGetLeft2": 0x80405480,
		"cShineGetLeft2": 0x80405480,
		"TConsoleStr::cShineGetRight3": 0x80405488,
		"cShineGetRight3": 0x80405488,
		"TConsoleStr::cShineGetLeft3": 0x80405490,
		"cShineGetLeft3": 0x80405490,
		"GC2D::vtable": 0x804054a4,
		"vtable": 0x804054a4,
		"GC2D::hxs_logo_resetflag": 0x80405508,
		"hxs_logo_resetflag": 0x80405508,
		"GC2D::hxs_logodraw_resetflag": 0x8040550c,
		"hxs_logodraw_resetflag": 0x8040550c,
		"Enemy::gpConductor": 0x80404870,
		"gpConductor": 0x80404870,
		"Enemy::gpEffectObjManager": 0x80404878,
		"gpEffectObjManager": 0x80404878,
		"Enemy::gpCurGesso": 0x80404880,
		"gpCurGesso": 0x80404880,
		"Enemy::gpCurNameKuri": 0x80404978,
		"gpCurNameKuri": 0x80404978,
		"Enemy::gpCurPakkun": 0x804049b8,
		"gpCurPakkun": 0x804049b8,
		"Enemy::gpCurPakkunSeed": 0x804049bc,
		"gpCurPakkunSeed": 0x804049bc,
		"Enemy::instance$2166": 0x80404a34,
		"instance$2166": 0x80404a34,
		"Enemy::instance$3999": 0x80404c48,
		"instance$3999": 0x80404c48,
		"Enemy::gpCurTobiPuku": 0x80404c60,
		"gpCurTobiPuku": 0x80404c60,
		"Enemy::gpCurChuuHana": 0x80404d38,
		"gpCurChuuHana": 0x80404d38,
		"Enemy::instance$3238": 0x80404d80,
		"instance$3238": 0x80404d80,
		"Enemy::gpCurRollEnemy": 0x80404d98,
		"gpCurRollEnemy": 0x80404d98,
		"TRollEnemy::mTransYOffset": 0x80404d9c,
		"mTransYOffset": 0x80404d9c,
		"Enemy::testHeight": 0x80404f58,
		"testHeight": 0x80404f58,
		"Enemy::gpCurKiller": 0x80404f98,
		"gpCurKiller": 0x80404f98,
		"Enemy::gpBeamManager": 0x80404fb8,
		"gpBeamManager": 0x80404fb8,
		"Enemy::gpCurSamboHead": 0x80404fc4,
		"gpCurSamboHead": 0x80404fc4,
		"Enemy::gpCurPopo": 0x80405028,
		"gpCurPopo": 0x80405028,
		"TPopo::mTestAng_z": 0x8040502c,
		"Enemy::instance$2264": 0x80405064,
		"Enemy::instance$2270": 0x8040506c,
		"instance$2270": 0x8040506c,
		"Enemy::sCommonSaveFileName$2709": 0x80405080,
		"sCommonSaveFileName$2709": 0x80405080,
		"Enemy::instance$2359": 0x8040508c,
		"Enemy::instance$2371": 0x80405094,
		"instance$2371": 0x80405094,
		"Enemy::instance$2383": 0x8040509c,
		"instance$2383": 0x8040509c,
		"Enemy::instance$2391": 0x804050a4,
		"instance$2391": 0x804050a4,
		"Enemy::instance$2399": 0x804050ac,
		"instance$2399": 0x804050ac,
		"Enemy::instance$2408": 0x804050b4,
		"instance$2408": 0x804050b4,
		"Enemy::instance$2423": 0x804050bc,
		"instance$2423": 0x804050bc,
		"Enemy::instance$2838": 0x80405134,
		"instance$2838": 0x80405134,
		"Enemy::instance$2856": 0x8040513c,
		"instance$2856": 0x8040513c,
		"Enemy::gpCurHauntLeg": 0x80405148,
		"gpCurHauntLeg": 0x80405148,
		"TRocket::mTestAng_x": 0x80405190,
		"TRocket::mTestAng_z": 0x80405194,
		"Enemy::instance$2918": 0x804051f4,
		"instance$2918": 0x804051f4,
		"Enemy::instance$2924": 0x804051fc,
		"instance$2924": 0x804051fc,
		"Enemy::instance$2930": 0x80405204,
		"instance$2930": 0x80405204,
		"Enemy::instance$2936": 0x8040520c,
		"instance$2936": 0x8040520c,
		"Enemy::instance$2942": 0x80405214,
		"instance$2942": 0x80405214,
		"TBossManta::sCenterJointIndex": 0x80405218,
		"sCenterJointIndex": 0x80405218,
		"TBossManta::sBodyJointIndex": 0x8040521c,
		"sBodyJointIndex": 0x8040521c,
		"TBossManta::sRwingJointIndex": 0x80405220,
		"sRwingJointIndex": 0x80405220,
		"TBossManta::sLwingJointIndex": 0x80405224,
		"sLwingJointIndex": 0x80405224,
		"Enemy::sDefeatSE$3156": 0x8040522c,
		"sDefeatSE$3156": 0x8040522c,
		"TNerveKoopaTurnR::nerve$localstatic0$theNerve": 0x804052e4,
		"TNerveKoopaTurnL::nerve$localstatic0$theNerve": 0x804052ec,
		"TNerveKoopaTumble::nerve$localstatic0$theNerve": 0x804052f4,
		"TNerveKoopaProvoke::nerve$localstatic0$theNerve": 0x804052fc,
		"TNerveKoopaWait::nerve$localstatic0$theNerve": 0x80405304,
		"TNerveKoopaFlame::nerve$localstatic0$theNerve": 0x8040530c,
		"TNerveKoopaGetDown::nerve$localstatic0$theNerve": 0x80405314,
		"TNerveKoopaStagger::nerve$localstatic0$theNerve": 0x8040531c,
		"TNerveKoopaFall::nerve$localstatic0$theNerve": 0x80405324,
		"TNerveKoopaGetShowered::nerve$localstatic0$theNerve": 0x8040532c,
		"TNervePeachStagger::nerve$localstatic0$theNerve": 0x8040537c,
		"TNervePeachEscape::nerve$localstatic0$theNerve": 0x80405384,
		"@unnamed@::cAngleMax": 0x804053d0,
		"cAngleMax": 0x804053d0,
		"Camera::gpCamera": 0x80404808,
		"gpCamera": 0x80404808,
		"Camera::gpCameraMario": 0x80404810,
		"gpCameraMario": 0x80404810,
		"Camera::gpCameraShake": 0x80404818,
		"gpCameraShake": 0x80404818,
		"Camera::gpSunMgr": 0x80404820,
		"gpSunMgr": 0x80404820,
		"Camera::gpSunModel": 0x80404828,
		"gpSunModel": 0x80404828,
		"Camera::gpCubeCamera": 0x80404830,
		"gpCubeCamera": 0x80404830,
		"Camera::gpCubeMirror": 0x80404834,
		"gpCubeMirror": 0x80404834,
		"Camera::gpCubeWire": 0x80404838,
		"gpCubeWire": 0x80404838,
		"Camera::gpCubeStream": 0x8040483c,
		"gpCubeStream": 0x8040483c,
		"Camera::gpCubeShadow": 0x80404840,
		"gpCubeShadow": 0x80404840,
		"Camera::gpCubeArea": 0x80404844,
		"gpCubeArea": 0x80404844,
		"Camera::gpCubeFastA": 0x80404848,
		"gpCubeFastA": 0x80404848,
		"Camera::gpCubeFastB": 0x8040484c,
		"gpCubeFastB": 0x8040484c,
		"Camera::gpCubeFastC": 0x80404850,
		"gpCubeFastC": 0x80404850,
		"Camera::gpCubeSoundChange": 0x80404854,
		"gpCubeSoundChange": 0x80404854,
		"Camera::gpCubeSoundEffect": 0x80404858,
		"gpCubeSoundEffect": 0x80404858,
		"Camera::gpCamMapToolTable": 0x80404860,
		"gpCamMapToolTable": 0x80404860,
		"Camera::gpCameraOption": 0x80404868,
		"gpCameraOption": 0x80404868,
		"Animal::instance$2000": 0x80404734,
		"instance$2000": 0x80404734,
		"Animal::instance$3025": 0x8040473c,
		"Animal::instance$3040": 0x80404744,
		"instance$3040": 0x80404744,
		"Animal::instance$3055": 0x8040474c,
		"Animal::instance$3067": 0x80404754,
		"instance$3067": 0x80404754,
		"Animal::instance$3077": 0x8040475c,
		"instance$3077": 0x8040475c,
		"Animal::instance$3096": 0x80404764,
		"instance$3096": 0x80404764,
		"Animal::instance$3104": 0x8040476c,
		"instance$3104": 0x8040476c,
		"Animal::instance$3116": 0x80404774,
		"instance$3116": 0x80404774,
		"Animal::instance$3128": 0x8040477c,
		"@unnamed@::cAngleLimit": 0x80404780,
		"cAngleLimit": 0x80404780,
		"Animal::instance$2989": 0x80404788,
		"instance$2989": 0x80404788,
		"Animal::instance$3003": 0x80404790,
		"instance$3003": 0x80404790,
		"Animal::instance$3013": 0x80404798,
		"Animal::instance$3023": 0x804047a0,
		"instance$3023": 0x804047a0,
		"Animal::instance$3035": 0x804047a8,
		"Animal::instance$3047": 0x804047b0,
		"instance$3047": 0x804047b0,
		"Animal::@2344": 0x804062e8,
		"Animal::@2367": 0x804062f0,
		"Animal::@2459": 0x80406304,
		"Animal::@2460": 0x80406308,
		"Animal::@2461": 0x8040630c,
		"Animal::@2462": 0x80406310,
		"Animal::@2632": 0x80406314,
		"Animal::@2633": 0x80406318,
		"Animal::@2694": 0x8040631c,
		"Animal::@2185": 0x804063c0,
		"Animal::@2186": 0x804063c4,
		"Animal::@2198": 0x804063c8,
		"Animal::@2204": 0x804063cc,
		"MSound::@1986": 0x80406554,
		"MSound::@1987": 0x80406558,
		"MSound::@2470": 0x80406578,
		"MSound::@2528": 0x8040657c,
		"MSound::@2602": 0x80406580,
		"MSound::@2603": 0x80406584,
		"MSound::@2622": 0x80406590,
		"MSound::@2623": 0x80406594,
		"MSound::@2984": 0x804065b8,
		"MSound::@2985": 0x804065bc,
		"MSound::@2986": 0x804065c0,
		"MSound::@3109": 0x804065c4,
		"MSound::@3450": 0x804065c8,
		"MSound::@3451": 0x804065cc,
		"MSound::@3456": 0x804065d0,
		"MSound::@2940": 0x80406764,
		"MSound::@2941": 0x80406768,
		"MSound::@2942": 0x8040676c,
		"MSound::@2943": 0x80406770,
		"MSound::@3170": 0x80406780,
		"THPPlayer::@435": 0x804068b8,
		"THPPlayer::@484": 0x804068bc,
		"@484": 0x804068bc,
		"THPPlayer::@796": 0x804068c0,
		"@796": 0x804068c0,
		"THPPlayer::@797": 0x804068c4,
		"Camera::@2334": 0x80406900,
		"Camera::@3713": 0x80406908,
		"Camera::@3714": 0x8040690c,
		"Camera::@2641": 0x80406920,
		"Camera::@2642": 0x80406924,
		"Camera::@2661": 0x80406928,
		"Camera::@2662": 0x8040692c,
		"Camera::@2663": 0x80406930,
		"Camera::@2750": 0x80406948,
		"Camera::@2751": 0x8040694c,
		"Camera::@2752": 0x80406950,
		"Camera::@3265": 0x80406960,
		"Camera::@3266": 0x80406964,
		"Camera::@3267": 0x80406968,
		"Camera::@3268": 0x8040696c,
		"Camera::@3269": 0x80406970,
		"Camera::@3270": 0x80406974,
		"Camera::@3369": 0x80406980,
		"Camera::@3726": 0x80406984,
		"Camera::@3727": 0x8040698c,
		"Camera::@3825": 0x80406990,
		"Camera::@2182": 0x80406a20,
		"Camera::@2071": 0x80406a38,
		"Camera::@2072": 0x80406a3c,
		"Camera::@2073": 0x80406a40,
		"Camera::@2200": 0x80406a50,
		"Camera::@2201": 0x80406a54,
		"Camera::@2319": 0x80406a58,
		"Camera::@2320": 0x80406a5c,
		"Camera::@2321": 0x80406a60,
		"Camera::@2322": 0x80406a64,
		"Camera::@2323": 0x80406a68,
		"Camera::@2324": 0x80406a6c,
		"Camera::@2352": 0x80406cc0,
		"Camera::@2353": 0x80406cc4,
		"Camera::@2354": 0x80406cc8,
		"Camera::@2355": 0x80406ccc,
		"Camera::@2702": 0x80406cd0,
		"Camera::@2703": 0x80406cd4,
		"Camera::@2704": 0x80406cd8,
		"Camera::@2705": 0x80406cdc,
		"Camera::@2706": 0x80406ce0,
		"Camera::@2707": 0x80406ce4,
		"Camera::@2708": 0x80406ce8,
		"Camera::@1830": 0x80406d58,
		"@1830": 0x80406d58,
		"Camera::@1831": 0x80406d5c,
		"Camera::@1832": 0x80406d60,
		"Enemy::@2778": 0x80406e88,
		"Enemy::@2779": 0x80406e90,
		"Enemy::@2780": 0x80406e98,
		"Enemy::@2785": 0x80406ea0,
		"Enemy::@2786": 0x80406ea8,
		"Enemy::@3203": 0x8040715c,
		"Enemy::@4103": 0x80407180,
		"Enemy::@4104": 0x80407184,
		"Enemy::@4106": 0x8040718c,
		"Enemy::@4406": 0x804071d8,
		"Enemy::@5197": 0x80407204,
		"Enemy::@5508": 0x80407208,
		"@5508": 0x80407208,
		"Enemy::@5509": 0x8040720c,
		"@5509": 0x8040720c,
		"Enemy::@3680": 0x80407290,
		"Enemy::@3681": 0x80407294,
		"Enemy::@4082": 0x804072cc,
		"Enemy::@4548": 0x804072f0,
		"Enemy::@4549": 0x804072f4,
		"Enemy::@4808": 0x804072fc,
		"@4808": 0x804072fc,
		"Enemy::@5215": 0x80407304,
		"Enemy::@5343": 0x80407314,
		"Enemy::@4792": 0x804073dc,
		"Enemy::@6518": 0x8040740c,
		"Enemy::@6519": 0x80407410,
		"Enemy::@6520": 0x80407414,
		"Enemy::@7348": 0x8040741c,
		"@7348": 0x8040741c,
		"Enemy::@3646": 0x804074a8,
		"Enemy::@3648": 0x804074ac,
		"Enemy::@4257": 0x804074d8,
		"Enemy::@3443": 0x804074e8,
		"Enemy::@3444": 0x804074ec,
		"Enemy::@4054": 0x80407510,
		"Enemy::@4221": 0x80407534,
		"Enemy::@4444": 0x80407548,
		"@4444": 0x80407548,
		"Enemy::@4499": 0x80407558,
		"Enemy::@4033": 0x804075e8,
		"Enemy::@4035": 0x804075f0,
		"Enemy::@4558": 0x80407604,
		"Enemy::idxarray$3431": 0x804076d8,
		"idxarray$3431": 0x804076d8,
		"Enemy::idxarray$3453": 0x804076e0,
		"idxarray$3453": 0x804076e0,
		"Enemy::idxarray$3500": 0x804076e8,
		"idxarray$3500": 0x804076e8,
		"Enemy::idxarray$3520": 0x804076f0,
		"idxarray$3520": 0x804076f0,
		"Enemy::@4704": 0x80407718,
		"Enemy::@4706": 0x8040771c,
		"Enemy::@4707": 0x80407720,
		"Enemy::@4708": 0x80407724,
		"Enemy::@6056": 0x8040775c,
		"@6056": 0x8040775c,
		"Enemy::@6299": 0x80407760,
		"@6299": 0x80407760,
		"Enemy::@6321": 0x80407764,
		"@6321": 0x80407764,
		"Enemy::@6322": 0x80407768,
		"@6322": 0x80407768,
		"Enemy::@6323": 0x8040776c,
		"@6323": 0x8040776c,
		"Enemy::@6589": 0x80407770,
		"Enemy::@7131": 0x80407774,
		"@7131": 0x80407774,
		"Enemy::@7132": 0x80407778,
		"@7132": 0x80407778,
		"Enemy::@7133": 0x8040777c,
		"@7133": 0x8040777c,
		"Enemy::@7192": 0x80407780,
		"@7192": 0x80407780,
		"Enemy::@7193": 0x80407784,
		"@7193": 0x80407784,
		"Enemy::@7822": 0x8040778c,
		"@7822": 0x8040778c,
		"Enemy::@7863": 0x80407790,
		"@7863": 0x80407790,
		"Enemy::@7864": 0x80407794,
		"@7864": 0x80407794,
		"Enemy::@7865": 0x80407798,
		"@7865": 0x80407798,
		"Enemy::@8145": 0x8040779c,
		"@8145": 0x8040779c,
		"Enemy::@8146": 0x804077a0,
		"@8146": 0x804077a0,
		"Enemy::@8147": 0x804077a8,
		"@8147": 0x804077a8,
		"Enemy::@8149": 0x804077ac,
		"@8149": 0x804077ac,
		"Enemy::@8360": 0x804077b0,
		"Enemy::@8735": 0x804077b4,
		"@8735": 0x804077b4,
		"Enemy::@9038": 0x804077b8,
		"@9038": 0x804077b8,
		"Enemy::@9197": 0x804077bc,
		"@9197": 0x804077bc,
		"Enemy::@9200": 0x804077c0,
		"@9200": 0x804077c0,
		"Enemy::@9202": 0x804077c4,
		"@9202": 0x804077c4,
		"Enemy::@9205": 0x804077c8,
		"@9205": 0x804077c8,
		"Enemy::@9207": 0x804077cc,
		"@9207": 0x804077cc,
		"Enemy::@9210": 0x804077d0,
		"@9210": 0x804077d0,
		"Enemy::@9212": 0x804077d4,
		"@9212": 0x804077d4,
		"Enemy::@9218": 0x804077d8,
		"@9218": 0x804077d8,
		"Enemy::@9222": 0x804077dc,
		"@9222": 0x804077dc,
		"Enemy::@9227": 0x804077e0,
		"@9227": 0x804077e0,
		"Enemy::@4122": 0x80407824,
		"Enemy::@4123": 0x80407828,
		"Enemy::@4435": 0x8040784c,
		"Enemy::@4741": 0x80407854,
		"Enemy::@5172": 0x80407860,
		"Enemy::@4390": 0x804078b8,
		"Enemy::@4391": 0x804078bc,
		"Enemy::@4537": 0x804078c8,
		"Enemy::@4538": 0x804078cc,
		"@4538": 0x804078cc,
		"Enemy::@5296": 0x80407904,
		"Enemy::@5076": 0x80407978,
		"Enemy::@5183": 0x8040797c,
		"Enemy::@5386": 0x80407990,
		"@5386": 0x80407990,
		"Enemy::@5387": 0x80407994,
		"@5387": 0x80407994,
		"Enemy::@6628": 0x804079b4,
		"@6628": 0x804079b4,
		"Enemy::@6948": 0x804079b8,
		"@6948": 0x804079b8,
		"Enemy::@7610": 0x804079d0,
		"@7610": 0x804079d0,
		"Enemy::@7611": 0x804079d4,
		"@7611": 0x804079d4,
		"Enemy::@7688": 0x804079d8,
		"@7688": 0x804079d8,
		"Enemy::@7689": 0x804079dc,
		"@7689": 0x804079dc,
		"Enemy::@7893": 0x804079e4,
		"@7893": 0x804079e4,
		"Enemy::@7894": 0x804079e8,
		"@7894": 0x804079e8,
		"Enemy::@8404": 0x804079ec,
		"@8404": 0x804079ec,
		"Enemy::@8768": 0x804079f0,
		"Enemy::@9151": 0x80407a14,
		"@9151": 0x80407a14,
		"Enemy::@9482": 0x80407a18,
		"@9482": 0x80407a18,
		"Enemy::@9483": 0x80407a1c,
		"@9483": 0x80407a1c,
		"Enemy::@4339": 0x80407a54,
		"Enemy::@5038": 0x80407a74,
		"Enemy::@5039": 0x80407a78,
		"Enemy::@5390": 0x80407a7c,
		"@5390": 0x80407a7c,
		"Enemy::@5392": 0x80407a84,
		"@5392": 0x80407a84,
		"Enemy::@5393": 0x80407a88,
		"@5393": 0x80407a88,
		"Enemy::@5394": 0x80407a8c,
		"@5394": 0x80407a8c,
		"Enemy::@5788": 0x80407a9c,
		"@5788": 0x80407a9c,
		"Enemy::@5789": 0x80407aa0,
		"@5789": 0x80407aa0,
		"Enemy::@5790": 0x80407aa4,
		"@5790": 0x80407aa4,
		"Enemy::@6199": 0x80407aac,
		"@6199": 0x80407aac,
		"Enemy::@6929": 0x80407ac0,
		"@6929": 0x80407ac0,
		"Enemy::@6930": 0x80407ac4,
		"@6930": 0x80407ac4,
		"Enemy::@6931": 0x80407ac8,
		"@6931": 0x80407ac8,
		"Enemy::@6932": 0x80407acc,
		"@6932": 0x80407acc,
		"Enemy::@6933": 0x80407ad0,
		"@6933": 0x80407ad0,
		"Enemy::@7230": 0x80407ae8,
		"@7230": 0x80407ae8,
		"Enemy::@7408": 0x80407aec,
		"@7408": 0x80407aec,
		"Enemy::@7471": 0x80407afc,
		"@7471": 0x80407afc,
		"Enemy::@7472": 0x80407b00,
		"@7472": 0x80407b00,
		"Enemy::@7473": 0x80407b04,
		"Enemy::@7474": 0x80407b08,
		"@7474": 0x80407b08,
		"Enemy::@7475": 0x80407b0c,
		"@7475": 0x80407b0c,
		"Enemy::@7997": 0x80407b18,
		"@7997": 0x80407b18,
		"Enemy::@7998": 0x80407b1c,
		"@7998": 0x80407b1c,
		"Enemy::@8342": 0x80407b34,
		"@8342": 0x80407b34,
		"Enemy::@3407": 0x80407b58,
		"Enemy::@4901": 0x80407bc0,
		"Enemy::@4992": 0x80407bc8,
		"Enemy::@4830": 0x80407c4c,
		"Enemy::@5660": 0x80407c68,
		"Enemy::@5661": 0x80407c6c,
		"Enemy::@6085": 0x80407c80,
		"@6085": 0x80407c80,
		"Enemy::@6602": 0x80407d7c,
		"@6602": 0x80407d7c,
		"Enemy::@6603": 0x80407d80,
		"@6603": 0x80407d80,
		"Enemy::@6604": 0x80407d84,
		"@6604": 0x80407d84,
		"Enemy::@6605": 0x80407d88,
		"@6605": 0x80407d88,
		"Enemy::@6606": 0x80407d8c,
		"@6606": 0x80407d8c,
		"Enemy::@6843": 0x80407d90,
		"Enemy::@6844": 0x80407d94,
		"Enemy::@6845": 0x80407d98,
		"Enemy::@7168": 0x80407d9c,
		"@7168": 0x80407d9c,
		"Enemy::@7169": 0x80407da0,
		"@7169": 0x80407da0,
		"Enemy::@7302": 0x80407da4,
		"@7302": 0x80407da4,
		"Enemy::@7303": 0x80407da8,
		"@7303": 0x80407da8,
		"Enemy::@7304": 0x80407dac,
		"@7304": 0x80407dac,
		"Enemy::@7305": 0x80407db4,
		"@7305": 0x80407db4,
		"Enemy::@7385": 0x80407db8,
		"@7385": 0x80407db8,
		"Enemy::@7505": 0x80407dbc,
		"@7505": 0x80407dbc,
		"Enemy::@7506": 0x80407dc0,
		"@7506": 0x80407dc0,
		"Enemy::@7507": 0x80407dc4,
		"@7507": 0x80407dc4,
		"Enemy::@7508": 0x80407dc8,
		"@7508": 0x80407dc8,
		"Enemy::@7509": 0x80407dcc,
		"@7509": 0x80407dcc,
		"Enemy::@7510": 0x80407dd0,
		"@7510": 0x80407dd0,
		"Enemy::@7780": 0x80407de4,
		"@7780": 0x80407de4,
		"Enemy::@7781": 0x80407de8,
		"@7781": 0x80407de8,
		"Enemy::@7782": 0x80407dec,
		"@7782": 0x80407dec,
		"Enemy::@7783": 0x80407df0,
		"@7783": 0x80407df0,
		"Enemy::@7784": 0x80407df4,
		"@7784": 0x80407df4,
		"Enemy::@7785": 0x80407df8,
		"@7785": 0x80407df8,
		"Enemy::@7786": 0x80407dfc,
		"@7786": 0x80407dfc,
		"Enemy::@4404": 0x80407e68,
		"Enemy::@4752": 0x80407e70,
		"Enemy::@5579": 0x80407e94,
		"@5579": 0x80407e94,
		"Enemy::@5580": 0x80407e98,
		"@5580": 0x80407e98,
		"Enemy::@5619": 0x80407e9c,
		"@5619": 0x80407e9c,
		"Enemy::@3684": 0x80407ec0,
		"Enemy::@3685": 0x80407ec4,
		"@3685": 0x80407ec4,
		"Enemy::@4858": 0x80407f24,
		"Enemy::@5177": 0x80407f38,
		"Enemy::@5179": 0x80407f40,
		"Enemy::@5201": 0x80407f48,
		"Enemy::@5202": 0x80407f4c,
		"Enemy::@3871": 0x80407fb4,
		"Enemy::@4486": 0x80407fd0,
		"Enemy::@4353": 0x80408064,
		"Enemy::@6148": 0x804080d0,
		"Enemy::@6149": 0x804080d4,
		"Enemy::@6150": 0x804080d8,
		"Enemy::@6225": 0x804080dc,
		"@6225": 0x804080dc,
		"Enemy::@6297": 0x804080fc,
		"@6297": 0x804080fc,
		"Enemy::@6814": 0x80408100,
		"@6814": 0x80408100,
		"Enemy::@6815": 0x80408104,
		"@6815": 0x80408104,
		"Enemy::@7194": 0x8040810c,
		"@7194": 0x8040810c,
		"Enemy::@7195": 0x80408110,
		"@7195": 0x80408110,
		"Enemy::@8019": 0x80408120,
		"@8019": 0x80408120,
		"Enemy::@8020": 0x80408124,
		"@8020": 0x80408124,
		"Enemy::@8054": 0x80408140,
		"@8054": 0x80408140,
		"Enemy::@8181": 0x80408144,
		"@8181": 0x80408144,
		"Enemy::@8345": 0x80408148,
		"@8345": 0x80408148,
		"Enemy::@8749": 0x8040814c,
		"@8749": 0x8040814c,
		"Enemy::@8796": 0x80408154,
		"@8796": 0x80408154,
		"Enemy::@8849": 0x80408160,
		"@8849": 0x80408160,
		"Enemy::@9019": 0x80408164,
		"@9019": 0x80408164,
		"Enemy::@2747": 0x80408184,
		"Enemy::@2749": 0x80408188,
		"Enemy::@3838": 0x8040822c,
		"Enemy::@5103": 0x80408298,
		"Enemy::@5104": 0x8040829c,
		"Enemy::@5246": 0x80408378,
		"Enemy::@5247": 0x8040837c,
		"Enemy::@5248": 0x80408380,
		"Enemy::@5249": 0x80408384,
		"Enemy::@6127": 0x804083b8,
		"Enemy::@6840": 0x804083cc,
		"Enemy::@6887": 0x804083d0,
		"Enemy::@6888": 0x804083d4,
		"Enemy::@6889": 0x804083d8,
		"Enemy::@6900": 0x804083dc,
		"Enemy::@6902": 0x804083e0,
		"Enemy::@6904": 0x804083e4,
		"Enemy::@6905": 0x804083e8,
		"Enemy::@7021": 0x804083ec,
		"@7021": 0x804083ec,
		"Enemy::@7022": 0x804083f0,
		"@7022": 0x804083f0,
		"Enemy::@7125": 0x804083f4,
		"@7125": 0x804083f4,
		"Enemy::@7126": 0x804083f8,
		"@7126": 0x804083f8,
		"Enemy::@7322": 0x804083fc,
		"@7322": 0x804083fc,
		"Enemy::@7447": 0x80408404,
		"@7447": 0x80408404,
		"Enemy::@7448": 0x80408408,
		"@7448": 0x80408408,
		"Enemy::@7449": 0x8040840c,
		"@7449": 0x8040840c,
		"Enemy::@8977": 0x80408450,
		"@8977": 0x80408450,
		"Enemy::@8978": 0x80408454,
		"@8978": 0x80408454,
		"Enemy::@8979": 0x80408458,
		"@8979": 0x80408458,
		"Enemy::@8980": 0x8040845c,
		"@8980": 0x8040845c,
		"Enemy::@8997": 0x80408460,
		"@8997": 0x80408460,
		"Enemy::@3807": 0x804084d8,
		"Enemy::@4210": 0x80408510,
		"Enemy::@3335": 0x8040854c,
		"Enemy::@4494": 0x804085b4,
		"Enemy::@5369": 0x804085cc,
		"@5369": 0x804085cc,
		"Enemy::@5533": 0x804085d8,
		"@5533": 0x804085d8,
		"Enemy::@5893": 0x804085f4,
		"Enemy::@3323": 0x804085f8,
		"Enemy::@4009": 0x80408634,
		"Enemy::@4241": 0x80408640,
		"Enemy::@4242": 0x80408644,
		"Enemy::@5091": 0x80408680,
		"Enemy::@5092": 0x80408684,
		"Enemy::@5154": 0x80408688,
		"Enemy::@3319": 0x80408714,
		"Enemy::@3320": 0x80408718,
		"Enemy::@3778": 0x80408984,
		"Enemy::@4163": 0x80408990,
		"Enemy::@4362": 0x80408998,
		"Enemy::@4431": 0x804089a0,
		"Enemy::@3640": 0x804089a8,
		"Enemy::@3641": 0x804089ac,
		"Enemy::@4563": 0x804089c8,
		"Enemy::@2300": 0x80408a74,
		"Enemy::@2301": 0x80408a78,
		"Enemy::@2302": 0x80408a7c,
		"Enemy::@2303": 0x80408a80,
		"Enemy::@3802": 0x80408ac8,
		"Enemy::@4089": 0x80408b0c,
		"Enemy::@4223": 0x80408b2c,
		"Enemy::@4226": 0x80408b38,
		"Enemy::@4437": 0x80408b3c,
		"Enemy::@4438": 0x80408b40,
		"Enemy::@4719": 0x80408b44,
		"Enemy::@4720": 0x80408b48,
		"Enemy::@4723": 0x80408b54,
		"Enemy::@4724": 0x80408b58,
		"Enemy::@4727": 0x80408b64,
		"Enemy::@5439": 0x80408b8c,
		"@5439": 0x80408b8c,
		"Enemy::@5442": 0x80408b98,
		"@5442": 0x80408b98,
		"Enemy::@5979": 0x80408b9c,
		"Enemy::@6548": 0x80408ba0,
		"Enemy::@6549": 0x80408ba4,
		"Enemy::@6550": 0x80408ba8,
		"Enemy::@6642": 0x80408bb8,
		"@6642": 0x80408bb8,
		"Enemy::@3217": 0x80408c00,
		"Enemy::@3218": 0x80408c04,
		"Enemy::@3526": 0x80408ccc,
		"Enemy::@4457": 0x80408d3c,
		"@4457": 0x80408d3c,
		"Enemy::@4685": 0x80408d44,
		"Enemy::@3883": 0x80408ebc,
		"Enemy::@3884": 0x80408ec0,
		"Enemy::@3831": 0x80408f04,
		"Enemy::@4559": 0x80408f20,
		"Enemy::@4560": 0x80408f24,
		"Enemy::@4561": 0x80408f28,
		"Enemy::@4562": 0x80408f2c,
		"Enemy::@6036": 0x80408f58,
		"Enemy::@6041": 0x80408f5c,
		"Enemy::@6042": 0x80408f60,
		"Enemy::@6043": 0x80408f64,
		"Enemy::@6044": 0x80408f68,
		"@6044": 0x80408f68,
		"Enemy::@6057": 0x80408fd0,
		"@6057": 0x80408fd0,
		"Enemy::@3669": 0x80409044,
		"Enemy::@4248": 0x80409074,
		"Enemy::@4249": 0x8040907c,
		"Enemy::@4417": 0x8040908c,
		"Enemy::@3638": 0x8040912c,
		"Enemy::@4495": 0x80409154,
		"Enemy::@4611": 0x80409164,
		"Enemy::@3413": 0x804091d8,
		"Enemy::@3957": 0x80409288,
		"Enemy::@4718": 0x80409290,
		"Enemy::@5691": 0x804092b4,
		"Enemy::@5693": 0x804092b8,
		"Enemy::@5695": 0x804092bc,
		"@5695": 0x804092bc,
		"Enemy::@3956": 0x804093a4,
		"Enemy::@4797": 0x804093b0,
		"GC2D::@3499": 0x80409438,
		"GC2D::@3527": 0x8040943c,
		"GC2D::@3581": 0x80409440,
		"GC2D::@6874": 0x80409454,
		"@6874": 0x80409454,
		"GC2D::@6875": 0x80409458,
		"@6875": 0x80409458,
		"GC2D::@6876": 0x8040945c,
		"@6876": 0x8040945c,
		"GC2D::@6877": 0x80409460,
		"@6877": 0x80409460,
		"GC2D::@6878": 0x80409464,
		"@6878": 0x80409464,
		"GC2D::@6879": 0x80409468,
		"@6879": 0x80409468,
		"GC2D::@6880": 0x8040946c,
		"@6880": 0x8040946c,
		"GC2D::@6881": 0x80409470,
		"@6881": 0x80409470,
		"GC2D::@6882": 0x80409474,
		"@6882": 0x80409474,
		"GC2D::@6883": 0x80409478,
		"@6883": 0x80409478,
		"GC2D::@6884": 0x8040947c,
		"@6884": 0x8040947c,
		"GC2D::@6885": 0x80409480,
		"@6885": 0x80409480,
		"GC2D::@6886": 0x80409484,
		"@6886": 0x80409484,
		"GC2D::@6889": 0x80409488,
		"GC2D::@7039": 0x804094a0,
		"@7039": 0x804094a0,
		"GC2D::@7121": 0x804094a4,
		"@7121": 0x804094a4,
		"GC2D::@7122": 0x804094a8,
		"@7122": 0x804094a8,
		"GC2D::@9030": 0x804094b8,
		"@9030": 0x804094b8,
		"GC2D::@9031": 0x804094bc,
		"@9031": 0x804094bc,
		"GC2D::@9512": 0x804094c0,
		"@9512": 0x804094c0,
		"GC2D::@9835": 0x804094c4,
		"@9835": 0x804094c4,
		"GC2D::@11686": 0x804094c8,
		"@11686": 0x804094c8,
		"GC2D::@11687": 0x804094cc,
		"@11687": 0x804094cc,
		"GC2D::@11688": 0x804094d0,
		"@11688": 0x804094d0,
		"GC2D::@11905": 0x804094d4,
		"@11905": 0x804094d4,
		"GC2D::@11973": 0x804094dc,
		"@11973": 0x804094dc,
		"GC2D::@11974": 0x804094e0,
		"@11974": 0x804094e0,
		"GC2D::@2727": 0x804094e8,
		"GC2D::@2728": 0x804094f0,
		"GC2D::@3331": 0x804094f4,
		"GC2D::@3586": 0x80409524,
		"GC2D::@3592": 0x8040952c,
		"GC2D::@3780": 0x80409530,
		"GC2D::@3941": 0x80409534,
		"GC2D::@4419": 0x80409538,
		"GC2D::@4604": 0x8040953c,
		"GC2D::@4605": 0x80409540,
		"GC2D::@4606": 0x80409544,
		"GC2D::@4607": 0x80409548,
		"@4607": 0x80409548,
		"GC2D::@4608": 0x8040954c,
		"@4608": 0x8040954c,
		"GC2D::@4609": 0x80409550,
		"GC2D::@4610": 0x80409554,
		"@4610": 0x80409554,
		"GC2D::@4611": 0x80409558,
		"GC2D::@4612": 0x8040955c,
		"GC2D::@4613": 0x80409560,
		"GC2D::@5003": 0x80409570,
		"GC2D::@5004": 0x80409574,
		"GC2D::@5043": 0x80409578,
		"GC2D::@3162": 0x8040963c,
		"GC2D::@3226": 0x80409650,
		"GC2D::@3227": 0x80409654,
		"GC2D::@3228": 0x80409658,
		"GC2D::@3229": 0x8040965c,
		"GC2D::@3230": 0x80409660,
		"GC2D::@3231": 0x80409664,
		"GC2D::@3351": 0x80409668,
		"GC2D::@3355": 0x80409670,
		"GC2D::@4233": 0x80409680,
		"GC2D::@4234": 0x80409684,
		"GC2D::@4235": 0x80409688,
		"GC2D::@4275": 0x804096a0,
		"GC2D::@5958": 0x804096a4,
		"GC2D::@5959": 0x804096a8,
		"GC2D::@5960": 0x804096ac,
		"GC2D::@5961": 0x804096b0,
		"GC2D::@5962": 0x804096b4,
		"GC2D::@5963": 0x804096b8,
		"GC2D::@7094": 0x804096bc,
		"@7094": 0x804096bc,
		"GC2D::@7096": 0x804096c4,
		"@7096": 0x804096c4,
		"GC2D::@2783": 0x8040972c,
		"GC2D::@2784": 0x80409730,
		"GC2D::@2785": 0x80409734,
		"GC2D::@2786": 0x80409738,
		"GC2D::@2787": 0x8040973c,
		"GC2D::@4680": 0x80409740,
		"GC2D::@4681": 0x80409744,
		"GC2D::@4682": 0x80409748,
		"GC2D::@5282": 0x80409758,
		"GC2D::@5283": 0x8040975c,
		"GC2D::@5284": 0x80409760,
		"GC2D::@5285": 0x80409764,
		"GC2D::@5286": 0x80409768,
		"GC2D::@5287": 0x8040976c,
		"GC2D::@5615": 0x80409770,
		"@5615": 0x80409770,
		"GC2D::@7196": 0x80409780,
		"GC2D::@7457": 0x80409784,
		"GC2D::@7458": 0x80409788,
		"@7458": 0x80409788,
		"GC2D::@7459": 0x8040978c,
		"@7459": 0x8040978c,
		"GC2D::@7460": 0x80409790,
		"@7460": 0x80409790,
		"GC2D::@7461": 0x80409794,
		"@7461": 0x80409794,
		"GC2D::@7462": 0x80409798,
		"@7462": 0x80409798,
		"GC2D::@7897": 0x8040979c,
		"@7897": 0x8040979c,
		"GC2D::@7898": 0x804097a0,
		"@7898": 0x804097a0,
		"GC2D::@7899": 0x804097a4,
		"@7899": 0x804097a4,
		"GC2D::@7900": 0x804097a8,
		"@7900": 0x804097a8,
		"GC2D::@7901": 0x804097ac,
		"@7901": 0x804097ac,
		"GC2D::@8768": 0x804097b0,
		"GC2D::@8786": 0x804097b8,
		"@8786": 0x804097b8,
		"GC2D::@8826": 0x804097bc,
		"@8826": 0x804097bc,
		"GC2D::@2439": 0x80409810,
		"GC2D::@2440": 0x80409814,
		"GC2D::@2576": 0x80409818,
		"GC2D::@2943": 0x8040981c,
		"GC2D::@2944": 0x80409820,
		"GC2D::@3407": 0x80409828,
		"GC2D::@3408": 0x8040982c,
		"GC2D::@3409": 0x80409830,
		"GC2D::@3410": 0x80409834,
		"GC2D::@3508": 0x80409840,
		"GC2D::@3513": 0x80409848,
		"GC2D::@3514": 0x8040984c,
		"GC2D::@3517": 0x80409850,
		"GC2D::@3631": 0x804098c8,
		"GC2D::@3632": 0x804098cc,
		"GC2D::@3633": 0x804098d0,
		"GC2D::@3634": 0x804098d4,
		"GC2D::@3635": 0x804098d8,
		"GC2D::@3636": 0x804098dc,
		"GC2D::@3637": 0x804098e0,
		"GC2D::@3957": 0x804098f8,
		"GC2D::@3961": 0x804098fc,
		"GC2D::@3962": 0x80409900,
		"GC2D::@4077": 0x80409904,
		"GC2D::@4078": 0x80409908,
		"GC2D::@4079": 0x8040990c,
		"GC2D::@4080": 0x80409910,
		"GC2D::@3080": 0x8040994c,
		"GC2D::@3081": 0x80409950,
		"GC2D::@3083": 0x80409954,
		"GC2D::@3084": 0x80409958,
		"GC2D::@3125": 0x8040995c,
		"GC2D::@2643": 0x80409a2c,
		"GC2D::@2644": 0x80409a34,
		"GC2D::@2645": 0x80409a38,
		"GC2D::@2646": 0x80409a3c,
		"GC2D::@2746": 0x80409a48,
		"GC2D::@2747": 0x80409a4c,
		"GC2D::@2748": 0x80409a50,
		"GC2D::@2848": 0x80409a54,
		"GC2D::@2849": 0x80409a58,
		"GC2D::@2946": 0x80409a60,
		"GC2D::@2947": 0x80409a64,
		"GC2D::@3811": 0x80409a7c,
		"GC2D::@262": 0x80409abc,
		"GC2D::@301": 0x80409ac0,
		"GC2D::@304": 0x80409ac4,
		"GC2D::@634": 0x80409ac8,
		"GC2D::@635": 0x80409acc,
		"@635": 0x80409acc,
		"GC2D::@636": 0x80409ad0,
		"@636": 0x80409ad0,
		"GC2D::@637": 0x80409ad4,
		"@637": 0x80409ad4,
		"GC2D::@638": 0x80409ad8,
		"@638": 0x80409ad8,
		"GC2D::@639": 0x80409adc,
		"GC2D::@640": 0x80409ae0,
		"GC2D::@641": 0x80409ae4,
		"@641": 0x80409ae4,
		"GC2D::@642": 0x80409ae8,
		"GC2D::@643": 0x80409aec,
		"GC2D::@644": 0x80409af0,
		"@644": 0x80409af0,
		"GC2D::@688": 0x80409b00,
		"GC2D::@689": 0x80409b04,
		"GC2D::@690": 0x80409b08,
		"@690": 0x80409b08,
		"GC2D::@691": 0x80409b0c,
		"@691": 0x80409b0c,
		"GC2D::@692": 0x80409b10,
		"@692": 0x80409b10,
		"GC2D::@693": 0x80409b14,
		"@693": 0x80409b14,
		"GC2D::@694": 0x80409b18,
		"GC2D::@695": 0x80409b1c,
		"GC2D::@797": 0x80409b38,
		"GC2D::@798": 0x80409b3c,
		"GC2D::@799": 0x80409b40,
		"GC2D::@800": 0x80409b44,
		"GC2D::@801": 0x80409b48,
		"GC2D::@802": 0x80409b4c,
		"GC2D::@803": 0x80409b50,
		"GC2D::@804": 0x80409b54,
		"GC2D::@805": 0x80409b58,
		"GC2D::@806": 0x80409b5c,
		"GC2D::@902": 0x80409b60,
		"@902": 0x80409b60,
		"GC2D::@903": 0x80409b64,
		"GC2D::@1002": 0x80409b68,
		"@1002": 0x80409b68,
		"GC2D::@1003": 0x80409b6c,
		"@1003": 0x80409b6c,
		"GC2D::@1026": 0x80409b70,
		"@1026": 0x80409b70,
		"GC2D::@1058": 0x80409b74,
		"@1058": 0x80409b74,
		"GC2D::@1059": 0x80409b78,
		"@1059": 0x80409b78,
		"GC2D::@1060": 0x80409b7c,
		"@1060": 0x80409b7c,
		"GC2D::@1099": 0x80409b80,
		"GC2D::@1135": 0x80409b94,
		"@1135": 0x80409b94,
		"GC2D::@1136": 0x80409b98,
		"@1136": 0x80409b98,
		"GC2D::@1137": 0x80409b9c,
		"@1137": 0x80409b9c,
		"GC2D::@1194": 0x80409ba0,
		"@1194": 0x80409ba0,
		"GC2D::@1195": 0x80409ba4,
		"@1195": 0x80409ba4,
		"GC2D::@1196": 0x80409ba8,
		"@1196": 0x80409ba8,
		"GC2D::@1197": 0x80409bac,
		"@1197": 0x80409bac,
		"GC2D::@1340": 0x80409bb0,
		"@1340": 0x80409bb0,
		"GC2D::@1687": 0x80409bb4,
		"GC2D::@1688": 0x80409bb8,
		"GC2D::@1689": 0x80409bbc,
		"GC2D::@1691": 0x80409bc4,
		"@1691": 0x80409bc4,
		"GC2D::@1692": 0x80409bc8,
		"@1692": 0x80409bc8,
		"GC2D::@1693": 0x80409bcc,
		"@1693": 0x80409bcc,
		"GC2D::@1694": 0x80409bd0,
		"GC2D::@1695": 0x80409bd4,
		"@1695": 0x80409bd4,
		"GC2D::@1835": 0x80409bd8,
		"@1835": 0x80409bd8,
		"GC2D::@1936": 0x80409bdc,
		"GC2D::@1641": 0x80409be8,
		"GC2D::@2027": 0x80409bf8,
		"GC2D::@2028": 0x80409bfc,
		"GC2D::@2029": 0x80409c00,
		"GC2D::@2030": 0x80409c04,
		"@unnamed@::cSubtitleToggleItems": 0x80409c14,
		"cSubtitleToggleItems": 0x80409c14,
		"GC2D::@2079": 0x80409c1c,
		"GC2D::@2118": 0x80409c24,
		"GC2D::@2677": 0x80409c34,
		"GC2D::@2678": 0x80409c38,
		"GC2D::@3337": 0x80409c3c,
		"GC2D::@3594": 0x80409c50,
		"GC2D::@3595": 0x80409c54,
		"GC2D::@3896": 0x80409c5c,
		"GC2D::@4380": 0x80409c64,
		"GC2D::@4537": 0x80409c68,
		"Map::@3225": 0x80409d28,
		"Map::@3226": 0x80409d2c,
		"Map::@3227": 0x80409d30,
		"Map::@3228": 0x80409d34,
		"Map::@3229": 0x80409d38,
		"Map::@3623": 0x80409d40,
		"Map::@2631": 0x80409dd8,
		"Map::@2635": 0x80409df8,
		"Map::@2637": 0x80409e08,
		"Map::@2638": 0x80409e10,
		"Map::@2769": 0x80409e6c,
		"Map::@2953": 0x80409e78,
		"Map::@2954": 0x80409e7c,
		"Map::@2955": 0x80409e80,
		"Map::@2956": 0x80409e84,
		"Map::@3021": 0x80409e9c,
		"Map::@3189": 0x80409ea4,
		"Map::@3329": 0x80409ea8,
		"Map::@3480": 0x80409eb0,
		"Map::@3481": 0x80409eb4,
		"Map::@2794": 0x80409fa8,
		"Map::@2549": 0x80409fec,
		"Map::@2717": 0x80409ff0,
		"Map::@3059": 0x8040a080,
		"Map::@3069": 0x8040a084,
		"Map::@3070": 0x8040a08c,
		"Map::@3411": 0x8040a18c,
		"Map::@3412": 0x8040a190,
		"Map::@3453": 0x8040a1c8,
		"Map::@3841": 0x8040a1e0,
		"@3841": 0x8040a1e0,
		"Map::@3842": 0x8040a1e4,
		"Map::@4477": 0x8040a1f0,
		"Map::@4624": 0x8040a200,
		"Map::@4734": 0x8040a204,
		"Map::@4735": 0x8040a20c,
		"Map::@4736": 0x8040a214,
		"Map::@4737": 0x8040a21c,
		"Map::@4738": 0x8040a224,
		"Map::@5827": 0x8040a2b4,
		"MoveBG::@3476": 0x8040b46c,
		"MoveBG::@3935": 0x8040b498,
		"MoveBG::@3448": 0x8040b528,
		"MoveBG::@3638": 0x8040b53c,
		"MoveBG::@3881": 0x8040b558,
		"MoveBG::@3882": 0x8040b55c,
		"MoveBG::@3892": 0x8040b560,
		"MoveBG::@4100": 0x8040b58c,
		"MoveBG::@4302": 0x8040b590,
		"MoveBG::@4303": 0x8040b594,
		"MoveBG::@4468": 0x8040b598,
		"MoveBG::@4469": 0x8040b59c,
		"MoveBG::@4470": 0x8040b5a0,
		"MoveBG::@2627": 0x8040b5a8,
		"MoveBG::@2628": 0x8040b5ac,
		"MoveBG::@2629": 0x8040b5b0,
		"MoveBG::@2656": 0x8040b5b4,
		"MoveBG::@2657": 0x8040b5bc,
		"MoveBG::@3609": 0x8040b620,
		"MoveBG::@3660": 0x8040b6d0,
		"MoveBG::@3661": 0x8040b6d4,
		"MoveBG::@3662": 0x8040b6d8,
		"MoveBG::@3836": 0x8040b6e8,
		"MoveBG::@3837": 0x8040b6ec,
		"MoveBG::@3838": 0x8040b6f0,
		"MoveBG::@3839": 0x8040b6f4,
		"@3839": 0x8040b6f4,
		"MoveBG::@4030": 0x8040b700,
		"MoveBG::@4031": 0x8040b704,
		"MoveBG::@4084": 0x8040b708,
		"MoveBG::@4240": 0x8040b714,
		"MoveBG::@3671": 0x8040b744,
		"MoveBG::@3672": 0x8040b748,
		"MoveBG::@3673": 0x8040b74c,
		"MoveBG::@3741": 0x8040b750,
		"MoveBG::@3895": 0x8040b76c,
		"MoveBG::@3896": 0x8040b770,
		"MoveBG::@4055": 0x8040b788,
		"MoveBG::@4066": 0x8040b798,
		"MoveBG::@4067": 0x8040b79c,
		"MoveBG::@4289": 0x8040b7ac,
		"MoveBG::@4436": 0x8040b7c0,
		"MoveBG::@4437": 0x8040b7c4,
		"MoveBG::@4625": 0x8040b7c8,
		"MoveBG::@4626": 0x8040b7cc,
		"MoveBG::@4627": 0x8040b7d0,
		"MoveBG::@4628": 0x8040b7d4,
		"MoveBG::@4630": 0x8040b7dc,
		"MoveBG::@4818": 0x8040b7e4,
		"MoveBG::@4819": 0x8040b7e8,
		"MoveBG::@4820": 0x8040b7ec,
		"@4820": 0x8040b7ec,
		"MoveBG::@4831": 0x8040b7f0,
		"MoveBG::@4876": 0x8040b7f8,
		"MoveBG::@4877": 0x8040b7fc,
		"MoveBG::@5056": 0x8040b800,
		"MoveBG::@5057": 0x8040b804,
		"MoveBG::@5219": 0x8040b808,
		"MoveBG::@5220": 0x8040b80c,
		"MoveBG::@5224": 0x8040b818,
		"MoveBG::@3468": 0x8040b888,
		"MoveBG::@3653": 0x8040b8b0,
		"MoveBG::@4245": 0x8040b8f8,
		"MoveBG::@4246": 0x8040b8fc,
		"MoveBG::@4247": 0x8040b900,
		"MoveBG::@4248": 0x8040b904,
		"MoveBG::@4249": 0x8040b908,
		"MoveBG::@4250": 0x8040b90c,
		"MoveBG::@4251": 0x8040b910,
		"MoveBG::@4252": 0x8040b914,
		"MoveBG::@4253": 0x8040b918,
		"MoveBG::@4779": 0x8040b948,
		"MoveBG::@4780": 0x8040b94c,
		"MoveBG::@4781": 0x8040b950,
		"MoveBG::@4782": 0x8040b954,
		"MoveBG::@4801": 0x8040b958,
		"@4801": 0x8040b958,
		"MoveBG::@4993": 0x8040b96c,
		"MoveBG::@4994": 0x8040b970,
		"MoveBG::@4996": 0x8040b974,
		"MoveBG::@5184": 0x8040b984,
		"MoveBG::@5185": 0x8040b988,
		"MoveBG::@5249": 0x8040b98c,
		"MoveBG::@5250": 0x8040b990,
		"MoveBG::@5256": 0x8040b994,
		"MoveBG::@5365": 0x8040b998,
		"MoveBG::@3510": 0x8040b9b8,
		"MoveBG::@3590": 0x8040b9d0,
		"MoveBG::@3706": 0x8040b9dc,
		"MoveBG::@3707": 0x8040b9e0,
		"MoveBG::@4039": 0x8040ba30,
		"MoveBG::@4090": 0x8040ba34,
		"MoveBG::@4091": 0x8040ba38,
		"MoveBG::@4092": 0x8040ba3c,
		"MoveBG::@4218": 0x8040ba58,
		"MoveBG::@3725": 0x8040bafc,
		"MoveBG::@3891": 0x8040bb10,
		"MoveBG::@3998": 0x8040bb14,
		"MoveBG::@3999": 0x8040bb18,
		"MoveBG::@4126": 0x8040bb20,
		"MoveBG::@4129": 0x8040bb24,
		"MoveBG::@4130": 0x8040bb2c,
		"MoveBG::@4131": 0x8040bb30,
		"MoveBG::@4132": 0x8040bb34,
		"MoveBG::@4270": 0x8040bb58,
		"MoveBG::@2395": 0x8040bb74,
		"MoveBG::@2593": 0x8040bb8c,
		"MoveBG::@2594": 0x8040bb90,
		"MoveBG::@2595": 0x8040bb94,
		"MoveBG::@2597": 0x8040bb9c,
		"MoveBG::@2598": 0x8040bba0,
		"MoveBG::@3593": 0x8040bd08,
		"MoveBG::@3613": 0x8040bd0c,
		"MoveBG::@3965": 0x8040bd24,
		"MoveBG::@4226": 0x8040bd28,
		"MoveBG::@4360": 0x8040bd2c,
		"MoveBG::@4735": 0x8040bd50,
		"MoveBG::@4736": 0x8040bd54,
		"MoveBG::@4737": 0x8040bd58,
		"MoveBG::@4738": 0x8040bd5c,
		"MoveBG::@4739": 0x8040bd60,
		"MoveBG::@4740": 0x8040bd64,
		"MoveBG::@4741": 0x8040bd68,
		"MoveBG::@4742": 0x8040bd6c,
		"MoveBG::@4743": 0x8040bd70,
		"MoveBG::@4744": 0x8040bd74,
		"MoveBG::@5124": 0x8040bd7c,
		"MoveBG::@2696": 0x8040bf54,
		"MoveBG::@2718": 0x8040bf58,
		"MoveBG::@3447": 0x8040c000,
		"MoveBG::@3724": 0x8040c01c,
		"MoveBG::@3936": 0x8040c020,
		"MoveBG::@3937": 0x8040c024,
		"MoveBG::@3938": 0x8040c028,
		"MoveBG::@3939": 0x8040c02c,
		"MoveBG::@3940": 0x8040c030,
		"MoveBG::@3556": 0x8040c148,
		"MoveBG::@4465": 0x8040c1ec,
		"@4465": 0x8040c1ec,
		"MoveBG::@4651": 0x8040c1f0,
		"MoveBG::@4652": 0x8040c1f4,
		"MoveBG::@4653": 0x8040c1f8,
		"MoveBG::@4655": 0x8040c200,
		"MoveBG::@4656": 0x8040c204,
		"MoveBG::@5240": 0x8040c218,
		"MoveBG::@5241": 0x8040c21c,
		"MoveBG::@5343": 0x8040c220,
		"MoveBG::@3739": 0x8040c310,
		"NPC::@2672": 0x8040c508,
		"NPC::@2673": 0x8040c510,
		"NPC::@2676": 0x8040c514,
		"NPC::@2812": 0x8040c518,
		"Strategic::@2842": 0x8040c798,
		"Strategic::@2939": 0x8040c7a4,
		"Strategic::@3080": 0x8040c7b0,
		"Strategic::@3179": 0x8040c7b4,
		"Strategic::@3298": 0x8040c7b8,
		"Strategic::@2878": 0x8040c814,
		"Strategic::@3180": 0x8040c820,
		"M3DUtil::@3225": 0x8040cba0,
		"M3DUtil::@3566": 0x8040cba4,
		"Player::@2179": 0x8040cc50,
		"Player::@3234": 0x8040cc78,
		"Player::@2269": 0x8040ccd0,
		"Player::@2270": 0x8040ccd4,
		"Player::@2271": 0x8040ccd8,
		"Player::@2476": 0x8040ccdc,
		"Player::@3638": 0x8040cfd0,
		"Player::@3650": 0x8040cfd8,
		"Player::@3960": 0x8040cfe4,
		"Player::@3961": 0x8040cfe8,
		"Player::@4321": 0x8040cfec,
		"Player::@4322": 0x8040cff0,
		"Player::@4323": 0x8040cff4,
		"Player::@4324": 0x8040cff8,
		"Player::@4938": 0x8040d010,
		"Player::@4939": 0x8040d014,
		"Player::@4940": 0x8040d018,
		"Player::@4941": 0x8040d01c,
		"Player::@4942": 0x8040d020,
		"Player::@5652": 0x8040d024,
		"Player::@5734": 0x8040d03c,
		"Player::@5735": 0x8040d040,
		"Player::@6339": 0x8040d044,
		"@6339": 0x8040d044,
		"Player::@6340": 0x8040d048,
		"@6340": 0x8040d048,
		"Player::@6341": 0x8040d04c,
		"@6341": 0x8040d04c,
		"Player::@6666": 0x8040d050,
		"Player::@3367": 0x8040d074,
		"Player::@3592": 0x8040d090,
		"Player::@3593": 0x8040d094,
		"Player::@3594": 0x8040d098,
		"Player::@3595": 0x8040d09c,
		"Player::@3905": 0x8040d0a0,
		"Player::@3941": 0x8040d0a4,
		"Player::@3942": 0x8040d0a8,
		"Player::@3943": 0x8040d0ac,
		"Player::@3944": 0x8040d0b0,
		"Player::@3945": 0x8040d0b4,
		"Player::@4059": 0x8040d0c8,
		"Player::@4060": 0x8040d0cc,
		"Player::@4180": 0x8040d0d0,
		"Player::@4597": 0x8040d0e0,
		"Player::@3063": 0x8040d0f8,
		"Player::@4207": 0x8040d100,
		"Player::@4208": 0x8040d104,
		"Player::@4209": 0x8040d108,
		"Player::@4512": 0x8040d144,
		"Player::@5125": 0x8040d15c,
		"Player::@5126": 0x8040d160,
		"Player::@5151": 0x8040d164,
		"Player::@5152": 0x8040d168,
		"Player::@5285": 0x8040d16c,
		"Player::@5286": 0x8040d170,
		"Player::@5287": 0x8040d174,
		"Player::@5706": 0x8040d178,
		"Player::@5708": 0x8040d180,
		"Player::@5709": 0x8040d184,
		"Player::@5710": 0x8040d188,
		"Player::@5808": 0x8040d18c,
		"@5808": 0x8040d18c,
		"Player::@5809": 0x8040d190,
		"@5809": 0x8040d190,
		"Player::@5810": 0x8040d194,
		"@5810": 0x8040d194,
		"Player::@5811": 0x8040d198,
		"Player::@6169": 0x8040d19c,
		"Player::@6170": 0x8040d1a0,
		"Player::@6171": 0x8040d1a4,
		"Player::@6172": 0x8040d1a8,
		"Player::@6173": 0x8040d1ac,
		"Player::@7138": 0x8040d1b0,
		"@7138": 0x8040d1b0,
		"Player::@7139": 0x8040d1b4,
		"Player::@7299": 0x8040d1b8,
		"@7299": 0x8040d1b8,
		"Player::@7578": 0x8040d1bc,
		"Player::@7579": 0x8040d1c0,
		"Player::@7580": 0x8040d1c4,
		"Player::@7581": 0x8040d1c8,
		"Player::@7582": 0x8040d1cc,
		"Player::@7583": 0x8040d1d0,
		"Player::@7584": 0x8040d1d4,
		"Player::@7585": 0x8040d1d8,
		"Player::@8023": 0x8040d1dc,
		"Player::@8056": 0x8040d1e0,
		"@8056": 0x8040d1e0,
		"Player::@3030": 0x8040d210,
		"Player::@3031": 0x8040d214,
		"Player::@3032": 0x8040d218,
		"Player::@3033": 0x8040d21c,
		"Player::@3843": 0x8040d288,
		"Player::@3844": 0x8040d28c,
		"Player::@3845": 0x8040d290,
		"Player::@3900": 0x8040d294,
		"Player::@3901": 0x8040d298,
		"Player::@3957": 0x8040d2a8,
		"Player::@4123": 0x8040d2c8,
		"Player::@4124": 0x8040d2cc,
		"Player::@4125": 0x8040d2d0,
		"Player::@4164": 0x8040d2d4,
		"Player::@4242": 0x8040d2d8,
		"Player::@4521": 0x8040d2e0,
		"Player::@4522": 0x8040d2e4,
		"Player::@4544": 0x8040d2ec,
		"Player::@4545": 0x8040d2f0,
		"Player::@4686": 0x8040d2f4,
		"Player::@4778": 0x8040d2fc,
		"Player::@4944": 0x8040d300,
		"Player::@4945": 0x8040d304,
		"Player::@4946": 0x8040d308,
		"Player::@3391": 0x8040d310,
		"Player::@3392": 0x8040d314,
		"Player::@3393": 0x8040d318,
		"Player::@3394": 0x8040d31c,
		"Player::@3395": 0x8040d320,
		"Player::@3396": 0x8040d324,
		"Player::@3397": 0x8040d328,
		"Player::@3398": 0x8040d32c,
		"Player::@3631": 0x8040d344,
		"Player::@3632": 0x8040d348,
		"Player::@3633": 0x8040d34c,
		"Player::@3634": 0x8040d350,
		"Player::@4049": 0x8040d360,
		"Player::@4050": 0x8040d364,
		"Player::@4051": 0x8040d368,
		"Player::@4200": 0x8040d36c,
		"Player::@4576": 0x8040d370,
		"Player::@4577": 0x8040d374,
		"Player::@4952": 0x8040d380,
		"Player::@5119": 0x8040d398,
		"Player::@5149": 0x8040d39c,
		"Player::@5223": 0x8040d3a0,
		"Player::@5224": 0x8040d3a4,
		"Player::@5225": 0x8040d3a8,
		"Player::@5226": 0x8040d3ac,
		"Player::@5227": 0x8040d3b0,
		"Player::@5321": 0x8040d3b4,
		"Player::@5322": 0x8040d3b8,
		"Player::@5323": 0x8040d3bc,
		"Player::@5324": 0x8040d3c0,
		"Player::@2222": 0x8040d3c8,
		"Player::@2223": 0x8040d3cc,
		"Player::@3057": 0x8040d3fc,
		"Player::@3058": 0x8040d400,
		"Player::@3059": 0x8040d404,
		"Player::@3061": 0x8040d40c,
		"Player::@3062": 0x8040d410,
		"Player::@3159": 0x8040d418,
		"Player::@3353": 0x8040d438,
		"Player::@3438": 0x8040d460,
		"Player::@1969": 0x8040d468,
		"Player::@2005": 0x8040d46c,
		"Player::@2087": 0x8040d470,
		"Player::@2630": 0x8040d4a0,
		"Player::@3274": 0x8040d4e0,
		"Player::@3275": 0x8040d4e4,
		"Player::@3948": 0x8040d514,
		"Player::@4662": 0x8040d538,
		"Player::@5099": 0x8040d544,
		"Player::@6090": 0x8040d548,
		"Player::@6091": 0x8040d550,
		"Player::@6093": 0x8040d558,
		"Player::@6095": 0x8040d55c,
		"Player::@6098": 0x8040d560,
		"Player::@6100": 0x8040d568,
		"Player::@6109": 0x8040d56c,
		"@6109": 0x8040d56c,
		"Player::@6111": 0x8040d570,
		"@6111": 0x8040d570,
		"Player::@6119": 0x8040d574,
		"@6119": 0x8040d574,
		"Player::@6125": 0x8040d57c,
		"@6125": 0x8040d57c,
		"Player::@6127": 0x8040d580,
		"Player::@6130": 0x8040d584,
		"Player::@6132": 0x8040d588,
		"Player::@6134": 0x8040d58c,
		"Player::@6139": 0x8040d594,
		"Player::@3296": 0x8040d598,
		"Player::@3846": 0x8040d5a8,
		"Player::@3847": 0x8040d5ac,
		"Player::@3848": 0x8040d5b0,
		"Player::@3849": 0x8040d5b4,
		"Player::@3859": 0x8040d5c8,
		"Player::@4110": 0x8040d5cc,
		"Player::@4955": 0x8040d5d0,
		"Player::@4966": 0x8040d5e0,
		"Player::@4967": 0x8040d5e4,
		"Player::@4968": 0x8040d5e8,
		"Player::@4969": 0x8040d5ec,
		"Player::@4971": 0x8040d5f4,
		"Player::@4972": 0x8040d5f8,
		"Player::@4973": 0x8040d5fc,
		"Player::@4974": 0x8040d600,
		"Player::@4977": 0x8040d604,
		"Player::@2010": 0x8040d658,
		"Player::@2509": 0x8040d660,
		"Player::@2510": 0x8040d664,
		"Player::@2511": 0x8040d668,
		"Player::@2512": 0x8040d670,
		"Player::@2513": 0x8040d674,
		"Player::@2514": 0x8040d67c,
		"Player::@2551": 0x8040d684,
		"Player::@2553": 0x8040d688,
		"Player::@2580": 0x8040d690,
		"Player::@2583": 0x8040d698,
		"Player::@2585": 0x8040d6a0,
		"Player::@2586": 0x8040d6a4,
		"Player::@2587": 0x8040d6ac,
		"Player::@2606": 0x8040d6b0,
		"Player::@2608": 0x8040d6b8,
		"Player::@2610": 0x8040d6bc,
		"Player::@2612": 0x8040d6c0,
		"Player::@2614": 0x8040d6c4,
		"Player::@2627": 0x8040d6c8,
		"Player::@2702": 0x8040d6e0,
		"Player::@2703": 0x8040d6e4,
		"Player::@2704": 0x8040d6ec,
		"Player::@2705": 0x8040d6f0,
		"Player::@2706": 0x8040d6f8,
		"Player::@2707": 0x8040d6fc,
		"Player::@2708": 0x8040d704,
		"Player::@2709": 0x8040d708,
		"Player::@3237": 0x8040d7a8,
		"Player::@3240": 0x8040d7ac,
		"Player::@3360": 0x8040d7c0,
		"Player::@3552": 0x8040d7e8,
		"Player::@3557": 0x8040d7f0,
		"Player::@3778": 0x8040d824,
		"Player::@3963": 0x8040d830,
		"Player::@3965": 0x8040d838,
		"Player::@4126": 0x8040d858,
		"Player::@6706": 0x8040d880,
		"Player::@4212": 0x8040da08,
		"Player::@4213": 0x8040da0c,
		"Player::@4217": 0x8040da1c,
		"Player::@4218": 0x8040da20,
		"Player::@4219": 0x8040da24,
		"Player::@4220": 0x8040da28,
		"Player::@4263": 0x8040da38,
		"@4263": 0x8040da38,
		"System::@3855": 0x8040da78,
		"System::@3856": 0x8040da7c,
		"System::@3857": 0x8040da80,
		"System::@3858": 0x8040da84,
		"System::@2178": 0x8040dab8,
		"System::@2179": 0x8040dabc,
		"System::@2180": 0x8040dac0,
		"System::@3909": 0x8040db08,
		"System::@3910": 0x8040db0c,
		"System::@3912": 0x8040db10,
		"System::@4379": 0x8040db28,
		"System::@3070": 0x8040db40,
		"System::@2536": 0x8040dcd8,
		"System::@2540": 0x8040dcdc,
		"System::@2676": 0x8040dcf8,
		"System::@2679": 0x8040dd04,
		"System::@2680": 0x8040dd08,
		"System::@2681": 0x8040dd0c,
		"System::@2682": 0x8040dd10,
		"System::@1904": 0x8040dd60,
		"System::@4212": 0x8040deb0,
		"System::@4213": 0x8040deb4,
		"System::@2545": 0x8040e098,
		"System::@2546": 0x8040e09c,
		"System::@2547": 0x8040e0a0,
		"System::@2956": 0x8040e0ac,
		"System::@2963": 0x8040e0b4,
		"System::@2965": 0x8040e0b8,
		"System::@2796": 0x8040e100,
		"System::@3008": 0x8040e118,
		"System::@3449": 0x8040e128,
		"System::@3450": 0x8040e12c,
		"System::@3643": 0x8040e130,
		"System::@3644": 0x8040e134,
		"System::@3645": 0x8040e138,
		"System::@3646": 0x8040e13c,
		"JSystem::@722": 0x8040e158,
		"@722": 0x8040e158,
		"JSystem::@724": 0x8040e160,
		"@724": 0x8040e160,
		"JSystem::@728": 0x8040e170,
		"@728": 0x8040e170,
		"JSystem::@730": 0x8040e178,
		"@730": 0x8040e178,
		"JSystem::@1783": 0x8040e188,
		"JSystem::@370": 0x8040e190,
		"@370": 0x8040e190,
		"JSystem::@1565": 0x8040e1c0,
		"JSystem::@1629": 0x8040e1c4,
		"JSystem::@1630": 0x8040e1c8,
		"JSystem::@1756": 0x8040e1cc,
		"JSystem::@2094": 0x8040e1d0,
		"JSystem::@2216": 0x8040e1d8,
		"JSystem::@192": 0x8040e1e0,
		"JSystem::@604": 0x8040e1e8,
		"JSystem::@609": 0x8040e1f8,
		"JSystem::@639": 0x8040e210,
		"JSystem::@640": 0x8040e214,
		"JSystem::@669": 0x8040e220,
		"JSystem::@670": 0x8040e224,
		"@670": 0x8040e224,
		"JSystem::@671": 0x8040e228,
		"@671": 0x8040e228,
		"JSystem::@672": 0x8040e22c,
		"@672": 0x8040e22c,
		"JSystem::@135": 0x8040e230,
		"@135": 0x8040e230,
		"JSystem::@543": 0x8040e288,
		"@543": 0x8040e288,
		"JSystem::@297": 0x8040e298,
		"JSystem::@920": 0x8040e2b0,
		"JSystem::@1014": 0x8040e2b4,
		"@1014": 0x8040e2b4,
		"JSystem::@52": 0x8040e2b8,
		"JSystem::@276": 0x8040e2c8,
		"@276": 0x8040e2c8,
		"JSystem::@403": 0x8040e2cc,
		"@403": 0x8040e2cc,
		"JSystem::@1321": 0x8040e2e8,
		"@1321": 0x8040e2e8,
		"JSystem::@1322": 0x8040e2ec,
		"@1322": 0x8040e2ec,
		"JSystem::@1329": 0x8040e2f8,
		"@1329": 0x8040e2f8,
		"JSystem::@871": 0x8040e300,
		"@871": 0x8040e300,
		"JSystem::@872": 0x8040e304,
		"@872": 0x8040e304,
		"JSystem::@912": 0x8040e308,
		"@912": 0x8040e308,
		"JSystem::@1084": 0x8040e310,
		"@1084": 0x8040e310,
		"JSystem::@1099": 0x8040e314,
		"JSystem::@1259": 0x8040e31c,
		"@1259": 0x8040e31c,
		"JSystem::@1260": 0x8040e320,
		"@1260": 0x8040e320,
		"JSystem::@1261": 0x8040e324,
		"@1261": 0x8040e324,
		"JSystem::@1262": 0x8040e328,
		"@1262": 0x8040e328,
		"JSystem::@1077": 0x8040e348,
		"@1077": 0x8040e348,
		"JSystem::@1258": 0x8040e34c,
		"@1258": 0x8040e34c,
		"JSystem::@330": 0x8040e350,
		"@330": 0x8040e350,
		"JSystem::@2218": 0x8040e35c,
		"JSystem::@2219": 0x8040e360,
		"JSystem::@2221": 0x8040e364,
		"JSystem::@2222": 0x8040e36c,
		"JSystem::@2223": 0x8040e370,
		"JSystem::@2225": 0x8040e374,
		"JSystem::@2226": 0x8040e37c,
		"JSystem::@2227": 0x8040e380,
		"JSystem::@2456": 0x8040e384,
		"JSystem::@1460": 0x8040e388,
		"@1460": 0x8040e388,
		"JSystem::@2249": 0x8040e38c,
		"JSystem::@994": 0x8040e3a0,
		"@994": 0x8040e3a0,
		"JSystem::@956": 0x8040e3ac,
		"@956": 0x8040e3ac,
		"JSystem::@1073": 0x8040e3b0,
		"JSystem::@1500": 0x8040e3c8,
		"@1500": 0x8040e3c8,
		"JSystem::@1288": 0x8040e3d8,
		"@1288": 0x8040e3d8,
		"JSystem::@1345": 0x8040e3dc,
		"@1345": 0x8040e3dc,
		"JSystem::@1425": 0x8040e3e0,
		"@1425": 0x8040e3e0,
		"JSystem::@1443": 0x8040e3e8,
		"@1443": 0x8040e3e8,
		"JSystem::@1126": 0x8040e3f0,
		"@1126": 0x8040e3f0,
		"JSystem::@123": 0x8040e408,
		"JSystem::@124": 0x8040e40c,
		"@124": 0x8040e40c,
		"JSystem::@926": 0x8040e428,
		"@926": 0x8040e428,
		"JSystem::@927": 0x8040e42c,
		"@927": 0x8040e42c,
		"JSystem::@978": 0x8040e430,
		"@978": 0x8040e430,
		"JSystem::@979": 0x8040e434,
		"@979": 0x8040e434,
		"JSystem::@824": 0x8040e440,
		"@824": 0x8040e440,
		"JSystem::@825": 0x8040e444,
		"@825": 0x8040e444,
		"JSystem::@360": 0x8040e450,
		"JSystem::@100": 0x8040e460,
		"JSystem::@111": 0x8040e468,
		"JSystem::@335": 0x8040e470,
		"@335": 0x8040e470,
		"JSystem::@295": 0x8040e48c,
		"JSystem::@385": 0x8040e498,
		"JSystem::@386": 0x8040e49c,
		"JSystem::@388": 0x8040e4a8,
		"JSystem::@390": 0x8040e4b8,
		"@390": 0x8040e4b8,
		"JSystem::@697": 0x8040e4c8,
		"@697": 0x8040e4c8,
		"JSystem::@2338": 0x8040e4e8,
		"JSystem::@878": 0x8040e4f4,
		"@878": 0x8040e4f4,
		"JSystem::@879": 0x8040e4f8,
		"@879": 0x8040e4f8,
		"JSystem::@633": 0x8040e508,
		"@633": 0x8040e508,
		"JSystem::@634": 0x8040e50c,
		"JSystem::@1466": 0x8040e510,
		"@1466": 0x8040e510,
		"JSystem::@1467": 0x8040e514,
		"@1467": 0x8040e514,
		"JSystem::@1469": 0x8040e518,
		"@1469": 0x8040e518,
		"JSystem::@1470": 0x8040e51c,
		"@1470": 0x8040e51c,
		"JSystem::@1471": 0x8040e520,
		"@1471": 0x8040e520,
		"JSystem::@1472": 0x8040e524,
		"@1472": 0x8040e524,
		"JSystem::@1477": 0x8040e528,
		"@1477": 0x8040e528,
		"JSystem::@1478": 0x8040e530,
		"@1478": 0x8040e530,
		"JSystem::@1479": 0x8040e538,
		"@1479": 0x8040e538,
		"JSystem::@48": 0x8040e548,
		"@48": 0x8040e548,
		"JSystem::@244": 0x8040e568,
		"@244": 0x8040e568,
		"JSystem::@354": 0x8040e570,
		"JSystem::@355": 0x8040e574,
		"JSystem::@544": 0x8040e588,
		"@544": 0x8040e588,
		"JSystem::@461": 0x8040e590,
		"JSystem::@622": 0x8040e594,
		"@622": 0x8040e594,
		"JSystem::@623": 0x8040e598,
		"@623": 0x8040e598,
		"JSystem::@624": 0x8040e59c,
		"@624": 0x8040e59c,
		"JSystem::@413": 0x8040e5b8,
		"@413": 0x8040e5b8,
		"JSystem::@694": 0x8040e5c0,
		"JSystem::@695": 0x8040e5c4,
		"JSystem::@696": 0x8040e5c8,
		"@696": 0x8040e5c8,
		"JSystem::@1287": 0x8040e5cc,
		"@1287": 0x8040e5cc,
		"JSystem::@494": 0x8040e5d8,
		"@494": 0x8040e5d8,
		"JSystem::@495": 0x8040e5dc,
		"@495": 0x8040e5dc,
		"JSystem::@496": 0x8040e5e0,
		"@496": 0x8040e5e0,
		"JSystem::@551": 0x8040e5ec,
		"@551": 0x8040e5ec,
		"JSystem::@587": 0x8040e5f8,
		"@587": 0x8040e5f8,
		"JSystem::@588": 0x8040e5fc,
		"@588": 0x8040e5fc,
		"JSystem::@589": 0x8040e600,
		"@589": 0x8040e600,
		"JSystem::@590": 0x8040e604,
		"@590": 0x8040e604,
		"JSystem::@762": 0x8040e628,
		"JSystem::@763": 0x8040e62c,
		"JSystem::@934": 0x8040e638,
		"@934": 0x8040e638,
		"JSystem::@935": 0x8040e63c,
		"@935": 0x8040e63c,
		"JSystem::@826": 0x8040e644,
		"@826": 0x8040e644,
		"JSystem::@829": 0x8040e658,
		"@829": 0x8040e658,
		"JSystem::@830": 0x8040e65c,
		"@830": 0x8040e65c,
		"JSystem::@932": 0x8040e668,
		"@932": 0x8040e668,
		"JSystem::@504": 0x8040e678,
		"@504": 0x8040e678,
		"JSystem::@989": 0x8040e680,
		"@989": 0x8040e680,
		"JSystem::@534": 0x8040e698,
		"@534": 0x8040e698,
		"JSystem::@535": 0x8040e6a0,
		"@535": 0x8040e6a0,
		"JSystem::@536": 0x8040e6a8,
		"@536": 0x8040e6a8,
		"JSystem::@434": 0x8040e6b8,
		"@434": 0x8040e6b8,
		"JSystem::@602": 0x8040e6bc,
		"JSystem::@680": 0x8040e6e0,
		"@680": 0x8040e6e0,
		"JSystem::@681": 0x8040e6e4,
		"@681": 0x8040e6e4,
		"JSystem::@943": 0x8040e6e8,
		"JSystem::@944": 0x8040e6ec,
		"@944": 0x8040e6ec,
		"JSystem::@1207": 0x8040e6f4,
		"@1207": 0x8040e6f4,
		"JSystem::@1242": 0x8040e6f8,
		"@1242": 0x8040e6f8,
		"JSystem::@1373": 0x8040e6fc,
		"@1373": 0x8040e6fc,
		"JSystem::@509": 0x8040e700,
		"@509": 0x8040e700,
		"JSystem::@339": 0x8040e708,
		"JSystem::@340": 0x8040e70c,
		"JSystem::@418": 0x8040e710,
		"@418": 0x8040e710,
		"JSystem::@419": 0x8040e714,
		"@419": 0x8040e714,
		"JSystem::@435": 0x8040e720,
		"JSystem::@568": 0x8040e748,
		"@568": 0x8040e748,
		"JSystem::@328": 0x8040e758,
		"@328": 0x8040e758,
		"JSystem::@345": 0x8040e760,
		"@345": 0x8040e760,
		"JSystem::@346": 0x8040e764,
		"@346": 0x8040e764,
		"JSystem::@252": 0x8040e770,
		"@252": 0x8040e770,
		"JSystem::@253": 0x8040e774,
		"@253": 0x8040e774,
		"JSystem::@274": 0x8040e7a0,
		"@274": 0x8040e7a0,
		"JSystem::@836": 0x8040e7ac,
		"@836": 0x8040e7ac,
		"JSystem::@120": 0x8040e7c0,
		"@120": 0x8040e7c0,
		"JSystem::@204": 0x8040e7d0,
		"@204": 0x8040e7d0,
		"JSystem::@231": 0x8040e7d4,
		"@231": 0x8040e7d4,
		"JSystem::@260": 0x8040e7d8,
		"JSystem::@261": 0x8040e7dc,
		"JSystem::@332": 0x8040e7f0,
		"@332": 0x8040e7f0,
		"JSystem::@334": 0x8040e800,
		"@334": 0x8040e800,
		"JSystem::@236": 0x8040e808,
		"@236": 0x8040e808,
		"JSystem::@525": 0x8040e818,
		"@525": 0x8040e818,
		"JSystem::@526": 0x8040e81c,
		"@526": 0x8040e81c,
		"JSystem::@527": 0x8040e820,
		"@527": 0x8040e820,
		"JSystem::@528": 0x8040e824,
		"@528": 0x8040e824,
		"JSystem::@621": 0x8040e83c,
		"@621": 0x8040e83c,
		"JSystem::@754": 0x8040e848,
		"JSystem::@129": 0x8040e868,
		"@129": 0x8040e868,
		"JSystem::@642": 0x8040e890,
		"JSystem::@797": 0x8040e898,
		"JSystem::@948": 0x8040e8a0,
		"@948": 0x8040e8a0,
		"JSystem::@949": 0x8040e8a4,
		"@949": 0x8040e8a4,
		"JSystem::@950": 0x8040e8a8,
		"@950": 0x8040e8a8,
		"JSystem::@981": 0x8040e8b8,
		"@981": 0x8040e8b8,
		"JSystem::@1217": 0x8040e8c0,
		"@1217": 0x8040e8c0,
		"JSystem::@1326": 0x8040e8c4,
		"@1326": 0x8040e8c4,
		"JSystem::@1344": 0x8040e8cc,
		"@1344": 0x8040e8cc,
		"JSystem::@363": 0x8040e8d0,
		"JSystem::@377": 0x8040e8d8,
		"@377": 0x8040e8d8,
		"JSystem::@411": 0x8040e8f8,
		"@411": 0x8040e8f8,
		"JSystem::@1706": 0x8040e910,
		"JSystem::@1707": 0x8040e914,
		"JSystem::@2032": 0x8040e930,
		"JSystem::@2829": 0x8040e934,
		"JSystem::@2830": 0x8040e938,
		"JSystem::@2840": 0x8040e948,
		"JSystem::@1786": 0x8040e950,
		"JSystem::@1787": 0x8040e954,
		"JSystem::@1673": 0x8040e960,
		"JSystem::@1877": 0x8040e964,
		"@1877": 0x8040e964,
		"JSystem::@1955": 0x8040e968,
		"JSystem::@1956": 0x8040e96c,
		"JSystem::@1957": 0x8040e970,
		"JSystem::@2076": 0x8040e974,
		"JSystem::@1639": 0x8040e97c,
		"JSystem::@1681": 0x8040e98c,
		"JSystem::@1682": 0x8040e990,
		"JSystem::@1683": 0x8040e994,
		"JSystem::@1675": 0x8040e9b0,
		"JSystem::@1689": 0x8040e9b4,
		"JSystem::@1820": 0x8040e9b8,
		"JSystem::@1659": 0x8040e9c0,
		"JSystem::@1860": 0x8040e9c4,
		"JSystem::@2759": 0x8040e9e8,
		"JSystem::@2760": 0x8040e9ec,
		"JSystem::@2761": 0x8040e9f0,
		"JSystem::@2762": 0x8040e9f4,
		"JSystem::@3307": 0x8040e9f8,
		"JSystem::@1743": 0x8040ea08,
		"@1743": 0x8040ea08,
		"JSystem::@1744": 0x8040ea0c,
		"@1744": 0x8040ea0c,
		"JSystem::@1745": 0x8040ea10,
		"@1745": 0x8040ea10,
		"JSystem::@2374": 0x8040ea28,
		"JSystem::@2375": 0x8040ea2c,
		"JSystem::@2378": 0x8040ea30,
		"JSystem::@2379": 0x8040ea34,
		"JSystem::@2380": 0x8040ea38,
		"JSystem::@2538": 0x8040ea3c,
		"JSystem::@2542": 0x8040ea40,
		"JSystem::@4485": 0x8040ea44,
		"JSystem::@4568": 0x8040ea48,
		"@4568": 0x8040ea48,
		"JSystem::@1505": 0x8040ea50,
		"JSystem::@1506": 0x8040ea54,
		"@1506": 0x8040ea54,
		"JSystem::@1570": 0x8040ea68,
		"JSystem::@1571": 0x8040ea6c,
		"JSystem::@1509": 0x8040ea70,
		"@1509": 0x8040ea70,
		"JSystem::@1510": 0x8040ea74,
		"@1510": 0x8040ea74,
		"JSystem::@1511": 0x8040ea78,
		"@1511": 0x8040ea78,
		"JSystem::@126": 0x8040ea98,
		"JSystem::@118": 0x8040eaa0,
		"@118": 0x8040eaa0,
		"JSystem::@71": 0x8040eaa8,
		"MSL_C.PPCEABI.bare.H::@156": 0x8040eb68,
		"MSL_C.PPCEABI.bare.H::@157": 0x8040eb6c,
		"MSL_C.PPCEABI.bare.H::@158": 0x8040eb70,
		"MSL_C.PPCEABI.bare.H::@159": 0x8040eb74,
		"MSL_C.PPCEABI.bare.H::@168": 0x8040eb78,
		"MSL_C.PPCEABI.bare.H::@169": 0x8040eb7c,
		"MSL_C.PPCEABI.bare.H::@170": 0x8040eb80,
		"MSL_C.PPCEABI.bare.H::@188": 0x8040eb84,
		"MSL_C.PPCEABI.bare.H::@106": 0x8040eb88,
		"@106": 0x8040eb88,
		"MSL_C.PPCEABI.bare.H::@107": 0x8040eb8c,
		"@107": 0x8040eb8c,
		"MSL_C.PPCEABI.bare.H::@108": 0x8040eb90,
		"@108": 0x8040eb90,
		"MSL_C.PPCEABI.bare.H::__log2e_m1$localstatic0$__log2f__Ff": 0x8040eba0,
		"__log2e_m1$localstatic0$__log2f__Ff": 0x8040eba0,
		"MSL_C.PPCEABI.bare.H::@93": 0x8040eba8,
		"MSL_C.PPCEABI.bare.H::_inf": 0x8040ebb0,
		"_inf": 0x8040ebb0,
		"MSL_C.PPCEABI.bare.H::_nan": 0x8040ebb4,
		"_nan": 0x8040ebb4,
		"MSL_C.PPCEABI.bare.H::@246": 0x8040ebb8,
		"@246": 0x8040ebb8,
		"MSL_C.PPCEABI.bare.H::@247": 0x8040ebbc,
		"@247": 0x8040ebbc,
		"MSL_C.PPCEABI.bare.H::@248": 0x8040ebc0,
		"@248": 0x8040ebc0,
		"MSL_C.PPCEABI.bare.H::@249": 0x8040ebc4,
		"@249": 0x8040ebc4,
		"MSL_C.PPCEABI.bare.H::@250": 0x8040ebc8,
		"@250": 0x8040ebc8,
		"MSL_C.PPCEABI.bare.H::@251": 0x8040ebcc,
		"@251": 0x8040ebcc,
		"MSL_C.PPCEABI.bare.H::@259": 0x8040ebd8,
		"MSL_C.PPCEABI.bare.H::@260": 0x8040ebdc,
		"MSL_C.PPCEABI.bare.H::@261": 0x8040ebe0,
		"MSL_C.PPCEABI.bare.H::@262": 0x8040ebe4,
		"os::@153": 0x8040ebe8,
		"mtx::@94": 0x8040ebf0,
		"mtx::@95": 0x8040ebf4,
		"mtx::@193": 0x8040ebf8,
		"mtx::@214": 0x8040ebfc,
		"mtx::@217": 0x8040ec00,
		"@217": 0x8040ec00,
		"mtx::@218": 0x8040ec04,
		"@218": 0x8040ec04,
		"mtx::@97": 0x8040ec08,
		"mtx::@98": 0x8040ec0c,
		"mtx::@99": 0x8040ec10,
		"mtx::@100": 0x8040ec14,
		"mtx::@103": 0x8040ec18,
		"@103": 0x8040ec18,
		"mtx::@104": 0x8040ec1c,
		"@104": 0x8040ec1c,
		"mtx::@116": 0x8040ec20,
		"mtx::@117": 0x8040ec24,
		"gx::@122": 0x8040ec2c,
		"@122": 0x8040ec2c,
		"gx::@123": 0x8040ec30,
		"gx::@177": 0x8040ec34,
		"gx::@178": 0x8040ec38,
		"gx::@179": 0x8040ec3c,
		"gx::@83": 0x8040ec48,
		"gx::@127": 0x8040ec5c,
		"gx::@148": 0x8040ec60,
		"gx::@167": 0x8040ec78,
		"gx::@164": 0x8040ec80,
		"gx::@192": 0x8040ec90,
		"gx::@193": 0x8040ec94,
		"gx::@194": 0x8040ec98,
		"@194": 0x8040ec98,
		"gx::@195": 0x8040ec9c,
		"@195": 0x8040ec9c,
		"gx::@196": 0x8040eca0,
		"@196": 0x8040eca0,
		"gx::@197": 0x8040eca4,
		"gx::@45": 0x8040eca8,
		"@45": 0x8040eca8,
		"gx::@125": 0x8040ecb0,
		"@125": 0x8040ecb0,
		"gx::@126": 0x8040ecb4,
		"gx::@130": 0x8040ecd0,
		"gx::@357": 0x8040ece4,
		"gx::@358": 0x8040ece8,
		"gx::@360": 0x8040ecec,
		"gx::@405": 0x8040ed00,
		"@405": 0x8040ed00,
		"gx::@493": 0x8040ed04,
		"@493": 0x8040ed04,
		"gx::@14": 0x8040ed08,
		"gx::@15": 0x8040ed0c,
		"gx::@16": 0x8040ed10,
		"gx::@63": 0x8040ed20,
		"gx::@64": 0x8040ed24,
		"thp::@665": 0x8040ed30,
		"@665": 0x8040ed30,
		"thp::@666": 0x8040ed34,
		"@666": 0x8040ed34,
		"thp::@667": 0x8040ed38,
		"@667": 0x8040ed38,
		"thp::@668": 0x8040ed3c,
		"@668": 0x8040ed3c,
		"thp::@669": 0x8040ed40,
		"THPPlayer::@22": 0x80406888,
		"THPPlayer::@25": 0x80406890,
		"THPPlayer::@28": 0x80406894,
		"THPPlayer::@31": 0x80406898,
		"THPPlayer::@55": 0x8040689c,
		"@55": 0x8040689c,
		"THPPlayer::@71": 0x804068a0,
		"THPPlayer::@72": 0x804068a4,
		"@72": 0x804068a4,
		"MarioUtil::@1997": 0x8040c8d8,
		"MarioUtil::@1999": 0x8040c8dc,
		"MarioUtil::@2009": 0x8040c8e0,
		"MarioUtil::@2452": 0x8040c8f0,
		"MarioUtil::@2453": 0x8040c8f4,
		"MarioUtil::@2472": 0x8040c8f8,
		"MarioUtil::@2473": 0x8040c8fc,
		"MarioUtil::@2948": 0x8040c900,
		"MarioUtil::@3041": 0x8040c904,
		"MarioUtil::@3042": 0x8040c908,
		"MarioUtil::@3043": 0x8040c90c,
		"MarioUtil::@3044": 0x8040c910,
		"MarioUtil::@3357": 0x8040c914,
		"MarioUtil::@3505": 0x8040c918,
		"MarioUtil::@3506": 0x8040c91c,
		"MarioUtil::@3507": 0x8040c920,
		"MarioUtil::@3555": 0x8040c924,
		"MarioUtil::@3556": 0x8040c928,
		"MarioUtil::@3557": 0x8040c92c,
		"MarioUtil::@3558": 0x8040c930,
		"MarioUtil::@3560": 0x8040c934,
		"MarioUtil::@3561": 0x8040c938,
		"MarioUtil::@3565": 0x8040c93c,
		"MarioUtil::@3566": 0x8040c940,
		"MarioUtil::@2043": 0x8040c950,
		"MarioUtil::@2044": 0x8040c954,
		"MarioUtil::@2045": 0x8040c958,
		"MarioUtil::@2046": 0x8040c95c,
		"MarioUtil::@2228": 0x8040c964,
		"MarioUtil::@2229": 0x8040c968,
		"MarioUtil::@2230": 0x8040c96c,
		"MarioUtil::@2231": 0x8040c970,
		"MarioUtil::@2665": 0x8040c978,
		"MarioUtil::@2666": 0x8040c980,
		"MarioUtil::@2667": 0x8040c984,
		"MarioUtil::@2844": 0x8040c988,
		"MarioUtil::@1608": 0x8040c990,
		"MarioUtil::@1627": 0x8040c9a0,
		"MarioUtil::@1638": 0x8040c9a4,
		"MarioUtil::@1639": 0x8040c9a8,
		"MarioUtil::@1673": 0x8040c9ac,
		"MarioUtil::@1674": 0x8040c9b0,
		"MarioUtil::@1675": 0x8040c9b4,
		"MarioUtil::@1676": 0x8040c9b8,
		"MarioUtil::@1797": 0x8040c9bc,
		"MarioUtil::@1798": 0x8040c9c0,
		"MarioUtil::@1884": 0x8040c9d8,
		"@1884": 0x8040c9d8,
		"MarioUtil::@2093": 0x8040c9e0,
		"MarioUtil::@2094": 0x8040c9e4,
		"MarioUtil::@2123": 0x8040c9e8,
		"MarioUtil::@2124": 0x8040c9ec,
		"MarioUtil::@2156": 0x8040c9f0,
		"MarioUtil::@2194": 0x8040c9f8,
		"MarioUtil::@2550": 0x8040ca10,
		"MarioUtil::@2551": 0x8040ca18,
		"MarioUtil::@2552": 0x8040ca1c,
		"MarioUtil::@2553": 0x8040ca20,
		"MarioUtil::@2554": 0x8040ca24,
		"MarioUtil::@2555": 0x8040ca2c,
		"MarioUtil::@1629": 0x8040ca48,
		"MarioUtil::@1630": 0x8040ca4c,
		"MarioUtil::@1631": 0x8040ca50,
		"MarioUtil::@1802": 0x8040ca5c,
		"MarioUtil::@1803": 0x8040ca60,
		"MarioUtil::@1833": 0x8040ca70,
		"MarioUtil::@1834": 0x8040ca74,
		"@1834": 0x8040ca74,
		"MarioUtil::@2235": 0x8040ca78,
		"MarioUtil::@2297": 0x8040ca7c,
		"MarioUtil::@2312": 0x8040ca80,
		"MarioUtil::@2315": 0x8040ca84,
		"MarioUtil::@2743": 0x8040ca8c,
		"MarioUtil::@2744": 0x8040ca90,
		"MarioUtil::@2745": 0x8040ca94,
		"MarioUtil::@2746": 0x8040ca98,
		"MarioUtil::@2747": 0x8040ca9c,
		"MarioUtil::@2748": 0x8040caa0,
		"MarioUtil::@2749": 0x8040caa4,
		"MarioUtil::@2750": 0x8040caa8,
		"MarioUtil::@2751": 0x8040caac,
		"MarioUtil::@2752": 0x8040cab0,
		"MarioUtil::@2753": 0x8040cab4,
		"MarioUtil::@2754": 0x8040cab8,
		"MarioUtil::@2857": 0x8040cabc,
		"MarioUtil::@2858": 0x8040cac0,
		"MarioUtil::@2859": 0x8040cac4,
		"MarioUtil::@2976": 0x8040cac8,
		"MarioUtil::@2977": 0x8040cacc,
		"MarioUtil::@2978": 0x8040cad0,
		"MarioUtil::@4014": 0x8040cad4,
		"MarioUtil::@4158": 0x8040cad8,
		"MarioUtil::@4159": 0x8040cadc,
		"MarioUtil::@4634": 0x8040cae0,
		"MarioUtil::@4756": 0x8040cae4,
		"MarioUtil::@4757": 0x8040cae8,
		"MarioUtil::@4758": 0x8040caec,
		"MarioUtil::@4759": 0x8040caf0,
		"MarioUtil::@4869": 0x8040caf4,
		"MarioUtil::@5163": 0x8040cb00,
		"MarioUtil::@5164": 0x8040cb04,
		"MarioUtil::@51": 0x8040cb08,
		"@51": 0x8040cb08,
		"MarioUtil::@52": 0x8040cb0c,
		"MarioUtil::@53": 0x8040cb10,
		"@53": 0x8040cb10,
		"MarioUtil::@1799": 0x8040cb18,
		"MarioUtil::@2233": 0x8040cb2c,
		"MarioUtil::@1767": 0x8040cb38,
		"MarioUtil::@1790": 0x8040cb3c,
		"MarioUtil::@1841": 0x8040cb40,
		"MarioUtil::@2244": 0x8040cb44,
		"MarioUtil::@2245": 0x8040cb48,
		"MarioUtil::sFogOffColor$1583": 0x8040cb50,
		"sFogOffColor$1583": 0x8040cb50,
		"MarioUtil::@2280": 0x8040cb68,
		"MarioUtil::@2282": 0x8040cb78,
		"MarioUtil::@1941": 0x8040cb88,
		"MarioUtil::@1942": 0x8040cb8c,
		"M3DUtil::@1572": 0x8040cb90,
		"M3DUtil::@1573": 0x8040cb94,
		"M3DUtil::@1716": 0x8040cb98,
		"@1716": 0x8040cb98,
		"M3DUtil::@1875": 0x8040cbb0,
		"M3DUtil::@1908": 0x8040cbb8,
		"M3DUtil::@1909": 0x8040cbbc,
		"M3DUtil::@2660": 0x8040cbc8,
		"M3DUtil::@2663": 0x8040cbd0,
		"M3DUtil::@2666": 0x8040cbd8,
		"M3DUtil::@2669": 0x8040cbe0,
		"M3DUtil::@2672": 0x8040cbe8,
		"M3DUtil::@2019": 0x8040cbf0,
		"M3DUtil::@2020": 0x8040cbf8,
		"M3DUtil::@2021": 0x8040cbfc,
		"M3DUtil::@2022": 0x8040cc04,
		"M3DUtil::@2023": 0x8040cc0c,
		"M3DUtil::@2024": 0x8040cc14,
		"M3DUtil::@2025": 0x8040cc1c,
		"M3DUtil::@2161": 0x8040cc24,
		"M3DUtil::@2162": 0x8040cc2c,
		"M3DUtil::@2163": 0x8040cc30,
		"M3DUtil::@1661": 0x8040cc38,
		"M3DUtil::@1694": 0x8040cc3c,
		"System::@2802": 0x8040da58,
		"System::@2803": 0x8040da5c,
		"System::@1731": 0x8040dae8,
		"@1731": 0x8040dae8,
		"System::@2398": 0x8040daf0,
		"System::@2389": 0x8040db48,
		"System::@2731": 0x8040db50,
		"System::@2738": 0x8040db58,
		"System::@2739": 0x8040db5c,
		"System::@2740": 0x8040db60,
		"System::@2741": 0x8040db64,
		"System::@2742": 0x8040db68,
		"System::@2753": 0x8040db70,
		"System::@2754": 0x8040db74,
		"System::@2975": 0x8040db90,
		"System::@1626": 0x8040db98,
		"System::@4673": 0x8040dbf0,
		"System::@2844": 0x8040dc44,
		"System::@2850": 0x8040dc74,
		"System::@2851": 0x8040dc7c,
		"System::@2852": 0x8040dc84,
		"System::@2853": 0x8040dc8c,
		"System::@1607": 0x8040dcc0,
		"System::@1806": 0x8040dd40,
		"System::@1807": 0x8040dd44,
		"System::@2115": 0x8040dd48,
		"System::@2116": 0x8040dd4c,
		"System::@2121": 0x8040dd58,
		"System::@2122": 0x8040dd5c,
		"System::@1665": 0x8040dd68,
		"System::@3960": 0x8040ddd4,
		"System::@3962": 0x8040dddc,
		"System::@3964": 0x8040dde4,
		"System::@4118": 0x8040de30,
		"System::@2093": 0x8040dec8,
		"System::@2094": 0x8040decc,
		"System::@5046": 0x8040df14,
		"System::@5060": 0x8040df40,
		"System::@5102": 0x8040df74,
		"System::@5207": 0x8040dfc8,
		"@5207": 0x8040dfc8,
		"System::@5328": 0x8040e048,
		"System::@5333": 0x8040e058,
		"System::@3804": 0x8040e0e8,
		"Strategic::@2101": 0x8040c828,
		"Strategic::@2103": 0x8040c82c,
		"Strategic::@2104": 0x8040c830,
		"Strategic::@2277": 0x8040c838,
		"Strategic::@1841": 0x8040c840,
		"Strategic::@1947": 0x8040c848,
		"Strategic::@1662": 0x8040c850,
		"Strategic::@2285": 0x8040c860,
		"Strategic::@2409": 0x8040c864,
		"Strategic::@2532": 0x8040c868,
		"Strategic::@2533": 0x8040c870,
		"Strategic::@2534": 0x8040c878,
		"Strategic::@2535": 0x8040c880,
		"Strategic::@2536": 0x8040c888,
		"Strategic::@2537": 0x8040c890,
		"Strategic::@2538": 0x8040c898,
		"Strategic::@2539": 0x8040c89c,
		"Strategic::@2540": 0x8040c8a4,
		"Strategic::@2829": 0x8040c8ac,
		"Strategic::@2830": 0x8040c8b0,
		"Strategic::@2831": 0x8040c8b4,
		"Strategic::@1772": 0x8040c8b8,
		"Strategic::@1825": 0x8040c8bc,
		"Strategic::@1540": 0x8040c8c0,
		"Strategic::@1618": 0x8040c8c8,
		"Strategic::@1619": 0x8040c8cc,
		"Strategic::@1660": 0x8040c8d0,
		"Player::@2856": 0x8040ce0c,
		"Player::@2857": 0x8040ce14,
		"Player::@2859": 0x8040ce24,
		"Player::@2860": 0x8040ce2c,
		"Player::@2861": 0x8040ce34,
		"Player::@2865": 0x8040ce54,
		"Player::@2866": 0x8040ce5c,
		"Player::@2867": 0x8040ce64,
		"Player::@2958": 0x8040cf50,
		"Player::@3647": 0x8040cfd4,
		"Player::@3070": 0x8040d414,
		"Player::@2710": 0x8040d710,
		"Player::@2712": 0x8040d714,
		"Player::@2714": 0x8040d718,
		"Player::@2717": 0x8040d71c,
		"Player::@2718": 0x8040d724,
		"Player::@2719": 0x8040d728,
		"Player::@3571": 0x8040d7fc,
		"Player::@3749": 0x8040d810,
		"Player::@3998": 0x8040d844,
		"Player::@6572": 0x8040d86c,
		"@6572": 0x8040d86c,
		"Player::@6573": 0x8040d870,
		"@6573": 0x8040d870,
		"Player::@2699": 0x8040d888,
		"Player::@3018": 0x8040d890,
		"Player::@3035": 0x8040d894,
		"Player::@3049": 0x8040d89c,
		"Player::@3680": 0x8040d8dc,
		"Player::@3825": 0x8040d8ec,
		"Player::@3865": 0x8040d900,
		"@3865": 0x8040d900,
		"Player::@4343": 0x8040d904,
		"Player::@4344": 0x8040d908,
		"Player::@4345": 0x8040d90c,
		"Player::@4346": 0x8040d910,
		"Player::@4347": 0x8040d914,
		"Player::@4502": 0x8040d918,
		"Player::@4503": 0x8040d91c,
		"Player::@4561": 0x8040d924,
		"Player::@4562": 0x8040d928,
		"Player::@4563": 0x8040d92c,
		"Player::@4623": 0x8040d930,
		"Player::@4624": 0x8040d934,
		"Player::@4625": 0x8040d938,
		"Player::@4637": 0x8040d944,
		"Player::@4638": 0x8040d948,
		"Player::@4639": 0x8040d94c,
		"Player::@4640": 0x8040d950,
		"Player::@4641": 0x8040d954,
		"Player::@4642": 0x8040d958,
		"Player::@4643": 0x8040d95c,
		"Player::@4644": 0x8040d960,
		"Player::@4648": 0x8040d964,
		"Player::@4650": 0x8040d968,
		"Player::@4651": 0x8040d96c,
		"Player::@4652": 0x8040d974,
		"Player::@4653": 0x8040d978,
		"Player::@4654": 0x8040d97c,
		"Player::@4731": 0x8040d980,
		"Player::@4732": 0x8040d988,
		"Player::@4733": 0x8040d990,
		"Player::@4734": 0x8040d998,
		"Player::@4735": 0x8040d9a0,
		"Player::@4737": 0x8040d9a4,
		"Player::@4739": 0x8040d9ac,
		"Player::@4740": 0x8040d9b4,
		"Player::@4744": 0x8040d9b8,
		"Player::@4745": 0x8040d9c0,
		"NPC::@3245": 0x8040c348,
		"NPC::@3246": 0x8040c34c,
		"NPC::@3247": 0x8040c350,
		"NPC::@3361": 0x8040c360,
		"NPC::@3362": 0x8040c364,
		"NPC::@3363": 0x8040c368,
		"NPC::@3365": 0x8040c370,
		"NPC::@3366": 0x8040c374,
		"NPC::@3472": 0x8040c378,
		"NPC::@3878": 0x8040c37c,
		"NPC::@3879": 0x8040c380,
		"NPC::@4245": 0x8040c384,
		"NPC::@4246": 0x8040c388,
		"NPC::@4247": 0x8040c38c,
		"NPC::@4250": 0x8040c3a0,
		"NPC::@4778": 0x8040c3a4,
		"NPC::@3704": 0x8040c3ac,
		"NPC::@3705": 0x8040c3b0,
		"NPC::@3706": 0x8040c3b4,
		"NPC::@3707": 0x8040c3b8,
		"NPC::@3935": 0x8040c3d0,
		"NPC::@3936": 0x8040c3d4,
		"NPC::@3989": 0x8040c3d8,
		"NPC::@4213": 0x8040c3dc,
		"NPC::@2536": 0x8040c40c,
		"NPC::@2804": 0x8040c410,
		"NPC::@2805": 0x8040c414,
		"NPC::@2860": 0x8040c418,
		"NPC::@2898": 0x8040c420,
		"NPC::@2934": 0x8040c424,
		"NPC::@2857": 0x8040c450,
		"NPC::@3036": 0x8040c454,
		"NPC::@3037": 0x8040c458,
		"NPC::@2161": 0x8040c460,
		"NPC::@2163": 0x8040c464,
		"NPC::@2165": 0x8040c468,
		"NPC::@2167": 0x8040c46c,
		"NPC::@2169": 0x8040c470,
		"NPC::@2171": 0x8040c474,
		"NPC::@2173": 0x8040c478,
		"NPC::@2175": 0x8040c47c,
		"NPC::@2177": 0x8040c480,
		"NPC::@2180": 0x8040c484,
		"NPC::@2182": 0x8040c488,
		"NPC::@2184": 0x8040c48c,
		"NPC::@2187": 0x8040c490,
		"NPC::@2189": 0x8040c494,
		"NPC::@2194": 0x8040c498,
		"NPC::@2196": 0x8040c49c,
		"NPC::@2204": 0x8040c4ac,
		"NPC::@2206": 0x8040c4b0,
		"NPC::@2208": 0x8040c4b4,
		"NPC::@2341": 0x8040c4e0,
		"NPC::@2356": 0x8040c4e8,
		"NPC::@2375": 0x8040c4fc,
		"NPC::@2419": 0x8040c500,
		"NPC::sPeach_TakenMiddle": 0x8040c520,
		"sPeach_TakenMiddle": 0x8040c520,
		"NPC::@1539": 0x8040c528,
		"NPC::sMonteM_TieBColorBuf0": 0x8040c530,
		"sMonteM_TieBColorBuf0": 0x8040c530,
		"NPC::sMonteM_TieBColorBuf1": 0x8040c538,
		"sMonteM_TieBColorBuf1": 0x8040c538,
		"NPC::@1573": 0x8040c540,
		"NPC::@1577": 0x8040c548,
		"NPC::sMareMB_ElderMat1ColorBuf0": 0x8040c550,
		"sMareMB_ElderMat1ColorBuf0": 0x8040c550,
		"NPC::sMareMB_ElderMat1ColorBuf1": 0x8040c558,
		"sMareMB_ElderMat1ColorBuf1": 0x8040c558,
		"NPC::sMareMB_ElderMat2ColorBuf0": 0x8040c560,
		"sMareMB_ElderMat2ColorBuf0": 0x8040c560,
		"NPC::sMareMB_ElderMat2ColorBuf1": 0x8040c568,
		"sMareMB_ElderMat2ColorBuf1": 0x8040c568,
		"NPC::@1583": 0x8040c570,
		"NPC::sMareMB_ElderMat3ColorBuf0": 0x8040c578,
		"sMareMB_ElderMat3ColorBuf0": 0x8040c578,
		"NPC::sMareMB_ElderMat3ColorBuf1": 0x8040c580,
		"sMareMB_ElderMat3ColorBuf1": 0x8040c580,
		"NPC::@1584": 0x8040c588,
		"NPC::sMareMB_FishingRodMat1ColorBuf0": 0x8040c590,
		"sMareMB_FishingRodMat1ColorBuf0": 0x8040c590,
		"NPC::sMareMB_FishingRodMat1ColorBuf1": 0x8040c598,
		"sMareMB_FishingRodMat1ColorBuf1": 0x8040c598,
		"NPC::sMareMB_FishingRodMat2ColorBuf0": 0x8040c5a0,
		"sMareMB_FishingRodMat2ColorBuf0": 0x8040c5a0,
		"NPC::sMareMB_FishingRodMat2ColorBuf1": 0x8040c5a8,
		"sMareMB_FishingRodMat2ColorBuf1": 0x8040c5a8,
		"NPC::sMareMB_FishingRodMat3ColorBuf0": 0x8040c5b0,
		"sMareMB_FishingRodMat3ColorBuf0": 0x8040c5b0,
		"NPC::sMareMB_FishingRodMat3ColorBuf1": 0x8040c5b8,
		"sMareMB_FishingRodMat3ColorBuf1": 0x8040c5b8,
		"NPC::sMareMC_HatFColorBuf0": 0x8040c5c0,
		"sMareMC_HatFColorBuf0": 0x8040c5c0,
		"NPC::sMareMC_HatFColorBuf1": 0x8040c5c8,
		"sMareMC_HatFColorBuf1": 0x8040c5c8,
		"NPC::sMareMC_BeardColorBuf0": 0x8040c5d0,
		"sMareMC_BeardColorBuf0": 0x8040c5d0,
		"NPC::sMareMC_BeardColorBuf1": 0x8040c5d8,
		"sMareMC_BeardColorBuf1": 0x8040c5d8,
		"NPC::sMareMC_MustacheColorBuf0": 0x8040c5e0,
		"sMareMC_MustacheColorBuf0": 0x8040c5e0,
		"NPC::sMareMC_MustacheColorBuf1": 0x8040c5e8,
		"sMareMC_MustacheColorBuf1": 0x8040c5e8,
		"NPC::sMareMD_PipeColorBuf0": 0x8040c5f0,
		"sMareMD_PipeColorBuf0": 0x8040c5f0,
		"NPC::sMareMD_PipeColorBuf1": 0x8040c5f8,
		"sMareMD_PipeColorBuf1": 0x8040c5f8,
		"NPC::@1590": 0x8040c600,
		"NPC::sMareWB_BabyBodyColorBuf0": 0x8040c608,
		"sMareWB_BabyBodyColorBuf0": 0x8040c608,
		"NPC::@1598": 0x8040c610,
		"NPC::sMareWB_BabyHatColorBuf0": 0x8040c618,
		"sMareWB_BabyHatColorBuf0": 0x8040c618,
		"NPC::sMareWB_BabyHatColorBuf1": 0x8040c620,
		"sMareWB_BabyHatColorBuf1": 0x8040c620,
		"NPC::sMareWB_BabyBedColorBuf0": 0x8040c628,
		"sMareWB_BabyBedColorBuf0": 0x8040c628,
		"NPC::sMareWB_BabyBedColorBuf1": 0x8040c630,
		"sMareWB_BabyBedColorBuf1": 0x8040c630,
		"NPC::@1614": 0x8040c638,
		"@1614": 0x8040c638,
		"NPC::@1621": 0x8040c640,
		"TBaseNPC::sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x8040c650,
		"sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x8040c650,
		"NPC::@2532": 0x8040c658,
		"NPC::@2533": 0x8040c65c,
		"NPC::@2534": 0x8040c660,
		"NPC::@2754": 0x8040c678,
		"NPC::@2755": 0x8040c67c,
		"NPC::@2756": 0x8040c680,
		"NPC::@1832": 0x8040c688,
		"NPC::@1833": 0x8040c68c,
		"NPC::@3189": 0x8040c6a8,
		"NPC::@3190": 0x8040c6ac,
		"NPC::@3191": 0x8040c6b0,
		"NPC::@3387": 0x8040c6b8,
		"NPC::@3388": 0x8040c6bc,
		"NPC::@3467": 0x8040c6c8,
		"NPC::@3468": 0x8040c6cc,
		"NPC::@3776": 0x8040c6d0,
		"NPC::@1682": 0x8040c6d8,
		"NPC::@1683": 0x8040c6dc,
		"NPC::@1684": 0x8040c6e0,
		"NPC::@1685": 0x8040c6e4,
		"NPC::@1686": 0x8040c6e8,
		"NPC::@2611": 0x8040c700,
		"NPC::@2612": 0x8040c704,
		"NPC::@2613": 0x8040c708,
		"NPC::@2614": 0x8040c70c,
		"NPC::@2615": 0x8040c710,
		"NPC::@2695": 0x8040c714,
		"NPC::@2499": 0x8040c730,
		"NPC::@2500": 0x8040c734,
		"NPC::@2501": 0x8040c738,
		"NPC::@2319": 0x8040c778,
		"NPC::@2320": 0x8040c77c,
		"NPC::@2321": 0x8040c780,
		"NPC::@2322": 0x8040c784,
		"MSound::@1983": 0x80406548,
		"MSound::@1984": 0x8040654c,
		"MSound::@1985": 0x80406550,
		"MSound::@2263": 0x804065e0,
		"MSound::@2264": 0x804065e4,
		"MSound::@2265": 0x804065e8,
		"MSound::@2486": 0x804065f8,
		"MSound::@2543": 0x804065fc,
		"MSound::@2544": 0x80406600,
		"MSound::@2545": 0x80406604,
		"MSound::@2575": 0x80406608,
		"MSound::@2576": 0x8040660c,
		"MSound::@2577": 0x80406610,
		"MSound::@2818": 0x80406620,
		"MSound::@2819": 0x80406624,
		"MSound::@2820": 0x80406628,
		"MSound::@2821": 0x8040662c,
		"MSound::@2823": 0x80406630,
		"MSound::@2824": 0x80406634,
		"MSound::@2825": 0x80406638,
		"MSound::@2827": 0x8040663c,
		"MSound::@2828": 0x80406640,
		"MSound::@2829": 0x80406644,
		"MSound::@2830": 0x80406648,
		"MSound::@2831": 0x8040664c,
		"MSound::@2833": 0x80406650,
		"MSound::@2837": 0x80406654,
		"MSound::@2838": 0x80406658,
		"MSound::@2839": 0x8040665c,
		"MSound::@2840": 0x80406660,
		"MSound::@2842": 0x80406664,
		"MSound::@2843": 0x80406668,
		"MSound::@2845": 0x8040666c,
		"MSound::@2847": 0x80406670,
		"MSound::@2848": 0x80406674,
		"MSound::@2849": 0x80406678,
		"MSound::@2850": 0x8040667c,
		"MSound::@2859": 0x8040669c,
		"MSound::@2860": 0x804066a0,
		"MSound::@2874": 0x804066c4,
		"MSound::@2878": 0x804066c8,
		"MSound::@2884": 0x804066d8,
		"MSound::@2890": 0x804066e0,
		"MSound::@2895": 0x804066e8,
		"MSound::@2902": 0x804066f8,
		"MSound::@2907": 0x80406704,
		"MSound::@2909": 0x8040670c,
		"MSound::@2910": 0x80406710,
		"MSound::@2912": 0x80406714,
		"MSound::@2915": 0x8040671c,
		"MSound::@2919": 0x80406724,
		"MSound::@2920": 0x80406728,
		"MSound::@2923": 0x80406730,
		"MSound::@2924": 0x80406734,
		"MSound::@2925": 0x80406738,
		"MSound::@2927": 0x8040673c,
		"MSound::@2929": 0x80406744,
		"MSound::@2931": 0x8040674c,
		"MSound::@2933": 0x80406750,
		"MSound::@2935": 0x80406754,
		"MSound::@2937": 0x80406758,
		"MSound::@2939": 0x8040675c,
		"MSound::@1995": 0x80406788,
		"MSound::@1996": 0x8040678c,
		"MSound::@1997": 0x80406790,
		"MSound::@1998": 0x80406794,
		"MSound::@1999": 0x80406798,
		"MSound::@2000": 0x8040679c,
		"MSound::@2001": 0x804067a0,
		"MSound::@2020": 0x804067e4,
		"MSound::@2021": 0x804067e8,
		"MSound::@2022": 0x804067ec,
		"MSound::@2023": 0x804067f4,
		"MSound::@2025": 0x804067fc,
		"MSound::@2027": 0x80406800,
		"MSound::@2029": 0x80406804,
		"MSound::@2030": 0x80406808,
		"MSound::@2031": 0x8040680c,
		"MSound::@2036": 0x80406840,
		"MSound::@2080": 0x80406860,
		"MSound::@2039": 0x80406878,
		"MSound::@2040": 0x8040687c,
		"MSound::@2041": 0x80406880,
		"MoveBG::no_data_anim_info": 0x8040a2e0,
		"no_data_anim_info": 0x8040a2e0,
		"MoveBG::normal_sound_info": 0x8040a2e8,
		"normal_sound_info": 0x8040a2e8,
		"MoveBG::billboard_dolphin_anim_info": 0x8040a2f8,
		"billboard_dolphin_anim_info": 0x8040a2f8,
		"MoveBG::billboard_sun_anim_info": 0x8040a300,
		"billboard_sun_anim_info": 0x8040a300,
		"MoveBG::billboard_restaurant_anim_info": 0x8040a308,
		"billboard_restaurant_anim_info": 0x8040a308,
		"MoveBG::billboard_fish_anim_info": 0x8040a310,
		"billboard_fish_anim_info": 0x8040a310,
		"MoveBG::MonteChair_anim_info": 0x8040a320,
		"MonteChair_anim_info": 0x8040a320,
		"MoveBG::@2798": 0x8040a328,
		"MoveBG::doorHotel_anim_info": 0x8040a330,
		"doorHotel_anim_info": 0x8040a330,
		"MoveBG::@2802": 0x8040a338,
		"MoveBG::manhole_anim_info": 0x8040a340,
		"manhole_anim_info": 0x8040a340,
		"MoveBG::manhole_map_collision_info": 0x8040a348,
		"manhole_map_collision_info": 0x8040a348,
		"MoveBG::@2804": 0x8040a350,
		"MoveBG::FruitBasket_anim_info": 0x8040a358,
		"FruitBasket_anim_info": 0x8040a358,
		"MoveBG::@2805": 0x8040a360,
		"MoveBG::FruitBasket_map_collision_data": 0x8040a368,
		"FruitBasket_map_collision_data": 0x8040a368,
		"MoveBG::FruitBasket_map_collision_info": 0x8040a370,
		"FruitBasket_map_collision_info": 0x8040a370,
		"MoveBG::BasketReverse_anim_info": 0x8040a378,
		"BasketReverse_anim_info": 0x8040a378,
		"MoveBG::BasketReverse_map_collision_data": 0x8040a380,
		"BasketReverse_map_collision_data": 0x8040a380,
		"MoveBG::BasketReverse_map_collision_info": 0x8040a388,
		"BasketReverse_map_collision_info": 0x8040a388,
		"MoveBG::Pile_map_collision_data": 0x8040a398,
		"Pile_map_collision_data": 0x8040a398,
		"MoveBG::Pile_map_collision_info": 0x8040a3a0,
		"Pile_map_collision_info": 0x8040a3a0,
		"MoveBG::ChipShine_anim_info": 0x8040a3a8,
		"ChipShine_anim_info": 0x8040a3a8,
		"MoveBG::KoopaJrSignM_anim_info": 0x8040a3b0,
		"KoopaJrSignM_anim_info": 0x8040a3b0,
		"MoveBG::SignCircle_anim_info": 0x8040a3b8,
		"SignCircle_anim_info": 0x8040a3b8,
		"MoveBG::SignCross_anim_info": 0x8040a3c0,
		"SignCross_anim_info": 0x8040a3c0,
		"MoveBG::SignTriangle_anim_info": 0x8040a3c8,
		"SignTriangle_anim_info": 0x8040a3c8,
		"MoveBG::ObjSwitch_map_collision_data": 0x8040a3d0,
		"ObjSwitch_map_collision_data": 0x8040a3d0,
		"MoveBG::ObjSwitch_map_collision_info": 0x8040a3d8,
		"ObjSwitch_map_collision_info": 0x8040a3d8,
		"MoveBG::RedCoinSwitch_map_collision_data": 0x8040a3e0,
		"RedCoinSwitch_map_collision_data": 0x8040a3e0,
		"MoveBG::RedCoinSwitch_map_collision_info": 0x8040a3e8,
		"RedCoinSwitch_map_collision_info": 0x8040a3e8,
		"MoveBG::coin_sound_info": 0x8040a3f8,
		"coin_sound_info": 0x8040a3f8,
		"MoveBG::mario_cap_anim_info": 0x8040a410,
		"mario_cap_anim_info": 0x8040a410,
		"MoveBG::coin_anim_info": 0x8040a418,
		"coin_anim_info": 0x8040a418,
		"MoveBG::eggYoshi_anim_info": 0x8040a420,
		"eggYoshi_anim_info": 0x8040a420,
		"MoveBG::NozzleBox_anim_info": 0x8040a428,
		"NozzleBox_anim_info": 0x8040a428,
		"MoveBG::mushroom1up_anim_info": 0x8040a430,
		"mushroom1up_anim_info": 0x8040a430,
		"MoveBG::jumpbase_anim_info": 0x8040a438,
		"jumpbase_anim_info": 0x8040a438,
		"MoveBG::jumpbase_map_collision_data": 0x8040a440,
		"jumpbase_map_collision_data": 0x8040a440,
		"MoveBG::jumpbase_map_collision_info": 0x8040a448,
		"jumpbase_map_collision_info": 0x8040a448,
		"MoveBG::fruit_sound_info": 0x8040a450,
		"fruit_sound_info": 0x8040a450,
		"MoveBG::CoverPine_anim_info": 0x8040a458,
		"CoverPine_anim_info": 0x8040a458,
		"MoveBG::durian_sound_info": 0x8040a460,
		"durian_sound_info": 0x8040a460,
		"MoveBG::fence3x3_anim_info": 0x8040a468,
		"fence3x3_anim_info": 0x8040a468,
		"MoveBG::fence_revolve_outer_anim_info": 0x8040a470,
		"fence_revolve_outer_anim_info": 0x8040a470,
		"MoveBG::FenceWaterV_map_collision_data": 0x8040a478,
		"FenceWaterV_map_collision_data": 0x8040a478,
		"MoveBG::FenceWaterV_map_collision_info": 0x8040a480,
		"FenceWaterV_map_collision_info": 0x8040a480,
		"MoveBG::FenceWaterH_map_collision_info": 0x8040a488,
		"FenceWaterH_map_collision_info": 0x8040a488,
		"MoveBG::RailFence_anim_info": 0x8040a490,
		"RailFence_anim_info": 0x8040a490,
		"MoveBG::RailFence_map_collision_info": 0x8040a498,
		"RailFence_map_collision_info": 0x8040a498,
		"MoveBG::BambooRailFence_anim_info": 0x8040a4a0,
		"BambooRailFence_anim_info": 0x8040a4a0,
		"MoveBG::wood_barrel_anim_info": 0x8040a4a8,
		"wood_barrel_anim_info": 0x8040a4a8,
		"MoveBG::wood_barrel_map_collision_info": 0x8040a4b8,
		"wood_barrel_map_collision_info": 0x8040a4b8,
		"MoveBG::wood_barrel_sound_info": 0x8040a4c0,
		"wood_barrel_sound_info": 0x8040a4c0,
		"MoveBG::wood_barrel_sink_data": 0x8040a4c8,
		"wood_barrel_sink_data": 0x8040a4c8,
		"MoveBG::barrel_float_map_collision_data": 0x8040a4d0,
		"barrel_float_map_collision_data": 0x8040a4d0,
		"MoveBG::barrel_float_map_collision_info": 0x8040a4d8,
		"barrel_float_map_collision_info": 0x8040a4d8,
		"MoveBG::drum_can_anim_info": 0x8040a4e0,
		"drum_can_anim_info": 0x8040a4e0,
		"MoveBG::drum_can_map_collision_info": 0x8040a4e8,
		"drum_can_map_collision_info": 0x8040a4e8,
		"MoveBG::barrel_oil_anim_info": 0x8040a4f0,
		"barrel_oil_anim_info": 0x8040a4f0,
		"MoveBG::warp_block_map_collision_data": 0x8040a4f8,
		"warp_block_map_collision_data": 0x8040a4f8,
		"MoveBG::warp_block_map_collision_info": 0x8040a500,
		"warp_block_map_collision_info": 0x8040a500,
		"MoveBG::move_block_map_collision_data": 0x8040a508,
		"move_block_map_collision_data": 0x8040a508,
		"MoveBG::move_block_map_collision_info": 0x8040a510,
		"move_block_map_collision_info": 0x8040a510,
		"MoveBG::move_block_center_map_collision_data": 0x8040a518,
		"move_block_center_map_collision_data": 0x8040a518,
		"MoveBG::move_block_center_map_collision_info": 0x8040a520,
		"move_block_center_map_collision_info": 0x8040a520,
		"MoveBG::breakable_block_anim_info": 0x8040a528,
		"breakable_block_anim_info": 0x8040a528,
		"MoveBG::breakable_block_map_collision_data": 0x8040a530,
		"breakable_block_map_collision_data": 0x8040a530,
		"MoveBG::breakable_block_map_collision_info": 0x8040a538,
		"breakable_block_map_collision_info": 0x8040a538,
		"MoveBG::water_roll_block_anim_info": 0x8040a540,
		"water_roll_block_anim_info": 0x8040a540,
		"MoveBG::water_roll_block_map_collision_data": 0x8040a548,
		"water_roll_block_map_collision_data": 0x8040a548,
		"MoveBG::water_roll_block_map_collision_info": 0x8040a550,
		"water_roll_block_map_collision_info": 0x8040a550,
		"MoveBG::sand_block_anim_info": 0x8040a558,
		"sand_block_anim_info": 0x8040a558,
		"MoveBG::sand_block_map_collision_info": 0x8040a560,
		"sand_block_map_collision_info": 0x8040a560,
		"MoveBG::MoveCoin_anim_info": 0x8040a568,
		"MoveCoin_anim_info": 0x8040a568,
		"MoveBG::cluster_block_anim_info": 0x8040a570,
		"cluster_block_anim_info": 0x8040a570,
		"MoveBG::NormalBlock_map_collision_data": 0x8040a578,
		"NormalBlock_map_collision_data": 0x8040a578,
		"MoveBG::NormalBlock_map_collision_info": 0x8040a580,
		"NormalBlock_map_collision_info": 0x8040a580,
		"MoveBG::IceBlock_map_collision_data": 0x8040a588,
		"IceBlock_map_collision_data": 0x8040a588,
		"MoveBG::IceBlock_map_collision_info": 0x8040a590,
		"IceBlock_map_collision_info": 0x8040a590,
		"MoveBG::BrickBlock_anim_info": 0x8040a598,
		"BrickBlock_anim_info": 0x8040a598,
		"MoveBG::BrickBlock_map_collision_data": 0x8040a5a0,
		"BrickBlock_map_collision_data": 0x8040a5a0,
		"MoveBG::BrickBlock_map_collision_info": 0x8040a5a8,
		"BrickBlock_map_collision_info": 0x8040a5a8,
		"MoveBG::WaterMelonBlock_anim_info": 0x8040a5b0,
		"WaterMelonBlock_anim_info": 0x8040a5b0,
		"MoveBG::WaterMelonBlock_map_collision_data": 0x8040a5b8,
		"WaterMelonBlock_map_collision_data": 0x8040a5b8,
		"MoveBG::WaterMelonBlock_map_collision_info": 0x8040a5c0,
		"WaterMelonBlock_map_collision_info": 0x8040a5c0,
		"MoveBG::TelesaBlock_map_collision_data": 0x8040a5c8,
		"TelesaBlock_map_collision_data": 0x8040a5c8,
		"MoveBG::TelesaBlock_map_collision_info": 0x8040a5d0,
		"TelesaBlock_map_collision_info": 0x8040a5d0,
		"MoveBG::JuiceBlock_map_collision_data": 0x8040a5d8,
		"JuiceBlock_map_collision_data": 0x8040a5d8,
		"MoveBG::JuiceBlock_map_collision_info": 0x8040a5e0,
		"JuiceBlock_map_collision_info": 0x8040a5e0,
		"MoveBG::SuperHipDropBlock_anim_info": 0x8040a5e8,
		"SuperHipDropBlock_anim_info": 0x8040a5e8,
		"MoveBG::SuperHipDropBlock_map_collision_data": 0x8040a5f0,
		"SuperHipDropBlock_map_collision_data": 0x8040a5f0,
		"MoveBG::SuperHipDropBlock_map_collision_info": 0x8040a5f8,
		"SuperHipDropBlock_map_collision_info": 0x8040a5f8,
		"MoveBG::PalmNormal_anim_info": 0x8040a600,
		"PalmNormal_anim_info": 0x8040a600,
		"MoveBG::PalmNormalTree_map_collision_data": 0x8040a608,
		"PalmNormalTree_map_collision_data": 0x8040a608,
		"MoveBG::PalmNormalTree_map_collision_info": 0x8040a610,
		"PalmNormalTree_map_collision_info": 0x8040a610,
		"MoveBG::PalmOugiTree_map_collision_data": 0x8040a618,
		"PalmOugiTree_map_collision_data": 0x8040a618,
		"MoveBG::PalmOugiTree_map_collision_info": 0x8040a620,
		"PalmOugiTree_map_collision_info": 0x8040a620,
		"MoveBG::PalmSagoTree_map_collision_data": 0x8040a628,
		"PalmSagoTree_map_collision_data": 0x8040a628,
		"MoveBG::PalmSagoTree_map_collision_info": 0x8040a630,
		"PalmSagoTree_map_collision_info": 0x8040a630,
		"MoveBG::PalmNatumeTree_map_collision_data": 0x8040a638,
		"PalmNatumeTree_map_collision_data": 0x8040a638,
		"MoveBG::PalmNatumeTree_map_collision_info": 0x8040a640,
		"PalmNatumeTree_map_collision_info": 0x8040a640,
		"MoveBG::PalmLeaf_anim_info": 0x8040a648,
		"PalmLeaf_anim_info": 0x8040a648,
		"MoveBG::PalmLeafTree_map_collision_data": 0x8040a650,
		"PalmLeafTree_map_collision_data": 0x8040a650,
		"MoveBG::PalmLeafTree_map_collision_info": 0x8040a658,
		"PalmLeafTree_map_collision_info": 0x8040a658,
		"MoveBG::BananaTree_anim_info": 0x8040a660,
		"BananaTree_anim_info": 0x8040a660,
		"MoveBG::BananaTree_map_collision_data": 0x8040a668,
		"BananaTree_map_collision_data": 0x8040a668,
		"MoveBG::BananaTree_map_collision_info": 0x8040a670,
		"BananaTree_map_collision_info": 0x8040a670,
		"MoveBG::FruitTree_map_collision_data": 0x8040a678,
		"FruitTree_map_collision_data": 0x8040a678,
		"MoveBG::FruitTree_map_collision_info": 0x8040a680,
		"FruitTree_map_collision_info": 0x8040a680,
		"MoveBG::flowerOrange_anim_info": 0x8040a690,
		"flowerOrange_anim_info": 0x8040a690,
		"MoveBG::flowerPink_anim_info": 0x8040a698,
		"flowerPink_anim_info": 0x8040a698,
		"MoveBG::flowerPurple_anim_info": 0x8040a6a0,
		"flowerPurple_anim_info": 0x8040a6a0,
		"MoveBG::flowerRed_anim_info": 0x8040a6a8,
		"flowerRed_anim_info": 0x8040a6a8,
		"MoveBG::flowerYellow_anim_info": 0x8040a6b0,
		"flowerYellow_anim_info": 0x8040a6b0,
		"MoveBG::flowerSunflower_anim_info": 0x8040a6b8,
		"flowerSunflower_anim_info": 0x8040a6b8,
		"MoveBG::pole_sound_info": 0x8040a6c0,
		"pole_sound_info": 0x8040a6c0,
		"MoveBG::dptlight_anim_info": 0x8040a6c8,
		"dptlight_anim_info": 0x8040a6c8,
		"MoveBG::streetlamp_map_collision_info": 0x8040a6d0,
		"streetlamp_map_collision_info": 0x8040a6d0,
		"MoveBG::football_anim_info": 0x8040a6d8,
		"football_anim_info": 0x8040a6d8,
		"MoveBG::football_sound_info": 0x8040a6e0,
		"football_sound_info": 0x8040a6e0,
		"MoveBG::football_goal_anim_info": 0x8040a6e8,
		"football_goal_anim_info": 0x8040a6e8,
		"MoveBG::football_goal_map_collision_info": 0x8040a6f0,
		"football_goal_map_collision_info": 0x8040a6f0,
		"MoveBG::Watermelon_anim_info": 0x8040a6f8,
		"Watermelon_anim_info": 0x8040a6f8,
		"MoveBG::watermelon_sound_info": 0x8040a700,
		"watermelon_sound_info": 0x8040a700,
		"MoveBG::WatermelonStatic_anim_info": 0x8040a708,
		"WatermelonStatic_anim_info": 0x8040a708,
		"MoveBG::cloud_anim_info": 0x8040a710,
		"cloud_anim_info": 0x8040a710,
		"MoveBG::cloud_map_collision_data": 0x8040a720,
		"cloud_map_collision_data": 0x8040a720,
		"MoveBG::cloud_map_collision_info": 0x8040a728,
		"cloud_map_collision_info": 0x8040a728,
		"MoveBG::normallift_anim_info": 0x8040a730,
		"normallift_anim_info": 0x8040a730,
		"MoveBG::normallift_map_collision_data": 0x8040a738,
		"normallift_map_collision_data": 0x8040a738,
		"MoveBG::normallift_map_collision_info": 0x8040a740,
		"normallift_map_collision_info": 0x8040a740,
		"MoveBG::exrollcube_anim_info": 0x8040a748,
		"exrollcube_anim_info": 0x8040a748,
		"MoveBG::exrollcube_map_collision_data": 0x8040a750,
		"exrollcube_map_collision_data": 0x8040a750,
		"MoveBG::exrollcube_map_collision_info": 0x8040a758,
		"exrollcube_map_collision_info": 0x8040a758,
		"MoveBG::exkickboard_anim_info": 0x8040a760,
		"exkickboard_anim_info": 0x8040a760,
		"MoveBG::exkickboard_map_collision_data": 0x8040a768,
		"exkickboard_map_collision_data": 0x8040a768,
		"MoveBG::exkickboard_map_collision_info": 0x8040a770,
		"exkickboard_map_collision_info": 0x8040a770,
		"MoveBG::railblockr_anim_info": 0x8040a778,
		"railblockr_anim_info": 0x8040a778,
		"MoveBG::railblocky_anim_info": 0x8040a780,
		"railblocky_anim_info": 0x8040a780,
		"MoveBG::railblockb_anim_info": 0x8040a788,
		"railblockb_anim_info": 0x8040a788,
		"MoveBG::railblock_map_collision_data": 0x8040a790,
		"railblock_map_collision_data": 0x8040a790,
		"MoveBG::railblock_map_collision_info": 0x8040a798,
		"railblock_map_collision_info": 0x8040a798,
		"MoveBG::umaibou_anim_info": 0x8040a7a0,
		"umaibou_anim_info": 0x8040a7a0,
		"MoveBG::umaibou_map_collision_data": 0x8040a7b0,
		"umaibou_map_collision_data": 0x8040a7b0,
		"MoveBG::umaibou_map_collision_info": 0x8040a7b8,
		"umaibou_map_collision_info": 0x8040a7b8,
		"MoveBG::kamaboko_anim_info": 0x8040a7c0,
		"kamaboko_anim_info": 0x8040a7c0,
		"MoveBG::kamaboko_map_collision_data": 0x8040a7c8,
		"kamaboko_map_collision_data": 0x8040a7c8,
		"MoveBG::kamaboko_map_collision_info": 0x8040a7d0,
		"kamaboko_map_collision_info": 0x8040a7d0,
		"MoveBG::getag_anim_info": 0x8040a7d8,
		"getag_anim_info": 0x8040a7d8,
		"MoveBG::getao_anim_info": 0x8040a7e0,
		"getao_anim_info": 0x8040a7e0,
		"MoveBG::geta_map_collision_data": 0x8040a7f0,
		"geta_map_collision_data": 0x8040a7f0,
		"MoveBG::geta_map_collision_info": 0x8040a7f8,
		"geta_map_collision_info": 0x8040a7f8,
		"MoveBG::uirou_anim_info": 0x8040a810,
		"uirou_anim_info": 0x8040a810,
		"MoveBG::uirou_map_collision_data": 0x8040a820,
		"uirou_map_collision_data": 0x8040a820,
		"MoveBG::uirou_map_collision_info": 0x8040a828,
		"uirou_map_collision_info": 0x8040a828,
		"MoveBG::hikidashi_anim_info": 0x8040a830,
		"hikidashi_anim_info": 0x8040a830,
		"MoveBG::hikidashi_map_collision_data": 0x8040a838,
		"hikidashi_map_collision_data": 0x8040a838,
		"MoveBG::hikidashi_map_collision_info": 0x8040a840,
		"hikidashi_map_collision_info": 0x8040a840,
		"MoveBG::castella_anim_info": 0x8040a848,
		"castella_anim_info": 0x8040a848,
		"MoveBG::castella_map_collision_data": 0x8040a850,
		"castella_map_collision_data": 0x8040a850,
		"MoveBG::castella_map_collision_info": 0x8040a858,
		"castella_map_collision_info": 0x8040a858,
		"MoveBG::yoshiblock_anim_info": 0x8040a860,
		"yoshiblock_anim_info": 0x8040a860,
		"MoveBG::yoshiblock_map_collision_data": 0x8040a868,
		"yoshiblock_map_collision_data": 0x8040a868,
		"MoveBG::yoshiblock_map_collision_info": 0x8040a870,
		"yoshiblock_map_collision_info": 0x8040a870,
		"MoveBG::WoodBlockTriangle_map_collision_data": 0x8040a878,
		"WoodBlockTriangle_map_collision_data": 0x8040a878,
		"MoveBG::WoodBlockTriangle_map_collision_info": 0x8040a880,
		"WoodBlockTriangle_map_collision_info": 0x8040a880,
		"MoveBG::WoodBlockPyramid_map_collision_data": 0x8040a888,
		"WoodBlockPyramid_map_collision_data": 0x8040a888,
		"MoveBG::WoodBlockPyramid_map_collision_info": 0x8040a890,
		"WoodBlockPyramid_map_collision_info": 0x8040a890,
		"MoveBG::WoodBlockLong_map_collision_data": 0x8040a898,
		"WoodBlockLong_map_collision_data": 0x8040a898,
		"MoveBG::WoodBlockLong_map_collision_info": 0x8040a8a0,
		"WoodBlockLong_map_collision_info": 0x8040a8a0,
		"MoveBG::WoodBlockLarge_map_collision_data": 0x8040a8a8,
		"WoodBlockLarge_map_collision_data": 0x8040a8a8,
		"MoveBG::WoodBlockLarge_map_collision_info": 0x8040a8b0,
		"WoodBlockLarge_map_collision_info": 0x8040a8b0,
		"MoveBG::WoodBlockCone_map_collision_data": 0x8040a8b8,
		"WoodBlockCone_map_collision_data": 0x8040a8b8,
		"MoveBG::WoodBlockCone_map_collision_info": 0x8040a8c0,
		"WoodBlockCone_map_collision_info": 0x8040a8c0,
		"MoveBG::WoodBlockL_map_collision_data": 0x8040a8c8,
		"WoodBlockL_map_collision_data": 0x8040a8c8,
		"MoveBG::WoodBlockL_map_collision_info": 0x8040a8d0,
		"WoodBlockL_map_collision_info": 0x8040a8d0,
		"MoveBG::WoodBlockBridge_map_collision_data": 0x8040a8d8,
		"WoodBlockBridge_map_collision_data": 0x8040a8d8,
		"MoveBG::WoodBlockBridge_map_collision_info": 0x8040a8e0,
		"WoodBlockBridge_map_collision_info": 0x8040a8e0,
		"MoveBG::WoodBlockCube_map_collision_data": 0x8040a8e8,
		"WoodBlockCube_map_collision_data": 0x8040a8e8,
		"MoveBG::WoodBlockCube_map_collision_info": 0x8040a8f0,
		"WoodBlockCube_map_collision_info": 0x8040a8f0,
		"MoveBG::normalvariant0_map_collision_data": 0x8040a8f8,
		"normalvariant0_map_collision_data": 0x8040a8f8,
		"MoveBG::normalvariant0_map_collision_info": 0x8040a900,
		"normalvariant0_map_collision_info": 0x8040a900,
		"MoveBG::normalvariant1_map_collision_data": 0x8040a908,
		"normalvariant1_map_collision_data": 0x8040a908,
		"MoveBG::normalvariant1_map_collision_info": 0x8040a910,
		"normalvariant1_map_collision_info": 0x8040a910,
		"MoveBG::normalvariant2_map_collision_data": 0x8040a918,
		"normalvariant2_map_collision_data": 0x8040a918,
		"MoveBG::normalvariant2_map_collision_info": 0x8040a920,
		"normalvariant2_map_collision_info": 0x8040a920,
		"MoveBG::normalvariant3_map_collision_data": 0x8040a928,
		"normalvariant3_map_collision_data": 0x8040a928,
		"MoveBG::normalvariant3_map_collision_info": 0x8040a930,
		"normalvariant3_map_collision_info": 0x8040a930,
		"MoveBG::normalvariant4_map_collision_data": 0x8040a938,
		"normalvariant4_map_collision_data": 0x8040a938,
		"MoveBG::normalvariant4_map_collision_info": 0x8040a940,
		"normalvariant4_map_collision_info": 0x8040a940,
		"MoveBG::railvariant0_map_collision_data": 0x8040a948,
		"railvariant0_map_collision_data": 0x8040a948,
		"MoveBG::railvariant0_map_collision_info": 0x8040a950,
		"railvariant0_map_collision_info": 0x8040a950,
		"MoveBG::railvariant1_map_collision_data": 0x8040a958,
		"railvariant1_map_collision_data": 0x8040a958,
		"MoveBG::railvariant1_map_collision_info": 0x8040a960,
		"railvariant1_map_collision_info": 0x8040a960,
		"MoveBG::railvariant2_map_collision_data": 0x8040a968,
		"railvariant2_map_collision_data": 0x8040a968,
		"MoveBG::railvariant2_map_collision_info": 0x8040a970,
		"railvariant2_map_collision_info": 0x8040a970,
		"MoveBG::railvariant3_map_collision_data": 0x8040a978,
		"railvariant3_map_collision_data": 0x8040a978,
		"MoveBG::railvariant3_map_collision_info": 0x8040a980,
		"railvariant3_map_collision_info": 0x8040a980,
		"MoveBG::railvariant4_map_collision_data": 0x8040a988,
		"railvariant4_map_collision_data": 0x8040a988,
		"MoveBG::railvariant4_map_collision_info": 0x8040a990,
		"railvariant4_map_collision_info": 0x8040a990,
		"MoveBG::rollvariant0_map_collision_data": 0x8040a998,
		"rollvariant0_map_collision_data": 0x8040a998,
		"MoveBG::rollvariant0_map_collision_info": 0x8040a9a0,
		"rollvariant0_map_collision_info": 0x8040a9a0,
		"MoveBG::rollvariant1_map_collision_data": 0x8040a9a8,
		"rollvariant1_map_collision_data": 0x8040a9a8,
		"MoveBG::rollvariant1_map_collision_info": 0x8040a9b0,
		"rollvariant1_map_collision_info": 0x8040a9b0,
		"MoveBG::rollvariant2_map_collision_data": 0x8040a9b8,
		"rollvariant2_map_collision_data": 0x8040a9b8,
		"MoveBG::rollvariant2_map_collision_info": 0x8040a9c0,
		"rollvariant2_map_collision_info": 0x8040a9c0,
		"MoveBG::rollvariant3_map_collision_data": 0x8040a9c8,
		"rollvariant3_map_collision_data": 0x8040a9c8,
		"MoveBG::rollvariant3_map_collision_info": 0x8040a9d0,
		"rollvariant3_map_collision_info": 0x8040a9d0,
		"MoveBG::rollvariant4_map_collision_data": 0x8040a9d8,
		"rollvariant4_map_collision_data": 0x8040a9d8,
		"MoveBG::rollvariant4_map_collision_info": 0x8040a9e0,
		"rollvariant4_map_collision_info": 0x8040a9e0,
		"MoveBG::lamptrapspike_anim_info": 0x8040a9e8,
		"lamptrapspike_anim_info": 0x8040a9e8,
		"MoveBG::lamptrapiron_anim_info": 0x8040a9f0,
		"lamptrapiron_anim_info": 0x8040a9f0,
		"MoveBG::lamptrap_map_collision_data": 0x8040a9f8,
		"lamptrap_map_collision_data": 0x8040a9f8,
		"MoveBG::lamptrap_map_collision_info": 0x8040aa00,
		"lamptrap_map_collision_info": 0x8040aa00,
		"MoveBG::airplane_map_collision_data": 0x8040aa08,
		"airplane_map_collision_data": 0x8040aa08,
		"MoveBG::airplane_map_collision_info": 0x8040aa10,
		"airplane_map_collision_info": 0x8040aa10,
		"MoveBG::WoodBox_anim_info": 0x8040aa18,
		"WoodBox_anim_info": 0x8040aa18,
		"MoveBG::WoodBoxNozzle_map_collision_data": 0x8040aa28,
		"WoodBoxNozzle_map_collision_data": 0x8040aa28,
		"MoveBG::WoodBoxNozzle_map_collision_info": 0x8040aa30,
		"WoodBoxNozzle_map_collision_info": 0x8040aa30,
		"MoveBG::ice_car_anim_info": 0x8040aa40,
		"ice_car_anim_info": 0x8040aa40,
		"MoveBG::ice_car_map_collision_data": 0x8040aa50,
		"ice_car_map_collision_data": 0x8040aa50,
		"MoveBG::ice_car_map_collision_info": 0x8040aa58,
		"ice_car_map_collision_info": 0x8040aa58,
		"MoveBG::move_ice_car_map_collision_data": 0x8040aa68,
		"move_ice_car_map_collision_data": 0x8040aa68,
		"MoveBG::move_ice_car_map_collision_info": 0x8040aa70,
		"move_ice_car_map_collision_info": 0x8040aa70,
		"MoveBG::@3098": 0x8040aa78,
		"MoveBG::AirportBuoy_map_collision_data": 0x8040aa80,
		"AirportBuoy_map_collision_data": 0x8040aa80,
		"MoveBG::AirportBuoy_map_collision_info": 0x8040aa88,
		"AirportBuoy_map_collision_info": 0x8040aa88,
		"MoveBG::dptKing_map_collision_info": 0x8040aa98,
		"dptKing_map_collision_info": 0x8040aa98,
		"MoveBG::KoopaJrSubmarine_map_collision_data": 0x8040aaa0,
		"KoopaJrSubmarine_map_collision_data": 0x8040aaa0,
		"MoveBG::KoopaJrSubmarine_map_collision_info": 0x8040aaa8,
		"KoopaJrSubmarine_map_collision_info": 0x8040aaa8,
		"MoveBG::monumentshine_anim_info": 0x8040aab0,
		"monumentshine_anim_info": 0x8040aab0,
		"MoveBG::belldolpic_anim_info": 0x8040aab8,
		"belldolpic_anim_info": 0x8040aab8,
		"MoveBG::DptWeathercock_anim_info": 0x8040aac0,
		"DptWeathercock_anim_info": 0x8040aac0,
		"MoveBG::DptMonteFence_map_collision_data": 0x8040aac8,
		"DptMonteFence_map_collision_data": 0x8040aac8,
		"MoveBG::DptMonteFence_map_collision_info": 0x8040aad0,
		"DptMonteFence_map_collision_info": 0x8040aad0,
		"MoveBG::DptCoronaFence_map_collision_data": 0x8040aad8,
		"DptCoronaFence_map_collision_data": 0x8040aad8,
		"MoveBG::DptCoronaFence_map_collision_info": 0x8040aae0,
		"DptCoronaFence_map_collision_info": 0x8040aae0,
		"MoveBG::MareGate_anim_info": 0x8040aae8,
		"MareGate_anim_info": 0x8040aae8,
		"MoveBG::NozzleDoor_anim_info": 0x8040aaf0,
		"NozzleDoor_anim_info": 0x8040aaf0,
		"MoveBG::NozzleDoor_map_collision_data": 0x8040aaf8,
		"NozzleDoor_map_collision_data": 0x8040aaf8,
		"MoveBG::NozzleDoor_map_collision_info": 0x8040ab00,
		"NozzleDoor_map_collision_info": 0x8040ab00,
		"MoveBG::DokanGate_anim_info": 0x8040ab08,
		"DokanGate_anim_info": 0x8040ab08,
		"MoveBG::@3121": 0x8040ab10,
		"MoveBG::crane_map_collision_data": 0x8040ab18,
		"crane_map_collision_data": 0x8040ab18,
		"MoveBG::crane_map_collision_info": 0x8040ab20,
		"crane_map_collision_info": 0x8040ab20,
		"MoveBG::crane90Scene2_map_collision_data": 0x8040ab28,
		"crane90Scene2_map_collision_data": 0x8040ab28,
		"MoveBG::crane90Scene2_map_collision_info": 0x8040ab30,
		"crane90Scene2_map_collision_info": 0x8040ab30,
		"MoveBG::crane180Scene1_map_collision_data": 0x8040ab38,
		"crane180Scene1_map_collision_data": 0x8040ab38,
		"MoveBG::crane180Scene1_map_collision_info": 0x8040ab40,
		"crane180Scene1_map_collision_info": 0x8040ab40,
		"MoveBG::crane_updown_map_collision_data": 0x8040ab48,
		"crane_updown_map_collision_data": 0x8040ab48,
		"MoveBG::crane_updown_map_collision_info": 0x8040ab50,
		"crane_updown_map_collision_info": 0x8040ab50,
		"MoveBG::crane_cargo_map_collision_data": 0x8040ab58,
		"crane_cargo_map_collision_data": 0x8040ab58,
		"MoveBG::crane_cargo_map_collision_info": 0x8040ab60,
		"crane_cargo_map_collision_info": 0x8040ab60,
		"MoveBG::tank_map_collision_data": 0x8040ab70,
		"tank_map_collision_data": 0x8040ab70,
		"MoveBG::tank_map_collision_info": 0x8040ab78,
		"tank_map_collision_info": 0x8040ab78,
		"MoveBG::container_map_collision_data": 0x8040ab80,
		"container_map_collision_data": 0x8040ab80,
		"MoveBG::container_map_collision_info": 0x8040ab88,
		"container_map_collision_info": 0x8040ab88,
		"MoveBG::submarine_map_collision_info": 0x8040ab90,
		"submarine_map_collision_info": 0x8040ab90,
		"MoveBG::riccoShip_map_collision_data": 0x8040ab98,
		"riccoShip_map_collision_data": 0x8040ab98,
		"MoveBG::riccoShip_map_collision_info": 0x8040aba0,
		"riccoShip_map_collision_info": 0x8040aba0,
		"MoveBG::riccoLog_map_collision_data": 0x8040aba8,
		"riccoLog_map_collision_data": 0x8040aba8,
		"MoveBG::riccoLog_map_collision_info": 0x8040abb0,
		"riccoLog_map_collision_info": 0x8040abb0,
		"MoveBG::gesoSurfboard_anim_info": 0x8040abb8,
		"gesoSurfboard_anim_info": 0x8040abb8,
		"MoveBG::riccoShipLog_map_collision_data": 0x8040abc0,
		"riccoShipLog_map_collision_data": 0x8040abc0,
		"MoveBG::riccoShipLog_map_collision_info": 0x8040abc8,
		"riccoShipLog_map_collision_info": 0x8040abc8,
		"MoveBG::riccoShipDol_map_collision_data": 0x8040abd0,
		"riccoShipDol_map_collision_data": 0x8040abd0,
		"MoveBG::riccoShipDol_map_collision_info": 0x8040abd8,
		"riccoShipDol_map_collision_info": 0x8040abd8,
		"MoveBG::riccoYachtL_map_collision_data": 0x8040abe0,
		"riccoYachtL_map_collision_data": 0x8040abe0,
		"MoveBG::riccoYachtL_map_collision_info": 0x8040abe8,
		"riccoYachtL_map_collision_info": 0x8040abe8,
		"MoveBG::riccoYachtS_map_collision_data": 0x8040abf0,
		"riccoYachtS_map_collision_data": 0x8040abf0,
		"MoveBG::riccoYachtS_map_collision_info": 0x8040abf8,
		"riccoYachtS_map_collision_info": 0x8040abf8,
		"MoveBG::riccoBoatL_map_collision_data": 0x8040ac00,
		"riccoBoatL_map_collision_data": 0x8040ac00,
		"MoveBG::riccoBoatL_map_collision_info": 0x8040ac08,
		"riccoBoatL_map_collision_info": 0x8040ac08,
		"MoveBG::riccoBoatS_map_collision_data": 0x8040ac10,
		"riccoBoatS_map_collision_data": 0x8040ac10,
		"MoveBG::riccoBoatS_map_collision_info": 0x8040ac18,
		"riccoBoatS_map_collision_info": 0x8040ac18,
		"MoveBG::riccoBasket_map_collision_data": 0x8040ac20,
		"riccoBasket_map_collision_data": 0x8040ac20,
		"MoveBG::riccoBasket_map_collision_info": 0x8040ac28,
		"riccoBasket_map_collision_info": 0x8040ac28,
		"MoveBG::riccoGangway_map_collision_data": 0x8040ac30,
		"riccoGangway_map_collision_data": 0x8040ac30,
		"MoveBG::riccoGangway_map_collision_info": 0x8040ac38,
		"riccoGangway_map_collision_info": 0x8040ac38,
		"MoveBG::riccoShipFish_map_collision_data": 0x8040ac40,
		"riccoShipFish_map_collision_data": 0x8040ac40,
		"MoveBG::riccoShipFish_map_collision_info": 0x8040ac48,
		"riccoShipFish_map_collision_info": 0x8040ac48,
		"MoveBG::riccoShipGeso_map_collision_data": 0x8040ac50,
		"riccoShipGeso_map_collision_data": 0x8040ac50,
		"MoveBG::riccoShipGeso_map_collision_info": 0x8040ac58,
		"riccoShipGeso_map_collision_info": 0x8040ac58,
		"MoveBG::riccoSwitch_map_collision_data": 0x8040ac60,
		"riccoSwitch_map_collision_data": 0x8040ac60,
		"MoveBG::riccoSwitch_map_collision_info": 0x8040ac68,
		"riccoSwitch_map_collision_info": 0x8040ac68,
		"MoveBG::riccoFenceMaze_map_collision_data": 0x8040ac70,
		"riccoFenceMaze_map_collision_data": 0x8040ac70,
		"MoveBG::riccoFenceMaze_map_collision_info": 0x8040ac78,
		"riccoFenceMaze_map_collision_info": 0x8040ac78,
		"MoveBG::riccoStand_map_collision_data": 0x8040ac80,
		"riccoStand_map_collision_data": 0x8040ac80,
		"MoveBG::riccoStand_map_collision_info": 0x8040ac88,
		"riccoStand_map_collision_info": 0x8040ac88,
		"MoveBG::riccoGrille_map_collision_data": 0x8040ac90,
		"riccoGrille_map_collision_data": 0x8040ac90,
		"MoveBG::riccoGrille_map_collision_info": 0x8040ac98,
		"riccoGrille_map_collision_info": 0x8040ac98,
		"MoveBG::riccoArrow_map_collision_data": 0x8040aca0,
		"riccoArrow_map_collision_data": 0x8040aca0,
		"MoveBG::riccoArrow_map_collision_info": 0x8040aca8,
		"riccoArrow_map_collision_info": 0x8040aca8,
		"MoveBG::riccoStreetStall_map_collision_data": 0x8040acb0,
		"riccoStreetStall_map_collision_data": 0x8040acb0,
		"MoveBG::riccoStreetStall_map_collision_info": 0x8040acb8,
		"riccoStreetStall_map_collision_info": 0x8040acb8,
		"MoveBG::riccoHericopter_map_collision_data": 0x8040acc0,
		"riccoHericopter_map_collision_data": 0x8040acc0,
		"MoveBG::riccoHericopter_map_collision_info": 0x8040acc8,
		"riccoHericopter_map_collision_info": 0x8040acc8,
		"MoveBG::windmill_anim_info": 0x8040acd0,
		"windmill_anim_info": 0x8040acd0,
		"MoveBG::windmill_map_collision_data": 0x8040acd8,
		"windmill_map_collision_data": 0x8040acd8,
		"MoveBG::windmill_map_collision_info": 0x8040ace0,
		"windmill_map_collision_info": 0x8040ace0,
		"MoveBG::MiniWindmillL_map_collision_data": 0x8040ace8,
		"MiniWindmillL_map_collision_data": 0x8040ace8,
		"MoveBG::MiniWindmillL_map_collision_info": 0x8040acf0,
		"MiniWindmillL_map_collision_info": 0x8040acf0,
		"MoveBG::MiniWindmillS_map_collision_data": 0x8040acf8,
		"MiniWindmillS_map_collision_data": 0x8040acf8,
		"MoveBG::MiniWindmillS_map_collision_info": 0x8040ad00,
		"MiniWindmillS_map_collision_info": 0x8040ad00,
		"MoveBG::windmill_roof_map_collision_data": 0x8040ad08,
		"windmill_roof_map_collision_data": 0x8040ad08,
		"MoveBG::windmill_roof_map_collision_info": 0x8040ad10,
		"windmill_roof_map_collision_info": 0x8040ad10,
		"MoveBG::lamp_bianco_anim_info": 0x8040ad18,
		"lamp_bianco_anim_info": 0x8040ad18,
		"MoveBG::lamp_bianco_map_collision_info": 0x8040ad20,
		"lamp_bianco_map_collision_info": 0x8040ad20,
		"MoveBG::RootPakkun_map_collision_data": 0x8040ad28,
		"RootPakkun_map_collision_data": 0x8040ad28,
		"MoveBG::RootPakkun_map_collision_info": 0x8040ad30,
		"RootPakkun_map_collision_info": 0x8040ad30,
		"MoveBG::windmill_block_map_collision_data": 0x8040ad38,
		"windmill_block_map_collision_data": 0x8040ad38,
		"MoveBG::windmill_block_map_collision_info": 0x8040ad40,
		"windmill_block_map_collision_info": 0x8040ad40,
		"MoveBG::BiaBell_anim_info": 0x8040ad48,
		"BiaBell_anim_info": 0x8040ad48,
		"MoveBG::watermill00_anim_info": 0x8040ad58,
		"watermill00_anim_info": 0x8040ad58,
		"MoveBG::BiaWatermill01_map_collision_data": 0x8040ad60,
		"BiaWatermill01_map_collision_data": 0x8040ad60,
		"MoveBG::BiaWatermill01_map_collision_info": 0x8040ad68,
		"BiaWatermill01_map_collision_info": 0x8040ad68,
		"MoveBG::BiaWatermillVertical_map_collision_data": 0x8040ad70,
		"BiaWatermillVertical_map_collision_data": 0x8040ad70,
		"MoveBG::BiaWatermillVertical_map_collision_info": 0x8040ad78,
		"BiaWatermillVertical_map_collision_info": 0x8040ad78,
		"MoveBG::BiaTurnBridge_map_collision_data": 0x8040ad80,
		"BiaTurnBridge_map_collision_data": 0x8040ad80,
		"MoveBG::BiaTurnBridge_map_collision_info": 0x8040ad88,
		"BiaTurnBridge_map_collision_info": 0x8040ad88,
		"MoveBG::LeafBoat_map_collision_data": 0x8040ad90,
		"LeafBoat_map_collision_data": 0x8040ad90,
		"MoveBG::LeafBoat_map_collision_info": 0x8040ad98,
		"LeafBoat_map_collision_info": 0x8040ad98,
		"MoveBG::LampSeesaw_anim_info": 0x8040ada0,
		"LampSeesaw_anim_info": 0x8040ada0,
		"MoveBG::LampSeesaw_map_collision_data": 0x8040ada8,
		"LampSeesaw_map_collision_data": 0x8040ada8,
		"MoveBG::LampSeesaw_map_collision_info": 0x8040adb0,
		"LampSeesaw_map_collision_info": 0x8040adb0,
		"MoveBG::BiancoDoor_map_collision_data": 0x8040adc0,
		"BiancoDoor_map_collision_data": 0x8040adc0,
		"MoveBG::BiancoDoor_map_collision_info": 0x8040adc8,
		"BiancoDoor_map_collision_info": 0x8040adc8,
		"MoveBG::BiaBridge_map_collision_data": 0x8040add0,
		"BiaBridge_map_collision_data": 0x8040add0,
		"MoveBG::BiaBridge_map_collision_info": 0x8040add8,
		"BiaBridge_map_collision_info": 0x8040add8,
		"MoveBG::SandBird_anim_info": 0x8040ade0,
		"SandBird_anim_info": 0x8040ade0,
		"MoveBG::SandBirdBlock_map_collision_info": 0x8040ade8,
		"SandBirdBlock_map_collision_info": 0x8040ade8,
		"MoveBG::SkyIsland_anim_info": 0x8040adf0,
		"SkyIsland_anim_info": 0x8040adf0,
		"MoveBG::SkyIsland_map_collision_data": 0x8040adf8,
		"SkyIsland_map_collision_data": 0x8040adf8,
		"MoveBG::SkyIsland_map_collision_info": 0x8040ae00,
		"SkyIsland_map_collision_info": 0x8040ae00,
		"MoveBG::SandLeaf_anim_info": 0x8040ae08,
		"SandLeaf_anim_info": 0x8040ae08,
		"MoveBG::SandLeafBase00_anim_info": 0x8040ae10,
		"SandLeafBase00_anim_info": 0x8040ae10,
		"MoveBG::SandLeafBase00_map_collision_info": 0x8040ae18,
		"SandLeafBase00_map_collision_info": 0x8040ae18,
		"MoveBG::SandLeafBase01_anim_info": 0x8040ae20,
		"SandLeafBase01_anim_info": 0x8040ae20,
		"MoveBG::SandLeafBase01_map_collision_info": 0x8040ae28,
		"SandLeafBase01_map_collision_info": 0x8040ae28,
		"MoveBG::SandLeafBase02_anim_info": 0x8040ae30,
		"SandLeafBase02_anim_info": 0x8040ae30,
		"MoveBG::SandLeafBase02_map_collision_info": 0x8040ae38,
		"SandLeafBase02_map_collision_info": 0x8040ae38,
		"MoveBG::SandLeafBase03_anim_info": 0x8040ae40,
		"SandLeafBase03_anim_info": 0x8040ae40,
		"MoveBG::SandLeafBase03_map_collision_info": 0x8040ae48,
		"SandLeafBase03_map_collision_info": 0x8040ae48,
		"MoveBG::SandBomb_anim_info": 0x8040ae50,
		"SandBomb_anim_info": 0x8040ae50,
		"MoveBG::mirror_L_map_collision_info": 0x8040ae60,
		"mirror_L_map_collision_info": 0x8040ae60,
		"MoveBG::mirror_M_map_collision_info": 0x8040ae70,
		"mirror_M_map_collision_info": 0x8040ae70,
		"MoveBG::mirrorS_map_collision_info": 0x8040ae80,
		"mirrorS_map_collision_info": 0x8040ae80,
		"MoveBG::SandCastle_anim_info": 0x8040ae88,
		"SandCastle_anim_info": 0x8040ae88,
		"MoveBG::SandCastle_map_collision_info": 0x8040ae90,
		"SandCastle_map_collision_info": 0x8040ae90,
		"MoveBG::MammaBlockRotate_map_collision_info": 0x8040ae98,
		"MammaBlockRotate_map_collision_info": 0x8040ae98,
		"MoveBG::SandEgg_map_collision_data": 0x8040aea0,
		"SandEgg_map_collision_data": 0x8040aea0,
		"MoveBG::SandEgg_map_collision_info": 0x8040aea8,
		"SandEgg_map_collision_info": 0x8040aea8,
		"MoveBG::SandEggBroken_map_collision_data": 0x8040aeb0,
		"SandEggBroken_map_collision_data": 0x8040aeb0,
		"MoveBG::SandEggBroken_map_collision_info": 0x8040aeb8,
		"SandEggBroken_map_collision_info": 0x8040aeb8,
		"MoveBG::MammaSurfboardStand_map_collision_data": 0x8040aec0,
		"MammaSurfboardStand_map_collision_data": 0x8040aec0,
		"MoveBG::MammaSurfboardStand_map_collision_info": 0x8040aec8,
		"MammaSurfboardStand_map_collision_info": 0x8040aec8,
		"MoveBG::MammaYacht00_map_collision_data": 0x8040aed0,
		"MammaYacht00_map_collision_data": 0x8040aed0,
		"MoveBG::MammaYacht00_map_collision_info": 0x8040aed8,
		"MammaYacht00_map_collision_info": 0x8040aed8,
		"MoveBG::MammaYacht01_map_collision_data": 0x8040aee0,
		"MammaYacht01_map_collision_data": 0x8040aee0,
		"MoveBG::MammaYacht01_map_collision_info": 0x8040aee8,
		"MammaYacht01_map_collision_info": 0x8040aee8,
		"MoveBG::MammaYacht02_map_collision_data": 0x8040aef0,
		"MammaYacht02_map_collision_data": 0x8040aef0,
		"MoveBG::MammaYacht02_map_collision_info": 0x8040aef8,
		"MammaYacht02_map_collision_info": 0x8040aef8,
		"MoveBG::SandBombBase00_anim_info": 0x8040af00,
		"SandBombBase00_anim_info": 0x8040af00,
		"MoveBG::SandBombBase00_map_collision_info": 0x8040af08,
		"SandBombBase00_map_collision_info": 0x8040af08,
		"MoveBG::SandBombBaseMushroom_anim_info": 0x8040af10,
		"SandBombBaseMushroom_anim_info": 0x8040af10,
		"MoveBG::SandBombBaseMushroom_map_collision_info": 0x8040af18,
		"SandBombBaseMushroom_map_collision_info": 0x8040af18,
		"MoveBG::SandBombBasePyramid_anim_info": 0x8040af20,
		"SandBombBasePyramid_anim_info": 0x8040af20,
		"MoveBG::SandBombBasePyramid_map_collision_info": 0x8040af28,
		"SandBombBasePyramid_map_collision_info": 0x8040af28,
		"MoveBG::SandBombBaseShit_anim_info": 0x8040af30,
		"SandBombBaseShit_anim_info": 0x8040af30,
		"MoveBG::SandBombBaseShit_map_collision_info": 0x8040af38,
		"SandBombBaseShit_map_collision_info": 0x8040af38,
		"MoveBG::SandBombBaseStar_anim_info": 0x8040af40,
		"SandBombBaseStar_anim_info": 0x8040af40,
		"MoveBG::SandBombBaseStar_map_collision_info": 0x8040af48,
		"SandBombBaseStar_map_collision_info": 0x8040af48,
		"MoveBG::SandBombBaseTurtle_anim_info": 0x8040af50,
		"SandBombBaseTurtle_anim_info": 0x8040af50,
		"MoveBG::SandBombBaseTurtle_map_collision_info": 0x8040af58,
		"SandBombBaseTurtle_map_collision_info": 0x8040af58,
		"MoveBG::SandBombBaseFoot_anim_info": 0x8040af60,
		"SandBombBaseFoot_anim_info": 0x8040af60,
		"MoveBG::SandBombBaseFoot_map_collision_info": 0x8040af68,
		"SandBombBaseFoot_map_collision_info": 0x8040af68,
		"MoveBG::SandBombBaseHand_anim_info": 0x8040af70,
		"SandBombBaseHand_anim_info": 0x8040af70,
		"MoveBG::SandBombBaseHand_map_collision_info": 0x8040af78,
		"SandBombBaseHand_map_collision_info": 0x8040af78,
		"MoveBG::SandBombBaseStairs_anim_info": 0x8040af80,
		"SandBombBaseStairs_anim_info": 0x8040af80,
		"MoveBG::SandBombBaseStairs_map_collision_info": 0x8040af88,
		"SandBombBaseStairs_map_collision_info": 0x8040af88,
		"MoveBG::TeethOfJuicer_anim_info": 0x8040afa0,
		"TeethOfJuicer_anim_info": 0x8040afa0,
		"MoveBG::SandEggRepair_map_collision_data": 0x8040afa8,
		"SandEggRepair_map_collision_data": 0x8040afa8,
		"MoveBG::SandEggRepair_map_collision_info": 0x8040afb0,
		"SandEggRepair_map_collision_info": 0x8040afb0,
		"MoveBG::merrygoround_anim_info": 0x8040afc0,
		"merrygoround_anim_info": 0x8040afc0,
		"MoveBG::merrygoround_map_collision_data": 0x8040afc8,
		"merrygoround_map_collision_data": 0x8040afc8,
		"MoveBG::merrygoround_map_collision_info": 0x8040afd0,
		"merrygoround_map_collision_info": 0x8040afd0,
		"MoveBG::merry_egg_map_collision_data": 0x8040afd8,
		"merry_egg_map_collision_data": 0x8040afd8,
		"MoveBG::merry_egg_map_collision_info": 0x8040afe0,
		"merry_egg_map_collision_info": 0x8040afe0,
		"MoveBG::FerrisWheel_anim_info": 0x8040afe8,
		"FerrisWheel_anim_info": 0x8040afe8,
		"MoveBG::gondola_map_collision_data": 0x8040aff0,
		"gondola_map_collision_data": 0x8040aff0,
		"MoveBG::gondola_map_collision_info": 0x8040aff8,
		"gondola_map_collision_info": 0x8040aff8,
		"MoveBG::FerrisLOD_anim_info": 0x8040b000,
		"FerrisLOD_anim_info": 0x8040b000,
		"MoveBG::viking_map_collision_data": 0x8040b010,
		"viking_map_collision_data": 0x8040b010,
		"MoveBG::viking_map_collision_info": 0x8040b018,
		"viking_map_collision_info": 0x8040b018,
		"MoveBG::PinnaEntrance_map_collision_data": 0x8040b020,
		"PinnaEntrance_map_collision_data": 0x8040b020,
		"MoveBG::PinnaEntrance_map_collision_info": 0x8040b028,
		"PinnaEntrance_map_collision_info": 0x8040b028,
		"MoveBG::PinnaEntranceOpen_map_collision_data": 0x8040b030,
		"PinnaEntranceOpen_map_collision_data": 0x8040b030,
		"MoveBG::PinnaEntranceOpen_map_collision_info": 0x8040b038,
		"PinnaEntranceOpen_map_collision_info": 0x8040b038,
		"MoveBG::SirenaGate_map_collision_data": 0x8040b040,
		"SirenaGate_map_collision_data": 0x8040b040,
		"MoveBG::SirenaGate_map_collision_info": 0x8040b048,
		"SirenaGate_map_collision_info": 0x8040b048,
		"MoveBG::balloon_koopajr_anim_info": 0x8040b050,
		"balloon_koopajr_anim_info": 0x8040b050,
		"MoveBG::ShellCup_anim_info": 0x8040b058,
		"ShellCup_anim_info": 0x8040b058,
		"MoveBG::ShellCup_map_collision_data": 0x8040b060,
		"ShellCup_map_collision_data": 0x8040b060,
		"MoveBG::ShellCup_map_collision_info": 0x8040b068,
		"ShellCup_map_collision_info": 0x8040b068,
		"MoveBG::Gateshell_anim_info": 0x8040b070,
		"Gateshell_anim_info": 0x8040b070,
		"MoveBG::Gateshell_map_collision_data": 0x8040b078,
		"Gateshell_map_collision_data": 0x8040b078,
		"MoveBG::Gateshell_map_collision_info": 0x8040b080,
		"Gateshell_map_collision_info": 0x8040b080,
		"MoveBG::PinnaHangingBridgeBoard_anim_info": 0x8040b088,
		"PinnaHangingBridgeBoard_anim_info": 0x8040b088,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_data": 0x8040b090,
		"PinnaHangingBridgeBoard_map_collision_data": 0x8040b090,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_info": 0x8040b098,
		"PinnaHangingBridgeBoard_map_collision_info": 0x8040b098,
		"MoveBG::GateManta_anim_info": 0x8040b0a0,
		"GateManta_anim_info": 0x8040b0a0,
		"MoveBG::AmiKing_anim_info": 0x8040b0a8,
		"AmiKing_anim_info": 0x8040b0a8,
		"MoveBG::@3291": 0x8040b0b0,
		"MoveBG::casinoroulette_map_collision_data": 0x8040b0c0,
		"casinoroulette_map_collision_data": 0x8040b0c0,
		"MoveBG::casinoroulette_map_collision_info": 0x8040b0c8,
		"casinoroulette_map_collision_info": 0x8040b0c8,
		"MoveBG::@3295": 0x8040b0d0,
		"MoveBG::roulette_anim_info": 0x8040b0d8,
		"roulette_anim_info": 0x8040b0d8,
		"MoveBG::roulette00_map_collision_data": 0x8040b0e0,
		"roulette00_map_collision_data": 0x8040b0e0,
		"MoveBG::roulette00_map_collision_info": 0x8040b0e8,
		"roulette00_map_collision_info": 0x8040b0e8,
		"MoveBG::roulette01_map_collision_data": 0x8040b0f8,
		"roulette01_map_collision_data": 0x8040b0f8,
		"MoveBG::roulette01_map_collision_info": 0x8040b100,
		"roulette01_map_collision_info": 0x8040b100,
		"MoveBG::roulette02_map_collision_data": 0x8040b110,
		"roulette02_map_collision_data": 0x8040b110,
		"MoveBG::roulette02_map_collision_info": 0x8040b118,
		"roulette02_map_collision_info": 0x8040b118,
		"MoveBG::pazul_map_collision_data": 0x8040b138,
		"pazul_map_collision_data": 0x8040b138,
		"MoveBG::pazul_map_collision_info": 0x8040b140,
		"pazul_map_collision_info": 0x8040b140,
		"MoveBG::bosswall_anim_info": 0x8040b148,
		"bosswall_anim_info": 0x8040b148,
		"MoveBG::casinoroof_anim_info": 0x8040b150,
		"casinoroof_anim_info": 0x8040b150,
		"MoveBG::GlassBreak_anim_info": 0x8040b158,
		"GlassBreak_anim_info": 0x8040b158,
		"MoveBG::GlassBreak_map_collision_data": 0x8040b160,
		"GlassBreak_map_collision_data": 0x8040b160,
		"MoveBG::GlassBreak_map_collision_info": 0x8040b168,
		"GlassBreak_map_collision_info": 0x8040b168,
		"MoveBG::GlassBreak_sound_info": 0x8040b170,
		"GlassBreak_sound_info": 0x8040b170,
		"MoveBG::closet_anim_info": 0x8040b178,
		"closet_anim_info": 0x8040b178,
		"MoveBG::ChestRevolve_anim_info": 0x8040b188,
		"ChestRevolve_anim_info": 0x8040b188,
		"MoveBG::ChestRevolve_map_collision_info": 0x8040b190,
		"ChestRevolve_map_collision_info": 0x8040b190,
		"MoveBG::PosterTeresa_map_collision_data": 0x8040b198,
		"PosterTeresa_map_collision_data": 0x8040b198,
		"MoveBG::PosterTeresa_map_collision_info": 0x8040b1a0,
		"PosterTeresa_map_collision_info": 0x8040b1a0,
		"MoveBG::PictureTeresa_map_collision_data": 0x8040b1a8,
		"PictureTeresa_map_collision_data": 0x8040b1a8,
		"MoveBG::PictureTeresa_map_collision_info": 0x8040b1b0,
		"PictureTeresa_map_collision_info": 0x8040b1b0,
		"MoveBG::PanelBreak_anim_info": 0x8040b1b8,
		"PanelBreak_anim_info": 0x8040b1b8,
		"MoveBG::PanelBreak_map_collision_data": 0x8040b1c0,
		"PanelBreak_map_collision_data": 0x8040b1c0,
		"MoveBG::PanelBreak_map_collision_info": 0x8040b1c8,
		"PanelBreak_map_collision_info": 0x8040b1c8,
		"MoveBG::PanelBreak_sound_info": 0x8040b1d0,
		"PanelBreak_sound_info": 0x8040b1d0,
		"MoveBG::PanelRevolve_anim_info": 0x8040b1d8,
		"PanelRevolve_anim_info": 0x8040b1d8,
		"MoveBG::PanelRevolve_map_collision_data": 0x8040b1e0,
		"PanelRevolve_map_collision_data": 0x8040b1e0,
		"MoveBG::PanelRevolve_map_collision_info": 0x8040b1e8,
		"PanelRevolve_map_collision_info": 0x8040b1e8,
		"MoveBG::SirenaShop_map_collision_data": 0x8040b1f0,
		"SirenaShop_map_collision_data": 0x8040b1f0,
		"MoveBG::SirenaShop_map_collision_info": 0x8040b1f8,
		"SirenaShop_map_collision_info": 0x8040b1f8,
		"MoveBG::cogwheel_anim_info": 0x8040b200,
		"cogwheel_anim_info": 0x8040b200,
		"MoveBG::cogwheel_map_collision_data": 0x8040b208,
		"cogwheel_map_collision_data": 0x8040b208,
		"MoveBG::cogwheel_map_collision_info": 0x8040b210,
		"cogwheel_map_collision_info": 0x8040b210,
		"MoveBG::CogwheelPlate_map_collision_data": 0x8040b218,
		"CogwheelPlate_map_collision_data": 0x8040b218,
		"MoveBG::CogwheelPlate_map_collision_info": 0x8040b220,
		"CogwheelPlate_map_collision_info": 0x8040b220,
		"MoveBG::CogwheelPot_map_collision_data": 0x8040b228,
		"CogwheelPot_map_collision_data": 0x8040b228,
		"MoveBG::CogwheelPot_map_collision_info": 0x8040b230,
		"CogwheelPot_map_collision_info": 0x8040b230,
		"MoveBG::@3338": 0x8040b238,
		"MoveBG::mare_float_house_map_collision_data": 0x8040b240,
		"mare_float_house_map_collision_data": 0x8040b240,
		"MoveBG::mare_float_house_map_collision_info": 0x8040b248,
		"mare_float_house_map_collision_info": 0x8040b248,
		"MoveBG::StopRock_map_collision_data": 0x8040b250,
		"StopRock_map_collision_data": 0x8040b250,
		"MoveBG::StopRock_map_collision_info": 0x8040b258,
		"StopRock_map_collision_info": 0x8040b258,
		"MoveBG::GrowthTree_anim_info": 0x8040b260,
		"GrowthTree_anim_info": 0x8040b260,
		"MoveBG::@3344": 0x8040b268,
		"MoveBG::GrowthTree_map_collision_data": 0x8040b270,
		"GrowthTree_map_collision_data": 0x8040b270,
		"MoveBG::GrowthTree_map_collision_info": 0x8040b278,
		"GrowthTree_map_collision_info": 0x8040b278,
		"MoveBG::MuddyBoat_anim_info": 0x8040b280,
		"MuddyBoat_anim_info": 0x8040b280,
		"MoveBG::MuddyBoat_map_collision_data": 0x8040b288,
		"MuddyBoat_map_collision_data": 0x8040b288,
		"MoveBG::MuddyBoat_map_collision_info": 0x8040b290,
		"MuddyBoat_map_collision_info": 0x8040b290,
		"MoveBG::Puncher_anim_info": 0x8040b298,
		"Puncher_anim_info": 0x8040b298,
		"MoveBG::HatoPop_anim_info": 0x8040b2a8,
		"HatoPop_anim_info": 0x8040b2a8,
		"MoveBG::@3357": 0x8040b2b0,
		"MoveBG::MareWaterJump_map_collision_data": 0x8040b2b8,
		"MareWaterJump_map_collision_data": 0x8040b2b8,
		"MoveBG::MareWaterJump_map_collision_info": 0x8040b2c0,
		"MareWaterJump_map_collision_info": 0x8040b2c0,
		"MoveBG::CoinFish_anim_info": 0x8040b2c8,
		"CoinFish_anim_info": 0x8040b2c8,
		"MoveBG::MareFall_anim_info": 0x8040b2d0,
		"MareFall_anim_info": 0x8040b2d0,
		"MoveBG::MareCork_map_collision_data": 0x8040b2d8,
		"MareCork_map_collision_data": 0x8040b2d8,
		"MoveBG::MareCork_map_collision_info": 0x8040b2e0,
		"MareCork_map_collision_info": 0x8040b2e0,
		"MoveBG::MonteRoot_anim_info": 0x8040b2e8,
		"MonteRoot_anim_info": 0x8040b2e8,
		"MoveBG::JumpMushroom_anim_info": 0x8040b2f0,
		"JumpMushroom_anim_info": 0x8040b2f0,
		"MoveBG::JumpMushroom_map_collision_data": 0x8040b2f8,
		"JumpMushroom_map_collision_data": 0x8040b2f8,
		"MoveBG::JumpMushroom_map_collision_info": 0x8040b300,
		"JumpMushroom_map_collision_info": 0x8040b300,
		"MoveBG::MonteGoalFlag_anim_info": 0x8040b308,
		"MonteGoalFlag_anim_info": 0x8040b308,
		"MoveBG::HangingBridgeBoard_anim_info": 0x8040b310,
		"HangingBridgeBoard_anim_info": 0x8040b310,
		"MoveBG::HangingBridgeBoard_map_collision_data": 0x8040b320,
		"HangingBridgeBoard_map_collision_data": 0x8040b320,
		"MoveBG::HangingBridgeBoard_map_collision_info": 0x8040b328,
		"HangingBridgeBoard_map_collision_info": 0x8040b328,
		"MoveBG::SwingBoard_map_collision_data": 0x8040b330,
		"SwingBoard_map_collision_data": 0x8040b330,
		"MoveBG::SwingBoard_map_collision_info": 0x8040b338,
		"SwingBoard_map_collision_info": 0x8040b338,
		"MoveBG::Fluff_anim_info": 0x8040b340,
		"Fluff_anim_info": 0x8040b340,
		"MoveBG::Bathtub_anim_info": 0x8040b350,
		"Bathtub_anim_info": 0x8040b350,
		"MoveBG::BathtubStandBreaking_anim_info": 0x8040b368,
		"BathtubStandBreaking_anim_info": 0x8040b368,
		"MoveBG::ex1_turn_lift_anim_info": 0x8040b370,
		"ex1_turn_lift_anim_info": 0x8040b370,
		"MoveBG::ex1_turn_lift_map_collision_data": 0x8040b378,
		"ex1_turn_lift_map_collision_data": 0x8040b378,
		"MoveBG::ex1_turn_lift_map_collision_info": 0x8040b380,
		"ex1_turn_lift_map_collision_info": 0x8040b380,
		"MoveBG::z_turn_disk_map_collision_data": 0x8040b388,
		"z_turn_disk_map_collision_data": 0x8040b388,
		"MoveBG::z_turn_disk_map_collision_info": 0x8040b390,
		"z_turn_disk_map_collision_info": 0x8040b390,
		"MoveBG::y_turn_lift_anim_info": 0x8040b398,
		"y_turn_lift_anim_info": 0x8040b398,
		"MoveBG::y_turn_lift_map_collision_data": 0x8040b3a0,
		"y_turn_lift_map_collision_data": 0x8040b3a0,
		"MoveBG::y_turn_lift_map_collision_info": 0x8040b3a8,
		"y_turn_lift_map_collision_info": 0x8040b3a8,
		"MoveBG::Nail_anim_info": 0x8040b3b0,
		"Nail_anim_info": 0x8040b3b0,
		"MoveBG::Nail_map_collision_data": 0x8040b3c0,
		"Nail_map_collision_data": 0x8040b3c0,
		"MoveBG::Nail_map_collision_info": 0x8040b3c8,
		"Nail_map_collision_info": 0x8040b3c8,
		"MoveBG::PachinkoNail_anim_info": 0x8040b3d0,
		"PachinkoNail_anim_info": 0x8040b3d0,
		"MoveBG::PachinkoNail_map_collision_data": 0x8040b3d8,
		"PachinkoNail_map_collision_data": 0x8040b3d8,
		"MoveBG::PachinkoNail_map_collision_info": 0x8040b3e0,
		"PachinkoNail_map_collision_info": 0x8040b3e0,
		"MoveBG::FileLoadBlock_map_collision_data": 0x8040b3e8,
		"FileLoadBlock_map_collision_data": 0x8040b3e8,
		"MoveBG::FileLoadBlock_map_collision_info": 0x8040b3f0,
		"FileLoadBlock_map_collision_info": 0x8040b3f0,
		"MoveBG::FileLoadBlockA_anim_info": 0x8040b3f8,
		"FileLoadBlockA_anim_info": 0x8040b3f8,
		"MoveBG::FileLoadBlockB_anim_info": 0x8040b400,
		"FileLoadBlockB_anim_info": 0x8040b400,
		"MoveBG::FileLoadBlockC_anim_info": 0x8040b408,
		"FileLoadBlockC_anim_info": 0x8040b408,
		"MoveBG::@3910": 0x8040b414,
		"MoveBG::@3969": 0x8040b41c,
		"MoveBG::@4008": 0x8040b420,
		"MoveBG::@3676": 0x8040b458,
		"MoveBG::@3727": 0x8040b45c,
		"MoveBG::@3738": 0x8040b460,
		"MoveBG::@3651": 0x8040b4f0,
		"MoveBG::@4224": 0x8040b500,
		"MoveBG::@4629": 0x8040b7d8,
		"MoveBG::@3439": 0x8040b874,
		"MoveBG::@3654": 0x8040b878,
		"MoveBG::@3655": 0x8040b87c,
		"MoveBG::@3656": 0x8040b880,
		"MoveBG::@3657": 0x8040b884,
		"MoveBG::@4133": 0x8040bb38,
		"MoveBG::@4136": 0x8040bb44,
		"MoveBG::@4137": 0x8040bb48,
		"MoveBG::@4138": 0x8040bb4c,
		"MoveBG::@4139": 0x8040bb50,
		"MoveBG::@2393": 0x8040bb6c,
		"MoveBG::@2394": 0x8040bb70,
		"MoveBG::@2646": 0x8040bbc0,
		"MoveBG::@2647": 0x8040bbc4,
		"MoveBG::@2648": 0x8040bbc8,
		"MoveBG::@2676": 0x8040bbe8,
		"MoveBG::@2677": 0x8040bbec,
		"MoveBG::@2681": 0x8040bbf8,
		"MoveBG::@2682": 0x8040bbfc,
		"MoveBG::@2687": 0x8040bc10,
		"MoveBG::@2689": 0x8040bc18,
		"MoveBG::@2465": 0x8040bc48,
		"MoveBG::@2466": 0x8040bc50,
		"@2466": 0x8040bc50,
		"MoveBG::@2512": 0x8040bc58,
		"MoveBG::@2633": 0x8040bc6c,
		"MoveBG::@2705": 0x8040bc84,
		"MoveBG::@3689": 0x8040bd10,
		"MoveBG::@4727": 0x8040bd30,
		"MoveBG::@4728": 0x8040bd34,
		"MoveBG::@4729": 0x8040bd38,
		"MoveBG::@4730": 0x8040bd3c,
		"MoveBG::@4731": 0x8040bd40,
		"MoveBG::@4732": 0x8040bd44,
		"MoveBG::@4733": 0x8040bd48,
		"MoveBG::@4734": 0x8040bd4c,
		"MoveBG::@2453": 0x8040be08,
		"MoveBG::@2620": 0x8040be14,
		"MoveBG::@2621": 0x8040be18,
		"MoveBG::@2622": 0x8040be1c,
		"MoveBG::@2623": 0x8040be20,
		"MoveBG::@2186": 0x8040be30,
		"MoveBG::@2263": 0x8040be34,
		"MoveBG::@2279": 0x8040be38,
		"MoveBG::@2303": 0x8040be3c,
		"MoveBG::@2574": 0x8040be48,
		"MoveBG::@3681": 0x8040bf24,
		"MoveBG::@3682": 0x8040bf28,
		"@3682": 0x8040bf28,
		"MoveBG::@2671": 0x8040bf50,
		"MoveBG::@3442": 0x8040bfec,
		"MoveBG::@3443": 0x8040bff0,
		"MoveBG::@3444": 0x8040bff4,
		"MoveBG::@3445": 0x8040bff8,
		"MoveBG::@3446": 0x8040bffc,
		"MoveBG::@2668": 0x8040c0f0,
		"MoveBG::@2697": 0x8040c0fc,
		"MoveBG::@2702": 0x8040c10c,
		"MoveBG::@2713": 0x8040c124,
		"MoveBG::@5980": 0x8040c230,
		"@5980": 0x8040c230,
		"MoveBG::@5988": 0x8040c248,
		"MoveBG::@5994": 0x8040c254,
		"Map::@3002": 0x80409c80,
		"Map::@3209": 0x80409c84,
		"Map::@3210": 0x80409c88,
		"Map::@3211": 0x80409c8c,
		"Map::@3508": 0x80409c90,
		"Map::@2050": 0x80409c98,
		"Map::@2904": 0x80409ca0,
		"Map::@2905": 0x80409ca4,
		"Map::@2906": 0x80409ca8,
		"Map::@3158": 0x80409cb8,
		"Map::@3159": 0x80409cbc,
		"Map::@3160": 0x80409cc0,
		"Map::@3161": 0x80409cc4,
		"Map::@3196": 0x80409cc8,
		"Map::@3255": 0x80409ccc,
		"Map::@3256": 0x80409cd0,
		"Map::@3279": 0x80409cd4,
		"Map::@2183": 0x80409cd8,
		"Map::@2184": 0x80409cdc,
		"Map::@2185": 0x80409ce0,
		"Map::@2221": 0x80409ce4,
		"Map::@1871": 0x80409cf0,
		"Map::@2017": 0x80409cf4,
		"Map::@1838": 0x80409d00,
		"@1838": 0x80409d00,
		"Map::@1839": 0x80409d04,
		"Map::@1840": 0x80409d08,
		"Map::@1841": 0x80409d10,
		"Map::@3152": 0x80409d20,
		"Map::@3153": 0x80409d24,
		"Map::@2976": 0x80409d50,
		"Map::@2088": 0x80409d58,
		"Map::@2089": 0x80409d5c,
		"Map::@2207": 0x80409d68,
		"Map::@2841": 0x80409d88,
		"Map::@3181": 0x80409d98,
		"Map::@3182": 0x80409d9c,
		"Map::@3183": 0x80409da0,
		"Map::@2429": 0x80409da8,
		"Map::@2430": 0x80409dac,
		"Map::@2431": 0x80409db4,
		"Map::@2432": 0x80409dbc,
		"Map::@2505": 0x80409dc4,
		"Map::@2506": 0x80409dc8,
		"Map::@2640": 0x80409e20,
		"Map::@2643": 0x80409e38,
		"Map::@2644": 0x80409e40,
		"Map::@2645": 0x80409e48,
		"Map::@2646": 0x80409e50,
		"Map::@2648": 0x80409e60,
		"Map::@2569": 0x80409ebc,
		"Map::@2570": 0x80409ec0,
		"Map::@2572": 0x80409ec8,
		"Map::@2573": 0x80409ecc,
		"Map::@2574": 0x80409ed0,
		"Map::@2575": 0x80409ed4,
		"Map::@2577": 0x80409edc,
		"Map::@2578": 0x80409ee0,
		"Map::@2547": 0x80409f34,
		"Map::@2610": 0x80409f44,
		"Map::@2863": 0x80409f58,
		"Map::@2958": 0x80409f5c,
		"Map::@3188": 0x80409f68,
		"Map::@2849": 0x80409f70,
		"Map::@2850": 0x80409f74,
		"Map::@2851": 0x80409f78,
		"Map::@2852": 0x80409f7c,
		"Map::@2390": 0x80409f88,
		"Map::@2392": 0x80409f8c,
		"Map::@2396": 0x80409f90,
		"Map::@2460": 0x80409f94,
		"Map::@2788": 0x80409fb8,
		"Map::@2790": 0x80409fc0,
		"Map::@2865": 0x80409fcc,
		"Map::@2866": 0x80409fd0,
		"Map::@2785": 0x80409fdc,
		"Map::@2352": 0x8040a00c,
		"Map::@2353": 0x8040a010,
		"Map::@1992": 0x8040a028,
		"Map::@1993": 0x8040a02c,
		"Map::@2926": 0x8040a054,
		"Map::@2927": 0x8040a058,
		"Map::@2928": 0x8040a05c,
		"Map::@3135": 0x8040a09c,
		"Map::@3136": 0x8040a0a0,
		"Map::@3169": 0x8040a0a4,
		"Map::@3258": 0x8040a0a8,
		"Map::@3272": 0x8040a0b0,
		"Map::@3290": 0x8040a0b8,
		"Map::@3291": 0x8040a0c0,
		"Map::@3292": 0x8040a0c4,
		"Map::@3397": 0x8040a0d0,
		"Map::@3400": 0x8040a0e8,
		"Map::@3401": 0x8040a0ec,
		"Map::@3402": 0x8040a0f0,
		"Map::@3700": 0x8040a0f4,
		"Map::@3760": 0x8040a0f8,
		"Map::@3761": 0x8040a0fc,
		"Map::@3762": 0x8040a100,
		"Map::@3763": 0x8040a104,
		"Map::@3764": 0x8040a108,
		"Map::@3765": 0x8040a10c,
		"Map::@3766": 0x8040a110,
		"Map::@3767": 0x8040a114,
		"Map::@3768": 0x8040a118,
		"Map::@3769": 0x8040a11c,
		"Map::@3770": 0x8040a120,
		"Map::@3771": 0x8040a124,
		"Map::@3772": 0x8040a128,
		"Map::@3773": 0x8040a12c,
		"Map::@3774": 0x8040a130,
		"Map::@3775": 0x8040a134,
		"Map::@3776": 0x8040a138,
		"Map::@3777": 0x8040a13c,
		"Map::@3778": 0x8040a140,
		"Map::@3779": 0x8040a144,
		"Map::@3780": 0x8040a148,
		"Map::@3781": 0x8040a14c,
		"Map::@3782": 0x8040a150,
		"Map::@3783": 0x8040a154,
		"Map::@3784": 0x8040a158,
		"Map::@3785": 0x8040a15c,
		"Map::@3786": 0x8040a160,
		"Map::@3787": 0x8040a164,
		"Map::@3788": 0x8040a168,
		"Map::@3789": 0x8040a16c,
		"Map::@2566": 0x8040a17c,
		"Map::@2567": 0x8040a180,
		"Map::@3413": 0x8040a194,
		"Map::@3414": 0x8040a198,
		"Map::@3419": 0x8040a1ac,
		"Map::@3420": 0x8040a1b0,
		"Map::@3421": 0x8040a1b4,
		"Map::@3422": 0x8040a1b8,
		"Map::@3843": 0x8040a1e8,
		"Map::@3844": 0x8040a1ec,
		"Map::@4740": 0x8040a234,
		"Map::@4741": 0x8040a23c,
		"Map::@4759": 0x8040a264,
		"Map::@4842": 0x8040a284,
		"Map::@4846": 0x8040a298,
		"Map::@4847": 0x8040a29c,
		"Map::@4848": 0x8040a2a4,
		"Map::@4851": 0x8040a2b0,
		"GC2D::@1644": 0x804093f0,
		"GC2D::@2120": 0x80409420,
		"GC2D::@2375": 0x80409428,
		"TGCConsole2::height$localstatic0$drawWater": 0x80409444,
		"height$localstatic0$drawWater": 0x80409444,
		"TGCConsole2::topDiff$localstatic1$drawWater": 0x8040944c,
		"topDiff$localstatic1$drawWater": 0x8040944c,
		"GC2D::@1549": 0x80409580,
		"GC2D::@1550": 0x80409584,
		"GC2D::@1551": 0x80409588,
		"GC2D::@1552": 0x8040958c,
		"GC2D::@1553": 0x80409590,
		"GC2D::@2667": 0x804095dc,
		"GC2D::@2668": 0x804095e0,
		"GC2D::@2669": 0x804095e4,
		"GC2D::@2670": 0x804095e8,
		"GC2D::@2671": 0x804095ec,
		"GC2D::@2672": 0x804095f0,
		"GC2D::@2673": 0x804095f4,
		"GC2D::@2674": 0x804095f8,
		"GC2D::@3222": 0x80409640,
		"GC2D::@3223": 0x80409644,
		"GC2D::@3224": 0x80409648,
		"GC2D::@3225": 0x8040964c,
		"GC2D::@1995": 0x80409678,
		"GC2D::@1996": 0x8040967c,
		"GC2D::@2809": 0x804098b4,
		"GC2D::@2878": 0x804098b8,
		"GC2D::@2879": 0x804098bc,
		"GC2D::@1912": 0x80409968,
		"GC2D::@1913": 0x8040996c,
		"GC2D::@2032": 0x80409974,
		"GC2D::@2033": 0x80409978,
		"GC2D::@2034": 0x8040997c,
		"GC2D::@2035": 0x80409980,
		"GC2D::@2036": 0x80409984,
		"GC2D::@2037": 0x80409988,
		"GC2D::@2220": 0x804099a4,
		"GC2D::@2488": 0x804099b4,
		"GC2D::@2489": 0x804099b8,
		"GC2D::@2490": 0x804099bc,
		"GC2D::@2514": 0x804099c0,
		"GC2D::@2515": 0x804099c4,
		"GC2D::@1505": 0x804099c8,
		"GC2D::@1507": 0x804099cc,
		"@1507": 0x804099cc,
		"GC2D::@1844": 0x80409a88,
		"@1844": 0x80409a88,
		"GC2D::@114": 0x80409ab8,
		"GC2D::@1134": 0x80409b90,
		"@1134": 0x80409b90,
		"@unnamed@::cLongHeightMovieIdList": 0x80409be0,
		"cLongHeightMovieIdList": 0x80409be0,
		"@unnamed@::cRumbleToggleItems": 0x80409c0c,
		"cRumbleToggleItems": 0x80409c0c,
		"GC2D::@3596": 0x80409c58,
		"GC2D::@1558": 0x80409c70,
		"GC2D::@1580": 0x80409c78,
		"Enemy::@4578": 0x80406d98,
		"Enemy::@2718": 0x80406da0,
		"Enemy::@2800": 0x80406f10,
		"Enemy::@2802": 0x80406f20,
		"Enemy::@2824": 0x80406fa4,
		"Enemy::@2849": 0x8040705c,
		"Enemy::@2856": 0x80407094,
		"Enemy::@3205": 0x80407164,
		"Enemy::@3678": 0x80407288,
		"@3678": 0x80407288,
		"Enemy::@5337": 0x8040730c,
		"Enemy::mFireHamNoseColorStart": 0x80407358,
		"mFireHamNoseColorStart": 0x80407358,
		"Enemy::mFireHamNoseColorEnd": 0x80407360,
		"mFireHamNoseColorEnd": 0x80407360,
		"Enemy::mFireHamOtherColorStart": 0x80407368,
		"mFireHamOtherColorStart": 0x80407368,
		"Enemy::mFireHamOtherColorEnd": 0x80407370,
		"mFireHamOtherColorEnd": 0x80407370,
		"Enemy::@6521": 0x80407418,
		"Enemy::@2402": 0x80407638,
		"Enemy::@2403": 0x8040763c,
		"Enemy::@2404": 0x80407640,
		"Enemy::@1602": 0x8040764c,
		"Enemy::@1603": 0x80407650,
		"Enemy::@1630": 0x80407654,
		"Enemy::@2245": 0x8040766c,
		"Enemy::@4121": 0x80407820,
		"Enemy::@4317": 0x80407830,
		"@4317": 0x80407830,
		"Enemy::cTelesaColorStart": 0x80407870,
		"cTelesaColorStart": 0x80407870,
		"@unnamed@::cBodyColorOnFire": 0x80407910,
		"cBodyColorOnFire": 0x80407910,
		"@unnamed@::cBodyColorOnCool": 0x80407918,
		"cBodyColorOnCool": 0x80407918,
		"@unnamed@::cBodyColorOnSilver": 0x80407920,
		"cBodyColorOnSilver": 0x80407920,
		"Enemy::@5383": 0x80407984,
		"@5383": 0x80407984,
		"Enemy::@5385": 0x8040798c,
		"@5385": 0x8040798c,
		"Enemy::@7892": 0x804079e0,
		"@7892": 0x804079e0,
		"Enemy::@9121": 0x804079f8,
		"@9121": 0x804079f8,
		"Enemy::@9130": 0x80407a00,
		"@9130": 0x80407a00,
		"Enemy::@9149": 0x80407a10,
		"@9149": 0x80407a10,
		"Enemy::@1696": 0x80407a20,
		"@1696": 0x80407a20,
		"Enemy::@2231": 0x80407a38,
		"Enemy::@2232": 0x80407a3c,
		"Enemy::@2299": 0x80407a40,
		"Enemy::@7468": 0x80407af0,
		"@7468": 0x80407af0,
		"Enemy::@7469": 0x80407af4,
		"@7469": 0x80407af4,
		"Enemy::@7470": 0x80407af8,
		"@7470": 0x80407af8,
		"Enemy::@8328": 0x80407b28,
		"Enemy::@8337": 0x80407b30,
		"Enemy::@3406": 0x80407b54,
		"Enemy::@5924": 0x804080a8,
		"@5924": 0x804080a8,
		"Enemy::@5926": 0x804080b0,
		"@5926": 0x804080b0,
		"Enemy::@5928": 0x804080b8,
		"@5928": 0x804080b8,
		"Enemy::@5929": 0x804080bc,
		"@5929": 0x804080bc,
		"Enemy::@5930": 0x804080c0,
		"@5930": 0x804080c0,
		"Enemy::@6816": 0x80408108,
		"@6816": 0x80408108,
		"Enemy::@8021": 0x80408128,
		"@8021": 0x80408128,
		"Enemy::@8022": 0x8040812c,
		"@8022": 0x8040812c,
		"Enemy::@8023": 0x80408130,
		"Enemy::@8024": 0x80408134,
		"@8024": 0x80408134,
		"Enemy::@8025": 0x80408138,
		"@8025": 0x80408138,
		"Enemy::@8026": 0x8040813c,
		"@8026": 0x8040813c,
		"Enemy::@8750": 0x80408150,
		"@8750": 0x80408150,
		"Enemy::@4926": 0x80408270,
		"Enemy::@4927": 0x80408274,
		"Enemy::@4930": 0x80408280,
		"Enemy::@6157": 0x804082ec,
		"Enemy::@6170": 0x804082f8,
		"Enemy::@4678": 0x80408360,
		"Enemy::@4204": 0x804084f8,
		"Enemy::@4206": 0x80408500,
		"Enemy::@4208": 0x80408508,
		"Enemy::@4209": 0x8040850c,
		"Enemy::@2022": 0x80408530,
		"Enemy::@2023": 0x80408534,
		"Enemy::@2024": 0x80408538,
		"Enemy::@2025": 0x8040853c,
		"Enemy::@4239": 0x80408638,
		"Enemy::@4240": 0x8040863c,
		"Enemy::@2030": 0x804086bc,
		"Enemy::@2032": 0x804086c0,
		"Enemy::@2082": 0x80408740,
		"Enemy::@2083": 0x80408744,
		"Enemy::@2084": 0x80408748,
		"Enemy::@2085": 0x8040874c,
		"Enemy::@2086": 0x80408750,
		"Enemy::@2087": 0x80408754,
		"Enemy::@2088": 0x80408758,
		"Enemy::@4374": 0x804087e8,
		"@4374": 0x804087e8,
		"Enemy::@4377": 0x804087f4,
		"Enemy::@4378": 0x804087f8,
		"Enemy::@4379": 0x804087fc,
		"Enemy::@4832": 0x80408818,
		"Enemy::@4835": 0x8040881c,
		"Enemy::@4836": 0x80408820,
		"Enemy::@2474": 0x80408840,
		"Enemy::@1638": 0x804088b8,
		"Enemy::@1640": 0x804088bc,
		"Enemy::@1642": 0x804088c0,
		"Enemy::@1644": 0x804088c4,
		"Enemy::@1647": 0x804088c8,
		"@1647": 0x804088c8,
		"Enemy::@1649": 0x804088cc,
		"@1649": 0x804088cc,
		"Enemy::@1651": 0x804088d0,
		"@1651": 0x804088d0,
		"Enemy::@1653": 0x804088d4,
		"Enemy::@1655": 0x804088d8,
		"Enemy::@1659": 0x804088dc,
		"Enemy::@1663": 0x804088e0,
		"Enemy::@1665": 0x804088e4,
		"Enemy::@1668": 0x804088e8,
		"Enemy::@1670": 0x804088ec,
		"Enemy::@1680": 0x804088f0,
		"Enemy::@1683": 0x804088f4,
		"Enemy::@1685": 0x804088f8,
		"Enemy::@1688": 0x804088fc,
		"Enemy::@1779": 0x80408900,
		"Enemy::@1781": 0x80408904,
		"Enemy::@1787": 0x80408910,
		"Enemy::@1789": 0x80408914,
		"@1789": 0x80408914,
		"Enemy::@1791": 0x80408918,
		"@1791": 0x80408918,
		"Enemy::@1794": 0x8040891c,
		"@1794": 0x8040891c,
		"Enemy::@1796": 0x80408920,
		"@1796": 0x80408920,
		"Enemy::@1804": 0x80408928,
		"@1804": 0x80408928,
		"Enemy::@1807": 0x8040892c,
		"Enemy::@1809": 0x80408930,
		"Enemy::@1811": 0x80408934,
		"Enemy::@1813": 0x80408938,
		"@1813": 0x80408938,
		"Enemy::@1815": 0x8040893c,
		"@1815": 0x8040893c,
		"Enemy::@1817": 0x80408940,
		"@1817": 0x80408940,
		"Enemy::@1819": 0x80408944,
		"Enemy::@1823": 0x80408948,
		"@1823": 0x80408948,
		"Enemy::sEmitSandFrameFoot": 0x80408a30,
		"sEmitSandFrameFoot": 0x80408a30,
		"Enemy::@4729": 0x80408b6c,
		"Enemy::@2137": 0x80408c28,
		"Enemy::@2138": 0x80408c2c,
		"Enemy::@2149": 0x80408c38,
		"@unnamed@::cRedColor": 0x80408c48,
		"cRedColor": 0x80408c48,
		"@unnamed@::cBlueColor": 0x80408c50,
		"cBlueColor": 0x80408c50,
		"Enemy::@3864": 0x80408db4,
		"@3864": 0x80408db4,
		"Enemy::@4199": 0x80408dd8,
		"Enemy::@5252": 0x80408e1c,
		"Enemy::@5253": 0x80408e20,
		"Enemy::@5506": 0x80408e28,
		"@5506": 0x80408e28,
		"Enemy::@5507": 0x80408e2c,
		"@5507": 0x80408e2c,
		"Enemy::@1966": 0x80408e48,
		"Enemy::@2039": 0x80408e4c,
		"Enemy::@2040": 0x80408e50,
		"Enemy::@2119": 0x80408e54,
		"Enemy::@2152": 0x80408e58,
		"Enemy::@3774": 0x80408fa8,
		"Enemy::@6421": 0x80408fd8,
		"@6421": 0x80408fd8,
		"Enemy::@6422": 0x80408fdc,
		"@6422": 0x80408fdc,
		"Enemy::@6423": 0x80408fe0,
		"@6423": 0x80408fe0,
		"Enemy::@3636": 0x80409128,
		"Enemy::@3600": 0x8040938c,
		"Enemy::@2126": 0x804093cc,
		"Enemy::@2127": 0x804093d0,
		"Enemy::@2128": 0x804093d4,
		"Enemy::@2129": 0x804093d8,
		"Enemy::@2130": 0x804093dc,
		"Enemy::@2131": 0x804093e0,
		"Camera::@2112": 0x804068d4,
		"Camera::@2113": 0x804068d8,
		"Camera::@2304": 0x804068e0,
		"Camera::@2305": 0x804068e4,
		"Camera::@2306": 0x804068e8,
		"Camera::@2307": 0x804068ec,
		"Camera::@2308": 0x804068f0,
		"Camera::@2309": 0x804068f4,
		"Camera::@1717": 0x80406918,
		"@1717": 0x80406918,
		"Camera::@1655": 0x804069a0,
		"Camera::@1663": 0x804069b0,
		"Camera::@1659": 0x804069c0,
		"Camera::@1660": 0x804069c4,
		"Camera::@2403": 0x80406a04,
		"Camera::@2404": 0x80406a08,
		"Camera::@1896": 0x80406a80,
		"@1896": 0x80406a80,
		"Camera::@1900": 0x80406a88,
		"Camera::@1902": 0x80406a8c,
		"Camera::@1904": 0x80406a90,
		"Camera::@1914": 0x80406a9c,
		"@1914": 0x80406a9c,
		"Camera::@1916": 0x80406aa0,
		"@1916": 0x80406aa0,
		"Camera::@1918": 0x80406aa4,
		"@1918": 0x80406aa4,
		"Camera::@1920": 0x80406aa8,
		"@1920": 0x80406aa8,
		"Camera::@1938": 0x80406aac,
		"Camera::@1940": 0x80406ab0,
		"Camera::@1942": 0x80406ab4,
		"Camera::@1945": 0x80406ab8,
		"Camera::@1947": 0x80406abc,
		"Camera::@1958": 0x80406ad0,
		"Camera::@1960": 0x80406ad4,
		"Camera::@1963": 0x80406ad8,
		"Camera::@1965": 0x80406adc,
		"Camera::@2121": 0x80406ae0,
		"Camera::@2126": 0x80406ae4,
		"Camera::@2128": 0x80406ae8,
		"Camera::@2132": 0x80406aec,
		"Camera::@2134": 0x80406af0,
		"Camera::@2137": 0x80406af4,
		"Camera::@2145": 0x80406af8,
		"Camera::@2205": 0x80406afc,
		"Camera::@1807": 0x80406b18,
		"Camera::@1808": 0x80406b1c,
		"Camera::@1810": 0x80406b24,
		"Camera::@1811": 0x80406b28,
		"Camera::@2158": 0x80406bd8,
		"Camera::@2159": 0x80406bdc,
		"Camera::@2160": 0x80406be0,
		"Camera::@1864": 0x80406bfc,
		"@1864": 0x80406bfc,
		"Camera::@1865": 0x80406c00,
		"Camera::@1887": 0x80406c10,
		"@1887": 0x80406c10,
		"Camera::@2042": 0x80406c38,
		"Camera::@2043": 0x80406c3c,
		"Camera::@2044": 0x80406c40,
		"Camera::@2045": 0x80406c44,
		"Camera::@1778": 0x80406c50,
		"Camera::@1652": 0x80406c78,
		"Camera::@1653": 0x80406c7c,
		"Camera::@1758": 0x80406c90,
		"Camera::@1759": 0x80406c94,
		"@1759": 0x80406c94,
		"Camera::@1762": 0x80406ca8,
		"@1762": 0x80406ca8,
		"Camera::@1763": 0x80406cac,
		"Camera::@1705": 0x80406cf4,
		"Camera::@1706": 0x80406cf8,
		"Camera::@1707": 0x80406cfc,
		"Camera::@1710": 0x80406d08,
		"Camera::@1765": 0x80406d0c,
		"@1765": 0x80406d0c,
		"Camera::@1768": 0x80406d54,
		"Animal::@2190": 0x80406280,
		"Animal::@2191": 0x80406284,
		"Animal::@2192": 0x80406288,
		"Animal::@2193": 0x8040628c,
		"Animal::@2194": 0x80406290,
		"Animal::@2195": 0x80406294,
		"Animal::@2196": 0x80406298,
		"Animal::@2202": 0x804062a8,
		"Animal::@2203": 0x804062ac,
		"Animal::@2289": 0x804062b0,
		"Animal::@2290": 0x804062b4,
		"Animal::@2526": 0x804062b8,
		"Animal::@2527": 0x804062bc,
		"Animal::@2528": 0x804062c0,
		"Animal::@2529": 0x804062c4,
		"Animal::@2530": 0x804062c8,
		"Animal::@2531": 0x804062cc,
		"Animal::@2532": 0x804062d0,
		"Animal::@2533": 0x804062d4,
		"Animal::@2577": 0x804062d8,
		"Animal::@2578": 0x804062dc,
		"Animal::@2580": 0x804062e4,
		"Animal::@2455": 0x804062f4,
		"Animal::@2456": 0x804062f8,
		"Animal::@2457": 0x804062fc,
		"Animal::@2601": 0x80406324,
		"Animal::@2605": 0x80406328,
		"Animal::@2606": 0x8040632c,
		"Animal::@2760": 0x80406330,
		"Animal::@2761": 0x80406334,
		"Animal::@2762": 0x80406338,
		"Animal::@2763": 0x8040633c,
		"Animal::@2764": 0x80406340,
		"Animal::@2765": 0x80406344,
		"Animal::@2766": 0x80406348,
		"Animal::@2767": 0x8040634c,
		"Animal::@2768": 0x80406350,
		"Animal::@2929": 0x80406354,
		"Animal::@3022": 0x80406358,
		"Animal::@3023": 0x8040635c,
		"Animal::@3201": 0x80406370,
		"Animal::@3267": 0x80406374,
		"Animal::@3268": 0x80406378,
		"Animal::@3269": 0x8040637c,
		"Animal::@2600": 0x80406380,
		"Animal::@2613": 0x80406384,
		"Animal::@1564": 0x80406388,
		"Animal::@1566": 0x8040638c,
		"Animal::@1568": 0x80406390,
		"Animal::@1570": 0x80406394,
		"Animal::@1572": 0x80406398,
		"Animal::@1574": 0x8040639c,
		"Animal::@1576": 0x804063a0,
		"Animal::@1578": 0x804063a4,
		"Animal::@2158": 0x804063a8,
		"Animal::@2159": 0x804063ac,
		"Animal::@2160": 0x804063b0,
		"Animal::@3220": 0x804063d4,
		"Animal::@3221": 0x804063d8,
		"Animal::@3303": 0x804063e8,
		"Animal::@3407": 0x804063ec,
		"Animal::@3411": 0x804063f0,
		"Animal::@3412": 0x804063f4,
		"Animal::@3453": 0x804063f8,
		"Animal::@3544": 0x804063fc,
		"Animal::@3545": 0x80406400,
		"Animal::@3691": 0x80406404,
		"Animal::@3692": 0x80406408,
		"Animal::@3773": 0x8040640c,
		"Animal::@3930": 0x80406410,
		"Animal::@3933": 0x80406414,
		"Animal::@3935": 0x80406418,
		"Animal::@3937": 0x8040641c,
		"Animal::@3939": 0x80406420,
		"Animal::@3944": 0x80406424,
		"Animal::@3946": 0x80406428,
		"Animal::@3951": 0x8040642c,
		"Animal::@3954": 0x80406430,
		"Animal::@4172": 0x80406434,
		"Animal::@4173": 0x80406438,
		"Animal::@4755": 0x8040643c,
		"Animal::@4897": 0x80406440,
		"Animal::@4898": 0x80406448,
		"Animal::@4921": 0x8040644c,
		"Animal::@4922": 0x80406450,
		"Animal::@4923": 0x80406454,
		"Animal::@3087": 0x80406458,
		"Animal::@3088": 0x8040645c,
		"Animal::@3089": 0x80406460,
		"Animal::@3203": 0x80406464,
		"Animal::@3204": 0x80406468,
		"Animal::@3205": 0x8040646c,
		"Animal::@3206": 0x80406470,
		"Animal::@3207": 0x80406474,
		"Animal::@3208": 0x80406478,
		"Animal::@3448": 0x80406480,
		"Animal::@3664": 0x80406484,
		"Animal::@3667": 0x80406488,
		"Animal::@3668": 0x8040648c,
		"Animal::@3669": 0x80406494,
		"Animal::@3671": 0x80406498,
		"Animal::@3673": 0x8040649c,
		"Animal::@3676": 0x804064a0,
		"Animal::@3852": 0x804064b0,
		"Animal::@3853": 0x804064b4,
		"Animal::@3854": 0x804064b8,
		"Animal::@3855": 0x804064bc,
		"Animal::@4245": 0x804064c0,
		"Animal::@4246": 0x804064c4,
		"Animal::@4332": 0x804064c8,
		"Animal::@4452": 0x804064cc,
		"Animal::@4453": 0x804064d0,
		"@4453": 0x804064d0,
		"Animal::@4454": 0x804064d4,
		"Animal::@4455": 0x804064d8,
		"Animal::@4456": 0x804064dc,
		"Animal::@4641": 0x804064e0,
		"Animal::@4642": 0x804064e4,
		"Animal::@4709": 0x804064ec,
		"Animal::@4869": 0x804064f0,
		"Animal::@4870": 0x804064f4,
		"Animal::@5080": 0x804064fc,
		"Animal::@5340": 0x80406500,
		"Animal::@2489": 0x80406508,
		"Animal::@2490": 0x8040650c,
		"Animal::@2491": 0x80406510,
		"Animal::@2492": 0x80406518,
		"Animal::@2586": 0x8040651c,
		"Animal::@2587": 0x80406520,
		"Animal::@2588": 0x80406524,
		"Animal::@2589": 0x80406528,
		"Animal::@2590": 0x8040652c,
		"Animal::@2591": 0x80406530,
		"Animal::@2592": 0x80406534,
		"Animal::@2593": 0x80406538,
		"Animal::@2710": 0x80406540,
	},
	"GMSJ0A": {
		"Runtime.PPCEABI.H::memset": 0x80003100,
		"memset": 0x80003100,
		"Runtime.PPCEABI.H::__fill_mem": 0x80003130,
		"__fill_mem": 0x80003130,
		"Runtime.PPCEABI.H::memcpy": 0x800031f4,
		"memcpy": 0x800031f4,
		"TRK_MINNOW_DOLPHIN::TRK_memcpy": 0x80003244,
		"TRK_memcpy": 0x80003244,
		"TRK_MINNOW_DOLPHIN::TRK_memset": 0x80003268,
		"TRK_memset": 0x80003268,
		"TRK_MINNOW_DOLPHIN::__TRK_reset": 0x800051cc,
		"__TRK_reset": 0x800051cc,
		"os::__check_pad3": 0x800051ec,
		"__check_pad3": 0x800051ec,
		"os::__start": 0x8000522c,
		"os::__init_registers": 0x80005364,
		"__init_registers": 0x80005364,
		"os::__init_data": 0x80005380,
		"__init_data": 0x80005380,
		"os::__init_hardware": 0x80005440,
		"__init_hardware": 0x80005440,
		"os::__flush_cache": 0x80005460,
		"__flush_cache": 0x80005460,
		"Runtime.PPCEABI.H::@152": 0x80005540,
		"Runtime.PPCEABI.H::@157": 0x80005548,
		"Runtime.PPCEABI.H::@174": 0x80005550,
		"Runtime.PPCEABI.H::@182": 0x80005568,
		"Runtime.PPCEABI.H::@201": 0x80005570,
		"@201": 0x80005570,
		"Runtime.PPCEABI.H::@153": 0x800055a0,
		"Runtime.PPCEABI.H::@158": 0x800055ac,
		"Runtime.PPCEABI.H::@175": 0x800055b8,
		"Runtime.PPCEABI.H::@183": 0x800055c4,
		"Runtime.PPCEABI.H::@202": 0x800055d0,
		"@202": 0x800055d0,
		"main::main": 0x80005600,
		"main::__sinit_main_cpp": 0x80005644,
		"__sinit_main_cpp": 0x80005644,
		"Animal::CLBChaseGeneralConstantSpecifySpeed": 0x8000945c,
		"Animal::CLBPalFrame": 0x8000ab94,
		"Animal::CLBRoundf": 0x8000abec,
		"Animal::SMS_EasyEmitParticle": 0x8000e400,
		"MAnmSoundMario::startAnimSound": 0x80012cdc,
		"MSound::getDistPowFromCamera": 0x80015224,
		"getDistPowFromCamera": 0x80015224,
		"Enemy::SpcTrace": 0x80029d40,
		"Enemy::__ct__Q26JDrama10TFlagT<Us>FUs": 0x800356a0,
		"Enemy::MsPerpendicFootToLineR": 0x8008f414,
		"Enemy::__sinit_riccohook_cpp": 0x800adc48,
		"__sinit_riccohook_cpp": 0x800adc48,
		"TBombHeiManager::clipEnemies": 0x800b0774,
		"Enemy::CLBRoundf": 0x800d34b8,
		"Enemy::CLBSquared": 0x800d6b6c,
		"Enemy::CLBCalcRatio": 0x800d8b80,
		"Enemy::CLBChaseConstantSpecifyFrame": 0x800da78c,
		"TAmiNoko::emitEffects": 0x800dcdb0,
		"TAmiNoko::calcDirection": 0x800dcff0,
		"calcDirection": 0x800dcff0,
		"GC2D::CLBLinearInbetween": 0x8011fd18,
		"TGCConsole2::countBlueCoin": 0x80128950,
		"countBlueCoin": 0x80128950,
		"TGCConsole2::countShine": 0x80128de0,
		"countShine": 0x80128de0,
		"TGCConsole2::checkDolpic8": 0x80129ba8,
		"checkDolpic8": 0x80129ba8,
		"TGCConsole2::startDisappearTank": 0x8012dd18,
		"startDisappearTank": 0x8012dd18,
		"TCardLoad::setupTitleScreen": 0x8014f31c,
		"setupTitleScreen": 0x8014f31c,
		"TCardLoad::resetScoreScreenObjects": 0x8014f42c,
		"resetScoreScreenObjects": 0x8014f42c,
		"TGuide::startMoveCursor2": 0x8015c20c,
		"startMoveCursor2": 0x8015c20c,
		"TItemNozzle::calcRootMatrix": 0x8019b86c,
		"TJuiceBlock::touchActor": 0x801a3028,
		"TWatermelonStatic::touchWater": 0x801af750,
		"TAmiKing::calc": 0x801b40cc,
		"System::evStartMontemanFanfare": 0x80269694,
		"evStartMontemanFanfare": 0x80269694,
		"System::evStartMontemanBGM": 0x80269730,
		"evStartMontemanBGM": 0x80269730,
		"System::SMSSetupGCLogoRenderMode": 0x802851b8,
		"SMSSetupGCLogoRenderMode": 0x802851b8,
		"System::SMSGetRealVSyncTimesPerSec": 0x80287ae4,
		"SMSGetRealVSyncTimesPerSec": 0x80287ae4,
		"TMarDirector::thpInit": 0x802932b4,
		"thpInit": 0x802932b4,
		"MSStageCubeFadeDouble::proc": 0x80299c04,
		"MSStageCubeFade::setBgmVolumeForce": 0x80299f9c,
		"setBgmVolumeForce": 0x80299f9c,
		"MSMainProc::getGateKeeperBGMStopFlag": 0x8029bd08,
		"getGateKeeperBGMStopFlag": 0x8029bd08,
		"MSMainProc::setGateKeeperBGMPlayFlag": 0x8029bd50,
		"setGateKeeperBGMPlayFlag": 0x8029bd50,
		"JKRArchive::~JKRArchive": 0x8029c2c0,
		"JKRArchive::findDirectory": 0x8029c324,
		"findDirectory": 0x8029c324,
		"JKRArchive::findTypeResource": 0x8029c4e4,
		"findTypeResource": 0x8029c4e4,
		"JKRArchive::findFsResource": 0x8029c5dc,
		"findFsResource": 0x8029c5dc,
		"JKRArchive::findIdxResource": 0x8029c6e0,
		"findIdxResource": 0x8029c6e0,
		"JKRArchive::findNameResource": 0x8029c708,
		"findNameResource": 0x8029c708,
		"JKRArchive::findPtrResource": 0x8029c7c8,
		"findPtrResource": 0x8029c7c8,
		"JKRAramArchive::JKRAramArchive": 0x8029c96c,
		"JKRAramArchive::~JKRAramArchive": 0x8029ca18,
		"JKRFile::~JKRFile": 0x8029cb4c,
		"JKRAramArchive::open": 0x8029cbb0,
		"JKRAramHeap::JKRAramHeap": 0x8029d188,
		"JKRAramHeap::~JKRAramHeap": 0x8029d26c,
		"JKRAramHeap::alloc": 0x8029d314,
		"JKRAramHeap::allocFromHead": 0x8029d394,
		"JKRAramHeap::allocFromTail": 0x8029d420,
		"JSystem::__sinit_JKRAramHeap_cpp": 0x8029d498,
		"__sinit_JKRAramHeap_cpp": 0x8029d498,
		"JSUList<JKRAramBlock>::~JSUList": 0x8029d4e4,
		"JKRAram::create": 0x8029d53c,
		"JKRAram::JKRAram": 0x8029d5cc,
		"JKRAram::~JKRAram": 0x8029d6f8,
		"JKRAram::run": 0x8029d788,
		"JKRAram::mainRamToAram": 0x8029d7f0,
		"mainRamToAram": 0x8029d7f0,
		"JSystem::JKRDecompressFromAramToMainRam": 0x8029de64,
		"JKRDecompressFromAramToMainRam": 0x8029de64,
		"JSystem::__sinit_JKRAram_cpp": 0x8029e384,
		"__sinit_JKRAram_cpp": 0x8029e384,
		"JSUList<JKRAMCommand>::~JSUList": 0x8029e3d0,
		"JKRArchive::check_mount_already": 0x8029e428,
		"check_mount_already": 0x8029e428,
		"JKRArchive::mount": 0x8029e47c,
		"mount": 0x8029e47c,
		"JKRArchive::becomeCurrent": 0x8029e640,
		"becomeCurrent": 0x8029e640,
		"JKRArchive::getDirEntry": 0x8029e6d0,
		"getDirEntry": 0x8029e6d0,
		"JKRArchive::getGlbResource": 0x8029e748,
		"JKRArchive::removeResourceAll": 0x8029ea64,
		"JKRArchive::removeResource": 0x8029eafc,
		"JKRArchive::detachResource": 0x8029eb5c,
		"detachResource": 0x8029eb5c,
		"JKRArchive::getResSize": 0x8029eb98,
		"JKRArchive::countFile": 0x8029ebcc,
		"countFile": 0x8029ebcc,
		"JKRArchive::getFirstFile": 0x8029ec2c,
		"getFirstFile": 0x8029ec2c,
		"JKRCompArchive::JKRCompArchive": 0x8029ecd4,
		"JKRCompArchive::~JKRCompArchive": 0x8029ed7c,
		"JKRCompArchive::open": 0x8029eeb0,
		"JKRCompArchive::removeResourceAll": 0x8029f6ec,
		"JKRCompArchive::removeResource": 0x8029f790,
		"JKRDisposer::JKRDisposer": 0x8029f804,
		"JKRDisposer::~JKRDisposer": 0x8029f87c,
		"JKRDvdArchive::JKRDvdArchive": 0x8029f900,
		"JKRDvdArchive::~JKRDvdArchive": 0x8029f9a8,
		"JKRDvdArchive::open": 0x8029fab0,
		"JKRDvdFile::~JKRDvdFile": 0x802a0324,
		"JKRDvdFile::initiate": 0x802a03c4,
		"JKRDvdFile::close": 0x802a0520,
		"close": 0x802a0520,
		"JKRDvdFile::readData": 0x802a059c,
		"JKRDvdFile::writeData": 0x802a0664,
		"JKRDvdFile::sync": 0x802a066c,
		"JKRDvdFile::doneProcess": 0x802a06c0,
		"doneProcess": 0x802a06c0,
		"JKRDvdFile::getFileSize": 0x802a06f0,
		"getFileSize": 0x802a06f0,
		"JSystem::__sinit_JKRDvdFile_cpp": 0x802a06f8,
		"__sinit_JKRDvdFile_cpp": 0x802a06f8,
		"JSUList<JKRDvdFile>::~JSUList": 0x802a0744,
		"JKRExpHeap::createRoot": 0x802a079c,
		"createRoot": 0x802a079c,
		"JKRExpHeap::destroy": 0x802a09a4,
		"destroy": 0x802a09a4,
		"JKRExpHeap::JKRExpHeap": 0x802a0a34,
		"JKRExpHeap::~JKRExpHeap": 0x802a0ad8,
		"JKRExpHeap::changeGroupID": 0x802a0b44,
		"JKRExpHeap::alloc": 0x802a0b9c,
		"JKRExpHeap::free": 0x802a1324,
		"JKRExpHeap::freeAll": 0x802a1398,
		"JKRExpHeap::freeTail": 0x802a1414,
		"JKRExpHeap::resize": 0x802a14a4,
		"JKRExpHeap::getSize": 0x802a1664,
		"JKRExpHeap::getFreeSize": 0x802a16ec,
		"JKRExpHeap::getTotalFreeSize": 0x802a1758,
		"JKRExpHeap::getUsedSize": 0x802a17bc,
		"getUsedSize": 0x802a17bc,
		"JKRExpHeap::check": 0x802a1838,
		"JKRExpHeap::appendUsedList": 0x802a1a1c,
		"appendUsedList": 0x802a1a1c,
		"JKRExpHeap::setFreeBlock": 0x802a1ab4,
		"setFreeBlock": 0x802a1ab4,
		"JKRExpHeap::removeFreeBlock": 0x802a1b00,
		"removeFreeBlock": 0x802a1b00,
		"JKRExpHeap::recycleFreeBlock": 0x802a1b34,
		"recycleFreeBlock": 0x802a1b34,
		"JKRExpHeap::joinTwoBlocks": 0x802a1d1c,
		"joinTwoBlocks": 0x802a1d1c,
		"JKRExpHeap::dump": 0x802a1e24,
		"JKRExpHeap::dump_sort": 0x802a1fec,
		"JKRExpHeap::CMemBlock::initiate": 0x802a21e4,
		"JKRExpHeap::CMemBlock::allocFore": 0x802a2204,
		"allocFore": 0x802a2204,
		"JKRExpHeap::CMemBlock::allocBack": 0x802a2248,
		"allocBack": 0x802a2248,
		"JKRExpHeap::CMemBlock::free": 0x802a22a0,
		"JKRExpHeap::CMemBlock::getHeapBlock": 0x802a2300,
		"getHeapBlock": 0x802a2300,
		"JKRExpHeap::state_register": 0x802a231c,
		"JKRExpHeap::state_compare": 0x802a23e0,
		"JKRExpHeap::getCurrentGroupId": 0x802a2410,
		"JKRExpHeap::getHeapType": 0x802a2418,
		"JKRArcFinder::JKRArcFinder": 0x802a2424,
		"JKRArcFinder::findNextFile": 0x802a24c0,
		"findNextFile": 0x802a24c0,
		"JKRArcFinder::~JKRArcFinder": 0x802a2578,
		"JKRFileLoader::JKRFileLoader": 0x802a25d4,
		"JKRFileLoader::~JKRFileLoader": 0x802a2634,
		"JKRFileLoader::unmount": 0x802a26c0,
		"JKRFileLoader::getVolume": 0x802a2710,
		"getVolume": 0x802a2710,
		"JKRFileLoader::changeDirectory": 0x802a277c,
		"changeDirectory": 0x802a277c,
		"JKRFileLoader::getResSize": 0x802a28a4,
		"JKRFileLoader::findVolume": 0x802a2934,
		"findVolume": 0x802a2934,
		"JKRFileLoader::findFirstFile": 0x802a29c0,
		"findFirstFile": 0x802a29c0,
		"JKRFileLoader::fetchVolumeName": 0x802a2a88,
		"fetchVolumeName": 0x802a2a88,
		"JSystem::__sinit_JKRFileLoader_cpp": 0x802a2b70,
		"__sinit_JKRFileLoader_cpp": 0x802a2b70,
		"JSUList<JKRFileLoader>::~JSUList": 0x802a2bbc,
		"JKRHeap::JKRHeap": 0x802a2c14,
		"JKRHeap::~JKRHeap": 0x802a2d34,
		"JKRHeap::initArena": 0x802a2e4c,
		"initArena": 0x802a2e4c,
		"JKRHeap::becomeSystemHeap": 0x802a2f30,
		"becomeSystemHeap": 0x802a2f30,
		"JKRHeap::becomeCurrentHeap": 0x802a2f40,
		"becomeCurrentHeap": 0x802a2f40,
		"JKRHeap::alloc": 0x802a2f50,
		"JKRHeap::free": 0x802a2fc8,
		"JKRHeap::freeAll": 0x802a3020,
		"JKRHeap::findFromRoot": 0x802a3070,
		"findFromRoot": 0x802a3070,
		"JKRHeap::find": 0x802a30ac,
		"find": 0x802a30ac,
		"JKRHeap::dispose_subroutine": 0x802a31b8,
		"dispose_subroutine": 0x802a31b8,
		"JKRHeap::copyMemory": 0x802a32f4,
		"copyMemory": 0x802a32f4,
		"JSystem::JKRDefaultMemoryErrorRoutine": 0x802a3380,
		"JKRDefaultMemoryErrorRoutine": 0x802a3380,
		"JSystem::operator_delete": 0x802a35b4,
		"operator_delete": 0x802a35b4,
		"JSystem::operator_delete[]": 0x802a3618,
		"operator_delete[]": 0x802a3618,
		"JKRHeap::state_register": 0x802a367c,
		"JKRHeap::state_compare": 0x802a3680,
		"JKRHeap::state_dump": 0x802a3698,
		"state_dump": 0x802a3698,
		"JKRHeap::dump_sort": 0x802a369c,
		"JKRHeap::changeGroupID": 0x802a36a4,
		"JKRHeap::getCurrentGroupId": 0x802a36ac,
		"JKRMemArchive::~JKRMemArchive": 0x802a3854,
		"JKRMemArchive::mountFixed": 0x802a38fc,
		"mountFixed": 0x802a38fc,
		"JKRMemArchive::unmountFixed": 0x802a3a0c,
		"unmountFixed": 0x802a3a0c,
		"JKRMemArchive::removeResourceAll": 0x802a3d78,
		"JKRMemArchive::removeResource": 0x802a3dc8,
		"JKRMemArchive::fetchResource_subroutine": 0x802a3e04,
		"JKRSolidHeap::create": 0x802a3edc,
		"JKRSolidHeap::JKRSolidHeap": 0x802a3f5c,
		"JKRSolidHeap::~JKRSolidHeap": 0x802a3fb8,
		"JKRSolidHeap::alloc": 0x802a4024,
		"JKRSolidHeap::allocFromHead": 0x802a40d4,
		"JKRSolidHeap::allocFromTail": 0x802a41b8,
		"JKRSolidHeap::free": 0x802a428c,
		"JKRSolidHeap::freeAll": 0x802a42b8,
		"JKRSolidHeap::freeTail": 0x802a4318,
		"JKRSolidHeap::resize": 0x802a43a4,
		"JKRSolidHeap::getSize": 0x802a43d4,
		"JKRSolidHeap::check": 0x802a4404,
		"JKRSolidHeap::dump": 0x802a4494,
		"JKRSolidHeap::state_register": 0x802a45b4,
		"JKRSolidHeap::getTotalFreeSize": 0x802a461c,
		"JKRSolidHeap::getFreeSize": 0x802a4648,
		"JKRSolidHeap::state_compare": 0x802a4650,
		"JKRSolidHeap::getHeapType": 0x802a4680,
		"JKRStdHeap::create": 0x802a468c,
		"JKRStdHeap::JKRStdHeap": 0x802a470c,
		"JKRStdHeap::~JKRStdHeap": 0x802a4760,
		"JKRStdHeap::alloc": 0x802a47dc,
		"JKRStdHeap::free": 0x802a488c,
		"JKRStdHeap::freeAll": 0x802a48d4,
		"JKRStdHeap::freeTail": 0x802a4928,
		"JKRStdHeap::resize": 0x802a4950,
		"JKRStdHeap::getFreeSize": 0x802a4980,
		"JKRStdHeap::state_register": 0x802a49ac,
		"JKRStdHeap::state_compare": 0x802a49c0,
		"JKRStdHeap::getSize": 0x802a49f0,
		"JKRStdHeap::getTotalFreeSize": 0x802a4a14,
		"JKRStdHeap::getHeapType": 0x802a4a40,
		"JKRStdHeap::check": 0x802a4a4c,
		"JKRStdHeap::dump": 0x802a4a7c,
		"JKRThread::JKRThread": 0x802a4ac0,
		"JKRThread::~JKRThread": 0x802a4bf0,
		"JKRThread::start": 0x802a4cc8,
		"JKRThread::run": 0x802a4cf4,
		"JSystem::__sinit_JKRThread_cpp": 0x802a4cfc,
		"__sinit_JKRThread_cpp": 0x802a4cfc,
		"JSUList<JKRThread>::~JSUList": 0x802a4d48,
		"JSUOutputStream::~JSUOutputStream": 0x802a4da0,
		"JSUOutputStream::write": 0x802a4dfc,
		"JSUOutputStream::skip": 0x802a4e54,
		"JSURandomOutputStream::seek": 0x802a4ee0,
		"JSUInputStream::~JSUInputStream": 0x802a4f24,
		"JSUInputStream::read": 0x802a4f80,
		"JSUInputStream::skip": 0x802a51cc,
		"JSURandomInputStream::align": 0x802a5254,
		"align": 0x802a5254,
		"JSURandomInputStream::skip": 0x802a52e4,
		"JSURandomInputStream::peek": 0x802a5340,
		"peek": 0x802a5340,
		"JSURandomInputStream::seek": 0x802a53fc,
		"JSUPtrLink::JSUPtrLink": 0x802a5440,
		"JSUPtrLink::~JSUPtrLink": 0x802a5458,
		"JSUPtrList::~JSUPtrList": 0x802a54f4,
		"JSUPtrList::initiate": 0x802a555c,
		"JSUPtrList::append": 0x802a5570,
		"JSUPtrList::prepend": 0x802a562c,
		"prepend": 0x802a562c,
		"JSUPtrList::insert": 0x802a56e8,
		"JSUPtrList::remove": 0x802a58c4,
		"JSUMemoryInputStream::setBuffer": 0x802a5974,
		"JSUMemoryInputStream::readData": 0x802a5988,
		"JSUMemoryInputStream::seekPos": 0x802a5a00,
		"JSUMemoryOutputStream::setBuffer": 0x802a5a7c,
		"JSUMemoryOutputStream::writeData": 0x802a5a90,
		"JSUMemoryOutputStream::seekPos": 0x802a5b04,
		"JSUMemoryOutputStream::getLength": 0x802a5b80,
		"JSUMemoryOutputStream::getPosition": 0x802a5b88,
		"JSUFileInputStream::JSUFileInputStream": 0x802a5b90,
		"JSUFileInputStream::readData": 0x802a5bd4,
		"JSUFileInputStream::seekPos": 0x802a5ca8,
		"JSUFileInputStream::~JSUFileInputStream": 0x802a5d90,
		"JSUFileInputStream::getLength": 0x802a5e04,
		"JSUFileInputStream::getPosition": 0x802a5e34,
		"JUTException::create": 0x802a5e3c,
		"JUTException::run": 0x802a5ea0,
		"JUTException::JUTException": 0x802a5f60,
		"JUTException::errorHandler": 0x802a6040,
		"errorHandler": 0x802a6040,
		"JUTException::showFloat": 0x802a6130,
		"showFloat": 0x802a6130,
		"JSystem::__fpclassifyf": 0x802a6578,
		"__fpclassifyf": 0x802a6578,
		"JUTException::searchPartialModule": 0x802a65e0,
		"searchPartialModule": 0x802a65e0,
		"JSystem::search_name_part": 0x802a66a0,
		"search_name_part": 0x802a66a0,
		"JUTException::showStack": 0x802a6718,
		"showStack": 0x802a6718,
		"JUTException::showGPR": 0x802a6818,
		"showGPR": 0x802a6818,
		"JUTException::showMapInfo_subroutine": 0x802a68d8,
		"showMapInfo_subroutine": 0x802a68d8,
		"JUTException::showGPRMap": 0x802a6a38,
		"showGPRMap": 0x802a6a38,
		"JUTException::readPad": 0x802a6b28,
		"readPad": 0x802a6b28,
		"JUTException::printContext": 0x802a6d14,
		"printContext": 0x802a6d14,
		"JUTException::waitTime": 0x802a71b8,
		"waitTime": 0x802a71b8,
		"JUTException::createFB": 0x802a7244,
		"createFB": 0x802a7244,
		"JUTException::getFpscr": 0x802a730c,
		"getFpscr": 0x802a730c,
		"JUTException::setPreUserCallback": 0x802a7334,
		"setPreUserCallback": 0x802a7334,
		"JUTException::appendMapFile": 0x802a7344,
		"appendMapFile": 0x802a7344,
		"JUTException::queryMapAddress": 0x802a73d8,
		"queryMapAddress": 0x802a73d8,
		"JUTException::queryMapAddress_single": 0x802a74d0,
		"queryMapAddress_single": 0x802a74d0,
		"JUTException::createConsole": 0x802a781c,
		"createConsole": 0x802a781c,
		"JUTExternalFB::JUTExternalFB": 0x802a78fc,
		"JUTException::~JUTException": 0x802a791c,
		"JSystem::__sinit_JUTException_cpp": 0x802a7980,
		"__sinit_JUTException_cpp": 0x802a7980,
		"JSUList<JUTException::JUTExMapFile>::~JSUList": 0x802a79d0,
		"JUTDirectPrint::start": 0x802a7a28,
		"JUTDirectPrint::JUTDirectPrint": 0x802a7a78,
		"JUTDirectPrint::erase": 0x802a7ab4,
		"JUTDirectPrint::drawChar": 0x802a7ba8,
		"drawChar": 0x802a7ba8,
		"JUTDirectPrint::changeFrameBuffer": 0x802a7da8,
		"changeFrameBuffer": 0x802a7da8,
		"JUTDirectPrint::drawString": 0x802a7ddc,
		"drawString": 0x802a7ddc,
		"JUTDirectPrint::drawString_f": 0x802a7e08,
		"drawString_f": 0x802a7e08,
		"JUTFont::JUTFont": 0x802a7f90,
		"JUTFont::initiate": 0x802a7ffc,
		"JUTFont::setCharColor": 0x802a8000,
		"setCharColor": 0x802a8000,
		"JUTFont::setGradColor": 0x802a8024,
		"setGradColor": 0x802a8024,
		"JUTFont::drawString_size_scale": 0x802a8048,
		"drawString_size_scale": 0x802a8048,
		"JUTFont::~JUTFont": 0x802a8138,
		"JUTFont::setGX": 0x802a8184,
		"JUTGamePad::JUTGamePad": 0x802a81b0,
		"JUTGamePad::~JUTGamePad": 0x802a828c,
		"JUTGamePad::initList": 0x802a8338,
		"initList": 0x802a8338,
		"JUTGamePad::init": 0x802a8374,
		"JUTGamePad::read": 0x802a83ac,
		"JUTGamePad::assign": 0x802a86d0,
		"assign": 0x802a86d0,
		"JUTGamePad::update": 0x802a8780,
		"JUTGamePad::checkResetSwitch": 0x802a8968,
		"checkResetSwitch": 0x802a8968,
		"JUTGamePad::clearForReset": 0x802a89e8,
		"clearForReset": 0x802a89e8,
		"JUTGamePad::CButton::clear": 0x802a8a14,
		"JUTGamePad::CButton::update": 0x802a8a50,
		"JUTGamePad::CStick::clear": 0x802a8be0,
		"JUTGamePad::CStick::update": 0x802a8bfc,
		"JUTGamePad::CStick::getButton": 0x802a8d98,
		"getButton": 0x802a8d98,
		"JUTGamePad::CRumble::clear": 0x802a8e44,
		"JUTGamePad::CRumble::stopMotor": 0x802a8eb0,
		"stopMotor": 0x802a8eb0,
		"JUTGamePad::CRumble::stopMotorHard": 0x802a8f10,
		"stopMotorHard": 0x802a8f10,
		"JUTGamePad::CRumble::update": 0x802a8f70,
		"JUTGamePad::CRumble::setEnable": 0x802a913c,
		"setEnable": 0x802a913c,
		"JUTGamePad::CButton::setRepeat": 0x802a9240,
		"setRepeat": 0x802a9240,
		"JUTGamePad::setButtonRepeat": 0x802a925c,
		"setButtonRepeat": 0x802a925c,
		"JUTGamePad::recalibrate": 0x802a92a8,
		"recalibrate": 0x802a92a8,
		"JUTGamePadRecord::read": 0x802a9364,
		"JUTGamePadRecord::write": 0x802a9410,
		"JUTGamePadRecord::streamDataToPadStatus": 0x802a94cc,
		"streamDataToPadStatus": 0x802a94cc,
		"JUTGamePadRecord::padStatusToStreamData": 0x802a9564,
		"padStatusToStreamData": 0x802a9564,
		"JSystem::__sinit_JUTGamePad_cpp": 0x802a95fc,
		"__sinit_JUTGamePad_cpp": 0x802a95fc,
		"JUTGamePad::CStick::CStick": 0x802a96f0,
		"JUTGamePad::CButton::CButton": 0x802a970c,
		"JSUList<JUTGamePad>::~JSUList": 0x802a9748,
		"JUTNameTab::JUTNameTab": 0x802a97a0,
		"JUTNameTab::getIndex": 0x802a97c4,
		"JUTNameTab::getName": 0x802a9860,
		"getName": 0x802a9860,
		"JUTNameTab::calcKeyCode": 0x802a9890,
		"JUTPalette::storeTLUT": 0x802a98c0,
		"storeTLUT": 0x802a98c0,
		"JUTPalette::JUTPalette": 0x802a9958,
		"JUTPalette::load": 0x802a99a8,
		"JUTRect::set": 0x802a99f0,
		"JUTRect::copy": 0x802a9a04,
		"JUTRect::add": 0x802a9a28,
		"JUTRect::intersect": 0x802a9a5c,
		"intersect": 0x802a9a5c,
		"JUTRect::move": 0x802a9adc,
		"JUTRect::resize": 0x802a9b18,
		"JUTRect::reform": 0x802a9b34,
		"reform": 0x802a9b34,
		"JUTRect::normalize": 0x802a9b68,
		"JUTRect::isEmpty": 0x802a9b9c,
		"isEmpty": 0x802a9b9c,
		"JUTTexture::JUTTexture": 0x802a9cfc,
		"JUTTexture::~JUTTexture": 0x802a9de0,
		"JUTTexture::storeTIMG": 0x802a9e50,
		"storeTIMG": 0x802a9e50,
		"JUTTexture::attachPalette": 0x802a9fd8,
		"attachPalette": 0x802a9fd8,
		"JUTTexture::load": 0x802aa24c,
		"JSystem::JMANewSinTable": 0x802aa29c,
		"JMANewSinTable": 0x802aa29c,
		"JSystem::JMAEulerToQuat": 0x802aa45c,
		"JMAEulerToQuat": 0x802aa45c,
		"JSystem::JMAQuatLerp": 0x802aa514,
		"JMAQuatLerp": 0x802aa514,
		"JSystem::JMAHermiteInterpolation": 0x802aa5b8,
		"JMAHermiteInterpolation": 0x802aa5b8,
		"J2DPane::~J2DPane": 0x802aae04,
		"J2DPane::draw": 0x802aaee4,
		"J2DGrafContext::~J2DGrafContext": 0x802ab2e0,
		"J2DPane::clip": 0x802ab32c,
		"clip": 0x802ab32c,
		"J2DPane::search": 0x802ab378,
		"J2DPane::makeMatrix": 0x802ab40c,
		"makeMatrix": 0x802ab40c,
		"J2DPane::setCullBack": 0x802ab578,
		"setCullBack": 0x802ab578,
		"J2DPane::setBasePosition": 0x802ab664,
		"setBasePosition": 0x802ab664,
		"J2DPane::setConnectParent": 0x802ab72c,
		"J2DPicture::J2DPicture": 0x802ab740,
		"J2DPicture::~J2DPicture": 0x802abbcc,
		"J2DPicture::insert": 0x802abc98,
		"J2DPicture::remove": 0x802abdc4,
		"J2DPicture::changeTexture": 0x802abeb0,
		"J2DPicture::drawFullSet": 0x802ac048,
		"drawFullSet": 0x802ac048,
		"J2DPicture::draw": 0x802ac704,
		"J2DPicture::drawTexCoord": 0x802acafc,
		"drawTexCoord": 0x802acafc,
		"J2DPicture::setTevMode": 0x802accf4,
		"J2DPicture::swap": 0x802ad148,
		"swap": 0x802ad148,
		"J2DPicture::setBlendKonstColor": 0x802ad15c,
		"setBlendKonstColor": 0x802ad15c,
		"J2DPicture::setBlendKonstAlpha": 0x802ad294,
		"setBlendKonstAlpha": 0x802ad294,
		"JSystem::J2DPrint_print_alpha_va": 0x802ad3cc,
		"J2DPrint_print_alpha_va": 0x802ad3cc,
		"J2DPrint::~J2DPrint": 0x802ad580,
		"J2DPrint::initiate": 0x802ad5cc,
		"J2DPrint::private_initiate": 0x802ad654,
		"private_initiate": 0x802ad654,
		"J2DPrint::setBuffer": 0x802ad7dc,
		"J2DPrint::setFontSize": 0x802ad848,
		"setFontSize": 0x802ad848,
		"J2DPrint::locate": 0x802ad8a8,
		"locate": 0x802ad8a8,
		"J2DPrint::getWidth": 0x802adaa4,
		"J2DPrint::printReturn": 0x802adbb0,
		"printReturn": 0x802adbb0,
		"J2DPrint::parse": 0x802ade0c,
		"parse": 0x802ade0c,
		"J2DPrint::doCtrlCode": 0x802ae64c,
		"doCtrlCode": 0x802ae64c,
		"J2DPrint::doEscapeCode": 0x802ae7c0,
		"doEscapeCode": 0x802ae7c0,
		"J2DPrint::initchar": 0x802aeda8,
		"initchar": 0x802aeda8,
		"J2DPrint::getNumber": 0x802aedec,
		"getNumber": 0x802aedec,
		"J2DScreen::~J2DScreen": 0x802aeef4,
		"J2DScreen::makeHiearachyPanes": 0x802aef58,
		"makeHiearachyPanes": 0x802aef58,
		"J2DScreen::stop": 0x802af57c,
		"J2DScreen::draw": 0x802af5b8,
		"J2DScreen::search": 0x802af860,
		"J2DSetScreen::J2DSetScreen": 0x802af890,
		"J2DScreen::drawSelf": 0x802af9d8,
		"J2DSetScreen::~J2DSetScreen": 0x802afa90,
		"J2DTextBox::initiate": 0x802b00f4,
		"J2DTextBox::~J2DTextBox": 0x802b0224,
		"J2DTextBox::setFont": 0x802b02c8,
		"setFont": 0x802b02c8,
		"J2DTextBox::draw": 0x802b0338,
		"J2DTextBox::getStringPtr": 0x802b0470,
		"getStringPtr": 0x802b0470,
		"J2DTextBox::setString": 0x802b0478,
		"setString": 0x802b0478,
		"J2DTextBox::setConnectParent": 0x802b0548,
		"J2DTextBox::resize": 0x802b0724,
		"J2DWindow::J2DWindow": 0x802b07d4,
		"J2DWindow::~J2DWindow": 0x802b0f70,
		"J2DWindow::Texture::~Texture": 0x802b1098,
		"J2DWindow::draw_private": 0x802b10fc,
		"draw_private": 0x802b10fc,
		"J2DWindow::resize": 0x802b15b8,
		"J2DWindow::drawContents": 0x802b1798,
		"drawContents": 0x802b1798,
		"J2DWindow::Texture::drawContentsTexture": 0x802b1c4c,
		"drawContentsTexture": 0x802b1c4c,
		"J2DWindow::Texture::setTevMode": 0x802b1e34,
		"JSystem::J3DCalcZValue": 0x802b2204,
		"J3DCalcZValue": 0x802b2204,
		"JSystem::J3DPSCalcInverseTranspose": 0x802b223c,
		"J3DPSCalcInverseTranspose": 0x802b223c,
		"JSystem::J3DGetTextureMtx": 0x802b2470,
		"J3DGetTextureMtx": 0x802b2470,
		"JSystem::J3DGetTextureMtxOld": 0x802b2548,
		"J3DGetTextureMtxOld": 0x802b2548,
		"JSystem::J3DGetTextureMtxMaya": 0x802b2620,
		"J3DGetTextureMtxMaya": 0x802b2620,
		"JSystem::J3DGetTextureMtxMayaOld": 0x802b2770,
		"J3DGetTextureMtxMayaOld": 0x802b2770,
		"JSystem::J3DScaleNrmMtx33": 0x802b28c0,
		"J3DScaleNrmMtx33": 0x802b28c0,
		"JSystem::J3DMtxProjConcat": 0x802b2914,
		"J3DMtxProjConcat": 0x802b2914,
		"JSystem::J3DPSMtx33Copy": 0x802b2a38,
		"J3DPSMtx33Copy": 0x802b2a38,
		"JSystem::J3DPSMtx33CopyFrom34": 0x802b2a64,
		"J3DPSMtx33CopyFrom34": 0x802b2a64,
		"JSystem::J3DPSMtxArrayCopy": 0x802b2a98,
		"J3DPSMtxArrayCopy": 0x802b2a98,
		"JSystem::J3DMTXConcatArrayIndexedSrc": 0x802b2adc,
		"J3DMTXConcatArrayIndexedSrc": 0x802b2adc,
		"JSystem::J3DPSMtxArrayConcat": 0x802b2c14,
		"J3DPSMtxArrayConcat": 0x802b2c14,
		"J3DDeformData::deform": 0x802b2cf0,
		"J3DDeformData::setAnm": 0x802b2dd8,
		"J3DAnmCluster::getWeight": 0x802b2f80,
		"J3DDeformer::normalize": 0x802b36d8,
		"J3DDeformer::normalizeWeight": 0x802b3788,
		"normalizeWeight": 0x802b3788,
		"J3DSkinDeform::J3DSkinDeform": 0x802b37e4,
		"J3DSkinDeform::initMtxIndexArray": 0x802b380c,
		"initMtxIndexArray": 0x802b380c,
		"J3DSkinDeform::calcNrmMtx": 0x802b3be8,
		"J3DSkinDeform::deform": 0x802b3d14,
		"J3DAnmVtxColor::getColor": 0x802b41b8,
		"J3DSkinDeform::~J3DSkinDeform": 0x802b41bc,
		"J3DMtxCalcBasic::J3DMtxCalcBasic": 0x802b42f4,
		"J3DNode::updateOut": 0x802b44f8,
		"J3DNode::updateIn": 0x802b44fc,
		"J3DNode::calcOut": 0x802b46bc,
		"J3DNode::calcIn": 0x802b46c0,
		"J3DNode::entryIn": 0x802b4740,
		"JSystem::J3DNewMtxCalcAnm": 0x802b4e64,
		"J3DNewMtxCalcAnm": 0x802b4e64,
		"J3DMtxCalcMaya::~J3DMtxCalcMaya": 0x802b50d4,
		"J3DJoint::initialize": 0x802b5164,
		"J3DJoint::addMesh": 0x802b5258,
		"addMesh": 0x802b5258,
		"J3DJoint::updateIn": 0x802b5278,
		"J3DJoint::updateOut": 0x802b54b0,
		"J3DJoint::calcIn": 0x802b54d4,
		"J3DJoint::calcOut": 0x802b5554,
		"J3DJoint::entryIn": 0x802b5578,
		"J3DJoint::getType": 0x802b5750,
		"J3DJoint::~J3DJoint": 0x802b575c,
		"J3DNode::init": 0x802b57c0,
		"J3DColorBlockLightOff::initialize": 0x802b5c00,
		"J3DColorBlockLightOn::initialize": 0x802b5c6c,
		"J3DTevBlock2::initialize": 0x802b5d40,
		"J3DTevBlock4::initialize": 0x802b5e78,
		"J3DTevBlock16::initialize": 0x802b6000,
		"J3DMaterial::createColorBlock": 0x802b6324,
		"createColorBlock": 0x802b6324,
		"J3DColorChan::J3DColorChan": 0x802b6468,
		"JSystem::calcColorChanID": 0x802b64cc,
		"calcColorChanID": 0x802b64cc,
		"J3DGXColor::J3DGXColor": 0x802b6648,
		"J3DColorBlock::~J3DColorBlock": 0x802b664c,
		"J3DMaterial::createTexGenBlock": 0x802b6698,
		"createTexGenBlock": 0x802b6698,
		"J3DTexCoord::J3DTexCoord": 0x802b6768,
		"J3DTexGenBlock::~J3DTexGenBlock": 0x802b6788,
		"J3DMaterial::createTevBlock": 0x802b67d4,
		"createTevBlock": 0x802b67d4,
		"J3DTevSwapModeTable::J3DTevSwapModeTable": 0x802b6b84,
		"J3DGXColorS10::J3DGXColorS10": 0x802b6b90,
		"J3DIndTevStage::J3DIndTevStage": 0x802b6b94,
		"J3DTevStage::J3DTevStage": 0x802b6be4,
		"J3DTevOrder::J3DTevOrder": 0x802b6d18,
		"J3DTevBlock::~J3DTevBlock": 0x802b6d38,
		"J3DMaterial::createIndBlock": 0x802b6d84,
		"createIndBlock": 0x802b6d84,
		"J3DIndTexCoordScale::~J3DIndTexCoordScale": 0x802b6e7c,
		"J3DIndTexCoordScale::J3DIndTexCoordScale": 0x802b6ebc,
		"J3DIndTexMtx::~J3DIndTexMtx": 0x802b6ed4,
		"J3DIndTexMtx::J3DIndTexMtx": 0x802b6f14,
		"J3DIndTexOrder::J3DIndTexOrder": 0x802b6f54,
		"J3DIndBlock::~J3DIndBlock": 0x802b6f6c,
		"J3DMaterial::createPEBlock": 0x802b6fb8,
		"createPEBlock": 0x802b6fb8,
		"J3DPEBlock::~J3DPEBlock": 0x802b7100,
		"J3DMaterial::initialize": 0x802b714c,
		"J3DMaterial::addShape": 0x802b719c,
		"addShape": 0x802b719c,
		"J3DColorBlockLightOff::countDLSize": 0x802b71a4,
		"J3DColorBlockLightOn::countDLSize": 0x802b71ac,
		"J3DTexGenBlockBasic::countDLSize": 0x802b71b4,
		"J3DTevBlock1::countDLSize": 0x802b71bc,
		"J3DTevBlock2::countDLSize": 0x802b71c4,
		"J3DTevBlock4::countDLSize": 0x802b71cc,
		"J3DTevBlock16::countDLSize": 0x802b71d4,
		"J3DIndBlockFull::countDLSize": 0x802b71dc,
		"J3DPEBlockOpa::countDLSize": 0x802b71e4,
		"J3DPEBlockTexEdge::countDLSize": 0x802b71ec,
		"J3DPEBlockXlu::countDLSize": 0x802b71f4,
		"J3DPEBlockFull::countDLSize": 0x802b71fc,
		"J3DMaterial::countDLSize": 0x802b7204,
		"J3DColorBlockLightOff::load": 0x802b72b8,
		"J3DColorBlockLightOn::load": 0x802b73b0,
		"J3DTexGenBlockBasic::load": 0x802b750c,
		"J3DTexGenBlockBasic::patch": 0x802b75c4,
		"patch": 0x802b75c4,
		"J3DTevBlock1::load": 0x802b7664,
		"J3DTevBlock2::load": 0x802b7850,
		"J3DTevBlock4::load": 0x802b7d54,
		"J3DTevBlock16::load": 0x802b828c,
		"J3DIndBlockFull::load": 0x802b87c4,
		"J3DPEBlockOpa::load": 0x802b89b4,
		"J3DPEBlockTexEdge::load": 0x802b8b2c,
		"J3DPEBlockXlu::load": 0x802b8ca0,
		"J3DPEBlockFull::load": 0x802b8e18,
		"JSystem::J3DGDWrite_u32": 0x802b8f50,
		"J3DGDWrite_u32": 0x802b8f50,
		"JSystem::__GDWrite": 0x802b8fb0,
		"__GDWrite": 0x802b8fb0,
		"JSystem::GDOverflowCheck": 0x802b8fc8,
		"J3DColorBlockLightOff::reset": 0x802b9000,
		"J3DColorBlockLightOn::reset": 0x802b90d4,
		"J3DLightInfo::operator_=": 0x802b9294,
		"J3DTexGenBlockBasic::reset": 0x802b9318,
		"J3DTevBlock1::reset": 0x802b9484,
		"J3DTevBlock2::reset": 0x802b95ac,
		"J3DTevBlock4::reset": 0x802b9914,
		"J3DTevBlock16::reset": 0x802b9ed4,
		"J3DIndBlockFull::reset": 0x802ba180,
		"J3DIndTexMtxInfo::operator_=": 0x802ba2a4,
		"J3DPEBlockFull::reset": 0x802ba2e0,
		"J3DPEBlock::getZCompLoc": 0x802ba658,
		"J3DPEBlock::getBlend": 0x802ba660,
		"J3DPEBlock::getAlphaComp": 0x802ba668,
		"J3DFogInfo::operator_=": 0x802ba670,
		"J3DMaterial::makeDisplayList": 0x802ba738,
		"makeDisplayList": 0x802ba738,
		"J3DMaterial::load": 0x802ba89c,
		"J3DMaterial::safeMakeDisplayList": 0x802ba920,
		"safeMakeDisplayList": 0x802ba920,
		"J3DTexGenBlockBasic::calc": 0x802baa84,
		"J3DMaterial::calc": 0x802bad14,
		"J3DMaterial::setCurrentMtx": 0x802bad44,
		"setCurrentMtx": 0x802bad44,
		"J3DMaterial::copy": 0x802bae70,
		"J3DPEBlock::reset": 0x802baf30,
		"J3DIndBlock::reset": 0x802baf34,
		"J3DTevBlock::reset": 0x802baf38,
		"J3DTexGenBlock::reset": 0x802baf3c,
		"J3DColorBlock::reset": 0x802baf40,
		"J3DMaterial::change": 0x802baf44,
		"change": 0x802baf44,
		"J3DMaterial::newSharedDisplayList": 0x802baf7c,
		"newSharedDisplayList": 0x802baf7c,
		"J3DPEBlockFull::getType": 0x802baff4,
		"J3DPEBlockFull::setFog": 0x802bb000,
		"J3DPEBlockFull::replaceFog": 0x802bb008,
		"J3DPEBlockFull::getFog": 0x802bb018,
		"J3DPEBlockFull::getAlphaComp": 0x802bb058,
		"J3DPEBlockFull::getBlend": 0x802bb0a8,
		"J3DPEBlockFull::getZMode": 0x802bb0c8,
		"J3DPEBlockFull::getZCompLoc": 0x802bb0e4,
		"J3DPEBlockFull::getDither": 0x802bb100,
		"J3DPEBlockFull::~J3DPEBlockFull": 0x802bb108,
		"J3DIndBlockFull::getType": 0x802bb164,
		"J3DIndBlockFull::setIndTexStageNum": 0x802bb170,
		"J3DIndBlockFull::getIndTexStageNum": 0x802bb178,
		"J3DIndBlockFull::getIndTexOrder": 0x802bb1b8,
		"J3DIndBlockFull::getIndTexMtx": 0x802bb22c,
		"J3DIndBlockFull::getIndTexCoordScale": 0x802bb278,
		"J3DIndBlockFull::~J3DIndBlockFull": 0x802bb28c,
		"J3DTevBlock16::getType": 0x802bb328,
		"J3DTevBlock16::getTexNo": 0x802bb358,
		"J3DTevBlock16::getTevOrder": 0x802bb3b0,
		"J3DTevBlock16::getTevColor": 0x802bb3fc,
		"J3DTevBlock16::getTevKColor": 0x802bb438,
		"J3DTevBlock16::getTevKColorSel": 0x802bb468,
		"J3DTevBlock16::getTevKAlphaSel": 0x802bb490,
		"J3DTevBlock16::getTevStageNum": 0x802bb4b0,
		"J3DTevBlock16::getTevStage": 0x802bb530,
		"J3DTevBlock16::getTevSwapModeTable": 0x802bb5d4,
		"J3DTevBlock16::getIndTevStage": 0x802bb68c,
		"J3DTevBlock16::~J3DTevBlock16": 0x802bb6a0,
		"J3DTevBlock4::getType": 0x802bb6fc,
		"J3DTevBlock4::getTexNo": 0x802bb72c,
		"J3DTevBlock4::getTevOrder": 0x802bb784,
		"J3DTevBlock4::getTevColor": 0x802bb7d0,
		"J3DTevBlock4::getTevKColor": 0x802bb80c,
		"J3DTevBlock4::getTevKColorSel": 0x802bb83c,
		"J3DTevBlock4::getTevKAlphaSel": 0x802bb864,
		"J3DTevBlock4::getTevStageNum": 0x802bb884,
		"J3DTevBlock4::getTevStage": 0x802bb904,
		"J3DTevBlock4::getTevSwapModeTable": 0x802bb9a8,
		"J3DTevBlock4::getIndTevStage": 0x802bba60,
		"J3DTevBlock4::~J3DTevBlock4": 0x802bba74,
		"J3DTevBlock2::getType": 0x802bbad0,
		"J3DTevBlock2::getTexNo": 0x802bbb00,
		"J3DTevBlock2::getTevOrder": 0x802bbb58,
		"J3DTevBlock2::getTevColor": 0x802bbba4,
		"J3DTevBlock2::getTevKColor": 0x802bbbe0,
		"J3DTevBlock2::getTevKColorSel": 0x802bbc10,
		"J3DTevBlock2::getTevKAlphaSel": 0x802bbc38,
		"J3DTevBlock2::getTevStageNum": 0x802bbc58,
		"J3DTevBlock2::getTevStage": 0x802bbcd8,
		"J3DTevBlock2::getTevSwapModeTable": 0x802bbd7c,
		"J3DTevBlock2::getIndTevStage": 0x802bbe34,
		"J3DTevBlock2::~J3DTevBlock2": 0x802bbe48,
		"J3DTevBlock1::getType": 0x802bbea4,
		"J3DTevBlock1::getTexNo": 0x802bbed4,
		"J3DTevBlock1::getTevOrder": 0x802bbf2c,
		"J3DTevBlock1::getTevColor": 0x802bbf48,
		"J3DTevBlock1::getTevKColor": 0x802bbf58,
		"J3DTevBlock1::getTevKColorSel": 0x802bbf68,
		"J3DTevBlock1::getTevKAlphaSel": 0x802bbf78,
		"J3DTevBlock1::getTevStageNum": 0x802bbf88,
		"J3DTevBlock1::getTevStage": 0x802bc008,
		"J3DTevBlock1::getTevSwapModeTable": 0x802bc02c,
		"J3DTevBlock1::getIndTevStage": 0x802bc0dc,
		"J3DTevBlock1::~J3DTevBlock1": 0x802bc0f0,
		"J3DTexGenBlockBasic::getType": 0x802bc14c,
		"J3DTexGenBlockBasic::getTexGenNum": 0x802bc16c,
		"getTexGenNum": 0x802bc16c,
		"J3DTexGenBlockBasic::setTexCoord": 0x802bc174,
		"setTexCoord": 0x802bc174,
		"J3DTexGenBlockBasic::getTexCoord": 0x802bc198,
		"getTexCoord": 0x802bc198,
		"J3DTexGenBlockBasic::setTexMtx": 0x802bc1ac,
		"setTexMtx": 0x802bc1ac,
		"J3DTexGenBlockBasic::replaceTexMtx": 0x802bc1bc,
		"replaceTexMtx": 0x802bc1bc,
		"J3DTexGenBlockBasic::getTexMtx": 0x802bc1d0,
		"getTexMtx": 0x802bc1d0,
		"J3DTexGenBlockBasic::getNBTScale": 0x802bc228,
		"getNBTScale": 0x802bc228,
		"J3DTexGenBlockBasic::~J3DTexGenBlockBasic": 0x802bc230,
		"J3DColorBlockLightOn::getType": 0x802bc28c,
		"J3DColorBlockLightOn::getMatColor": 0x802bc2c0,
		"J3DColorBlockLightOn::getAmbColor": 0x802bc2fc,
		"J3DColorBlockLightOn::getColorChanNum": 0x802bc324,
		"J3DColorBlockLightOn::getColorChan": 0x802bc354,
		"J3DColorBlockLightOn::setLight": 0x802bc368,
		"J3DColorBlockLightOn::replaceLight": 0x802bc378,
		"J3DColorBlockLightOn::getLight": 0x802bc38c,
		"J3DColorBlockLightOn::getCullMode": 0x802bc3b0,
		"J3DColorBlockLightOn::~J3DColorBlockLightOn": 0x802bc3b8,
		"J3DColorBlockLightOff::getType": 0x802bc414,
		"J3DColorBlockLightOff::getMatColor": 0x802bc448,
		"J3DColorBlockLightOff::getAmbColor": 0x802bc464,
		"J3DColorBlockLightOff::getColorChanNum": 0x802bc480,
		"J3DColorBlockLightOff::getColorChan": 0x802bc4b0,
		"J3DColorBlockLightOff::setLight": 0x802bc4c4,
		"J3DColorBlockLightOff::replaceLight": 0x802bc4c8,
		"J3DColorBlockLightOff::getLight": 0x802bc4d0,
		"J3DColorBlockLightOff::getCullMode": 0x802bc4ec,
		"J3DColorBlockLightOff::~J3DColorBlockLightOff": 0x802bc4f4,
		"J3DPEBlockXlu::getType": 0x802bc550,
		"J3DPEBlockXlu::~J3DPEBlockXlu": 0x802bc55c,
		"J3DPEBlock::setFog": 0x802bc5b8,
		"J3DPEBlock::replaceFog": 0x802bc5bc,
		"J3DPEBlock::getDither": 0x802bc5ec,
		"J3DPEBlockTexEdge::getType": 0x802bc5f4,
		"J3DPEBlockTexEdge::~J3DPEBlockTexEdge": 0x802bc600,
		"J3DPEBlockOpa::getType": 0x802bc65c,
		"J3DPEBlockOpa::~J3DPEBlockOpa": 0x802bc668,
		"J3DIndBlockNull::reset": 0x802bc6c4,
		"J3DIndBlockNull::countDLSize": 0x802bc6c8,
		"J3DIndBlockNull::getType": 0x802bc6d0,
		"J3DIndBlockNull::setIndTexStageNum": 0x802bc6dc,
		"J3DIndBlockNull::getIndTexStageNum": 0x802bc6e0,
		"J3DIndBlockNull::getIndTexOrder": 0x802bc6f0,
		"J3DIndBlockNull::getIndTexMtx": 0x802bc700,
		"J3DIndBlockNull::getIndTexCoordScale": 0x802bc710,
		"J3DIndBlockNull::~J3DIndBlockNull": 0x802bc718,
		"J3DIndBlockNull::load": 0x802bc774,
		"J3DModelData::clear": 0x802bc778,
		"J3DModelData::J3DModelData": 0x802bc7ec,
		"J3DModelData::~J3DModelData": 0x802bc840,
		"J3DModelData::makeHierarchy": 0x802bc8b0,
		"J3DNode::getType": 0x802bca5c,
		"J3DModelData::isDeformableVertexFormat": 0x802bca68,
		"isDeformableVertexFormat": 0x802bca68,
		"J3DModelData::setMaterialTable": 0x802bcaec,
		"setMaterialTable": 0x802bcaec,
		"J3DModelData::entryMatColorAnimator": 0x802bcba4,
		"entryMatColorAnimator": 0x802bcba4,
		"J3DModelData::entryTexMtxAnimator": 0x802bcc58,
		"entryTexMtxAnimator": 0x802bcc58,
		"J3DModelData::entryTevRegAnimator": 0x802bce2c,
		"entryTevRegAnimator": 0x802bce2c,
		"J3DModelData::removeMatColorAnimator": 0x802bcf98,
		"removeMatColorAnimator": 0x802bcf98,
		"J3DModelData::removeTexNoAnimator": 0x802bd010,
		"removeTexNoAnimator": 0x802bd010,
		"J3DModelData::removeTexMtxAnimator": 0x802bd0a4,
		"removeTexMtxAnimator": 0x802bd0a4,
		"J3DModelData::removeTevRegAnimator": 0x802bd148,
		"removeTevRegAnimator": 0x802bd148,
		"J3DModelData::setMatColorAnimator": 0x802bd264,
		"setMatColorAnimator": 0x802bd264,
		"J3DModelData::setTexNoAnimator": 0x802bd2e4,
		"setTexNoAnimator": 0x802bd2e4,
		"J3DModelData::setTexMtxAnimator": 0x802bd38c,
		"setTexMtxAnimator": 0x802bd38c,
		"J3DModelData::setTevRegAnimator": 0x802bd4c4,
		"setTevRegAnimator": 0x802bd4c4,
		"J3DModel::~J3DModel": 0x802bd6b0,
		"J3DModel::initialize": 0x802bd6fc,
		"J3DModel::entryModelData": 0x802bd7a0,
		"entryModelData": 0x802bd7a0,
		"J3DModel::lock": 0x802bdc80,
		"lock": 0x802bdc80,
		"J3DModel::unlock": 0x802bddb0,
		"unlock": 0x802bddb0,
		"J3DModel::makeDL": 0x802bdee0,
		"J3DModel::setSkinDeform": 0x802bdf78,
		"setSkinDeform": 0x802bdf78,
		"J3DModel::calcWeightEnvelopeMtx": 0x802bdff4,
		"calcWeightEnvelopeMtx": 0x802bdff4,
		"J3DModel::update": 0x802be1d0,
		"J3DModel::calc": 0x802be3d4,
		"J3DModel::entry": 0x802be5d8,
		"J3DModel::viewCalc": 0x802be6c8,
		"J3DModel::calcNrmMtx": 0x802be900,
		"J3DModel::calcBumpMtx": 0x802bea58,
		"calcBumpMtx": 0x802bea58,
		"J3DModel::calcBBoard": 0x802beb4c,
		"calcBBoard": 0x802beb4c,
		"J3DModel::prepareShapePackets": 0x802bf054,
		"prepareShapePackets": 0x802bf054,
		"J3DNode::J3DNode": 0x802bf218,
		"J3DNode::~J3DNode": 0x802bf23c,
		"J3DNode::appendChild": 0x802bf288,
		"appendChild": 0x802bf288,
		"J3DShapeMtx::loadMtxIndx_PNGP": 0x802bf2bc,
		"loadMtxIndx_PNGP": 0x802bf2bc,
		"J3DShapeMtx::loadMtxIndx_PCPU": 0x802bf318,
		"loadMtxIndx_PCPU": 0x802bf318,
		"J3DShapeMtx::loadMtxIndx_NCPU": 0x802bf378,
		"loadMtxIndx_NCPU": 0x802bf378,
		"J3DShapeMtx::loadMtxIndx_PNCPU": 0x802bf3c4,
		"loadMtxIndx_PNCPU": 0x802bf3c4,
		"J3DShapeMtx::load": 0x802bf414,
		"J3DShapeMtx::calcNBTScale": 0x802bf470,
		"J3DShapeMtx::~J3DShapeMtx": 0x802bf4d8,
		"J3DShapeMtxDL::load": 0x802bf524,
		"J3DShapeMtxMulti::load": 0x802bf54c,
		"J3DShapeMtxMulti::calcNBTScale": 0x802bf5f4,
		"J3DShapeDraw::J3DShapeDraw": 0x802bf680,
		"J3DShapeDraw::draw": 0x802bf698,
		"J3DShape::initialize": 0x802bf6c4,
		"J3DShape::calcNBTScale": 0x802bf730,
		"J3DShape::countBumpMtxNum": 0x802bf7a8,
		"countBumpMtxNum": 0x802bf7a8,
		"J3DShape::makeVtxArrayCmd": 0x802bf824,
		"makeVtxArrayCmd": 0x802bf824,
		"J3DShape::makeVcdVatCmd": 0x802bfabc,
		"makeVcdVatCmd": 0x802bfabc,
		"J3DShape::loadVtxArray": 0x802bfb30,
		"loadVtxArray": 0x802bfb30,
		"J3DShape::draw": 0x802bfba0,
		"J3DShapeDraw::~J3DShapeDraw": 0x802bfd08,
		"J3DShapeMtxMulti::~J3DShapeMtxMulti": 0x802bfd54,
		"J3DShapeMtxMulti::getType": 0x802bfdb0,
		"J3DShapeMtxMulti::getUseMtxNum": 0x802bfdbc,
		"J3DShapeMtxMulti::getUseMtxIndex": 0x802bfdc4,
		"J3DShapeMtxDL::~J3DShapeMtxDL": 0x802bfdd4,
		"J3DShapeMtxDL::calcNBTScale": 0x802bfe30,
		"J3DShapeMtx::getType": 0x802bfe34,
		"JSystem::__sinit_J3DShape_cpp": 0x802bfe40,
		"__sinit_J3DShape_cpp": 0x802bfe40,
		"J3DSys::J3DSys": 0x802bfeac,
		"J3DSys::loadPosMtxIndx": 0x802bffc8,
		"loadPosMtxIndx": 0x802bffc8,
		"J3DSys::loadNrmMtxIndx": 0x802bfff0,
		"loadNrmMtxIndx": 0x802bfff0,
		"J3DSys::setTexCacheRegion": 0x802c0018,
		"setTexCacheRegion": 0x802c0018,
		"J3DSys::drawInit": 0x802c01d8,
		"drawInit": 0x802c01d8,
		"J3DSys::reinitTexture": 0x802c08a4,
		"reinitTexture": 0x802c08a4,
		"JSystem::__sinit_J3DSys_cpp": 0x802c0948,
		"__sinit_J3DSys_cpp": 0x802c0948,
		"J3DFrameCtrl::init": 0x802c0970,
		"J3DFrameCtrl::checkPass": 0x802c09a0,
		"checkPass": 0x802c09a0,
		"J3DFrameCtrl::update": 0x802c0f40,
		"J3DAnmBase::~J3DAnmBase": 0x802c13b8,
		"J3DAnmTransformFull::getTransform": 0x802c1404,
		"JSystem::J3DHermiteInterpolationS": 0x802c1af8,
		"J3DHermiteInterpolationS": 0x802c1af8,
		"JSystem::J3DGetKeyFrameInterpolationS": 0x802c1b4c,
		"J3DGetKeyFrameInterpolationS": 0x802c1b4c,
		"J3DAnmTransformKey::calcTransform": 0x802c1d7c,
		"J3DAnmTextureSRTKey::calcTransform": 0x802c2268,
		"J3DAnmClusterFull::getWeight": 0x802c252c,
		"J3DAnmClusterKey::getWeight": 0x802c2604,
		"J3DAnmVtxColorFull::getColor": 0x802c2688,
		"J3DAnmVtxColorKey::getColor": 0x802c29e0,
		"J3DAnmColor::searchUpdateMaterialID": 0x802c2d3c,
		"J3DAnmColorFull::getColor": 0x802c2dcc,
		"J3DAnmColorKey::getColor": 0x802c311c,
		"J3DAnmTexPattern::getTexNo": 0x802c3468,
		"J3DAnmTexPattern::searchUpdateMaterialID": 0x802c3554,
		"J3DAnmTextureSRTKey::searchUpdateMaterialID": 0x802c35e4,
		"J3DAnmTevRegKey::getTevColorReg": 0x802c3708,
		"getTevColorReg": 0x802c3708,
		"J3DAnmTevRegKey::getTevKonstReg": 0x802c3a54,
		"getTevKonstReg": 0x802c3a54,
		"J3DAnmTevRegKey::searchUpdateMaterialID": 0x802c3da0,
		"J3DAnmColorKey::~J3DAnmColorKey": 0x802c3e94,
		"J3DAnmColor::getColor": 0x802c3f00,
		"J3DAnmColor::~J3DAnmColor": 0x802c3f04,
		"J3DAnmColorFull::~J3DAnmColorFull": 0x802c3f60,
		"J3DAnmVtxColorKey::~J3DAnmVtxColorKey": 0x802c3fcc,
		"J3DAnmVtxColor::~J3DAnmVtxColor": 0x802c4038,
		"J3DAnmVtxColorFull::~J3DAnmVtxColorFull": 0x802c4094,
		"J3DAnmClusterKey::~J3DAnmClusterKey": 0x802c4100,
		"J3DAnmCluster::~J3DAnmCluster": 0x802c416c,
		"J3DAnmClusterFull::~J3DAnmClusterFull": 0x802c41c8,
		"J3DAnmTransformKey::~J3DAnmTransformKey": 0x802c4234,
		"J3DAnmTransform::~J3DAnmTransform": 0x802c42a0,
		"J3DAnmTransformFull::~J3DAnmTransformFull": 0x802c42fc,
		"J3DJointFactory::J3DJointFactory": 0x802c4830,
		"J3DJointFactory::create": 0x802c4888,
		"J3DMaterialFactory::J3DMaterialFactory": 0x802c4a5c,
		"J3DMaterialFactory::countUniqueMaterials": 0x802c4c90,
		"J3DMaterialFactory::countStages": 0x802c4ccc,
		"J3DMaterialFactory::create": 0x802c4db0,
		"J3DMaterialFactory::newMatColor": 0x802c56d4,
		"J3DMaterialFactory::newColorChanNum": 0x802c5764,
		"J3DMaterialFactory::newColorChan": 0x802c579c,
		"J3DMaterialFactory::newAmbColor": 0x802c5864,
		"newAmbColor": 0x802c5864,
		"J3DMaterialFactory::newTexGenNum": 0x802c58f4,
		"J3DMaterialFactory::newTexCoord": 0x802c592c,
		"J3DMaterialFactory::newTexMtx": 0x802c59a0,
		"J3DMaterialFactory::newCullMode": 0x802c5a34,
		"J3DMaterialFactory::newTexNo": 0x802c5a74,
		"J3DMaterialFactory::newTevOrder": 0x802c5abc,
		"J3DMaterialFactory::newTevColor": 0x802c5b30,
		"J3DMaterialFactory::newTevKColor": 0x802c5bc8,
		"J3DMaterialFactory::newTevStageNum": 0x802c5c58,
		"J3DMaterialFactory::newTevStage": 0x802c5c90,
		"J3DMaterialFactory::newTevSwapModeTable": 0x802c5efc,
		"J3DMaterialFactory::newIndTexStageNum": 0x802c5f98,
		"newIndTexStageNum": 0x802c5f98,
		"J3DMaterialFactory::newIndTexOrder": 0x802c5fc0,
		"newIndTexOrder": 0x802c5fc0,
		"J3DMaterialFactory::newIndTexMtx": 0x802c6020,
		"newIndTexMtx": 0x802c6020,
		"J3DMaterialFactory::newIndTevStage": 0x802c60e8,
		"newIndTevStage": 0x802c60e8,
		"J3DMaterialFactory::newIndTexCoordScale": 0x802c61cc,
		"newIndTexCoordScale": 0x802c61cc,
		"J3DMaterialFactory::newFog": 0x802c622c,
		"J3DMaterialFactory::newAlphaComp": 0x802c62b8,
		"J3DMaterialFactory::newBlend": 0x802c6338,
		"J3DMaterialFactory::newZMode": 0x802c63b4,
		"J3DMaterialFactory::newZCompLoc": 0x802c6418,
		"J3DMaterialFactory::newDither": 0x802c6450,
		"J3DMaterialFactory::newNBTScale": 0x802c6488,
		"J3DModelLoaderDataBase::load": 0x802c6710,
		"J3DModelLoader_v26::~J3DModelLoader_v26": 0x802c6834,
		"J3DModelLoader_v21::~J3DModelLoader_v21": 0x802c6890,
		"J3DModelLoader::~J3DModelLoader": 0x802c68ec,
		"J3DModelLoaderDataBase::loadMaterialTable": 0x802c6938,
		"J3DModelLoader::load": 0x802c6a58,
		"J3DModelLoader::readMaterial_v21": 0x802c6c7c,
		"J3DModelLoader::readMaterial": 0x802c6c80,
		"J3DModelLoader::loadMaterialTable": 0x802c6c84,
		"J3DModelLoader::readMaterialTable_v21": 0x802c6dc8,
		"J3DModelLoader::readMaterialTable": 0x802c6dcc,
		"J3DModelLoader::setupBBoardInfo": 0x802c6dd0,
		"setupBBoardInfo": 0x802c6dd0,
		"J3DModelLoader::readInformation": 0x802c6f1c,
		"readInformation": 0x802c6f1c,
		"J3DModelLoader::readVertex": 0x802c70e0,
		"readVertex": 0x802c70e0,
		"J3DModelLoader::readEnvelop": 0x802c72dc,
		"readEnvelop": 0x802c72dc,
		"J3DModelLoader::readDraw": 0x802c736c,
		"readDraw": 0x802c736c,
		"J3DModelLoader::readJoint": 0x802c7400,
		"readJoint": 0x802c7400,
		"J3DModelLoader_v26::readMaterial": 0x802c74f0,
		"J3DMaterial::~J3DMaterial": 0x802c7748,
		"J3DMaterial::J3DMaterial": 0x802c7788,
		"J3DModelLoader_v21::readMaterial_v21": 0x802c77b8,
		"J3DModelLoader::readShape": 0x802c7a10,
		"readShape": 0x802c7a10,
		"J3DModelLoader::readTexture": 0x802c7b58,
		"readTexture": 0x802c7b58,
		"J3DModelLoader_v26::readMaterialTable": 0x802c7c10,
		"J3DModelLoader_v21::readMaterialTable_v21": 0x802c7d54,
		"J3DModelLoader::readTextureTable": 0x802c7e98,
		"readTextureTable": 0x802c7e98,
		"J3DTexture::~J3DTexture": 0x802c7f50,
		"J3DShapeFactory::J3DShapeFactory": 0x802c802c,
		"J3DShapeFactory::create": 0x802c80dc,
		"J3DShapeFactory::newShapeMtx": 0x802c8294,
		"newShapeMtx": 0x802c8294,
		"J3DShapeFactory::newShapeDraw": 0x802c8388,
		"newShapeDraw": 0x802c8388,
		"J3DShapeFactory::allocVcdVatCmdBuffer": 0x802c841c,
		"allocVcdVatCmdBuffer": 0x802c841c,
		"J3DAnmLoaderDataBase::load": 0x802c84b4,
		"J3DAnmVtxColor::J3DAnmVtxColor": 0x802c8bb4,
		"J3DAnmColor::J3DAnmColor": 0x802c8c0c,
		"J3DAnmFullLoader_v15::J3DAnmFullLoader_v15": 0x802c8c70,
		"J3DAnmLoader::~J3DAnmLoader": 0x802c8c8c,
		"J3DAnmFullLoader_v15::~J3DAnmFullLoader_v15": 0x802c8cd8,
		"J3DAnmKeyLoader_v15::J3DAnmKeyLoader_v15": 0x802c8d34,
		"J3DAnmKeyLoader_v15::~J3DAnmKeyLoader_v15": 0x802c8d50,
		"J3DAnmFullLoader_v15::load": 0x802c8dac,
		"J3DAnmFullLoader_v15::readAnmTransform": 0x802c8ed8,
		"J3DAnmFullLoader_v15::readAnmColor": 0x802c8f6c,
		"J3DAnmFullLoader_v15::readAnmTexPattern": 0x802c9054,
		"readAnmTexPattern": 0x802c9054,
		"J3DAnmFullLoader_v15::readAnmVisibility": 0x802c9114,
		"readAnmVisibility": 0x802c9114,
		"J3DAnmFullLoader_v15::readAnmCluster": 0x802c9190,
		"J3DAnmFullLoader_v15::readAnmVtxColor": 0x802c91fc,
		"J3DAnmKeyLoader_v15::load": 0x802c9374,
		"J3DAnmKeyLoader_v15::readAnmTransform": 0x802c94a0,
		"J3DAnmKeyLoader_v15::readAnmTextureSRT": 0x802c953c,
		"readAnmTextureSRT": 0x802c953c,
		"J3DAnmKeyLoader_v15::readAnmColor": 0x802c9738,
		"J3DAnmKeyLoader_v15::readAnmCluster": 0x802c9840,
		"J3DAnmKeyLoader_v15::readAnmTevReg": 0x802c98ac,
		"readAnmTevReg": 0x802c98ac,
		"J3DAnmKeyLoader_v15::readAnmVtxColor": 0x802c9a68,
		"J3DAnmVisibilityFull::~J3DAnmVisibilityFull": 0x802c9be0,
		"J3DAnmTexPattern::~J3DAnmTexPattern": 0x802c9c44,
		"J3DAnmTevRegKey::~J3DAnmTevRegKey": 0x802c9ca8,
		"J3DAnmTextureSRTKey::~J3DAnmTextureSRTKey": 0x802c9d0c,
		"JGadget::TList_pointer_void::TList_pointer_void": 0x802c9ea8,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::erase": 0x802c9ec8,
		"JGadget::TList_pointer_void::~TList_pointer_void": 0x802c9f34,
		"JGadget::TList_pointer_void::insert": 0x802ca010,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::CreateNode_": 0x802ca098,
		"CreateNode_": 0x802ca098,
		"JSystem::JKRDecompressFromDVD": 0x802ca650,
		"JKRDecompressFromDVD": 0x802ca650,
		"JKRDvdRipper::isErrorRetry": 0x802cabc4,
		"isErrorRetry": 0x802cabc4,
		"JSystem::__sinit_JKRDvdRipper_cpp": 0x802cabcc,
		"__sinit_JKRDvdRipper_cpp": 0x802cabcc,
		"JSUList<JKRDMCommand>::~JSUList": 0x802cac18,
		"J2DGrafContext::setPort": 0x802cae00,
		"J2DGrafContext::setup2D": 0x802caecc,
		"setup2D": 0x802caecc,
		"J2DGrafContext::setScissor": 0x802cb078,
		"setScissor": 0x802cb078,
		"J2DGrafContext::scissor": 0x802cb130,
		"scissor": 0x802cb130,
		"J2DGrafContext::setColor": 0x802cb198,
		"J2DGrafContext::setLineWidth": 0x802cb254,
		"setLineWidth": 0x802cb254,
		"J2DGrafContext::fillBox": 0x802cb280,
		"fillBox": 0x802cb280,
		"J2DGrafContext::setLookat": 0x802cb3ac,
		"JKRDvdAramRipper::loadToAram_Async": 0x802cb554,
		"loadToAram_Async": 0x802cb554,
		"JKRDvdAramRipper::callCommand_Async": 0x802cb600,
		"callCommand_Async": 0x802cb600,
		"JKRDvdAramRipper::syncAram": 0x802cb92c,
		"syncAram": 0x802cb92c,
		"JKRADCommand::JKRADCommand": 0x802cb9fc,
		"JKRADCommand::~JKRADCommand": 0x802cba38,
		"JSystem::JKRDecompressFromDVDToAram": 0x802cbac4,
		"JKRDecompressFromDVDToAram": 0x802cbac4,
		"JSystem::dmaBufferFlush": 0x802cc024,
		"dmaBufferFlush": 0x802cc024,
		"JSystem::__sinit_JKRDvdAramRipper_cpp": 0x802cc08c,
		"__sinit_JKRDvdAramRipper_cpp": 0x802cc08c,
		"JSUList<JKRADCommand>::~JSUList": 0x802cc0d8,
		"JKRDecomp::create": 0x802cc130,
		"JKRDecomp::JKRDecomp": 0x802cc18c,
		"JKRDecomp::~JKRDecomp": 0x802cc1e4,
		"JKRDecomp::run": 0x802cc248,
		"JKRDecomp::sendCommand": 0x802cc308,
		"JKRDecomp::orderSync": 0x802cc338,
		"JKRDecomp::decode": 0x802cc3e0,
		"decode": 0x802cc3e0,
		"JKRDecomp::decodeSZP": 0x802cc46c,
		"decodeSZP": 0x802cc46c,
		"JKRDecomp::decodeSZS": 0x802cc618,
		"decodeSZS": 0x802cc618,
		"JKRDecomp::checkCompressed": 0x802cc6fc,
		"checkCompressed": 0x802cc6fc,
		"JKRDecompCommand::JKRDecompCommand": 0x802cc74c,
		"JKRDecompCommand::~JKRDecompCommand": 0x802cc79c,
		"J2DOrthoGraph::setPort": 0x802cc990,
		"J2DOrthoGraph::setLookat": 0x802cca48,
		"J2DOrthoGraph::scissorBounds": 0x802cca84,
		"scissorBounds": 0x802cca84,
		"J3DVertexData::J3DVertexData": 0x802cce24,
		"J3DVertexData::~J3DVertexData": 0x802cce70,
		"J3DVertexBuffer::J3DVertexBuffer": 0x802cceb0,
		"J3DVertexBuffer::~J3DVertexBuffer": 0x802ccf1c,
		"J3DVertexBuffer::copyTransformedVtxArray": 0x802ccf68,
		"copyTransformedVtxArray": 0x802ccf68,
		"J3DDrawMtxData::J3DDrawMtxData": 0x802cd038,
		"J3DDrawMtxData::~J3DDrawMtxData": 0x802cd04c,
		"J3DDisplayListObj::newDisplayList": 0x802cd08c,
		"newDisplayList": 0x802cd08c,
		"J3DDisplayListObj::callDL": 0x802cd0e8,
		"callDL": 0x802cd0e8,
		"J3DPacket::isSame": 0x802cd114,
		"J3DPacket::entry": 0x802cd11c,
		"J3DPacket::addChildPacket": 0x802cd124,
		"addChildPacket": 0x802cd124,
		"J3DCallBackPacket::draw": 0x802cd144,
		"J3DPacket::draw": 0x802cd1d4,
		"J3DPacket::~J3DPacket": 0x802cd1d8,
		"J3DDrawPacket::~J3DDrawPacket": 0x802cd224,
		"J3DDrawPacket::draw": 0x802cd280,
		"J3DDrawPacket::beginDL": 0x802cd2ac,
		"beginDL": 0x802cd2ac,
		"J3DDrawPacket::endDL": 0x802cd30c,
		"endDL": 0x802cd30c,
		"J3DMatPacket::J3DMatPacket": 0x802cd368,
		"J3DMatPacket::~J3DMatPacket": 0x802cd3bc,
		"J3DMatPacket::addShapePacket": 0x802cd428,
		"addShapePacket": 0x802cd428,
		"J3DMatPacket::draw": 0x802cd448,
		"J3DShapePacket::J3DShapePacket": 0x802cd4e8,
		"J3DCallBackPacket::~J3DCallBackPacket": 0x802cd54c,
		"J3DShapePacket::~J3DShapePacket": 0x802cd5a8,
		"J3DShapePacket::draw": 0x802cd614,
		"J3DMatPacket::isSame": 0x802cd6d8,
		"JSystem::J3DLoadArrayBasePtr": 0x802cd6fc,
		"J3DLoadArrayBasePtr": 0x802cd6fc,
		"JSystem::J3DSetVtxAttrFmtv": 0x802cd730,
		"J3DSetVtxAttrFmtv": 0x802cd730,
		"JSystem::loadCullMode": 0x802cdcbc,
		"loadCullMode": 0x802cdcbc,
		"J3DLightObj::load": 0x802cdcc0,
		"J3DTexMtx::calc": 0x802cdd54,
		"J3DTexMtx::load": 0x802ce1e4,
		"JSystem::loadTexNo": 0x802ce214,
		"loadTexNo": 0x802ce214,
		"JSystem::loadDither": 0x802ce55c,
		"loadDither": 0x802ce55c,
		"JSystem::loadNBTScale": 0x802ce560,
		"loadNBTScale": 0x802ce560,
		"JSystem::makeTexCoordTable": 0x802ce594,
		"makeTexCoordTable": 0x802ce594,
		"JSystem::makeAlphaCmpTable": 0x802ce780,
		"makeAlphaCmpTable": 0x802ce780,
		"JSystem::makeZModeTable": 0x802ceb28,
		"makeZModeTable": 0x802ceb28,
		"JSystem::makeTevSwapTable": 0x802cec60,
		"makeTevSwapTable": 0x802cec60,
		"J3DDrawBuffer::J3DDrawBuffer": 0x802cedd4,
		"J3DDrawBuffer::frameInit": 0x802cee7c,
		"frameInit": 0x802cee7c,
		"J3DDrawBuffer::entryMatSort": 0x802ceeb4,
		"entryMatSort": 0x802ceeb4,
		"J3DDrawBuffer::entryMatAnmSort": 0x802cf00c,
		"entryMatAnmSort": 0x802cf00c,
		"J3DDrawBuffer::entryZSort": 0x802cf0cc,
		"entryZSort": 0x802cf0cc,
		"J3DDrawBuffer::entryModelSort": 0x802cf1cc,
		"entryModelSort": 0x802cf1cc,
		"J3DDrawBuffer::entryInvalidSort": 0x802cf21c,
		"entryInvalidSort": 0x802cf21c,
		"J3DDrawBuffer::entryNonSort": 0x802cf270,
		"entryNonSort": 0x802cf270,
		"J3DDrawBuffer::entryImm": 0x802cf2a4,
		"entryImm": 0x802cf2a4,
		"J3DDrawBuffer::draw": 0x802cf2c4,
		"J3DDrawBuffer::drawHead": 0x802cf318,
		"drawHead": 0x802cf318,
		"J3DDrawBuffer::drawTail": 0x802cf3a4,
		"drawTail": 0x802cf3a4,
		"JSystem::__sinit_J3DDrawBuffer_cpp": 0x802cf430,
		"__sinit_J3DDrawBuffer_cpp": 0x802cf430,
		"J3DTexNoAnm::calc": 0x802cf4fc,
		"J3DMaterialAnm::initialize": 0x802cf52c,
		"J3DMaterialAnm::calc": 0x802cf59c,
		"J3DMaterialAnm::~J3DMaterialAnm": 0x802cf790,
		"JGadget::TVector_pointer_void::TVector_pointer_void": 0x802cf7dc,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::DestroyElement_": 0x802cf808,
		"std::__copy<void*,1,0>::copy": 0x802cf81c,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::InsertRaw": 0x802cf8d8,
		"JGadget::TVector_pointer_void::~TVector_pointer_void": 0x802cfbcc,
		"JGadget::TVector<void*,JGadget::TAllocator<void*>>::erase": 0x802cfc34,
		"JGadget::TVector_pointer_void::insert": 0x802cfc9c,
		"JGadget::TVector_pointer_void::reserve": 0x802cfd14,
		"reserve": 0x802cfd14,
		"JKRAramBlock::JKRAramBlock": 0x802cfdec,
		"JKRAramBlock::~JKRAramBlock": 0x802cfe58,
		"JKRAramBlock::allocHead": 0x802cff14,
		"allocHead": 0x802cff14,
		"JKRAramBlock::allocTail": 0x802cffb0,
		"allocTail": 0x802cffb0,
		"JKRAramPiece::sendCommand": 0x802d0054,
		"JKRAramPiece::orderAsync": 0x802d0074,
		"orderAsync": 0x802d0074,
		"JKRAramPiece::orderSync": 0x802d01c8,
		"JKRAramPiece::startDMA": 0x802d0278,
		"startDMA": 0x802d0278,
		"JKRAramPiece::doneDMA": 0x802d02f0,
		"doneDMA": 0x802d02f0,
		"JKRAMCommand::JKRAMCommand": 0x802d0398,
		"JKRAMCommand::~JKRAMCommand": 0x802d040c,
		"JSystem::__sinit_JKRAramPiece_cpp": 0x802d04b4,
		"__sinit_JKRAramPiece_cpp": 0x802d04b4,
		"JKRAramStream::create": 0x802d0500,
		"JKRAramStream::JKRAramStream": 0x802d056c,
		"JKRAramStream::~JKRAramStream": 0x802d05c4,
		"JKRAramStream::run": 0x802d0628,
		"JKRAramStream::readFromAram": 0x802d0690,
		"readFromAram": 0x802d0690,
		"JKRAramStream::writeToAram": 0x802d0698,
		"writeToAram": 0x802d0698,
		"JKRAramStream::write_StreamToAram_Async": 0x802d0868,
		"write_StreamToAram_Async": 0x802d0868,
		"JKRAramStream::sync": 0x802d0924,
		"JKRAramStream::setTransBuffer": 0x802d09b8,
		"setTransBuffer": 0x802d09b8,
		"JKRAramStreamCommand::JKRAramStreamCommand": 0x802d0a0c,
		"JUTAssertion::flushMessage": 0x802d0a18,
		"flushMessage": 0x802d0a18,
		"JUTFont::isLeadByte_1Byte": 0x802d0ab0,
		"isLeadByte_1Byte": 0x802d0ab0,
		"JUTFont::isLeadByte_2Byte": 0x802d0ab8,
		"isLeadByte_2Byte": 0x802d0ab8,
		"JUTFont::isLeadByte_ShiftJIS": 0x802d0ac0,
		"isLeadByte_ShiftJIS": 0x802d0ac0,
		"JUTResFont::JUTResFont": 0x802d0b10,
		"JUTResFont::~JUTResFont": 0x802d0b8c,
		"JUTResFont::initiate": 0x802d0c28,
		"JUTResFont::protected_initiate": 0x802d0cb4,
		"protected_initiate": 0x802d0cb4,
		"JUTResFont::countBlock": 0x802d0d64,
		"countBlock": 0x802d0d64,
		"JUTResFont::setBlock": 0x802d0e5c,
		"setBlock": 0x802d0e5c,
		"JUTResFont::drawChar_scale": 0x802d1310,
		"JUTResFont::getDescent": 0x802d1720,
		"JUTResFont::getHeight": 0x802d172c,
		"JUTResFont::getAscent": 0x802d1788,
		"JUTResFont::loadFont": 0x802d1794,
		"loadFont": 0x802d1794,
		"JUTResFont::getWidthEntry": 0x802d1894,
		"JUTResFont::isLeadByte": 0x802d1930,
		"JUTResFont::getFontCode": 0x802d1960,
		"getFontCode": 0x802d1960,
		"JUTResFont::getFontType": 0x802d1ae0,
		"JUTResFont::loadImage": 0x802d1aec,
		"JUTResFont::convertSjis": 0x802d1c60,
		"convertSjis": 0x802d1c60,
		"JUTResFont::getLeading": 0x802d1c90,
		"JUTRomFont::JUTRomFont": 0x802d1c9c,
		"JUTRomFont::initiate": 0x802d1cf8,
		"JUTRomFont::~JUTRomFont": 0x802d1d3c,
		"JUTRomFont::loadImage": 0x802d1dd8,
		"JUTRomFont::setGX": 0x802d1eac,
		"JUTRomFont::drawChar_scale": 0x802d1f84,
		"JUTRomFont::getDescent": 0x802d23d8,
		"JUTRomFont::getAscent": 0x802d23e4,
		"JUTRomFont::getHeight": 0x802d23f0,
		"JUTRomFont::getWidth": 0x802d244c,
		"JUTRomFont::getWidthEntry": 0x802d2458,
		"JUTRomFont::isLeadByte": 0x802d24c0,
		"JUTRomFont::getLeading": 0x802d24f0,
		"JUTRomFont::getResFont": 0x802d24fc,
		"getResFont": 0x802d24fc,
		"JUTRomFont::getFontType": 0x802d2504,
		"JSystem::J3DGDLoadTexMtxImm": 0x802d2510,
		"J3DGDLoadTexMtxImm": 0x802d2510,
		"JSystem::J3DGDSetChanAmbColor": 0x802d2bb8,
		"J3DGDSetChanAmbColor": 0x802d2bb8,
		"JSystem::J3DGDSetChanMatColor": 0x802d2cfc,
		"J3DGDSetChanMatColor": 0x802d2cfc,
		"JSystem::J3DGDSetChanCtrl": 0x802d2e40,
		"J3DGDSetChanCtrl": 0x802d2e40,
		"JSystem::J3DGDSetTexCoordGen": 0x802d30ac,
		"J3DGDSetTexCoordGen": 0x802d30ac,
		"JSystem::J3DGDSetFog": 0x802d3414,
		"J3DGDSetFog": 0x802d3414,
		"JSystem::J3DGDSetTexCoordScale2": 0x802d3790,
		"J3DGDSetTexCoordScale2": 0x802d3790,
		"JSystem::J3DGDSetTexImgAttr": 0x802d398c,
		"J3DGDSetTexImgAttr": 0x802d398c,
		"JSystem::J3DGDSetTexImgPtr": 0x802d3a70,
		"J3DGDSetTexImgPtr": 0x802d3a70,
		"JSystem::J3DGDSetTexTlut": 0x802d3b3c,
		"J3DGDSetTexTlut": 0x802d3b3c,
		"JSystem::J3DGDLoadTlut": 0x802d3c10,
		"J3DGDLoadTlut": 0x802d3c10,
		"JSystem::J3DGDSetTevKColor": 0x802d3fc8,
		"J3DGDSetTevKColor": 0x802d3fc8,
		"JSystem::JRNLoadCurrentMtx": 0x802d4130,
		"JRNLoadCurrentMtx": 0x802d4130,
		"JSystem::JRNSetTevIndirect": 0x802d41c8,
		"JRNSetTevIndirect": 0x802d41c8,
		"JSystem::JRNSetIndTexMtx": 0x802d42f0,
		"JRNSetIndTexMtx": 0x802d42f0,
		"JSystem::JRNSetIndTexCoordScale": 0x802d45c8,
		"JRNSetIndTexCoordScale": 0x802d45c8,
		"JSystem::JRNSetIndTexOrder": 0x802d46b8,
		"JRNSetIndTexOrder": 0x802d46b8,
		"JSystem::JRNLoadTexCached": 0x802d48cc,
		"JRNLoadTexCached": 0x802d48cc,
		"JSystem::JRNISetTevOrder": 0x802d494c,
		"JRNISetTevOrder": 0x802d494c,
		"JSystem::JRNISetTevColorS10": 0x802d4abc,
		"JRNISetTevColorS10": 0x802d4abc,
		"JSystem::JRNISetFogRangeAdj": 0x802d4cf0,
		"JRNISetFogRangeAdj": 0x802d4cf0,
		"JUTConsole::create": 0x802d4e9c,
		"JUTConsole::JUTConsole": 0x802d4f34,
		"JUTConsole::~JUTConsole": 0x802d5038,
		"JUTConsole::getLineFromObjectSize": 0x802d50a8,
		"getLineFromObjectSize": 0x802d50a8,
		"JUTConsole::clear": 0x802d50b8,
		"JUTConsole::doDraw": 0x802d5114,
		"doDraw": 0x802d5114,
		"JUTConsole::print_f": 0x802d55b8,
		"print_f": 0x802d55b8,
		"JUTConsole::print": 0x802d5638,
		"JSystem::JUTConsole_print_f_va_": 0x802d5848,
		"JUTConsole_print_f_va_": 0x802d5848,
		"JUTConsole::scroll": 0x802d5890,
		"scroll": 0x802d5890,
		"JUTConsole::getUsedLine": 0x802d596c,
		"getUsedLine": 0x802d596c,
		"JUTConsole::getLineOffset": 0x802d5990,
		"getLineOffset": 0x802d5990,
		"JUTConsoleManager::JUTConsoleManager": 0x802d59b4,
		"JUTConsoleManager::createManager": 0x802d59dc,
		"createManager": 0x802d59dc,
		"JUTConsoleManager::appendConsole": 0x802d5a24,
		"appendConsole": 0x802d5a24,
		"JUTConsoleManager::removeConsole": 0x802d5ac0,
		"removeConsole": 0x802d5ac0,
		"JGadget::TNodeLinkList::end": 0x802d5b98,
		"JGadget::TLinkList<10JUTConsole,-24>::iterator::iterator": 0x802d5ba4,
		"JUTConsoleManager::drawDirect": 0x802d5bb0,
		"drawDirect": 0x802d5bb0,
		"JUTConsoleManager::setDirectConsole": 0x802d5c30,
		"setDirectConsole": 0x802d5c30,
		"JGadget::TLinkListNode::getNext": 0x802d5de0,
		"getNext": 0x802d5de0,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getValue": 0x802d5de8,
		"Element_getValue": 0x802d5de8,
		"JGadget::TNodeLinkList::iterator::operator_->": 0x802d5df0,
		"operator_->": 0x802d5df0,
		"JGadget::TLinkListNode::getPrev": 0x802d5df8,
		"getPrev": 0x802d5df8,
		"JGadget::TLinkList<JUTConsole,undefined,4>::Element_getNode": 0x802d5e00,
		"JSystem::JUTSetReportConsole": 0x802d5e08,
		"JUTSetReportConsole": 0x802d5e08,
		"JSystem::JUTGetReportConsole": 0x802d5e10,
		"JUTGetReportConsole": 0x802d5e10,
		"JSystem::JUTSetWarningConsole": 0x802d5e18,
		"JUTSetWarningConsole": 0x802d5e18,
		"JSystem::JUTGetWarningConsole": 0x802d5e20,
		"JUTGetWarningConsole": 0x802d5e20,
		"JSystem::JUTReportConsole_f": 0x802d5e28,
		"JUTReportConsole_f": 0x802d5e28,
		"JSystem::JUTReportConsole": 0x802d5eec,
		"JUTReportConsole": 0x802d5eec,
		"JSystem::JUTWarningConsole_f": 0x802d5f18,
		"JUTWarningConsole_f": 0x802d5f18,
		"JSystem::JUTWarningConsole": 0x802d5fdc,
		"JUTWarningConsole": 0x802d5fdc,
		"JUTDirectFile::JUTDirectFile": 0x802d6008,
		"JUTDirectFile::~JUTDirectFile": 0x802d602c,
		"JUTDirectFile::fopen": 0x802d6074,
		"fopen": 0x802d6074,
		"JUTDirectFile::fclose": 0x802d6118,
		"fclose": 0x802d6118,
		"JUTDirectFile::fgets": 0x802d6174,
		"fgets": 0x802d6174,
		"JGadget::TNodeLinkList::Insert": 0x802d63ac,
		"JGadget::TNodeLinkList::Erase": 0x802d63d8,
		"Erase": 0x802d63d8,
		"JGadget::TNodeLinkList::Remove": 0x802d63fc,
		"Remove": 0x802d63fc,
		"JGadget::TNodeLinkList::Remove_if": 0x802d644c,
		"Remove_if": 0x802d644c,
		"JGadget::TSingleNodeLinkList::~TSingleNodeLinkList": 0x802d656c,
		"JGadget::TSingleNodeLinkList::Insert": 0x802d65ac,
		"JDrama::TActor::load": 0x802d65e0,
		"JDrama::TActor::perform": 0x802d6734,
		"JDrama::TPolarCamera::load": 0x802d6990,
		"JDrama::TPolarCamera::perform": 0x802d69f8,
		"JDrama::TLookAtCamera::perform": 0x802d6e64,
		"JDrama::TOrthoProj::load": 0x802d6fdc,
		"JDrama::TOrthoProj::perform": 0x802d7054,
		"JDrama::TSmplChara::load": 0x802d7440,
		"JDrama::TSmplChara::~TSmplChara": 0x802d7494,
		"JDrama::TSmplChara::getRes": 0x802d7528,
		"JDrama::TSmplChara::mountArc": 0x802d7558,
		"mountArc": 0x802d7558,
		"JDrama::TDirector::searchF": 0x802d7598,
		"JDrama::TDirector::direct": 0x802d764c,
		"JDrama::TDisplay::TDisplay": 0x802d77d0,
		"JDrama::TDisplay::startRendering": 0x802d78fc,
		"startRendering": 0x802d78fc,
		"JDrama::TDisplay::endRendering": 0x802d79f4,
		"endRendering": 0x802d79f4,
		"JDrama::TDrawBufObj::load": 0x802d7bb8,
		"JDrama::TDrawBufObj::perform": 0x802d7c30,
		"JDrama::TDStageDisp::TDStageDisp": 0x802d7cd4,
		"JDrama::TViewConnecter::~TViewConnecter": 0x802d7e30,
		"JDrama::TDStageDisp::getEfbCtrlDisp": 0x802d7ea4,
		"getEfbCtrlDisp": 0x802d7ea4,
		"JDrama::TDStageDisp::~TDStageDisp": 0x802d7eac,
		"JDrama::TDStageGroup::perform": 0x802d7f30,
		"JDrama::TDStageGroup::~TDStageGroup": 0x802d7fc4,
		"JDrama::TEfbCtrl::perform": 0x802d8098,
		"JDrama::TEfbCtrl::setSrcRect": 0x802d8170,
		"setSrcRect": 0x802d8170,
		"JDrama::TEfbCtrlDisp::perform": 0x802d8228,
		"JDrama::TEfbCtrlTex::TEfbCtrlTex": 0x802d8380,
		"JDrama::TEfbCtrlTex::setTexAttb": 0x802d8464,
		"setTexAttb": 0x802d8464,
		"JDrama::TEfbCtrlTex::perform": 0x802d84d0,
		"JDrama::TEfbCtrlTex::~TEfbCtrlTex": 0x802d86c8,
		"JDrama::TEfbCtrlDisp::~TEfbCtrlDisp": 0x802d874c,
		"JDrama::DecidePixelFmt": 0x802d87d0,
		"DecidePixelFmt": 0x802d87d0,
		"JDrama::IssueGXSetCopyFilter": 0x802d8978,
		"IssueGXSetCopyFilter": 0x802d8978,
		"JDrama::IssueGXSetCopyClear": 0x802d89c8,
		"IssueGXSetCopyClear": 0x802d89c8,
		"JDrama::IssueGXCopyDisp": 0x802d8aa0,
		"IssueGXCopyDisp": 0x802d8aa0,
		"JDrama::TFrmGXSet::perform": 0x802d8c34,
		"JDrama::TGraphics::setViewport": 0x802d8e58,
		"setViewport": 0x802d8e58,
		"JDrama::TLight::load": 0x802d8fdc,
		"JDrama::TLight::perform": 0x802d9040,
		"JDrama::TLight::correct": 0x802d9098,
		"correct": 0x802d9098,
		"JDrama::TLightAry::load": 0x802d919c,
		"JDrama::TLightAry::searchF": 0x802d9294,
		"JDrama::TLightAry::setLightNum": 0x802d9324,
		"setLightNum": 0x802d9324,
		"JDrama::TIdxLight::TIdxLight": 0x802d9470,
		"JDrama::TLightAry::perform": 0x802d9638,
		"JDrama::TAmbColor::load": 0x802d96d8,
		"JDrama::TAmbColor::perform": 0x802d9728,
		"JDrama::TAmbAry::load": 0x802d9784,
		"JDrama::TAmbAry::searchF": 0x802d987c,
		"JDrama::TAmbAry::setAmbNum": 0x802d990c,
		"setAmbNum": 0x802d990c,
		"JDrama::TAmbColor::TAmbColor": 0x802d9a04,
		"JDrama::TLightMap::load": 0x802d9aa8,
		"JDrama::TLightMap::TLightInfo::TLightInfo": 0x802d9b9c,
		"JDrama::TLightMap::perform": 0x802d9bac,
		"JDrama::TLightMap::~TLightMap": 0x802d9c44,
		"JDrama::TAmbAry::~TAmbAry": 0x802d9cb8,
		"JDrama::TAmbAry::perform": 0x802d9d2c,
		"JDrama::TLightAry::~TLightAry": 0x802d9d30,
		"JDrama::TNameRef::calcKeyCode": 0x802d9dfc,
		"JDrama::TNameRef::genObject": 0x802d9ebc,
		"genObject": 0x802d9ebc,
		"JDrama::TNameRef::~TNameRef": 0x802d9f6c,
		"JDrama::TNameRef::load": 0x802d9fc0,
		"JDrama::TNameRef::save": 0x802da018,
		"JDrama::TNameRef::loadAfter": 0x802da01c,
		"JDrama::TNameRef::searchF": 0x802da020,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadSuper": 0x802da090,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfterSuper": 0x802da0b0,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::searchF": 0x802da0d0,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::loadAfter": 0x802da1b8,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::load": 0x802da264,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::perform": 0x802da3a0,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::searchF": 0x802da45c,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::loadAfter": 0x802da544,
		"JDrama::TViewObjPtrListT<JDrama::TViewObj,JDrama::TViewObj>::load": 0x802da5fc,
		"JDrama::TNameRefGen::load": 0x802da744,
		"JDrama::TNameRefGen::getNameRef": 0x802da830,
		"JDrama::TLight::TLight": 0x802dae78,
		"JDrama::TCamera::TCamera": 0x802daf80,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::~TNameRefPtrListT": 0x802db04c,
		"~TNameRefPtrListT": 0x802db04c,
		"JDrama::TPlacement::load": 0x802db0c4,
		"JDrama::IsEqualRenderModeVIParams": 0x802db12c,
		"IsEqualRenderModeVIParams": 0x802db12c,
		"JDrama::IsRenderModeHalfAspectRatio": 0x802db24c,
		"IsRenderModeHalfAspectRatio": 0x802db24c,
		"JDrama::GetRenderModeYScale": 0x802db268,
		"GetRenderModeYScale": 0x802db268,
		"JDrama::CalcRenderModeXFBHeight": 0x802db30c,
		"CalcRenderModeXFBHeight": 0x802db30c,
		"JDrama::CalcRenderModeVIXOrigin": 0x802db3ec,
		"CalcRenderModeVIXOrigin": 0x802db3ec,
		"JDrama::CalcRenderModeVIYOrigin": 0x802db438,
		"CalcRenderModeVIYOrigin": 0x802db438,
		"JDrama::CopyRenderModeSamplePattern": 0x802db484,
		"CopyRenderModeSamplePattern": 0x802db484,
		"JDrama::CopyRenderModeVFilter": 0x802db4ac,
		"CopyRenderModeVFilter": 0x802db4ac,
		"TCamConnecter::perform": 0x802db564,
		"JDrama::TScreen::TScreen": 0x802db600,
		"JDrama::TScreen::assignCamera": 0x802db6d8,
		"assignCamera": 0x802db6d8,
		"JDrama::TScreen::assignViewObj": 0x802db6e4,
		"assignViewObj": 0x802db6e4,
		"JDrama::TScreen::~TScreen": 0x802db6f0,
		"TCamConnecter::~TCamConnecter": 0x802db774,
		"JDrama::TSmJ3DAct::load": 0x802db7f8,
		"JDrama::TSmJ3DAct::perform": 0x802db8fc,
		"JDrama::TSmJ3DScn::TSmJ3DScn": 0x802dbe3c,
		"JDrama::TSmJ3DScn::perform": 0x802dbf40,
		"JDrama::TSmJ3DScn::loadSuper": 0x802dc054,
		"JDrama::TSmJ3DScn::~TSmJ3DScn": 0x802dc108,
		"JDrama::TVideo::TVideo": 0x802dc1a4,
		"JDrama::TVideo::setNextXFB": 0x802dc298,
		"setNextXFB": 0x802dc298,
		"JDrama::TVideo::waitForRetrace": 0x802dc2a0,
		"waitForRetrace": 0x802dc2a0,
		"JDrama::TViewConnecter::TViewConnecter": 0x802dc468,
		"JDrama::TViewConnecter::perform": 0x802dc504,
		"JDrama::TViewObj::testPerform": 0x802dc5a0,
		"testPerform": 0x802dc5a0,
		"JDrama::TViewport::TViewport": 0x802dc608,
		"JDrama::TViewport::perform": 0x802dc698,
		"JDrama::TViewport::load": 0x802dc748,
		"JDrama::TViewport::~TViewport": 0x802dc7c0,
		"JALCalc::linearTransform": 0x802dc834,
		"linearTransform": 0x802dc834,
		"JALCalc::getParamByExp": 0x802dc8a8,
		"getParamByExp": 0x802dc8a8,
		"JALCalc::getRandom": 0x802dc9fc,
		"getRandom": 0x802dc9fc,
		"JALCalc::getRandom_0_1": 0x802dca90,
		"getRandom_0_1": 0x802dca90,
		"JALCalc::getDist": 0x802dcb04,
		"getDist": 0x802dcb04,
		"JALCalc::getDistPow": 0x802dcb7c,
		"getDistPow": 0x802dcb7c,
		"JALSystem::init": 0x802dcc50,
		"JALSystem::gateCheckFunc": 0x802dcc90,
		"gateCheckFunc": 0x802dcc90,
		"JALSystem::processModFunc": 0x802dce04,
		"processModFunc": 0x802dce04,
		"JALSystem::processModDistVolume": 0x802dd004,
		"processModDistVolume": 0x802dd004,
		"JALSystem::append": 0x802dd0b0,
		"JSUList<JALSeModDataGrpMemb>::JSUList": 0x802dd67c,
		"JALSystem::appendGrpMember": 0x802dd6ac,
		"appendGrpMember": 0x802dd6ac,
		"JALSystem::TFlagManager::TFlagManager": 0x802dd97c,
		"JALSystem::TFlagManager::addUseFlag": 0x802ddac4,
		"addUseFlag": 0x802ddac4,
		"JALSystem::TFlagManager::isRegistered": 0x802ddae0,
		"isRegistered": 0x802ddae0,
		"JALSeModDataGrp<JALSeModVolDGrp>::calcGrp": 0x802ddb0c,
		"JALSeModDataGrp<JALSeModEffFGrp>::calcGrp": 0x802ddb70,
		"JALSeModDataGrp<JALSeModEffFGrp>::gateCheckGrp": 0x802ddbd4,
		"JALSeModDataGrp<JALSeModPitFGrp>::gateCheckGrp": 0x802ddc24,
		"JALSeModDataGrp<JALSeModVolFGrp>::calcGrp": 0x802ddc74,
		"JALSeModDataGrp<JALSeModVolFGrp>::gateCheckGrp": 0x802ddcd8,
		"JALSeModData<JALSeModEffDGrp>::calcDyna": 0x802ddd28,
		"JALSeModData<JALSeModEffDGrp>::gateCheckDyna": 0x802ddd60,
		"JALSeModData<JALSeModPitDGrp>::calcDyna": 0x802dddf4,
		"JALSeModData<JALSeModPitDGrp>::gateCheckDyna": 0x802dde2c,
		"JALSeModData<JALSeModVolDGrp>::calcDyna": 0x802ddec0,
		"JALSeModData<JALSeModVolDGrp>::gateCheckDyna": 0x802ddef8,
		"JALSeModData<JALSeModEffFGrp>::calcDyna": 0x802ddf8c,
		"JALSeModData<JALSeModEffFGrp>::gateCheckDyna": 0x802ddfc4,
		"JALSeModData<JALSeModPitFGrp>::gateCheckDyna": 0x802de058,
		"JALSeModData<JALSeModVolFGrp>::calcDyna": 0x802de0ec,
		"JALSeModData<JALSeModVolFGrp>::gateCheckDyna": 0x802de124,
		"JALSeModData<JALSeModEffDist>::calcDyna": 0x802de1b8,
		"JALSeModData<JALSeModEffDist>::gateCheckDyna": 0x802de1f0,
		"JALSeModData<JALSeModPitDist>::calcDyna": 0x802de284,
		"JALSeModData<JALSeModPitDist>::gateCheckDyna": 0x802de2bc,
		"JALSeModData<JALSeModVolDist>::calc": 0x802de350,
		"JALSeModData<JALSeModVolDist>::calcDyna": 0x802de3b4,
		"JALSeModData<JALSeModVolDist>::gateCheckDyna": 0x802de3ec,
		"JALSeModData<JALSeModEffFunk>::calc": 0x802de480,
		"JALSeModData<JALSeModEffFunk>::calcDyna": 0x802de4e4,
		"JALSeModData<JALSeModEffFunk>::gateCheck": 0x802de51c,
		"JALSeModData<JALSeModEffFunk>::gateCheckDyna": 0x802de56c,
		"JALSeModData<JALSeModPitFunk>::calc": 0x802de600,
		"JALSeModData<JALSeModPitFunk>::calcDyna": 0x802de664,
		"JALSeModData<JALSeModPitFunk>::gateCheck": 0x802de69c,
		"JALSeModData<JALSeModPitFunk>::gateCheckDyna": 0x802de6ec,
		"JALSeModData<JALSeModVolFunk>::gateCheck": 0x802de780,
		"JALSeModData<JALSeModVolFunk>::gateCheckDyna": 0x802de7d0,
		"JALListS<JALSeModPitFunk,unsigned_long><JALSeModPitFunk,unsigned_long>::search": 0x802de864,
		"JALListS<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::search": 0x802de898,
		"JALListS<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::search": 0x802de8cc,
		"JALListS<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::search": 0x802de900,
		"JALListS<JALSeModPitFGrp,unsigned_long><JALSeModPitFGrp,unsigned_long>::search": 0x802de934,
		"JALListS<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::search": 0x802de968,
		"JALListS<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::search": 0x802de99c,
		"JALListS<JALSeModPitDGrp,unsigned_long><JALSeModPitDGrp,unsigned_long>::search": 0x802de9d0,
		"JALListS<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::search": 0x802dea04,
		"JALLinkD<JALSeModDataGrpMemb,unsigned_long><JALSeModDataGrpMemb,unsigned_long>::JALLinkD": 0x802dea38,
		"JALLinkD": 0x802dea38,
		"JALSeModData<JALSeModVolFunk>::JALSeModData": 0x802deaa8,
		"JALSeModData<JALSeModPitFunk>::JALSeModData": 0x802deb34,
		"JALSeModData<JALSeModEffFunk>::JALSeModData": 0x802debc0,
		"JALSeModData<JALSeModVolDist>::JALSeModData": 0x802dec4c,
		"JALSeModData<JALSeModPitDist>::JALSeModData": 0x802decd8,
		"JALSeModData<JALSeModEffDist>::JALSeModData": 0x802ded64,
		"JALSeModData<JALSeModVolFGrp>::JALSeModData": 0x802dedf0,
		"JALSeModData<JALSeModPitFGrp>::JALSeModData": 0x802dee7c,
		"JALSeModData<JALSeModEffFGrp>::JALSeModData": 0x802def08,
		"JALSeModData<JALSeModVolDGrp>::JALSeModData": 0x802def94,
		"JALSeModData<JALSeModPitDGrp>::JALSeModData": 0x802df020,
		"JALSeModData<JALSeModEffDGrp>::JALSeModData": 0x802df0ac,
		"JALListGrp<JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802df138,
		"JALListGrp<JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModEffFGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802df194,
		"JALListGrp<JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb><JALSeModVolDGrp,unsigned_long,JALSeModDataGrpMemb>::searchGroup": 0x802df1f0,
		"JALListHioNode<JALSeModVolFunk,unsigned_long><JALSeModVolFunk,unsigned_long>::JALListHioNode": 0x802df24c,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x802df2a0,
		"__ct__36JALListHioNode<15JALSeModPitFunk,Ul>FPCcUlP15JALSeModPitFunk": 0x802df2a0,
		"JALListHioNode<JALSeModEffFunk,unsigned_long><JALSeModEffFunk,unsigned_long>::JALListHioNode": 0x802df2f4,
		"JALListHioNode<JALSeModVolDist,unsigned_long><JALSeModVolDist,unsigned_long>::JALListHioNode": 0x802df348,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x802df39c,
		"__ct__36JALListHioNode<15JALSeModPitDist,Ul>FPCcUlP15JALSeModPitDist": 0x802df39c,
		"JALListHioNode<JALSeModEffDist,unsigned_long><JALSeModEffDist,unsigned_long>::JALListHioNode": 0x802df3f0,
		"JALListHioNode<JALSeModVolFGrp,unsigned_long><JALSeModVolFGrp,unsigned_long>::JALListHioNode": 0x802df444,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x802df498,
		"__ct__36JALListHioNode<15JALSeModPitFGrp,Ul>FPCcUlP15JALSeModPitFGrp": 0x802df498,
		"JALListHioNode<JALSeModEffFGrp,unsigned_long><JALSeModEffFGrp,unsigned_long>::JALListHioNode": 0x802df4ec,
		"JALListHioNode<JALSeModVolDGrp,unsigned_long><JALSeModVolDGrp,unsigned_long>::JALListHioNode": 0x802df540,
		"JSystem::__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x802df594,
		"__ct__36JALListHioNode<15JALSeModPitDGrp,Ul>FPCcUlP15JALSeModPitDGrp": 0x802df594,
		"JALListHioNode<JALSeModEffDGrp,unsigned_long><JALSeModEffDGrp,unsigned_long>::JALListHioNode": 0x802df5e8,
		"JSystem::__sinit_JALModSe_cpp": 0x802df63c,
		"__sinit_JALModSe_cpp": 0x802df63c,
		"JAIAnimeSound::JAIAnimeSound": 0x802df8a8,
		"JAIAnimeSound::initActorAnimSound": 0x802df91c,
		"initActorAnimSound": 0x802df91c,
		"JAIAnimeSound::setAnimSoundVec": 0x802dfa70,
		"setAnimSoundVec": 0x802dfa70,
		"JAIAnimeSound::setAnimSoundActor": 0x802dfaa8,
		"setAnimSoundActor": 0x802dfaa8,
		"JAIAnimeSound::playActorAnimSound": 0x802dfefc,
		"playActorAnimSound": 0x802dfefc,
		"JAIAnimeSound::startAnimSound": 0x802e0110,
		"JAIAnimeSound::setSpeedModifySound": 0x802e0144,
		"JAIAnimeSound::stop": 0x802e0284,
		"JAIBasic::JAIBasic": 0x802e02ec,
		"JAIBasic::initInterfaceMain": 0x802e03c4,
		"initInterfaceMain": 0x802e03c4,
		"JAIBasic::setCameraInfo": 0x802e05f0,
		"JAIBasic::initStream": 0x802e0624,
		"initStream": 0x802e0624,
		"JAIBasic::setRegisterTrackCallback": 0x802e065c,
		"JAIBasic::initReadFile": 0x802e0684,
		"initReadFile": 0x802e0684,
		"JAIBasic::checkInitListFile": 0x802e0750,
		"checkInitListFile": 0x802e0750,
		"JAIBasic::checkInitDataFile": 0x802e083c,
		"checkInitDataFile": 0x802e083c,
		"JAIBasic::checkInitDataOnMemory": 0x802e08ac,
		"checkInitDataOnMemory": 0x802e08ac,
		"JAIBasic::transInitDataFile": 0x802e0ce0,
		"transInitDataFile": 0x802e0ce0,
		"JAIBasic::initBankWave": 0x802e0dcc,
		"initBankWave": 0x802e0dcc,
		"JAIBasic::setWaveScene": 0x802e0fa0,
		"setWaveScene": 0x802e0fa0,
		"JAIBasic::setSceneSetFinishCallback": 0x802e1050,
		"setSceneSetFinishCallback": 0x802e1050,
		"JAIBasic::finishSceneSet": 0x802e109c,
		"finishSceneSet": 0x802e109c,
		"JAIBasic::loadSceneWave": 0x802e10bc,
		"loadSceneWave": 0x802e10bc,
		"JAIBasic::checkSceneWaveOnMemory": 0x802e115c,
		"checkSceneWaveOnMemory": 0x802e115c,
		"JAIBasic::loadGroupWave": 0x802e1190,
		"JAIBasic::initNullData": 0x802e1214,
		"initNullData": 0x802e1214,
		"JAIBasic::initDriver": 0x802e1334,
		"initDriver": 0x802e1334,
		"JAIBasic::initInterface": 0x802e13ac,
		"initInterface": 0x802e13ac,
		"JAIBasic::initAllocParameter": 0x802e13d0,
		"initAllocParameter": 0x802e13d0,
		"JAIBasic::initSeqsLoadArea": 0x802e1494,
		"initSeqsLoadArea": 0x802e1494,
		"JAIBasic::setInitFileLoadSwitch": 0x802e1520,
		"setInitFileLoadSwitch": 0x802e1520,
		"JAIBasic::startFrameInterfaceWork": 0x802e1528,
		"startFrameInterfaceWork": 0x802e1528,
		"JAIBasic::processFrameWork": 0x802e1548,
		"processFrameWork": 0x802e1548,
		"JAIBasic::checkStream": 0x802e16b0,
		"checkStream": 0x802e16b0,
		"JAIBasic::checkDummyPositionBuffer": 0x802e16f4,
		"checkDummyPositionBuffer": 0x802e16f4,
		"JAIBasic::startSoundActor": 0x802e178c,
		"JAIBasic::startSoundActorReturnHandle": 0x802e1820,
		"startSoundActorReturnHandle": 0x802e1820,
		"JAIBasic::startSoundDirectID": 0x802e18d0,
		"startSoundDirectID": 0x802e18d0,
		"JAIBasic::startSoundIndirectID": 0x802e1940,
		"startSoundIndirectID": 0x802e1940,
		"JAIBasic::startSoundBasic": 0x802e19b8,
		"startSoundBasic": 0x802e19b8,
		"JAIBasic::stopSoundHandle": 0x802e1b30,
		"stopSoundHandle": 0x802e1b30,
		"JAIBasic::changeIDToCategory": 0x802e1d20,
		"changeIDToCategory": 0x802e1d20,
		"JAIBasic::stopAllSe": 0x802e1d28,
		"stopAllSe": 0x802e1d28,
		"JAIBasic::getControllerHandle": 0x802e1d90,
		"getControllerHandle": 0x802e1d90,
		"JAIBasic::releaseControllerHandle": 0x802e1de8,
		"releaseControllerHandle": 0x802e1de8,
		"JAIBasic::getStreamParameter": 0x802e1e60,
		"JAIBasic::releaseStreamParameterPointer": 0x802e1ec0,
		"releaseStreamParameterPointer": 0x802e1ec0,
		"JAIBasic::getSeqParametermeterPointer": 0x802e1f38,
		"getSeqParametermeterPointer": 0x802e1f38,
		"JAIBasic::releaseSeqParameterPointer": 0x802e1f98,
		"releaseSeqParameterPointer": 0x802e1f98,
		"JAIBasic::getSeParametermeterPointer": 0x802e2010,
		"getSeParametermeterPointer": 0x802e2010,
		"JAIBasic::releaseSeParameterPointer": 0x802e20a0,
		"releaseSeParameterPointer": 0x802e20a0,
		"JAIBasic::releaseDummyVecPointer": 0x802e2120,
		"releaseDummyVecPointer": 0x802e2120,
		"JAIBasic::getMapInfoFxline": 0x802e2198,
		"getMapInfoFxline": 0x802e2198,
		"JAIBasic::getMapInfoGround": 0x802e21b0,
		"JAIBasic::getMapInfoFxParameter": 0x802e21c8,
		"getMapInfoFxParameter": 0x802e21c8,
		"JAIBasic::getInfoPointerFromID": 0x802e21e0,
		"getInfoPointerFromID": 0x802e21e0,
		"JAIBasic::getInfoFormat": 0x802e2258,
		"getInfoFormat": 0x802e2258,
		"JAIBasic::setSeCategoryVolume": 0x802e22b0,
		"setSeCategoryVolume": 0x802e22b0,
		"JAIBasic::setParameterSeqSync": 0x802e22ec,
		"JAIBasic::getSoundInfoFromID": 0x802e24bc,
		"getSoundInfoFromID": 0x802e24bc,
		"JAIBasic::getSeqTrackNumber": 0x802e24e8,
		"getSeqTrackNumber": 0x802e24e8,
		"JAIBasic::getSoundPrioity": 0x802e24f0,
		"getSoundPrioity": 0x802e24f0,
		"JAIBasic::getSoundSwBit": 0x802e24f8,
		"getSoundSwBit": 0x802e24f8,
		"JAIBasic::setSeExtParameter": 0x802e2500,
		"JAIBasic::routeToTrack": 0x802e26ac,
		"routeToTrack": 0x802e26ac,
		"JAIBasic::initHeap": 0x802e26ec,
		"initHeap": 0x802e26ec,
		"JAIBasic::allocHeap": 0x802e2734,
		"allocHeap": 0x802e2734,
		"JAIBasic::makeSound": 0x802e277c,
		"JAIBasic::loadDVDFile": 0x802e2810,
		"loadDVDFile": 0x802e2810,
		"JAIBasic::loadTmpDVDFile": 0x802e2894,
		"loadTmpDVDFile": 0x802e2894,
		"JAIBasic::deleteTmpDVDFile": 0x802e290c,
		"deleteTmpDVDFile": 0x802e290c,
		"JAIBasic::loadArcSeqData": 0x802e2948,
		"loadArcSeqData": 0x802e2948,
		"JSystem::__sinit_JAIBasic_cpp": 0x802e2ab8,
		"__sinit_JAIBasic_cpp": 0x802e2ab8,
		"JSystem::__sinit_JAIConst_cpp": 0x802e2ae8,
		"__sinit_JAIConst_cpp": 0x802e2ae8,
		"JAIData::init": 0x802e2b2c,
		"JAIData::initLinkBuffer": 0x802e2b50,
		"initLinkBuffer": 0x802e2b50,
		"JAIData::initSeqParaLinkBuffer": 0x802e2ca8,
		"initSeqParaLinkBuffer": 0x802e2ca8,
		"JAIData::initSeqParameter": 0x802e2db4,
		"initSeqParameter": 0x802e2db4,
		"JAIData::initSePara": 0x802e3004,
		"initSePara": 0x802e3004,
		"JAIData::initStreamParaLinkBuffer": 0x802e3164,
		"initStreamParaLinkBuffer": 0x802e3164,
		"JAIData::initStreamParameter": 0x802e3270,
		"initStreamParameter": 0x802e3270,
		"JAIData::initSeqTrackInfoParameter": 0x802e32cc,
		"initSeqTrackInfoParameter": 0x802e32cc,
		"JAIData::initStreamUpdateParameter": 0x802e33b0,
		"initStreamUpdateParameter": 0x802e33b0,
		"JAIData::setSeMovePara": 0x802e3400,
		"setSeMovePara": 0x802e3400,
		"JAIData::moveParameter": 0x802e3464,
		"moveParameter": 0x802e3464,
		"JAIData::checkOnMemory": 0x802e34ac,
		"checkOnMemory": 0x802e34ac,
		"JAIData::checkUsefulAutoHeapPosition": 0x802e3574,
		"checkUsefulAutoHeapPosition": 0x802e3574,
		"JAIData::getFreeAutoHeapPointer": 0x802e3624,
		"getFreeAutoHeapPointer": 0x802e3624,
		"JAIData::releaseAutoHeapPointer": 0x802e3670,
		"releaseAutoHeapPointer": 0x802e3670,
		"JAIData::getFreeStayHeapPointer": 0x802e3694,
		"getFreeStayHeapPointer": 0x802e3694,
		"JAIData::setAutoHeapLoadedFlag": 0x802e374c,
		"setAutoHeapLoadedFlag": 0x802e374c,
		"JAIData::getInfoPointer": 0x802e3760,
		"getInfoPointer": 0x802e3760,
		"JAIData::initData": 0x802e38b8,
		"JAIData::initInfoDataWork": 0x802e4128,
		"initInfoDataWork": 0x802e4128,
		"JAIEntry::checkSoundHandle": 0x802e4248,
		"checkSoundHandle": 0x802e4248,
		"JAIEntry::initSoundParameter": 0x802e4304,
		"initSoundParameter": 0x802e4304,
		"JAISeEntry::storeBuffer": 0x802e43a8,
		"JAISeqEntry::storeBuffer": 0x802e4724,
		"JAIStreamEntry::storeBuffer": 0x802e4a10,
		"JAIBasic::checkNextFrameSe": 0x802e4b10,
		"checkNextFrameSe": 0x802e4b10,
		"JAIBasic::sendPlayingSeCommand": 0x802e5264,
		"sendPlayingSeCommand": 0x802e5264,
		"JAIBasic::setSeqMuteFromSeStart": 0x802e57e8,
		"setSeqMuteFromSeStart": 0x802e57e8,
		"JAIBasic::checkSeMovePara": 0x802e58c8,
		"checkSeMovePara": 0x802e58c8,
		"JAIBasic::sendSeAllParameter": 0x802e59f4,
		"sendSeAllParameter": 0x802e59f4,
		"JAIBasic::releaseSeRegist": 0x802e6000,
		"releaseSeRegist": 0x802e6000,
		"JAIBasic::stopSeq": 0x802e61e4,
		"JAIBasic::checkEntriedSeq": 0x802e6328,
		"checkEntriedSeq": 0x802e6328,
		"JAIBasic::checkPlayingSeqTrack": 0x802e66b4,
		"checkPlayingSeqTrack": 0x802e66b4,
		"JAIBasic::checkPlayingSeq": 0x802e7550,
		"checkPlayingSeq": 0x802e7550,
		"JAIBasic::checkStoppedSeq": 0x802e7658,
		"checkStoppedSeq": 0x802e7658,
		"JAIBasic::checkStartedSeq": 0x802e7724,
		"checkStartedSeq": 0x802e7724,
		"JAIBasic::checkFadeoutSeq": 0x802e77dc,
		"checkFadeoutSeq": 0x802e77dc,
		"JAIBasic::checkReadSeq": 0x802e78b8,
		"checkReadSeq": 0x802e78b8,
		"JAIBasic::checkSeqWave": 0x802e7a84,
		"checkSeqWave": 0x802e7a84,
		"JAIBasic::checkDvdLoadArc": 0x802e7b9c,
		"checkDvdLoadArc": 0x802e7b9c,
		"JAIBasic::checkEntriedStream": 0x802e7c78,
		"checkEntriedStream": 0x802e7c78,
		"JAIBasic::checkWaitStream": 0x802e7d44,
		"checkWaitStream": 0x802e7d44,
		"JAIBasic::checkRequestStream": 0x802e7e2c,
		"checkRequestStream": 0x802e7e2c,
		"JAIBasic::checkPlayingStream": 0x802e7ec4,
		"checkPlayingStream": 0x802e7ec4,
		"JAInter::StreamLib::Play_DirectPCM": 0x802e82f4,
		"Play_DirectPCM": 0x802e82f4,
		"JAInter::StreamLib::init": 0x802e8410,
		"JAInter::StreamLib::allocBuffer": 0x802e8470,
		"allocBuffer": 0x802e8470,
		"JAInter::StreamLib::getNeedBufferSize": 0x802e8598,
		"getNeedBufferSize": 0x802e8598,
		"JAInter::StreamLib::__DecodePCM": 0x802e8624,
		"__DecodePCM": 0x802e8624,
		"JAInter::StreamLib::__DecodeADPCM": 0x802e8784,
		"__DecodeADPCM": 0x802e8784,
		"JAInter::StreamLib::__LoadFin": 0x802e8c58,
		"__LoadFin": 0x802e8c58,
		"JAInter::StreamLib::LoadADPCM": 0x802e8c78,
		"LoadADPCM": 0x802e8c78,
		"JAInter::StreamLib::setVolume": 0x802e8d8c,
		"JAInter::StreamLib::setPitch": 0x802e8d9c,
		"JAInter::StreamLib::setPan": 0x802e8dac,
		"JAInter::StreamLib::stop": 0x802e8dbc,
		"JAInter::StreamLib::setPauseFlag": 0x802e8dcc,
		"JAInter::StreamLib::clearPauseFlag": 0x802e8de0,
		"clearPauseFlag": 0x802e8de0,
		"JAInter::StreamLib::setPrepareFlag": 0x802e8df8,
		"setPrepareFlag": 0x802e8df8,
		"JAInter::StreamLib::setOutputMode": 0x802e8e00,
		"JAInter::StreamLib::getPlayingFlag": 0x802e8e08,
		"getPlayingFlag": 0x802e8e08,
		"JAInter::StreamLib::start": 0x802e8e10,
		"JAInter::StreamLib::__start": 0x802e8e88,
		"JAInter::StreamLib::callBack": 0x802e91d4,
		"callBack": 0x802e91d4,
		"JSystem::__sinit_JAIGFrameStream_cpp": 0x802e9aa8,
		"__sinit_JAIGFrameStream_cpp": 0x802e9aa8,
		"JASystem::Kernel::TSolidHeap::~TSolidHeap": 0x802e9ae4,
		"JAIGlobalParameter::setParamInitDataPointer": 0x802e9b24,
		"setParamInitDataPointer": 0x802e9b24,
		"JAIGlobalParameter::setParamSeqPlayTrackMax": 0x802e9b3c,
		"setParamSeqPlayTrackMax": 0x802e9b3c,
		"JAIGlobalParameter::setParamSeqControlBufferMax": 0x802e9b4c,
		"setParamSeqControlBufferMax": 0x802e9b4c,
		"JAIGlobalParameter::setParamAutoHeapMax": 0x802e9b54,
		"setParamAutoHeapMax": 0x802e9b54,
		"JAIGlobalParameter::setParamStayHeapMax": 0x802e9b5c,
		"setParamStayHeapMax": 0x802e9b5c,
		"JAIGlobalParameter::setParamInputGainDown": 0x802e9b64,
		"setParamInputGainDown": 0x802e9b64,
		"JAIGlobalParameter::setParamOutputGainUp": 0x802e9b6c,
		"setParamOutputGainUp": 0x802e9b6c,
		"JAIGlobalParameter::setParamDistanceMax": 0x802e9b74,
		"setParamDistanceMax": 0x802e9b74,
		"JAIGlobalParameter::setParamMaxVolumeDistance": 0x802e9b7c,
		"setParamMaxVolumeDistance": 0x802e9b7c,
		"JAIGlobalParameter::setParamMinDistanceVolume": 0x802e9b84,
		"setParamMinDistanceVolume": 0x802e9b84,
		"JAIGlobalParameter::setParamStreamInsideBufferCut": 0x802e9b8c,
		"setParamStreamInsideBufferCut": 0x802e9b8c,
		"JAIGlobalParameter::setParamAutoHeapRoomSize": 0x802e9ba0,
		"setParamAutoHeapRoomSize": 0x802e9ba0,
		"JAIGlobalParameter::setParamStayHeapSize": 0x802e9ba8,
		"setParamStayHeapSize": 0x802e9ba8,
		"JAIGlobalParameter::setParamInitDataFileName": 0x802e9bb0,
		"setParamInitDataFileName": 0x802e9bb0,
		"JAIGlobalParameter::setParamWavePath": 0x802e9bb8,
		"setParamWavePath": 0x802e9bb8,
		"JAIGlobalParameter::setParamSequenceArchivesPath": 0x802e9bc0,
		"setParamSequenceArchivesPath": 0x802e9bc0,
		"JAIGlobalParameter::setParamStreamPath": 0x802e9bc8,
		"setParamStreamPath": 0x802e9bc8,
		"JAIGlobalParameter::setParamSystemTrackMax": 0x802e9bd0,
		"setParamSystemTrackMax": 0x802e9bd0,
		"JAIGlobalParameter::setParamSystemRootTrackMax": 0x802e9bd8,
		"setParamSystemRootTrackMax": 0x802e9bd8,
		"JAIGlobalParameter::setParamSoundOutputMode": 0x802e9be0,
		"setParamSoundOutputMode": 0x802e9be0,
		"JAIGlobalParameter::getParamSeCategoryMax": 0x802e9c6c,
		"getParamSeCategoryMax": 0x802e9c6c,
		"JAIGlobalParameter::getParamSeqTrackMax": 0x802e9c7c,
		"getParamSeqTrackMax": 0x802e9c7c,
		"JAIGlobalParameter::getParamOutputGainUp": 0x802e9c84,
		"getParamOutputGainUp": 0x802e9c84,
		"JAIGlobalParameter::getParamMaxVolumeDistance": 0x802e9c8c,
		"getParamMaxVolumeDistance": 0x802e9c8c,
		"JAISound::JAISound": 0x802e9c94,
		"JAISound::initMoveParameter": 0x802e9cbc,
		"initMoveParameter": 0x802e9cbc,
		"JAISound::getSeCategoryNumber": 0x802e9d6c,
		"getSeCategoryNumber": 0x802e9d6c,
		"JAISound::getSwBit": 0x802e9d98,
		"getSwBit": 0x802e9d98,
		"JAISound::checkSwBit": 0x802e9dc4,
		"checkSwBit": 0x802e9dc4,
		"JAISound::getInfoPriority": 0x802e9e00,
		"getInfoPriority": 0x802e9e00,
		"JAISound::clearMainSoundPPointer": 0x802e9e2c,
		"clearMainSoundPPointer": 0x802e9e2c,
		"JAISound::release": 0x802e9e44,
		"JAISound::stop": 0x802e9e58,
		"JAISound::setVolume": 0x802e9e88,
		"JAISound::setPan": 0x802e9f10,
		"JAISound::setPitch": 0x802e9f98,
		"JAISound::setFxmix": 0x802ea020,
		"setFxmix": 0x802ea020,
		"JAISound::setDolby": 0x802ea098,
		"JAISound::setTempoProportion": 0x802ea110,
		"setTempoProportion": 0x802ea110,
		"JAISound::setPortData": 0x802ea168,
		"setPortData": 0x802ea168,
		"JAISound::setDistanceVolumeCommon": 0x802ea1cc,
		"JAISound::setDistancePanCommon": 0x802ea320,
		"setDistancePanCommon": 0x802ea320,
		"JAISound::setPositionDopplarCommon": 0x802ea474,
		"setPositionDopplarCommon": 0x802ea474,
		"JAISound::setSeqInterVolume": 0x802ea650,
		"setSeqInterVolume": 0x802ea650,
		"JAISound::setSeqInterPan": 0x802ea750,
		"setSeqInterPan": 0x802ea750,
		"JAISound::setSeqInterPitch": 0x802ea850,
		"setSeqInterPitch": 0x802ea850,
		"JAISound::setSeqInterFxmix": 0x802ea950,
		"setSeqInterFxmix": 0x802ea950,
		"JAISound::setSeqInterDolby": 0x802eaa50,
		"setSeqInterDolby": 0x802eaa50,
		"JAISound::setSeqTempoProportion": 0x802eab8c,
		"setSeqTempoProportion": 0x802eab8c,
		"JAISound::setSeqPortData": 0x802eac3c,
		"setSeqPortData": 0x802eac3c,
		"JAISound::setWaveReadMode": 0x802eada8,
		"setWaveReadMode": 0x802eada8,
		"JAISound::setTrackInterruptSwitch": 0x802eae48,
		"setTrackInterruptSwitch": 0x802eae48,
		"JAISound::setTrackPortData": 0x802eaeec,
		"setTrackPortData": 0x802eaeec,
		"JAISound::setSeInterVolume": 0x802eb00c,
		"setSeInterVolume": 0x802eb00c,
		"JAISound::setSeInterPan": 0x802eb1d4,
		"setSeInterPan": 0x802eb1d4,
		"JAISound::setSeInterFxmix": 0x802eb39c,
		"setSeInterFxmix": 0x802eb39c,
		"JAISound::setSeInterDolby": 0x802eb564,
		"setSeInterDolby": 0x802eb564,
		"JAISound::setSeInterPitch": 0x802eb72c,
		"setSeInterPitch": 0x802eb72c,
		"JAISound::setSePortData": 0x802eb8e8,
		"setSePortData": 0x802eb8e8,
		"JAISound::setSeDistanceParameters": 0x802eba68,
		"JAISound::setSeDistanceVolume": 0x802ebbdc,
		"JAISound::setSeDistancePan": 0x802ebcdc,
		"JAISound::setSeDistancePitch": 0x802ebda4,
		"JAISound::setSePositionDopplar": 0x802ebf9c,
		"setSePositionDopplar": 0x802ebf9c,
		"JAISound::setSeDistanceFxmix": 0x802ec098,
		"setSeDistanceFxmix": 0x802ec098,
		"JAISound::setSeDistanceFir": 0x802ec18c,
		"setSeDistanceFir": 0x802ec18c,
		"JAISound::setSeDistanceDolby": 0x802ec190,
		"JAISound::setStreamInterVolume": 0x802ec25c,
		"setStreamInterVolume": 0x802ec25c,
		"JAISound::setStreamInterPitch": 0x802ec35c,
		"setStreamInterPitch": 0x802ec35c,
		"JAISound::setStreamInterPan": 0x802ec45c,
		"setStreamInterPan": 0x802ec45c,
		"JAISound::setPauseMode": 0x802ec55c,
		"setPauseMode": 0x802ec55c,
		"JAISound::getSeqInterVolume": 0x802ec90c,
		"getSeqInterVolume": 0x802ec90c,
		"JAISound::getStreamInterVolume": 0x802ec960,
		"getStreamInterVolume": 0x802ec960,
		"JAISound::getSeqParameter": 0x802ec9f0,
		"getSeqParameter": 0x802ec9f0,
		"JAISound::getSeParameter": 0x802ec9f8,
		"getSeParameter": 0x802ec9f8,
		"JAISound::getStreamParameter": 0x802eca00,
		"JAISound::getTrackPortRoute": 0x802eca08,
		"getTrackPortRoute": 0x802eca08,
		"JAISystemInterface::checkFileExsistence": 0x802eca44,
		"checkFileExsistence": 0x802eca44,
		"JAISystemInterface::checkSeqActiveFlag": 0x802eca88,
		"checkSeqActiveFlag": 0x802eca88,
		"JAISystemInterface::trackToSeqp": 0x802ecb90,
		"trackToSeqp": 0x802ecb90,
		"JAISystemInterface::setSeqPortargsF32": 0x802ecc20,
		"setSeqPortargsF32": 0x802ecc20,
		"JAISystemInterface::setSeqPortargsU32": 0x802ecc3c,
		"setSeqPortargsU32": 0x802ecc3c,
		"JAISystemInterface::rootInit": 0x802ecc58,
		"rootInit": 0x802ecc58,
		"JAISystemInterface::trackInit": 0x802eccd0,
		"trackInit": 0x802eccd0,
		"JAISystemInterface::outerInit": 0x802ecdc0,
		"outerInit": 0x802ecdc0,
		"JAISystemInterface::setSePortParameter": 0x802ecfb0,
		"setSePortParameter": 0x802ecfb0,
		"JAISystemInterface::setSeqData": 0x802ed104,
		"JAISystemInterface::startSeq": 0x802ed184,
		"JAISystemInterface::stopSeq": 0x802ed1dc,
		"JAISystemInterface::writePortApp": 0x802ed224,
		"JAISystemInterface::readPortApp": 0x802ed27c,
		"JSystem::__sinit_JAISystemInterface_cpp": 0x802ed2d4,
		"__sinit_JAISystemInterface_cpp": 0x802ed2d4,
		"JASystem::Kernel::TPortCmd::~TPortCmd": 0x802ed310,
		"JASystem::TBank::getCurrentHeap": 0x802ed350,
		"JASystem::BankMgr::init": 0x802ed364,
		"JASystem::BankMgr::registBankBNK": 0x802ed480,
		"registBankBNK": 0x802ed480,
		"JASystem::BankMgr::getPhysicalNumber": 0x802ed4e8,
		"getPhysicalNumber": 0x802ed4e8,
		"JASystem::BankMgr::setVir2PhyTable": 0x802ed4f8,
		"setVir2PhyTable": 0x802ed4f8,
		"JASystem::BankMgr::assignWaveBank": 0x802ed514,
		"assignWaveBank": 0x802ed514,
		"JASystem::BankMgr::noteOn": 0x802ed588,
		"JASystem::BankMgr::noteOnOsc": 0x802ed998,
		"noteOnOsc": 0x802ed998,
		"JASystem::BankMgr::gateOn": 0x802edaf0,
		"JASystem::TBasicBank::TBasicBank": 0x802edbb8,
		"JASystem::TBank::~TBank": 0x802edbe4,
		"JASystem::TBasicBank::~TBasicBank": 0x802edc30,
		"JASystem::TBasicBank::setInstCount": 0x802edca4,
		"setInstCount": 0x802edca4,
		"JASystem::TBasicBank::setInst": 0x802edd08,
		"setInst": 0x802edd08,
		"JASystem::TBasicBank::getInst": 0x802edd18,
		"getInst": 0x802edd18,
		"JASystem::TBasicBank::getType": 0x802edd3c,
		"JASystem::TBasicInst::TBasicInst": 0x802edd48,
		"JASystem::TInst::~TInst": 0x802edd8c,
		"JASystem::TBasicInst::~TBasicInst": 0x802eddd8,
		"JASystem::TBasicInst::getParam": 0x802ede64,
		"JASystem::TBasicInst::getKeymapIndex": 0x802ee040,
		"getKeymapIndex": 0x802ee040,
		"JASystem::TBasicInst::setKeyRegionCount": 0x802ee048,
		"setKeyRegionCount": 0x802ee048,
		"JASystem::TBasicInst::TKeymap::TKeymap": 0x802ee0d0,
		"JASystem::TBasicInst::setEffectCount": 0x802ee0e8,
		"JASystem::TBasicInst::setEffect": 0x802ee160,
		"JASystem::TBasicInst::setOscCount": 0x802ee170,
		"setOscCount": 0x802ee170,
		"JASystem::TBasicInst::setOsc": 0x802ee1e8,
		"setOsc": 0x802ee1e8,
		"JASystem::TBasicInst::getKeyRegion": 0x802ee1f8,
		"getKeyRegion": 0x802ee1f8,
		"JASystem::TBasicInst::TKeymap::~TKeymap": 0x802ee21c,
		"JASystem::TBasicInst::TKeymap::setVeloRegionCount": 0x802ee270,
		"JASystem::TBasicInst::getType": 0x802ee310,
		"JASystem::TBasicWaveBank::TBasicWaveBank": 0x802ee31c,
		"JASystem::TWaveBank::~TWaveBank": 0x802ee34c,
		"JASystem::TBasicWaveBank::~TBasicWaveBank": 0x802ee398,
		"JASystem::TBasicWaveBank::getWaveGroup": 0x802ee41c,
		"getWaveGroup": 0x802ee41c,
		"JASystem::TBasicWaveBank::setGroupCount": 0x802ee440,
		"setGroupCount": 0x802ee440,
		"JASystem::TBasicWaveBank::setWaveTableSize": 0x802ee4c8,
		"JASystem::TBasicWaveBank::incWaveTable": 0x802ee52c,
		"incWaveTable": 0x802ee52c,
		"JASystem::TBasicWaveBank::decWaveTable": 0x802ee58c,
		"decWaveTable": 0x802ee58c,
		"JASystem::TBasicWaveBank::getWaveHandle": 0x802ee61c,
		"JASystem::TBasicWaveBank::TWaveGroup::TWaveGroup": 0x802ee650,
		"JASystem::Kernel::THeap::~THeap": 0x802ee6b0,
		"JASystem::TBasicWaveBank::TWaveGroup::~TWaveGroup": 0x802ee6f0,
		"JASystem::TBasicWaveBank::TWaveInfo::~TWaveInfo": 0x802ee760,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveArcFileName": 0x802ee7c0,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveCount": 0x802ee834,
		"setWaveCount": 0x802ee834,
		"JASystem::TBasicWaveBank::TWaveInfo::TWaveInfo": 0x802ee9d4,
		"JASystem::TBasicWaveBank::TWaveHandle::~TWaveHandle": 0x802eea04,
		"JASystem::TWaveHandle::~TWaveHandle": 0x802eea60,
		"JASystem::TBasicWaveBank::TWaveGroup::setWaveInfo": 0x802eeaac,
		"JASystem::TBasicWaveBank::TWaveHandle::getWaveInfo": 0x802eeb30,
		"JASystem::TBasicWaveBank::TWaveHandle::getWavePtr": 0x802eeb38,
		"JASystem::TBasicWaveBank::TWaveGroup::getWaveArcFileName": 0x802eeb5c,
		"JASystem::TBasicWaveBank::TWaveGroup::getHeap": 0x802eeb64,
		"JASystem::TBasicWaveBank::getType": 0x802eeb6c,
		"JASystem::BNKParser::createBasicBank": 0x802eeb78,
		"createBasicBank": 0x802eeb78,
		"JASystem::TDrumSet::TDrumSet": 0x802ef2a8,
		"JASystem::BNKParser::findOscPtr": 0x802ef310,
		"findOscPtr": 0x802ef310,
		"JASystem::BNKParser::getOscTableEndPtr": 0x802ef46c,
		"getOscTableEndPtr": 0x802ef46c,
		"JASystem::TDrumSet::getParam": 0x802ef558,
		"JASystem::TDrumSet::getPerc": 0x802ef748,
		"getPerc": 0x802ef748,
		"JASystem::TDrumSet::TPerc::TPerc": 0x802ef75c,
		"JASystem::TDrumSet::TPerc::~TPerc": 0x802ef790,
		"JASystem::TDrumSet::TPerc::setEffectCount": 0x802ef7ec,
		"JASystem::TDrumSet::TPerc::setVeloRegionCount": 0x802ef864,
		"JASystem::TDrumSet::TPerc::getVeloRegion": 0x802ef8bc,
		"JASystem::TDrumSet::TPerc::setEffect": 0x802ef8cc,
		"JASystem::TDrumSet::TPerc::setRelease": 0x802ef8dc,
		"setRelease": 0x802ef8dc,
		"JASystem::TDrumSet::~TDrumSet": 0x802ef8e4,
		"JASystem::TDrumSet::getType": 0x802ef968,
		"JASystem::TInstEffect::setTarget": 0x802ef974,
		"setTarget": 0x802ef974,
		"JASystem::TInstRand::getY": 0x802ef97c,
		"JASystem::TInstSense::getY": 0x802efa1c,
		"JASystem::TInstSense::setParams": 0x802efb40,
		"setParams": 0x802efb40,
		"JASystem::TSimpleWaveBank::TSimpleWaveBank": 0x802efb54,
		"JASystem::TSimpleWaveBank::~TSimpleWaveBank": 0x802efbd4,
		"JASystem::TSimpleWaveBank::TWaveHandle::~TWaveHandle": 0x802efc60,
		"JASystem::TSimpleWaveBank::setWaveTableSize": 0x802efcbc,
		"JASystem::TSimpleWaveBank::TWaveHandle::TWaveHandle": 0x802efd44,
		"JASystem::TSimpleWaveBank::getWaveHandle": 0x802efd68,
		"JASystem::TSimpleWaveBank::setWaveInfo": 0x802efd8c,
		"JASystem::TSimpleWaveBank::setWaveArcFileName": 0x802efe14,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWaveInfo": 0x802efe88,
		"JASystem::TSimpleWaveBank::TWaveHandle::getWavePtr": 0x802efe90,
		"JASystem::TSimpleWaveBank::getType": 0x802efeb4,
		"JASystem::WaveArcLoader::init": 0x802efee8,
		"JASystem::WaveArcLoader::setCurrentDir": 0x802eff34,
		"setCurrentDir": 0x802eff34,
		"JASystem::WaveArcLoader::getCurrentDir": 0x802eff94,
		"getCurrentDir": 0x802eff94,
		"JASystem::WaveArcLoader::loadWave": 0x802effa0,
		"JASystem::WaveArcLoader::eraseWave": 0x802f00d0,
		"JASystem::WaveArcLoader::getRootHeap": 0x802f015c,
		"getRootHeap": 0x802f015c,
		"JSystem::__sinit_JASWaveArcLoader_cpp": 0x802f0168,
		"__sinit_JASWaveArcLoader_cpp": 0x802f0168,
		"JASystem::TWaveBank::getCurrentHeap": 0x802f01a4,
		"JASystem::WaveBankMgr::init": 0x802f01b8,
		"JASystem::WaveBankMgr::getWaveBank": 0x802f0210,
		"getWaveBank": 0x802f0210,
		"JASystem::WaveBankMgr::registWaveBankWS": 0x802f0220,
		"registWaveBankWS": 0x802f0220,
		"JASystem::WaveBankMgr::loadWave": 0x802f02a0,
		"JASystem::WaveBankMgr::eraseWave": 0x802f0390,
		"JASystem::WSParser::getGroupCount": 0x802f0480,
		"getGroupCount": 0x802f0480,
		"JASystem::WSParser::createBasicWaveBank": 0x802f04a8,
		"createBasicWaveBank": 0x802f04a8,
		"JASystem::WSParser::createSimpleWaveBank": 0x802f06d4,
		"createSimpleWaveBank": 0x802f06d4,
		"JSystem::Console_printf": 0x802f099c,
		"Console_printf": 0x802f099c,
		"JASystem::AudioThread::setDSPSyncCount": 0x802f09ec,
		"setDSPSyncCount": 0x802f09ec,
		"JASystem::AudioThread::getDSPSyncCount": 0x802f09f4,
		"getDSPSyncCount": 0x802f09f4,
		"JASystem::AudioThread::syncAudio": 0x802f09fc,
		"syncAudio": 0x802f09fc,
		"JASystem::AudioThread::audioproc": 0x802f0a7c,
		"audioproc": 0x802f0a7c,
		"JASystem::AudioThread::syncDSP": 0x802f0bdc,
		"syncDSP": 0x802f0bdc,
		"JASystem::AudioThread::stop": 0x802f0c64,
		"JASystem::AudioThread::setPriority": 0x802f0cb4,
		"setPriority": 0x802f0cb4,
		"JASystem::AudioThread::start": 0x802f0cd0,
		"JASystem::Driver::DSPQueue::init": 0x802f0dec,
		"JASystem::Driver::DSPQueue::enQueue": 0x802f0e5c,
		"enQueue": 0x802f0e5c,
		"JASystem::Driver::DSPQueue::deQueue": 0x802f0f0c,
		"deQueue": 0x802f0f0c,
		"JASystem::Driver::DSPQueue::deleteQueue": 0x802f1014,
		"deleteQueue": 0x802f1014,
		"JASystem::Driver::DSPQueue::checkQueue": 0x802f1074,
		"checkQueue": 0x802f1074,
		"JASystem::Driver::calcEffect": 0x802f1150,
		"calcEffect": 0x802f1150,
		"JASystem::Driver::calcPan": 0x802f1210,
		"JASystem::Driver::__UpdateJcToDSP": 0x802f130c,
		"__UpdateJcToDSP": 0x802f130c,
		"JASystem::Driver::__UpdateJcToDSPInit": 0x802f1454,
		"__UpdateJcToDSPInit": 0x802f1454,
		"JASystem::Driver::extraUpdate": 0x802f155c,
		"extraUpdate": 0x802f155c,
		"JASystem::Driver::updatecallLogicalChannel": 0x802f1640,
		"updatecallLogicalChannel": 0x802f1640,
		"JASystem::Driver::killBrokenLogicalChannels": 0x802f17dc,
		"killBrokenLogicalChannels": 0x802f17dc,
		"JASystem::Driver::updateMixer": 0x802f1884,
		"updateMixer": 0x802f1884,
		"JASystem::Driver::updatecallDSPChannel": 0x802f1ab8,
		"updatecallDSPChannel": 0x802f1ab8,
		"JASystem::TChannel::init": 0x802f1e5c,
		"JASystem::TChannel::setOscillator": 0x802f2004,
		"setOscillator": 0x802f2004,
		"JASystem::TChannel::setOscInit": 0x802f2014,
		"setOscInit": 0x802f2014,
		"JASystem::TChannel::forceStopOsc": 0x802f2048,
		"forceStopOsc": 0x802f2048,
		"JASystem::TChannel::releaseOsc": 0x802f209c,
		"releaseOsc": 0x802f209c,
		"JASystem::TChannel::directReleaseOsc": 0x802f20f0,
		"directReleaseOsc": 0x802f20f0,
		"JASystem::TChannel::bankOscToOfs": 0x802f2104,
		"bankOscToOfs": 0x802f2104,
		"JASystem::TChannel::effectOsc": 0x802f2158,
		"effectOsc": 0x802f2158,
		"JASystem::TChannel::getOscState": 0x802f21d0,
		"getOscState": 0x802f21d0,
		"JASystem::TChannel::isOsc": 0x802f21e4,
		"isOsc": 0x802f21e4,
		"JASystem::TChannel::copyOsc": 0x802f220c,
		"copyOsc": 0x802f220c,
		"JASystem::TChannel::overwriteOsc": 0x802f226c,
		"overwriteOsc": 0x802f226c,
		"JASystem::TChannel::setKeySweepTarget": 0x802f2350,
		"setKeySweepTarget": 0x802f2350,
		"JASystem::TChannel::setPauseFlag": 0x802f23e8,
		"JASystem::TChannel::setPauseFlagReq": 0x802f23f0,
		"setPauseFlagReq": 0x802f23f0,
		"JASystem::TChannel::setPanPower": 0x802f2400,
		"setPanPower": 0x802f2400,
		"JASystem::TChannel::resetInitialVolume": 0x802f2434,
		"resetInitialVolume": 0x802f2434,
		"JASystem::TChannel::play": 0x802f24c4,
		"JASystem::TChannel::stop": 0x802f25e8,
		"JASystem::TChannel::updateJcToDSP": 0x802f2640,
		"updateJcToDSP": 0x802f2640,
		"JASystem::TChannel::forceStopLogicalChannel": 0x802f2678,
		"forceStopLogicalChannel": 0x802f2678,
		"JASystem::TChannel::stopLogicalChannel": 0x802f26b0,
		"stopLogicalChannel": 0x802f26b0,
		"JASystem::TChannel::playLogicalChannel": 0x802f2720,
		"playLogicalChannel": 0x802f2720,
		"JASystem::TChannel::updateEffectorParam": 0x802f29b8,
		"updateEffectorParam": 0x802f29b8,
		"JASystem::TChannelMgr::init": 0x802f2c84,
		"JASystem::TChannelMgr::stopAll": 0x802f2d78,
		"stopAll": 0x802f2d78,
		"JASystem::TChannelMgr::stopAllRelease": 0x802f2dbc,
		"stopAllRelease": 0x802f2dbc,
		"JASystem::TChannelMgr::addListHead": 0x802f2e18,
		"addListHead": 0x802f2e18,
		"JASystem::TChannelMgr::addListTail": 0x802f2e78,
		"addListTail": 0x802f2e78,
		"JASystem::TChannelMgr::getListHead": 0x802f2f0c,
		"getListHead": 0x802f2f0c,
		"JASystem::TChannelMgr::cutList": 0x802f2f84,
		"cutList": 0x802f2f84,
		"JASystem::TChannelMgr::initAllocChannel": 0x802f3000,
		"initAllocChannel": 0x802f3000,
		"JASystem::TChannelMgr::getLogicalChannel": 0x802f3074,
		"getLogicalChannel": 0x802f3074,
		"JASystem::TChannelMgr::receiveAllChannels": 0x802f31b8,
		"receiveAllChannels": 0x802f31b8,
		"JASystem::TChannelMgr::checkLimitStart": 0x802f3310,
		"checkLimitStart": 0x802f3310,
		"JASystem::TChannelMgr::checkLimitStop": 0x802f3494,
		"checkLimitStop": 0x802f3494,
		"JASystem::ChGlobal::getChannelHandle": 0x802f3560,
		"getChannelHandle": 0x802f3560,
		"JASystem::ChGlobal::init": 0x802f3580,
		"JASystem::TOscillator::~TOscillator": 0x802f36a8,
		"JASystem::TOscillator::TOscillator": 0x802f36e8,
		"JASystem::TChannel::~TChannel": 0x802f3718,
		"JASystem::TChannel::TChannel": 0x802f3758,
		"JASystem::ChGlobal::alloc": 0x802f3780,
		"JASystem::ChGlobal::release": 0x802f3828,
		"JASystem::ChGlobal::releaseAll": 0x802f388c,
		"releaseAll": 0x802f388c,
		"JASystem::Driver::init": 0x802f39d8,
		"JASystem::Driver::setMixerLevel": 0x802f3a10,
		"setMixerLevel": 0x802f3a10,
		"JASystem::Driver::getMixerLevel": 0x802f3a4c,
		"getMixerLevel": 0x802f3a4c,
		"JASystem::Driver::setOutputMode": 0x802f3a54,
		"JASystem::Driver::getOutputMode": 0x802f3a5c,
		"getOutputMode": 0x802f3a5c,
		"JASystem::Driver::getUpdateInterval": 0x802f3a64,
		"getUpdateInterval": 0x802f3a64,
		"JASystem::DSPBuf::updateDSP": 0x802f3a6c,
		"updateDSP": 0x802f3a6c,
		"JASystem::DSPBuf::mixDSP": 0x802f3ac0,
		"mixDSP": 0x802f3ac0,
		"JASystem::DSPBuf::finishDSPFrame": 0x802f3ae4,
		"finishDSPFrame": 0x802f3ae4,
		"JASystem::DSPBuf::process": 0x802f3b08,
		"process": 0x802f3b08,
		"JASystem::TDSPChannel::forceStop": 0x802f3f6c,
		"JASystem::TDSPChannel::forceDelete": 0x802f3ffc,
		"forceDelete": 0x802f3ffc,
		"JASystem::TDSPChannel::play": 0x802f4010,
		"JASystem::TDSPChannel::stop": 0x802f4048,
		"JASystem::TDSPChannel::initAll": 0x802f4078,
		"initAll": 0x802f4078,
		"JASystem::TDSPChannel::~TDSPChannel": 0x802f4168,
		"JASystem::TDSPChannel::TDSPChannel": 0x802f41a8,
		"JASystem::TDSPChannel::alloc": 0x802f41b8,
		"JASystem::TDSPChannel::free": 0x802f42b8,
		"JASystem::TDSPChannel::getLower": 0x802f4340,
		"getLower": 0x802f4340,
		"JASystem::TDSPChannel::getLowerActive": 0x802f43f4,
		"getLowerActive": 0x802f43f4,
		"JASystem::TDSPChannel::breakLower": 0x802f4480,
		"breakLower": 0x802f4480,
		"JASystem::TDSPChannel::updateAll": 0x802f456c,
		"updateAll": 0x802f456c,
		"JSystem::DSP_CreateMap": 0x802f4794,
		"DSP_CreateMap": 0x802f4794,
		"JASystem::DSPInterface::getDSPHandle": 0x802f4820,
		"getDSPHandle": 0x802f4820,
		"JASystem::DSPInterface::invalChannelAll": 0x802f4834,
		"invalChannelAll": 0x802f4834,
		"JASystem::DSPInterface::initBuffer": 0x802f485c,
		"initBuffer": 0x802f485c,
		"JASystem::DSPInterface::getFXHandle": 0x802f4968,
		"getFXHandle": 0x802f4968,
		"JASystem::DSPInterface::FXBuffer::setFXLine": 0x802f4978,
		"setFXLine": 0x802f4978,
		"JASystem::DSPInterface::DSPBuffer::allocInit": 0x802f4acc,
		"allocInit": 0x802f4acc,
		"JASystem::DSPInterface::DSPBuffer::playStart": 0x802f4b18,
		"playStart": 0x802f4b18,
		"JASystem::DSPInterface::DSPBuffer::setWaveInfo": 0x802f4bd4,
		"JASystem::DSPInterface::DSPBuffer::setOscInfo": 0x802f4ca0,
		"setOscInfo": 0x802f4ca0,
		"JASystem::DSPInterface::DSPBuffer::initAutoMixer": 0x802f4cb8,
		"initAutoMixer": 0x802f4cb8,
		"JASystem::DSPInterface::DSPBuffer::setAutoMixer": 0x802f4ce4,
		"setAutoMixer": 0x802f4ce4,
		"JASystem::DSPInterface::DSPBuffer::setPitch": 0x802f4d08,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitDelayMax": 0x802f4d20,
		"setMixerInitDelayMax": 0x802f4d20,
		"JASystem::DSPInterface::DSPBuffer::setMixerInitVolume": 0x802f4d2c,
		"setMixerInitVolume": 0x802f4d2c,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolume": 0x802f4d50,
		"setMixerVolume": 0x802f4d50,
		"JASystem::DSPInterface::DSPBuffer::setMixerVolumeOnly": 0x802f4d80,
		"setMixerVolumeOnly": 0x802f4d80,
		"JASystem::DSPInterface::DSPBuffer::setPauseFlag": 0x802f4d9c,
		"JASystem::DSPInterface::DSPBuffer::flushChannel": 0x802f4da8,
		"flushChannel": 0x802f4da8,
		"JASystem::DSPInterface::DSPBuffer::setIIRFilterParam": 0x802f4dcc,
		"setIIRFilterParam": 0x802f4dcc,
		"JASystem::DSPInterface::DSPBuffer::setFIR8FilterParam": 0x802f4df0,
		"setFIR8FilterParam": 0x802f4df0,
		"JASystem::DSPInterface::DSPBuffer::setFilterMode": 0x802f4e34,
		"setFilterMode": 0x802f4e34,
		"JASystem::DSPInterface::DSPBuffer::initFilter": 0x802f4e74,
		"initFilter": 0x802f4e74,
		"JASystem::DSPInterface::DSPBuffer::setDistFilter": 0x802f4ebc,
		"setDistFilter": 0x802f4ebc,
		"JASystem::DSPInterface::DSPBuffer::setBusConnect": 0x802f4ec4,
		"setBusConnect": 0x802f4ec4,
		"JASystem::TOscillator::init": 0x802f4ee8,
		"JASystem::TOscillator::initStart": 0x802f4f20,
		"initStart": 0x802f4f20,
		"JASystem::TOscillator::getOffset": 0x802f4f80,
		"getOffset": 0x802f4f80,
		"JASystem::TOscillator::getOffsetNoCount": 0x802f508c,
		"getOffsetNoCount": 0x802f508c,
		"JASystem::TOscillator::forceStop": 0x802f50e8,
		"JASystem::TOscillator::release": 0x802f5124,
		"JASystem::TOscillator::calc": 0x802f52ac,
		"JASystem::Kernel::init": 0x802f564c,
		"JASystem::Kernel::initSystem": 0x802f567c,
		"initSystem": 0x802f567c,
		"JASystem::Kernel::registerMixCallback": 0x802f5730,
		"registerMixCallback": 0x802f5730,
		"JASystem::Kernel::vframeWork": 0x802f573c,
		"vframeWork": 0x802f573c,
		"JASystem::Kernel::updateDac": 0x802f58cc,
		"updateDac": 0x802f58cc,
		"JASystem::Kernel::mixMonoTrack": 0x802f5974,
		"mixMonoTrack": 0x802f5974,
		"JASystem::Kernel::mixMonoTrackWide": 0x802f5a70,
		"mixMonoTrackWide": 0x802f5a70,
		"JASystem::Kernel::mixExtraTrack": 0x802f5b6c,
		"mixExtraTrack": 0x802f5b6c,
		"JASystem::Kernel::mixInterleaveTrack": 0x802f5c84,
		"mixInterleaveTrack": 0x802f5c84,
		"JASystem::Calc::initSinfT": 0x802f5d20,
		"initSinfT": 0x802f5d20,
		"JASystem::Calc::sinfT": 0x802f5e48,
		"sinfT": 0x802f5e48,
		"JASystem::Calc::sinfDolby2": 0x802f5e74,
		"sinfDolby2": 0x802f5e74,
		"JASystem::Calc::imixcopy": 0x802f5ea0,
		"imixcopy": 0x802f5ea0,
		"JASystem::Calc::bcopy": 0x802f5f74,
		"bcopy": 0x802f5f74,
		"JASystem::Calc::bzero": 0x802f6254,
		"bzero": 0x802f6254,
		"JASystem::Kernel::resetCallback": 0x802f64b8,
		"resetCallback": 0x802f64b8,
		"JASystem::Kernel::registerSubframeCallback": 0x802f652c,
		"registerSubframeCallback": 0x802f652c,
		"JASystem::Kernel::registerAiCallback": 0x802f6584,
		"registerAiCallback": 0x802f6584,
		"JASystem::Kernel::aiCallback": 0x802f666c,
		"aiCallback": 0x802f666c,
		"JASystem::Kernel::subframeCallback": 0x802f670c,
		"subframeCallback": 0x802f670c,
		"JASystem::Kernel::TPortCmd::TPortCmd": 0x802f67ac,
		"JASystem::Kernel::TPortCmd::addPortCmdOnce": 0x802f67c4,
		"addPortCmdOnce": 0x802f67c4,
		"JASystem::Kernel::TPortCmd::setPortCmd": 0x802f67e8,
		"setPortCmd": 0x802f67e8,
		"JASystem::Kernel::TPortCmd::addPortCmd": 0x802f6800,
		"addPortCmd": 0x802f6800,
		"JASystem::Kernel::portCmdInit": 0x802f6880,
		"portCmdInit": 0x802f6880,
		"JASystem::Kernel::getPortCmd": 0x802f68c8,
		"getPortCmd": 0x802f68c8,
		"JASystem::Kernel::portCmdMain": 0x802f6908,
		"portCmdMain": 0x802f6908,
		"JASystem::Dvd::init": 0x802f6978,
		"JASystem::Dvd::extendPath": 0x802f69c4,
		"extendPath": 0x802f69c4,
		"JASystem::Dvd::dvdProcInit": 0x802f6a4c,
		"dvdProcInit": 0x802f6a4c,
		"JASystem::Dvd::dvdProc": 0x802f6af8,
		"dvdProc": 0x802f6af8,
		"JASystem::Dvd::loadToDramDvdTMain": 0x802f6b84,
		"loadToDramDvdTMain": 0x802f6b84,
		"JASystem::Dvd::loadToDramDvdT": 0x802f6cac,
		"loadToDramDvdT": 0x802f6cac,
		"JASystem::Dvd::loadToAramDvdTMain": 0x802f6d60,
		"loadToAramDvdTMain": 0x802f6d60,
		"JASystem::Dvd::loadToAramDvdT": 0x802f6fc8,
		"loadToAramDvdT": 0x802f6fc8,
		"JASystem::Dvd::checkFileExtend": 0x802f707c,
		"checkFileExtend": 0x802f707c,
		"JASystem::Dvd::loadFileDvdT": 0x802f7130,
		"loadFileDvdT": 0x802f7130,
		"JASystem::Dvd::checkPassDvdT": 0x802f7218,
		"checkPassDvdT": 0x802f7218,
		"JASystem::Dvd::checkFile": 0x802f729c,
		"checkFile": 0x802f729c,
		"JASystem::Dvd::loadFile": 0x802f72f8,
		"JASystem::Dvd::pauseDvdT": 0x802f73ac,
		"pauseDvdT": 0x802f73ac,
		"JASystem::Dvd::unpauseDvdT": 0x802f73b8,
		"unpauseDvdT": 0x802f73b8,
		"JASystem::Dvd::registerFastOpen": 0x802f73f0,
		"registerFastOpen": 0x802f73f0,
		"JASystem::Dvd::openDvd": 0x802f74e0,
		"openDvd": 0x802f74e0,
		"JASystem::Dvd::getCallStack": 0x802f7538,
		"getCallStack": 0x802f7538,
		"JASystem::Dvd::dvdReadMutex": 0x802f7594,
		"dvdReadMutex": 0x802f7594,
		"JASystem::Dvd::doError": 0x802f7620,
		"doError": 0x802f7620,
		"JASystem::Dvd::doFinish": 0x802f7668,
		"doFinish": 0x802f7668,
		"JASystem::Dvd::dvdThreadCheckBack": 0x802f76ac,
		"dvdThreadCheckBack": 0x802f76ac,
		"JASystem::Dvd::allocDvdBuffer": 0x802f76f8,
		"allocDvdBuffer": 0x802f76f8,
		"JASystem::Dvd::writeBufferSize": 0x802f77d0,
		"writeBufferSize": 0x802f77d0,
		"JASystem::Dvd::updateBuffer": 0x802f7888,
		"updateBuffer": 0x802f7888,
		"JASystem::Dvd::aramDmaFinish": 0x802f795c,
		"aramDmaFinish": 0x802f795c,
		"JASystem::HardStream::main": 0x802f796c,
		"JASystem::HardStream::firstBgmCallback": 0x802f7df0,
		"firstBgmCallback": 0x802f7df0,
		"JASystem::HardStream::secondBgmCallback": 0x802f7e7c,
		"secondBgmCallback": 0x802f7e7c,
		"JASystem::HardStream::getAddrCallback": 0x802f7e90,
		"getAddrCallback": 0x802f7e90,
		"JASystem::HardStream::TControl::TControl": 0x802f8010,
		"JASystem::HardStream::TControl::getIntroNum": 0x802f8070,
		"getIntroNum": 0x802f8070,
		"JASystem::HardStream::TControl::getLoopNum": 0x802f80a8,
		"getLoopNum": 0x802f80a8,
		"JASystem::HardStream::TControl::clearListOne": 0x802f80e0,
		"clearListOne": 0x802f80e0,
		"JASystem::HardStream::TControl::getLastAddr": 0x802f8114,
		"getLastAddr": 0x802f8114,
		"JASystem::HardStream::TControl::startFirst": 0x802f8128,
		"startFirst": 0x802f8128,
		"JASystem::HardStream::TControl::startSecond": 0x802f8248,
		"startSecond": 0x802f8248,
		"JASystem::HardStream::TControl::resetFader": 0x802f8368,
		"resetFader": 0x802f8368,
		"JASystem::HardStream::TControl::getCurVol": 0x802f83a4,
		"getCurVol": 0x802f83a4,
		"JASystem::HardStream::TControl::calcCurVolume": 0x802f83dc,
		"calcCurVolume": 0x802f83dc,
		"JASystem::HardStream::TControl::volFloatToU8": 0x802f8660,
		"volFloatToU8": 0x802f8660,
		"JSystem::__sinit_JASHardStream_cpp": 0x802f86a0,
		"__sinit_JASHardStream_cpp": 0x802f86a0,
		"JASystem::HardStream::TControl::~TControl": 0x802f86dc,
		"JASystem::Kernel::THeap::THeap": 0x802f871c,
		"JASystem::Kernel::THeap::selfAlloc": 0x802f8768,
		"selfAlloc": 0x802f8768,
		"JASystem::Kernel::THeap::initMotherHeap": 0x802f8868,
		"initMotherHeap": 0x802f8868,
		"JASystem::Kernel::THeap::allocHeapCheck": 0x802f88c4,
		"allocHeapCheck": 0x802f88c4,
		"JASystem::Kernel::THeap::alloc": 0x802f8a78,
		"JASystem::Kernel::THeap::free": 0x802f8ab8,
		"JASystem::Kernel::TSolidHeap::TSolidHeap": 0x802f8c58,
		"JASystem::Kernel::TSolidHeap::alloc": 0x802f8c74,
		"JASystem::Kernel::TSolidHeap::init": 0x802f8cd0,
		"JASystem::Kernel::TSolidHeap::getRemain": 0x802f8d18,
		"getRemain": 0x802f8d18,
		"JASystem::Kernel::stackInit": 0x802f8d30,
		"stackInit": 0x802f8d30,
		"JASystem::Kernel::probeStart": 0x802f8e00,
		"probeStart": 0x802f8e00,
		"JASystem::Kernel::probeFinish": 0x802f8e04,
		"probeFinish": 0x802f8e04,
		"JASystem::Kernel::sysDramSetup": 0x802f8e08,
		"sysDramSetup": 0x802f8e08,
		"JASystem::Kernel::allocFromSysDram": 0x802f8e60,
		"allocFromSysDram": 0x802f8e60,
		"JASystem::Kernel::sysAramSetup": 0x802f8eb8,
		"sysAramSetup": 0x802f8eb8,
		"JASystem::Kernel::allocFromSysAramFull": 0x802f8f20,
		"allocFromSysAramFull": 0x802f8f20,
		"JSystem::__sinit_JASSystemHeap_cpp": 0x802f8f80,
		"__sinit_JASSystemHeap_cpp": 0x802f8f80,
		"JASystem::Vload::initHeader": 0x802f8fbc,
		"initHeader": 0x802f8fbc,
		"JASystem::Vload::initHeaderM": 0x802f8fe4,
		"initHeaderM": 0x802f8fe4,
		"JASystem::Vload::getArchiveHandle": 0x802f9150,
		"getArchiveHandle": 0x802f9150,
		"JASystem::Vload::getRealHandle": 0x802f91d8,
		"getRealHandle": 0x802f91d8,
		"JASystem::Vload::checkSize": 0x802f9250,
		"checkSize": 0x802f9250,
		"JASystem::Vload::loadFile": 0x802f9284,
		"JASystem::Vload::loadFileAsync": 0x802f9330,
		"loadFileAsync": 0x802f9330,
		"JASystem::Vload::initVloadBuffers": 0x802f93d0,
		"initVloadBuffers": 0x802f93d0,
		"JASystem::TTrack::TNoteMgr::init": 0x802f9494,
		"JASystem::TTrack::TNoteMgr::endProcess": 0x802f94ec,
		"endProcess": 0x802f94ec,
		"JASystem::TTrack::TNoteMgr::getChannel": 0x802f9514,
		"getChannel": 0x802f9514,
		"JASystem::TTrack::TOuterParam::TOuterParam": 0x802f9564,
		"JASystem::TTrack::TOuterParam::initExtBuffer": 0x802f95b0,
		"initExtBuffer": 0x802f95b0,
		"JASystem::TTrack::TOuterParam::setOuterSwitch": 0x802f95c0,
		"setOuterSwitch": 0x802f95c0,
		"JASystem::TTrack::TOuterParam::checkOuterSwitch": 0x802f95c8,
		"checkOuterSwitch": 0x802f95c8,
		"JASystem::TTrack::TOuterParam::setOuterUpdate": 0x802f95e8,
		"setOuterUpdate": 0x802f95e8,
		"JASystem::TTrack::TOuterParam::getOuterUpdate": 0x802f95f0,
		"getOuterUpdate": 0x802f95f0,
		"JASystem::TTrack::TOuterParam::getIntFirFilter": 0x802f95f8,
		"getIntFirFilter": 0x802f95f8,
		"JASystem::TTrack::TOuterParam::setParam": 0x802f9608,
		"setParam": 0x802f9608,
		"JASystem::TTrack::TOuterParam::onSwitch": 0x802f96a4,
		"onSwitch": 0x802f96a4,
		"JASystem::TTrack::TOuterParam::setFirFilter": 0x802f96c0,
		"setFirFilter": 0x802f96c0,
		"JASystem::Player::extend8to16": 0x802f971c,
		"extend8to16": 0x802f971c,
		"JASystem::Player::pitchToCent": 0x802f973c,
		"pitchToCent": 0x802f973c,
		"JASystem::Player::getRandomS32": 0x802f9808,
		"getRandomS32": 0x802f9808,
		"JASystem::TRegisterParam::TRegisterParam": 0x802f9840,
		"JASystem::TRegisterParam::init": 0x802f9890,
		"JASystem::TRegisterParam::inherit": 0x802f98f8,
		"inherit": 0x802f98f8,
		"JASystem::TRegisterParam::getBankNumber": 0x802f9968,
		"getBankNumber": 0x802f9968,
		"JASystem::TRegisterParam::getProgramNumber": 0x802f9978,
		"getProgramNumber": 0x802f9978,
		"JASystem::TSeqCtrl::init": 0x802f9984,
		"JASystem::TSeqCtrl::loopE": 0x802f99ec,
		"loopE": 0x802f99ec,
		"JASystem::TSeqCtrl::waitCountDown": 0x802f9a58,
		"waitCountDown": 0x802f9a58,
		"JASystem::TSeqCtrl::callIntr": 0x802f9a88,
		"callIntr": 0x802f9a88,
		"JASystem::TSeqCtrl::retIntr": 0x802f9ac0,
		"retIntr": 0x802f9ac0,
		"JASystem::TSeqCtrl::get16": 0x802f9af4,
		"get16": 0x802f9af4,
		"JASystem::TSeqCtrl::get24": 0x802f9b1c,
		"get24": 0x802f9b1c,
		"JASystem::TSeqCtrl::get32": 0x802f9b44,
		"get32": 0x802f9b44,
		"JASystem::TSeqCtrl::read16": 0x802f9b7c,
		"read16": 0x802f9b7c,
		"JASystem::TSeqCtrl::read24": 0x802f9bb4,
		"read24": 0x802f9bb4,
		"JASystem::TTrack::TTrack": 0x802f9bf8,
		"JASystem::TTrack::MoveParam_::MoveParam_": 0x802f9e18,
		"JASystem::TTrack::AInnerParam_::AInnerParam_": 0x802f9e30,
		"JASystem::TTrack::setInterrupt": 0x802f9f60,
		"setInterrupt": 0x802f9f60,
		"JASystem::TTrack::assignExtBuffer": 0x802f9f88,
		"assignExtBuffer": 0x802f9f88,
		"JASystem::TTrack::setInnerMemory": 0x802f9fa4,
		"setInnerMemory": 0x802f9fa4,
		"JASystem::TTrack::setPanSwitchExt": 0x802f9fac,
		"setPanSwitchExt": 0x802f9fac,
		"JASystem::TTrack::setPanSwitchParent": 0x802f9fbc,
		"setPanSwitchParent": 0x802f9fbc,
		"JASystem::TTrack::flushAll": 0x802f9fcc,
		"flushAll": 0x802f9fcc,
		"JASystem::TTrack::initTimed": 0x802fa004,
		"initTimed": 0x802fa004,
		"JASystem::TTrack::noteOn": 0x802fa124,
		"JASystem::TTrack::noteOff": 0x802fa45c,
		"noteOff": 0x802fa45c,
		"JASystem::TTrack::gateOn": 0x802fa4e8,
		"JASystem::TTrack::oscSetupFull": 0x802fa558,
		"oscSetupFull": 0x802fa558,
		"JASystem::TTrack::oscSetupSimpleEnv": 0x802fa684,
		"oscSetupSimpleEnv": 0x802fa684,
		"JASystem::TTrack::oscUpdateParam": 0x802fa6f4,
		"oscUpdateParam": 0x802fa6f4,
		"JASystem::TTrack::oscSetupSimple": 0x802fa75c,
		"oscSetupSimple": 0x802fa75c,
		"JASystem::TTrack::updateTrackAll": 0x802fa838,
		"updateTrackAll": 0x802fa838,
		"JASystem::TTrack::updateTrack": 0x802fabf0,
		"updateTrack": 0x802fabf0,
		"JASystem::TTrack::updateTempo": 0x802fb120,
		"updateTempo": 0x802fb120,
		"JASystem::TTrack::updateSeq": 0x802fb24c,
		"updateSeq": 0x802fb24c,
		"JASystem::TTrack::incSelfOsc": 0x802fb320,
		"incSelfOsc": 0x802fb320,
		"JASystem::TTrack::mainProc": 0x802fb414,
		"JASystem::TTrack::seqTimeToDspTime": 0x802fb8b8,
		"seqTimeToDspTime": 0x802fb8b8,
		"JASystem::TTrack::writeTimeParam": 0x802fb974,
		"writeTimeParam": 0x802fb974,
		"JASystem::TTrack::writeRegParam": 0x802fbb78,
		"writeRegParam": 0x802fbb78,
		"JASystem::TTrack::setSeqData": 0x802fc080,
		"JASystem::TTrack::startSeq": 0x802fc124,
		"JASystem::TTrack::stopSeq": 0x802fc1a0,
		"JASystem::TTrack::closeTrack": 0x802fc220,
		"closeTrack": 0x802fc220,
		"JASystem::TTrack::muteTrack": 0x802fc380,
		"muteTrack": 0x802fc380,
		"JASystem::TTrack::initTrack": 0x802fc450,
		"initTrack": 0x802fc450,
		"JASystem::TTrack::startTrack": 0x802fc6e0,
		"startTrack": 0x802fc6e0,
		"JASystem::TTrack::openTrack": 0x802fc774,
		"openTrack": 0x802fc774,
		"JASystem::TTrack::loadTbl": 0x802fc7cc,
		"loadTbl": 0x802fc7cc,
		"JASystem::TTrack::readReg32": 0x802fc874,
		"readReg32": 0x802fc874,
		"JASystem::TTrack::exchangeRegisterValue": 0x802fc910,
		"exchangeRegisterValue": 0x802fc910,
		"JASystem::TTrack::readRegDirect": 0x802fc9c8,
		"readRegDirect": 0x802fc9c8,
		"JASystem::TTrack::writeRegDirect": 0x802fcc04,
		"writeRegDirect": 0x802fcc04,
		"JASystem::TTrack::writePortAppDirect": 0x802fccd0,
		"writePortAppDirect": 0x802fccd0,
		"JASystem::TTrack::readPortAppDirect": 0x802fcd2c,
		"readPortAppDirect": 0x802fcd2c,
		"JASystem::TTrack::setExtFirFilterD": 0x802fcd50,
		"setExtFirFilterD": 0x802fcd50,
		"JASystem::TTrack::writePortApp": 0x802fcd7c,
		"JASystem::TTrack::readPortApp": 0x802fce24,
		"JASystem::TTrack::pauseTrack": 0x802fce94,
		"pauseTrack": 0x802fce94,
		"JASystem::TTrack::unPauseTrack": 0x802fcfc8,
		"unPauseTrack": 0x802fcfc8,
		"JASystem::TTrack::pauseTrackAll": 0x802fd0a4,
		"pauseTrackAll": 0x802fd0a4,
		"JASystem::TTrack::unPauseTrackAll": 0x802fd0c8,
		"unPauseTrackAll": 0x802fd0c8,
		"JASystem::TTrack::reset": 0x802fd0ec,
		"JASystem::TTrack::panCalc": 0x802fd0fc,
		"panCalc": 0x802fd0fc,
		"JASystem::TTrack::rootCallback": 0x802fd148,
		"rootCallback": 0x802fd148,
		"JASystem::TTrack::registerTrackCallback": 0x802fd2d8,
		"JSystem::__sinit_JASTrack_cpp": 0x802fd2e4,
		"__sinit_JASTrack_cpp": 0x802fd2e4,
		"JASystem::TIntrMgr::init": 0x802fd310,
		"JASystem::TIntrMgr::request": 0x802fd354,
		"JASystem::TIntrMgr::setIntr": 0x802fd378,
		"setIntr": 0x802fd378,
		"JASystem::TIntrMgr::resetInter": 0x802fd39c,
		"resetInter": 0x802fd39c,
		"JASystem::TIntrMgr::checkIntr": 0x802fd3b4,
		"checkIntr": 0x802fd3b4,
		"JASystem::TIntrMgr::timerProcess": 0x802fd420,
		"timerProcess": 0x802fd420,
		"JASystem::TrackMgr::init": 0x802fd490,
		"JASystem::TTrack::~TTrack": 0x802fd584,
		"JASystem::TrackMgr::handleToSeq": 0x802fd5e8,
		"handleToSeq": 0x802fd5e8,
		"JASystem::TrackMgr::reset": 0x802fd60c,
		"JASystem::TrackMgr::initRegistTrack": 0x802fd6a8,
		"initRegistTrack": 0x802fd6a8,
		"JASystem::TrackMgr::getNewTrack": 0x802fd738,
		"getNewTrack": 0x802fd738,
		"JASystem::TrackMgr::allocNewRoot": 0x802fd7c0,
		"allocNewRoot": 0x802fd7c0,
		"JASystem::TrackMgr::deAllocRoot": 0x802fd808,
		"deAllocRoot": 0x802fd808,
		"JASystem::TrackMgr::registTrack": 0x802fd854,
		"registTrack": 0x802fd854,
		"JASystem::TrackMgr::unRegistTrack": 0x802fd970,
		"unRegistTrack": 0x802fd970,
		"JASystem::TrackMgr::backTrack": 0x802fd9e8,
		"backTrack": 0x802fd9e8,
		"JASystem::TrackMgr::registerTrackCallback": 0x802fda48,
		"JASystem::TTrackPort::init": 0x802fda68,
		"JMath::TRandom_fast_::TRandom_fast_": 0x802fdb50,
		"JMath::TRandom_enough_::setSeed": 0x802fdb58,
		"setSeed": 0x802fdb58,
		"J3DMaterialFactory_v21::J3DMaterialFactory_v21": 0x802fdc4c,
		"J3DMaterialFactory_v21::countUniqueMaterials": 0x802fde2c,
		"J3DMaterialFactory_v21::countStages": 0x802fde84,
		"J3DMaterialFactory_v21::create": 0x802fdf68,
		"J3DMaterialFactory_v21::newMatColor": 0x802fe6b4,
		"J3DMaterialFactory_v21::newColorChanNum": 0x802fe744,
		"J3DMaterialFactory_v21::newColorChan": 0x802fe77c,
		"J3DMaterialFactory_v21::newTexGenNum": 0x802fe844,
		"J3DMaterialFactory_v21::newTexCoord": 0x802fe87c,
		"J3DMaterialFactory_v21::newTexMtx": 0x802fe8f0,
		"J3DMaterialFactory_v21::newCullMode": 0x802fe984,
		"J3DMaterialFactory_v21::newTexNo": 0x802fe9c4,
		"J3DMaterialFactory_v21::newTevOrder": 0x802fea0c,
		"J3DMaterialFactory_v21::newTevColor": 0x802fea80,
		"J3DMaterialFactory_v21::newTevKColor": 0x802feb18,
		"J3DMaterialFactory_v21::newTevStageNum": 0x802feba8,
		"J3DMaterialFactory_v21::newTevStage": 0x802febe0,
		"J3DMaterialFactory_v21::newTevSwapModeTable": 0x802fee4c,
		"J3DMaterialFactory_v21::newFog": 0x802feee8,
		"J3DMaterialFactory_v21::newAlphaComp": 0x802fef74,
		"J3DMaterialFactory_v21::newBlend": 0x802feff4,
		"J3DMaterialFactory_v21::newZMode": 0x802ff070,
		"J3DMaterialFactory_v21::newZCompLoc": 0x802ff0d4,
		"J3DMaterialFactory_v21::newDither": 0x802ff10c,
		"J3DMaterialFactory_v21::newNBTScale": 0x802ff144,
		"JASystem::TSeqParser::cmdOpenTrack": 0x802ff204,
		"cmdOpenTrack": 0x802ff204,
		"JASystem::TSeqParser::cmdOpenTrackBros": 0x802ff284,
		"cmdOpenTrackBros": 0x802ff284,
		"JASystem::TSeqParser::cmdCall": 0x802ff318,
		"cmdCall": 0x802ff318,
		"JASystem::TSeqParser::cmdRet": 0x802ff434,
		"cmdRet": 0x802ff434,
		"JASystem::TSeqParser::cmdJmp": 0x802ff4b4,
		"cmdJmp": 0x802ff4b4,
		"JASystem::TSeqParser::cmdLoopS": 0x802ff5f0,
		"cmdLoopS": 0x802ff5f0,
		"JASystem::TSeqParser::cmdLoopE": 0x802ff628,
		"cmdLoopE": 0x802ff628,
		"JASystem::TSeqParser::cmdReadPort": 0x802ff660,
		"cmdReadPort": 0x802ff660,
		"JASystem::TSeqParser::cmdWritePort": 0x802ff6ac,
		"cmdWritePort": 0x802ff6ac,
		"JASystem::TSeqParser::cmdCheckPortImport": 0x802ff6d4,
		"cmdCheckPortImport": 0x802ff6d4,
		"JASystem::TSeqParser::cmdCheckPortExport": 0x802ff70c,
		"cmdCheckPortExport": 0x802ff70c,
		"JASystem::TSeqParser::cmdWait": 0x802ff744,
		"cmdWait": 0x802ff744,
		"JASystem::TSeqParser::cmdConnectName": 0x802ff764,
		"cmdConnectName": 0x802ff764,
		"JASystem::TSeqParser::cmdParentWritePort": 0x802ff780,
		"cmdParentWritePort": 0x802ff780,
		"JASystem::TSeqParser::cmdChildWritePort": 0x802ff7b8,
		"cmdChildWritePort": 0x802ff7b8,
		"JASystem::TSeqParser::cmdSetLastNote": 0x802ff7f8,
		"cmdSetLastNote": 0x802ff7f8,
		"JASystem::TSeqParser::cmdTimeRelate": 0x802ff814,
		"cmdTimeRelate": 0x802ff814,
		"JASystem::TSeqParser::cmdSimpleOsc": 0x802ff838,
		"cmdSimpleOsc": 0x802ff838,
		"JASystem::TSeqParser::cmdSimpleEnv": 0x802ff868,
		"cmdSimpleEnv": 0x802ff868,
		"JASystem::TSeqParser::cmdSimpleADSR": 0x802ff89c,
		"cmdSimpleADSR": 0x802ff89c,
		"JASystem::TSeqParser::cmdTranspose": 0x802ff958,
		"cmdTranspose": 0x802ff958,
		"JASystem::TSeqParser::cmdCloseTrack": 0x802ff990,
		"cmdCloseTrack": 0x802ff990,
		"JASystem::TSeqParser::cmdOutSwitch": 0x802ff9e8,
		"cmdOutSwitch": 0x802ff9e8,
		"JASystem::TSeqParser::cmdUpdateSync": 0x802ffa40,
		"cmdUpdateSync": 0x802ffa40,
		"JASystem::TSeqParser::cmdBusConnect": 0x802ffa6c,
		"cmdBusConnect": 0x802ffa6c,
		"JASystem::TSeqParser::cmdPauseStatus": 0x802ffa90,
		"cmdPauseStatus": 0x802ffa90,
		"JASystem::TSeqParser::cmdVolumeMode": 0x802ffaa0,
		"cmdVolumeMode": 0x802ffaa0,
		"JASystem::TSeqParser::cmdSetInterrupt": 0x802ffab0,
		"cmdSetInterrupt": 0x802ffab0,
		"JASystem::TSeqParser::cmdDisInterrupt": 0x802ffae8,
		"cmdDisInterrupt": 0x802ffae8,
		"JASystem::TSeqParser::cmdClrI": 0x802ffb14,
		"cmdClrI": 0x802ffb14,
		"JASystem::TSeqParser::cmdSetI": 0x802ffb2c,
		"cmdSetI": 0x802ffb2c,
		"JASystem::TSeqParser::cmdRetI": 0x802ffb3c,
		"cmdRetI": 0x802ffb3c,
		"JASystem::TSeqParser::cmdIntTimer": 0x802ffb6c,
		"cmdIntTimer": 0x802ffb6c,
		"JASystem::TSeqParser::cmdConnectOpen": 0x802ffb88,
		"cmdConnectOpen": 0x802ffb88,
		"JASystem::TSeqParser::cmdConnectClose": 0x802ffbc4,
		"cmdConnectClose": 0x802ffbc4,
		"JASystem::TSeqParser::cmdSyncCPU": 0x802ffc0c,
		"cmdSyncCPU": 0x802ffc0c,
		"JASystem::TSeqParser::cmdFlushAll": 0x802ffc74,
		"cmdFlushAll": 0x802ffc74,
		"JASystem::TSeqParser::cmdFlushRelease": 0x802ffc9c,
		"cmdFlushRelease": 0x802ffc9c,
		"JASystem::TSeqParser::cmdTimeBase": 0x802ffcc4,
		"cmdTimeBase": 0x802ffcc4,
		"JASystem::TSeqParser::cmdTempo": 0x802ffd00,
		"cmdTempo": 0x802ffd00,
		"JASystem::TSeqParser::cmdFinish": 0x802ffd48,
		"cmdFinish": 0x802ffd48,
		"JASystem::TSeqParser::cmdNop": 0x802ffe34,
		"cmdNop": 0x802ffe34,
		"JASystem::TSeqParser::cmdPanPowSet": 0x802ffe3c,
		"cmdPanPowSet": 0x802ffe3c,
		"JASystem::TSeqParser::cmdIIRSet": 0x802ffec0,
		"cmdIIRSet": 0x802ffec0,
		"JASystem::TSeqParser::cmdFIRSet": 0x802fffc4,
		"cmdFIRSet": 0x802fffc4,
		"JASystem::TSeqParser::cmdEXTSet": 0x802ffff8,
		"cmdEXTSet": 0x802ffff8,
		"JASystem::TSeqParser::cmdPanSwSet": 0x8030004c,
		"cmdPanSwSet": 0x8030004c,
		"JASystem::TSeqParser::cmdOscRoute": 0x8030013c,
		"cmdOscRoute": 0x8030013c,
		"JASystem::TSeqParser::cmdIIRCutOff": 0x8030018c,
		"cmdIIRCutOff": 0x8030018c,
		"JASystem::TSeqParser::cmdOscFull": 0x80300294,
		"cmdOscFull": 0x80300294,
		"JASystem::TSeqParser::cmdCheckWave": 0x803002d0,
		"cmdCheckWave": 0x803002d0,
		"JASystem::TSeqParser::cmdPrintf": 0x80300300,
		"cmdPrintf": 0x80300300,
		"JASystem::TSeqParser::Cmd_Process": 0x80300520,
		"Cmd_Process": 0x80300520,
		"JASystem::TSeqParser::RegCmd_Process": 0x80300678,
		"RegCmd_Process": 0x80300678,
		"JASystem::TSeqParser::cmdNoteOff": 0x8030075c,
		"cmdNoteOff": 0x8030075c,
		"JASystem::TSeqParser::cmdNoteOn": 0x8030083c,
		"cmdNoteOn": 0x8030083c,
		"JASystem::TSeqParser::conditionCheck": 0x80300b1c,
		"conditionCheck": 0x80300b1c,
		"JASystem::TSeqParser::mainProc": 0x80300c0c,
		"JSystem::__sinit_JASSeqParser_cpp": 0x80300ee0,
		"__sinit_JASSeqParser_cpp": 0x80300ee0,
		"J3DMaterialTable::clear": 0x80301514,
		"J3DMaterialTable::J3DMaterialTable": 0x80301530,
		"J3DMaterialTable::~J3DMaterialTable": 0x80301558,
		"JSystem::JPAGetEmitterInfoPtr": 0x803015a4,
		"JPAGetEmitterInfoPtr": 0x803015a4,
		"JPABaseEmitter::JPABaseEmitter": 0x803015b0,
		"JPABaseEmitter::getFovy": 0x803016c8,
		"getFovy": 0x803016c8,
		"JPABaseEmitter::getAspect": 0x803016d8,
		"getAspect": 0x803016d8,
		"JPABaseEmitter::deleteAllParticle": 0x803016e8,
		"deleteAllParticle": 0x803016e8,
		"JPABaseEmitter::createChildParticle": 0x803017bc,
		"createChildParticle": 0x803017bc,
		"JPAParticle::addBaseVelVec": 0x80301d70,
		"addBaseVelVec": 0x80301d70,
		"JPAParticle::setBaseVelVec": 0x80301da4,
		"setBaseVelVec": 0x80301da4,
		"JPABaseEmitter::getEmitterGlobalTranslation": 0x80301dc0,
		"getEmitterGlobalTranslation": 0x80301dc0,
		"JPABaseEmitter::calcEmitterGlobalParams": 0x80301ea8,
		"calcEmitterGlobalParams": 0x80301ea8,
		"JPABaseEmitter::loadBaseEmitterBlock": 0x8030221c,
		"loadBaseEmitterBlock": 0x8030221c,
		"JPABaseEmitter::drawEmitterCallBack": 0x803025e4,
		"drawEmitterCallBack": 0x803025e4,
		"JPABaseEmitter::createParticle": 0x80302620,
		"createParticle": 0x80302620,
		"JPABaseEmitter::calcCurrentRateTimerStep": 0x803038c8,
		"calcCurrentRateTimerStep": 0x803038c8,
		"JPABaseEmitter::calcCreateParticle": 0x8030391c,
		"calcCreateParticle": 0x8030391c,
		"JPABaseEmitter::checkStartFrame": 0x80303c2c,
		"checkStartFrame": 0x80303c2c,
		"JPABaseEmitter::checkMaxFrame": 0x80303c88,
		"checkMaxFrame": 0x80303c88,
		"JPABaseEmitter::doParticle": 0x80303d34,
		"doParticle": 0x80303d34,
		"JPABaseEmitter::doChildParticle": 0x80303ea0,
		"doChildParticle": 0x80303ea0,
		"JPABaseEmitter::calcKeyFrameAnime": 0x80303ffc,
		"calcKeyFrameAnime": 0x80303ffc,
		"JPABaseEmitter::calc": 0x803041cc,
		"JPABaseEmitter::setGlobalRTMatrix": 0x80304318,
		"setGlobalRTMatrix": 0x80304318,
		"JPABaseEmitter::setGlobalSRTMatrix": 0x80304348,
		"setGlobalSRTMatrix": 0x80304348,
		"JSystem::__sinit_JPAEmitter_cpp": 0x8030437c,
		"__sinit_JPAEmitter_cpp": 0x8030437c,
		"JPAEmitterManager::JPAEmitterManager": 0x803043dc,
		"JSUList<JPABaseEmitter>::JSUList": 0x803046b4,
		"JSUList<JPABaseEmitter>::~JSUList": 0x803046e4,
		"JPAEmitterManager::calcBase": 0x8030473c,
		"calcBase": 0x8030473c,
		"JPAEmitterManager::calc": 0x80304818,
		"JPAEmitterManager::createEmitterBase": 0x803049f8,
		"createEmitterBase": 0x803049f8,
		"JPAEmitterManager::createSimpleEmitterID": 0x80304ba4,
		"createSimpleEmitterID": 0x80304ba4,
		"JPAEmitterManager::createEmitter": 0x80304c0c,
		"createEmitter": 0x80304c0c,
		"JPAEmitterManager::deleteEmitter": 0x80304ca4,
		"deleteEmitter": 0x80304ca4,
		"JPAEmitterManager::forceDeleteEmitter": 0x80304d08,
		"forceDeleteEmitter": 0x80304d08,
		"JPABaseField::JPABaseField": 0x80304d70,
		"JPABaseField::~JPABaseField": 0x80304e08,
		"JPABaseField::set": 0x80304e70,
		"JPABaseField::checkMaxDistance": 0x80304e74,
		"JPABaseField::calcFieldFadeScale": 0x80304ecc,
		"calcFieldFadeScale": 0x80304ecc,
		"JPABaseField::calcFieldVelocity": 0x80304ff0,
		"calcFieldVelocity": 0x80304ff0,
		"JPABaseField::affect": 0x80305160,
		"JPABaseField::loadFieldBlock": 0x80305180,
		"loadFieldBlock": 0x80305180,
		"JPAGravityField::JPAGravityField": 0x803053dc,
		"JPAGravityField::~JPAGravityField": 0x80305420,
		"JPAGravityField::set": 0x80305498,
		"JPAAirField::JPAAirField": 0x80305534,
		"JPAAirField::set": 0x80305578,
		"JPAAirField::affect": 0x803056c0,
		"JPAParticle::getBaseVelVec": 0x803058f8,
		"getBaseVelVec": 0x803058f8,
		"JPAMagnetField::JPAMagnetField": 0x80305914,
		"JPAMagnetField::~JPAMagnetField": 0x80305958,
		"JPAMagnetField::set": 0x803059d0,
		"JPAMagnetField::affect": 0x80305a48,
		"JPANewtonField::JPANewtonField": 0x80305b88,
		"JPANewtonField::~JPANewtonField": 0x80305bcc,
		"JPANewtonField::set": 0x80305c44,
		"JPANewtonField::affect": 0x80305cc8,
		"JPAVortexField::JPAVortexField": 0x80305ec4,
		"JPAVortexField::~JPAVortexField": 0x80305f1c,
		"JPAVortexField::set": 0x80305f94,
		"JPAVortexField::affect": 0x80305fec,
		"JPAVortexField::checkMaxDistance": 0x80306154,
		"JPAConvectionField::JPAConvectionField": 0x8030615c,
		"JPAConvectionField::~JPAConvectionField": 0x803061c0,
		"JPAConvectionField::set": 0x80306238,
		"JPAConvectionField::affect": 0x803064ec,
		"JPAConvectionField::checkMaxDistance": 0x803067e4,
		"JPARandomField::JPARandomField": 0x803067ec,
		"JPARandomField::~JPARandomField": 0x80306830,
		"JPARandomField::affect": 0x803068a8,
		"JPADragField::JPADragField": 0x803069e8,
		"JPADragField::~JPADragField": 0x80306a2c,
		"JPADragField::affect": 0x80306aa4,
		"JPAParticle::getDragForce": 0x80306bc4,
		"getDragForce": 0x80306bc4,
		"JPAFieldManager::JPAFieldManager": 0x80306bcc,
		"JPAFieldManager::deleteAllField": 0x80306bfc,
		"deleteAllField": 0x80306bfc,
		"JPAFieldManager::calcFieldParams": 0x80306c74,
		"calcFieldParams": 0x80306c74,
		"JPAFieldManager::affectField": 0x80306cfc,
		"affectField": 0x80306cfc,
		"JPAFieldManager::setField": 0x80306dd4,
		"setField": 0x80306dd4,
		"JPAFieldManager::setGravityField": 0x80306e78,
		"setGravityField": 0x80306e78,
		"JPAFieldManager::setAirField": 0x80306eec,
		"setAirField": 0x80306eec,
		"JPAFieldManager::setMagnetField": 0x80306f60,
		"setMagnetField": 0x80306f60,
		"JPAFieldManager::setNewtonField": 0x80306fd4,
		"setNewtonField": 0x80306fd4,
		"JPAFieldManager::setVortexField": 0x80307048,
		"setVortexField": 0x80307048,
		"JPAFieldManager::setConvectionField": 0x803070bc,
		"setConvectionField": 0x803070bc,
		"JPAFieldManager::setRandomField": 0x80307130,
		"setRandomField": 0x80307130,
		"JPAFieldManager::setDragField": 0x803071a4,
		"setDragField": 0x803071a4,
		"JPAAirField::~JPAAirField": 0x80307218,
		"JSystem::__sinit_JPAField_cpp": 0x80307290,
		"__sinit_JPAField_cpp": 0x80307290,
		"JSystem::JPASqrtf": 0x803072b8,
		"JPASqrtf": 0x803072b8,
		"JSystem::JPAGetXYZRotateMtx": 0x803072dc,
		"JPAGetXYZRotateMtx": 0x803072dc,
		"JSystem::JPAGetXYRotateMtx": 0x803074f4,
		"JPAGetXYRotateMtx": 0x803074f4,
		"JSystem::JPAGetYZRotateMtx": 0x80307628,
		"JPAGetYZRotateMtx": 0x80307628,
		"JSystem::JPAGetYRotateMtx": 0x8030775c,
		"JPAGetYRotateMtx": 0x8030775c,
		"JSystem::JPAVecToRotaMtx": 0x803077f4,
		"JPAVecToRotaMtx": 0x803077f4,
		"JSystem::JPAConvertFixToFloat": 0x803079a8,
		"JPAConvertFixToFloat": 0x803079a8,
		"JSystem::JPAConvertFixVecToFloatVec": 0x80307a64,
		"JPAConvertFixVecToFloatVec": 0x80307a64,
		"JSystem::JPAGetRMtxSTVecElement": 0x80307c8c,
		"JPAGetRMtxSTVecElement": 0x80307c8c,
		"JSystem::JPAGetRMtxTVecElement": 0x80307f20,
		"JPAGetRMtxTVecElement": 0x80307f20,
		"JSystem::JPAGetKeyFrameValue": 0x80308190,
		"JPAGetKeyFrameValue": 0x80308190,
		"JSystem::JPAGetKeyFrameInterpolation": 0x803081b0,
		"JPAGetKeyFrameInterpolation": 0x803081b0,
		"JPABaseParticle::incTimer": 0x80308260,
		"incTimer": 0x80308260,
		"JPABaseParticle::executeParticleCallBack": 0x803082c0,
		"executeParticleCallBack": 0x803082c0,
		"JPABaseParticle::drawParticleCallBack": 0x803082fc,
		"drawParticleCallBack": 0x803082fc,
		"JPAParticle::JPAParticle": 0x80308338,
		"JPAParticle::init": 0x80308384,
		"JPAParticle::setVelocity": 0x803083c4,
		"setVelocity": 0x803083c4,
		"JPAParticle::calcVelocity": 0x80308480,
		"JPABaseParticle::initGlobalPosition": 0x803085a8,
		"initGlobalPosition": 0x803085a8,
		"JPABaseParticle::calcGlobalPosition": 0x80308610,
		"calcGlobalPosition": 0x80308610,
		"JPABaseParticle::getCurrentPosition": 0x803086a8,
		"getCurrentPosition": 0x803086a8,
		"JPAParticle::checkCreateChildParticle": 0x80308734,
		"checkCreateChildParticle": 0x80308734,
		"JPAParticle::getDynamicsWeight": 0x803087f8,
		"getDynamicsWeight": 0x803087f8,
		"JPAParticle::getAirResistance": 0x80308800,
		"getAirResistance": 0x80308800,
		"JPAParticle::getCurrentDragForce": 0x80308808,
		"getCurrentDragForce": 0x80308808,
		"JPAParticle::accessBaseVelVec": 0x80308810,
		"accessBaseVelVec": 0x80308810,
		"JPAParticle::accessFAccVec": 0x80308818,
		"accessFAccVec": 0x80308818,
		"JPAParticle::accessFVelVec": 0x80308820,
		"accessFVelVec": 0x80308820,
		"JPAParticle::getDrawParamPPtr": 0x80308828,
		"getDrawParamPPtr": 0x80308828,
		"JPAParticle::getDrawParamCPtr": 0x80308830,
		"getDrawParamCPtr": 0x80308830,
		"JPAParticle::getWidth": 0x80308838,
		"JPAParticle::getHeight": 0x80308858,
		"JPADrawSetupTev::setupTev": 0x80308878,
		"setupTev": 0x80308878,
		"JPADraw::initialize": 0x80308bb8,
		"JPADraw::draw": 0x80308f1c,
		"JPADraw::calc": 0x803091a0,
		"JPADraw::calcParticle": 0x80309214,
		"calcParticle": 0x80309214,
		"JPADraw::calcChild": 0x803092bc,
		"calcChild": 0x803092bc,
		"JPADraw::initParticle": 0x80309364,
		"JPADraw::initChild": 0x803096b4,
		"initChild": 0x803096b4,
		"JPADraw::swapImage": 0x80309978,
		"swapImage": 0x80309978,
		"JPADraw::setDrawExecVisitorsBeforeCB": 0x803099d8,
		"setDrawExecVisitorsBeforeCB": 0x803099d8,
		"JPADraw::setDrawExecVisitorsAfterCB": 0x8030a080,
		"setDrawExecVisitorsAfterCB": 0x8030a080,
		"JPADraw::setDrawCalcVisitors": 0x8030a680,
		"setDrawCalcVisitors": 0x8030a680,
		"JPADraw::setParticleClipBoard": 0x8030af5c,
		"setParticleClipBoard": 0x8030af5c,
		"JPADraw::setChildClipBoard": 0x8030b2fc,
		"setChildClipBoard": 0x8030b2fc,
		"JPADraw::drawParticle": 0x8030b61c,
		"drawParticle": 0x8030b61c,
		"JPADraw::drawChild": 0x8030b87c,
		"drawChild": 0x8030b87c,
		"JPADraw::zDraw": 0x8030bb20,
		"zDraw": 0x8030bb20,
		"JPADraw::zDrawParticle": 0x8030bba8,
		"zDrawParticle": 0x8030bba8,
		"JPADraw::zDrawChild": 0x8030bdb8,
		"zDrawChild": 0x8030bdb8,
		"JPADraw::getMainTextureID": 0x8030c00c,
		"getMainTextureID": 0x8030c00c,
		"JPADraw::loadYBBMtx": 0x8030c04c,
		"loadYBBMtx": 0x8030c04c,
		"JSystem::__sinit_JPADraw_cpp": 0x8030c11c,
		"__sinit_JPADraw_cpp": 0x8030c11c,
		"JPADrawClipBoard::~JPADrawClipBoard": 0x8030c698,
		"JPADrawVisitorContainer::~JPADrawVisitorContainer": 0x8030c6d8,
		"JPADrawCalcChildScaleOut::~JPADrawCalcChildScaleOut": 0x8030d2b8,
		"JPADrawCalcChildAlphaOut::~JPADrawCalcChildAlphaOut": 0x8030d314,
		"JPADrawCalcAlphaFlickMultSin::~JPADrawCalcAlphaFlickMultSin": 0x8030d5dc,
		"JPADrawCalcAlphaFlickAddSin::~JPADrawCalcAlphaFlickAddSin": 0x8030d638,
		"JPADrawCalcAlphaFlickNrmSin::~JPADrawCalcAlphaFlickNrmSin": 0x8030d694,
		"JPADrawCalcAlpha::~JPADrawCalcAlpha": 0x8030d6f0,
		"JPADrawCalcColorCopyFromEmitter::~JPADrawCalcColorCopyFromEmitter": 0x8030d9b8,
		"JPADrawCalcEmitterVisitor::~JPADrawCalcEmitterVisitor": 0x8030db0c,
		"JPADrawCalcScaleAnmTimingReverseY::~JPADrawCalcScaleAnmTimingReverseY": 0x8030db58,
		"JPADrawCalcScaleAnmTimingReverseX::~JPADrawCalcScaleAnmTimingReverseX": 0x8030dbb4,
		"JPADrawCalcScaleAnmTimingRepeatY::~JPADrawCalcScaleAnmTimingRepeatY": 0x8030dc10,
		"JPADrawCalcScaleAnmTimingRepeatX::~JPADrawCalcScaleAnmTimingRepeatX": 0x8030dc6c,
		"JPADrawCalcScaleAnmTimingNormal::~JPADrawCalcScaleAnmTimingNormal": 0x8030dcc8,
		"JPADrawCalcScaleCopyX2Y::~JPADrawCalcScaleCopyX2Y": 0x8030dd24,
		"JPADrawCalcScaleYBySpeed::~JPADrawCalcScaleYBySpeed": 0x8030dd80,
		"JPADrawCalcScaleY::~JPADrawCalcScaleY": 0x8030dddc,
		"JPADrawCalcScaleXBySpeed::~JPADrawCalcScaleXBySpeed": 0x8030de38,
		"JPADrawCalcScaleX::~JPADrawCalcScaleX": 0x8030de94,
		"JPADrawCalcParticleVisitor::~JPADrawCalcParticleVisitor": 0x8030def0,
		"JPADrawExecStripeCross::~JPADrawExecStripeCross": 0x8030dfb8,
		"JPADrawExecStripe::~JPADrawExecStripe": 0x8030e014,
		"JPADrawExecLine::~JPADrawExecLine": 0x8030e070,
		"JPADrawExecPoint::~JPADrawExecPoint": 0x8030e0cc,
		"JPADrawExecRotationCross::~JPADrawExecRotationCross": 0x8030e128,
		"JPADrawExecRotation::~JPADrawExecRotation": 0x8030e184,
		"JPADrawExecDirBillBoard::~JPADrawExecDirBillBoard": 0x8030e1e0,
		"JPADrawExecRotDirectionalCross::~JPADrawExecRotDirectionalCross": 0x8030e23c,
		"JPADrawExecDirectionalCross::~JPADrawExecDirectionalCross": 0x8030e298,
		"JPADrawExecRotDirectional::~JPADrawExecRotDirectional": 0x8030e2f4,
		"JPADrawExecDirectional::~JPADrawExecDirectional": 0x8030e350,
		"JPADrawExecRotYBillBoard::~JPADrawExecRotYBillBoard": 0x8030e3ac,
		"JPADrawExecYBillBoard::~JPADrawExecYBillBoard": 0x8030e408,
		"JPADrawExecRotBillBoard::~JPADrawExecRotBillBoard": 0x8030e464,
		"JPADrawExecBillBoard::~JPADrawExecBillBoard": 0x8030e4c0,
		"JPADrawExecLoadExTex::~JPADrawExecLoadExTex": 0x8030e51c,
		"JPADrawExecLoadDefaultTexture::~JPADrawExecLoadDefaultTexture": 0x8030e5f4,
		"JPADrawExecRegisterPrmAEnv::~JPADrawExecRegisterPrmAEnv": 0x8030e650,
		"JPADrawExecRegisterPrmCEnv::~JPADrawExecRegisterPrmCEnv": 0x8030e6ac,
		"JPADrawExecRegisterEnvColorAnm::~JPADrawExecRegisterEnvColorAnm": 0x8030e708,
		"JPADrawExecRegisterPrmAlphaAnm::~JPADrawExecRegisterPrmAlphaAnm": 0x8030e764,
		"JPADrawExecRegisterPrmColorAnm::~JPADrawExecRegisterPrmColorAnm": 0x8030e7c0,
		"JPADrawExecRegisterColorChildPE::~JPADrawExecRegisterColorChildPE": 0x8030e81c,
		"JPADrawExecRegisterColorEmitterE::~JPADrawExecRegisterColorEmitterE": 0x8030e878,
		"JPADrawExecRegisterColorEmitterP::~JPADrawExecRegisterColorEmitterP": 0x8030e8d4,
		"JPADrawExecRegisterColorEmitterPE::~JPADrawExecRegisterColorEmitterPE": 0x8030e930,
		"JPADrawExecSetLineWidth::~JPADrawExecSetLineWidth": 0x8030e98c,
		"JPADrawExecSetPointSize::~JPADrawExecSetPointSize": 0x8030e9e8,
		"JPADrawExecParticleVisitor::~JPADrawExecParticleVisitor": 0x8030eac0,
		"JPADrawExecGenIdtMtx::~JPADrawExecGenIdtMtx": 0x8030eb0c,
		"JPADrawExecGenTexMtx0::~JPADrawExecGenTexMtx0": 0x8030eb68,
		"JPADrawExecGenPrjTexMtx::~JPADrawExecGenPrjTexMtx": 0x8030ebc4,
		"JPADrawExecGenPrjMtx::~JPADrawExecGenPrjMtx": 0x8030ec20,
		"JPADrawExecEmitterVisitor::~JPADrawExecEmitterVisitor": 0x8030ec7c,
		"JPADrawExecLoadExTex::exec": 0x8030ecc8,
		"JPADrawExecGenPrjMtx::exec": 0x8030eebc,
		"JPADrawExecGenPrjTexMtx::exec": 0x8030ef6c,
		"JPADrawExecGenTexMtx0::exec": 0x8030f118,
		"JPADrawExecGenIdtMtx::exec": 0x8030f160,
		"JPADrawExecLoadDefaultTexture::exec": 0x8030f374,
		"JPADrawExecSetPointSize::exec": 0x8030f3e0,
		"JPADrawExecSetLineWidth::exec": 0x8030f434,
		"JPADrawExecRegisterPrmColorAnm::exec": 0x8030f488,
		"JPADrawExecRegisterPrmAlphaAnm::exec": 0x8030f564,
		"JPADrawExecRegisterEnvColorAnm::exec": 0x8030f650,
		"JPADrawExecRegisterPrmCEnv::exec": 0x8030f6e8,
		"JPADrawExecRegisterPrmAEnv::exec": 0x8030f828,
		"JPADrawExecBillBoard::exec": 0x8030fb68,
		"JPADrawExecRotBillBoard::exec": 0x8030fd40,
		"JPADrawExecYBillBoard::exec": 0x8030ff5c,
		"JPADrawExecRotYBillBoard::exec": 0x80310180,
		"JSystem::dirTypeVel": 0x803103e8,
		"dirTypeVel": 0x803103e8,
		"JSystem::dirTypePos": 0x80310404,
		"dirTypePos": 0x80310404,
		"JSystem::dirTypePosInv": 0x80310420,
		"dirTypePosInv": 0x80310420,
		"JSystem::dirTypeEmtrDir": 0x80310460,
		"dirTypeEmtrDir": 0x80310460,
		"JSystem::dirTypePrevPtcl": 0x8031047c,
		"dirTypePrevPtcl": 0x8031047c,
		"JSystem::rotTypeY": 0x80310524,
		"rotTypeY": 0x80310524,
		"JSystem::rotTypeX": 0x80310564,
		"rotTypeX": 0x80310564,
		"JSystem::rotTypeZ": 0x803105a4,
		"rotTypeZ": 0x803105a4,
		"JSystem::rotTypeXYZ": 0x803105e4,
		"rotTypeXYZ": 0x803105e4,
		"JSystem::rotTypeYJiggle": 0x80310640,
		"rotTypeYJiggle": 0x80310640,
		"JPADrawExecDirectional::exec": 0x80310698,
		"JPADrawExecRotDirectional::exec": 0x80310aac,
		"JPADrawExecDirectionalCross::exec": 0x80310f08,
		"JPADrawExecRotDirectionalCross::exec": 0x80311460,
		"JPADrawExecDirBillBoard::exec": 0x80311a00,
		"JPADrawExecRotation::exec": 0x80311d50,
		"JPADrawExecRotationCross::exec": 0x80311f78,
		"JPADrawExecPoint::exec": 0x803122e4,
		"JPADrawExecLine::exec": 0x80312370,
		"JSystem::stripeGetNext": 0x80312530,
		"stripeGetNext": 0x80312530,
		"JSystem::stripeGetPrev": 0x80312538,
		"stripeGetPrev": 0x80312538,
		"JPADrawExecStripe::exec": 0x80312540,
		"JPADrawExecStripeCross::exec": 0x803129b0,
		"JPADrawExecRegisterColorEmitterPE::exec": 0x80313198,
		"JPADrawExecRegisterColorEmitterP::exec": 0x8031329c,
		"JPADrawExecRegisterColorEmitterE::exec": 0x8031333c,
		"JPADrawExecRegisterColorChildPE::exec": 0x803133c4,
		"JPADrawCalcScaleX::calc": 0x803137d4,
		"JPADrawCalcScaleY::calc": 0x80313878,
		"JPADrawCalcScaleXBySpeed::calc": 0x8031391c,
		"JPADrawCalcScaleYBySpeed::calc": 0x80313a4c,
		"JPADrawCalcScaleCopyX2Y::calc": 0x80313b7c,
		"JPADrawCalcScaleAnmTimingNormal::calc": 0x80313bb4,
		"JPADrawCalcScaleAnmTimingRepeatX::calc": 0x80313bc4,
		"JPADrawCalcScaleAnmTimingRepeatY::calc": 0x80313c30,
		"JPADrawCalcScaleAnmTimingReverseX::calc": 0x80313c9c,
		"JPADrawCalcScaleAnmTimingReverseY::calc": 0x80313d3c,
		"JPADrawCalcColorCopyFromEmitter::calc": 0x80313e94,
		"JPADrawCalcAlpha::calc": 0x803141a4,
		"JPADrawCalcAlphaFlickNrmSin::calc": 0x80314228,
		"JPADrawCalcAlphaFlickAddSin::calc": 0x80314318,
		"JPADrawCalcAlphaFlickMultSin::calc": 0x8031443c,
		"JPADrawCalcChildAlphaOut::calc": 0x803148dc,
		"JPADrawCalcChildScaleOut::calc": 0x80314924,
		"JPAExTexShape::JPAExTexShape": 0x80314a7c,
		"JPADataBlock::~JPADataBlock": 0x80314b9c,
		"JPAExTexShape::~JPAExTexShape": 0x80314be8,
		"JPADataBlock::JPADataBlock": 0x80314c44,
		"JPAEmitterLoaderDataBase::load": 0x80314cc4,
		"JPAEmitterLoader_v10::~JPAEmitterLoader_v10": 0x80314d48,
		"JPAEmitterLoader_v10::JPAEmitterLoader_v10": 0x80314da4,
		"JPAEmitterLoader::~JPAEmitterLoader": 0x80314dd4,
		"JPAEmitterLoader_v10::load": 0x80314e20,
		"JPAKeyFrameAnime::JPAKeyFrameAnime": 0x80315208,
		"JPAKeyFrameAnime::~JPAKeyFrameAnime": 0x80315244,
		"JSystem::makeColorTable": 0x803152a0,
		"makeColorTable": 0x803152a0,
		"JPABaseShape::JPABaseShape": 0x80315510,
		"JPABaseShape::~JPABaseShape": 0x80315a70,
		"JPAExtraShape::JPAExtraShape": 0x80315acc,
		"JPAExtraShape::~JPAExtraShape": 0x80315d80,
		"JPATextureResource::JPATextureResource": 0x80315ddc,
		"JPATextureResource::registration": 0x80315e4c,
		"registration": 0x80315e4c,
		"JPAEmitterResource::getByUserIndex": 0x80315f08,
		"getByUserIndex": 0x80315f08,
		"JPAResourceManager::JPAResourceManager": 0x80315f4c,
		"JPASweepShape::JPASweepShape": 0x803160d8,
		"JPASweepShape::~JPASweepShape": 0x80316224,
		"JPATexture::JPATexture": 0x80316280,
		"JPADefaultTexture::initialize": 0x803162e0,
		"JPATexture::~JPATexture": 0x80316788,
		"JStage::TAmbientLight::~TAmbientLight": 0x80316800,
		"JStage::TAmbientLight::JSGFGetType": 0x80316864,
		"JStage::TAmbientLight::JSGGetColor": 0x8031686c,
		"JStage::TAmbientLight::JSGSetColor": 0x80316884,
		"JStage::TCamera::~TCamera": 0x80316888,
		"JStage::TCamera::JSGFGetType": 0x803168ec,
		"JStage::TCamera::JSGGetProjectionType": 0x803168f4,
		"JStage::TCamera::JSGSetProjectionType": 0x803168fc,
		"JStage::TCamera::JSGGetProjectionNear": 0x80316900,
		"JStage::TCamera::JSGSetProjectionNear": 0x80316908,
		"JStage::TCamera::JSGGetProjectionFar": 0x8031690c,
		"JStage::TCamera::JSGSetProjectionFar": 0x80316914,
		"JStage::TCamera::JSGGetProjectionFovy": 0x80316918,
		"JStage::TCamera::JSGSetProjectionFovy": 0x80316920,
		"JStage::TCamera::JSGGetProjectionAspect": 0x80316924,
		"JStage::TCamera::JSGSetProjectionAspect": 0x8031692c,
		"JStage::TCamera::JSGGetProjectionField": 0x80316930,
		"JStage::TCamera::JSGSetProjectionField": 0x80316934,
		"JStage::TCamera::JSGGetViewType": 0x80316938,
		"JSGGetViewType": 0x80316938,
		"JStage::TCamera::JSGSetViewType": 0x80316940,
		"JSGSetViewType": 0x80316940,
		"JStage::TCamera::JSGGetViewPosition": 0x80316944,
		"JStage::TCamera::JSGSetViewPosition": 0x80316948,
		"JStage::TCamera::JSGGetViewUpVector": 0x8031694c,
		"JStage::TCamera::JSGSetViewUpVector": 0x80316950,
		"JStage::TCamera::JSGGetViewTargetPosition": 0x80316954,
		"JStage::TCamera::JSGSetViewTargetPosition": 0x80316958,
		"JStage::TCamera::JSGGetViewRoll": 0x8031695c,
		"JSGGetViewRoll": 0x8031695c,
		"JStage::TCamera::JSGSetViewRoll": 0x80316964,
		"JSGSetViewRoll": 0x80316964,
		"JStage::TActor::~TActor": 0x80316968,
		"JStage::TActor::JSGFGetType": 0x803169cc,
		"JStage::TActor::JSGGetTranslation": 0x803169d4,
		"JStage::TActor::JSGSetTranslation": 0x803169d8,
		"JStage::TActor::JSGGetScaling": 0x803169dc,
		"JStage::TActor::JSGSetScaling": 0x803169e0,
		"JStage::TActor::JSGGetRotation": 0x803169e4,
		"JStage::TActor::JSGSetRotation": 0x803169e8,
		"JStage::TActor::JSGGetShape": 0x803169ec,
		"JSGGetShape": 0x803169ec,
		"JStage::TActor::JSGSetShape": 0x803169f4,
		"JSGSetShape": 0x803169f4,
		"JStage::TActor::JSGGetAnimation": 0x803169f8,
		"JSGGetAnimation": 0x803169f8,
		"JStage::TActor::JSGSetAnimation": 0x80316a00,
		"JSGSetAnimation": 0x80316a00,
		"JStage::TActor::JSGGetAnimationFrame": 0x80316a04,
		"JSGGetAnimationFrame": 0x80316a04,
		"JStage::TActor::JSGSetAnimationFrame": 0x80316a0c,
		"JSGSetAnimationFrame": 0x80316a0c,
		"JStage::TActor::JSGGetAnimationFrameMax": 0x80316a10,
		"JSGGetAnimationFrameMax": 0x80316a10,
		"JStage::TLight::~TLight": 0x80316a18,
		"JStage::TLight::JSGFGetType": 0x80316a7c,
		"JStage::TLight::JSGGetLightType": 0x80316a84,
		"JStage::TLight::JSGSetLightType": 0x80316a8c,
		"JStage::TLight::JSGGetColor": 0x80316a90,
		"JStage::TLight::JSGSetColor": 0x80316aa8,
		"JStage::TLight::JSGGetDistanceAttenuation": 0x80316aac,
		"JSGGetDistanceAttenuation": 0x80316aac,
		"JStage::TLight::JSGSetDistanceAttenuation": 0x80316ab0,
		"JSGSetDistanceAttenuation": 0x80316ab0,
		"JStage::TLight::JSGGetAngleAttenuation": 0x80316ab4,
		"JSGGetAngleAttenuation": 0x80316ab4,
		"JStage::TLight::JSGSetAngleAttenuation": 0x80316ab8,
		"JSGSetAngleAttenuation": 0x80316ab8,
		"JStage::TLight::JSGGetPosition": 0x80316abc,
		"JStage::TLight::JSGSetPosition": 0x80316ac0,
		"JStage::TLight::JSGGetDirection": 0x80316ac4,
		"JSGGetDirection": 0x80316ac4,
		"JStage::TLight::JSGSetDirection": 0x80316ac8,
		"JSGSetDirection": 0x80316ac8,
		"JStage::TObject::~TObject": 0x80316acc,
		"JStage::TObject::JSGGetName": 0x80316b18,
		"JSGGetName": 0x80316b18,
		"JStage::TObject::JSGGetFlag": 0x80316b20,
		"JStage::TObject::JSGSetFlag": 0x80316b28,
		"JStage::TObject::JSGGetData": 0x80316b2c,
		"JSGGetData": 0x80316b2c,
		"JStage::TObject::JSGSetData": 0x80316b34,
		"JSGSetData": 0x80316b34,
		"JStage::TObject::JSGGetParent": 0x80316b38,
		"JSGGetParent": 0x80316b38,
		"JStage::TObject::JSGSetParent": 0x80316b3c,
		"JSGSetParent": 0x80316b3c,
		"JStage::TObject::JSGSetRelation": 0x80316b40,
		"JSGSetRelation": 0x80316b40,
		"JStage::TSystem::~TSystem": 0x80316b44,
		"JStage::TSystem::JSGFGetType": 0x80316ba8,
		"JStage::TSystem::JSGFindObject": 0x80316bb0,
		"JStage::TSystem::JSGCreateObject": 0x80316bb8,
		"JSGCreateObject": 0x80316bb8,
		"JStage::TSystem::JSGDestroyObject": 0x80316bc0,
		"JSGDestroyObject": 0x80316bc0,
		"JStage::TSystem::JSGGetSystemData": 0x80316bc4,
		"JSGGetSystemData": 0x80316bc4,
		"JStage::TSystem::JSGSetSystemData": 0x80316bcc,
		"JSGSetSystemData": 0x80316bcc,
		"Runtime.PPCEABI.H::__va_arg": 0x803175cc,
		"__va_arg": 0x803175cc,
		"Runtime.PPCEABI.H::__destroy_global_chain": 0x803176c0,
		"__destroy_global_chain": 0x803176c0,
		"Runtime.PPCEABI.H::__register_global_object": 0x80317708,
		"__register_global_object": 0x80317708,
		"Runtime.PPCEABI.H::__destroy_new_array": 0x80317720,
		"__destroy_new_array": 0x80317720,
		"Runtime.PPCEABI.H::__destroy_arr": 0x8031779c,
		"__destroy_arr": 0x8031779c,
		"Runtime.PPCEABI.H::__construct_array": 0x80317814,
		"__construct_array": 0x80317814,
		"__partial_array_destructor::~__partial_array_destructor": 0x80317914,
		"Runtime.PPCEABI.H::__construct_new_array": 0x803179cc,
		"__construct_new_array": 0x803179cc,
		"Runtime.PPCEABI.H::__ptmf_test": 0x80317ad4,
		"__ptmf_test": 0x80317ad4,
		"Runtime.PPCEABI.H::__ptmf_scall": 0x80317b04,
		"__ptmf_scall": 0x80317b04,
		"Runtime.PPCEABI.H::__unregister_fragment": 0x80317b2c,
		"__unregister_fragment": 0x80317b2c,
		"Runtime.PPCEABI.H::__register_fragment": 0x80317b60,
		"__register_fragment": 0x80317b60,
		"Runtime.PPCEABI.H::__cvt_fp2unsigned": 0x80317b9c,
		"__cvt_fp2unsigned": 0x80317b9c,
		"Runtime.PPCEABI.H::__div2u": 0x80317bf8,
		"__div2u": 0x80317bf8,
		"Runtime.PPCEABI.H::__div2i": 0x80317ce4,
		"__div2i": 0x80317ce4,
		"Runtime.PPCEABI.H::__mod2u": 0x80317e1c,
		"__mod2u": 0x80317e1c,
		"Runtime.PPCEABI.H::__mod2i": 0x80317f00,
		"__mod2i": 0x80317f00,
		"Runtime.PPCEABI.H::__shl2i": 0x8031800c,
		"__shl2i": 0x8031800c,
		"Runtime.PPCEABI.H::__shr2u": 0x80318030,
		"__shr2u": 0x80318030,
		"Runtime.PPCEABI.H::__shr2i": 0x80318054,
		"__shr2i": 0x80318054,
		"Runtime.PPCEABI.H::__cvt_sll_flt": 0x8031807c,
		"__cvt_sll_flt": 0x8031807c,
		"Runtime.PPCEABI.H::__cvt_dbl_usll": 0x80318130,
		"__cvt_dbl_usll": 0x80318130,
		"Runtime.PPCEABI.H::GetR2": 0x803181fc,
		"GetR2": 0x803181fc,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions": 0x80318204,
		"__fini_cpp_exceptions": 0x80318204,
		"Runtime.PPCEABI.H::__init_cpp_exceptions": 0x80318238,
		"__init_cpp_exceptions": 0x80318238,
		"MSL_C.PPCEABI.bare.H::exit": 0x80318278,
		"exit": 0x80318278,
		"MSL_C.PPCEABI.bare.H::__num2dec": 0x80318384,
		"__num2dec": 0x80318384,
		"MSL_C.PPCEABI.bare.H::__flush_buffer": 0x80318738,
		"__flush_buffer": 0x80318738,
		"MSL_C.PPCEABI.bare.H::__prep_buffer": 0x80318804,
		"__prep_buffer": 0x80318804,
		"MSL_C.PPCEABI.bare.H::__kill_critical_regions": 0x80318838,
		"__kill_critical_regions": 0x80318838,
		"MSL_C.PPCEABI.bare.H::toupper": 0x8031883c,
		"toupper": 0x8031883c,
		"MSL_C.PPCEABI.bare.H::tolower": 0x80318864,
		"tolower": 0x80318864,
		"MSL_C.PPCEABI.bare.H::fwrite": 0x8031888c,
		"fwrite": 0x8031888c,
		"MSL_C.PPCEABI.bare.H::wcstombs": 0x80318b68,
		"wcstombs": 0x80318b68,
		"MSL_C.PPCEABI.bare.H::memcmp": 0x80318ba4,
		"memcmp": 0x80318ba4,
		"MSL_C.PPCEABI.bare.H::memchr": 0x80318be8,
		"memchr": 0x80318be8,
		"MSL_C.PPCEABI.bare.H::memmove": 0x80318c14,
		"memmove": 0x80318c14,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_unaligned": 0x80318cf0,
		"__copy_longs_rev_unaligned": 0x80318cf0,
		"MSL_C.PPCEABI.bare.H::__copy_longs_unaligned": 0x80318da0,
		"__copy_longs_unaligned": 0x80318da0,
		"MSL_C.PPCEABI.bare.H::__copy_longs_rev_aligned": 0x80318e64,
		"__copy_longs_rev_aligned": 0x80318e64,
		"MSL_C.PPCEABI.bare.H::__copy_longs_aligned": 0x80318f10,
		"__copy_longs_aligned": 0x80318f10,
		"MSL_C.PPCEABI.bare.H::__stdio_atexit": 0x80318fcc,
		"__stdio_atexit": 0x80318fcc,
		"MSL_C.PPCEABI.bare.H::sprintf": 0x80318fd0,
		"sprintf": 0x80318fd0,
		"MSL_C.PPCEABI.bare.H::snprintf": 0x803190a4,
		"snprintf": 0x803190a4,
		"MSL_C.PPCEABI.bare.H::vsnprintf": 0x80319174,
		"vsnprintf": 0x80319174,
		"MSL_C.PPCEABI.bare.H::vprintf": 0x803191e4,
		"vprintf": 0x803191e4,
		"MSL_C.PPCEABI.bare.H::__StringWrite": 0x80319260,
		"__StringWrite": 0x80319260,
		"MSL_C.PPCEABI.bare.H::__FileWrite": 0x803192cc,
		"__FileWrite": 0x803192cc,
		"MSL_C.PPCEABI.bare.H::__pformatter": 0x80319324,
		"__pformatter": 0x80319324,
		"MSL_C.PPCEABI.bare.H::float2str": 0x80319954,
		"float2str": 0x80319954,
		"MSL_C.PPCEABI.bare.H::round_decimal": 0x80319f8c,
		"round_decimal": 0x80319f8c,
		"MSL_C.PPCEABI.bare.H::longlong2str": 0x8031a0c0,
		"longlong2str": 0x8031a0c0,
		"MSL_C.PPCEABI.bare.H::long2str": 0x8031a3a0,
		"long2str": 0x8031a3a0,
		"MSL_C.PPCEABI.bare.H::parse_format": 0x8031a5c4,
		"parse_format": 0x8031a5c4,
		"MSL_C.PPCEABI.bare.H::srand": 0x8031aa9c,
		"srand": 0x8031aa9c,
		"MSL_C.PPCEABI.bare.H::rand": 0x8031aaa4,
		"rand": 0x8031aaa4,
		"MSL_C.PPCEABI.bare.H::__StringRead": 0x8031aac8,
		"__StringRead": 0x8031aac8,
		"MSL_C.PPCEABI.bare.H::strstr": 0x8031ab58,
		"strstr": 0x8031ab58,
		"MSL_C.PPCEABI.bare.H::strrchr": 0x8031abc4,
		"strrchr": 0x8031abc4,
		"MSL_C.PPCEABI.bare.H::strchr": 0x8031ac0c,
		"strchr": 0x8031ac0c,
		"MSL_C.PPCEABI.bare.H::strcmp": 0x8031ac3c,
		"strcmp": 0x8031ac3c,
		"MSL_C.PPCEABI.bare.H::strcat": 0x8031ad60,
		"strcat": 0x8031ad60,
		"MSL_C.PPCEABI.bare.H::strncpy": 0x8031ad8c,
		"strncpy": 0x8031ad8c,
		"MSL_C.PPCEABI.bare.H::strcpy": 0x8031add0,
		"strcpy": 0x8031add0,
		"MSL_C.PPCEABI.bare.H::strlen": 0x8031ae84,
		"strlen": 0x8031ae84,
		"MSL_C.PPCEABI.bare.H::strtol": 0x8031aea4,
		"strtol": 0x8031aea4,
		"MSL_C.PPCEABI.bare.H::strtoul": 0x8031af94,
		"strtoul": 0x8031af94,
		"MSL_C.PPCEABI.bare.H::__strtoul": 0x8031b040,
		"__strtoul": 0x8031b040,
		"MSL_C.PPCEABI.bare.H::__close_console": 0x8031b388,
		"__close_console": 0x8031b388,
		"MSL_C.PPCEABI.bare.H::__write_console": 0x8031b390,
		"__write_console": 0x8031b390,
		"MSL_C.PPCEABI.bare.H::__read_console": 0x8031b428,
		"__read_console": 0x8031b428,
		"MSL_C.PPCEABI.bare.H::fwide": 0x8031b508,
		"fwide": 0x8031b508,
		"MSL_C.PPCEABI.bare.H::fabs": 0x8031b588,
		"fabs": 0x8031b588,
		"MSL_C.PPCEABI.bare.H::__ieee754_atan2": 0x8031b590,
		"__ieee754_atan2": 0x8031b590,
		"MSL_C.PPCEABI.bare.H::frexp": 0x8031ba68,
		"frexp": 0x8031ba68,
		"MSL_C.PPCEABI.bare.H::atan2": 0x8031bb04,
		"atan2": 0x8031bb04,
		"MSL_C.PPCEABI.bare.H::fabsf": 0x8031bb24,
		"fabsf": 0x8031bb24,
		"MSL_C.PPCEABI.bare.H::atanf": 0x8031bb2c,
		"atanf": 0x8031bb2c,
		"MSL_C.PPCEABI.bare.H::_inv_sqrtf": 0x8031bd40,
		"_inv_sqrtf": 0x8031bd40,
		"MSL_C.PPCEABI.bare.H::acosf": 0x8031bdb0,
		"acosf": 0x8031bdb0,
		"MSL_C.PPCEABI.bare.H::atan2f": 0x8031bdf4,
		"atan2f": 0x8031bdf4,
		"MSL_C.PPCEABI.bare.H::tanf": 0x8031becc,
		"tanf": 0x8031becc,
		"MSL_C.PPCEABI.bare.H::cos": 0x8031bf10,
		"cos": 0x8031bf10,
		"MSL_C.PPCEABI.bare.H::sin": 0x8031bf30,
		"sin": 0x8031bf30,
		"MSL_C.PPCEABI.bare.H::cosf": 0x8031bf50,
		"cosf": 0x8031bf50,
		"MSL_C.PPCEABI.bare.H::sinf": 0x8031c0e4,
		"sinf": 0x8031c0e4,
		"MSL_C.PPCEABI.bare.H::__sinit_trigf_c": 0x8031c288,
		"__sinit_trigf_c": 0x8031c288,
		"MSL_C.PPCEABI.bare.H::powf": 0x8031c2b8,
		"powf": 0x8031c2b8,
		"MSL_C.PPCEABI.bare.H::expf": 0x8031c9f8,
		"expf": 0x8031c9f8,
		"TRK_MINNOW_DOLPHIN::TRKHandleRequestEvent": 0x8031cae0,
		"TRKHandleRequestEvent": 0x8031cae0,
		"TRK_MINNOW_DOLPHIN::TRKHandleSupportEvent": 0x8031cb08,
		"TRKHandleSupportEvent": 0x8031cb08,
		"TRK_MINNOW_DOLPHIN::TRKIdle": 0x8031cb28,
		"TRKIdle": 0x8031cb28,
		"TRK_MINNOW_DOLPHIN::TRKNubMainLoop": 0x8031cb54,
		"TRKNubMainLoop": 0x8031cb54,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEventQueue": 0x8031cc48,
		"TRKInitializeEventQueue": 0x8031cc48,
		"TRK_MINNOW_DOLPHIN::TRKCopyEvent": 0x8031cca4,
		"TRKCopyEvent": 0x8031cca4,
		"TRK_MINNOW_DOLPHIN::TRKGetNextEvent": 0x8031ccc8,
		"TRKGetNextEvent": 0x8031ccc8,
		"TRK_MINNOW_DOLPHIN::TRKPostEvent": 0x8031cd88,
		"TRKPostEvent": 0x8031cd88,
		"TRK_MINNOW_DOLPHIN::TRKConstructEvent": 0x8031ce68,
		"TRKConstructEvent": 0x8031ce68,
		"TRK_MINNOW_DOLPHIN::TRKDestructEvent": 0x8031ce80,
		"TRKDestructEvent": 0x8031ce80,
		"TRK_MINNOW_DOLPHIN::TRKInitializeNub": 0x8031cea4,
		"TRKInitializeNub": 0x8031cea4,
		"TRK_MINNOW_DOLPHIN::TRKTerminateNub": 0x8031cf78,
		"TRKTerminateNub": 0x8031cf78,
		"TRK_MINNOW_DOLPHIN::TRKNubWelcome": 0x8031cf9c,
		"TRKNubWelcome": 0x8031cf9c,
		"TRK_MINNOW_DOLPHIN::TRKInitializeEndian": 0x8031cfc4,
		"TRKInitializeEndian": 0x8031cfc4,
		"TRK_MINNOW_DOLPHIN::TRKMessageSend": 0x8031d038,
		"TRKMessageSend": 0x8031d038,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferUsed": 0x8031d060,
		"TRKSetBufferUsed": 0x8031d060,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMessageBuffers": 0x8031d068,
		"TRKInitializeMessageBuffers": 0x8031d068,
		"TRK_MINNOW_DOLPHIN::TRKGetFreeBuffer": 0x8031d0e0,
		"TRKGetFreeBuffer": 0x8031d0e0,
		"TRK_MINNOW_DOLPHIN::TRKGetBuffer": 0x8031d17c,
		"TRKGetBuffer": 0x8031d17c,
		"TRK_MINNOW_DOLPHIN::TRKReleaseBuffer": 0x8031d1a8,
		"TRKReleaseBuffer": 0x8031d1a8,
		"TRK_MINNOW_DOLPHIN::TRKResetBuffer": 0x8031d210,
		"TRKResetBuffer": 0x8031d210,
		"TRK_MINNOW_DOLPHIN::TRKSetBufferPosition": 0x8031d250,
		"TRKSetBufferPosition": 0x8031d250,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer": 0x8031d280,
		"TRKAppendBuffer": 0x8031d280,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer": 0x8031d324,
		"TRKReadBuffer": 0x8031d324,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui16": 0x8031d3b0,
		"TRKAppendBuffer1_ui16": 0x8031d3b0,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui32": 0x8031d404,
		"TRKAppendBuffer1_ui32": 0x8031d404,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer1_ui64": 0x8031d468,
		"TRKAppendBuffer1_ui64": 0x8031d468,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui8": 0x8031d4f0,
		"TRKAppendBuffer_ui8": 0x8031d4f0,
		"TRK_MINNOW_DOLPHIN::TRKAppendBuffer_ui32": 0x8031d558,
		"TRKAppendBuffer_ui32": 0x8031d558,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui8": 0x8031d5d4,
		"TRKReadBuffer1_ui8": 0x8031d5d4,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui16": 0x8031d5f8,
		"TRKReadBuffer1_ui16": 0x8031d5f8,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui32": 0x8031d678,
		"TRKReadBuffer1_ui32": 0x8031d678,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer1_ui64": 0x8031d708,
		"TRKReadBuffer1_ui64": 0x8031d708,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui8": 0x8031d7b8,
		"TRKReadBuffer_ui8": 0x8031d7b8,
		"TRK_MINNOW_DOLPHIN::TRKReadBuffer_ui32": 0x8031d82c,
		"TRKReadBuffer_ui32": 0x8031d82c,
		"TRK_MINNOW_DOLPHIN::TRKTestForPacket": 0x8031d8a8,
		"TRKTestForPacket": 0x8031d8a8,
		"TRK_MINNOW_DOLPHIN::TRKGetInput": 0x8031d978,
		"TRKGetInput": 0x8031d978,
		"TRK_MINNOW_DOLPHIN::TRKProcessInput": 0x8031d9f4,
		"TRKProcessInput": 0x8031d9f4,
		"TRK_MINNOW_DOLPHIN::TRKInitializeSerialHandler": 0x8031da44,
		"TRKInitializeSerialHandler": 0x8031da44,
		"TRK_MINNOW_DOLPHIN::TRKTerminateSerialHandler": 0x8031da68,
		"TRKTerminateSerialHandler": 0x8031da68,
		"TRK_MINNOW_DOLPHIN::usr_put_initialize": 0x8031da70,
		"usr_put_initialize": 0x8031da70,
		"TRK_MINNOW_DOLPHIN::TRKInitializeDispatcher": 0x8031da74,
		"TRKInitializeDispatcher": 0x8031da74,
		"TRK_MINNOW_DOLPHIN::TRKDispatchMessage": 0x8031da88,
		"TRKDispatchMessage": 0x8031da88,
		"TRK_MINNOW_DOLPHIN::TRKMessageIntoReply": 0x8031db0c,
		"TRKMessageIntoReply": 0x8031db0c,
		"TRK_MINNOW_DOLPHIN::TRKSendACK": 0x8031dba4,
		"TRKSendACK": 0x8031dba4,
		"TRK_MINNOW_DOLPHIN::TRKStandardACK": 0x8031dbf4,
		"TRKStandardACK": 0x8031dbf4,
		"TRK_MINNOW_DOLPHIN::TRKDoUnsupported": 0x8031dc28,
		"TRKDoUnsupported": 0x8031dc28,
		"TRK_MINNOW_DOLPHIN::TRKDoConnect": 0x8031dc50,
		"TRKDoConnect": 0x8031dc50,
		"TRK_MINNOW_DOLPHIN::TRKDoDisconnect": 0x8031dc78,
		"TRKDoDisconnect": 0x8031dc78,
		"TRK_MINNOW_DOLPHIN::TRKDoReset": 0x8031dcc8,
		"TRKDoReset": 0x8031dcc8,
		"TRK_MINNOW_DOLPHIN::TRKDoVersions": 0x8031dcf8,
		"TRKDoVersions": 0x8031dcf8,
		"TRK_MINNOW_DOLPHIN::TRKDoSupportMask": 0x8031de7c,
		"TRKDoSupportMask": 0x8031de7c,
		"TRK_MINNOW_DOLPHIN::TRKDoCPUType": 0x8031df58,
		"TRKDoCPUType": 0x8031df58,
		"TRK_MINNOW_DOLPHIN::TRKDoReadMemory": 0x8031e19c,
		"TRKDoReadMemory": 0x8031e19c,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteMemory": 0x8031e384,
		"TRKDoWriteMemory": 0x8031e384,
		"TRK_MINNOW_DOLPHIN::TRKDoReadRegisters": 0x8031e580,
		"TRKDoReadRegisters": 0x8031e580,
		"TRK_MINNOW_DOLPHIN::TRKDoWriteRegisters": 0x8031e784,
		"TRKDoWriteRegisters": 0x8031e784,
		"TRK_MINNOW_DOLPHIN::TRKDoFlushCache": 0x8031e98c,
		"TRKDoFlushCache": 0x8031e98c,
		"TRK_MINNOW_DOLPHIN::TRKDoContinue": 0x8031eac4,
		"TRKDoContinue": 0x8031eac4,
		"TRK_MINNOW_DOLPHIN::TRKDoStep": 0x8031eb28,
		"TRKDoStep": 0x8031eb28,
		"TRK_MINNOW_DOLPHIN::TRKDoStop": 0x8031ed2c,
		"TRKDoStop": 0x8031ed2c,
		"TRK_MINNOW_DOLPHIN::TRKSuppAccessFile": 0x8031edb0,
		"TRKSuppAccessFile": 0x8031edb0,
		"TRK_MINNOW_DOLPHIN::TRKRequestSend": 0x8031f088,
		"TRKRequestSend": 0x8031f088,
		"TRK_MINNOW_DOLPHIN::TRKInitializeMutex": 0x8031f22c,
		"TRKInitializeMutex": 0x8031f22c,
		"TRK_MINNOW_DOLPHIN::TRKAcquireMutex": 0x8031f234,
		"TRKAcquireMutex": 0x8031f234,
		"TRK_MINNOW_DOLPHIN::TRKReleaseMutex": 0x8031f23c,
		"TRKReleaseMutex": 0x8031f23c,
		"TRK_MINNOW_DOLPHIN::TRKDoNotifyStopped": 0x8031f244,
		"TRKDoNotifyStopped": 0x8031f244,
		"TRK_MINNOW_DOLPHIN::TRK_flush_cache": 0x8031f31c,
		"TRK_flush_cache": 0x8031f31c,
		"TRK_MINNOW_DOLPHIN::TRK_fill_mem": 0x8031f354,
		"TRK_fill_mem": 0x8031f354,
		"TRK_MINNOW_DOLPHIN::__TRK_get_MSR": 0x8031f418,
		"__TRK_get_MSR": 0x8031f418,
		"TRK_MINNOW_DOLPHIN::__TRK_set_MSR": 0x8031f420,
		"__TRK_set_MSR": 0x8031f420,
		"TRK_MINNOW_DOLPHIN::TRKValidMemory32": 0x8031f428,
		"TRKValidMemory32": 0x8031f428,
		"TRK_MINNOW_DOLPHIN::TRK_ppc_memcpy": 0x8031f560,
		"TRK_ppc_memcpy": 0x8031f560,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessMemory": 0x8031f59c,
		"TRKTargetAccessMemory": 0x8031f59c,
		"TRK_MINNOW_DOLPHIN::TRKTargetReadInstruction": 0x8031f700,
		"TRKTargetReadInstruction": 0x8031f700,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessDefault": 0x8031f74c,
		"TRKTargetAccessDefault": 0x8031f74c,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessFP": 0x8031f848,
		"TRKTargetAccessFP": 0x8031f848,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended1": 0x8031f990,
		"TRKTargetAccessExtended1": 0x8031f990,
		"TRK_MINNOW_DOLPHIN::TRKTargetAccessExtended2": 0x8031fb08,
		"TRKTargetAccessExtended2": 0x8031fb08,
		"TRK_MINNOW_DOLPHIN::TRKTargetVersions": 0x8031fc84,
		"TRKTargetVersions": 0x8031fc84,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportMask": 0x8031fcac,
		"TRKTargetSupportMask": 0x8031fcac,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUType": 0x8031fd50,
		"TRKTargetCPUType": 0x8031fd50,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandler": 0x8031fdb8,
		"TRKInterruptHandler": 0x8031fdb8,
		"TRK_MINNOW_DOLPHIN::TRKExceptionHandler": 0x8031ff4c,
		"TRKExceptionHandler": 0x8031ff4c,
		"TRK_MINNOW_DOLPHIN::TRKPostInterruptEvent": 0x8031ffe8,
		"TRKPostInterruptEvent": 0x8031ffe8,
		"TRK_MINNOW_DOLPHIN::TRKSwapAndGo": 0x80320098,
		"TRKSwapAndGo": 0x80320098,
		"TRK_MINNOW_DOLPHIN::TRKInterruptHandlerEnableInterrupts": 0x8032015c,
		"TRKInterruptHandlerEnableInterrupts": 0x8032015c,
		"TRK_MINNOW_DOLPHIN::TRKTargetInterrupt": 0x803201b0,
		"TRKTargetInterrupt": 0x803201b0,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddStopInfo": 0x80320214,
		"TRKTargetAddStopInfo": 0x80320214,
		"TRK_MINNOW_DOLPHIN::TRKTargetAddExceptionInfo": 0x803202a4,
		"TRKTargetAddExceptionInfo": 0x803202a4,
		"TRK_MINNOW_DOLPHIN::TRKTargetEnableTrace": 0x8032032c,
		"TRKTargetEnableTrace": 0x8032032c,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepDone": 0x80320368,
		"TRKTargetStepDone": 0x80320368,
		"TRK_MINNOW_DOLPHIN::TRKTargetDoStep": 0x803203ec,
		"TRKTargetDoStep": 0x803203ec,
		"TRK_MINNOW_DOLPHIN::TRKTargetCheckStep": 0x8032045c,
		"TRKTargetCheckStep": 0x8032045c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSingleStep": 0x803204c4,
		"TRKTargetSingleStep": 0x803204c4,
		"TRK_MINNOW_DOLPHIN::TRKTargetStepOutOfRange": 0x80320508,
		"TRKTargetStepOutOfRange": 0x80320508,
		"TRK_MINNOW_DOLPHIN::TRKTargetGetPC": 0x80320550,
		"TRKTargetGetPC": 0x80320550,
		"TRK_MINNOW_DOLPHIN::TRKTargetSupportRequest": 0x80320560,
		"TRKTargetSupportRequest": 0x80320560,
		"TRK_MINNOW_DOLPHIN::TRKTargetFlushCache": 0x80320650,
		"TRKTargetFlushCache": 0x80320650,
		"TRK_MINNOW_DOLPHIN::TRKTargetStopped": 0x8032068c,
		"TRKTargetStopped": 0x8032068c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetStopped": 0x8032069c,
		"TRKTargetSetStopped": 0x8032069c,
		"TRK_MINNOW_DOLPHIN::TRKTargetStop": 0x803206ac,
		"TRKTargetStop": 0x803206ac,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSPR": 0x803206d4,
		"TRKPPCAccessSPR": 0x803206d4,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessPairedSingleRegister": 0x80320784,
		"TRKPPCAccessPairedSingleRegister": 0x80320784,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessFPRegister": 0x803207fc,
		"TRKPPCAccessFPRegister": 0x803207fc,
		"TRK_MINNOW_DOLPHIN::TRKPPCAccessSpecialReg": 0x8032097c,
		"TRKPPCAccessSpecialReg": 0x8032097c,
		"TRK_MINNOW_DOLPHIN::TRKTargetSetInputPendingPtr": 0x803209e4,
		"TRKTargetSetInputPendingPtr": 0x803209e4,
		"TRK_MINNOW_DOLPHIN::InitMetroTRK": 0x803209f4,
		"InitMetroTRK": 0x803209f4,
		"TRK_MINNOW_DOLPHIN::EnableMetroTRKInterrupts": 0x80320a88,
		"EnableMetroTRKInterrupts": 0x80320a88,
		"TRK_MINNOW_DOLPHIN::TRKTargetTranslate": 0x80320aa8,
		"TRKTargetTranslate": 0x80320aa8,
		"TRK_MINNOW_DOLPHIN::TRK_copy_vector": 0x80320af0,
		"TRK_copy_vector": 0x80320af0,
		"TRK_MINNOW_DOLPHIN::__TRK_copy_vectors": 0x80320b50,
		"__TRK_copy_vectors": 0x80320b50,
		"TRK_MINNOW_DOLPHIN::TRKInitializeTarget": 0x80320be4,
		"TRKInitializeTarget": 0x80320be4,
		"TRK_MINNOW_DOLPHIN::TRKSaveExtended1Block": 0x80320c34,
		"TRKSaveExtended1Block": 0x80320c34,
		"TRK_MINNOW_DOLPHIN::TRKRestoreExtended1Block": 0x80320dec,
		"TRKRestoreExtended1Block": 0x80320dec,
		"TRK_MINNOW_DOLPHIN::TRKTargetCPUMinorType": 0x80320fa4,
		"TRKTargetCPUMinorType": 0x80320fa4,
		"TRK_MINNOW_DOLPHIN::TRK_main": 0x80320fac,
		"TRK_main": 0x80320fac,
		"TRK_MINNOW_DOLPHIN::TRKLoadContext": 0x80320ff4,
		"TRKLoadContext": 0x80320ff4,
		"TRK_MINNOW_DOLPHIN::TRKEXICallBack": 0x8032107c,
		"TRKEXICallBack": 0x8032107c,
		"TRK_MINNOW_DOLPHIN::InitMetroTRKCommTable": 0x803210b4,
		"InitMetroTRKCommTable": 0x803210b4,
		"TRK_MINNOW_DOLPHIN::TRKUARTInterruptHandler": 0x8032119c,
		"TRKUARTInterruptHandler": 0x8032119c,
		"TRK_MINNOW_DOLPHIN::TRKInitializeIntDrivenUART": 0x803211a0,
		"TRKInitializeIntDrivenUART": 0x803211a0,
		"TRK_MINNOW_DOLPHIN::EnableEXI2Interrupts": 0x803211e0,
		"EnableEXI2Interrupts": 0x803211e0,
		"TRK_MINNOW_DOLPHIN::TRKPollUART": 0x80321210,
		"TRKPollUART": 0x80321210,
		"TRK_MINNOW_DOLPHIN::TRKReadUARTN": 0x80321240,
		"TRKReadUARTN": 0x80321240,
		"TRK_MINNOW_DOLPHIN::TRKWriteUARTN": 0x80321284,
		"TRKWriteUARTN": 0x80321284,
		"TRK_MINNOW_DOLPHIN::ReserveEXI2Port": 0x803212c8,
		"ReserveEXI2Port": 0x803212c8,
		"TRK_MINNOW_DOLPHIN::UnreserveEXI2Port": 0x803212f8,
		"UnreserveEXI2Port": 0x803212f8,
		"TRK_MINNOW_DOLPHIN::TRK_board_display": 0x80321328,
		"TRK_board_display": 0x80321328,
		"TRK_MINNOW_DOLPHIN::TRKTargetContinue": 0x8032134c,
		"TRKTargetContinue": 0x8032134c,
		"base::PPCMfmsr": 0x80321380,
		"PPCMfmsr": 0x80321380,
		"base::PPCMtmsr": 0x80321388,
		"PPCMtmsr": 0x80321388,
		"base::PPCMfhid0": 0x80321390,
		"PPCMfhid0": 0x80321390,
		"base::PPCMthid0": 0x80321398,
		"PPCMthid0": 0x80321398,
		"base::PPCMfl2cr": 0x803213a0,
		"PPCMfl2cr": 0x803213a0,
		"base::PPCMtl2cr": 0x803213a8,
		"PPCMtl2cr": 0x803213a8,
		"base::PPCMtdec": 0x803213b0,
		"PPCMtdec": 0x803213b0,
		"base::PPCSync": 0x803213b8,
		"PPCSync": 0x803213b8,
		"base::PPCHalt": 0x803213c0,
		"PPCHalt": 0x803213c0,
		"base::PPCMfhid2": 0x803213d4,
		"PPCMfhid2": 0x803213d4,
		"base::PPCMthid2": 0x803213dc,
		"PPCMthid2": 0x803213dc,
		"base::PPCMtwpar": 0x803213e4,
		"PPCMtwpar": 0x803213e4,
		"base::PPCDisableSpeculation": 0x803213ec,
		"PPCDisableSpeculation": 0x803213ec,
		"base::PPCSetFpNonIEEEMode": 0x80321414,
		"PPCSetFpNonIEEEMode": 0x80321414,
		"db::DBInit": 0x8032141c,
		"DBInit": 0x8032141c,
		"db::__DBExceptionDestinationAux": 0x80321444,
		"__DBExceptionDestinationAux": 0x80321444,
		"db::__DBExceptionDestination": 0x8032148c,
		"__DBExceptionDestination": 0x8032148c,
		"db::__DBIsExceptionMarked": 0x8032149c,
		"__DBIsExceptionMarked": 0x8032149c,
		"db::DBPrintf": 0x803214b8,
		"DBPrintf": 0x803214b8,
		"os::OSGetConsoleType": 0x80321508,
		"OSGetConsoleType": 0x80321508,
		"os::ClearArena": 0x80321530,
		"ClearArena": 0x80321530,
		"os::InquiryCallback": 0x80321658,
		"InquiryCallback": 0x80321658,
		"os::OSInit": 0x80321694,
		"OSInit": 0x80321694,
		"os::OSExceptionInit": 0x80321a4c,
		"OSExceptionInit": 0x80321a4c,
		"os::__OSDBIntegrator": 0x80321ccc,
		"__OSDBIntegrator": 0x80321ccc,
		"os::__OSDBJump": 0x80321cf0,
		"__OSDBJump": 0x80321cf0,
		"os::__OSSetExceptionHandler": 0x80321cf4,
		"__OSSetExceptionHandler": 0x80321cf4,
		"os::__OSGetExceptionHandler": 0x80321d10,
		"__OSGetExceptionHandler": 0x80321d10,
		"os::OSExceptionVector": 0x80321d24,
		"OSExceptionVector": 0x80321d24,
		"os::OSDefaultExceptionHandler": 0x80321dc0,
		"OSDefaultExceptionHandler": 0x80321dc0,
		"os::__OSPSInit": 0x80321e18,
		"__OSPSInit": 0x80321e18,
		"os::__OSGetDIConfig": 0x80321e50,
		"__OSGetDIConfig": 0x80321e50,
		"os::OSInitAlarm": 0x80321e64,
		"OSInitAlarm": 0x80321e64,
		"os::OSCreateAlarm": 0x80321eb0,
		"OSCreateAlarm": 0x80321eb0,
		"os::InsertAlarm": 0x80321ebc,
		"InsertAlarm": 0x80321ebc,
		"os::OSSetAlarm": 0x8032210c,
		"OSSetAlarm": 0x8032210c,
		"os::OSCancelAlarm": 0x80322174,
		"OSCancelAlarm": 0x80322174,
		"os::DecrementerExceptionCallback": 0x80322290,
		"DecrementerExceptionCallback": 0x80322290,
		"os::DecrementerExceptionHandler": 0x803224c0,
		"DecrementerExceptionHandler": 0x803224c0,
		"os::DLInsert": 0x80322510,
		"DLInsert": 0x80322510,
		"os::OSAllocFromHeap": 0x803225bc,
		"OSAllocFromHeap": 0x803225bc,
		"os::OSFreeToHeap": 0x803226b8,
		"OSFreeToHeap": 0x803226b8,
		"os::OSInitAlloc": 0x80322734,
		"OSInitAlloc": 0x80322734,
		"os::OSCreateHeap": 0x803227a4,
		"OSCreateHeap": 0x803227a4,
		"os::OSDestroyHeap": 0x80322810,
		"OSDestroyHeap": 0x80322810,
		"os::OSCheckHeap": 0x80322824,
		"OSCheckHeap": 0x80322824,
		"os::OSReferentSize": 0x80322b84,
		"OSReferentSize": 0x80322b84,
		"os::OSDumpHeap": 0x80322b90,
		"OSDumpHeap": 0x80322b90,
		"os::OSGetArenaHi": 0x80322c94,
		"OSGetArenaHi": 0x80322c94,
		"os::OSGetArenaLo": 0x80322c9c,
		"OSGetArenaLo": 0x80322c9c,
		"os::OSSetArenaHi": 0x80322ca4,
		"OSSetArenaHi": 0x80322ca4,
		"os::OSSetArenaLo": 0x80322cac,
		"OSSetArenaLo": 0x80322cac,
		"os::__OSInitAudioSystem": 0x80322cb4,
		"__OSInitAudioSystem": 0x80322cb4,
		"os::__OSStopAudioSystem": 0x80322e70,
		"__OSStopAudioSystem": 0x80322e70,
		"os::DCEnable": 0x80322f48,
		"DCEnable": 0x80322f48,
		"os::DCInvalidateRange": 0x80322f5c,
		"DCInvalidateRange": 0x80322f5c,
		"os::DCFlushRange": 0x80322f8c,
		"DCFlushRange": 0x80322f8c,
		"os::DCStoreRange": 0x80322fc0,
		"DCStoreRange": 0x80322fc0,
		"os::DCFlushRangeNoSync": 0x80322ff4,
		"DCFlushRangeNoSync": 0x80322ff4,
		"os::DCZeroRange": 0x80323024,
		"DCZeroRange": 0x80323024,
		"os::ICInvalidateRange": 0x80323054,
		"ICInvalidateRange": 0x80323054,
		"os::ICFlashInvalidate": 0x8032308c,
		"ICFlashInvalidate": 0x8032308c,
		"os::ICEnable": 0x8032309c,
		"ICEnable": 0x8032309c,
		"os::__LCEnable": 0x803230b0,
		"__LCEnable": 0x803230b0,
		"os::LCEnable": 0x8032317c,
		"LCEnable": 0x8032317c,
		"os::LCDisable": 0x803231b4,
		"LCDisable": 0x803231b4,
		"os::LCStoreBlocks": 0x803231dc,
		"LCStoreBlocks": 0x803231dc,
		"os::LCStoreData": 0x80323200,
		"LCStoreData": 0x80323200,
		"os::LCQueueWait": 0x803232ac,
		"LCQueueWait": 0x803232ac,
		"os::L2GlobalInvalidate": 0x803232c4,
		"L2GlobalInvalidate": 0x803232c4,
		"os::DMAErrorHandler": 0x8032335c,
		"DMAErrorHandler": 0x8032335c,
		"os::__OSCacheInit": 0x803234bc,
		"__OSCacheInit": 0x803234bc,
		"os::__OSLoadFPUContext": 0x803235b0,
		"__OSLoadFPUContext": 0x803235b0,
		"os::__OSSaveFPUContext": 0x803236d4,
		"__OSSaveFPUContext": 0x803236d4,
		"os::OSSetCurrentContext": 0x803237fc,
		"OSSetCurrentContext": 0x803237fc,
		"os::OSGetCurrentContext": 0x80323858,
		"OSGetCurrentContext": 0x80323858,
		"os::OSSaveContext": 0x80323864,
		"OSSaveContext": 0x80323864,
		"os::OSLoadContext": 0x803238e4,
		"OSLoadContext": 0x803238e4,
		"os::OSGetStackPointer": 0x803239bc,
		"OSGetStackPointer": 0x803239bc,
		"os::OSClearContext": 0x803239c4,
		"OSClearContext": 0x803239c4,
		"os::OSInitContext": 0x803239e8,
		"OSInitContext": 0x803239e8,
		"os::OSDumpContext": 0x80323aa4,
		"OSDumpContext": 0x80323aa4,
		"os::OSSwitchFPUContext": 0x80323d4c,
		"OSSwitchFPUContext": 0x80323d4c,
		"os::__OSContextInit": 0x80323dd0,
		"__OSContextInit": 0x80323dd0,
		"os::OSFillFPUContext": 0x80323e18,
		"OSFillFPUContext": 0x80323e18,
		"os::OSReport": 0x80323f44,
		"OSReport": 0x80323f44,
		"os::OSPanic": 0x80323fc4,
		"OSPanic": 0x80323fc4,
		"os::OSSetErrorHandler": 0x803240f0,
		"OSSetErrorHandler": 0x803240f0,
		"os::__OSUnhandledException": 0x8032410c,
		"__OSUnhandledException": 0x8032410c,
		"os::GetFontCode": 0x8032430c,
		"GetFontCode": 0x8032430c,
		"os::Decode": 0x803244a8,
		"Decode": 0x803244a8,
		"os::OSGetFontEncode": 0x8032461c,
		"OSGetFontEncode": 0x8032461c,
		"os::ReadROM": 0x80324674,
		"ReadROM": 0x80324674,
		"os::OSLoadFont": 0x80324700,
		"OSLoadFont": 0x80324700,
		"os::ExpandFontSheet": 0x80324a34,
		"ExpandFontSheet": 0x80324a34,
		"os::OSInitFont": 0x80324de4,
		"OSInitFont": 0x80324de4,
		"os::OSGetFontTexture": 0x80324ec4,
		"OSGetFontTexture": 0x80324ec4,
		"os::OSGetFontWidth": 0x8032506c,
		"OSGetFontWidth": 0x8032506c,
		"os::OSDisableInterrupts": 0x803251ac,
		"OSDisableInterrupts": 0x803251ac,
		"os::OSEnableInterrupts": 0x803251c0,
		"OSEnableInterrupts": 0x803251c0,
		"os::OSRestoreInterrupts": 0x803251d4,
		"OSRestoreInterrupts": 0x803251d4,
		"os::__OSSetInterruptHandler": 0x803251f8,
		"__OSSetInterruptHandler": 0x803251f8,
		"os::__OSGetInterruptHandler": 0x80325214,
		"__OSGetInterruptHandler": 0x80325214,
		"os::__OSInterruptInit": 0x80325228,
		"__OSInterruptInit": 0x80325228,
		"os::SetInterruptMask": 0x8032529c,
		"SetInterruptMask": 0x8032529c,
		"os::__OSMaskInterrupts": 0x80325574,
		"__OSMaskInterrupts": 0x80325574,
		"os::__OSUnmaskInterrupts": 0x803255fc,
		"__OSUnmaskInterrupts": 0x803255fc,
		"os::__OSDispatchInterrupt": 0x80325684,
		"__OSDispatchInterrupt": 0x80325684,
		"os::ExternalInterruptHandler": 0x803259c8,
		"ExternalInterruptHandler": 0x803259c8,
		"os::__OSModuleInit": 0x80325a18,
		"__OSModuleInit": 0x80325a18,
		"os::OSInitMessageQueue": 0x80325a30,
		"OSInitMessageQueue": 0x80325a30,
		"os::OSSendMessage": 0x80325a90,
		"OSSendMessage": 0x80325a90,
		"os::OSReceiveMessage": 0x80325b58,
		"OSReceiveMessage": 0x80325b58,
		"os::OnReset": 0x80325c34,
		"os::MEMIntrruptHandler": 0x80325c70,
		"MEMIntrruptHandler": 0x80325c70,
		"os::OSProtectRange": 0x80325cdc,
		"OSProtectRange": 0x80325cdc,
		"os::Config24MB": 0x80325da0,
		"Config24MB": 0x80325da0,
		"os::Config48MB": 0x80325e20,
		"Config48MB": 0x80325e20,
		"os::RealMode": 0x80325ea0,
		"RealMode": 0x80325ea0,
		"os::__OSInitMemoryProtection": 0x80325eb8,
		"__OSInitMemoryProtection": 0x80325eb8,
		"os::OSInitMutex": 0x80325fd8,
		"OSInitMutex": 0x80325fd8,
		"os::OSLockMutex": 0x80326010,
		"OSLockMutex": 0x80326010,
		"os::OSUnlockMutex": 0x803260ec,
		"OSUnlockMutex": 0x803260ec,
		"os::__OSUnlockAllMutex": 0x803261b4,
		"__OSUnlockAllMutex": 0x803261b4,
		"os::OSTryLockMutex": 0x80326224,
		"OSTryLockMutex": 0x80326224,
		"os::OSInitCond": 0x803262e0,
		"OSInitCond": 0x803262e0,
		"os::OSWaitCond": 0x80326300,
		"OSWaitCond": 0x80326300,
		"os::OSSignalCond": 0x803263d4,
		"OSSignalCond": 0x803263d4,
		"os::Run": 0x803263f4,
		"Run": 0x803263f4,
		"os::Callback": 0x80326434,
		"os::__OSReboot": 0x80326440,
		"__OSReboot": 0x80326440,
		"os::OSRegisterResetFunction": 0x80326600,
		"OSRegisterResetFunction": 0x80326600,
		"os::Reset": 0x80326684,
		"Reset": 0x80326684,
		"os::__OSDoHotReset": 0x803266f4,
		"__OSDoHotReset": 0x803266f4,
		"os::OSResetSystem": 0x8032673c,
		"OSResetSystem": 0x8032673c,
		"os::OSGetResetCode": 0x803269b4,
		"OSGetResetCode": 0x803269b4,
		"os::__OSResetSWInterruptHandler": 0x803269e4,
		"__OSResetSWInterruptHandler": 0x803269e4,
		"os::OSGetResetButtonState": 0x80326ad8,
		"OSGetResetButtonState": 0x80326ad8,
		"os::OSGetResetSwitchState": 0x80326d70,
		"OSGetResetSwitchState": 0x80326d70,
		"os::WriteSramCallback": 0x80326d90,
		"WriteSramCallback": 0x80326d90,
		"os::WriteSram": 0x80326df0,
		"WriteSram": 0x80326df0,
		"os::__OSInitSram": 0x80326f08,
		"__OSInitSram": 0x80326f08,
		"os::__OSLockSram": 0x8032703c,
		"__OSLockSram": 0x8032703c,
		"os::__OSLockSramEx": 0x80327098,
		"__OSLockSramEx": 0x80327098,
		"os::UnlockSram": 0x803270f4,
		"UnlockSram": 0x803270f4,
		"os::__OSUnlockSram": 0x803273fc,
		"__OSUnlockSram": 0x803273fc,
		"os::__OSUnlockSramEx": 0x80327420,
		"__OSUnlockSramEx": 0x80327420,
		"os::__OSSyncSram": 0x80327444,
		"__OSSyncSram": 0x80327444,
		"os::__OSReadROM": 0x80327454,
		"__OSReadROM": 0x80327454,
		"os::OSGetSoundMode": 0x80327578,
		"OSGetSoundMode": 0x80327578,
		"os::OSSetSoundMode": 0x803275f8,
		"OSSetSoundMode": 0x803275f8,
		"os::OSGetProgressiveMode": 0x8032769c,
		"OSGetProgressiveMode": 0x8032769c,
		"os::OSSetProgressiveMode": 0x8032770c,
		"OSSetProgressiveMode": 0x8032770c,
		"os::OSGetWirelessID": 0x803277b0,
		"OSGetWirelessID": 0x803277b0,
		"os::OSSetWirelessID": 0x80327834,
		"OSSetWirelessID": 0x80327834,
		"os::OSInitStopwatch": 0x803278e0,
		"OSInitStopwatch": 0x803278e0,
		"os::OSStartStopwatch": 0x8032790c,
		"OSStartStopwatch": 0x8032790c,
		"os::OSStopStopwatch": 0x80327948,
		"OSStopStopwatch": 0x80327948,
		"os::OSCheckStopwatch": 0x80327a14,
		"OSCheckStopwatch": 0x80327a14,
		"os::OSResetStopwatch": 0x80327a84,
		"OSResetStopwatch": 0x80327a84,
		"os::SystemCallVector": 0x80327aac,
		"SystemCallVector": 0x80327aac,
		"os::__OSInitSystemCall": 0x80327acc,
		"__OSInitSystemCall": 0x80327acc,
		"os::__OSThreadInit": 0x80327b30,
		"__OSThreadInit": 0x80327b30,
		"os::OSInitThreadQueue": 0x80327c58,
		"OSInitThreadQueue": 0x80327c58,
		"os::OSGetCurrentThread": 0x80327c68,
		"OSGetCurrentThread": 0x80327c68,
		"os::OSIsThreadTerminated": 0x80327c74,
		"OSIsThreadTerminated": 0x80327c74,
		"os::OSDisableScheduler": 0x80327ca8,
		"OSDisableScheduler": 0x80327ca8,
		"os::OSEnableScheduler": 0x80327ce8,
		"OSEnableScheduler": 0x80327ce8,
		"os::UnsetRun": 0x80327d28,
		"UnsetRun": 0x80327d28,
		"os::__OSGetEffectivePriority": 0x80327d90,
		"__OSGetEffectivePriority": 0x80327d90,
		"os::SetEffectivePriority": 0x80327dcc,
		"SetEffectivePriority": 0x80327dcc,
		"os::__OSPromoteThread": 0x80327f8c,
		"__OSPromoteThread": 0x80327f8c,
		"os::SelectThread": 0x80327fdc,
		"SelectThread": 0x80327fdc,
		"os::__OSReschedule": 0x803281dc,
		"__OSReschedule": 0x803281dc,
		"os::OSYieldThread": 0x8032820c,
		"OSYieldThread": 0x8032820c,
		"os::OSCreateThread": 0x80328248,
		"OSCreateThread": 0x80328248,
		"os::OSExitThread": 0x80328368,
		"OSExitThread": 0x80328368,
		"os::OSCancelThread": 0x8032844c,
		"OSCancelThread": 0x8032844c,
		"os::OSJoinThread": 0x80328608,
		"OSJoinThread": 0x80328608,
		"os::OSDetachThread": 0x80328748,
		"OSDetachThread": 0x80328748,
		"os::OSResumeThread": 0x803287e8,
		"OSResumeThread": 0x803287e8,
		"os::OSSuspendThread": 0x80328a70,
		"OSSuspendThread": 0x80328a70,
		"os::OSSleepThread": 0x80328be0,
		"OSSleepThread": 0x80328be0,
		"os::OSWakeupThread": 0x80328ccc,
		"OSWakeupThread": 0x80328ccc,
		"os::OSGetThreadPriority": 0x80328dd0,
		"OSGetThreadPriority": 0x80328dd0,
		"os::OSGetTime": 0x80328dd8,
		"OSGetTime": 0x80328dd8,
		"os::OSGetTick": 0x80328df0,
		"OSGetTick": 0x80328df0,
		"os::__OSGetSystemTime": 0x80328df8,
		"__OSGetSystemTime": 0x80328df8,
		"os::GetDates": 0x80328e5c,
		"GetDates": 0x80328e5c,
		"os::OSTicksToCalendarTime": 0x80328ff8,
		"OSTicksToCalendarTime": 0x80328ff8,
		"os::__init_user": 0x803291fc,
		"__init_user": 0x803291fc,
		"os::__init_cpp": 0x8032921c,
		"__init_cpp": 0x8032921c,
		"os::_ExitProcess": 0x80329270,
		"_ExitProcess": 0x80329270,
		"mtx::PSMTXIdentity": 0x80329290,
		"PSMTXIdentity": 0x80329290,
		"mtx::PSMTXCopy": 0x803292bc,
		"PSMTXCopy": 0x803292bc,
		"mtx::PSMTXConcat": 0x803292f0,
		"PSMTXConcat": 0x803292f0,
		"mtx::PSMTXInverse": 0x803293bc,
		"PSMTXInverse": 0x803293bc,
		"mtx::PSMTXRotRad": 0x803294b4,
		"PSMTXRotRad": 0x803294b4,
		"mtx::PSMTXRotTrig": 0x80329524,
		"PSMTXRotTrig": 0x80329524,
		"mtx::PSMTXRotAxisRad": 0x803295cc,
		"PSMTXRotAxisRad": 0x803295cc,
		"mtx::PSMTXTrans": 0x803296d0,
		"PSMTXTrans": 0x803296d0,
		"mtx::PSMTXTransApply": 0x80329704,
		"PSMTXTransApply": 0x80329704,
		"mtx::PSMTXScale": 0x80329744,
		"PSMTXScale": 0x80329744,
		"mtx::PSMTXScaleApply": 0x8032976c,
		"PSMTXScaleApply": 0x8032976c,
		"mtx::PSMTXQuat": 0x803297b8,
		"PSMTXQuat": 0x803297b8,
		"mtx::C_MTXLookAt": 0x8032985c,
		"C_MTXLookAt": 0x8032985c,
		"mtx::C_MTXLightFrustum": 0x803299e8,
		"C_MTXLightFrustum": 0x803299e8,
		"mtx::C_MTXLightPerspective": 0x80329a7c,
		"C_MTXLightPerspective": 0x80329a7c,
		"mtx::C_MTXLightOrtho": 0x80329b48,
		"C_MTXLightOrtho": 0x80329b48,
		"mtx::PSMTXMultVec": 0x80329bd0,
		"PSMTXMultVec": 0x80329bd0,
		"mtx::PSMTXMultVecArray": 0x80329c24,
		"PSMTXMultVecArray": 0x80329c24,
		"mtx::PSMTXMultVecSR": 0x80329cb0,
		"PSMTXMultVecSR": 0x80329cb0,
		"mtx::C_MTXPerspective": 0x80329d04,
		"C_MTXPerspective": 0x80329d04,
		"mtx::C_MTXOrtho": 0x80329dd4,
		"C_MTXOrtho": 0x80329dd4,
		"mtx::PSVECAdd": 0x80329e6c,
		"PSVECAdd": 0x80329e6c,
		"mtx::PSVECSubtract": 0x80329e90,
		"PSVECSubtract": 0x80329e90,
		"mtx::PSVECScale": 0x80329eb4,
		"PSVECScale": 0x80329eb4,
		"mtx::PSVECNormalize": 0x80329ed0,
		"PSVECNormalize": 0x80329ed0,
		"mtx::PSVECMag": 0x80329f14,
		"PSVECMag": 0x80329f14,
		"mtx::PSVECDotProduct": 0x80329f50,
		"PSVECDotProduct": 0x80329f50,
		"mtx::PSVECCrossProduct": 0x80329f70,
		"PSVECCrossProduct": 0x80329f70,
		"mtx::PSVECSquareDistance": 0x80329fac,
		"PSVECSquareDistance": 0x80329fac,
		"mtx::PSVECDistance": 0x80329fd4,
		"PSVECDistance": 0x80329fd4,
		"dvd::__DVDInitWA": 0x8032a020,
		"__DVDInitWA": 0x8032a020,
		"dvd::__DVDInterruptHandler": 0x8032a060,
		"__DVDInterruptHandler": 0x8032a060,
		"dvd::AlarmHandlerForTimeout": 0x8032a3d8,
		"AlarmHandlerForTimeout": 0x8032a3d8,
		"dvd::Read": 0x8032a448,
		"Read": 0x8032a448,
		"dvd::SeekTwiceBeforeRead": 0x8032a558,
		"SeekTwiceBeforeRead": 0x8032a558,
		"dvd::DVDLowRead": 0x8032a5d8,
		"DVDLowRead": 0x8032a5d8,
		"dvd::DVDLowSeek": 0x8032a870,
		"DVDLowSeek": 0x8032a870,
		"dvd::DVDLowWaitCoverClose": 0x8032a904,
		"DVDLowWaitCoverClose": 0x8032a904,
		"dvd::DVDLowReadDiskID": 0x8032a930,
		"DVDLowReadDiskID": 0x8032a930,
		"dvd::DVDLowStopMotor": 0x8032a9d4,
		"DVDLowStopMotor": 0x8032a9d4,
		"dvd::DVDLowRequestError": 0x8032aa60,
		"DVDLowRequestError": 0x8032aa60,
		"dvd::DVDLowInquiry": 0x8032aaec,
		"DVDLowInquiry": 0x8032aaec,
		"dvd::DVDLowAudioStream": 0x8032ab88,
		"DVDLowAudioStream": 0x8032ab88,
		"dvd::DVDLowRequestAudioStatus": 0x8032ac20,
		"DVDLowRequestAudioStatus": 0x8032ac20,
		"dvd::DVDLowAudioBufferConfig": 0x8032acac,
		"DVDLowAudioBufferConfig": 0x8032acac,
		"dvd::DVDLowReset": 0x8032ad48,
		"DVDLowReset": 0x8032ad48,
		"dvd::DVDLowBreak": 0x8032ae04,
		"DVDLowBreak": 0x8032ae04,
		"dvd::DVDLowClearCallback": 0x8032ae18,
		"DVDLowClearCallback": 0x8032ae18,
		"dvd::__DVDLowSetWAType": 0x8032ae30,
		"__DVDLowSetWAType": 0x8032ae30,
		"dvd::__DVDFSInit": 0x8032ae74,
		"__DVDFSInit": 0x8032ae74,
		"dvd::DVDConvertPathToEntrynum": 0x8032aeac,
		"DVDConvertPathToEntrynum": 0x8032aeac,
		"dvd::DVDFastOpen": 0x8032b1a0,
		"DVDFastOpen": 0x8032b1a0,
		"dvd::DVDOpen": 0x8032b214,
		"DVDOpen": 0x8032b214,
		"dvd::DVDClose": 0x8032b2dc,
		"DVDClose": 0x8032b2dc,
		"dvd::entryToPath": 0x8032b300,
		"entryToPath": 0x8032b300,
		"dvd::DVDGetCurrentDir": 0x8032b460,
		"DVDGetCurrentDir": 0x8032b460,
		"dvd::DVDChangeDir": 0x8032b524,
		"DVDChangeDir": 0x8032b524,
		"dvd::DVDReadAsyncPrio": 0x8032b584,
		"DVDReadAsyncPrio": 0x8032b584,
		"dvd::cbForReadAsync": 0x8032b644,
		"cbForReadAsync": 0x8032b644,
		"dvd::DVDReadPrio": 0x8032b674,
		"DVDReadPrio": 0x8032b674,
		"dvd::cbForReadSync": 0x8032b78c,
		"cbForReadSync": 0x8032b78c,
		"dvd::DVDPrepareStreamAsync": 0x8032b7b0,
		"DVDPrepareStreamAsync": 0x8032b7b0,
		"dvd::cbForPrepareStreamAsync": 0x8032b89c,
		"cbForPrepareStreamAsync": 0x8032b89c,
		"dvd::DVDInit": 0x8032b8cc,
		"DVDInit": 0x8032b8cc,
		"dvd::stateReadingFST": 0x8032b9c8,
		"stateReadingFST": 0x8032b9c8,
		"dvd::cbForStateReadingFST": 0x8032ba1c,
		"cbForStateReadingFST": 0x8032ba1c,
		"dvd::cbForStateError": 0x8032ba9c,
		"cbForStateError": 0x8032ba9c,
		"dvd::stateTimeout": 0x8032bb44,
		"stateTimeout": 0x8032bb44,
		"dvd::stateGettingError": 0x8032bbe0,
		"stateGettingError": 0x8032bbe0,
		"dvd::CategorizeError": 0x8032bc08,
		"CategorizeError": 0x8032bc08,
		"dvd::cbForStateGettingError": 0x8032bcbc,
		"cbForStateGettingError": 0x8032bcbc,
		"dvd::cbForUnrecoveredError": 0x8032bf50,
		"cbForUnrecoveredError": 0x8032bf50,
		"dvd::cbForUnrecoveredErrorRetry": 0x8032bfb8,
		"cbForUnrecoveredErrorRetry": 0x8032bfb8,
		"dvd::stateGoToRetry": 0x8032c050,
		"stateGoToRetry": 0x8032c050,
		"dvd::cbForStateGoToRetry": 0x8032c078,
		"cbForStateGoToRetry": 0x8032c078,
		"dvd::stateCheckID": 0x8032c1d0,
		"stateCheckID": 0x8032c1d0,
		"dvd::stateCheckID3": 0x8032c2b4,
		"stateCheckID3": 0x8032c2b4,
		"dvd::stateCheckID2": 0x8032c2e8,
		"stateCheckID2": 0x8032c2e8,
		"dvd::cbForStateCheckID1": 0x8032c320,
		"cbForStateCheckID1": 0x8032c320,
		"dvd::cbForStateCheckID2": 0x8032c434,
		"cbForStateCheckID2": 0x8032c434,
		"dvd::cbForStateCheckID3": 0x8032c4d8,
		"cbForStateCheckID3": 0x8032c4d8,
		"dvd::stateCoverClosed": 0x8032c618,
		"stateCoverClosed": 0x8032c618,
		"dvd::stateCoverClosed_CMD": 0x8032c6e4,
		"stateCoverClosed_CMD": 0x8032c6e4,
		"dvd::cbForStateCoverClosed": 0x8032c714,
		"cbForStateCoverClosed": 0x8032c714,
		"dvd::stateMotorStopped": 0x8032c784,
		"stateMotorStopped": 0x8032c784,
		"dvd::cbForStateMotorStopped": 0x8032c7ac,
		"cbForStateMotorStopped": 0x8032c7ac,
		"dvd::stateReady": 0x8032c890,
		"stateReady": 0x8032c890,
		"dvd::stateBusy": 0x8032cad8,
		"stateBusy": 0x8032cad8,
		"dvd::cbForStateBusy": 0x8032cd98,
		"cbForStateBusy": 0x8032cd98,
		"dvd::DVDReadAbsAsyncPrio": 0x8032d36c,
		"DVDReadAbsAsyncPrio": 0x8032d36c,
		"dvd::DVDReadAbsAsyncForBS": 0x8032d448,
		"DVDReadAbsAsyncForBS": 0x8032d448,
		"dvd::DVDReadDiskID": 0x8032d518,
		"DVDReadDiskID": 0x8032d518,
		"dvd::DVDPrepareStreamAbsAsync": 0x8032d5ec,
		"DVDPrepareStreamAbsAsync": 0x8032d5ec,
		"dvd::DVDCancelStreamAsync": 0x8032d6b0,
		"DVDCancelStreamAsync": 0x8032d6b0,
		"dvd::DVDStopStreamAtEndAsync": 0x8032d76c,
		"DVDStopStreamAtEndAsync": 0x8032d76c,
		"dvd::DVDGetStreamPlayAddrAsync": 0x8032d828,
		"DVDGetStreamPlayAddrAsync": 0x8032d828,
		"dvd::DVDInquiryAsync": 0x8032d8e4,
		"DVDInquiryAsync": 0x8032d8e4,
		"dvd::DVDReset": 0x8032d9b4,
		"DVDReset": 0x8032d9b4,
		"dvd::DVDGetCommandBlockStatus": 0x8032d9f8,
		"DVDGetCommandBlockStatus": 0x8032d9f8,
		"dvd::DVDGetDriveStatus": 0x8032da44,
		"DVDGetDriveStatus": 0x8032da44,
		"dvd::DVDSetAutoInvalidation": 0x8032daf0,
		"DVDSetAutoInvalidation": 0x8032daf0,
		"dvd::DVDCancelAsync": 0x8032db00,
		"DVDCancelAsync": 0x8032db00,
		"dvd::DVDCancel": 0x8032dd70,
		"DVDCancel": 0x8032dd70,
		"dvd::cbForCancelSync": 0x8032de1c,
		"cbForCancelSync": 0x8032de1c,
		"dvd::DVDGetCurrentDiskID": 0x8032de40,
		"DVDGetCurrentDiskID": 0x8032de40,
		"dvd::DVDCheckDisk": 0x8032de48,
		"DVDCheckDisk": 0x8032de48,
		"dvd::__DVDPrepareResetAsync": 0x8032df2c,
		"__DVDPrepareResetAsync": 0x8032df2c,
		"dvd::__DVDClearWaitingQueue": 0x8032e048,
		"__DVDClearWaitingQueue": 0x8032e048,
		"dvd::__DVDPushWaitingQueue": 0x8032e080,
		"__DVDPushWaitingQueue": 0x8032e080,
		"dvd::__DVDPopWaitingQueue": 0x8032e0e8,
		"__DVDPopWaitingQueue": 0x8032e0e8,
		"dvd::__DVDCheckWaitingQueue": 0x8032e188,
		"__DVDCheckWaitingQueue": 0x8032e188,
		"dvd::__DVDDequeueWaitingQueue": 0x8032e1e0,
		"__DVDDequeueWaitingQueue": 0x8032e1e0,
		"dvd::ErrorCode2Num": 0x8032e240,
		"ErrorCode2Num": 0x8032e240,
		"dvd::__DVDStoreErrorCode": 0x8032e35c,
		"__DVDStoreErrorCode": 0x8032e35c,
		"dvd::cb": 0x8032e3d8,
		"dvd::__fstLoad": 0x8032e4b0,
		"__fstLoad": 0x8032e4b0,
		"vi::__VIRetraceHandler": 0x8032e618,
		"__VIRetraceHandler": 0x8032e618,
		"vi::VISetPostRetraceCallback": 0x8032e840,
		"VISetPostRetraceCallback": 0x8032e840,
		"vi::getTiming": 0x8032e884,
		"getTiming": 0x8032e884,
		"vi::__VIInit": 0x8032e914,
		"__VIInit": 0x8032e914,
		"vi::VIInit": 0x8032eb0c,
		"VIInit": 0x8032eb0c,
		"vi::VIWaitForRetrace": 0x8032ef84,
		"VIWaitForRetrace": 0x8032ef84,
		"vi::setFbbRegs": 0x8032efd8,
		"setFbbRegs": 0x8032efd8,
		"vi::setVerticalRegs": 0x8032f2ac,
		"setVerticalRegs": 0x8032f2ac,
		"vi::VIConfigure": 0x8032f44c,
		"VIConfigure": 0x8032f44c,
		"vi::VIFlush": 0x8032fbe8,
		"VIFlush": 0x8032fbe8,
		"vi::VISetNextFrameBuffer": 0x8032fd04,
		"VISetNextFrameBuffer": 0x8032fd04,
		"vi::VISetBlack": 0x8032fd70,
		"VISetBlack": 0x8032fd70,
		"vi::VIGetRetraceCount": 0x8032fdec,
		"VIGetRetraceCount": 0x8032fdec,
		"vi::getCurrentFieldEvenOdd": 0x8032fdf4,
		"getCurrentFieldEvenOdd": 0x8032fdf4,
		"vi::VIGetNextField": 0x8032fe5c,
		"VIGetNextField": 0x8032fe5c,
		"vi::VIGetCurrentLine": 0x8032ff04,
		"VIGetCurrentLine": 0x8032ff04,
		"vi::VIGetTvFormat": 0x8032ff9c,
		"VIGetTvFormat": 0x8032ff9c,
		"vi::VIGetDTVStatus": 0x80330018,
		"VIGetDTVStatus": 0x80330018,
		"pad::ClampStick": 0x80330054,
		"ClampStick": 0x80330054,
		"pad::PADClamp": 0x80330184,
		"PADClamp": 0x80330184,
		"pad::UpdateOrigin": 0x8033028c,
		"UpdateOrigin": 0x8033028c,
		"pad::PADOriginCallback": 0x80330430,
		"PADOriginCallback": 0x80330430,
		"pad::PADOriginUpdateCallback": 0x803304f4,
		"PADOriginUpdateCallback": 0x803304f4,
		"pad::PADProbeCallback": 0x803305b4,
		"PADProbeCallback": 0x803305b4,
		"pad::PADTypeAndStatusCallback": 0x8033068c,
		"PADTypeAndStatusCallback": 0x8033068c,
		"pad::PADReceiveCheckCallback": 0x803309b8,
		"PADReceiveCheckCallback": 0x803309b8,
		"pad::PADReset": 0x80330aec,
		"PADReset": 0x80330aec,
		"pad::PADRecalibrate": 0x80330bec,
		"PADRecalibrate": 0x80330bec,
		"pad::PADInit": 0x80330cf0,
		"PADInit": 0x80330cf0,
		"pad::PADRead": 0x80330f00,
		"PADRead": 0x80330f00,
		"pad::PADControlMotor": 0x803312ac,
		"PADControlMotor": 0x803312ac,
		"pad::PADSetSpec": 0x80331350,
		"PADSetSpec": 0x80331350,
		"pad::SPEC0_MakeStatus": 0x803313b0,
		"SPEC0_MakeStatus": 0x803313b0,
		"pad::SPEC1_MakeStatus": 0x80331524,
		"SPEC1_MakeStatus": 0x80331524,
		"pad::SPEC2_MakeStatus": 0x80331698,
		"SPEC2_MakeStatus": 0x80331698,
		"pad::PADSetAnalogMode": 0x80331a90,
		"PADSetAnalogMode": 0x80331a90,
		"pad::OnReset": 0x80331b04,
		"pad::SamplingHandler": 0x80331c98,
		"SamplingHandler": 0x80331c98,
		"pad::PADSetSamplingCallback": 0x80331cf8,
		"PADSetSamplingCallback": 0x80331cf8,
		"pad::__PADDisableRecalibration": 0x80331d4c,
		"__PADDisableRecalibration": 0x80331d4c,
		"ai::AIRegisterDMACallback": 0x80331dc8,
		"AIRegisterDMACallback": 0x80331dc8,
		"ai::AIInitDMA": 0x80331e0c,
		"AIInitDMA": 0x80331e0c,
		"ai::AIStartDMA": 0x80331e94,
		"AIStartDMA": 0x80331e94,
		"ai::AIResetStreamSampleCount": 0x80331eac,
		"AIResetStreamSampleCount": 0x80331eac,
		"ai::AISetStreamPlayState": 0x80331ec4,
		"AISetStreamPlayState": 0x80331ec4,
		"ai::AIGetStreamPlayState": 0x80331f9c,
		"AIGetStreamPlayState": 0x80331f9c,
		"ai::AISetDSPSampleRate": 0x80331fac,
		"AISetDSPSampleRate": 0x80331fac,
		"ai::AIGetDSPSampleRate": 0x8033208c,
		"AIGetDSPSampleRate": 0x8033208c,
		"ai::AISetStreamSampleRate": 0x803320a0,
		"AISetStreamSampleRate": 0x803320a0,
		"ai::__AI_set_stream_sample_rate": 0x803320c8,
		"__AI_set_stream_sample_rate": 0x803320c8,
		"ai::AIGetStreamSampleRate": 0x8033219c,
		"AIGetStreamSampleRate": 0x8033219c,
		"ai::AISetStreamVolLeft": 0x803321ac,
		"AISetStreamVolLeft": 0x803321ac,
		"ai::AIGetStreamVolLeft": 0x803321c8,
		"AIGetStreamVolLeft": 0x803321c8,
		"ai::AISetStreamVolRight": 0x803321d8,
		"AISetStreamVolRight": 0x803321d8,
		"ai::AIGetStreamVolRight": 0x803321f4,
		"AIGetStreamVolRight": 0x803321f4,
		"ai::AIInit": 0x80332204,
		"AIInit": 0x80332204,
		"ai::__AISHandler": 0x80332368,
		"__AISHandler": 0x80332368,
		"ai::__AIDHandler": 0x803323e4,
		"__AIDHandler": 0x803323e4,
		"ai::__AICallbackStackSwitch": 0x80332474,
		"__AICallbackStackSwitch": 0x80332474,
		"ai::__AI_SRC_INIT": 0x803324cc,
		"__AI_SRC_INIT": 0x803324cc,
		"ar::ARRegisterDMACallback": 0x803326b0,
		"ARRegisterDMACallback": 0x803326b0,
		"ar::ARStartDMA": 0x803326f4,
		"ARStartDMA": 0x803326f4,
		"ar::ARAlloc": 0x803327e4,
		"ARAlloc": 0x803327e4,
		"ar::ARInit": 0x8033284c,
		"ARInit": 0x8033284c,
		"ar::ARGetBaseAddress": 0x80332908,
		"ARGetBaseAddress": 0x80332908,
		"ar::ARGetSize": 0x80332910,
		"ARGetSize": 0x80332910,
		"ar::__ARHandler": 0x80332918,
		"__ARHandler": 0x80332918,
		"ar::__ARChecksize": 0x80332990,
		"__ARChecksize": 0x80332990,
		"ar::__ARQServiceQueueLo": 0x803332a4,
		"__ARQServiceQueueLo": 0x803332a4,
		"ar::__ARQCallbackHack": 0x803333a4,
		"__ARQCallbackHack": 0x803333a4,
		"ar::__ARQInterruptServiceRoutine": 0x803333a8,
		"__ARQInterruptServiceRoutine": 0x803333a8,
		"ar::ARQInit": 0x80333474,
		"ARQInit": 0x80333474,
		"ar::ARQPostRequest": 0x803334dc,
		"ARQPostRequest": 0x803334dc,
		"dsp::DSPCheckMailToDSP": 0x80333638,
		"DSPCheckMailToDSP": 0x80333638,
		"dsp::DSPCheckMailFromDSP": 0x80333648,
		"DSPCheckMailFromDSP": 0x80333648,
		"dsp::DSPReadMailFromDSP": 0x80333658,
		"DSPReadMailFromDSP": 0x80333658,
		"dsp::DSPSendMailToDSP": 0x80333670,
		"DSPSendMailToDSP": 0x80333670,
		"dsp::DSPAssertInt": 0x80333684,
		"DSPAssertInt": 0x80333684,
		"dsp::DSPInit": 0x803336c4,
		"DSPInit": 0x803336c4,
		"dsp::__DSP_debug_printf": 0x8033377c,
		"__DSP_debug_printf": 0x8033377c,
		"dsp::__DSP_exec_task": 0x803337cc,
		"__DSP_exec_task": 0x803337cc,
		"dsp::__DSP_boot_task": 0x8033396c,
		"__DSP_boot_task": 0x8033396c,
		"dsp::__DSP_insert_task": 0x80333af8,
		"__DSP_insert_task": 0x80333af8,
		"dsp::__DSP_remove_task": 0x80333b98,
		"__DSP_remove_task": 0x80333b98,
		"card::__CARDDefaultApiCallback": 0x80333c2c,
		"__CARDDefaultApiCallback": 0x80333c2c,
		"card::__CARDSyncCallback": 0x80333c30,
		"__CARDSyncCallback": 0x80333c30,
		"card::__CARDExtHandler": 0x80333c64,
		"__CARDExtHandler": 0x80333c64,
		"card::__CARDExiHandler": 0x80333d3c,
		"__CARDExiHandler": 0x80333d3c,
		"card::__CARDTxHandler": 0x80333e54,
		"__CARDTxHandler": 0x80333e54,
		"card::__CARDUnlockedHandler": 0x80333efc,
		"__CARDUnlockedHandler": 0x80333efc,
		"card::__CARDEnableInterrupt": 0x80333f80,
		"__CARDEnableInterrupt": 0x80333f80,
		"card::__CARDReadStatus": 0x80334040,
		"__CARDReadStatus": 0x80334040,
		"card::__CARDClearStatus": 0x80334130,
		"__CARDClearStatus": 0x80334130,
		"card::TimeoutHandler": 0x803341dc,
		"TimeoutHandler": 0x803341dc,
		"card::Retry": 0x80334280,
		"Retry": 0x80334280,
		"card::UnlockedCallback": 0x803344ac,
		"UnlockedCallback": 0x803344ac,
		"card::__CARDStart": 0x803345bc,
		"__CARDStart": 0x803345bc,
		"card::__CARDReadSegment": 0x80334770,
		"__CARDReadSegment": 0x80334770,
		"card::__CARDWritePage": 0x803348a4,
		"__CARDWritePage": 0x803348a4,
		"card::__CARDEraseSector": 0x803349c0,
		"__CARDEraseSector": 0x803349c0,
		"card::CARDInit": 0x80334aa0,
		"CARDInit": 0x80334aa0,
		"card::__CARDSetDiskID": 0x80334b3c,
		"__CARDSetDiskID": 0x80334b3c,
		"card::__CARDGetControlBlock": 0x80334b74,
		"__CARDGetControlBlock": 0x80334b74,
		"card::__CARDPutControlBlock": 0x80334c2c,
		"__CARDPutControlBlock": 0x80334c2c,
		"card::CARDFreeBlocks": 0x80334c90,
		"CARDFreeBlocks": 0x80334c90,
		"card::__CARDSync": 0x80334de0,
		"__CARDSync": 0x80334de0,
		"card::OnReset": 0x80334e78,
		"card::bitrev": 0x80334ec8,
		"bitrev": 0x80334ec8,
		"card::ReadArrayUnlock": 0x80335034,
		"ReadArrayUnlock": 0x80335034,
		"card::DummyLen": 0x80335178,
		"DummyLen": 0x80335178,
		"card::__CARDUnlock": 0x8033523c,
		"__CARDUnlock": 0x8033523c,
		"card::InitCallback": 0x80335d94,
		"InitCallback": 0x80335d94,
		"card::DoneCallback": 0x80335e04,
		"DoneCallback": 0x80335e04,
		"card::BlockReadCallback": 0x80336128,
		"BlockReadCallback": 0x80336128,
		"card::__CARDRead": 0x80336204,
		"__CARDRead": 0x80336204,
		"card::BlockWriteCallback": 0x80336268,
		"BlockWriteCallback": 0x80336268,
		"card::__CARDWrite": 0x80336344,
		"__CARDWrite": 0x80336344,
		"card::__CARDGetFatBlock": 0x803363a8,
		"__CARDGetFatBlock": 0x803363a8,
		"card::__CARDAllocBlock": 0x8033654c,
		"__CARDAllocBlock": 0x8033654c,
		"card::__CARDUpdateFatBlock": 0x80336664,
		"__CARDUpdateFatBlock": 0x80336664,
		"card::__CARDGetDirBlock": 0x80336710,
		"__CARDGetDirBlock": 0x80336710,
		"card::__CARDUpdateDir": 0x803368b0,
		"__CARDUpdateDir": 0x803368b0,
		"card::__CARDCheckSum": 0x80336974,
		"__CARDCheckSum": 0x80336974,
		"card::VerifyID": 0x80336b24,
		"VerifyID": 0x80336b24,
		"card::VerifyDir": 0x80336da8,
		"VerifyDir": 0x80336da8,
		"card::VerifyFAT": 0x80336fe8,
		"VerifyFAT": 0x80336fe8,
		"card::__CARDVerify": 0x8033726c,
		"__CARDVerify": 0x8033726c,
		"card::CARDCheckExAsync": 0x803372f8,
		"CARDCheckExAsync": 0x803372f8,
		"card::CARDCheck": 0x80337888,
		"CARDCheck": 0x80337888,
		"card::IsCard": 0x803378dc,
		"IsCard": 0x803378dc,
		"card::CARDProbeEx": 0x803379a8,
		"CARDProbeEx": 0x803379a8,
		"card::DoMount": 0x80337b24,
		"DoMount": 0x80337b24,
		"card::__CARDMountCallback": 0x80337f34,
		"__CARDMountCallback": 0x80337f34,
		"card::CARDMountAsync": 0x8033803c,
		"CARDMountAsync": 0x8033803c,
		"card::CARDMount": 0x803381dc,
		"CARDMount": 0x803381dc,
		"card::DoUnmount": 0x80338224,
		"DoUnmount": 0x80338224,
		"card::CARDUnmount": 0x803382c0,
		"CARDUnmount": 0x803382c0,
		"card::FormatCallback": 0x8033836c,
		"FormatCallback": 0x8033836c,
		"card::__CARDFormatRegionAsync": 0x803384b0,
		"__CARDFormatRegionAsync": 0x803384b0,
		"card::CARDFormat": 0x80338b08,
		"CARDFormat": 0x80338b08,
		"card::__CARDCompareFileName": 0x80338b5c,
		"__CARDCompareFileName": 0x80338b5c,
		"card::__CARDAccess": 0x80338bc4,
		"__CARDAccess": 0x80338bc4,
		"card::__CARDIsPublic": 0x80338c5c,
		"__CARDIsPublic": 0x80338c5c,
		"card::CARDOpen": 0x80338c8c,
		"CARDOpen": 0x80338c8c,
		"card::CARDClose": 0x80338e04,
		"CARDClose": 0x80338e04,
		"card::CreateCallbackFat": 0x80338e58,
		"CreateCallbackFat": 0x80338e58,
		"card::CARDCreateAsync": 0x80338f88,
		"CARDCreateAsync": 0x80338f88,
		"card::CARDCreate": 0x803391a8,
		"CARDCreate": 0x803391a8,
		"card::__CARDSeek": 0x803391f0,
		"__CARDSeek": 0x803391f0,
		"card::ReadCallback": 0x803393a8,
		"ReadCallback": 0x803393a8,
		"card::CARDReadAsync": 0x803394d8,
		"CARDReadAsync": 0x803394d8,
		"card::CARDRead": 0x80339620,
		"CARDRead": 0x80339620,
		"card::CARDWriteAsync": 0x80339888,
		"CARDWriteAsync": 0x80339888,
		"card::CARDWrite": 0x8033999c,
		"CARDWrite": 0x8033999c,
		"card::UpdateIconOffsets": 0x803399e4,
		"UpdateIconOffsets": 0x803399e4,
		"card::CARDGetStatus": 0x80339bdc,
		"CARDGetStatus": 0x80339bdc,
		"card::CARDSetStatusAsync": 0x80339d08,
		"CARDSetStatusAsync": 0x80339d08,
		"card::CARDSetStatus": 0x80339e7c,
		"CARDSetStatus": 0x80339e7c,
		"gx::__GXDefaultTexRegionCallback": 0x80339ec4,
		"__GXDefaultTexRegionCallback": 0x80339ec4,
		"gx::__GXDefaultTlutRegionCallback": 0x80339f40,
		"__GXDefaultTlutRegionCallback": 0x80339f40,
		"gx::GXInit": 0x80339f64,
		"GXInit": 0x80339f64,
		"gx::__GXInitGX": 0x8033a730,
		"__GXInitGX": 0x8033a730,
		"gx::GXCPInterruptHandler": 0x8033afb4,
		"GXCPInterruptHandler": 0x8033afb4,
		"gx::GXInitFifoBase": 0x8033b0f0,
		"GXInitFifoBase": 0x8033b0f0,
		"gx::GXInitFifoPtrs": 0x8033b15c,
		"GXInitFifoPtrs": 0x8033b15c,
		"gx::GXInitFifoLimits": 0x8033b1cc,
		"GXInitFifoLimits": 0x8033b1cc,
		"gx::GXSetCPUFifo": 0x8033b1d8,
		"GXSetCPUFifo": 0x8033b1d8,
		"gx::GXSetGPFifo": 0x8033b2e8,
		"GXSetGPFifo": 0x8033b2e8,
		"gx::GXGetFifoPtrs": 0x8033b460,
		"GXGetFifoPtrs": 0x8033b460,
		"gx::GXEnableBreakPt": 0x8033b4f8,
		"GXEnableBreakPt": 0x8033b4f8,
		"gx::GXDisableBreakPt": 0x8033b590,
		"GXDisableBreakPt": 0x8033b590,
		"gx::__GXFifoInit": 0x8033b5f4,
		"__GXFifoInit": 0x8033b5f4,
		"gx::__GXFifoReadEnable": 0x8033b640,
		"__GXFifoReadEnable": 0x8033b640,
		"gx::__GXFifoReadDisable": 0x8033b668,
		"__GXFifoReadDisable": 0x8033b668,
		"gx::__GXFifoLink": 0x8033b68c,
		"__GXFifoLink": 0x8033b68c,
		"gx::__GXWriteFifoIntEnable": 0x8033b6d0,
		"__GXWriteFifoIntEnable": 0x8033b6d0,
		"gx::__GXWriteFifoIntReset": 0x8033b71c,
		"__GXWriteFifoIntReset": 0x8033b71c,
		"gx::GXGetCPUFifo": 0x8033b768,
		"GXGetCPUFifo": 0x8033b768,
		"gx::__GXXfVtxSpecs": 0x8033b770,
		"__GXXfVtxSpecs": 0x8033b770,
		"gx::GXSetVtxDesc": 0x8033b8c8,
		"GXSetVtxDesc": 0x8033b8c8,
		"gx::GXSetVtxDescv": 0x8033bc28,
		"GXSetVtxDescv": 0x8033bc28,
		"gx::__GXSetVCD": 0x8033bfac,
		"__GXSetVCD": 0x8033bfac,
		"gx::__GXCalculateVLim": 0x8033c000,
		"__GXCalculateVLim": 0x8033c000,
		"gx::GXGetVtxDesc": 0x8033c124,
		"GXGetVtxDesc": 0x8033c124,
		"gx::GXGetVtxDescv": 0x8033c2d8,
		"GXGetVtxDescv": 0x8033c2d8,
		"gx::GXClearVtxDesc": 0x8033c348,
		"GXClearVtxDesc": 0x8033c348,
		"gx::GXSetVtxAttrFmt": 0x8033c394,
		"GXSetVtxAttrFmt": 0x8033c394,
		"gx::GXSetVtxAttrFmtv": 0x8033c6f0,
		"GXSetVtxAttrFmtv": 0x8033c6f0,
		"gx::__GXSetVAT": 0x8033ca6c,
		"__GXSetVAT": 0x8033ca6c,
		"gx::GXGetVtxAttrFmt": 0x8033cb08,
		"GXGetVtxAttrFmt": 0x8033cb08,
		"gx::GXGetVtxAttrFmtv": 0x8033cd50,
		"GXGetVtxAttrFmtv": 0x8033cd50,
		"gx::GXSetArray": 0x8033cdc4,
		"GXSetArray": 0x8033cdc4,
		"gx::GXInvalidateVtxCache": 0x8033ce50,
		"GXInvalidateVtxCache": 0x8033ce50,
		"gx::GXSetTexCoordGen2": 0x8033ce60,
		"GXSetTexCoordGen2": 0x8033ce60,
		"gx::GXSetNumTexGens": 0x8033d130,
		"GXSetNumTexGens": 0x8033d130,
		"gx::GXSetMisc": 0x8033d178,
		"GXSetMisc": 0x8033d178,
		"gx::GXFlush": 0x8033d1f0,
		"GXFlush": 0x8033d1f0,
		"gx::GXSetDrawSync": 0x8033d24c,
		"GXSetDrawSync": 0x8033d24c,
		"gx::GXSetDrawDone": 0x8033d304,
		"GXSetDrawDone": 0x8033d304,
		"gx::GXWaitDrawDone": 0x8033d39c,
		"GXWaitDrawDone": 0x8033d39c,
		"gx::GXDrawDone": 0x8033d3e8,
		"GXDrawDone": 0x8033d3e8,
		"gx::GXPixModeSync": 0x8033d468,
		"GXPixModeSync": 0x8033d468,
		"gx::GXPokeAlphaMode": 0x8033d48c,
		"GXPokeAlphaMode": 0x8033d48c,
		"gx::GXPokeAlphaRead": 0x8033d4a0,
		"GXPokeAlphaRead": 0x8033d4a0,
		"gx::GXPokeAlphaUpdate": 0x8033d4b4,
		"GXPokeAlphaUpdate": 0x8033d4b4,
		"gx::GXPokeBlendMode": 0x8033d4d0,
		"GXPokeBlendMode": 0x8033d4d0,
		"gx::GXPokeColorUpdate": 0x8033d558,
		"GXPokeColorUpdate": 0x8033d558,
		"gx::GXPokeDstAlpha": 0x8033d574,
		"GXPokeDstAlpha": 0x8033d574,
		"gx::GXPokeDither": 0x8033d588,
		"GXPokeDither": 0x8033d588,
		"gx::GXPokeZMode": 0x8033d5a4,
		"GXPokeZMode": 0x8033d5a4,
		"gx::GXPeekARGB": 0x8033d5cc,
		"GXPeekARGB": 0x8033d5cc,
		"gx::GXPeekZ": 0x8033d5f0,
		"GXPeekZ": 0x8033d5f0,
		"gx::GXSetDrawSyncCallback": 0x8033d618,
		"GXSetDrawSyncCallback": 0x8033d618,
		"gx::GXTokenInterruptHandler": 0x8033d65c,
		"GXTokenInterruptHandler": 0x8033d65c,
		"gx::GXFinishInterruptHandler": 0x8033d6e4,
		"GXFinishInterruptHandler": 0x8033d6e4,
		"gx::__GXPEInit": 0x8033d768,
		"__GXPEInit": 0x8033d768,
		"gx::__GXSetDirtyState": 0x8033d7e8,
		"__GXSetDirtyState": 0x8033d7e8,
		"gx::GXBegin": 0x8033d888,
		"GXBegin": 0x8033d888,
		"gx::__GXSendFlushPrim": 0x8033d978,
		"__GXSendFlushPrim": 0x8033d978,
		"gx::GXSetLineWidth": 0x8033da00,
		"GXSetLineWidth": 0x8033da00,
		"gx::GXSetPointSize": 0x8033da58,
		"GXSetPointSize": 0x8033da58,
		"gx::GXEnableTexOffsets": 0x8033daac,
		"GXEnableTexOffsets": 0x8033daac,
		"gx::GXSetCullMode": 0x8033db10,
		"GXSetCullMode": 0x8033db10,
		"gx::GXSetCoPlanar": 0x8033db60,
		"GXSetCoPlanar": 0x8033db60,
		"gx::__GXSetGenMode": 0x8033dba4,
		"__GXSetGenMode": 0x8033dba4,
		"gx::GXSetDispCopySrc": 0x8033dbc8,
		"GXSetDispCopySrc": 0x8033dbc8,
		"gx::GXSetTexCopySrc": 0x8033dc88,
		"GXSetTexCopySrc": 0x8033dc88,
		"gx::GXSetDispCopyDst": 0x8033dd48,
		"GXSetDispCopyDst": 0x8033dd48,
		"gx::GXSetTexCopyDst": 0x8033dd8c,
		"GXSetTexCopyDst": 0x8033dd8c,
		"gx::GXSetDispCopyFrame2Field": 0x8033defc,
		"GXSetDispCopyFrame2Field": 0x8033defc,
		"gx::GXSetCopyClamp": 0x8033df28,
		"GXSetCopyClamp": 0x8033df28,
		"gx::GXGetNumXfbLines": 0x8033dfa4,
		"GXGetNumXfbLines": 0x8033dfa4,
		"gx::GXGetYScaleFactor": 0x8033e034,
		"GXGetYScaleFactor": 0x8033e034,
		"gx::GXSetDispCopyYScale": 0x8033e26c,
		"GXSetDispCopyYScale": 0x8033e26c,
		"gx::GXSetCopyClear": 0x8033e340,
		"GXSetCopyClear": 0x8033e340,
		"gx::GXSetCopyFilter": 0x8033e3a8,
		"GXSetCopyFilter": 0x8033e3a8,
		"gx::GXSetDispCopyGamma": 0x8033e5d0,
		"GXSetDispCopyGamma": 0x8033e5d0,
		"gx::GXCopyDisp": 0x8033e5ec,
		"GXCopyDisp": 0x8033e5ec,
		"gx::GXCopyTex": 0x8033e75c,
		"GXCopyTex": 0x8033e75c,
		"gx::GXClearBoundingBox": 0x8033e8ec,
		"GXClearBoundingBox": 0x8033e8ec,
		"gx::GXInitLightAttn": 0x8033e924,
		"GXInitLightAttn": 0x8033e924,
		"gx::GXInitLightAttnA": 0x8033e940,
		"GXInitLightAttnA": 0x8033e940,
		"gx::GXInitLightAttnK": 0x8033e950,
		"GXInitLightAttnK": 0x8033e950,
		"gx::GXInitLightDistAttn": 0x8033e960,
		"GXInitLightDistAttn": 0x8033e960,
		"gx::GXInitLightPos": 0x8033ea30,
		"GXInitLightPos": 0x8033ea30,
		"gx::GXInitSpecularDir": 0x8033ea40,
		"GXInitSpecularDir": 0x8033ea40,
		"gx::GXInitLightColor": 0x8033eb14,
		"GXInitLightColor": 0x8033eb14,
		"gx::GXGetLightColor": 0x8033eb3c,
		"GXGetLightColor": 0x8033eb3c,
		"gx::GXLoadLightObjImm": 0x8033eb6c,
		"GXLoadLightObjImm": 0x8033eb6c,
		"gx::GXSetChanAmbColor": 0x8033ecb4,
		"GXSetChanAmbColor": 0x8033ecb4,
		"gx::GXSetChanMatColor": 0x8033ee1c,
		"GXSetChanMatColor": 0x8033ee1c,
		"gx::GXSetNumChans": 0x8033ef84,
		"GXSetNumChans": 0x8033ef84,
		"gx::GXSetChanCtrl": 0x8033efd0,
		"GXSetChanCtrl": 0x8033efd0,
		"gx::GXGetTexBufferSize": 0x8033f1b4,
		"GXGetTexBufferSize": 0x8033f1b4,
		"gx::__GetImageTileCount": 0x8033f310,
		"__GetImageTileCount": 0x8033f310,
		"gx::GXInitTexObj": 0x8033f3d8,
		"GXInitTexObj": 0x8033f3d8,
		"gx::GXInitTexObjCI": 0x8033f64c,
		"GXInitTexObjCI": 0x8033f64c,
		"gx::GXInitTexObjLOD": 0x8033f694,
		"GXInitTexObjLOD": 0x8033f694,
		"gx::GXGetTexObjAll": 0x8033f828,
		"GXGetTexObjAll": 0x8033f828,
		"gx::GXGetTexObjWidth": 0x8033f890,
		"GXGetTexObjWidth": 0x8033f890,
		"gx::GXGetTexObjHeight": 0x8033f8a0,
		"GXGetTexObjHeight": 0x8033f8a0,
		"gx::GXGetTexObjFmt": 0x8033f8b0,
		"GXGetTexObjFmt": 0x8033f8b0,
		"gx::GXLoadTexObjPreLoaded": 0x8033f8b8,
		"GXLoadTexObjPreLoaded": 0x8033f8b8,
		"gx::GXLoadTexObj": 0x8033fa60,
		"GXLoadTexObj": 0x8033fa60,
		"gx::GXInitTlutObj": 0x8033fab4,
		"GXInitTlutObj": 0x8033fab4,
		"gx::GXLoadTlut": 0x8033fafc,
		"GXLoadTlut": 0x8033fafc,
		"gx::GXInitTexCacheRegion": 0x8033fb98,
		"GXInitTexCacheRegion": 0x8033fb98,
		"gx::GXInitTlutRegion": 0x8033fcb8,
		"GXInitTlutRegion": 0x8033fcb8,
		"gx::GXInvalidateTexAll": 0x8033fd00,
		"GXInvalidateTexAll": 0x8033fd00,
		"gx::GXSetTexRegionCallback": 0x8033fd48,
		"GXSetTexRegionCallback": 0x8033fd48,
		"gx::GXSetTlutRegionCallback": 0x8033fd5c,
		"GXSetTlutRegionCallback": 0x8033fd5c,
		"gx::GXSetTexCoordScaleManually": 0x8033fd70,
		"GXSetTexCoordScaleManually": 0x8033fd70,
		"gx::GXSetTexCoordCylWrap": 0x8033fe0c,
		"GXSetTexCoordCylWrap": 0x8033fe0c,
		"gx::__SetSURegs": 0x8033fe90,
		"__SetSURegs": 0x8033fe90,
		"gx::__GXSetSUTexRegs": 0x8033ff5c,
		"__GXSetSUTexRegs": 0x8033ff5c,
		"gx::__GXSetTmemConfig": 0x803400d8,
		"__GXSetTmemConfig": 0x803400d8,
		"gx::GXSetTevIndirect": 0x80340318,
		"GXSetTevIndirect": 0x80340318,
		"gx::GXSetIndTexMtx": 0x803403b4,
		"GXSetIndTexMtx": 0x803403b4,
		"gx::GXSetIndTexCoordScale": 0x80340514,
		"GXSetIndTexCoordScale": 0x80340514,
		"gx::GXSetIndTexOrder": 0x803406e8,
		"GXSetIndTexOrder": 0x803406e8,
		"gx::GXSetNumIndStages": 0x80340820,
		"GXSetNumIndStages": 0x80340820,
		"gx::GXSetTevDirect": 0x8034084c,
		"GXSetTevDirect": 0x8034084c,
		"gx::GXSetTevIndWarp": 0x80340894,
		"GXSetTevIndWarp": 0x80340894,
		"gx::__GXUpdateBPMask": 0x803408f8,
		"__GXUpdateBPMask": 0x803408f8,
		"gx::__GXFlushTextureState": 0x803409c4,
		"__GXFlushTextureState": 0x803409c4,
		"gx::GXSetTevOp": 0x803409e8,
		"GXSetTevOp": 0x803409e8,
		"gx::GXSetTevColorIn": 0x80340b8c,
		"GXSetTevColorIn": 0x80340b8c,
		"gx::GXSetTevAlphaIn": 0x80340c0c,
		"GXSetTevAlphaIn": 0x80340c0c,
		"gx::GXSetTevColorOp": 0x80340c90,
		"GXSetTevColorOp": 0x80340c90,
		"gx::GXSetTevAlphaOp": 0x80340d50,
		"GXSetTevAlphaOp": 0x80340d50,
		"gx::GXSetTevColor": 0x80340e10,
		"GXSetTevColor": 0x80340e10,
		"gx::GXSetTevColorS10": 0x80340e84,
		"GXSetTevColorS10": 0x80340e84,
		"gx::GXSetTevKColor": 0x80340ef8,
		"GXSetTevKColor": 0x80340ef8,
		"gx::GXSetTevKColorSel": 0x80340f6c,
		"GXSetTevKColorSel": 0x80340f6c,
		"gx::GXSetTevKAlphaSel": 0x80340fd8,
		"GXSetTevKAlphaSel": 0x80340fd8,
		"gx::GXSetTevSwapMode": 0x80341044,
		"GXSetTevSwapMode": 0x80341044,
		"gx::GXSetTevSwapModeTable": 0x8034109c,
		"GXSetTevSwapModeTable": 0x8034109c,
		"gx::GXSetAlphaCompare": 0x8034113c,
		"GXSetAlphaCompare": 0x8034113c,
		"gx::GXSetZTexture": 0x8034118c,
		"GXSetZTexture": 0x8034118c,
		"gx::GXSetTevOrder": 0x80341210,
		"GXSetTevOrder": 0x80341210,
		"gx::GXSetNumTevStages": 0x803413ec,
		"GXSetNumTevStages": 0x803413ec,
		"gx::GXSetFog": 0x80341420,
		"GXSetFog": 0x80341420,
		"gx::GXSetFogRangeAdj": 0x803415d0,
		"GXSetFogRangeAdj": 0x803415d0,
		"gx::GXSetBlendMode": 0x803416d0,
		"GXSetBlendMode": 0x803416d0,
		"gx::GXSetColorUpdate": 0x803417d4,
		"GXSetColorUpdate": 0x803417d4,
		"gx::GXSetAlphaUpdate": 0x80341814,
		"GXSetAlphaUpdate": 0x80341814,
		"gx::GXSetZMode": 0x80341854,
		"GXSetZMode": 0x80341854,
		"gx::GXSetZCompLoc": 0x803418cc,
		"GXSetZCompLoc": 0x803418cc,
		"gx::GXSetPixelFmt": 0x8034190c,
		"GXSetPixelFmt": 0x8034190c,
		"gx::GXSetDither": 0x80341a1c,
		"GXSetDither": 0x80341a1c,
		"gx::GXSetDstAlpha": 0x80341a5c,
		"GXSetDstAlpha": 0x80341a5c,
		"gx::GXSetFieldMask": 0x80341ab0,
		"GXSetFieldMask": 0x80341ab0,
		"gx::GXSetFieldMode": 0x80341ae8,
		"GXSetFieldMode": 0x80341ae8,
		"gx::GXDrawSphere": 0x80341b68,
		"GXDrawSphere": 0x80341b68,
		"gx::GXDrawCubeFace": 0x80341ee4,
		"GXDrawCubeFace": 0x80341ee4,
		"gx::GXDrawCube": 0x803420fc,
		"GXDrawCube": 0x803420fc,
		"gx::__GXSetRange": 0x8034234c,
		"__GXSetRange": 0x8034234c,
		"gx::GXCallDisplayList": 0x80342350,
		"GXCallDisplayList": 0x80342350,
		"gx::GXProject": 0x803423c0,
		"GXProject": 0x803423c0,
		"gx::GXSetProjection": 0x80342534,
		"GXSetProjection": 0x80342534,
		"gx::GXGetProjectionv": 0x80342608,
		"GXGetProjectionv": 0x80342608,
		"gx::WriteMTXPS4x3": 0x80342680,
		"WriteMTXPS4x3": 0x80342680,
		"gx::WriteMTXPS3x3from3x4": 0x803426b4,
		"WriteMTXPS3x3from3x4": 0x803426b4,
		"gx::WriteMTXPS4x2": 0x803426e8,
		"WriteMTXPS4x2": 0x803426e8,
		"gx::GXLoadPosMtxImm": 0x8034270c,
		"GXLoadPosMtxImm": 0x8034270c,
		"gx::GXLoadPosMtxIndx": 0x80342748,
		"GXLoadPosMtxIndx": 0x80342748,
		"gx::GXLoadNrmMtxImm": 0x80342778,
		"GXLoadNrmMtxImm": 0x80342778,
		"gx::GXLoadNrmMtxIndx3x3": 0x803427b8,
		"GXLoadNrmMtxIndx3x3": 0x803427b8,
		"gx::GXSetCurrentMtx": 0x803427ec,
		"GXSetCurrentMtx": 0x803427ec,
		"gx::GXLoadTexMtxImm": 0x80342828,
		"GXLoadTexMtxImm": 0x80342828,
		"gx::GXSetViewportJitter": 0x803428ac,
		"GXSetViewportJitter": 0x803428ac,
		"gx::GXSetViewport": 0x803429c8,
		"GXSetViewport": 0x803429c8,
		"gx::GXGetViewportv": 0x803429ec,
		"GXGetViewportv": 0x803429ec,
		"gx::GXSetScissor": 0x80342a38,
		"GXSetScissor": 0x80342a38,
		"gx::GXSetScissorBoxOffset": 0x80342ae8,
		"GXSetScissorBoxOffset": 0x80342ae8,
		"gx::GXSetClipMode": 0x80342b2c,
		"GXSetClipMode": 0x80342b2c,
		"gx::__GXSetMatrixIndex": 0x80342b54,
		"__GXSetMatrixIndex": 0x80342b54,
		"gx::GXSetGPMetric": 0x80342bd8,
		"GXSetGPMetric": 0x80342bd8,
		"gx::GXClearGPMetric": 0x80343470,
		"GXClearGPMetric": 0x80343470,
		"gx::GXReadPixMetric": 0x80343480,
		"GXReadPixMetric": 0x80343480,
		"gx::GXClearPixMetric": 0x80343510,
		"GXClearPixMetric": 0x80343510,
		"OdemuExi2::DBClose": 0x80343540,
		"DBClose": 0x80343540,
		"OdemuExi2::DBOpen": 0x80343544,
		"DBOpen": 0x80343544,
		"OdemuExi2::DBWrite": 0x80343548,
		"DBWrite": 0x80343548,
		"OdemuExi2::DBRead": 0x803437a8,
		"DBRead": 0x803437a8,
		"OdemuExi2::DBQueryData": 0x80343834,
		"DBQueryData": 0x80343834,
		"OdemuExi2::DBInitInterrupts": 0x803438d0,
		"DBInitInterrupts": 0x803438d0,
		"OdemuExi2::DBInitComm": 0x80343924,
		"DBInitComm": 0x80343924,
		"OdemuExi2::DBGHandler": 0x8034399c,
		"DBGHandler": 0x8034399c,
		"OdemuExi2::MWCallback": 0x803439dc,
		"MWCallback": 0x803439dc,
		"OdemuExi2::DBGReadStatus": 0x80343a18,
		"DBGReadStatus": 0x80343a18,
		"OdemuExi2::DBGWrite": 0x80343ac4,
		"DBGWrite": 0x80343ac4,
		"OdemuExi2::DBGRead": 0x80343ba0,
		"DBGRead": 0x80343ba0,
		"OdemuExi2::DBGReadMailbox": 0x80343c7c,
		"DBGReadMailbox": 0x80343c7c,
		"OdemuExi2::DBGEXIImm": 0x80343d28,
		"DBGEXIImm": 0x80343d28,
		"amcstubs::EXI2_Init": 0x80343fc0,
		"EXI2_Init": 0x80343fc0,
		"amcstubs::EXI2_EnableInterrupts": 0x80343fc4,
		"EXI2_EnableInterrupts": 0x80343fc4,
		"amcstubs::EXI2_Poll": 0x80343fc8,
		"EXI2_Poll": 0x80343fc8,
		"amcstubs::EXI2_ReadN": 0x80343fd0,
		"EXI2_ReadN": 0x80343fd0,
		"amcstubs::EXI2_WriteN": 0x80343fd8,
		"EXI2_WriteN": 0x80343fd8,
		"amcstubs::EXI2_Reserve": 0x80343fe0,
		"EXI2_Reserve": 0x80343fe0,
		"amcstubs::EXI2_Unreserve": 0x80343fe4,
		"EXI2_Unreserve": 0x80343fe4,
		"amcstubs::AMC_IsStub": 0x80343fe8,
		"AMC_IsStub": 0x80343fe8,
		"odenotstub::Hu_IsStub": 0x80343ff0,
		"Hu_IsStub": 0x80343ff0,
		"gd::GDInitGDLObj": 0x80343ff8,
		"GDInitGDLObj": 0x80343ff8,
		"gd::GDFlushCurrToMem": 0x80344010,
		"GDFlushCurrToMem": 0x80344010,
		"gd::GDPadCurr32": 0x8034403c,
		"GDPadCurr32": 0x8034403c,
		"gd::GDOverflowed": 0x80344134,
		"GDOverflowed": 0x80344134,
		"gd::GDSetOverflowCallback": 0x80344164,
		"GDSetOverflowCallback": 0x80344164,
		"gd::GDSetVtxDescv": 0x8034416c,
		"GDSetVtxDescv": 0x8034416c,
		"gd::GDSetVtxAttrFmtv": 0x80344768,
		"GDSetVtxAttrFmtv": 0x80344768,
		"gd::GDSetArray": 0x80344d88,
		"GDSetArray": 0x80344d88,
		"gd::GDSetArrayRaw": 0x80344f94,
		"GDSetArrayRaw": 0x80344f94,
		"gd::GDSetCullMode": 0x8034519c,
		"GDSetCullMode": 0x8034519c,
		"gd::GDSetGenMode2": 0x80345328,
		"GDSetGenMode2": 0x80345328,
		"gd::GDSetLightAttn": 0x80345764,
		"GDSetLightAttn": 0x80345764,
		"gd::GDSetLightColor": 0x80345c00,
		"GDSetLightColor": 0x80345c00,
		"gd::GDSetLightPos": 0x80345da8,
		"GDSetLightPos": 0x80345da8,
		"gd::GDSetLightDir": 0x8034607c,
		"GDSetLightDir": 0x8034607c,
		"gd::GDSetChanMatColor": 0x80346350,
		"GDSetChanMatColor": 0x80346350,
		"gd::GDSetChanCtrl": 0x803464e8,
		"GDSetChanCtrl": 0x803464e8,
		"gd::GDSetBlendMode": 0x803467fc,
		"GDSetBlendMode": 0x803467fc,
		"gd::GDSetBlendModeEtc": 0x80346a88,
		"GDSetBlendModeEtc": 0x80346a88,
		"gd::GDSetZMode": 0x80346c94,
		"GDSetZMode": 0x80346c94,
		"gd::GDSetDstAlpha": 0x80346d98,
		"GDSetDstAlpha": 0x80346d98,
		"gd::GDSetTevOp": 0x80346e84,
		"GDSetTevOp": 0x80346e84,
		"gd::GDSetTevColorCalc": 0x80347118,
		"GDSetTevColorCalc": 0x80347118,
		"gd::GDSetTevAlphaCalcAndSwap": 0x80347364,
		"GDSetTevAlphaCalcAndSwap": 0x80347364,
		"gd::GDSetAlphaCompare": 0x803475d8,
		"GDSetAlphaCompare": 0x803475d8,
		"gd::GDSetTevOrder": 0x803476dc,
		"GDSetTevOrder": 0x803476dc,
		"gd::GDSetCurrentMtx": 0x8034784c,
		"GDSetCurrentMtx": 0x8034784c,
		"si::SIBusy": 0x80347c18,
		"SIBusy": 0x80347c18,
		"si::SIIsChanBusy": 0x80347c38,
		"SIIsChanBusy": 0x80347c38,
		"si::CompleteTransfer": 0x80347c74,
		"CompleteTransfer": 0x80347c74,
		"si::SIInterruptHandler": 0x80347f70,
		"SIInterruptHandler": 0x80347f70,
		"si::SIEnablePollingInterrupt": 0x803482b4,
		"SIEnablePollingInterrupt": 0x803482b4,
		"si::SIRegisterPollingHandler": 0x8034834c,
		"SIRegisterPollingHandler": 0x8034834c,
		"si::SIUnregisterPollingHandler": 0x80348418,
		"SIUnregisterPollingHandler": 0x80348418,
		"si::SIInit": 0x8034850c,
		"SIInit": 0x8034850c,
		"si::__SITransfer": 0x803485b0,
		"__SITransfer": 0x803485b0,
		"si::SIGetStatus": 0x803487bc,
		"SIGetStatus": 0x803487bc,
		"si::SISetCommand": 0x80348838,
		"SISetCommand": 0x80348838,
		"si::SITransferCommands": 0x8034884c,
		"SITransferCommands": 0x8034884c,
		"si::SISetXY": 0x8034885c,
		"SISetXY": 0x8034885c,
		"si::SIEnablePolling": 0x803488c8,
		"SIEnablePolling": 0x803488c8,
		"si::SIDisablePolling": 0x80348964,
		"SIDisablePolling": 0x80348964,
		"si::SIGetResponseRaw": 0x803489d0,
		"SIGetResponseRaw": 0x803489d0,
		"si::SIGetResponse": 0x80348aa4,
		"SIGetResponse": 0x80348aa4,
		"si::AlarmHandler": 0x80348b68,
		"si::SITransfer": 0x80348bf4,
		"SITransfer": 0x80348bf4,
		"si::GetTypeCallback": 0x80348d60,
		"GetTypeCallback": 0x80348d60,
		"si::SIGetType": 0x80348ff8,
		"SIGetType": 0x80348ff8,
		"si::SIGetTypeAsync": 0x803491bc,
		"SIGetTypeAsync": 0x803491bc,
		"si::SISetSamplingRate": 0x803492f8,
		"SISetSamplingRate": 0x803492f8,
		"si::SIRefreshSamplingRate": 0x803493dc,
		"SIRefreshSamplingRate": 0x803493dc,
		"exi::SetExiInterruptMask": 0x80349400,
		"SetExiInterruptMask": 0x80349400,
		"exi::EXIImm": 0x803494f4,
		"EXIImm": 0x803494f4,
		"exi::EXIImmEx": 0x80349750,
		"EXIImmEx": 0x80349750,
		"exi::EXIDma": 0x803497f0,
		"EXIDma": 0x803497f0,
		"exi::EXISync": 0x803498dc,
		"EXISync": 0x803498dc,
		"exi::EXIClearInterrupts": 0x80349b14,
		"EXIClearInterrupts": 0x80349b14,
		"exi::EXISetExiCallback": 0x80349b5c,
		"EXISetExiCallback": 0x80349b5c,
		"exi::__EXIProbe": 0x80349bd8,
		"__EXIProbe": 0x80349bd8,
		"exi::EXIProbe": 0x80349d4c,
		"EXIProbe": 0x80349d4c,
		"exi::EXIProbeEx": 0x80349dcc,
		"EXIProbeEx": 0x80349dcc,
		"exi::EXIAttach": 0x80349e80,
		"EXIAttach": 0x80349e80,
		"exi::EXIDetach": 0x80349f8c,
		"EXIDetach": 0x80349f8c,
		"exi::EXISelect": 0x8034a048,
		"EXISelect": 0x8034a048,
		"exi::EXIDeselect": 0x8034a174,
		"EXIDeselect": 0x8034a174,
		"exi::EXIIntrruptHandler": 0x8034a284,
		"EXIIntrruptHandler": 0x8034a284,
		"exi::TCIntrruptHandler": 0x8034a34c,
		"TCIntrruptHandler": 0x8034a34c,
		"exi::EXTIntrruptHandler": 0x8034a564,
		"EXTIntrruptHandler": 0x8034a564,
		"exi::EXIInit": 0x8034a62c,
		"EXIInit": 0x8034a62c,
		"exi::EXILock": 0x8034a740,
		"EXILock": 0x8034a740,
		"exi::EXIUnlock": 0x8034a834,
		"EXIUnlock": 0x8034a834,
		"exi::EXIGetState": 0x8034a910,
		"EXIGetState": 0x8034a910,
		"exi::UnlockedHandler": 0x8034a928,
		"UnlockedHandler": 0x8034a928,
		"exi::EXIGetID": 0x8034a950,
		"EXIGetID": 0x8034a950,
		"exi::InitializeUART": 0x8034accc,
		"InitializeUART": 0x8034accc,
		"exi::ReadUARTN": 0x8034ad3c,
		"ReadUARTN": 0x8034ad3c,
		"exi::WriteUARTN": 0x8034ad44,
		"WriteUARTN": 0x8034ad44,
		"thp::THPVideoDecode": 0x8034af44,
		"THPVideoDecode": 0x8034af44,
		"thp::__THPSetupBuffers": 0x8034b188,
		"__THPSetupBuffers": 0x8034b188,
		"thp::__THPReadFrameHeader": 0x8034b1cc,
		"__THPReadFrameHeader": 0x8034b1cc,
		"thp::__THPReadScaneHeader": 0x8034b308,
		"__THPReadScaneHeader": 0x8034b308,
		"thp::__THPReadQuantizationTable": 0x8034b424,
		"__THPReadQuantizationTable": 0x8034b424,
		"thp::__THPReadHuffmanTableSpecification": 0x8034b7e0,
		"__THPReadHuffmanTableSpecification": 0x8034b7e0,
		"thp::__THPHuffGenerateSizeTable": 0x8034b9c0,
		"__THPHuffGenerateSizeTable": 0x8034b9c0,
		"thp::__THPHuffGenerateCodeTable": 0x8034bab0,
		"__THPHuffGenerateCodeTable": 0x8034bab0,
		"thp::__THPHuffGenerateDecoderTables": 0x8034bb18,
		"__THPHuffGenerateDecoderTables": 0x8034bb18,
		"thp::__THPRestartDefinition": 0x8034bcd4,
		"__THPRestartDefinition": 0x8034bcd4,
		"thp::__THPPrepBitStream": 0x8034bd28,
		"__THPPrepBitStream": 0x8034bd28,
		"thp::__THPDecompressYUV": 0x8034bf74,
		"__THPDecompressYUV": 0x8034bf74,
		"thp::__THPDecompressiMCURow512x448": 0x8034c080,
		"__THPDecompressiMCURow512x448": 0x8034c080,
		"thp::__THPDecompressiMCURow640x480": 0x8034db08,
		"__THPDecompressiMCURow640x480": 0x8034db08,
		"thp::__THPDecompressiMCURowNxN": 0x8034f594,
		"__THPDecompressiMCURowNxN": 0x8034f594,
		"thp::__THPHuffDecodeDCTCompY": 0x80351040,
		"__THPHuffDecodeDCTCompY": 0x80351040,
		"thp::__THPHuffDecodeDCTCompU": 0x803516bc,
		"__THPHuffDecodeDCTCompU": 0x803516bc,
		"thp::__THPHuffDecodeDCTCompV": 0x80351d64,
		"__THPHuffDecodeDCTCompV": 0x80351d64,
		"thp::THPInit": 0x8035240c,
		"THPInit": 0x8035240c,
		"thp::THPAudioDecode": 0x80352484,
		"THPAudioDecode": 0x80352484,
		"thp::__THPAudioGetNewSample": 0x803528e8,
		"__THPAudioGetNewSample": 0x803528e8,
		"thp::__THPAudioInitialize": 0x80352978,
		"__THPAudioInitialize": 0x80352978,
		"THPPlayer::PopDecodedAudioBuffer": 0x8001db0c,
		"PopDecodedAudioBuffer": 0x8001db0c,
		"THPPlayer::PushFreeAudioBuffer": 0x8001db50,
		"PushFreeAudioBuffer": 0x8001db50,
		"THPPlayer::AudioDecode": 0x8001db80,
		"AudioDecode": 0x8001db80,
		"THPPlayer::AudioDecoderForOnMemory": 0x8001dc7c,
		"AudioDecoderForOnMemory": 0x8001dc7c,
		"THPPlayer::AudioDecoder": 0x8001dd2c,
		"AudioDecoder": 0x8001dd2c,
		"THPPlayer::AudioDecodeThreadCancel": 0x8001dd54,
		"AudioDecodeThreadCancel": 0x8001dd54,
		"THPPlayer::AudioDecodeThreadStart": 0x8001dd90,
		"AudioDecodeThreadStart": 0x8001dd90,
		"THPPlayer::CreateAudioDecodeThread": 0x8001ddc4,
		"CreateAudioDecodeThread": 0x8001ddc4,
		"THPPlayer::THPGXYuv2RgbDraw": 0x8001de84,
		"THPGXYuv2RgbDraw": 0x8001de84,
		"THPPlayer::THPGXYuv2RgbSetup": 0x8001e068,
		"THPGXYuv2RgbSetup": 0x8001e068,
		"THPPlayer::THPGXRestore": 0x8001e54c,
		"THPGXRestore": 0x8001e54c,
		"THPPlayer::THPPlayerSetVolume": 0x8001e664,
		"THPPlayerSetVolume": 0x8001e664,
		"THPPlayer::MixAudio": 0x8001e7a0,
		"MixAudio": 0x8001e7a0,
		"THPPlayer::THPPlayerDrawDone": 0x8001e97c,
		"THPPlayerDrawDone": 0x8001e97c,
		"THPPlayer::THPPlayerGetState": 0x8001e9f0,
		"THPPlayerGetState": 0x8001e9f0,
		"THPPlayer::THPPlayerGetAudioInfo": 0x8001ea00,
		"THPPlayerGetAudioInfo": 0x8001ea00,
		"THPPlayer::THPPlayerGetVideoInfo": 0x8001ea48,
		"THPPlayerGetVideoInfo": 0x8001ea48,
		"THPPlayer::THPPlayerDrawCurrentFrame": 0x8001ea90,
		"THPPlayerDrawCurrentFrame": 0x8001ea90,
		"THPPlayer::ProperTimingForGettingNextFrame": 0x8001eb5c,
		"ProperTimingForGettingNextFrame": 0x8001eb5c,
		"THPPlayer::PlayControl": 0x8001ec80,
		"PlayControl": 0x8001ec80,
		"THPPlayer::THPPlayerPause": 0x8001ef44,
		"THPPlayerPause": 0x8001ef44,
		"THPPlayer::THPPlayerStop": 0x8001ef84,
		"THPPlayerStop": 0x8001ef84,
		"THPPlayer::THPPlayerPlay": 0x8001f05c,
		"THPPlayerPlay": 0x8001f05c,
		"THPPlayer::THPPlayerPrepare": 0x8001f0b8,
		"THPPlayerPrepare": 0x8001f0b8,
		"THPPlayer::PrepareReady": 0x8001f328,
		"PrepareReady": 0x8001f328,
		"THPPlayer::InitAllMessageQueue": 0x8001f358,
		"InitAllMessageQueue": 0x8001f358,
		"THPPlayer::THPPlayerSetBuffer": 0x8001f428,
		"THPPlayerSetBuffer": 0x8001f428,
		"THPPlayer::THPPlayerCalcNeedMemory": 0x8001f658,
		"THPPlayerCalcNeedMemory": 0x8001f658,
		"THPPlayer::THPPlayerClose": 0x8001f700,
		"THPPlayerClose": 0x8001f700,
		"THPPlayer::THPPlayerOpen": 0x8001f758,
		"THPPlayerOpen": 0x8001f758,
		"THPPlayer::THPPlayerQuit": 0x8001f9e8,
		"THPPlayerQuit": 0x8001f9e8,
		"THPPlayer::THPPlayerInit": 0x8001fa1c,
		"THPPlayerInit": 0x8001fa1c,
		"THPPlayer::audioCallbackWithMSound": 0x8001fae4,
		"audioCallbackWithMSound": 0x8001fae4,
		"THPPlayer::PushReadedBuffer2": 0x8001fb98,
		"PushReadedBuffer2": 0x8001fb98,
		"THPPlayer::PopReadedBuffer2": 0x8001fbc8,
		"PopReadedBuffer2": 0x8001fbc8,
		"THPPlayer::PushFreeReadBuffer": 0x8001fbfc,
		"PushFreeReadBuffer": 0x8001fbfc,
		"THPPlayer::PopReadedBuffer": 0x8001fc2c,
		"PopReadedBuffer": 0x8001fc2c,
		"THPPlayer::Reader": 0x8001fc60,
		"Reader": 0x8001fc60,
		"THPPlayer::ReadThreadCancel": 0x8001fd50,
		"ReadThreadCancel": 0x8001fd50,
		"THPPlayer::ReadThreadStart": 0x8001fd8c,
		"ReadThreadStart": 0x8001fd8c,
		"THPPlayer::CreateReadThread": 0x8001fdc0,
		"CreateReadThread": 0x8001fdc0,
		"THPPlayer::PopDecodedTextureSet": 0x8001fe5c,
		"PopDecodedTextureSet": 0x8001fe5c,
		"THPPlayer::PushFreeTextureSet": 0x8001fea0,
		"PushFreeTextureSet": 0x8001fea0,
		"THPPlayer::VideoDecode": 0x8001fed0,
		"VideoDecode": 0x8001fed0,
		"THPPlayer::VideoDecoderForOnMemory": 0x80020000,
		"VideoDecoderForOnMemory": 0x80020000,
		"THPPlayer::VideoDecoder": 0x80020134,
		"VideoDecoder": 0x80020134,
		"THPPlayer::VideoDecodeThreadCancel": 0x80020210,
		"VideoDecodeThreadCancel": 0x80020210,
		"THPPlayer::VideoDecodeThreadStart": 0x8002024c,
		"VideoDecodeThreadStart": 0x8002024c,
		"THPPlayer::CreateVideoDecodeThread": 0x80020280,
		"CreateVideoDecodeThread": 0x80020280,
		"TDLColorTexQuad::draw": 0x80204e1c,
		"TDLColorTexQuad::setEnd": 0x80204ebc,
		"TDLColorTexQuad::requestCol": 0x80205054,
		"requestCol": 0x80205054,
		"TDLColorTexQuad::createBuffer": 0x80205238,
		"TDLTexQuad::draw": 0x80205318,
		"TDLTexQuad::setEnd": 0x80205420,
		"TDLTexQuad::request": 0x80205584,
		"TDLTexQuad::createBuffer": 0x80205720,
		"TDLTexQuad::createDLBuffer": 0x802057c0,
		"createDLBuffer": 0x802057c0,
		"TSilhouette::~TSilhouette": 0x80205878,
		"MarioUtil::SMS_UnifyMaterial": 0x802058ec,
		"SMS_UnifyMaterial": 0x802058ec,
		"MarioUtil::SMS_CalcMatAnmAndMakeDL": 0x802059a0,
		"SMS_CalcMatAnmAndMakeDL": 0x802059a0,
		"MarioUtil::SMS_ShowJoint": 0x80205a3c,
		"SMS_ShowJoint": 0x80205a3c,
		"MarioUtil::SMS_DrawInit": 0x80205a8c,
		"SMS_DrawInit": 0x80205a8c,
		"MarioUtil::SMS_MakeDLAndLock": 0x80205ab8,
		"SMS_MakeDLAndLock": 0x80205ab8,
		"MarioUtil::SMS_DrawShape": 0x80205b40,
		"SMS_DrawShape": 0x80205b40,
		"MarioUtil::SMS_SettingDrawShape": 0x80205ba4,
		"SMS_SettingDrawShape": 0x80205ba4,
		"MarioUtil::SMS_DrawCube": 0x80205c10,
		"SMS_DrawCube": 0x80205c10,
		"MarioUtil::SMS_CountPolygonNumInShape": 0x80205d90,
		"SMS_CountPolygonNumInShape": 0x80205d90,
		"MarioUtil::ViewFrustumClipCheck": 0x80205e6c,
		"ViewFrustumClipCheck": 0x80205e6c,
		"MarioUtil::SetViewFrustumClipCheckPerspective": 0x80205fdc,
		"SetViewFrustumClipCheckPerspective": 0x80205fdc,
		"MarioUtil::SetViewFrustumClipCheck": 0x80206084,
		"SetViewFrustumClipCheck": 0x80206084,
		"MarioUtil::SMS_ResetDamageFogEffect": 0x802063e8,
		"SMS_ResetDamageFogEffect": 0x802063e8,
		"MarioUtil::SMS_AddDamageFogEffect": 0x80206494,
		"SMS_AddDamageFogEffect": 0x80206494,
		"TTrembleModelEffect::reset": 0x802065b4,
		"TTrembleModelEffect::movement": 0x80206794,
		"JGeometry::TVec3<short><short>::sub": 0x80206c58,
		"TTrembleModelEffect::clash": 0x80206c8c,
		"clash": 0x80206c8c,
		"JGeometry::TVec3<short><short>::add": 0x80206ea4,
		"TTrembleModelEffect::tremble": 0x80206ed8,
		"tremble": 0x80206ed8,
		"TTrembleModelEffect::init": 0x8020729c,
		"TSilhouette::perform": 0x80207824,
		"TSilhouette::setting": 0x80207c1c,
		"setting": 0x80207c1c,
		"TSilhouette::loadAfter": 0x80207db8,
		"TSilhouette::load": 0x80207ff4,
		"TLightWithDBSetManager::~TLightWithDBSetManager": 0x80208054,
		"TLightWithDBSetManager::getLightPos": 0x802080c8,
		"getLightPos": 0x802080c8,
		"TLightWithDBSetManager::makeDrawBuffer": 0x802080d0,
		"TLightWithDBSetManager::addChildGroupObj": 0x80208144,
		"addChildGroupObj": 0x80208144,
		"JGadget::TList_pointer<PQ26JDrama8TViewObj>::iterator::iterator": 0x80208274,
		"JGadget::TList_pointer<JDrama::TViewObj*>::end": 0x80208280,
		"TLightWithDBSetManager::perform": 0x802082a4,
		"TLightWithDBSetManager::loadAfter": 0x802083a0,
		"TLightWithDBSetManager::TLightWithDBSetManager": 0x80208444,
		"TLightWithDBSet::~TLightWithDBSet": 0x80208848,
		"TIndirectLightWithDBSet::makeDrawBuffer": 0x802088bc,
		"TLightDrawBuffer::setLight": 0x80208a50,
		"TMapObjectLightWithDBSet::makeDrawBuffer": 0x80208a84,
		"TObjectLightWithDBSet::makeDrawBuffer": 0x80208c18,
		"TPlayerLightWithDBSet::makeDrawBuffer": 0x80208dbc,
		"TLightCommon::~TLightCommon": 0x80208f6c,
		"TLightWithDBSet::resetLightDrawBuffer": 0x80208fe0,
		"resetLightDrawBuffer": 0x80208fe0,
		"TLightWithDBSet::changeLightDrawBuffer": 0x8020901c,
		"changeLightDrawBuffer": 0x8020901c,
		"TLightWithDBSet::perform": 0x80209088,
		"TLightDrawBuffer::perform": 0x802091d0,
		"TLightDrawBuffer::TLightDrawBuffer": 0x80209214,
		"TLightMario::getAmbColor": 0x80209340,
		"TLightMario::getLightColor": 0x80209420,
		"TLightMario::setLight": 0x80209520,
		"TLightMario::perform": 0x80209790,
		"TLightShadow::perform": 0x802097d0,
		"TLightCommon::perform": 0x8020980c,
		"TLightCommon::setLight": 0x80209940,
		"TLightCommon::getLightPosition": 0x80209bb0,
		"getLightPosition": 0x80209bb0,
		"TLightCommon::getAmbColor": 0x80209bfc,
		"TLightCommon::getLightColor": 0x80209c88,
		"TLightCommon::loadAfter": 0x80209d40,
		"TLightCommon::TLightCommon": 0x80209ecc,
		"TIndirectLightWithDBSet::~TIndirectLightWithDBSet": 0x80209f98,
		"TMapObjectLightWithDBSet::~TMapObjectLightWithDBSet": 0x8020a01c,
		"TObjectLightWithDBSet::~TObjectLightWithDBSet": 0x8020a0a0,
		"TPlayerLightWithDBSet::~TPlayerLightWithDBSet": 0x8020a124,
		"TLightDrawBuffer::~TLightDrawBuffer": 0x8020a1a8,
		"TLightMario::~TLightMario": 0x8020a21c,
		"TLightShadow::~TLightShadow": 0x8020a2a0,
		"MarioUtil::MsVECMag2": 0x8020a324,
		"MsVECMag2": 0x8020a324,
		"MarioUtil::MsVECNormalize": 0x8020a34c,
		"MsVECNormalize": 0x8020a34c,
		"MarioUtil::SMSCalcJumpVelocityXZ": 0x8020a378,
		"SMSCalcJumpVelocityXZ": 0x8020a378,
		"MarioUtil::SMSCalcJumpVelocityY": 0x8020a474,
		"SMSCalcJumpVelocityY": 0x8020a474,
		"MarioUtil::SMS_GoRotate": 0x8020a51c,
		"SMS_GoRotate": 0x8020a51c,
		"MarioUtil::MsIsInSight": 0x8020a604,
		"MsIsInSight": 0x8020a604,
		"MarioUtil::MsWrap": 0x8020a7a4,
		"MarioUtil::MsMtxSetTRS": 0x8020a7f8,
		"MsMtxSetTRS": 0x8020a7f8,
		"MarioUtil::MsMtxSetXYZRPH": 0x8020a93c,
		"MsMtxSetXYZRPH": 0x8020a93c,
		"MarioUtil::MsMtxSetRotRPH": 0x8020a9ec,
		"MsMtxSetRotRPH": 0x8020a9ec,
		"MarioUtil::MsGetRotFromZaxis": 0x8020aae4,
		"MsGetRotFromZaxis": 0x8020aae4,
		"MarioUtil::matan": 0x8020ad18,
		"matan": 0x8020ad18,
		"MarioUtil::FConverge": 0x8020afbc,
		"FConverge": 0x8020afbc,
		"MarioUtil::IConverge": 0x8020afec,
		"IConverge": 0x8020afec,
		"MarioUtil::SMS_GetActorMtx": 0x8020b01c,
		"SMS_GetActorMtx": 0x8020b01c,
		"TRope::moveHead": 0x8020b06c,
		"TRope::constraintTail": 0x8020b1f8,
		"constraintTail": 0x8020b1f8,
		"TRope::constraintHead": 0x8020b424,
		"constraintHead": 0x8020b424,
		"TRope::collision": 0x8020b5c8,
		"collision": 0x8020b5c8,
		"TRope::TRope": 0x8020b730,
		"TRopePoint::TRopePoint": 0x8020b980,
		"MarioUtil::SMS_GetLightPerspectiveForEffectMtx": 0x8020b984,
		"SMS_GetLightPerspectiveForEffectMtx": 0x8020b984,
		"MarioUtil::SMS_MakeJointsToArc": 0x8020b9f0,
		"SMS_MakeJointsToArc": 0x8020b9f0,
		"TMultiMtxEffect::setUserArea": 0x8020be98,
		"setUserArea": 0x8020be98,
		"TMultiMtxEffect::setup": 0x8020bee8,
		"JGeometry::TVec3<float><float>::__ct": 0x8020c400,
		"__ct": 0x8020c400,
		"TParamT<JGeometry::TVec3<float><float>>::TParamT": 0x8020c410,
		"MarioUtil::TMtxSwingRZReverseXZCallBack": 0x8020c488,
		"TMtxSwingRZReverseXZCallBack": 0x8020c488,
		"MarioUtil::TMtxSwingRZCallBack": 0x8020c534,
		"TMtxSwingRZCallBack": 0x8020c534,
		"TMtxSwingRZ::calcLocalXY": 0x8020c5c8,
		"calcLocalXY": 0x8020c5c8,
		"MarioUtil::TMtxTimeLagCallBack": 0x8020c828,
		"TMtxTimeLagCallBack": 0x8020c828,
		"TMtxTimeLag::calc": 0x8020c860,
		"MarioUtil::MtxToQuat": 0x8020cdf4,
		"MtxToQuat": 0x8020cdf4,
		"TMtxSwingRZ::getParams": 0x8020d024,
		"TMtxTimeLag::getParams": 0x8020d02c,
		"TMtxEffectBase::getParams": 0x8020d034,
		"TScreenTexture::~TScreenTexture": 0x8020d03c,
		"TScreenTexture::perform": 0x8020d0b0,
		"MarioUtil::SMS_FillScreenAlpha": 0x8020d0b4,
		"SMS_FillScreenAlpha": 0x8020d0b4,
		"TScreenTexture::replace": 0x8020d270,
		"replace": 0x8020d270,
		"TScreenTexture::load": 0x8020d384,
		"TAfterEffect::perform": 0x8020d408,
		"TAfterEffect::calcDashBlurValue": 0x8020dba8,
		"calcDashBlurValue": 0x8020dba8,
		"TAfterEffect::loadAfter": 0x8020dc84,
		"TAfterEffect::load": 0x8020dcfc,
		"TAfterEffect::~TAfterEffect": 0x8020dde8,
		"TMBindShadowManager::~TMBindShadowManager": 0x8020de5c,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::erase": 0x8020df68,
		"JGadget::TList<P16TMBindShadowBody,Q27JGadget31TAllocator<P16TMBindShadowBody>>::iterator::iterator": 0x8020dfd4,
		"TMBindShadowManager::calcVtx": 0x8020dfdc,
		"calcVtx": 0x8020dfdc,
		"TMBindShadowManager::forceRequest": 0x8020eacc,
		"forceRequest": 0x8020eacc,
		"TMBindShadowManager::request": 0x8020ebfc,
		"TMBindShadowManager::drawShadow": 0x8020ef24,
		"drawShadow": 0x8020ef24,
		"TMBindShadowManager::drawShadowGD": 0x8020f950,
		"drawShadowGD": 0x8020f950,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::~TSetup5$2216ShadowUtil_cpp": 0x80210294,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::~TSetup4$2207ShadowUtil_cpp": 0x802102f8,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::~TSetup3$2195ShadowUtil_cpp": 0x8021035c,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::~TSetup2$2190ShadowUtil_cpp": 0x802103c0,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::~TCylinder$2171ShadowUtil_cpp": 0x80210424,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::~TSetup1$2172ShadowUtil_cpp": 0x80210488,
		"TMBindShadowManager::drawShadowVolume": 0x802104ec,
		"drawShadowVolume": 0x802104ec,
		"MarioUtil::conectCubeSame": 0x80210d78,
		"conectCubeSame": 0x80210d78,
		"MarioUtil::conectCubeDiffer": 0x80210ebc,
		"conectCubeDiffer": 0x80210ebc,
		"TMBindShadowManager::perform": 0x80211018,
		"JGadget::TList<TMBindShadowBody*,JGadget::TAllocator<TMBindShadowBody*>>::insert": 0x802110e0,
		"TMBindShadowManager::load": 0x80211198,
		"TMBindShadowManager::TMBindShadowManager": 0x802112f4,
		"TAlphaShadowBlendQuad::TAlphaShadowBlendQuad": 0x8021152c,
		"TAlphaShadowQuadAry::TAlphaShadowQuadAry": 0x8021155c,
		"TAlphaShadowQuad::TAlphaShadowQuad": 0x80211574,
		"TCircleShadowRequest::TCircleShadowRequest": 0x80211590,
		"TModelShadowInfo::TModelShadowInfo": 0x802115d8,
		"TSquareShadowInfo::TSquareShadowInfo": 0x80211604,
		"TMBindShadowBody::entryDrawShadow": 0x80211630,
		"entryDrawShadow": 0x80211630,
		"TMBindShadowBody::TMBindShadowBody": 0x80211908,
		"TMBindShadowParts::calc": 0x80211ce0,
		"TMBindShadowParts::TMBindShadowParts": 0x80211f58,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::makeDL": 0x80212244,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::makeDL": 0x802122a4,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::makeDL": 0x80212304,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::makeDL": 0x80212358,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::makeDL": 0x802123b8,
		"MarioUtil::GDOverflowCheck": 0x80212efc,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::makeDL": 0x80212f34,
		"MarioUtil::ReInitTevStages": 0x80213084,
		"ReInitTevStages": 0x80213084,
		"MarioUtil::ReInitTransform": 0x802132f0,
		"ReInitTransform": 0x802132f0,
		"MarioUtil::ReInitGeometry": 0x8021355c,
		"ReInitGeometry": 0x8021355c,
		"MarioUtil::ReInitializeGX": 0x80213670,
		"ReInitializeGX": 0x80213670,
		"MarioUtil::SMS_EmitSinkInPollutionEffect": 0x802138c4,
		"SMS_EmitSinkInPollutionEffect": 0x802138c4,
		"MarioUtil::SMS_EmitRippleSea": 0x80213aac,
		"SMS_EmitRippleSea": 0x80213aac,
		"MarioUtil::SMS_EmitRipplePool": 0x80213b5c,
		"SMS_EmitRipplePool": 0x80213b5c,
		"MarioUtil::SMS_EmitRippleTiny": 0x80213c0c,
		"SMS_EmitRippleTiny": 0x80213c0c,
		"MarioUtil::SMS_CreateMinimumSDLModel": 0x80213c8c,
		"SMS_CreateMinimumSDLModel": 0x80213c8c,
		"MarioUtil::SMS_CreatePartsModel": 0x80213d10,
		"SMS_CreatePartsModel": 0x80213d10,
		"MarioUtil::SMS_RideMoveCalcLocalPos": 0x80213d80,
		"SMS_RideMoveCalcLocalPos": 0x80213d80,
		"MarioUtil::SMS_RideMoveByGroundActor": 0x80213e20,
		"SMS_RideMoveByGroundActor": 0x80213e20,
		"TMultiBtk::update": 0x80213fb4,
		"TMultiBtk::setNthData": 0x80214040,
		"setNthData": 0x80214040,
		"TMultiBtk::TMultiBtk": 0x8021413c,
		"RumbleMgr::finishPause": 0x802141c0,
		"finishPause": 0x802141c0,
		"RumbleMgr::startPause": 0x802141d4,
		"startPause": 0x802141d4,
		"RumbleMgr::setActive": 0x80214248,
		"setActive": 0x80214248,
		"RumbleMgr::update": 0x802142fc,
		"RumbleMgr::reset": 0x802148d0,
		"RumbleMgr::init": 0x80214ac4,
		"RumbleMgr::RumbleMgr": 0x80214cd8,
		"RumbleControllerMgr::update": 0x80214e10,
		"RumbleControllerMgr::updateMotorCount": 0x80214ef4,
		"updateMotorCount": 0x80214ef4,
		"RumbleControllerMgr::stop": 0x80214f74,
		"RumbleControllerMgr::reset": 0x80215160,
		"RumbleChannelMgr::update": 0x802152e8,
		"RumbleChannelMgr::RumbleChannelMgr": 0x80215598,
		"RumbleType::getIndex": 0x802155c4,
		"MarioUtil::SMS_ShowAllShapePacket": 0x80215638,
		"SMS_ShowAllShapePacket": 0x80215638,
		"MarioUtil::SMS_HideAllShapePacket": 0x80215738,
		"SMS_HideAllShapePacket": 0x80215738,
		"MarioUtil::SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x80215838,
		"SMS_InitPacket_TwoTevColorAndOneTevKColor": 0x80215838,
		"MarioUtil::SMS_InitPacket_OneTevColorAndOneTevKColor": 0x802158c8,
		"SMS_InitPacket_OneTevColorAndOneTevKColor": 0x802158c8,
		"MarioUtil::SMS_InitPacket_OneTevKColorAndFog": 0x80215960,
		"SMS_InitPacket_OneTevKColorAndFog": 0x80215960,
		"MarioUtil::SMS_InitPacket_TwoTevKColor": 0x80215a48,
		"SMS_InitPacket_TwoTevKColor": 0x80215a48,
		"MarioUtil::SMS_InitPacket_OneTevKColor": 0x80215ad0,
		"SMS_InitPacket_OneTevKColor": 0x80215ad0,
		"MarioUtil::SMS_InitPacket_Fog": 0x80215b58,
		"SMS_InitPacket_Fog": 0x80215b58,
		"MarioUtil::SMS_InitPacket_ThreeTevColor": 0x80215be4,
		"SMS_InitPacket_ThreeTevColor": 0x80215be4,
		"MarioUtil::SMS_InitPacket_TwoTevColor": 0x80215c7c,
		"SMS_InitPacket_TwoTevColor": 0x80215c7c,
		"MarioUtil::SMS_InitPacket_OneTevColor": 0x80215d04,
		"SMS_InitPacket_OneTevColor": 0x80215d04,
		"MarioUtil::SMS_InitPacket_MatColor": 0x80215d8c,
		"SMS_InitPacket_MatColor": 0x80215d8c,
		"MarioUtil::ShapePacketCallBackFunc": 0x80215e14,
		"ShapePacketCallBackFunc": 0x80215e14,
		"MarioUtil::FifoSetFog": 0x802165a4,
		"FifoSetFog": 0x802165a4,
		"MarioUtil::FifoSetFogRangeAdj": 0x802166fc,
		"FifoSetFogRangeAdj": 0x802166fc,
		"TGDLStatic::make": 0x80216834,
		"make": 0x80216834,
		"TGDLStatic::alloc": 0x802169c4,
		"TGDLStatic::~TGDLStatic": 0x80216a70,
		"TGDLStatic::TGDLSentinel::~TGDLSentinel": 0x80216ac4,
		"MarioUtil::TGDLStaticOverFlow": 0x80216b3c,
		"TGDLStaticOverFlow": 0x80216b3c,
		"MarioUtil::SMS_ChangeTextureAll": 0x80216b4c,
		"SMS_ChangeTextureAll": 0x80216b4c,
		"MarioUtil::SMS_GetSandRiseUpRatio": 0x80216c68,
		"SMS_GetSandRiseUpRatio": 0x80216c68,
		"MarioUtil::SMS_GetGroundActor": 0x80216cb4,
		"SMS_GetGroundActor": 0x80216cb4,
		"MarioUtil::SMS_GetMonteVillageAreaInMario": 0x80216ce8,
		"SMS_GetMonteVillageAreaInMario": 0x80216ce8,
		"Koga::ToolData::Attach": 0x80216ee4,
		"Attach": 0x80216ee4,
		"Koga::ToolData::~ToolData": 0x80216f00,
		"Koga::ToolData::ToolData": 0x80216f4c,
		"M3DUtil::M3UMtxCalcBlendAux": 0x802173e4,
		"M3UMtxCalcBlendAux": 0x802173e4,
		"M3UModel::setMtxCalc": 0x80217800,
		"setMtxCalc": 0x80217800,
		"M3UModel::perform": 0x80217804,
		"M3UModel::entryOut": 0x802178dc,
		"M3UModel::entryIn": 0x8021792c,
		"M3UModel::updateOut": 0x802179a8,
		"M3UModel::updateIn": 0x802179f0,
		"M3UModel::updateInTexPatternAnm": 0x80217a3c,
		"updateInTexPatternAnm": 0x80217a3c,
		"M3UModel::updateInMotion": 0x80217a78,
		"M3UModel::changeAnmTexPattern": 0x80217b9c,
		"changeAnmTexPattern": 0x80217b9c,
		"M3UModel::changeMtxCalcAnmTransform": 0x80217be0,
		"changeMtxCalcAnmTransform": 0x80217be0,
		"M3UModelCommon::getMtxCalc": 0x80217c24,
		"MActor::updateMatAnm": 0x80217c80,
		"updateMatAnm": 0x80217c80,
		"MActor::entryOut": 0x80217d14,
		"MActorAnmBase::updateOut": 0x80217d90,
		"MActor::entryIn": 0x80217d94,
		"MActorAnmBase::updateIn": 0x80217e10,
		"MActor::setBrkFromIndex": 0x80217e14,
		"setBrkFromIndex": 0x80217e14,
		"MActorAnmMatEach<J3DAnmTevRegKey>::setAnmFromIndex": 0x80217e64,
		"MActor::setBrk": 0x80217f2c,
		"setBrk": 0x80217f2c,
		"MActorAnmEach<J3DAnmTevRegKey>::setAnm": 0x80217f7c,
		"MActor::setBlk": 0x802180a8,
		"setBlk": 0x802180a8,
		"MActorAnmEach<J3DAnmClusterKey>::setAnm": 0x802180f8,
		"MActor::setBtkFromIndex": 0x80218224,
		"setBtkFromIndex": 0x80218224,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::setAnmFromIndex": 0x80218274,
		"MActor::setBtk": 0x8021833c,
		"setBtk": 0x8021833c,
		"MActorAnmEach<J3DAnmTextureSRTKey>::setAnm": 0x8021838c,
		"MActor::setBtpFromIndex": 0x802184b8,
		"setBtpFromIndex": 0x802184b8,
		"MActorAnmMatEach<J3DAnmTexPattern>::setAnmFromIndex": 0x80218518,
		"MActor::setBtp": 0x802185e0,
		"setBtp": 0x802185e0,
		"MActorAnmEach<J3DAnmTexPattern>::setAnm": 0x80218630,
		"MActor::setBpkFromIndex": 0x8021875c,
		"setBpkFromIndex": 0x8021875c,
		"MActorAnmMatEach<J3DAnmColorKey>::setAnmFromIndex": 0x802187ac,
		"MActor::setBpk": 0x80218874,
		"setBpk": 0x80218874,
		"MActorAnmEach<J3DAnmColorKey>::setAnm": 0x802188c4,
		"MActorAnmEach<J3DAnmTransformKey>::setAnm": 0x802189f0,
		"MActor::checkCurBckFromIndex": 0x80218b1c,
		"checkCurBckFromIndex": 0x80218b1c,
		"MActor::setBckFromIndex": 0x80218b4c,
		"setBckFromIndex": 0x80218b4c,
		"MActor::setBck": 0x80218b88,
		"setBck": 0x80218b88,
		"MActor::setFrameRate": 0x80218bc4,
		"setFrameRate": 0x80218bc4,
		"MActor::getCurAnmIdx": 0x80218be0,
		"getCurAnmIdx": 0x80218be0,
		"MActor::checkBckPass": 0x80218c04,
		"checkBckPass": 0x80218c04,
		"MActor::getFrameCtrl": 0x80218c50,
		"MActor::checkAnmFileExist": 0x80218c74,
		"checkAnmFileExist": 0x80218c74,
		"MActor::checkCurAnmFromIndex": 0x80218d94,
		"checkCurAnmFromIndex": 0x80218d94,
		"MActor::checkCurAnm": 0x80218dcc,
		"checkCurAnm": 0x80218dcc,
		"MActor::perform": 0x80218f04,
		"MActor::matAnmFrameUpdate": 0x802190dc,
		"matAnmFrameUpdate": 0x802190dc,
		"MActor::frameUpdate": 0x80219150,
		"frameUpdate": 0x80219150,
		"MActor::entry": 0x80219210,
		"MActor::setLightType": 0x8021935c,
		"setLightType": 0x8021935c,
		"MActor::setLightData": 0x8021937c,
		"setLightData": 0x8021937c,
		"MActor::setLightID": 0x80219468,
		"setLightID": 0x80219468,
		"MActor::viewCalc": 0x8021947c,
		"MActor::calc": 0x802194b8,
		"MActor::calcAnm": 0x802195c0,
		"calcAnm": 0x802195c0,
		"MActor::updateOutSubBck": 0x80219754,
		"updateOutSubBck": 0x80219754,
		"MActor::updateInSubBck": 0x802197e0,
		"updateInSubBck": 0x802197e0,
		"MActor::setJointCallback": 0x8021986c,
		"setJointCallback": 0x8021986c,
		"MActor::offMakeDL": 0x80219888,
		"offMakeDL": 0x80219888,
		"MActor::unlockDLIfNeed": 0x802198d0,
		"unlockDLIfNeed": 0x802198d0,
		"MActor::resetDL": 0x80219940,
		"resetDL": 0x80219940,
		"MActor::initDL": 0x80219a84,
		"initDL": 0x80219a84,
		"MActor::setAnimation": 0x80219bac,
		"MActor::curAnmEndsNext": 0x80219c24,
		"curAnmEndsNext": 0x80219c24,
		"MActor::isCurAnmAlreadyEnd": 0x80219d90,
		"isCurAnmAlreadyEnd": 0x80219d90,
		"MActor::setModel": 0x80219e58,
		"MActorAnmBase::setModel": 0x8021a148,
		"MActor::MActor": 0x8021a150,
		"MActorAnmBase::MActorAnmBase": 0x8021a648,
		"MActorAnmBlk::verifySuffix": 0x8021a6ac,
		"MActorAnmBlk::setAnmFromIndex": 0x8021a6d4,
		"MActorAnmBlk::updateOut": 0x8021a754,
		"MActorAnmBlk::updateIn": 0x8021a77c,
		"MActorAnmBrk::checkUseMaterialID": 0x8021a7f8,
		"MActorAnmBrk::checkUseMaterialIDInit": 0x8021a838,
		"MActorAnmBrk::updateOut": 0x8021a878,
		"MActorAnmBrk::updateIn": 0x8021a8a4,
		"MActorAnmBrk::setTevKColorAnmKeyPtr": 0x8021a8f8,
		"setTevKColorAnmKeyPtr": 0x8021a8f8,
		"J3DTevKColorAnm::~J3DTevKColorAnm": 0x8021aa08,
		"J3DTevKColorAnm::J3DTevKColorAnm": 0x8021aa48,
		"MActorAnmBrk::setTevColorAnmKeyPtr": 0x8021aa58,
		"setTevColorAnmKeyPtr": 0x8021aa58,
		"J3DTevColorAnm::~J3DTevColorAnm": 0x8021ab68,
		"J3DTevColorAnm::J3DTevColorAnm": 0x8021aba8,
		"MActorAnmBpk::updateOut": 0x8021abb8,
		"MActorAnmBpk::updateIn": 0x8021abe4,
		"MActorAnmBpk::setMatColorAnmKeyPtr": 0x8021ac30,
		"setMatColorAnmKeyPtr": 0x8021ac30,
		"J3DMatColorAnm::~J3DMatColorAnm": 0x8021ad40,
		"J3DMatColorAnm::J3DMatColorAnm": 0x8021ad80,
		"MActorAnmBpk::checkUseMaterialID": 0x8021ad90,
		"MActorAnmBpk::checkUseMaterialIDInit": 0x8021ade8,
		"MActorAnmBtk::updateOut": 0x8021aed0,
		"MActorAnmBtk::updateIn": 0x8021aefc,
		"MActorAnmBtk::setTexMtxAnmKeyPtr": 0x8021af4c,
		"setTexMtxAnmKeyPtr": 0x8021af4c,
		"J3DTexMtxAnm::~J3DTexMtxAnm": 0x8021b074,
		"J3DTexMtxAnm::J3DTexMtxAnm": 0x8021b0b4,
		"MActorAnmBtk::checkUseMaterialID": 0x8021b0c4,
		"MActorAnmBtk::checkUseMaterialIDInit": 0x8021b134,
		"MActorAnmBtp::updateOut": 0x8021b234,
		"MActorAnmBtp::updateIn": 0x8021b260,
		"MActorAnmBtp::checkUseMaterialID": 0x8021b2ac,
		"MActorAnmBtp::checkUseMaterialIDInit": 0x8021b304,
		"MActorAnmBtp::setTexNoAnmFullPtr": 0x8021b3f8,
		"setTexNoAnmFullPtr": 0x8021b3f8,
		"MActorAnmBck::setAnmFromIndex": 0x8021b50c,
		"MActorAnmBck::updateOut": 0x8021b61c,
		"MActorAnmBck::updateIn": 0x8021b640,
		"MActorAnmBck::setModel": 0x8021b720,
		"J3DMtxCalcBasicAnm::J3DMtxCalcBasicAnm": 0x8021b7f0,
		"MActorAnmBck::getOldMotionBlendFrame": 0x8021b8c4,
		"MActorAnmBck::setOldMotionBlendAnmPtr": 0x8021b8f8,
		"MActorAnmBck::getOldMotionBlendAnmPtr": 0x8021b924,
		"MActorAnmBck::setMotionBlendRatio": 0x8021b958,
		"MActorAnmBck::getMotionBlendRatio": 0x8021b984,
		"MActorAnmBck::initNormalMotionBlend": 0x8021b9b8,
		"initNormalMotionBlend": 0x8021b9b8,
		"MActorAnmBck::initSimpleMotionBlend": 0x8021ba38,
		"initSimpleMotionBlend": 0x8021ba38,
		"MActorAnmBase::checkUseMaterialID": 0x8021bac8,
		"MActorAnmBase::checkUseMaterialIDInit": 0x8021bacc,
		"MActorAnmBrk::verifySuffix": 0x8021bad0,
		"MActorAnmBpk::verifySuffix": 0x8021baf8,
		"MActorAnmBtk::verifySuffix": 0x8021bb20,
		"MActorAnmBtp::verifySuffix": 0x8021bb48,
		"MActorAnmBck::verifySuffix": 0x8021bb70,
		"MActorAnmData::createSampleModelData": 0x8021bb98,
		"createSampleModelData": 0x8021bb98,
		"MActorAnmData::addFileTable": 0x8021bbf4,
		"addFileTable": 0x8021bbf4,
		"MActorAnmData::init": 0x8021c070,
		"MActorAnmData::partsNameToIdx": 0x8021c694,
		"partsNameToIdx": 0x8021c694,
		"M3DUtil::MActorCalcKeyCode": 0x8021c734,
		"MActorCalcKeyCode": 0x8021c734,
		"MActorAnmData::MActorAnmData": 0x8021c764,
		"MActorAnmDataBase::sortByFileNameRaw": 0x8021c7c8,
		"sortByFileNameRaw": 0x8021c7c8,
		"MActorAnmDataBase::checkLower": 0x8021c9e8,
		"checkLower": 0x8021c9e8,
		"MActorAnmDataEach<J3DAnmClusterKey>::loadAnmPtrArray": 0x8021cab0,
		"MActorAnmDataEach<J3DAnmTevRegKey>::loadAnmPtrArray": 0x8021cba0,
		"MActorAnmDataEach<J3DAnmTextureSRTKey>::loadAnmPtrArray": 0x8021cc90,
		"MActorAnmDataEach<J3DAnmTexPattern>::loadAnmPtrArray": 0x8021cd80,
		"MActorAnmDataEach<J3DAnmColorKey>::loadAnmPtrArray": 0x8021ce70,
		"MActorAnmDataEach<J3DAnmTransformKey>::loadAnmPtrArray": 0x8021cf60,
		"SDLModel::~SDLModel": 0x8021d050,
		"SDLModel::viewCalcSimple": 0x8021d0b4,
		"viewCalcSimple": 0x8021d0b4,
		"SDLModel::entry": 0x8021d18c,
		"JGadget::TList<SDLDrawBufToken*,JGadget::TAllocator<SDLDrawBufToken*>>::insert": 0x8021d30c,
		"SDLModel::entryModelDataSDL": 0x8021d3c4,
		"entryModelDataSDL": 0x8021d3c4,
		"SDLMatPacket::~SDLMatPacket": 0x8021da4c,
		"SDLModel::SDLModel": 0x8021dab0,
		"SDLMatPacket::SDLMatPacket": 0x8021db44,
		"SDLModelData::entrySDLModels": 0x8021db80,
		"entrySDLModels": 0x8021db80,
		"SDLModelData::SDLModelData": 0x8021dd7c,
		"SDLModelData::recursiveEntry": 0x8021dde0,
		"SDLModelData::entryNode": 0x8021e0ec,
		"entryNode": 0x8021e0ec,
		"SDLModelData::entrySameMat": 0x8021e178,
		"entrySameMat": 0x8021e178,
		"M3DUtil::SMS_MakeMActor": 0x8021e30c,
		"SMS_MakeMActor": 0x8021e30c,
		"M3DUtil::SMS_MakeMActorWithAnmData": 0x8021e384,
		"SMS_MakeMActorWithAnmData": 0x8021e384,
		"M3DUtil::SMS_MakeMActorsWithAnmData": 0x8021e420,
		"SMS_MakeMActorsWithAnmData": 0x8021e420,
		"M3DUtil::SMS_MakeSDLModelData": 0x8021e504,
		"SMS_MakeSDLModelData": 0x8021e504,
		"M3DUtil::SMS_MakeMActorFromSDLModelData": 0x8021e564,
		"SMS_MakeMActorFromSDLModelData": 0x8021e564,
		"SampleCtrlShape::SampleCtrlShape": 0x8021e604,
		"SampleCtrlMaterial::SampleCtrlMaterial": 0x8021e650,
		"SampleCtrlJoint::SampleCtrlJoint": 0x8021eb2c,
		"SampleCtrlJoint::~SampleCtrlJoint": 0x8021eb90,
		"SampleCtrlMaterial::~SampleCtrlMaterial": 0x8021ebdc,
		"SampleCtrlShape::~SampleCtrlShape": 0x8021ec28,
		"SampleCtrlModelData::SampleCtrlModelData": 0x8021ec74,
		"SampleCtrlModelData::makeHierarchy": 0x8021ee54,
		"SampleCtrlModelData::~SampleCtrlModelData": 0x8021ef50,
		"TMotionBlendCtrl::getOldMotionBlendFrame": 0x8021ef9c,
		"TMotionBlendCtrl::setOldMotionBlendAnmPtr": 0x8021efa8,
		"TMotionBlendCtrl::getOldMotionBlendAnmPtr": 0x8021efb4,
		"TMotionBlendCtrl::setNewAnm": 0x8021efc0,
		"setNewAnm": 0x8021efc0,
		"TMotionBlendCtrl::keepCurAnm": 0x8021efe4,
		"keepCurAnm": 0x8021efe4,
		"TMotionBlendCtrl::setMotionBlendRatio": 0x8021eff8,
		"TMotionBlendCtrl::getMotionBlendRatio": 0x8021f004,
		"TMotionBlendCtrl::execSimpleMotionBlend": 0x8021f010,
		"execSimpleMotionBlend": 0x8021f010,
		"TLodAnm::setBckAndBtpAnm": 0x8021f188,
		"setBckAndBtpAnm": 0x8021f188,
		"TLodAnm::setBtpAnm_": 0x8021f1ec,
		"setBtpAnm_": 0x8021f1ec,
		"TLodAnm::setBckAnm_": 0x8021f2c4,
		"setBckAnm_": 0x8021f2c4,
		"TLodAnm::TLodAnm": 0x8021f3a8,
		"TBaseParam::TBaseParam": 0x80267394,
		"TBaseParam::load": 0x802673e4,
		"TMarioParticleManager::~TMarioParticleManager": 0x802673e8,
		"System::SMSSetEmitterPolColor": 0x8026745c,
		"SMSSetEmitterPolColor": 0x8026745c,
		"TMarioParticleManager::getAvailableIdx": 0x80267578,
		"getAvailableIdx": 0x80267578,
		"TMarioParticleManager::emitTry": 0x8026769c,
		"emitTry": 0x8026769c,
		"TMarioParticleManager::emitParticleCallBack": 0x80267854,
		"emitParticleCallBack": 0x80267854,
		"TMarioParticleManager::emitAndBindToMtx": 0x802679e4,
		"emitAndBindToMtx": 0x802679e4,
		"TMarioParticleManager::emitAndBindToSRTMtxPtr": 0x80267ae8,
		"emitAndBindToSRTMtxPtr": 0x80267ae8,
		"TMarioParticleManager::emitAndBindToMtxPtr": 0x80267d2c,
		"emitAndBindToMtxPtr": 0x80267d2c,
		"TMarioParticleManager::emitAndBindToPosPtr": 0x80267f70,
		"emitAndBindToPosPtr": 0x80267f70,
		"TMarioParticleManager::emitWithRotate": 0x8026819c,
		"emitWithRotate": 0x8026819c,
		"TMarioParticleManager::emit": 0x802682bc,
		"TMarioParticleManager::perform": 0x802684d0,
		"TMarioParticleManager::createEffectInfoAry": 0x80268878,
		"createEffectInfoAry": 0x80268878,
		"TMarioParticleManager::TMarioParticleManager": 0x8026893c,
		"TMarioParticleManager::TInfo::TInfo": 0x802689a8,
		"TMarioEmitterCallBackBindToSRTMtxPtr::draw": 0x802689c8,
		"TMarioEmitterCallBackBindToSRTMtxPtr::execute": 0x802689cc,
		"TMarioEmitterCallBackBindToMtxPtr::draw": 0x802689f8,
		"TMarioEmitterCallBackBindToMtxPtr::execute": 0x802689fc,
		"TMarioEmitterCallBackBindToPosPtr::draw": 0x80268a28,
		"TMarioEmitterCallBackBindToPosPtr::execute": 0x80268a2c,
		"TEmitterIndirectViewObj::perform": 0x80268a4c,
		"TEmitterViewObj::perform": 0x80268b08,
		"TEmitterViewObj::TEmitterViewObj": 0x80268bac,
		"TEmitterIndirectViewObj::~TEmitterIndirectViewObj": 0x80268c24,
		"TEmitterViewObj::~TEmitterViewObj": 0x80268ca8,
		"System::__sinit_EmitterViewObj_cpp": 0x80268d20,
		"__sinit_EmitterViewObj_cpp": 0x80268d20,
		"TEventWatcher::perform": 0x80268d4c,
		"TEventWatcher::launchScript": 0x80268d8c,
		"launchScript": 0x80268d8c,
		"TSpcTypedBinary<TEventWatcher>::initUserBuiltin": 0x80268f50,
		"System::evIsWaterMelonIsReached": 0x80269800,
		"evIsWaterMelonIsReached": 0x80269800,
		"System::evInvalidatePad": 0x80269970,
		"evInvalidatePad": 0x80269970,
		"System::evOnNeutralMarioKey": 0x80269ab4,
		"evOnNeutralMarioKey": 0x80269ab4,
		"System::evWarpFrontToMario": 0x80269b54,
		"evWarpFrontToMario": 0x80269b54,
		"System::evAppear8RedCoinsAndTimer": 0x80269d88,
		"evAppear8RedCoinsAndTimer": 0x80269d88,
		"System::evAppearReadyGo": 0x80269f70,
		"evAppearReadyGo": 0x80269f70,
		"System::evSetEventForWaterMelon": 0x8026a010,
		"evSetEventForWaterMelon": 0x8026a010,
		"System::evStartAppearJetBalloon": 0x8026a1d4,
		"evStartAppearJetBalloon": 0x8026a1d4,
		"System::evWarpMario": 0x8026a430,
		"evWarpMario": 0x8026a430,
		"System::evSetCollision": 0x8026a7b0,
		"evSetCollision": 0x8026a7b0,
		"System::evChangeSunglass": 0x8026aa24,
		"evChangeSunglass": 0x8026aa24,
		"System::evStartMiss": 0x8026ac18,
		"evStartMiss": 0x8026ac18,
		"System::evStartEventSE": 0x8026acb0,
		"evStartEventSE": 0x8026acb0,
		"System::evStartSE": 0x8026ae38,
		"evStartSE": 0x8026ae38,
		"System::evStopBGM": 0x8026af9c,
		"evStopBGM": 0x8026af9c,
		"System::evPutNozzle": 0x8026b0d8,
		"evPutNozzle": 0x8026b0d8,
		"System::evEggYoshiStartFruit": 0x8026b2a8,
		"evEggYoshiStartFruit": 0x8026b2a8,
		"System::evStartBGM": 0x8026b478,
		"evStartBGM": 0x8026b478,
		"System::evManiCoinDown": 0x8026b5b0,
		"evManiCoinDown": 0x8026b5b0,
		"System::evSetEventID": 0x8026b64c,
		"evSetEventID": 0x8026b64c,
		"System::evSetTransScale": 0x8026b8a4,
		"evSetTransScale": 0x8026b8a4,
		"System::evIsInsideFastCube": 0x8026bf18,
		"evIsInsideFastCube": 0x8026bf18,
		"System::evIsFinishMareBottleDemo": 0x8026c1d8,
		"evIsFinishMareBottleDemo": 0x8026c1d8,
		"System::evStartMareBottleDemo": 0x8026c2cc,
		"evStartMareBottleDemo": 0x8026c2cc,
		"System::evSetMarioWaiting": 0x8026c3dc,
		"evSetMarioWaiting": 0x8026c3dc,
		"System::evIsInsideCube": 0x8026c484,
		"evIsInsideCube": 0x8026c484,
		"System::evKillWoodBox": 0x8026c608,
		"evKillWoodBox": 0x8026c608,
		"System::evRefreshWoodBox": 0x8026c8ac,
		"evRefreshWoodBox": 0x8026c8ac,
		"System::evCheckWoodBox": 0x8026cb50,
		"evCheckWoodBox": 0x8026cb50,
		"System::evStartMarioTalking": 0x8026cdfc,
		"evStartMarioTalking": 0x8026cdfc,
		"System::evChangeNozzle": 0x8026ce94,
		"evChangeNozzle": 0x8026ce94,
		"System::evAppearShineForWoodBox": 0x8026cff0,
		"evAppearShineForWoodBox": 0x8026cff0,
		"System::evAppearShineFromKageMario": 0x8026d15c,
		"evAppearShineFromKageMario": 0x8026d15c,
		"System::evAppearShineFromNPCWithoutDemo": 0x8026d418,
		"evAppearShineFromNPCWithoutDemo": 0x8026d418,
		"System::evAppearShine": 0x8026d6a8,
		"evAppearShine": 0x8026d6a8,
		"System::evAppearShineFromNPC": 0x8026d8d0,
		"evAppearShineFromNPC": 0x8026d8d0,
		"System::evAppearMushroom1up": 0x8026dc34,
		"evAppearMushroom1up": 0x8026dc34,
		"System::evKillMushroom1up": 0x8026de2c,
		"evKillMushroom1up": 0x8026de2c,
		"System::evKillShine": 0x8026dffc,
		"evKillShine": 0x8026dffc,
		"System::evGetTime": 0x8026e1cc,
		"evGetTime": 0x8026e1cc,
		"System::evMonteManReachFlag": 0x8026e268,
		"evMonteManReachFlag": 0x8026e268,
		"System::evStopTimer": 0x8026e354,
		"evStopTimer": 0x8026e354,
		"System::evStartMonteman": 0x8026e3f0,
		"evStartMonteman": 0x8026e3f0,
		"System::evStartTimer": 0x8026e57c,
		"evStartTimer": 0x8026e57c,
		"System::evInsertTimer": 0x8026e6e8,
		"evInsertTimer": 0x8026e6e8,
		"System::evForceCloseTalk": 0x8026e91c,
		"evForceCloseTalk": 0x8026e91c,
		"System::evRaiseBuilding": 0x8026e9b4,
		"evRaiseBuilding": 0x8026e9b4,
		"System::evIsMapEventFinishedAll": 0x8026eb44,
		"evIsMapEventFinishedAll": 0x8026eb44,
		"System::evStartOpenModelGate": 0x8026ed18,
		"evStartOpenModelGate": 0x8026ed18,
		"System::evStartEMarioDisappear": 0x8026eedc,
		"evStartEMarioDisappear": 0x8026eedc,
		"System::evStartEMarioGateDrawing": 0x8026f0a0,
		"evStartEMarioGateDrawing": 0x8026f0a0,
		"System::evStartEMarioRunAway": 0x8026f264,
		"evStartEMarioRunAway": 0x8026f264,
		"System::evIsEMarioDownWaitingToTalk": 0x8026f428,
		"evIsEMarioDownWaitingToTalk": 0x8026f428,
		"System::evIsEMarioReachedToGoal": 0x8026f5f0,
		"evIsEMarioReachedToGoal": 0x8026f5f0,
		"System::evLaunchEventClearDemo": 0x8026f7b8,
		"evLaunchEventClearDemo": 0x8026f7b8,
		"System::evIsBossDefeated": 0x8026f868,
		"evIsBossDefeated": 0x8026f868,
		"System::evSetGraffitoMultiplied": 0x8026f914,
		"evSetGraffitoMultiplied": 0x8026f914,
		"System::evIsGraffitoCoverage0": 0x8026fac0,
		"evIsGraffitoCoverage0": 0x8026fac0,
		"System::evGameOver": 0x8026fb6c,
		"evGameOver": 0x8026fb6c,
		"System::evRegisterMovie": 0x8026fc0c,
		"evRegisterMovie": 0x8026fc0c,
		"System::evSetNextStage": 0x8026fd50,
		"evSetNextStage": 0x8026fd50,
		"System::evGetPollutionLevel": 0x8026ff58,
		"evGetPollutionLevel": 0x8026ff58,
		"System::evGetRestTime": 0x8026fff0,
		"evGetRestTime": 0x8026fff0,
		"System::evSetPollutionIncreaseCount": 0x802700cc,
		"evSetPollutionIncreaseCount": 0x802700cc,
		"System::evSetAttentionTime": 0x80270184,
		"evSetAttentionTime": 0x80270184,
		"System::evSetTimeLimit": 0x8027023c,
		"evSetTimeLimit": 0x8027023c,
		"System::evSetDead4LiveActor": 0x80270390,
		"evSetDead4LiveActor": 0x80270390,
		"System::evSetHide4LiveActor": 0x802705bc,
		"evSetHide4LiveActor": 0x802705bc,
		"System::evIsOnLiveActorFlag": 0x802707e8,
		"evIsOnLiveActorFlag": 0x802707e8,
		"System::evPushNerve4LiveActor": 0x80270a50,
		"evPushNerve4LiveActor": 0x80270a50,
		"System::evSetFlagNPCCanTaken": 0x80270ca4,
		"evSetFlagNPCCanTaken": 0x80270ca4,
		"System::evIsTalkModeNow": 0x80270eb8,
		"evIsTalkModeNow": 0x80270eb8,
		"System::evSetValue2TalkVariable": 0x80270f7c,
		"evSetValue2TalkVariable": 0x80270f7c,
		"System::evGetTalkSelectedValue": 0x80271060,
		"evGetTalkSelectedValue": 0x80271060,
		"System::evGetTalkMode": 0x802710fc,
		"evGetTalkMode": 0x802710fc,
		"System::evSetTalkMsgID": 0x80271194,
		"evSetTalkMsgID": 0x80271194,
		"System::evGetTalkNPCName": 0x80271394,
		"evGetTalkNPCName": 0x80271394,
		"System::evGetTalkNPC": 0x802714d4,
		"evGetTalkNPC": 0x802714d4,
		"System::evIsNearActors": 0x8027157c,
		"evIsNearActors": 0x8027157c,
		"System::evIsNearSameActors": 0x80271900,
		"evIsNearSameActors": 0x80271900,
		"System::evSetFlagNPCDead": 0x80271e08,
		"evSetFlagNPCDead": 0x80271e08,
		"System::evSetFlagNPCDontThrow": 0x80272090,
		"evSetFlagNPCDontThrow": 0x80272090,
		"System::evSetFlagNPCDontTalk": 0x80272318,
		"evSetFlagNPCDontTalk": 0x80272318,
		"System::evGetNPCType": 0x802725a0,
		"evGetNPCType": 0x802725a0,
		"System::evGetNameRefName": 0x80272780,
		"evGetNameRefName": 0x80272780,
		"System::evGetNameRefHandle": 0x802728e8,
		"evGetNameRefHandle": 0x802728e8,
		"System::evSetSystemFlag": 0x80272a38,
		"evSetSystemFlag": 0x80272a38,
		"System::evGetSystemFlag": 0x80272c24,
		"evGetSystemFlag": 0x80272c24,
		"TSpcTypedInterp<TEventWatcher>::~TSpcTypedInterp": 0x80272d60,
		"~TSpcTypedInterp": 0x80272d60,
		"TSpcTypedBinary<TEventWatcher>::~TSpcTypedBinary": 0x80272dc4,
		"TSpcTypedInterp<TEventWatcher>::dispatchBuiltin": 0x80272e28,
		"System::__sinit_EventWatcher_cpp": 0x80272ea0,
		"__sinit_EventWatcher_cpp": 0x80272ea0,
		"TFlagManager::saveOption": 0x8027319c,
		"saveOption": 0x8027319c,
		"TFlagManager::loadOption": 0x802732c8,
		"loadOption": 0x802732c8,
		"TFlagManager::correctOptFlag": 0x802733cc,
		"correctOptFlag": 0x802733cc,
		"TFlagManager::resetOpt": 0x80273478,
		"resetOpt": 0x80273478,
		"TFlagManager::saveFail": 0x80273488,
		"saveFail": 0x80273488,
		"TFlagManager::saveSuccess": 0x802734c0,
		"saveSuccess": 0x802734c0,
		"TFlagManager::save": 0x80273518,
		"TFlagManager::correctFlag": 0x802736ac,
		"correctFlag": 0x802736ac,
		"TFlagManager::firstStart": 0x80273864,
		"firstStart": 0x80273864,
		"TFlagManager::restore": 0x80273ab8,
		"restore": 0x80273ab8,
		"TFlagManager::load": 0x80273d0c,
		"TFlagManager::setNozzleRight": 0x80274058,
		"setNozzleRight": 0x80274058,
		"TFlagManager::getNozzleRight": 0x802740f8,
		"getNozzleRight": 0x802740f8,
		"TFlagManager::setBlueCoinFlag": 0x80274188,
		"setBlueCoinFlag": 0x80274188,
		"TFlagManager::getBlueCoinFlag": 0x8027423c,
		"getBlueCoinFlag": 0x8027423c,
		"TFlagManager::incGoldCoinFlag": 0x802742cc,
		"incGoldCoinFlag": 0x802742cc,
		"TFlagManager::setShineFlag": 0x80274368,
		"setShineFlag": 0x80274368,
		"TFlagManager::getShineFlag": 0x802743e4,
		"getShineFlag": 0x802743e4,
		"TFlagManager::incMario": 0x80274428,
		"incMario": 0x80274428,
		"TFlagManager::decFlag": 0x8027448c,
		"decFlag": 0x8027448c,
		"TFlagManager::incFlag": 0x802744b0,
		"incFlag": 0x802744b0,
		"TFlagManager::setBool": 0x802745a0,
		"setBool": 0x802745a0,
		"TFlagManager::getBool": 0x802746e0,
		"getBool": 0x802746e0,
		"TFlagManager::setFlag": 0x802747d8,
		"setFlag": 0x802747d8,
		"TFlagManager::getFlag": 0x80274a08,
		"getFlag": 0x80274a08,
		"TFlagManager::resetStage": 0x80274bb0,
		"resetStage": 0x80274bb0,
		"TFlagManager::resetGame": 0x80274d5c,
		"resetGame": 0x80274d5c,
		"TFlagManager::resetCard": 0x80274f2c,
		"resetCard": 0x80274f2c,
		"TFlagManager::start": 0x80275140,
		"TGCLogoDir::direct_dolby": 0x802751e0,
		"direct_dolby": 0x802751e0,
		"TGCLogoDir::direct_nlogo": 0x80275344,
		"direct_nlogo": 0x80275344,
		"TGCLogoDir::direct": 0x802756b4,
		"TGCLogoDir::setup": 0x802758b8,
		"TGCLogoDir::TGCLogoDir": 0x80275fd8,
		"TNintendo2D::perform": 0x80276098,
		"TNintendo2D::~TNintendo2D": 0x80276268,
		"System::__sinit_GCLogoDir_cpp": 0x802762dc,
		"__sinit_GCLogoDir_cpp": 0x802762dc,
		"TGXAlphaUpdate::~TGXAlphaUpdate": 0x802765e0,
		"TGXAlphaUpdate::perform": 0x80276654,
		"TReInitGX::perform": 0x802766a8,
		"TSMSDrawInit::perform": 0x802766d0,
		"TJ3DSysSetViewMtx::perform": 0x802766f8,
		"TJ3DSysFlag::perform": 0x8027672c,
		"TReInitGX::~TReInitGX": 0x802767b0,
		"TSMSDrawInit::~TSMSDrawInit": 0x80276824,
		"TJ3DSysSetViewMtx::~TJ3DSysSetViewMtx": 0x80276898,
		"TJ3DSysFlag::~TJ3DSysFlag": 0x8027690c,
		"TMarDirector::registerEventWatcher": 0x80276980,
		"registerEventWatcher": 0x80276980,
		"TMarDirector::setup": 0x80276a08,
		"TMarDirector::setupThreadFunc": 0x80276a7c,
		"TMarDirector::TMarDirector": 0x80276a9c,
		"TMarDirector::TDemoInfo::TDemoInfo": 0x80276e18,
		"JGadget::TSingleNodeLinkList::Initialize_": 0x80276e24,
		"Initialize_": 0x80276e24,
		"System::__sinit_MarDirector_cpp": 0x80276e3c,
		"__sinit_MarDirector_cpp": 0x80276e3c,
		"TMarDirector::moveStage": 0x8027722c,
		"moveStage": 0x8027722c,
		"TMarDirector::updateGameMode": 0x8027765c,
		"updateGameMode": 0x8027765c,
		"TGameSequence::set": 0x80277ee4,
		"TMarDirector::nextStateInitialize": 0x80277ef8,
		"nextStateInitialize": 0x80277ef8,
		"TMarDirector::setMario": 0x80278584,
		"setMario": 0x80278584,
		"TMarDirector::currentStateFinalize": 0x80278858,
		"currentStateFinalize": 0x80278858,
		"TMarDirector::changeState": 0x80278b30,
		"System::decideNextScenario": 0x8027929c,
		"decideNextScenario": 0x8027929c,
		"System::decideNextStage": 0x802793f0,
		"decideNextStage": 0x802793f0,
		"JDrama::TFlagT<unsigned_short><unsigned_short>::set": 0x802794d4,
		"System::__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x802794dc,
		"__ct__Q26JDrama10TFlagT<Us>FRCQ26JDrama10TFlagT<Us>": 0x802794dc,
		"TMarDirector::direct": 0x802794e8,
		"System::__sinit_MarDirectorDirect_cpp": 0x802799f8,
		"__sinit_MarDirectorDirect_cpp": 0x802799f8,
		"TMarDirector::fireStreamingMovie": 0x80279cf4,
		"fireStreamingMovie": 0x80279cf4,
		"TMarDirector::fireEndDemoCamera": 0x80279edc,
		"fireEndDemoCamera": 0x80279edc,
		"TMarDirector::fireStartDemoCamera": 0x80279eec,
		"fireStartDemoCamera": 0x80279eec,
		"TMarDirector::setNextStage": 0x80279fcc,
		"setNextStage": 0x80279fcc,
		"TMarDirector::movement": 0x8027a15c,
		"TMarDirector::fireRideYoshi": 0x8027a18c,
		"fireRideYoshi": 0x8027a18c,
		"TMarDirector::fireGetStar": 0x8027a214,
		"fireGetStar": 0x8027a214,
		"TMarDirector::fireGetNozzle": 0x8027a2d4,
		"fireGetNozzle": 0x8027a2d4,
		"TMarDirector::fireGetBlueCoin": 0x8027a3e4,
		"fireGetBlueCoin": 0x8027a3e4,
		"TMarDirector::movement_game": 0x8027a47c,
		"movement_game": 0x8027a47c,
		"TMarDirector::findNearestTalkNPC": 0x8027a640,
		"findNearestTalkNPC": 0x8027a640,
		"TMarDirector::entryNPC": 0x8027a700,
		"entryNPC": 0x8027a700,
		"System::__sinit_MarDirectorEvent_cpp": 0x8027a734,
		"__sinit_MarDirectorEvent_cpp": 0x8027a734,
		"TMarDirector::setupPerformList_console": 0x8027aa30,
		"setupPerformList_console": 0x8027aa30,
		"TMarDirector::initECDisp": 0x8027ab40,
		"initECDisp": 0x8027ab40,
		"TMarDirector::initECTMir": 0x8027b7d0,
		"initECTMir": 0x8027b7d0,
		"TMarDirector::initECTGft": 0x8027b8c8,
		"initECTGft": 0x8027b8c8,
		"TMarDirector::preEntry": 0x8027be98,
		"preEntry": 0x8027be98,
		"TMarDirector::setup2": 0x8027c3ec,
		"setup2": 0x8027c3ec,
		"System::__sinit_MarDirectorSetup2_cpp": 0x8027c9a8,
		"__sinit_MarDirectorSetup2_cpp": 0x8027c9a8,
		"System::MarErrInit": 0x8027ccb4,
		"MarErrInit": 0x8027ccb4,
		"System::MarErrException": 0x8027cd34,
		"MarErrException": 0x8027cd34,
		"TMarNameRefGen::getNameRef": 0x8027cdd0,
		"TStagePositionInfo::~TStagePositionInfo": 0x8027eaec,
		"std::__copy<TStagePositionInfo,0,0>::copy": 0x8027eb50,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::TVector": 0x8027ed08,
		"TScenarioArchiveName::~TScenarioArchiveName": 0x8027ed34,
		"std::__copy<TScenarioArchiveName,0,0>::copy": 0x8027ed98,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::TVector": 0x8027eebc,
		"TCubeGeneralInfo::TCubeGeneralInfo": 0x8027ef4c,
		"std::__copy<TCameraMapTool,0,0>::copy": 0x8027f058,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::TVector": 0x8027f260,
		"TStageEventInfo::~TStageEventInfo": 0x8027f28c,
		"std::__copy<TStageEventInfo,0,0>::copy": 0x8027f2f0,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::TVector": 0x8027f4d0,
		"TCubeManagerMarioIn::~TCubeManagerMarioIn": 0x8027f4fc,
		"TSunGlass::TSunGlass": 0x8027f5f4,
		"JGadget::TList_pointer<THitActor*>::TList_pointer": 0x8027f6a4,
		"TList_pointer": 0x8027f6a4,
		"TWaterSplash::TWaterSplash": 0x8027f748,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::searchF": 0x8027f74c,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::loadAfter": 0x8027f7e8,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::load": 0x8027f848,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::erase": 0x8027fa40,
		"TStagePositionInfo::TStagePositionInfo": 0x8027fb24,
		"JGadget::TVector<TStagePositionInfo,JGadget::TAllocator<TStagePositionInfo>>::InsertRaw": 0x8027fb68,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::searchF": 0x80280018,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::loadAfter": 0x802800b4,
		"TNameRefPtrAryT<TCubeGeneralInfo,JDrama::TNameRef>::load": 0x80280114,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::perform": 0x80280224,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::searchF": 0x802802e0,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfterSuper": 0x802803c8,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadAfter": 0x802803e8,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::loadSuper": 0x802804a0,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::load": 0x802804c0,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::searchF": 0x80280608,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::loadAfter": 0x802806a4,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::load": 0x80280704,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::erase": 0x802808fc,
		"TCameraMapTool::TCameraMapTool": 0x802809e0,
		"JGadget::TVector<TCameraMapTool,JGadget::TAllocator<TCameraMapTool>>::InsertRaw": 0x80280a54,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::searchF": 0x80280f54,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::loadAfter": 0x80280ff0,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::load": 0x80281050,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::searchF": 0x80281160,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::loadAfter": 0x802811fc,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::load": 0x8028125c,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::erase": 0x80281434,
		"TScenarioArchiveName::TScenarioArchiveName": 0x80281518,
		"JGadget::TVector<TScenarioArchiveName,JGadget::TAllocator<TScenarioArchiveName>>::InsertRaw": 0x8028154c,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::~TNameRefAryT": 0x80281938,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::~TNameRefPtrAryT": 0x802819bc,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::~TNameRefAryT": 0x80281a34,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::~TNameRefAryT": 0x80281b30,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::~TNameRefAryT": 0x80281bb4,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::erase": 0x80281c38,
		"TCubeManagerFast::~TCubeManagerFast": 0x80281cb4,
		"TCubeManagerArea::~TCubeManagerArea": 0x80281d48,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::searchF": 0x80281ddc,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::loadAfter": 0x80281e78,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::load": 0x80281ed8,
		"TStageEventInfo::TStageEventInfo": 0x80282138,
		"JGadget::TVector<TStageEventInfo,JGadget::TAllocator<TStageEventInfo>>::InsertRaw": 0x802821a4,
		"TStageEventInfo::operator_=": 0x802824c4,
		"System::__sinit_MarNameRefGen_cpp": 0x80282518,
		"__sinit_MarNameRefGen_cpp": 0x80282518,
		"TMenuDirector::setFixedStageValue": 0x80282814,
		"setFixedStageValue": 0x80282814,
		"TMenuDirector::direct": 0x80282c4c,
		"TMenuDirector::rsetup": 0x80283544,
		"TMenuDirector::setup": 0x80283e60,
		"TMenuDirector::setupThreadFunc": 0x80283f8c,
		"TMenuDirector::TMenuDirector": 0x80284064,
		"System::__sinit_MenuDir_cpp": 0x80284138,
		"__sinit_MenuDir_cpp": 0x80284138,
		"TParams::finalize": 0x80284638,
		"TParams::init": 0x80284648,
		"TParamT<JGeometry::TVec3<float><float>>::load": 0x80284780,
		"TParamT<float><float>::load": 0x802847d4,
		"TParamT<long><long>::load": 0x80284828,
		"TParamT<short><short>::load": 0x8028487c,
		"TParamT<unsigned_char><unsigned_char>::load": 0x802848d0,
		"TPerformList::~TPerformList": 0x80284924,
		"TPerformList::load": 0x80284b54,
		"JGadget::TSingleLinkList<TPerformLink,0>::Element_getNode": 0x80284cb4,
		"JGadget::TSingleLinkList<12TPerformLink,0>::iterator::iterator": 0x80284cb8,
		"JGadget::TSingleNodeLinkList::end": 0x80284cc4,
		"TPerformList::perform": 0x80284cd0,
		"System::SMSSetupMovieRenderingInfo": 0x80284da8,
		"SMSSetupMovieRenderingInfo": 0x80284da8,
		"System::SMSSetupGameRenderingInfo": 0x80284ecc,
		"SMSSetupGameRenderingInfo": 0x80284ecc,
		"System::SMSSetupTitleRenderingInfo": 0x8028501c,
		"SMSSetupTitleRenderingInfo": 0x8028501c,
		"System::SMSSetupTitleRenderMode": 0x80285058,
		"SMSSetupTitleRenderMode": 0x80285058,
		"System::SMSSetupGCLogoRenderingInfo": 0x8028517c,
		"SMSSetupGCLogoRenderingInfo": 0x8028517c,
		"System::SMSGetRederRect_Game": 0x80285278,
		"SMSGetRederRect_Game": 0x80285278,
		"TSnapTimeObj::~TSnapTimeObj": 0x802852cc,
		"TSnapTimeObj::perform": 0x80285340,
		"TTalkCursor::~TTalkCursor": 0x80285424,
		"TTalkCursor::associateNPC": 0x80285498,
		"associateNPC": 0x80285498,
		"TTalkCursor::perform": 0x80285524,
		"TTalkCursor::loadAfter": 0x80285564,
		"System::SMS_ResetTexCacheRegion": 0x80285654,
		"SMS_ResetTexCacheRegion": 0x80285654,
		"TAlphaCatch::~TAlphaCatch": 0x80285690,
		"TAlphaCatch::perform": 0x80285704,
		"TZBufferCatch::perform": 0x80285748,
		"TZBufferCatch::~TZBufferCatch": 0x80285780,
		"TApplication::mountStageArchive": 0x802857f4,
		"mountStageArchive": 0x802857f4,
		"TApplication::drawDVDErr": 0x802859a0,
		"drawDVDErr": 0x802859a0,
		"TApplication::gameLoop": 0x80285dac,
		"gameLoop": 0x80285dac,
		"TTimeRec::crTimeAry": 0x802861dc,
		"crTimeAry": 0x802861dc,
		"TApplication::proc": 0x802861f4,
		"TApplication::checkAdditionalMovie": 0x80286644,
		"checkAdditionalMovie": 0x80286644,
		"TApplication::finalize": 0x80286828,
		"TApplication::initialize_nlogoAfter": 0x802868e0,
		"initialize_nlogoAfter": 0x802868e0,
		"TApplication::initialize_bootAfter": 0x80286c2c,
		"initialize_bootAfter": 0x80286c2c,
		"System::SetupThreadFuncLogo": 0x80286edc,
		"SetupThreadFuncLogo": 0x80286edc,
		"TApplication::setupThreadFuncLogo": 0x80286efc,
		"setupThreadFuncLogo": 0x80286efc,
		"TApplication::initialize": 0x80287230,
		"System::SetupThreadFuncBoot": 0x802876ec,
		"SetupThreadFuncBoot": 0x802876ec,
		"System::SMSSwitch2DArchive": 0x80287728,
		"SMSSwitch2DArchive": 0x80287728,
		"System::SMSMountAramArchive": 0x802877f0,
		"SMSMountAramArchive": 0x802877f0,
		"System::SMSLoadArchive": 0x802878a8,
		"SMSLoadArchive": 0x802878a8,
		"TApplication::TApplication": 0x8028797c,
		"System::SMSGetAnmFrameRate": 0x80287a4c,
		"SMSGetAnmFrameRate": 0x80287a4c,
		"System::SMSGetVSyncTimesPerSec": 0x80287a7c,
		"SMSGetVSyncTimesPerSec": 0x80287a7c,
		"TMarioGamePad::~TMarioGamePad": 0x80287b48,
		"System::__sinit_Application_cpp": 0x80287bac,
		"__sinit_Application_cpp": 0x80287bac,
		"TScenarioArchiveName::load": 0x80287ea8,
		"TMarioGamePad::read": 0x80287eec,
		"TMarioGamePad::onNeutralMarioKey": 0x80287f6c,
		"onNeutralMarioKey": 0x80287f6c,
		"TMarioGamePad::updateMeaning": 0x80287f78,
		"updateMeaning": 0x80287f78,
		"TMarioGamePad::reset": 0x80288814,
		"System::CLBCalcRatio": 0x8028888c,
		"System::__sinit_MarioGamePad_cpp": 0x802888f4,
		"__sinit_MarioGamePad_cpp": 0x802888f4,
		"TStageEventInfo::load": 0x80288900,
		"System::SMS_getShineIDofExStage": 0x80288998,
		"SMS_getShineIDofExStage": 0x80288998,
		"System::SMS_getShineStage": 0x802889c8,
		"SMS_getShineStage": 0x802889c8,
		"System::SMS_isOptionMap": 0x802889e0,
		"SMS_isOptionMap": 0x802889e0,
		"System::SMS_isDivingMap": 0x802889fc,
		"SMS_isDivingMap": 0x802889fc,
		"System::SMS_isMultiPlayerMap": 0x80288a30,
		"SMS_isMultiPlayerMap": 0x80288a30,
		"System::SMS_isExMap": 0x80288a58,
		"SMS_isExMap": 0x80288a58,
		"System::SMSGetGCLogoVideoWidth": 0x80288aa0,
		"SMSGetGCLogoVideoWidth": 0x80288aa0,
		"System::SMSGetGCLogoRenderHeight": 0x80288aa8,
		"SMSGetGCLogoRenderHeight": 0x80288aa8,
		"System::SMSGetGCLogoRenderWidth": 0x80288ab0,
		"SMSGetGCLogoRenderWidth": 0x80288ab0,
		"System::SMSGetTitleRenderHeight": 0x80288ab8,
		"SMSGetTitleRenderHeight": 0x80288ab8,
		"System::SMSGetTitleRenderWidth": 0x80288ac0,
		"SMSGetTitleRenderWidth": 0x80288ac0,
		"System::SMSGetGameRenderHeight": 0x80288ac8,
		"SMSGetGameRenderHeight": 0x80288ac8,
		"System::SMSGetGameRenderWidth": 0x80288ad0,
		"SMSGetGameRenderWidth": 0x80288ad0,
		"System::SMSGetTitleVideoWidth": 0x80288b18,
		"SMSGetTitleVideoWidth": 0x80288b18,
		"System::SMSGetGameVideoWidth": 0x80288b60,
		"SMSGetGameVideoWidth": 0x80288b60,
		"TStagePositionInfo::load": 0x80288b68,
		"TProcessMeter::TProcessMeter": 0x80288c30,
		"TTimeRec::drawSyncCallback": 0x80288c70,
		"TTimeRec::snapGXTime": 0x80288cc0,
		"snapGXTime": 0x80288cc0,
		"TTimeRec::flip": 0x80288d6c,
		"flip": 0x80288d6c,
		"TTimeArray::TTimeArray": 0x80288dfc,
		"TTimeRec::start": 0x80288e08,
		"TTimeArray::append": 0x80288ea4,
		"TDrawSyncManager::pushBreakPoint": 0x80288ed8,
		"pushBreakPoint": 0x80288ed8,
		"TDrawSyncManager::drawSyncCallbackSub": 0x80288f30,
		"drawSyncCallbackSub": 0x80288f30,
		"TDrawSyncManager::setCallback": 0x80288ff4,
		"setCallback": 0x80288ff4,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::DestroyElement_": 0x80289028,
		"TDrawSyncManager::threadFunc": 0x8028903c,
		"threadFunc": 0x8028903c,
		"TFifo::getLoopIdx": 0x802891b4,
		"getLoopIdx": 0x802891b4,
		"TDrawSyncManager::drawSyncCallback": 0x802891d0,
		"TDrawSyncManager::start": 0x80289204,
		"JGadget::TVector<TDrawSyncManager::TDrawSyncTokenRange,JGadget::TAllocator<TDrawSyncManager::TDrawSyncTokenRange>>::insert": 0x8028933c,
		"TDrawSyncManager::TDrawSyncTokenRange::TDrawSyncTokenRange": 0x802896e4,
		"TTHPRender::~TTHPRender": 0x802896f4,
		"TTHPRender::perform": 0x80289768,
		"TTHPRender::TTHPRender": 0x802897d8,
		"TMarNameRefGen::getNameRef_BossEnemy": 0x80289850,
		"getNameRef_BossEnemy": 0x80289850,
		"System::__sinit_MarNameRefGen_BossEnemy_cpp": 0x8028a184,
		"__sinit_MarNameRefGen_BossEnemy_cpp": 0x8028a184,
		"TMarNameRefGen::getNameRef_Enemy": 0x8028a480,
		"getNameRef_Enemy": 0x8028a480,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::TRotation3": 0x8028c548,
		"TNameKuriLauncherManager::~TNameKuriLauncherManager": 0x8028c618,
		"THamuKuriLauncherManager::~THamuKuriLauncherManager": 0x8028c68c,
		"TMarNameRefGen::getNameRef_Map": 0x8028c700,
		"getNameRef_Map": 0x8028c700,
		"TMarNameRefGen::getNameRef_MapObj": 0x8028ca38,
		"getNameRef_MapObj": 0x8028ca38,
		"TTelesaSlot::TTelesaSlot": 0x8029017c,
		"TFence::TFence": 0x80290214,
		"TMarNameRefGen::getNameRef_NPC": 0x80290390,
		"getNameRef_NPC": 0x80290390,
		"TMareWManager::~TMareWManager": 0x802912f0,
		"TMareMManager::~TMareMManager": 0x80291384,
		"TCardManager::cmdLoop": 0x80291418,
		"cmdLoop": 0x80291418,
		"TCardManager::writeOptionBlock_": 0x80291640,
		"writeOptionBlock_": 0x80291640,
		"TCardManager::writeBlock_": 0x802917d8,
		"writeBlock_": 0x802917d8,
		"TCardManager::readBlock_": 0x802919f8,
		"readBlock_": 0x802919f8,
		"TCardManager::getBookmarkInfos_": 0x80291c64,
		"getBookmarkInfos_": 0x80291c64,
		"TCardManager::open_": 0x80291e38,
		"open_": 0x80291e38,
		"TCardManager::setCardStat_": 0x80291fc8,
		"setCardStat_": 0x80291fc8,
		"TCardManager::filledInitData_": 0x8029220c,
		"filledInitData_": 0x8029220c,
		"TCardManager::createFile_": 0x802924fc,
		"createFile_": 0x802924fc,
		"TCardManager::mount_": 0x80292634,
		"mount_": 0x80292634,
		"System::detachCallback": 0x80292880,
		"detachCallback": 0x80292880,
		"TCardManager::getLastStatus": 0x80292890,
		"getLastStatus": 0x80292890,
		"TCardManager::writeOptionBlock": 0x802928e8,
		"writeOptionBlock": 0x802928e8,
		"TCardManager::getOptionWriteStream": 0x80292938,
		"getOptionWriteStream": 0x80292938,
		"TCardManager::getOptionReadStream": 0x80292a04,
		"getOptionReadStream": 0x80292a04,
		"TCardManager::readOptionBlock": 0x80292a34,
		"readOptionBlock": 0x80292a34,
		"TCardManager::writeBlock": 0x80292a84,
		"writeBlock": 0x80292a84,
		"TCardManager::getWriteStream": 0x80292ae4,
		"getWriteStream": 0x80292ae4,
		"TCardManager::getReadStream": 0x80292b38,
		"getReadStream": 0x80292b38,
		"TCardManager::readBlock": 0x80292b68,
		"readBlock": 0x80292b68,
		"TCardManager::getBookmarkInfos": 0x80292bc8,
		"getBookmarkInfos": 0x80292bc8,
		"TCardManager::createFile": 0x80292c28,
		"createFile": 0x80292c28,
		"TCardManager::format": 0x80292c78,
		"format": 0x80292c78,
		"TCardManager::unmount": 0x80292cc8,
		"TCardManager::probe": 0x80292d44,
		"probe": 0x80292d44,
		"TCardManager::~TCardManager": 0x80292dc8,
		"TCardManager::TCardManager": 0x80292e74,
		"TCardManager::TCriteria::TCriteria": 0x80292f40,
		"System::cardmain": 0x80292f4c,
		"cardmain": 0x80292f4c,
		"TCardManager::copyTo": 0x80292f6c,
		"copyTo": 0x80292f6c,
		"TCardManager::decideUseSector": 0x80293108,
		"decideUseSector": 0x80293108,
		"TCardManager::TCriteria::set": 0x80293178,
		"System::CalcCheckSum": 0x802931dc,
		"CalcCheckSum": 0x802931dc,
		"TMarDirector::loadParticleMario": 0x802933d4,
		"loadParticleMario": 0x802933d4,
		"TMarDirector::loadParticle": 0x80294638,
		"loadParticle": 0x80294638,
		"TMarDirector::initLoadParticle": 0x80294fb8,
		"initLoadParticle": 0x80294fb8,
		"TMarDirector::loadResource": 0x80295144,
		"loadResource": 0x80295144,
		"System::__sinit_MarDirectorLoadResource_cpp": 0x80295520,
		"__sinit_MarDirectorLoadResource_cpp": 0x80295520,
		"TMovieDirector::direct": 0x8029581c,
		"TMovieDirector::decideNextMode": 0x80295ef4,
		"decideNextMode": 0x80295ef4,
		"TMovieDirector::rsetup": 0x80296198,
		"TMovieDirector::setup": 0x8029695c,
		"TMovieDirector::setupThreadFunc": 0x80296a90,
		"TMovieDirector::TMovieDirector": 0x80296ab0,
		"TMovieDirector::getStreamMovieName": 0x80296b60,
		"getStreamMovieName": 0x80296b60,
		"System::__sinit_MovieDirector_cpp": 0x80296b88,
		"__sinit_MovieDirector_cpp": 0x80296b88,
		"TMarDirector::createObjects": 0x80296e8c,
		"createObjects": 0x80296e8c,
		"TMarDirector::setupObjects": 0x80296f04,
		"setupObjects": 0x80296f04,
		"TMarDirector::decideMarioPosIdx": 0x80298fb8,
		"decideMarioPosIdx": 0x80298fb8,
		"System::__sinit_MarDirectorSetupObjects_cpp": 0x80299248,
		"__sinit_MarDirectorSetupObjects_cpp": 0x80299248,
		"MSStage::setPosPtr": 0x80299544,
		"setPosPtr": 0x80299544,
		"MSSTageSimpleEnvironment::proc": 0x80299548,
		"MSStageCubeSwitch::proc": 0x80299584,
		"MSStageCubeFadeMonte::proc": 0x8029975c,
		"MSStageCubeFade::proc": 0x8029a120,
		"MSStageDistFadeMonte::proc": 0x8029a46c,
		"MSStageDistFade::proc": 0x8029a810,
		"MSStageDistFade::MSStageDistFade": 0x8029aae8,
		"MSStage::stageLoop": 0x8029ab40,
		"stageLoop": 0x8029ab40,
		"MSStage::init": 0x8029ab6c,
		"MSMainProc::startStageBGM": 0x8029af08,
		"startStageBGM": 0x8029af08,
		"MSMainProc::endStageEntranceDemo": 0x8029afec,
		"endStageEntranceDemo": 0x8029afec,
		"MSMainProc::entranceDemoLoop": 0x8029b08c,
		"entranceDemoLoop": 0x8029b08c,
		"MSMainProc::startStageEntranceDemo": 0x8029b090,
		"startStageEntranceDemo": 0x8029b090,
		"MSMainProc::setMSoundEnterStage": 0x8029b130,
		"setMSoundEnterStage": 0x8029b130,
		"MSMainProc::setBossNotDamagedFlag": 0x8029bb00,
		"setBossNotDamagedFlag": 0x8029bb00,
		"MSMainProc::setBossLivesFlag2": 0x8029bb08,
		"setBossLivesFlag2": 0x8029bb08,
		"MSMainProc::setBossLivesFlagOnlyFlag": 0x8029bb54,
		"setBossLivesFlagOnlyFlag": 0x8029bb54,
		"MSMainProc::setBossLivesFlag": 0x8029bb5c,
		"setBossLivesFlag": 0x8029bb5c,
		"MSMainProc::fromTalkingCameraDemo": 0x8029bba8,
		"fromTalkingCameraDemo": 0x8029bba8,
		"MSMainProc::toTalkingCameraDemo": 0x8029bbd0,
		"toTalkingCameraDemo": 0x8029bbd0,
		"MSMainProc::fromInnerCameraDemo": 0x8029bc3c,
		"fromInnerCameraDemo": 0x8029bc3c,
		"MSMainProc::toInnerCameraDemo": 0x8029bc4c,
		"toInnerCameraDemo": 0x8029bc4c,
		"MSMainProc::getMonteVillageActorArea": 0x8029bc5c,
		"getMonteVillageActorArea": 0x8029bc5c,
		"System::__sinit_MSoundMainSide_cpp": 0x8029bd7c,
		"__sinit_MSoundMainSide_cpp": 0x8029bd7c,
		"TTargetArrow::~TTargetArrow": 0x8029c078,
		"TTargetArrow::setPos": 0x8029c0ec,
		"setPos": 0x8029c0ec,
		"TTargetArrow::perform": 0x8029c11c,
		"TTargetArrow::loadAfter": 0x8029c158,
		"TLiveActor::stopAnmSound": 0x801f77f4,
		"stopAnmSound": 0x801f77f4,
		"TLiveActor::getBasNameTable": 0x801f7830,
		"TLiveActor::setCurAnmSound": 0x801f7838,
		"setCurAnmSound": 0x801f7838,
		"TLiveActor::setAnmSound": 0x801f792c,
		"setAnmSound": 0x801f792c,
		"TLiveActor::updateAnmSound": 0x801f79d0,
		"TLiveActor::initAnmSound": 0x801f7a38,
		"TLiveActor::getTakingMtx": 0x801f7b48,
		"TLiveActor::getFocalPoint": 0x801f7b68,
		"TLiveActor::getJointTransByIndex": 0x801f7b84,
		"getJointTransByIndex": 0x801f7b84,
		"TLiveActor::hasMapCollision": 0x801f7c0c,
		"TLiveActor::getGravityY": 0x801f7c28,
		"TLiveActor::calcVelocityToJumpToY": 0x801f7c30,
		"calcVelocityToJumpToY": 0x801f7c30,
		"TLiveActor::performOnlyDraw": 0x801f7c84,
		"performOnlyDraw": 0x801f7c84,
		"TLiveActor::perform": 0x801f7d60,
		"TLiveActor::drawObject": 0x801f7ed8,
		"TLiveActor::requestShadow": 0x801f7f30,
		"TLiveActor::moveObject": 0x801f809c,
		"TLiveActor::setGroundCollision": 0x801f8200,
		"TLiveActor::getShadowType": 0x801f8254,
		"TLiveActor::receiveMessage": 0x801f825c,
		"TLiveActor::kill": 0x801f8264,
		"TLiveActor::calcRootMatrix": 0x801f8280,
		"TLiveActor::control": 0x801f8324,
		"TLiveActor::bind": 0x801f83ec,
		"TLiveActor::load": 0x801f8648,
		"TLiveActor::init": 0x801f86e0,
		"TLiveActor::initLodAnm": 0x801f88cc,
		"initLodAnm": 0x801f88cc,
		"TLiveActor::getRootJointMtx": 0x801f8958,
		"TLiveActor::getModel": 0x801f8960,
		"getModel": 0x801f8960,
		"TLiveActor::calcRideMomentum": 0x801f896c,
		"calcRideMomentum": 0x801f896c,
		"Strategic::MsWrap": 0x801f8b88,
		"TLiveActor::belongToGround": 0x801f8bd0,
		"belongToGround": 0x801f8bd0,
		"TLiveActor::calcRidePos": 0x801f8c50,
		"calcRidePos": 0x801f8c50,
		"TLiveActor::TLiveActor": 0x801f8d80,
		"Strategic::__sinit_liveactor_cpp": 0x801f8eb0,
		"__sinit_liveactor_cpp": 0x801f8eb0,
		"TSpcTypedBinary<TLiveActor>::initUserBuiltin": 0x801f91b4,
		"Strategic::linPushNerve": 0x801f92a8,
		"linPushNerve": 0x801f92a8,
		"Strategic::linSetSRT": 0x801f94a0,
		"linSetSRT": 0x801f94a0,
		"Strategic::linGetSRT": 0x801f9890,
		"linGetSRT": 0x801f9890,
		"Strategic::linSetAnmRate": 0x801fa028,
		"linSetAnmRate": 0x801fa028,
		"Strategic::linSetBls": 0x801fa29c,
		"linSetBls": 0x801fa29c,
		"Strategic::linSetBlk": 0x801fa3b0,
		"linSetBlk": 0x801fa3b0,
		"Strategic::linSetBtk": 0x801fa4d8,
		"linSetBtk": 0x801fa4d8,
		"Strategic::linSetBtp": 0x801fa600,
		"linSetBtp": 0x801fa600,
		"Strategic::linSetBpk": 0x801fa728,
		"linSetBpk": 0x801fa728,
		"Strategic::linSetBck": 0x801fa850,
		"linSetBck": 0x801fa850,
		"Strategic::NerveGetByIndex": 0x801fa978,
		"NerveGetByIndex": 0x801fa978,
		"TLiveManager::hasMapCollision": 0x801fad10,
		"TLiveManager::getActorByFlag": 0x801fad58,
		"getActorByFlag": 0x801fad58,
		"TLiveManager::perform": 0x801fad98,
		"TLiveManager::setFlagOutOfCube": 0x801fae94,
		"TLiveManager::clipActors": 0x801faf5c,
		"TLiveManager::clipActorsAux": 0x801faf84,
		"clipActorsAux": 0x801faf84,
		"TLiveManager::manageActor": 0x801fb0ac,
		"manageActor": 0x801fb0ac,
		"TLiveManager::load": 0x801fb0d8,
		"TLiveManager::createSpcBinary": 0x801fb118,
		"createSpcBinary": 0x801fb118,
		"TLiveManager::TLiveManager": 0x801fb19c,
		"TObjCheckList::TObjCheckList": 0x801fb208,
		"TObjHitCheck::TObjHitCheck": 0x801fb218,
		"TObjHitCheck::clearHitNum": 0x801fb3f0,
		"clearHitNum": 0x801fb3f0,
		"JGadget::TList<void*,JGadget::TAllocator<void*>>::begin": 0x801fb804,
		"TObjHitCheck::checkActorsHit": 0x801fb810,
		"checkActorsHit": 0x801fb810,
		"TObjHitCheck::entryGroup": 0x801fbb5c,
		"entryGroup": 0x801fbb5c,
		"TObjHitCheck::checkAndEntryGroup": 0x801fbd34,
		"checkAndEntryGroup": 0x801fbd34,
		"TObjHitCheck::checkWater": 0x801fbff4,
		"checkWater": 0x801fbff4,
		"TObjHitCheck::suffererIsInAttackArea": 0x801fc1ac,
		"suffererIsInAttackArea": 0x801fc1ac,
		"Strategic::checkDistance": 0x801fc200,
		"checkDistance": 0x801fc200,
		"TObjManager::searchF": 0x801fc274,
		"TObjManager::getModelDataKeeper": 0x801fc304,
		"getModelDataKeeper": 0x801fc304,
		"TObjManager::createAnmData": 0x801fc350,
		"TObjManager::createModelData": 0x801fc3b0,
		"TObjManager::createModelDataArrayBase": 0x801fc3e4,
		"createModelDataArrayBase": 0x801fc3e4,
		"TObjManager::createModelDataArray": 0x801fc4cc,
		"TObjManager::perform": 0x801fc4f4,
		"TObjManager::getMActorAnmData": 0x801fc5e0,
		"TObjManager::load": 0x801fc62c,
		"TObjManager::manageObj": 0x801fc6d4,
		"manageObj": 0x801fc6d4,
		"TObjManager::TObjManager": 0x801fc6f4,
		"TObjChara::getRes": 0x801fc780,
		"TObjChara::~TObjChara": 0x801fc7c0,
		"TObjChara::load": 0x801fc834,
		"TMActorKeeper::createMActorFromAllBmd": 0x801fca6c,
		"createMActorFromAllBmd": 0x801fca6c,
		"TMActorKeeper::createMActor": 0x801fcb84,
		"createMActor": 0x801fcb84,
		"TMActorKeeper::createMActorFromNthData": 0x801fcdd8,
		"createMActorFromNthData": 0x801fcdd8,
		"TMActorKeeper::createMActorFromDefaultBmd": 0x801fcf18,
		"createMActorFromDefaultBmd": 0x801fcf18,
		"TMActorKeeper::getMActor": 0x801fd03c,
		"TMActorKeeper::createAndRegister": 0x801fd138,
		"createAndRegister": 0x801fd138,
		"TModelDataKeeper::TModelDataKeeper": 0x801fd1f4,
		"TModelDataKeeper::getModelDataNum": 0x801fd210,
		"getModelDataNum": 0x801fd210,
		"TModelDataKeeper::getDataByName": 0x801fd23c,
		"getDataByName": 0x801fd23c,
		"TModelDataKeeper::getNthData": 0x801fd358,
		"getNthData": 0x801fd358,
		"TModelDataKeeper::createAndKeepData": 0x801fd3d0,
		"createAndKeepData": 0x801fd3d0,
		"TModelDataKeeper::loadModelData": 0x801fd4b4,
		"loadModelData": 0x801fd4b4,
		"TModelDataNode::registerDataAndJoinNewNode": 0x801fd52c,
		"registerDataAndJoinNewNode": 0x801fd52c,
		"TSpcInterp::update": 0x801fd590,
		"TSpcInterp::verifyArgNum": 0x801fdaac,
		"verifyArgNum": 0x801fdaac,
		"TSpcInterp::dump": 0x801fdbcc,
		"TSpcInterp::~TSpcInterp": 0x801fde64,
		"TSpcInterp::TSpcInterp": 0x801fdf18,
		"TSpcStack<unsigned_long><unsigned_long>::~TSpcStack": 0x801fe11c,
		"TSpcStack<TSpcSlice>::~TSpcStack": 0x801fe17c,
		"TSpcSlice::TSpcSlice": 0x801fe1e0,
		"TSpcInterp::dispatchBuiltin": 0x801fe1f0,
		"TSpcInterp::dispatchBuiltinDefault": 0x801fe210,
		"dispatchBuiltinDefault": 0x801fe210,
		"TSpcInterp::execend": 0x801fe404,
		"execend": 0x801fe404,
		"TSpcInterp::execint1": 0x801fe440,
		"execint1": 0x801fe440,
		"TSpcInterp::execint0": 0x801fe4b8,
		"execint0": 0x801fe4b8,
		"TSpcInterp::execpop": 0x801fe52c,
		"execpop": 0x801fe52c,
		"TSpcInterp::execjmp": 0x801fe570,
		"execjmp": 0x801fe570,
		"TSpcInterp::execjne": 0x801fe5c8,
		"execjne": 0x801fe5c8,
		"TSpcInterp::execret0": 0x801fe6f0,
		"execret0": 0x801fe6f0,
		"TSpcInterp::execret": 0x801fe8cc,
		"execret": 0x801fe8cc,
		"TSpcInterp::execmkds": 0x801fea54,
		"execmkds": 0x801fea54,
		"TSpcInterp::execmkfr": 0x801feb68,
		"execmkfr": 0x801feb68,
		"TSpcInterp::execfunc": 0x801fec54,
		"execfunc": 0x801fec54,
		"TSpcInterp::execcall": 0x801fed10,
		"execcall": 0x801fed10,
		"TSpcInterp::execshr": 0x801fef54,
		"execshr": 0x801fef54,
		"TSpcInterp::execshl": 0x801ff124,
		"execshl": 0x801ff124,
		"TSpcInterp::execbor": 0x801ff2f4,
		"execbor": 0x801ff2f4,
		"TSpcInterp::execband": 0x801ff4c4,
		"execband": 0x801ff4c4,
		"TSpcInterp::execor": 0x801ff694,
		"execor": 0x801ff694,
		"TSpcSlice::getDataInt": 0x801ff860,
		"getDataInt": 0x801ff860,
		"TSpcInterp::execand": 0x801ff8a8,
		"execand": 0x801ff8a8,
		"TSpcInterp::execnot": 0x801ffa74,
		"execnot": 0x801ffa74,
		"TSpcInterp::execneg": 0x801ffba8,
		"execneg": 0x801ffba8,
		"TSpcInterp::execle": 0x801ffcc0,
		"execle": 0x801ffcc0,
		"TSpcSlice::getDataFloat": 0x801ffe9c,
		"getDataFloat": 0x801ffe9c,
		"TSpcInterp::execge": 0x801ffef4,
		"execge": 0x801ffef4,
		"TSpcInterp::execlt": 0x802000d0,
		"execlt": 0x802000d0,
		"TSpcInterp::execgt": 0x802002a8,
		"execgt": 0x802002a8,
		"TSpcInterp::execne": 0x80200480,
		"execne": 0x80200480,
		"TSpcSlice::operator_!=": 0x802005e8,
		"operator_!=": 0x802005e8,
		"TSpcInterp::execeq": 0x80200784,
		"execeq": 0x80200784,
		"TSpcSlice::operator_==": 0x802008ec,
		"TSpcInterp::execass": 0x80200a88,
		"execass": 0x80200a88,
		"TSpcInterp::execmod": 0x80200be4,
		"execmod": 0x80200be4,
		"TSpcInterp::execdiv": 0x80200dbc,
		"execdiv": 0x80200dbc,
		"TSpcInterp::execmul": 0x80201094,
		"execmul": 0x80201094,
		"TSpcInterp::execsub": 0x8020136c,
		"execsub": 0x8020136c,
		"TSpcInterp::execadd": 0x80201644,
		"execadd": 0x80201644,
		"TSpcInterp::execdec": 0x8020191c,
		"execdec": 0x8020191c,
		"TSpcInterp::execinc": 0x80201a88,
		"execinc": 0x80201a88,
		"TSpcInterp::execnop": 0x80201bf4,
		"execnop": 0x80201bf4,
		"TSpcInterp::execvar": 0x80201bf8,
		"execvar": 0x80201bf8,
		"TSpcInterp::execadr": 0x80201d0c,
		"execadr": 0x80201d0c,
		"TSpcInterp::fetchU32": 0x80201d90,
		"fetchU32": 0x80201d90,
		"TSpcInterp::execstr": 0x80201de4,
		"execstr": 0x80201de4,
		"TSpcBinary::getHeader": 0x80201edc,
		"getHeader": 0x80201edc,
		"TSpcInterp::execflt": 0x80201ee4,
		"execflt": 0x80201ee4,
		"TSpcInterp::execint": 0x80201fac,
		"execint": 0x80201fac,
		"TSpcInterp::fetchS32": 0x80202030,
		"fetchS32": 0x80202030,
		"TSpcBinary::bindSystemDataToSymbol": 0x80202084,
		"bindSystemDataToSymbol": 0x80202084,
		"TSpcBinary::searchSymbol": 0x80202160,
		"searchSymbol": 0x80202160,
		"TSpcBinary::initUserBuiltin": 0x80202218,
		"TSpcBinary::init": 0x8020221c,
		"TSpcBinary::~TSpcBinary": 0x802024bc,
		"TSpcBinary::TSpcBinary": 0x80202508,
		"Strategic::spcTypeof": 0x8020251c,
		"spcTypeof": 0x8020251c,
		"Strategic::spcFloat": 0x80202688,
		"spcFloat": 0x80202688,
		"Strategic::spcInt": 0x80202864,
		"spcInt": 0x80202864,
		"Strategic::spcDump": 0x80202a24,
		"spcDump": 0x80202a24,
		"Strategic::spcPrint": 0x80202b04,
		"spcPrint": 0x80202b04,
		"Strategic::spcUnlock": 0x80202cfc,
		"spcUnlock": 0x80202cfc,
		"Strategic::spcLock": 0x80202de0,
		"spcLock": 0x80202de0,
		"Strategic::spcExit": 0x80202ec4,
		"spcExit": 0x80202ec4,
		"Strategic::spcYield": 0x80202fac,
		"spcYield": 0x80202fac,
		"TStrategy::~TStrategy": 0x80203090,
		"TStrategy::perform": 0x80203104,
		"TStrategy::searchF": 0x8020328c,
		"TStrategy::loadAfter": 0x8020331c,
		"TStrategy::load": 0x80203390,
		"TStrategy::TStrategy": 0x802034a8,
		"TIdxGroupObj::loadSuper": 0x80203560,
		"TIdxGroupObj::~TIdxGroupObj": 0x802035a8,
		"TQuestionManager::~TQuestionManager": 0x802036d0,
		"TQuestionManager::perform": 0x80203744,
		"TQuestionManager::draw": 0x80203854,
		"TQuestionManager::makeDL": 0x802039c8,
		"TQuestionManager::request": 0x80203af0,
		"TQuestionManager::load": 0x80203b84,
		"TQuestionRequest::TQuestionRequest": 0x80203c74,
		"TSMSSmplChara::~TSMSSmplChara": 0x80203c78,
		"TSMSSmplChara::getRes": 0x80203cf8,
		"TSMSSmplChara::load": 0x80203d3c,
		"THitActor::THitActor": 0x80203d84,
		"THitActor::initHitActor": 0x80203eb0,
		"initHitActor": 0x80203eb0,
		"THitActor::perform": 0x80203f7c,
		"THitActor::calcEntryRadius": 0x80203f9c,
		"calcEntryRadius": 0x80203f9c,
		"TBinder::~TBinder": 0x80204020,
		"TBinder::TBinder": 0x8020406c,
		"TSharedParts::perform": 0x8020407c,
		"TSharedParts::getConnectedMtx": 0x80204140,
		"getConnectedMtx": 0x80204140,
		"TMirrorActor::~TMirrorActor": 0x80204444,
		"TMirrorActor::TMirrorActor": 0x802044b8,
		"TMirrorActor::init": 0x80204530,
		"TMirrorActor::entryMirrorDrawBufferAlways": 0x8020472c,
		"entryMirrorDrawBufferAlways": 0x8020472c,
		"TMirrorActor::perform": 0x80204820,
		"TMirrorActor::checkIsInMirror": 0x8020495c,
		"checkIsInMirror": 0x8020495c,
		"Strategic::__sinit_MirrorActor_cpp": 0x80204b20,
		"__sinit_MirrorActor_cpp": 0x80204b20,
		"TMario::actnMain": 0x8021f400,
		"actnMain": 0x8021f400,
		"TMario::taking": 0x8021f658,
		"taking": 0x8021f658,
		"Player::__sinit_MarioAction_cpp": 0x8021f77c,
		"__sinit_MarioAction_cpp": 0x8021f77c,
		"TMario::demoMain": 0x8021fa78,
		"demoMain": 0x8021fa78,
		"TMario::footDowning": 0x8021fdb8,
		"footDowning": 0x8021fdb8,
		"TMario::electricDamage": 0x8021ff00,
		"electricDamage": 0x8021ff00,
		"TMario::warpOut": 0x80220084,
		"warpOut": 0x80220084,
		"TMario::toroccoStart": 0x80220340,
		"toroccoStart": 0x80220340,
		"TMario::waitingStart": 0x80220404,
		"waitingStart": 0x80220404,
		"TMario::returnStart": 0x80220504,
		"returnStart": 0x80220504,
		"TMario::rollingStart": 0x8022069c,
		"rollingStart": 0x8022069c,
		"TMario::isUnUsualStageStart": 0x802207a0,
		"isUnUsualStageStart": 0x802207a0,
		"TMario::warpIn": 0x80220964,
		"warpIn": 0x80220964,
		"TMario::jumpingDemoCommon": 0x80220e30,
		"jumpingDemoCommon": 0x80220e30,
		"TMario::readBillboard": 0x80220eb8,
		"readBillboard": 0x80220eb8,
		"TMario::winDemo": 0x802210c0,
		"winDemo": 0x802210c0,
		"Player::__sinit_MarioAutodemo_cpp": 0x802211a4,
		"__sinit_MarioAutodemo_cpp": 0x802211a4,
		"M3UModelMario::updateOut": 0x802214a0,
		"M3UModelMario::updateIn": 0x802214e8,
		"M3UModelMario::updateInMotion": 0x8022151c,
		"M3UModelMario::changeMtxCalcSIAnmBQAnmTransform": 0x80221678,
		"changeMtxCalcSIAnmBQAnmTransform": 0x80221678,
		"TMarioCap::mtxEffectHide": 0x802216e4,
		"mtxEffectHide": 0x802216e4,
		"TMarioCap::mtxEffectShow": 0x80221758,
		"mtxEffectShow": 0x80221758,
		"TMarioCap::perform": 0x802217cc,
		"TMarioCap::createMirrorCap": 0x80221e50,
		"createMirrorCap": 0x80221e50,
		"TMarioCap::TMarioCap": 0x80221ed0,
		"TMario::considerTake": 0x80222360,
		"considerTake": 0x80222360,
		"TMario::damageExec": 0x80222554,
		"JGeometry::TVec3<float><float>::operator*=": 0x80222aec,
		"operator*=": 0x80222aec,
		"TMario::calcDamagePos": 0x80222b30,
		"calcDamagePos": 0x80222b30,
		"TMario::loserExec": 0x80222e44,
		"loserExec": 0x80222e44,
		"TMario::normalizeNozzle": 0x80222f94,
		"normalizeNozzle": 0x80222f94,
		"TMario::resetNozzle": 0x80222ffc,
		"resetNozzle": 0x80222ffc,
		"TMario::trampleExec": 0x80223000,
		"trampleExec": 0x80223000,
		"TMario::canTake": 0x80223298,
		"canTake": 0x80223298,
		"TMario::isTakeSituation": 0x802232e4,
		"isTakeSituation": 0x802232e4,
		"TMario::dropObject": 0x802234e4,
		"dropObject": 0x802234e4,
		"TMario::getAttackAngle": 0x80223538,
		"getAttackAngle": 0x80223538,
		"TMario::decHP": 0x80223570,
		"decHP": 0x80223570,
		"TMario::incHP": 0x80223670,
		"incHP": 0x80223670,
		"TMario::rumbleStart": 0x80223788,
		"rumbleStart": 0x80223788,
		"Player::__sinit_MarioCollision_cpp": 0x802237bc,
		"__sinit_MarioCollision_cpp": 0x802237bc,
		"TMario::addDamageFog": 0x80223ab8,
		"addDamageFog": 0x80223ab8,
		"TMario::addDirty": 0x80223db4,
		"addDirty": 0x80223db4,
		"TMario::boxDrawPrepare": 0x80223ed4,
		"boxDrawPrepare": 0x80223ed4,
		"TMario::drawLogic": 0x802240d0,
		"drawLogic": 0x802240d0,
		"TMario::drawSpecial": 0x80224268,
		"drawSpecial": 0x80224268,
		"TMario::entryModels": 0x802242d4,
		"entryModels": 0x802242d4,
		"TMario::calcView": 0x80224408,
		"calcView": 0x80224408,
		"TMario::calcAnim": 0x80224548,
		"TMario::addUpper": 0x80224bbc,
		"addUpper": 0x80224bbc,
		"TMario::setUpperDamageRun": 0x80224d70,
		"setUpperDamageRun": 0x80224d70,
		"TMario::addCallBack": 0x80224e08,
		"addCallBack": 0x80224e08,
		"TMario::calcBaseMtx": 0x80225198,
		"calcBaseMtx": 0x80225198,
		"TMario::considerWaist": 0x80225d18,
		"considerWaist": 0x80225d18,
		"TMario::isUpperPumpingStyle": 0x802260b0,
		"isUpperPumpingStyle": 0x802260b0,
		"TMario::finalDrawInitialize": 0x802260d4,
		"finalDrawInitialize": 0x802260d4,
		"TMario::initMirrorModel": 0x802261a4,
		"initMirrorModel": 0x802261a4,
		"TMario::initModel": 0x802262c0,
		"TMario::loadAnmTexPattern": 0x80227250,
		"loadAnmTexPattern": 0x80227250,
		"TMario::loadBas": 0x802272b4,
		"loadBas": 0x802272b4,
		"TMario::setReverseAnimation": 0x802272fc,
		"setReverseAnimation": 0x802272fc,
		"TMario::setAnimation": 0x802273b8,
		"TMario::changeHand": 0x802276f0,
		"changeHand": 0x802276f0,
		"TMario::isAnimeLoopOrStop": 0x80227af0,
		"isAnimeLoopOrStop": 0x80227af0,
		"TMario::isLast1AnimeFrame": 0x80227b14,
		"isLast1AnimeFrame": 0x80227b14,
		"TMario::getMotionFrameCtrl": 0x80227b64,
		"getMotionFrameCtrl": 0x80227b64,
		"TMario::getCurrentFrame": 0x80227b70,
		"getCurrentFrame": 0x80227b70,
		"TMario::getTakenMtx": 0x80227b88,
		"getTakenMtx": 0x80227b88,
		"TMario::getTakingMtx": 0x80227b98,
		"TMario::getTrampleCt": 0x80227bb4,
		"getTrampleCt": 0x80227bb4,
		"TMario::setPositions": 0x80227bfc,
		"setPositions": 0x80227bfc,
		"TMario::takeOffGlass": 0x80227ca0,
		"takeOffGlass": 0x80227ca0,
		"TMario::wearGlass": 0x80227cec,
		"wearGlass": 0x80227cec,
		"TMario::isWearingHelm": 0x80227d38,
		"isWearingHelm": 0x80227d38,
		"TMario::isWearingCap": 0x80227d68,
		"isWearingCap": 0x80227d68,
		"TMario::setDivHelm": 0x80227d98,
		"setDivHelm": 0x80227d98,
		"TMario::getWallAngle": 0x80227df0,
		"getWallAngle": 0x80227df0,
		"TMario::getPumpFrame": 0x80227e20,
		"getPumpFrame": 0x80227e20,
		"TMario::getCenterAnmMtx": 0x80227e30,
		"getCenterAnmMtx": 0x80227e30,
		"TMario::getRootAnmMtx": 0x80227e4c,
		"getRootAnmMtx": 0x80227e4c,
		"Player::MarioFootDirLCtrl": 0x80227e5c,
		"MarioFootDirLCtrl": 0x80227e5c,
		"Player::MarioFootPosLCtrl": 0x802280ec,
		"MarioFootPosLCtrl": 0x802280ec,
		"Player::MarioFootDirRCtrl": 0x80228224,
		"MarioFootDirRCtrl": 0x80228224,
		"Player::MarioFootPosRCtrl": 0x802284b4,
		"MarioFootPosRCtrl": 0x802284b4,
		"Player::MarioWaistCtrl": 0x802285ec,
		"MarioWaistCtrl": 0x802285ec,
		"Player::MarioHeadCtrl": 0x80228868,
		"MarioHeadCtrl": 0x80228868,
		"TMarioAnimeData::isPumpOK": 0x80228c64,
		"isPumpOK": 0x80228c64,
		"Player::__sinit_MarioDraw_cpp": 0x80228c80,
		"__sinit_MarioDraw_cpp": 0x80228c80,
		"TMario::jumpMain": 0x80228f7c,
		"jumpMain": 0x80228f7c,
		"TMario::diving": 0x80229ffc,
		"diving": 0x80229ffc,
		"TMario::hipAttacking": 0x8022a3f8,
		"hipAttacking": 0x8022a3f8,
		"TMario::rocketing": 0x8022a9b4,
		"rocketing": 0x8022a9b4,
		"TMario::rocketCheck": 0x8022adec,
		"rocketCheck": 0x8022adec,
		"TMario::boardJumping": 0x8022aef0,
		"boardJumping": 0x8022aef0,
		"TMario::thrownDowning": 0x8022b09c,
		"thrownDowning": 0x8022b09c,
		"TMario::fireDowning": 0x8022b264,
		"fireDowning": 0x8022b264,
		"TMario::slipFalling": 0x8022b4cc,
		"slipFalling": 0x8022b4cc,
		"TMario::catchStop": 0x8022b774,
		"catchStop": 0x8022b774,
		"TMario::stayWall": 0x8022b874,
		"stayWall": 0x8022b874,
		"TMario::jumpDownCommon": 0x8022bb5c,
		"jumpDownCommon": 0x8022bb5c,
		"TMario::jumpCatch": 0x8022bc54,
		"jumpCatch": 0x8022bc54,
		"TMario::landing": 0x8022bf20,
		"landing": 0x8022bf20,
		"TMario::checkBackTrig": 0x8022c094,
		"checkBackTrig": 0x8022c094,
		"TMario::considerJumpRotate": 0x8022c130,
		"considerJumpRotate": 0x8022c130,
		"TMario::jumpingBasic": 0x8022c1a4,
		"jumpingBasic": 0x8022c1a4,
		"TMario::doJumping": 0x8022c828,
		"doJumping": 0x8022c828,
		"TMario::startJumpWall": 0x8022cb00,
		"startJumpWall": 0x8022cb00,
		"Player::__sinit_MarioJump_cpp": 0x8022cbd0,
		"__sinit_MarioJump_cpp": 0x8022cbd0,
		"TMario::perform": 0x8022cff8,
		"TMario::isMario": 0x8022d85c,
		"isMario": 0x8022d85c,
		"Player::__sinit_MarioMain_cpp": 0x8022d878,
		"__sinit_MarioMain_cpp": 0x8022d878,
		"TMario::playerControl": 0x8022db88,
		"TYoshi::onYoshi": 0x8022e034,
		"TMario::gunExec": 0x8022e050,
		"gunExec": 0x8022e050,
		"TMario::checkWet": 0x8022e498,
		"checkWet": 0x8022e498,
		"TBGCheckData::isMarioThrough": 0x8022e6a0,
		"isMarioThrough": 0x8022e6a0,
		"TMario::thinkYoshiHeadCollision": 0x8022e6f4,
		"thinkYoshiHeadCollision": 0x8022e6f4,
		"TMario::getOffYoshi": 0x8022e8bc,
		"getOffYoshi": 0x8022e8bc,
		"TMario::thinkParams": 0x8022e994,
		"thinkParams": 0x8022e994,
		"TMario::thinkSand": 0x8022ec98,
		"thinkSand": 0x8022ec98,
		"TMario::thinkWaterSurface": 0x8022ed34,
		"thinkWaterSurface": 0x8022ed34,
		"TMario::thinkSituation": 0x8022f5c0,
		"thinkSituation": 0x8022f5c0,
		"TMario::calcGroundMtx": 0x8022fc34,
		"calcGroundMtx": 0x8022fc34,
		"TMario::stateMachine": 0x8022fdec,
		"stateMachine": 0x8022fdec,
		"TMario::checkPlayerAction": 0x8022fee8,
		"checkPlayerAction": 0x8022fee8,
		"TMario::checkRideReCalc": 0x8022ff54,
		"checkRideReCalc": 0x8022ff54,
		"TMario::checkRideMovement": 0x80230000,
		"checkRideMovement": 0x80230000,
		"TMario::checkCurrentPlane": 0x802302d0,
		"checkCurrentPlane": 0x802302d0,
		"TMario::getDmgMapCode": 0x80230d8c,
		"getDmgMapCode": 0x80230d8c,
		"TMario::checkGroundPlane": 0x80230e04,
		"checkGroundPlane": 0x80230e04,
		"TMario::makeHistory": 0x80230f28,
		"makeHistory": 0x80230f28,
		"TMario::checkStickRotate": 0x80231054,
		"checkStickRotate": 0x80231054,
		"TMario::checkController": 0x802311e4,
		"TMario::checkThrowObject": 0x80231f60,
		"checkThrowObject": 0x80231f60,
		"TMario::checkReturn": 0x80231fb4,
		"TMario::checkEnforceJump": 0x802320d4,
		"checkEnforceJump": 0x802320d4,
		"MSound::startForceJumpSound": 0x8023220c,
		"startForceJumpSound": 0x8023220c,
		"TMario::checkSink": 0x802322ec,
		"checkSink": 0x802322ec,
		"TMario::thinkHeight": 0x80232608,
		"thinkHeight": 0x80232608,
		"TMario::thinkDirty": 0x80232754,
		"thinkDirty": 0x80232754,
		"TMario::dirtyLimitCheck": 0x80232900,
		"dirtyLimitCheck": 0x80232900,
		"TMario::checkGraffito": 0x8023292c,
		"checkGraffito": 0x8023292c,
		"TMario::checkGraffitoElec": 0x80232f74,
		"checkGraffitoElec": 0x80232f74,
		"TMario::checkGraffitoSlip": 0x8023312c,
		"checkGraffitoSlip": 0x8023312c,
		"TMario::checkGraffitoFire": 0x802333b0,
		"checkGraffitoFire": 0x802333b0,
		"TMario::checkAllMotions": 0x80233630,
		"checkAllMotions": 0x80233630,
		"TMario::changePlayerDropping": 0x80233760,
		"changePlayerDropping": 0x80233760,
		"TMario::changePlayerJumping": 0x802337b8,
		"changePlayerJumping": 0x802337b8,
		"TMario::changePlayerTriJump": 0x80233aa4,
		"changePlayerTriJump": 0x80233aa4,
		"TMario::changePlayerStatus": 0x80233d84,
		"changePlayerStatus": 0x80233d84,
		"TMario::throwMario": 0x80233f50,
		"TMario::setStatusToJumping": 0x802340f0,
		"setStatusToJumping": 0x802340f0,
		"TMario::checkPlayerAround": 0x80234c48,
		"checkPlayerAround": 0x80234c48,
		"TMario::getSlideStopCatch": 0x80234cbc,
		"getSlideStopCatch": 0x80234cbc,
		"TMario::getSlideStopNormal": 0x80234e3c,
		"getSlideStopNormal": 0x80234e3c,
		"TMario::canSlipJump": 0x80234fb4,
		"canSlipJump": 0x80234fb4,
		"TMario::isSlipStart": 0x80235150,
		"isSlipStart": 0x80235150,
		"TMario::isFrontSlip": 0x802352c0,
		"isFrontSlip": 0x802352c0,
		"TMario::checkRoofPlane": 0x80235310,
		"checkRoofPlane": 0x80235310,
		"TMario::checkWallPlane": 0x8023534c,
		"checkWallPlane": 0x8023534c,
		"TMario::setPlayerVelocity": 0x80235484,
		"setPlayerVelocity": 0x80235484,
		"TMario::setNormalAttackArea": 0x802354e4,
		"setNormalAttackArea": 0x802354e4,
		"TMario::canBendBody": 0x80235528,
		"canBendBody": 0x80235528,
		"TMario::considerRotateJumpStart": 0x80235568,
		"considerRotateJumpStart": 0x80235568,
		"TMario::addVelocity": 0x802355f4,
		"addVelocity": 0x802355f4,
		"TMario::onYoshi": 0x80235618,
		"TMario::windMove": 0x80235660,
		"windMove": 0x80235660,
		"TMario::flowMove": 0x80235694,
		"flowMove": 0x80235694,
		"TMario::warpRequest": 0x802356ec,
		"warpRequest": 0x802356ec,
		"TMario::moveRequest": 0x802357dc,
		"TMario::isForceSlip": 0x80235a68,
		"isForceSlip": 0x80235a68,
		"TMario::getRidingMtx": 0x80235b10,
		"getRidingMtx": 0x80235b10,
		"TMario::isWallInFront": 0x80235b8c,
		"isWallInFront": 0x80235b8c,
		"TMario::isInvincible": 0x80235bf4,
		"isInvincible": 0x80235bf4,
		"TMario::isUnderWater": 0x80235ca8,
		"isUnderWater": 0x80235ca8,
		"TMario::canSquat": 0x80235cf0,
		"canSquat": 0x80235cf0,
		"TMario::getJumpSlideControl": 0x80235d7c,
		"getJumpSlideControl": 0x80235d7c,
		"TMario::getJumpAccelControl": 0x80235e18,
		"getJumpAccelControl": 0x80235e18,
		"Player::__sinit_MarioMove_cpp": 0x80235e34,
		"__sinit_MarioMove_cpp": 0x80235e34,
		"TMario::jumpProcess": 0x80236130,
		"jumpProcess": 0x80236130,
		"TMario::fallProcess": 0x8023629c,
		"fallProcess": 0x8023629c,
		"TMario::checkGroundAtJumping": 0x802363e4,
		"checkGroundAtJumping": 0x802363e4,
		"TMario::hangonCheck": 0x802369c4,
		"hangonCheck": 0x802369c4,
		"TMario::barProcess": 0x80236bb4,
		"barProcess": 0x80236bb4,
		"TMario::walkProcess": 0x80236e14,
		"walkProcess": 0x80236e14,
		"TMario::waitProcess": 0x80236ed4,
		"waitProcess": 0x80236ed4,
		"TMario::stopProcess": 0x80236ff4,
		"stopProcess": 0x80236ff4,
		"TMario::checkGroundAtWalking": 0x80237044,
		"checkGroundAtWalking": 0x80237044,
		"TMario::checkDescent": 0x802372e0,
		"checkDescent": 0x802372e0,
		"TMario::playerRefrection": 0x802378b0,
		"playerRefrection": 0x802378b0,
		"Player::__sinit_MarioPhysics_cpp": 0x80237948,
		"__sinit_MarioPhysics_cpp": 0x80237948,
		"TMarioInputReplay::reset": 0x80237c44,
		"TMarioInputReplay::play": 0x80237ca4,
		"TMarioInputReplay::init": 0x80237d88,
		"TRecordValueManager<unsigned_char><unsigned_char>::reset": 0x80237e78,
		"TRecordValueManager<unsigned_char><unsigned_char>::get": 0x80237e98,
		"TRecordValueManager<unsigned_short><unsigned_short>::reset": 0x80237ef0,
		"TRecordValueManager<unsigned_short><unsigned_short>::get": 0x80237f10,
		"TRecordValueManager<short><short>::reset": 0x80237f68,
		"TRecordValueManager<short><short>::get": 0x80237f88,
		"TRecordValueManager<float><float>::reset": 0x80237fe0,
		"TRecordValueManager<float><float>::get": 0x80238000,
		"TMario::moveMain": 0x80238058,
		"moveMain": 0x80238058,
		"TMario::jumpSlipEvents": 0x80238a74,
		"jumpSlipEvents": 0x80238a74,
		"TMario::jumpSlipCommon": 0x80238bac,
		"jumpSlipCommon": 0x80238bac,
		"TMario::loserDown": 0x80238ce4,
		"loserDown": 0x80238ce4,
		"TMario::downingCommon": 0x80238e08,
		"downingCommon": 0x80238e08,
		"TMario::oilSlip": 0x80238f58,
		"oilSlip": 0x80238f58,
		"TMario::oilRun": 0x80239188,
		"oilRun": 0x80239188,
		"TMario::catching": 0x8023945c,
		"catching": 0x8023945c,
		"TMario::slipBackCommon": 0x802395b0,
		"slipBackCommon": 0x802395b0,
		"TMario::slipForeCommon": 0x80239690,
		"slipForeCommon": 0x80239690,
		"TMario::slippingBasic": 0x80239758,
		"slippingBasic": 0x80239758,
		"TMario::fireDashing": 0x80239a74,
		"fireDashing": 0x80239a74,
		"TMario::walkEnd": 0x80239bfc,
		"walkEnd": 0x80239bfc,
		"TMario::surfing": 0x80239e44,
		"surfing": 0x80239e44,
		"TMario::turnEnd": 0x8023a124,
		"turnEnd": 0x8023a124,
		"TMario::turnning": 0x8023a388,
		"turnning": 0x8023a388,
		"TMario::rotating": 0x8023a774,
		"rotating": 0x8023a774,
		"TMario::running": 0x8023a89c,
		"running": 0x8023a89c,
		"TMario::doPushingAnimation": 0x8023b02c,
		"doPushingAnimation": 0x8023b02c,
		"TMario::doSurfing": 0x8023b184,
		"doSurfing": 0x8023b184,
		"TMario::getSurfingParamsWater": 0x8023b594,
		"getSurfingParamsWater": 0x8023b594,
		"TMario::doRunning": 0x8023b5c8,
		"doRunning": 0x8023b5c8,
		"TMario::slopeProcess": 0x8023b8b4,
		"slopeProcess": 0x8023b8b4,
		"TMario::doSliding": 0x8023ba28,
		"doSliding": 0x8023ba28,
		"TMario::slideProcess": 0x8023be14,
		"slideProcess": 0x8023be14,
		"TMario::getSlideStickMult": 0x8023c1dc,
		"getSlideStickMult": 0x8023c1dc,
		"TMario::getChangeAngleSpeed": 0x8023c284,
		"getChangeAngleSpeed": 0x8023c284,
		"TMario::getSlopeSlideAccele": 0x8023c438,
		"getSlopeSlideAccele": 0x8023c438,
		"TMario::getSlopeNormalAccele": 0x8023c594,
		"getSlopeNormalAccele": 0x8023c594,
		"TMario::doRunningAnimation": 0x8023c6f0,
		"doRunningAnimation": 0x8023c6f0,
		"TMario::isRunningInWater": 0x8023c9e0,
		"isRunningInWater": 0x8023c9e0,
		"TMario::considerRotateStart": 0x8023ca28,
		"considerRotateStart": 0x8023ca28,
		"Player::__sinit_MarioRun_cpp": 0x8023cab8,
		"__sinit_MarioRun_cpp": 0x8023cab8,
		"TMario::specMain": 0x8023cdb4,
		"specMain": 0x8023cdb4,
		"TMario::fencePunch": 0x8023db80,
		"fencePunch": 0x8023db80,
		"TMario::fenceMove": 0x8023de38,
		"fenceMove": 0x8023de38,
		"TMario::pulling": 0x8023e5f8,
		"pulling": 0x8023e5f8,
		"TMario::getCurrentPullParams": 0x8023eafc,
		"getCurrentPullParams": 0x8023eafc,
		"TMario::wireRolling": 0x8023ebb8,
		"wireRolling": 0x8023ebb8,
		"TMario::wireHanging": 0x8023f2ec,
		"wireHanging": 0x8023f2ec,
		"TMario::changeWireHanging": 0x8023f8e0,
		"changeWireHanging": 0x8023f8e0,
		"TMario::wireSWait": 0x8023f96c,
		"wireSWait": 0x8023f96c,
		"TMario::wireWait": 0x8023fcf8,
		"wireWait": 0x8023fcf8,
		"TMario::wireMove": 0x80240148,
		"wireMove": 0x80240148,
		"TMario::getOnWirePosAngle": 0x80240280,
		"getOnWirePosAngle": 0x80240280,
		"TMario::hanging": 0x80240468,
		"hanging": 0x80240468,
		"TMario::startHangLanding": 0x80240e94,
		"startHangLanding": 0x80240e94,
		"TMario::moveRoof": 0x80240f6c,
		"moveRoof": 0x80240f6c,
		"TMario::roofCommonEvents": 0x802411d0,
		"roofCommonEvents": 0x802411d0,
		"TMario::doRoofMovingProcess": 0x802412d0,
		"doRoofMovingProcess": 0x802412d0,
		"TMario::hangingCheckRoof": 0x80241430,
		"hangingCheckRoof": 0x80241430,
		"TMario::barClimb": 0x802415cc,
		"barClimb": 0x802415cc,
		"TMario::barWait": 0x80241898,
		"barWait": 0x80241898,
		"Player::__sinit_MarioSpecial_cpp": 0x80241cfc,
		"__sinit_MarioSpecial_cpp": 0x80241cfc,
		"TMario::stateMachineUpper": 0x80241ff8,
		"stateMachineUpper": 0x80241ff8,
		"TMario::checkPumpEnable": 0x802421f0,
		"checkPumpEnable": 0x802421f0,
		"TMario::checkPumping": 0x802423c4,
		"checkPumping": 0x802423c4,
		"Player::__sinit_MarioUpper_cpp": 0x802424dc,
		"__sinit_MarioUpper_cpp": 0x802424dc,
		"TMario::askJumpIntoWaterEffectExist": 0x802427d8,
		"askJumpIntoWaterEffectExist": 0x802427d8,
		"TMario::sinkInSandEffect": 0x8024280c,
		"sinkInSandEffect": 0x8024280c,
		"TMario::kickFruitEffect": 0x80242868,
		"kickFruitEffect": 0x80242868,
		"TMario::toroccoEffect": 0x8024290c,
		"toroccoEffect": 0x8024290c,
		"TMario::sleepingEffectKill": 0x80242a2c,
		"sleepingEffectKill": 0x80242a2c,
		"TMario::sleepingEffect": 0x80242a6c,
		"sleepingEffect": 0x80242a6c,
		"TMario::kickRoofEffect": 0x80242aa0,
		"kickRoofEffect": 0x80242aa0,
		"TMario::elecEndEffect": 0x80242b34,
		"elecEndEffect": 0x80242b34,
		"TMario::elecEffect": 0x80242b68,
		"elecEffect": 0x80242b68,
		"TMario::rocketEffectStart": 0x80242bd8,
		"rocketEffectStart": 0x80242bd8,
		"TMario::meltInWaterEffect": 0x80242ca4,
		"meltInWaterEffect": 0x80242ca4,
		"TMario::emitSandEffect": 0x80242d50,
		"emitSandEffect": 0x80242d50,
		"TMario::emitDirtyFootPrint": 0x80242d78,
		"emitDirtyFootPrint": 0x80242d78,
		"TMario::emitFootPrintWithEffect": 0x80242da0,
		"emitFootPrintWithEffect": 0x80242da0,
		"TMario::emitRotateShootEffect": 0x8024303c,
		"emitRotateShootEffect": 0x8024303c,
		"TMario::emitBlurSpinJump": 0x80243094,
		"emitBlurSpinJump": 0x80243094,
		"TMario::emitBlurHipDropSuper": 0x80243148,
		"emitBlurHipDropSuper": 0x80243148,
		"TMario::emitBlurHipDrop": 0x802431ec,
		"emitBlurHipDrop": 0x802431ec,
		"TMario::warpOutEffect": 0x80243230,
		"warpOutEffect": 0x80243230,
		"TMario::warpInLight": 0x802434bc,
		"warpInLight": 0x802434bc,
		"TMario::warpInEffect": 0x802434f0,
		"warpInEffect": 0x802434f0,
		"TWarpInCallBack::execute": 0x8024366c,
		"TMario::surfingEffect": 0x802437f0,
		"surfingEffect": 0x802437f0,
		"TMario::frontSlipEffect": 0x8024399c,
		"frontSlipEffect": 0x8024399c,
		"TMario::treeSlipEffect": 0x80243b10,
		"treeSlipEffect": 0x80243b10,
		"TMario::wallSlipEffect": 0x80243bc0,
		"wallSlipEffect": 0x80243bc0,
		"TMario::blurEffect": 0x80243bf4,
		"blurEffect": 0x80243bf4,
		"TMario::runningRippleEffect": 0x80243c34,
		"runningRippleEffect": 0x80243c34,
		"TMario::swimmingBubbleEffect": 0x80243c8c,
		"swimmingBubbleEffect": 0x80243c8c,
		"TMario::bubbleFromBody": 0x80243d60,
		"bubbleFromBody": 0x80243d60,
		"TMario::bubbleFromMouth": 0x80243e24,
		"bubbleFromMouth": 0x80243e24,
		"TBubbleCallBack::execute": 0x80243e94,
		"TMario::inOutWaterEffect": 0x80243f38,
		"inOutWaterEffect": 0x80243f38,
		"TMario::rippleEffect": 0x802440f0,
		"rippleEffect": 0x802440f0,
		"TMario::smallTouchDownEffect": 0x8024418c,
		"smallTouchDownEffect": 0x8024418c,
		"TMario::strongTouchDownEffect": 0x80244230,
		"strongTouchDownEffect": 0x80244230,
		"TMario::emitGetCoinEffect": 0x802442a0,
		"emitGetCoinEffect": 0x802442a0,
		"TMario::emitGetWaterEffect": 0x802442f8,
		"emitGetWaterEffect": 0x802442f8,
		"TMario::emitGetEffect": 0x8024432c,
		"emitGetEffect": 0x8024432c,
		"TMario::emitSweatSometimes": 0x80244378,
		"emitSweatSometimes": 0x80244378,
		"TMario::emitSweat": 0x802443ac,
		"emitSweat": 0x802443ac,
		"TMario::emitSmoke": 0x80244480,
		"emitSmoke": 0x80244480,
		"TMario::moveParticle": 0x802445d4,
		"moveParticle": 0x802445d4,
		"TMario::initParticle": 0x80244640,
		"Player::__sinit_MarioParticle_cpp": 0x80244718,
		"__sinit_MarioParticle_cpp": 0x80244718,
		"TMario::waitMain": 0x80244a2c,
		"waitMain": 0x80244a2c,
		"TMario::jumpEndEvents": 0x80245304,
		"jumpEndEvents": 0x80245304,
		"TMario::jumpEndCommon": 0x8024537c,
		"jumpEndCommon": 0x8024537c,
		"TMario::squatStandup": 0x802453fc,
		"squatStandup": 0x802453fc,
		"TMario::squating": 0x80245518,
		"squating": 0x80245518,
		"TMario::getSideWalkValues": 0x80245854,
		"getSideWalkValues": 0x80245854,
		"TMario::sleeping": 0x80245924,
		"sleeping": 0x80245924,
		"TMario::sleepily": 0x80245ab8,
		"sleepily": 0x80245ab8,
		"TMario::waiting": 0x80245bd8,
		"waiting": 0x80245bd8,
		"TMario::changeMontemanWaitingAnim": 0x80245e78,
		"changeMontemanWaitingAnim": 0x80245e78,
		"TMario::stopCommon": 0x80245e98,
		"stopCommon": 0x80245e98,
		"TMario::waitingCommonEvents": 0x80245f54,
		"waitingCommonEvents": 0x80245f54,
		"TMario::canPut": 0x80246174,
		"canPut": 0x80246174,
		"TMario::canSleep": 0x80246234,
		"canSleep": 0x80246234,
		"TMario::startTalking": 0x802463f0,
		"startTalking": 0x802463f0,
		"Player::__sinit_MarioWait_cpp": 0x80246478,
		"__sinit_MarioWait_cpp": 0x80246478,
		"TSplashManager::~TSplashManager": 0x80246774,
		"TSplashManager::perform": 0x80246814,
		"TSplashManager::draw": 0x80246894,
		"TSplashManager::makeDL": 0x80246ab4,
		"TSplashManager::move": 0x80246c3c,
		"TSplashManager::newSplash": 0x80246cfc,
		"newSplash": 0x80246cfc,
		"TSplashManager::load": 0x80246da0,
		"Player::__sinit_SplashManager_cpp": 0x80246f38,
		"__sinit_SplashManager_cpp": 0x80246f38,
		"TYoshiTongue::getTakingMtx": 0x802472d0,
		"TYoshiTongue::checkTaking": 0x802472dc,
		"checkTaking": 0x802472dc,
		"TYoshiTongue::checkTaken": 0x802472e0,
		"checkTaken": 0x802472e0,
		"TYoshiTongue::entry": 0x802472e4,
		"TYoshiTongue::viewCalc": 0x80247340,
		"TYoshiTongue::calcAnim": 0x8024739c,
		"TYoshiTongue::movement": 0x80247618,
		"JGeometry::TVec3<float><float>::operator_-=": 0x80247eb8,
		"operator_-=": 0x80247eb8,
		"TYoshiTongue::findTarget": 0x80247eec,
		"findTarget": 0x80247eec,
		"TYoshiTongue::canGo": 0x80248200,
		"canGo": 0x80248200,
		"TYoshiTongue::emit": 0x8024833c,
		"TYoshiTongue::initInLoadAfter": 0x802484d0,
		"TYoshiTongue::init": 0x802485dc,
		"Player::__sinit_Tongue_cpp": 0x802487d0,
		"__sinit_Tongue_cpp": 0x802487d0,
		"TWaterGun::changeBackup": 0x80248ad4,
		"changeBackup": 0x80248ad4,
		"TWaterGun::damage": 0x80248b80,
		"damage": 0x80248b80,
		"TWaterGun::suck": 0x80248bd0,
		"suck": 0x80248bd0,
		"TWaterGun::emit": 0x80248ce8,
		"TWaterGun::triggerPressureMovement": 0x80248f8c,
		"triggerPressureMovement": 0x80248f8c,
		"TWaterGun::rotateProp": 0x80249024,
		"rotateProp": 0x80249024,
		"TWaterGun::getEmitPosDirSpeed": 0x802490d8,
		"getEmitPosDirSpeed": 0x802490d8,
		"TWaterGun::getPressureMax": 0x80249198,
		"getPressureMax": 0x80249198,
		"TWaterGun::getPressure": 0x80249204,
		"getPressure": 0x80249204,
		"TWaterGun::isPressureOn": 0x80249270,
		"isPressureOn": 0x80249270,
		"TWaterGun::setAmountToRate": 0x802492ec,
		"setAmountToRate": 0x802492ec,
		"TWaterGun::getCurrentNozzle": 0x8024935c,
		"getCurrentNozzle": 0x8024935c,
		"TWaterGun::perform": 0x8024946c,
		"TWaterGun::calcAnimation": 0x802495b8,
		"calcAnimation": 0x802495b8,
		"TWaterGun::setBaseTRMtx": 0x80249844,
		"setBaseTRMtx": 0x80249844,
		"TWaterGun::movement": 0x80249930,
		"TWaterGun::changeNozzle": 0x80249eb4,
		"changeNozzle": 0x80249eb4,
		"TWaterGun::getNozzleMtx": 0x80249ff4,
		"getNozzleMtx": 0x80249ff4,
		"TWaterGun::getEmitMtx": 0x8024a010,
		"getEmitMtx": 0x8024a010,
		"TWaterGun::initInLoadAfter": 0x8024a108,
		"TWaterGun::init": 0x8024a10c,
		"TWaterGun::TWaterGun": 0x8024a798,
		"TNozzleDeform::animation": 0x8024ab44,
		"TNozzleDeform::emit": 0x8024b2d0,
		"TNozzleDeform::movement": 0x8024b678,
		"TNozzleTrigger::animation": 0x8024b7a0,
		"TNozzleTrigger::emit": 0x8024bd14,
		"TNozzleTrigger::movement": 0x8024c01c,
		"TNozzleTrigger::init": 0x8024c434,
		"TNozzleBase::animation": 0x8024c454,
		"TNozzleBase::emit": 0x8024c90c,
		"TNozzleBase::emitCommon": 0x8024cbd8,
		"emitCommon": 0x8024cbd8,
		"TNozzleBase::movement": 0x8024cd70,
		"TNozzleBase::calcGunAngle": 0x8024ce38,
		"calcGunAngle": 0x8024ce38,
		"TNozzleBase::init": 0x8024cf6c,
		"TNozzleBase::TNozzleBase": 0x8024cf90,
		"Player::WaterGunDivingCtrlR": 0x8024d790,
		"WaterGunDivingCtrlR": 0x8024d790,
		"Player::WaterGunDivingCtrlL": 0x8024d820,
		"WaterGunDivingCtrlL": 0x8024d820,
		"Player::RotateCtrl": 0x8024d8b0,
		"RotateCtrl": 0x8024d8b0,
		"Player::NozzleCtrl": 0x8024d934,
		"NozzleCtrl": 0x8024d934,
		"TNozzleBase::getWaistAngle": 0x8024d9e0,
		"getWaistAngle": 0x8024d9e0,
		"TNozzleDeform::getNozzleKind": 0x8024d9e8,
		"Player::__sinit_WaterGun_cpp": 0x8024d9f0,
		"__sinit_WaterGun_cpp": 0x8024d9f0,
		"TYoshi::entry": 0x8024dcec,
		"TYoshi::viewCalc": 0x8024e00c,
		"TYoshi::calcAnim": 0x8024e08c,
		"TYoshi::movement": 0x8024e4c8,
		"TYoshi::thinkHoldOut": 0x8024f1fc,
		"thinkHoldOut": 0x8024f1fc,
		"TYoshi::doEat": 0x8024f35c,
		"doEat": 0x8024f35c,
		"TYoshi::doSearch": 0x8024f480,
		"doSearch": 0x8024f480,
		"TYoshi::thinkUpper": 0x8024f9e0,
		"thinkUpper": 0x8024f9e0,
		"TYoshi::thinkAnimation": 0x8024fb88,
		"thinkAnimation": 0x8024fb88,
		"TYoshi::getOff": 0x8024ff7c,
		"getOff": 0x8024ff7c,
		"TYoshi::ride": 0x80250138,
		"ride": 0x80250138,
		"TYoshi::kill": 0x80250228,
		"TYoshi::disappear": 0x80250340,
		"disappear": 0x80250340,
		"TYoshi::appearFromEgg": 0x80250454,
		"appearFromEgg": 0x80250454,
		"TYoshi::setEggYoshiPtr": 0x802505dc,
		"setEggYoshiPtr": 0x802505dc,
		"TYoshi::getEmitPosDir": 0x802505e4,
		"getEmitPosDir": 0x802505e4,
		"TYoshi::changeAnimation": 0x80250630,
		"changeAnimation": 0x80250630,
		"TYoshi::thinkBtp": 0x802506cc,
		"thinkBtp": 0x802506cc,
		"TYoshi::initInLoadAfter": 0x8025077c,
		"TYoshi::init": 0x80250850,
		"TYoshi::getMtxPtrFootR": 0x802512f4,
		"getMtxPtrFootR": 0x802512f4,
		"TYoshi::getMtxPtrFootL": 0x80251310,
		"getMtxPtrFootL": 0x80251310,
		"TYoshi::getFrameCtrl": 0x8025132c,
		"Player::YoshiHeadCtrl": 0x80251354,
		"YoshiHeadCtrl": 0x80251354,
		"Player::__sinit_Yoshi_cpp": 0x802513e0,
		"__sinit_Yoshi_cpp": 0x802513e0,
		"TMarioEffect::perform": 0x80251760,
		"TMarioEffect::setJumpIntoWaterEffectSmall": 0x80251a40,
		"setJumpIntoWaterEffectSmall": 0x80251a40,
		"TMarioEffect::setJumpIntoWaterEffect": 0x80251bdc,
		"setJumpIntoWaterEffect": 0x80251bdc,
		"TMarioEffect::init": 0x80251e14,
		"Player::__sinit_MarioEffect_cpp": 0x80252024,
		"__sinit_MarioEffect_cpp": 0x80252024,
		"TMario::swimMain": 0x80252328,
		"swimMain": 0x80252328,
		"TMario::swimPaddle": 0x80252a20,
		"swimPaddle": 0x80252a20,
		"TMario::checkSwimJump": 0x80252b50,
		"checkSwimJump": 0x80252b50,
		"TMario::doSwimming": 0x80252cc0,
		"doSwimming": 0x80252cc0,
		"Player::__sinit_MarioSwim_cpp": 0x80253044,
		"__sinit_MarioSwim_cpp": 0x80253044,
		"Player::SMS_IsMarioRoofing": 0x80253340,
		"SMS_IsMarioRoofing": 0x80253340,
		"Player::SMS_IsMarioFencing": 0x8025336c,
		"SMS_IsMarioFencing": 0x8025336c,
		"Player::SMS_GetMarioRfPlane": 0x802533a0,
		"SMS_GetMarioRfPlane": 0x802533a0,
		"Player::SMS_GetMarioWlPlane": 0x802533ac,
		"SMS_GetMarioWlPlane": 0x802533ac,
		"Player::SMS_GetMarioGrPlane": 0x802533b8,
		"SMS_GetMarioGrPlane": 0x802533b8,
		"Player::SMS_WindMoveMario": 0x802533d0,
		"SMS_WindMoveMario": 0x802533d0,
		"Player::SMS_FlowMoveMario": 0x802533f8,
		"SMS_FlowMoveMario": 0x802533f8,
		"Player::SMS_MarioWarpRequest": 0x80253420,
		"SMS_MarioWarpRequest": 0x80253420,
		"Player::SMS_MarioMoveRequest": 0x80253448,
		"SMS_MarioMoveRequest": 0x80253448,
		"Player::SMS_IsMarioDashing": 0x8025347c,
		"SMS_IsMarioDashing": 0x8025347c,
		"Player::SMS_IsMarioOnYoshi": 0x802534b0,
		"SMS_IsMarioOnYoshi": 0x802534b0,
		"Player::SMS_IsMarioOpeningDoor": 0x802534e4,
		"SMS_IsMarioOpeningDoor": 0x802534e4,
		"Player::SMS_IsMarioOnWire": 0x8025350c,
		"SMS_IsMarioOnWire": 0x8025350c,
		"Player::SMS_IsMarioTouchGround4cm": 0x80253554,
		"SMS_IsMarioTouchGround4cm": 0x80253554,
		"Player::SMS_ThrowMario": 0x80253598,
		"SMS_ThrowMario": 0x80253598,
		"Player::SMS_SendMessageToMario": 0x802535c0,
		"SMS_SendMessageToMario": 0x802535c0,
		"Player::SMS_GetMarioWaterGun": 0x80253610,
		"SMS_GetMarioWaterGun": 0x80253610,
		"Player::SMS_GetMarioGravity": 0x8025361c,
		"SMS_GetMarioGravity": 0x8025361c,
		"Player::SMS_GetMarioGrLevel": 0x80253628,
		"SMS_GetMarioGrLevel": 0x80253628,
		"Player::SMS_GetMarioDamageRadius": 0x80253634,
		"SMS_GetMarioDamageRadius": 0x80253634,
		"Player::SMS_GetMarioHP": 0x80253640,
		"SMS_GetMarioHP": 0x80253640,
		"Player::SMS_IsMarioHeadSlideAttack": 0x8025364c,
		"SMS_IsMarioHeadSlideAttack": 0x8025364c,
		"Player::SMS_IsMarioStatusElecDamage": 0x80253678,
		"SMS_IsMarioStatusElecDamage": 0x80253678,
		"Player::SMS_IsMarioStatusThrownDown": 0x8025369c,
		"SMS_IsMarioStatusThrownDown": 0x8025369c,
		"Player::SMS_IsMarioStatusHipDrop": 0x802536c0,
		"SMS_IsMarioStatusHipDrop": 0x802536c0,
		"Player::SMS_IsMarioStatusTypeSwimming": 0x802536e4,
		"SMS_IsMarioStatusTypeSwimming": 0x802536e4,
		"Player::SMS_IsMarioStatusTypeJumping": 0x80253704,
		"SMS_IsMarioStatusTypeJumping": 0x80253704,
		"Player::SMS_GetMarioHitActor": 0x80253724,
		"SMS_GetMarioHitActor": 0x80253724,
		"Player::SMS_AskJumpIntoWaterEffectExist": 0x8025372c,
		"SMS_AskJumpIntoWaterEffectExist": 0x8025372c,
		"Player::SMS_GetYoshi": 0x80253750,
		"SMS_GetYoshi": 0x80253750,
		"Player::SMS_SetMarioAccessParams": 0x8025375c,
		"SMS_SetMarioAccessParams": 0x8025375c,
		"TMario::TSurfingParams::TSurfingParams": 0x802537c0,
		"TMario::TDirtyParams::TDirtyParams": 0x80253c1c,
		"TMario::TGraffitoParams::TGraffitoParams": 0x802540a0,
		"TMario::TWireParams::TWireParams": 0x802544a4,
		"TMario::TSwimParams::TSwimParams": 0x802547d0,
		"TMario::TRunParams::TRunParams": 0x80254d38,
		"TMario::TJumpParams::TJumpParams": 0x8025515c,
		"TMario::TDeParams::TDeParams": 0x802559b4,
		"TMario::setGamePad": 0x8025633c,
		"setGamePad": 0x8025633c,
		"TMario::resetHistory": 0x80256344,
		"resetHistory": 0x80256344,
		"TMario::initValues": 0x80256400,
		"TMario::loadAfter": 0x8025682c,
		"TMario::load": 0x80256920,
		"TMario::TMario": 0x80256a04,
		"Player::__sinit_MarioInit_cpp": 0x8025b874,
		"__sinit_MarioInit_cpp": 0x8025b874,
		"TModelWaterManager::~TModelWaterManager": 0x8025bb8c,
		"TModelWaterManager::perform": 0x8025bc00,
		"TModelWaterManager::drawRefracAndSpec": 0x8025be7c,
		"drawRefracAndSpec": 0x8025be7c,
		"TModelWaterManager::drawShineShadowVolume": 0x8025c3cc,
		"drawShineShadowVolume": 0x8025c3cc,
		"TModelWaterManager::drawMirror": 0x8025c97c,
		"drawMirror": 0x8025c97c,
		"TModelWaterManager::drawWaterVolume": 0x8025d168,
		"drawWaterVolume": 0x8025d168,
		"TModelWaterManager::drawSilhouette": 0x8025da50,
		"drawSilhouette": 0x8025da50,
		"TModelWaterManager::drawTouching": 0x8025de3c,
		"drawTouching": 0x8025de3c,
		"TModelWaterManager::calcVMAll": 0x8025df6c,
		"calcVMAll": 0x8025df6c,
		"TModelWaterManager::calcVMMtxWall": 0x8025e0f4,
		"calcVMMtxWall": 0x8025e0f4,
		"TModelWaterManager::calcVMMtxGround": 0x8025e208,
		"calcVMMtxGround": 0x8025e208,
		"TModelWaterManager::calcDrawVtx": 0x8025e344,
		"calcDrawVtx": 0x8025e344,
		"TModelWaterManager::calcWorldMinMax": 0x8025e630,
		"calcWorldMinMax": 0x8025e630,
		"TModelWaterManager::move": 0x8025e798,
		"TBGCheckData::isWaterSlip": 0x8025f7ec,
		"isWaterSlip": 0x8025f7ec,
		"TModelWaterManager::garbageCollect": 0x8025f820,
		"garbageCollect": 0x8025f820,
		"TModelWaterManager::wind": 0x8025f938,
		"wind": 0x8025f938,
		"TModelWaterManager::askDoWaterHitCheck": 0x8025f9ac,
		"askDoWaterHitCheck": 0x8025f9ac,
		"TModelWaterManager::emitRequest": 0x8025f9d4,
		"emitRequest": 0x8025f9d4,
		"TModelWaterManager::makeEmit": 0x8025fa78,
		"makeEmit": 0x8025fa78,
		"TModelWaterManager::askHitWaterParticleOnGround": 0x8025fd44,
		"askHitWaterParticleOnGround": 0x8025fd44,
		"TModelWaterManager::loadAfter": 0x8025fdd8,
		"TModelWaterManager::load": 0x8025fed4,
		"TWaterEmitInfo::TWaterEmitInfo": 0x80260444,
		"Player::__sinit_ModelWaterManager_cpp": 0x8026082c,
		"__sinit_ModelWaterManager_cpp": 0x8026082c,
		"TMarioPositionObj::~TMarioPositionObj": 0x80260b6c,
		"TMarioPositionObj::perform": 0x80260be0,
		"TMarioPositionObj::load": 0x80260be4,
		"TMario::checkCollision": 0x80260d38,
		"checkCollision": 0x80260d38,
		"TMario::hangPole": 0x802620a4,
		"hangPole": 0x802620a4,
		"TMario::hitNormal": 0x80262338,
		"hitNormal": 0x80262338,
		"Player::__sinit_MarioCheckCol_cpp": 0x80262548,
		"__sinit_MarioCheckCol_cpp": 0x80262548,
		"TMario::receiveMessage": 0x80262844,
		"TMario::getGesso": 0x80264b08,
		"getGesso": 0x80264b08,
		"Player::__sinit_MarioReceiveMsg_cpp": 0x80264c2c,
		"__sinit_MarioReceiveMsg_cpp": 0x80264c2c,
		"TMarioSoundValues::TMarioSoundValues": 0x80264f28,
		"TMario::startSoundActor": 0x80264f7c,
		"TMario::stopVoice": 0x80264fe0,
		"stopVoice": 0x80264fe0,
		"TMario::startVoiceIfNoVoice": 0x80265028,
		"startVoiceIfNoVoice": 0x80265028,
		"TMario::startVoice": 0x802650cc,
		"startVoice": 0x802650cc,
		"TMario::getVoiceStatus": 0x80265148,
		"getVoiceStatus": 0x80265148,
		"TMario::soundTorocco": 0x802651b4,
		"soundTorocco": 0x802651b4,
		"TMario::animSound": 0x802652a8,
		"animSound": 0x802652a8,
		"TMario::soundMovement": 0x8026558c,
		"soundMovement": 0x8026558c,
		"Player::__sinit_MarioSound_cpp": 0x80267098,
		"__sinit_MarioSound_cpp": 0x80267098,
		"TBaseNPC::monteMESetAnmWhenNear": 0x801e21cc,
		"monteMESetAnmWhenNear": 0x801e21cc,
		"TBaseNPC::monteMESetAnmWhenFar": 0x801e23f0,
		"monteMESetAnmWhenFar": 0x801e23f0,
		"TBaseNPC::sunflowerReviving": 0x801e2610,
		"sunflowerReviving": 0x801e2610,
		"TBaseNPC::sunflowerReviveIn": 0x801e26dc,
		"sunflowerReviveIn": 0x801e26dc,
		"TBaseNPC::sunflowerDownIn_": 0x801e27b8,
		"sunflowerDownIn_": 0x801e27b8,
		"TBaseNPC::peachTiredIn_": 0x801e27f4,
		"peachTiredIn_": 0x801e27f4,
		"TBaseNPC::peachParasolOut_": 0x801e28b0,
		"peachParasolOut_": 0x801e28b0,
		"TBaseNPC::peachParasolIn_": 0x801e28e0,
		"peachParasolIn_": 0x801e28e0,
		"TBaseNPC::npcMareStanding": 0x801e2910,
		"npcMareStanding": 0x801e2910,
		"TBaseNPC::npcMareStandIn": 0x801e2a6c,
		"npcMareStandIn": 0x801e2a6c,
		"TBaseNPC::npcBlowning": 0x801e2bc0,
		"npcBlowning": 0x801e2bc0,
		"TBaseNPC::npcBlownIn": 0x801e2bec,
		"npcBlownIn": 0x801e2bec,
		"TBaseNPC::npcMadding": 0x801e2cc8,
		"npcMadding": 0x801e2cc8,
		"TBaseNPC::npcMadIn": 0x801e2f90,
		"npcMadIn": 0x801e2f90,
		"TBaseNPC::npcThrowing": 0x801e309c,
		"npcThrowing": 0x801e309c,
		"TBaseNPC::npcThrowIn": 0x801e314c,
		"npcThrowIn": 0x801e314c,
		"TBaseNPC::npcSinking": 0x801e3220,
		"npcSinking": 0x801e3220,
		"TBaseNPC::npcWetting": 0x801e3364,
		"npcWetting": 0x801e3364,
		"TBaseNPC::npcWetIn": 0x801e3fcc,
		"npcWetIn": 0x801e3fcc,
		"TBaseNPC::npcHappyIn": 0x801e42c4,
		"npcHappyIn": 0x801e42c4,
		"TBaseNPC::npcDanceIn": 0x801e43a8,
		"npcDanceIn": 0x801e43a8,
		"TBaseNPC::npcTakenIn": 0x801e4488,
		"npcTakenIn": 0x801e4488,
		"TBaseNPC::npcTalkOut": 0x801e455c,
		"npcTalkOut": 0x801e455c,
		"TBaseNPC::npcTalking": 0x801e4728,
		"npcTalking": 0x801e4728,
		"TBaseNPC::npcTalkIn": 0x801e48c8,
		"npcTalkIn": 0x801e48c8,
		"TBaseNPC::npcStepIn": 0x801e4a5c,
		"npcStepIn": 0x801e4a5c,
		"TBaseNPC::npcRecoverAfterIn": 0x801e4b30,
		"npcRecoverAfterIn": 0x801e4b30,
		"TBaseNPC::npcRecoverFromSinking": 0x801e4c04,
		"npcRecoverFromSinking": 0x801e4c04,
		"TBaseNPC::npcFallIn": 0x801e4de4,
		"npcFallIn": 0x801e4de4,
		"TBaseNPC::npcWaitIn": 0x801e4eb8,
		"npcWaitIn": 0x801e4eb8,
		"TBaseNPC::getNpcWaitAnmBase_": 0x801e5090,
		"getNpcWaitAnmBase_": 0x801e5090,
		"TBaseNPC::walkAnmRateChange_": 0x801e50f8,
		"walkAnmRateChange_": 0x801e50f8,
		"TBaseNPC::randomizeBckAndBtpFrame_": 0x801e5524,
		"randomizeBckAndBtpFrame_": 0x801e5524,
		"TBaseNPC::requestTalkAnm_": 0x801e567c,
		"requestTalkAnm_": 0x801e567c,
		"TBaseNPC::setKeepAnm_": 0x801e5748,
		"setKeepAnm_": 0x801e5748,
		"TBaseNPC::requestNpcAnm_": 0x801e57a0,
		"requestNpcAnm_": 0x801e57a0,
		"TBaseNPC::setNpcAnm_": 0x801e5840,
		"setNpcAnm_": 0x801e5840,
		"NPC::CLBPalFrame": 0x801e5cb4,
		"NPC::__sinit_NpcAnm_cpp": 0x801e5d40,
		"__sinit_NpcAnm_cpp": 0x801e5d40,
		"TBaseNPC::getPtrInitPollutionColor": 0x801e60a8,
		"getPtrInitPollutionColor": 0x801e60a8,
		"TBaseNPC::setBalloonMessage": 0x801e61e0,
		"setBalloonMessage": 0x801e61e0,
		"TBaseNPC::setDummyConnectActor": 0x801e6204,
		"setDummyConnectActor": 0x801e6204,
		"TBaseNPC::perform": 0x801e6254,
		"TBaseNPC::getAnmOffDist_": 0x801e6a3c,
		"getAnmOffDist_": 0x801e6a3c,
		"TBaseNPC::updateForbidCount_": 0x801e6b40,
		"updateForbidCount_": 0x801e6b40,
		"TBaseNPC::calcRootMatrix": 0x801e6b80,
		"TBaseNPC::execMotionBlend_": 0x801e6ca8,
		"execMotionBlend_": 0x801e6ca8,
		"TBaseNPC::moveObject": 0x801e6d3c,
		"TBaseNPC::receiveMessage": 0x801e71a0,
		"TBaseNPC::getFocalPoint": 0x801e73bc,
		"TBaseNPC::getCursorPos": 0x801e73f0,
		"getCursorPos": 0x801e73f0,
		"TBaseNPC::isInMadSearchRange": 0x801e7424,
		"isInMadSearchRange": 0x801e7424,
		"TBaseNPC::isInBodyTurnSearchRange": 0x801e7490,
		"isInBodyTurnSearchRange": 0x801e7490,
		"TBaseNPC::isNeedNeckStraight": 0x801e74fc,
		"isNeedNeckStraight": 0x801e74fc,
		"TBaseNPC::isPartsAnmNpc": 0x801e764c,
		"isPartsAnmNpc": 0x801e764c,
		"TBaseNPC::isBehaveToWaterNpc": 0x801e76c8,
		"isBehaveToWaterNpc": 0x801e76c8,
		"TBaseNPC::isMadNpc": 0x801e7700,
		"isMadNpc": 0x801e7700,
		"TBaseNPC::isBeTrampledNpc": 0x801e77d4,
		"isBeTrampledNpc": 0x801e77d4,
		"TBaseNPC::isPollutionNpc": 0x801e797c,
		"isPollutionNpc": 0x801e797c,
		"TBaseNPC::isSmallNpc": 0x801e79b4,
		"isSmallNpc": 0x801e79b4,
		"TBaseNPC::isChild": 0x801e7aec,
		"isChild": 0x801e7aec,
		"TBaseNPC::isSunflower": 0x801e7b24,
		"isSunflower": 0x801e7b24,
		"TBaseNPC::isJellyFishMare": 0x801e7b50,
		"isJellyFishMare": 0x801e7b50,
		"TBaseNPC::isSpecialMareW": 0x801e7b80,
		"isSpecialMareW": 0x801e7b80,
		"TBaseNPC::isSpecialMareM": 0x801e7bac,
		"isSpecialMareM": 0x801e7bac,
		"TBaseNPC::isNormalMareW": 0x801e7bd8,
		"isNormalMareW": 0x801e7bd8,
		"TBaseNPC::isNormalMareM": 0x801e7bf8,
		"isNormalMareM": 0x801e7bf8,
		"TBaseNPC::isSpecialMonteW": 0x801e7c18,
		"isSpecialMonteW": 0x801e7c18,
		"TBaseNPC::isSpecialMonteM": 0x801e7c38,
		"isSpecialMonteM": 0x801e7c38,
		"TBaseNPC::isNormalMonteW": 0x801e7c64,
		"isNormalMonteW": 0x801e7c64,
		"TBaseNPC::isNormalMonteM": 0x801e7c90,
		"isNormalMonteM": 0x801e7c90,
		"TBaseNPC::loadAfter": 0x801e7cbc,
		"TBaseNPC::load": 0x801e7d44,
		"TBaseNPC::TBaseNPC": 0x801e7e20,
		"NPC::__sinit_NpcBase_cpp": 0x801e8124,
		"__sinit_NpcBase_cpp": 0x801e8124,
		"NPC::NPCNeckCallBack": 0x801e8428,
		"NPCNeckCallBack": 0x801e8428,
		"NPC::CLBEaseOutInbetween": 0x801e8850,
		"NPC::CLBTwoDegreeGeneralInbetween": 0x801e8898,
		"NPC::CLBPalIntSpeed": 0x801e89d8,
		"CLBPalIntSpeed": 0x801e89d8,
		"TSunflowerSManager::~TSunflowerSManager": 0x801e8a2c,
		"TSunflowerSManager::createModelData": 0x801e8aa0,
		"TSunflowerLManager::createModelData": 0x801e8ad4,
		"TRaccoonDogManager::createModelData": 0x801e8b08,
		"TPeachManager::createModelData": 0x801e8b3c,
		"TKinojiiManager::createModelData": 0x801e8b70,
		"TKinopioManager::createModelData": 0x801e8ba4,
		"TMareWBaseManager::createModelData": 0x801e8c14,
		"TMareMBaseManager::createModelData": 0x801e8c80,
		"TMonteWCManager::createModelData": 0x801e8cec,
		"TMonteWBManager::createModelData": 0x801e8d54,
		"TMonteWAManager::createModelData": 0x801e8dc0,
		"TMonteWManager::createModelData": 0x801e8e64,
		"TMonteMHManager::createModelData": 0x801e8f08,
		"TMonteMGManager::createModelData": 0x801e8f70,
		"TMonteMFManager::createModelData": 0x801e8fd8,
		"TMonteMEManager::createModelData": 0x801e9040,
		"TMonteMDManager::createModelData": 0x801e9074,
		"TMonteMCManager::createModelData": 0x801e90e0,
		"TMonteMBManager::createModelData": 0x801e9184,
		"TMonteMAManager::createModelData": 0x801e91f0,
		"TMonteMManager::createModelData": 0x801e9294,
		"TSunflowerLManager::load": 0x801e9338,
		"TRaccoonDogManager::load": 0x801e9374,
		"TPeachManager::load": 0x801e93e8,
		"TKinojiiManager::load": 0x801e945c,
		"TKinopioManager::load": 0x801e94d0,
		"TMareWBManager::load": 0x801e9544,
		"TMareWAManager::load": 0x801e95b8,
		"TMareMDManager::load": 0x801e962c,
		"TMareMCManager::load": 0x801e96a0,
		"TMareMBManager::load": 0x801e9714,
		"TMareMAManager::load": 0x801e9788,
		"TMonteWCManager::load": 0x801e97fc,
		"TMonteMHManager::load": 0x801e9870,
		"TMonteMGManager::load": 0x801e98e4,
		"TMonteMFManager::load": 0x801e9958,
		"TMonteWSpecialManager::createAnmData": 0x801e99cc,
		"TMonteMSpecialManager::createAnmData": 0x801e99ec,
		"TMonteWBaseManager::createAnmData": 0x801e9a0c,
		"TMonteMBaseManager::createAnmData": 0x801e9a68,
		"TMareBaseManager::getBmt_": 0x801e9ac4,
		"TMareWBaseManager::TMareWBaseManager": 0x801e9b40,
		"TMareBaseManager::~TMareBaseManager": 0x801e9c34,
		"TMareMBaseManager::TMareMBaseManager": 0x801e9ca8,
		"TMonteWBaseManager::TMonteWBaseManager": 0x801e9d9c,
		"TMonteMBaseManager::TMonteMBaseManager": 0x801e9e40,
		"TNPCManager::perform": 0x801e9ee4,
		"TNPCManager::clipEnemies": 0x801ea050,
		"TNPCManager::getPartsSDLModelData": 0x801ea210,
		"getPartsSDLModelData": 0x801ea210,
		"TNPCManager::getBmt_": 0x801ea284,
		"TNPCManager::makePartsModelData_": 0x801ea28c,
		"makePartsModelData_": 0x801ea28c,
		"TNPCManager::load": 0x801ea3dc,
		"TNPCManager::TNPCManager": 0x801ea410,
		"TMareJellyFishManager::createModelData": 0x801ea530,
		"TMareJellyFishManager::perform": 0x801ea60c,
		"TMareJellyFishManager::TMareJellyFishManager": 0x801ea610,
		"TBoardNpcManager::createModelData": 0x801ea6c4,
		"TBoardNpcManager::clipActors": 0x801ea6f8,
		"TMonteWBManager::~TMonteWBManager": 0x801ea82c,
		"TMonteWAManager::~TMonteWAManager": 0x801ea8b0,
		"TMonteWManager::~TMonteWManager": 0x801ea934,
		"TMonteMEManager::~TMonteMEManager": 0x801ea9b8,
		"TMonteMDManager::~TMonteMDManager": 0x801eaa4c,
		"TMonteMCManager::~TMonteMCManager": 0x801eaad0,
		"TMonteMBManager::~TMonteMBManager": 0x801eab54,
		"TMonteMAManager::~TMonteMAManager": 0x801eabd8,
		"TMonteMManager::~TMonteMManager": 0x801eac5c,
		"TSunflowerLManager::~TSunflowerLManager": 0x801eace0,
		"TRaccoonDogManager::~TRaccoonDogManager": 0x801ead54,
		"TPeachManager::~TPeachManager": 0x801eadc8,
		"TKinojiiManager::~TKinojiiManager": 0x801eae3c,
		"TKinopioManager::~TKinopioManager": 0x801eaeb0,
		"TMareWBManager::~TMareWBManager": 0x801eaf24,
		"TMareWAManager::~TMareWAManager": 0x801eafb8,
		"TMareMDManager::~TMareMDManager": 0x801eb04c,
		"TMareMCManager::~TMareMCManager": 0x801eb0e0,
		"TMareMBManager::~TMareMBManager": 0x801eb174,
		"TMareMAManager::~TMareMAManager": 0x801eb208,
		"TMonteWCManager::~TMonteWCManager": 0x801eb29c,
		"TMonteMHManager::~TMonteMHManager": 0x801eb330,
		"TMonteMGManager::~TMonteMGManager": 0x801eb3c4,
		"TMonteMFManager::~TMonteMFManager": 0x801eb458,
		"TMareJellyFishManager::~TMareJellyFishManager": 0x801eb6dc,
		"TBoardNpcManager::~TBoardNpcManager": 0x801eb760,
		"TNerveNPCMareStand::~TNerveNPCMareStand": 0x801eb7f4,
		"TNerveNPCMareStand::execute": 0x801eb850,
		"TNerveNPCMareStand::theNerve": 0x801eb8a8,
		"TNerveNPCBlown::execute": 0x801eb90c,
		"TNerveNPCBlown::theNerve": 0x801eba20,
		"TNerveNPCBlown::~TNerveNPCBlown": 0x801eba84,
		"TNerveNPCMad::execute": 0x801ebae0,
		"TNerveNPCMad::theNerve": 0x801ebb38,
		"TNerveNPCMad::~TNerveNPCMad": 0x801ebb9c,
		"TNerveNPCThrow::execute": 0x801ebbf8,
		"TNerveNPCThrow::theNerve": 0x801ebc50,
		"TNerveNPCThrow::~TNerveNPCThrow": 0x801ebcb4,
		"TNerveNPCTalk::execute": 0x801ebd10,
		"TNerveNPCTalk::theNerve": 0x801ebdc0,
		"TNerveNPCTalk::~TNerveNPCTalk": 0x801ebe24,
		"TNerveNPCSetPosAfterSinkBottom::execute": 0x801ebe80,
		"TNerveNPCSetPosAfterSinkBottom::theNerve": 0x801ebea8,
		"TNerveNPCSetPosAfterSinkBottom::~TNerveNPCSetPosAfterSinkBottom": 0x801ebf0c,
		"TNerveNPCRecoverAfter::execute": 0x801ebf68,
		"TNerveNPCRecoverAfter::theNerve": 0x801ebfd4,
		"TNerveNPCRecoverAfter::~TNerveNPCRecoverAfter": 0x801ec038,
		"TNerveNPCRecoverFromSink::execute": 0x801ec094,
		"TNerveNPCRecoverFromSink::theNerve": 0x801ec150,
		"TNerveNPCRecoverFromSink::~TNerveNPCRecoverFromSink": 0x801ec1b4,
		"TNerveNPCSink::execute": 0x801ec210,
		"TNerveNPCSink::theNerve": 0x801ec238,
		"TNerveNPCSink::~TNerveNPCSink": 0x801ec29c,
		"TNerveNPCWet::execute": 0x801ec2f8,
		"TNerveNPCWet::theNerve": 0x801ec350,
		"TNerveNPCWet::~TNerveNPCWet": 0x801ec3b4,
		"TNerveNPCTurnToMario::execute": 0x801ec410,
		"TNerveNPCWaitMarioApproach::~TNerveNPCWaitMarioApproach": 0x801ec778,
		"TNerveNPCTurnToMario::theNerve": 0x801ec7d4,
		"TNerveNPCTurnToMario::~TNerveNPCTurnToMario": 0x801ec838,
		"TNerveNPCWaitMarioApproach::execute": 0x801ec894,
		"TNerveNPCWaitMarioApproach::theNerve": 0x801eca58,
		"TNerveNPCWaitContinue::execute": 0x801ecabc,
		"TNerveNPCWaitContinue::theNerve": 0x801ecb04,
		"TNerveNPCWaitContinue::~TNerveNPCWaitContinue": 0x801ecb68,
		"TNerveNPCGraphWait::execute": 0x801ecbc4,
		"TNerveNPCGraphWander::~TNerveNPCGraphWander": 0x801ecd44,
		"TNerveNPCGraphWait::theNerve": 0x801ecda0,
		"TNerveNPCGraphWait::~TNerveNPCGraphWait": 0x801ece04,
		"TNerveNPCUTurn::execute": 0x801ece60,
		"TNerveNPCUTurn::theNerve": 0x801ecf3c,
		"TNerveNPCUTurn::~TNerveNPCUTurn": 0x801ecfa0,
		"TNerveNPCGraphWander::execute": 0x801ecffc,
		"TGraphTracer::getCurGraphIndex": 0x801ed3b0,
		"getCurGraphIndex": 0x801ed3b0,
		"TNerveNPCGraphWander::theNerve": 0x801ed3b8,
		"TNpcParams::TNpcParams": 0x801ed41c,
		"TNpcSaveIndividual::TNpcSaveIndividual": 0x801ed53c,
		"TNpcSaveNormal::TNpcSaveNormal": 0x801edd70,
		"TNpcSaveStageFarClip::TNpcSaveStageFarClip": 0x801ee36c,
		"TNpcEvent::reviveOneSunflower": 0x801ee620,
		"reviveOneSunflower": 0x801ee620,
		"NPC::ReviveSunflowerCallBack": 0x801ee774,
		"ReviveSunflowerCallBack": 0x801ee774,
		"TNpcEvent::initDownSunflowerNum": 0x801ee7fc,
		"initDownSunflowerNum": 0x801ee7fc,
		"TNpcEvent::initNpcBuiltin": 0x801ee844,
		"initNpcBuiltin": 0x801ee844,
		"NPC::evCheckMonteClear": 0x801ee9f4,
		"evCheckMonteClear": 0x801ee9f4,
		"NPC::evIsDemoMode": 0x801eeba4,
		"evIsDemoMode": 0x801eeba4,
		"NPC::evFireStartDemoCamera": 0x801eec64,
		"evFireStartDemoCamera": 0x801eec64,
		"NPC::evSetFruitType": 0x801eedb4,
		"evSetFruitType": 0x801eedb4,
		"NPC::evGetFruitNum": 0x801ef094,
		"evGetFruitNum": 0x801ef094,
		"NPC::evResetFruitNum": 0x801ef2c8,
		"evResetFruitNum": 0x801ef2c8,
		"NPC::evNpcDanceOffHappyOn": 0x801ef404,
		"evNpcDanceOffHappyOn": 0x801ef404,
		"NPC::evNpcDanceOn": 0x801ef550,
		"evNpcDanceOn": 0x801ef550,
		"NPC::evSetNpcTalkForbidCount": 0x801ef68c,
		"evSetNpcTalkForbidCount": 0x801ef68c,
		"NPC::evSetNpcBalloonMessage": 0x801ef878,
		"evSetNpcBalloonMessage": 0x801ef878,
		"NPC::evOnTalkToDummyNpc": 0x801efb1c,
		"evOnTalkToDummyNpc": 0x801efb1c,
		"NPC::evConnectDummyNpc": 0x801efc14,
		"evConnectDummyNpc": 0x801efc14,
		"NPC::ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x801efdd4,
		"ev__ForceStartTalkExceptNpc__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x801efdd4,
		"NPC::ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x801effb8,
		"ev__ForceStartTalk__FP32TSpcTypedInterp<13TEventWatcher>Ul": 0x801effb8,
		"NPC::evIsGameModeNormal": 0x801f01cc,
		"evIsGameModeNormal": 0x801f01cc,
		"NPC::evIsNpcSinkBottom": 0x801f0274,
		"evIsNpcSinkBottom": 0x801f0274,
		"NPC::evCheckLatestNerve4Npc": 0x801f03e4,
		"evCheckLatestNerve4Npc": 0x801f03e4,
		"NPC::evCheckCurNerve4Npc": 0x801f05b8,
		"evCheckCurNerve4Npc": 0x801f05b8,
		"NPC::evGetAddressFromViewObjName": 0x801f0788,
		"evGetAddressFromViewObjName": 0x801f0788,
		"NPC::__sinit_NpcEvent_cpp": 0x801f08dc,
		"__sinit_NpcEvent_cpp": 0x801f08dc,
		"NPC::SMSGetNpcInitData": 0x801f0bd8,
		"SMSGetNpcInitData": 0x801f0bd8,
		"NPC::__sinit_NpcInitData_cpp": 0x801f0bf0,
		"__sinit_NpcInitData_cpp": 0x801f0bf0,
		"TBaseNPC::setIndividualDifference_": 0x801f0c0c,
		"setIndividualDifference_": 0x801f0c0c,
		"TBaseNPC::init": 0x801f14f0,
		"TNpcInbetween::execMotionBlend": 0x801f1c04,
		"execMotionBlend": 0x801f1c04,
		"TNpcInbetween::execPosInbetween": 0x801f1de0,
		"execPosInbetween": 0x801f1de0,
		"TNpcParts::partsPerform": 0x801f1ebc,
		"partsPerform": 0x801f1ebc,
		"TNpcParts::partsFrameUpdate": 0x801f206c,
		"partsFrameUpdate": 0x801f206c,
		"TNpcParts::getPartsMActor": 0x801f20d4,
		"getPartsMActor": 0x801f20d4,
		"TNpcParts::setPartsAnmFrame": 0x801f20f8,
		"setPartsAnmFrame": 0x801f20f8,
		"TNpcParts::addJellyFishParts": 0x801f227c,
		"addJellyFishParts": 0x801f227c,
		"TNpcParts::TNpcParts": 0x801f23f4,
		"NPC::SMS_InitChangeNpcColor": 0x801f2824,
		"SMS_InitChangeNpcColor": 0x801f2824,
		"TBaseNPC::getBasNameTable": 0x801f2a54,
		"TBaseNPC::kill": 0x801f2bdc,
		"TBaseNPC::setPosAndInitAfterSinkBottom": 0x801f2be0,
		"setPosAndInitAfterSinkBottom": 0x801f2be0,
		"TBaseNPC::changeNerveProc_": 0x801f2fdc,
		"changeNerveProc_": 0x801f2fdc,
		"TBaseNPC::isNowCanTaken": 0x801f364c,
		"isNowCanTaken": 0x801f364c,
		"TBaseNPC::isStateGoToMad_": 0x801f377c,
		"isStateGoToMad_": 0x801f377c,
		"TBaseNPC::behaveToSandBomb_": 0x801f37f0,
		"behaveToSandBomb_": 0x801f37f0,
		"TBaseNPC::behaveToHitObject_": 0x801f3a0c,
		"behaveToHitObject_": 0x801f3a0c,
		"TBaseNPC::behaveToBeTrampled_": 0x801f3e7c,
		"behaveToBeTrampled_": 0x801f3e7c,
		"TBaseNPC::behaveToBeTaken_": 0x801f4384,
		"behaveToBeTaken_": 0x801f4384,
		"TBaseNPC::releaseTaken_": 0x801f4470,
		"releaseTaken_": 0x801f4470,
		"TBaseNPC::changeNerveToMad_": 0x801f4564,
		"changeNerveToMad_": 0x801f4564,
		"TBaseNPC::changeNerveFromTalk_": 0x801f4628,
		"changeNerveFromTalk_": 0x801f4628,
		"TBaseNPC::isNerveCanGoToMad": 0x801f4810,
		"isNerveCanGoToMad": 0x801f4810,
		"TBaseNPC::isNerveCanGoToTalk": 0x801f48b4,
		"isNerveCanGoToTalk": 0x801f48b4,
		"TBaseNPC::isNerveMaybeDontCalcAnim1": 0x801f49e4,
		"isNerveMaybeDontCalcAnim1": 0x801f49e4,
		"TBaseNPC::isNerveMaybeDontCalcAnim0": 0x801f4a58,
		"isNerveMaybeDontCalcAnim0": 0x801f4a58,
		"TBaseNPC::isNerveMaybeDontMovement": 0x801f4ac0,
		"isNerveMaybeDontMovement": 0x801f4ac0,
		"TBaseNPC::isNerveWalk": 0x801f4b34,
		"isNerveWalk": 0x801f4b34,
		"NPC::__sinit_NpcChange_cpp": 0x801f4ba8,
		"__sinit_NpcChange_cpp": 0x801f4ba8,
		"TNpcThrow::throwMario": 0x801f4ea4,
		"TNpcTrample::updateTrample": 0x801f4fe8,
		"updateTrample": 0x801f4fe8,
		"TNpcTrample::startTrample": 0x801f50dc,
		"startTrample": 0x801f50dc,
		"TBaseNPC::emitParticle_": 0x801f513c,
		"TBaseNPC::isPolWaitCEffectEmitTime_": 0x801f585c,
		"isPolWaitCEffectEmitTime_": 0x801f585c,
		"TBaseNPC::emitHappyEffect_": 0x801f59ac,
		"emitHappyEffect_": 0x801f59ac,
		"TBaseNPC::emitSinkEffect_": 0x801f5b10,
		"emitSinkEffect_": 0x801f5b10,
		"TBaseNPC::getEffectScale_": 0x801f5b68,
		"getEffectScale_": 0x801f5b68,
		"NPC::IsCheckPassFrame": 0x801f5bbc,
		"IsCheckPassFrame": 0x801f5bbc,
		"TBaseNPC::setSmokeEffectMtxPtr_": 0x801f5c48,
		"setSmokeEffectMtxPtr_": 0x801f5c48,
		"TBaseNPC::setPollutionEffectMtxPtr_": 0x801f5cd4,
		"setPollutionEffectMtxPtr_": 0x801f5cd4,
		"TBaseNPC::setNoteEffectMtxPtr_": 0x801f5e2c,
		"setNoteEffectMtxPtr_": 0x801f5e2c,
		"TBaseNPC::setHappyEffectMtxPtr_": 0x801f5ed4,
		"setHappyEffectMtxPtr_": 0x801f5ed4,
		"NPC::SMSGetNpcInitAnmData": 0x801f5fd8,
		"SMSGetNpcInitAnmData": 0x801f5fd8,
		"TBaseNPC::setKinoActionFlag_": 0x801f5fec,
		"setKinoActionFlag_": 0x801f5fec,
		"TBaseNPC::setMareActionFlag_": 0x801f6020,
		"setMareActionFlag_": 0x801f6020,
		"TBaseNPC::setMonteActionFlag_": 0x801f6054,
		"setMonteActionFlag_": 0x801f6054,
		"TNpcCoin::updateCoin": 0x801f6088,
		"updateCoin": 0x801f6088,
		"TNpcCoin::requestAppearCoin": 0x801f6224,
		"requestAppearCoin": 0x801f6224,
		"TNpcCoin::TNpcCoin": 0x801f6498,
		"NPC::__sinit_NpcCoin_cpp": 0x801f6510,
		"__sinit_NpcCoin_cpp": 0x801f6510,
		"TNpcBalloon::updateBalloon": 0x801f680c,
		"updateBalloon": 0x801f680c,
		"TNpcBalloon::setNextMessage": 0x801f6878,
		"setNextMessage": 0x801f6878,
		"TBaseNPC::isTurnToMarioWhenApproach": 0x801f6884,
		"isTurnToMarioWhenApproach": 0x801f6884,
		"TBaseNPC::isTurnToMarioWhenTalk": 0x801f68e8,
		"isTurnToMarioWhenTalk": 0x801f68e8,
		"TBaseNPC::isNeedTurnToFirstState": 0x801f695c,
		"isNeedTurnToFirstState": 0x801f695c,
		"TBaseNPC::execTurnToFirstState": 0x801f6a44,
		"execTurnToFirstState": 0x801f6a44,
		"TBaseNPC::execUTurn": 0x801f6b28,
		"execUTurn": 0x801f6b28,
		"TBaseNPC::execWalk": 0x801f6d08,
		"TBaseNPC::bind": 0x801f70f8,
		"TBaseNPC::setVariableDamageRadius_": 0x801f7310,
		"setVariableDamageRadius_": 0x801f7310,
		"TBaseNPC::execNpcObjCollision_": 0x801f73ec,
		"execNpcObjCollision_": 0x801f73ec,
		"TBaseNPC::initNpcObjCollision_": 0x801f7718,
		"initNpcObjCollision_": 0x801f7718,
		"MAnmSoundNPC::startAnimSound": 0x80012a20,
		"MAnmSound::setSpeedModifySound": 0x80012dd4,
		"MAnmSound::startAnimSound": 0x80012e50,
		"MAnmSound::animeLoop": 0x80012ec8,
		"animeLoop": 0x80012ec8,
		"MAnmSound::initAnmSound": 0x80012f0c,
		"MAnmSound::MAnmSound": 0x80012f2c,
		"MSound::__sinit_MAnmSound_cpp": 0x80012f70,
		"__sinit_MAnmSound_cpp": 0x80012f70,
		"MSound::getMapInfoGround": 0x8001326c,
		"MSound::getSwitch": 0x80013274,
		"getSwitch": 0x80013274,
		"MSound::getBstSwitch": 0x800132d4,
		"getBstSwitch": 0x800132d4,
		"MSound::gateCheck": 0x80013310,
		"MSound::cameraLooksAtMario": 0x80013360,
		"cameraLooksAtMario": 0x80013360,
		"MSound::startSoundActorSpecial": 0x800133b8,
		"startSoundActorSpecial": 0x800133b8,
		"MSound::startBeeSe": 0x80013528,
		"startBeeSe": 0x80013528,
		"MSound::getWallSound": 0x800136d8,
		"getWallSound": 0x800136d8,
		"MSound::checkMarioVoicePlaying": 0x80013738,
		"checkMarioVoicePlaying": 0x80013738,
		"MSound::stopMarioVoice": 0x8001375c,
		"stopMarioVoice": 0x8001375c,
		"MSound::getMarioVoiceID": 0x800137cc,
		"getMarioVoiceID": 0x800137cc,
		"MSound::startMarioVoice": 0x80013804,
		"startMarioVoice": 0x80013804,
		"MSound::playTimer": 0x80013eec,
		"playTimer": 0x80013eec,
		"MSound::setSeExtParameter": 0x80013fd8,
		"MSoundSESystem::MSRandVol::getRandomVolumeNormal": 0x800140c0,
		"getRandomVolumeNormal": 0x800140c0,
		"MSound::stopAllSound": 0x80014114,
		"stopAllSound": 0x80014114,
		"MSound::fadeOutAllSound": 0x800141a4,
		"fadeOutAllSound": 0x800141a4,
		"MSound::resetAudioAll": 0x800142b4,
		"resetAudioAll": 0x800142b4,
		"MSound::setCategoryVOLs": 0x80014388,
		"setCategoryVOLs": 0x80014388,
		"MSound::talkModeOut": 0x80014444,
		"talkModeOut": 0x80014444,
		"MSound::talkModeIn": 0x8001458c,
		"talkModeIn": 0x8001458c,
		"MSound::demoModeOut": 0x80014688,
		"demoModeOut": 0x80014688,
		"MSound::demoModeIn": 0x800147a0,
		"demoModeIn": 0x800147a0,
		"MSound::pauseOff": 0x80014874,
		"pauseOff": 0x80014874,
		"MSound::pauseOn": 0x80014a94,
		"pauseOn": 0x80014a94,
		"MSound::initSound": 0x80014bd8,
		"initSound": 0x80014bd8,
		"MSound::startSoundSetGrp": 0x80014cec,
		"MSound::startSoundSet": 0x80014d78,
		"MSound::mainLoop": 0x80014e04,
		"mainLoop": 0x80014e04,
		"MSound::MSound": 0x80014ecc,
		"JAICamera::JAICamera": 0x80015210,
		"MSound::getDistFromCamera": 0x800152ac,
		"getDistFromCamera": 0x800152ac,
		"MSound::setPlayerInfo": 0x800152d8,
		"setPlayerInfo": 0x800152d8,
		"MSound::setCameraInfo": 0x800153d4,
		"MSound::checkWaveOnAram": 0x80015428,
		"checkWaveOnAram": 0x80015428,
		"MSound::exitStage": 0x8001555c,
		"exitStage": 0x8001555c,
		"MSound::enterStage": 0x8001569c,
		"enterStage": 0x8001569c,
		"MSound::loadWave": 0x800156f8,
		"MSound::loadGroupWave": 0x80015748,
		"MSound::setRegisterTrackCallback": 0x8001580c,
		"MSound::makeSound": 0x80015834,
		"MSHandle::MSHandle": 0x800158c8,
		"MSSeCallBack::setParameterSeqSync": 0x80015904,
		"MSSeCallBack::setWaterCameraFir": 0x80015e10,
		"setWaterCameraFir": 0x80015e10,
		"MSound::__sinit_MSound_cpp": 0x800162a8,
		"__sinit_MSound_cpp": 0x800162a8,
		"MSBgm::setStageBgmYoshiPercussion": 0x800165a4,
		"setStageBgmYoshiPercussion": 0x800165a4,
		"MSBgm::setDolby": 0x80016658,
		"MSBgm::setPan": 0x800166a0,
		"MSBgm::setVolume": 0x800166e8,
		"MSBgm::setTrackVolume": 0x80016754,
		"setTrackVolume": 0x80016754,
		"MSBgm::stopTrackBGMs": 0x8001679c,
		"stopTrackBGMs": 0x8001679c,
		"MSBgm::stopTrackBGM": 0x80016848,
		"stopTrackBGM": 0x80016848,
		"MSBgm::stopBGM": 0x800168c8,
		"stopBGM": 0x800168c8,
		"MSBgm::getHandle": 0x800169a8,
		"getHandle": 0x800169a8,
		"MSBgm::startBGM": 0x800169d4,
		"startBGM": 0x800169d4,
		"MSBgm::getSceneNo": 0x80016b1c,
		"getSceneNo": 0x80016b1c,
		"MSBgm::init": 0x80016cbc,
		"JALList<MSBgm>::JALList": 0x80016d44,
		"JALList": 0x80016d44,
		"JALListS<MSBgm,unsigned_long><MSBgm,unsigned_long>::search": 0x80016da0,
		"MSound::__sinit_MSoundBGM_cpp": 0x80016dd4,
		"__sinit_MSoundBGM_cpp": 0x80016dd4,
		"JADPrm<unsigned_char><unsigned_char>::JADPrm": 0x800170d0,
		"MSound::__sinit_MSoundDebug_cpp": 0x800170d8,
		"__sinit_MSoundDebug_cpp": 0x800170d8,
		"MSSceneSE::sortMaxTrans": 0x800173d4,
		"sortMaxTrans": 0x800173d4,
		"MSSceneSE::frameLoop": 0x800175a8,
		"frameLoop": 0x800175a8,
		"MSSceneSE::MSSceneSE": 0x800179c0,
		"MSound::__sinit_MSoundScene_cpp": 0x80017b3c,
		"__sinit_MSoundScene_cpp": 0x80017b3c,
		"MSoundSESystem::MSoundSE::checkMonoSound": 0x80017e38,
		"checkMonoSound": 0x80017e38,
		"MSoundSESystem::MSoundSE::startSoundNpcActor": 0x80017f0c,
		"startSoundNpcActor": 0x80017f0c,
		"MSoundSESystem::MSoundSE::getNewIDBySurfaceCode": 0x8001801c,
		"getNewIDBySurfaceCode": 0x8001801c,
		"MSoundSESystem::MSoundSE::startSoundActorInner": 0x80018134,
		"startSoundActorInner": 0x80018134,
		"MSoundSESystem::MSoundSE::checkSoundArea": 0x800184f4,
		"checkSoundArea": 0x800184f4,
		"MSoundSESystem::MSoundSE::startSoundActorWithInfo": 0x80018650,
		"startSoundActorWithInfo": 0x80018650,
		"MSoundSESystem::MSoundSE::startSoundSystemSE": 0x800188c0,
		"MSoundSESystem::MSoundSE::startSoundActor": 0x80018a30,
		"MSoundSESystem::MSoundSE::getRandomID": 0x80018a70,
		"getRandomID": 0x80018a70,
		"MSoundSESystem::MSoundSE::construct": 0x80018cdc,
		"construct": 0x80018cdc,
		"MSoundSESystem::MSRandPlay::randPlay": 0x80019fe8,
		"randPlay": 0x80019fe8,
		"MSoundSESystem::MSRandPlay::MSRandPlay": 0x8001a1ac,
		"MSoundSESystem::MSRandPlay::startSeRandPlay": 0x8001a24c,
		"startSeRandPlay": 0x8001a24c,
		"MSoundSESystem::MSRandPlayVec::~MSRandPlayVec": 0x8001a2ac,
		"MSoundSESystem::MSRandPlayVec::MSRandPlayVec": 0x8001a30c,
		"MSoundSESystem::MSRandPlay::createRandPlayVec": 0x8001a364,
		"createRandPlayVec": 0x8001a364,
		"MSoundSESystem::MSRandPlay::registerTrans": 0x8001a408,
		"registerTrans": 0x8001a408,
		"MSoundSESystem::MSRandVol::getRandVol": 0x8001a45c,
		"getRandVol": 0x8001a45c,
		"MSoundSESystem::MSRandVol::MSRandVol": 0x8001a4d8,
		"MSound::__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x8001a580,
		"__ct__31JALLinkD<16MSSetSoundMember,Ul>FP16MSSetSoundMemberUlP31JALListD<16MSSetSoundMember,Ul>": 0x8001a580,
		"MSSetSoundTL<MSSetSoundGrp>::MSSetSoundTL": 0x8001a5f0,
		"JALListFrameLoop<MSSetSoundGrp>::frameLoopDyna": 0x8001a848,
		"MSound::__ct__9JADPrm<l>FlPCc": 0x8001a84c,
		"__ct__9JADPrm<l>FlPCc": 0x8001a84c,
		"MSound::__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x8001a85c,
		"__ct__34JALListHioNode<13MSSetSoundGrp,Ul>FPCcUlP13MSSetSoundGrp": 0x8001a85c,
		"MSound::__sinit_MSoundSE_cpp": 0x8001a8b0,
		"__sinit_MSoundSE_cpp": 0x8001a8b0,
		"JSUList<MSoundSESystem::MSRandPlay>::~JSUList": 0x8001ac08,
		"JSUList<MSoundSESystem::MSRandVol>::~JSUList": 0x8001ac60,
		"MSSetSoundGrp::startSoundSetGrp": 0x8001acc0,
		"MSSetSound::startSoundSet": 0x8001ad60,
		"MSSetSound::init": 0x8001aec4,
		"JALListGrp<MSSetSoundGrp,unsigned_long,MSSetSoundMember><MSSetSoundGrp,unsigned_long,MSSetSoundMember>::searchGroup": 0x8001b454,
		"MSSetSoundTL<MSSetSound>::startSoundSetDyna": 0x8001b4b0,
		"JALListD<MSSetSoundMember,unsigned_long><MSSetSoundMember,unsigned_long>::searchD": 0x8001bbfc,
		"searchD": 0x8001bbfc,
		"MSSetSoundTL<MSSetSound>::MSSetSoundTL": 0x8001bc28,
		"MSSetSoundTL<MSSetSoundGrp>::startSoundSetDyna": 0x8001be80,
		"JALListFrameLoop<MSSetSound>::frameLoopDyna": 0x8001c5cc,
		"MSound::__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x8001c5d0,
		"__ct__31JALListHioNode<10MSSetSound,Ul>FPCcUlP10MSSetSound": 0x8001c5d0,
		"MSound::__sinit_MSoundStruct_cpp": 0x8001c624,
		"__sinit_MSoundStruct_cpp": 0x8001c624,
		"MSHandle::calcVolume": 0x8001c928,
		"calcVolume": 0x8001c928,
		"MSHandle::setDistanceVolumeCommon": 0x8001ca08,
		"MSHandle::setSeDistanceVolume": 0x8001caac,
		"MSHandle::calcDolby": 0x8001cba4,
		"calcDolby": 0x8001cba4,
		"MSHandle::setSeDistanceDolby": 0x8001cc94,
		"MSHandle::calcPan": 0x8001cce8,
		"MSHandle::setSeDistancePan": 0x8001ce08,
		"MSHandle::setSeDistancePitch": 0x8001cea8,
		"MSHandle::setSeDistanceParameters": 0x8001cfbc,
		"MSHandle::MSACos": 0x8001d10c,
		"MSACos": 0x8001d10c,
		"MSound::__sinit_MSHandle_cpp": 0x8001d168,
		"__sinit_MSHandle_cpp": 0x8001d168,
		"MSBgmXFade::xFadeBgmForce": 0x8001d464,
		"xFadeBgmForce": 0x8001d464,
		"MSBgmXFade::xFadeBgm": 0x8001d540,
		"xFadeBgm": 0x8001d540,
		"MSModBgm::changeTempo": 0x8001d650,
		"changeTempo": 0x8001d650,
		"MSModBgm::loop": 0x8001d6d8,
		"loop": 0x8001d6d8,
		"MSModBgm::modBgm": 0x8001d714,
		"modBgm": 0x8001d714,
		"MSound::__sinit_MSModBgm_cpp": 0x8001d810,
		"__sinit_MSModBgm_cpp": 0x8001d810,
		"TWoodBarrel::getFlushTime": 0x8018e95c,
		"TMapObjGeneral::getLivingTime": 0x8018e964,
		"TMapObjGeneral::checkIllegalAttr": 0x8018e96c,
		"TWoodBarrel::TWoodBarrel": 0x8018e970,
		"TWoodBarrel::load": 0x8018ea40,
		"TWoodBarrel::loadAfter": 0x8018ea98,
		"TWoodBarrel::control": 0x8018eb00,
		"TWoodBarrel::receiveMessage": 0x8018eba4,
		"TWoodBarrel::touchActor": 0x8018ebe4,
		"TWoodBarrel::touchPlayer": 0x8018ecb0,
		"TWoodBarrel::touchGround": 0x8018ecfc,
		"TWoodBarrel::touchWall": 0x8018ed80,
		"TWoodBarrel::appear": 0x8018edac,
		"TWoodBarrel::appeared": 0x8018ee2c,
		"TWoodBarrel::kill": 0x8018eee0,
		"TWoodBarrel::breaking": 0x8018ef88,
		"TWoodBarrel::hold": 0x8018f008,
		"TWoodBarrel::put": 0x8018f060,
		"MoveBG::__sinit_WoodBarrel_cpp": 0x8018f124,
		"__sinit_WoodBarrel_cpp": 0x8018f124,
		"TMapObjBase::TMapObjBase": 0x8018f428,
		"TMapObjBase::load": 0x8018f4d0,
		"TMapObjBase::loadAfter": 0x8018f5b4,
		"TMapObjBase::initAndRegister": 0x8018f5f4,
		"initAndRegister": 0x8018f5f4,
		"TMapObjBase::receiveMessage": 0x8018f6c4,
		"TMapObjBase::calcRootMatrix": 0x8018f720,
		"TMapObjBase::getRootJointMtx": 0x8018f7cc,
		"TMapObjBase::getShadowType": 0x8018f800,
		"TMapObjBase::perform": 0x8018f8c8,
		"TMapObjBase::setGroundCollision": 0x8018fcf4,
		"TMapObjBase::control": 0x8018fe78,
		"TMapObjBase::ensureTakeSituation": 0x8018fff0,
		"TMapObjBase::touchActor": 0x80190050,
		"TMapObjBase::touchPlayer": 0x801900fc,
		"TMapObjBase::touchEnemy": 0x80190138,
		"TMapObjBase::touchBoss": 0x80190174,
		"touchBoss": 0x80190174,
		"TMapObjBase::makeObjAppeared": 0x801901b0,
		"TMapObjBase::makeObjDead": 0x801904b8,
		"TMapObjBase::makeObjDefault": 0x80190674,
		"TMapObjBase::startAnim": 0x80190754,
		"startAnim": 0x80190754,
		"TMapObjBase::startBck": 0x80190948,
		"startBck": 0x80190948,
		"TMapObjBase::startControlAnim": 0x80190978,
		"startControlAnim": 0x80190978,
		"TMapObjBase::animIsFinished": 0x801909f4,
		"animIsFinished": 0x801909f4,
		"TMapObjBase::hasAnim": 0x80190a74,
		"hasAnim": 0x80190a74,
		"TMapObjBase::hasModelOrAnimData": 0x80190abc,
		"hasModelOrAnimData": 0x80190abc,
		"TMapObjBase::startSound": 0x80190b10,
		"startSound": 0x80190b10,
		"TMapObjBase::soundBas": 0x80190c08,
		"soundBas": 0x80190c08,
		"TMapObjBase::setUpMapCollision": 0x80190cac,
		"setUpMapCollision": 0x80190cac,
		"TMapObjBase::setUpCurrentMapCollision": 0x80190dd8,
		"setUpCurrentMapCollision": 0x80190dd8,
		"TMapObjBase::removeMapCollision": 0x80190eb0,
		"removeMapCollision": 0x80190eb0,
		"TMapObjBase::setObjHitData": 0x80190f0c,
		"setObjHitData": 0x80190f0c,
		"TMapObjBase::sleep": 0x80190fb8,
		"TMapObjBase::awake": 0x8019102c,
		"TMapObjBase::getSDLModelFlag": 0x80191070,
		"TMapObjBase::changeObjSRT": 0x80191078,
		"changeObjSRT": 0x80191078,
		"TMapObjBase::changeObjMtx": 0x801910e8,
		"changeObjMtx": 0x801910e8,
		"MoveBG::__sinit_MapObjBase_cpp": 0x801911e0,
		"__sinit_MapObjBase_cpp": 0x801911e0,
		"TMapObjGeneral::getFlushTime": 0x801914e4,
		"TMapObjManager::initKeyCode": 0x801914ec,
		"initKeyCode": 0x801914ec,
		"TMapObjGeneral::initMapObj": 0x8019155c,
		"TMapObjBase::initMapObj": 0x801915a4,
		"TMapObjBase::initActorData": 0x80191850,
		"initActorData": 0x80191850,
		"TMapObjBase::initModelData": 0x801919b4,
		"initModelData": 0x801919b4,
		"TMapObjBase::makeMActors": 0x80191ae4,
		"TMapObjBase::initMActor": 0x80191df0,
		"initMActor": 0x80191df0,
		"TMapObjBase::initBckMoveData": 0x80191e9c,
		"initBckMoveData": 0x80191e9c,
		"TMapObjBase::initObjCollisionData": 0x80191f84,
		"initObjCollisionData": 0x80191f84,
		"TMapObjBase::initMapCollisionData": 0x8019210c,
		"TMapObjBase::checkIllegalAttr": 0x801921c8,
		"TMapObjBase::initUnique": 0x801921cc,
		"MoveBG::__sinit_MapObjInit_cpp": 0x80192a10,
		"__sinit_MapObjInit_cpp": 0x80192a10,
		"TMapObjGeneral::TMapObjGeneral": 0x80192d14,
		"TMapObjGeneral::loadAfter": 0x80192d70,
		"TMapObjGeneral::receiveMessage": 0x80192ddc,
		"TMapObjGeneral::perform": 0x801930e4,
		"TMapObjGeneral::calcRootMatrix": 0x801931dc,
		"TMapObjGeneral::control": 0x80193378,
		"TMapObjGeneral::bind": 0x80193438,
		"TMapObjGeneral::calcVelocity": 0x801936b8,
		"TMapObjGeneral::checkGroundCollision": 0x8019385c,
		"TMapObjGeneral::touchGround": 0x8019390c,
		"TMapObjGeneral::checkRoofCollision": 0x80193ae4,
		"checkRoofCollision": 0x80193ae4,
		"TMapObjGeneral::touchRoof": 0x80193b70,
		"TMapObjGeneral::checkWallCollision": 0x80193b7c,
		"TMapObjGeneral::touchWall": 0x80193c64,
		"TMapObjGeneral::work": 0x80193cac,
		"work": 0x80193cac,
		"TMapObjGeneral::appear": 0x80193d9c,
		"TMapObjGeneral::kill": 0x80193e94,
		"TMapObjGeneral::ensureTakeSituation": 0x80193f14,
		"TMapObjGeneral::hold": 0x80193f80,
		"TMapObjGeneral::recover": 0x80193ff4,
		"recover": 0x80193ff4,
		"TMapObjGeneral::touchPlayer": 0x801940fc,
		"TMapObjGeneral::touchWater": 0x80194150,
		"TMapObjGeneral::receiveMessageFromPlayer": 0x801941cc,
		"receiveMessageFromPlayer": 0x801941cc,
		"TMapObjGeneral::makeObjBuried": 0x801941f0,
		"makeObjBuried": 0x801941f0,
		"TMapObjGeneral::makeObjRecovered": 0x8019425c,
		"makeObjRecovered": 0x8019425c,
		"TMapObjGeneral::appeared": 0x801942a8,
		"TMapObjGeneral::appearing": 0x80194300,
		"TMapObjGeneral::breaking": 0x801943c4,
		"TMapObjGeneral::sinking": 0x80194444,
		"sinking": 0x80194444,
		"TMapObjGeneral::recovering": 0x80194564,
		"recovering": 0x80194564,
		"TMapObjGeneral::holding": 0x80194678,
		"holding": 0x80194678,
		"TMapObjGeneral::touchingPlayer": 0x801946d0,
		"touchingPlayer": 0x801946d0,
		"TMapObjGeneral::touchingWater": 0x80194724,
		"touchingWater": 0x80194724,
		"TMapObjGeneral::thrown": 0x80194778,
		"TMapObjGeneral::put": 0x8019495c,
		"TMapObjGeneral::sink": 0x80194a6c,
		"sink": 0x80194a6c,
		"TMapObjGeneral::waitToAppear": 0x80194ad4,
		"waitToAppear": 0x80194ad4,
		"TMapObjGeneral::waitingToRecover": 0x80194af8,
		"waitingToRecover": 0x80194af8,
		"TMapObjGeneral::waitingToAppear": 0x80194b50,
		"TMapObjGeneral::isPollutedGround": 0x80194cb0,
		"isPollutedGround": 0x80194cb0,
		"MoveBG::__sinit_MapObjGeneral_cpp": 0x80194da4,
		"__sinit_MapObjGeneral_cpp": 0x80194da4,
		"TMapObjBaseManager::~TMapObjBaseManager": 0x801950a0,
		"TMapObjBaseManager::TMapObjBaseManager": 0x80195134,
		"TMapObjBaseManager::load": 0x8019517c,
		"TMapObjBaseManager::getObjNumWithActorType": 0x801951d4,
		"getObjNumWithActorType": 0x801951d4,
		"TMapObjBaseManager::createModelData": 0x80195228,
		"TMapObjBaseManager::clipActors": 0x8019525c,
		"TMapObjBaseManager::getActorTypeByEventID": 0x80195290,
		"getActorTypeByEventID": 0x80195290,
		"TMapObjBaseManager::newAndRegisterObjByEventID": 0x80195390,
		"newAndRegisterObjByEventID": 0x80195390,
		"TMapObjBaseManager::newAndRegisterObj": 0x80195a04,
		"newAndRegisterObj": 0x80195a04,
		"MoveBG::newUniqueObjByName": 0x80195b30,
		"newUniqueObjByName": 0x80195b30,
		"MoveBG::newItemByName": 0x80196a40,
		"newItemByName": 0x80196a40,
		"TMapObjBaseManager::makeObjAppeared": 0x80196ad4,
		"TMapObjManager::TMapObjManager": 0x80196e1c,
		"TMapObjManager::load": 0x80196f4c,
		"TMapObjManager::loadAfter": 0x8019740c,
		"TMapObjManager::entryStaticDrawBufferSun": 0x801975e8,
		"entryStaticDrawBufferSun": 0x801975e8,
		"TMapObjManager::entryStaticDrawBufferShadow": 0x80197638,
		"entryStaticDrawBufferShadow": 0x80197638,
		"TMerryPole::getRootJointMtx": 0x8019770c,
		"TMapObjManager::~TMapObjManager": 0x80197714,
		"TMapObjManager::hasMapCollision": 0x801977a8,
		"MoveBG::__sinit_MapObjManager_cpp": 0x801977b0,
		"__sinit_MapObjManager_cpp": 0x801977b0,
		"TMapObjTurn::TMapObjTurn": 0x80197b50,
		"TMapObjTurn::initMapObj": 0x80197c3c,
		"TMapObjTurn::loadAfter": 0x80197cac,
		"TMapObjTurn::receiveMessage": 0x80197cec,
		"TMapObjTurn::control": 0x80197d88,
		"TMapObjTurn::turn": 0x80198310,
		"turn": 0x80198310,
		"TMapObjTurn::touchWater": 0x80198404,
		"TMapObjMessenger::TMapObjMessenger": 0x80198598,
		"TMapObjMessenger::receiveMessage": 0x801985e4,
		"TMapObjLibWave::TMapObjLibWave": 0x80198614,
		"TMapObjLibWave::movement": 0x801986bc,
		"TMapObjLibWave::getCurrentHeight": 0x80198714,
		"getCurrentHeight": 0x80198714,
		"TMapObjLibWave::push": 0x8019874c,
		"TMapObjBase::emitAndBindScale": 0x801987f0,
		"emitAndBindScale": 0x801987f0,
		"TMapObjBase::emitAndRotateScale": 0x801988e4,
		"emitAndRotateScale": 0x801988e4,
		"TMapObjBase::emitAndSRT": 0x801989d4,
		"emitAndSRT": 0x801989d4,
		"TMapObjBase::emitColumnWater": 0x80198ab4,
		"emitColumnWater": 0x80198ab4,
		"TMapObjBase::marioHipAttack": 0x80198b08,
		"marioHipAttack": 0x80198b08,
		"TMapObjBase::marioHeadAttack": 0x80198b78,
		"marioHeadAttack": 0x80198b78,
		"TMapObjBase::sendMsg": 0x80198c7c,
		"sendMsg": 0x80198c7c,
		"TMapObjBase::waterHitPlane": 0x80198d0c,
		"waterHitPlane": 0x80198d0c,
		"TMapObjBase::getWaterPos": 0x80198d98,
		"getWaterPos": 0x80198d98,
		"TMapObjBase::getWaterSpeed": 0x80198db0,
		"getWaterSpeed": 0x80198db0,
		"TMapObjBase::getWaterPlane": 0x80198dc8,
		"getWaterPlane": 0x80198dc8,
		"TMapObjBase::getWaterID": 0x80198de0,
		"getWaterID": 0x80198de0,
		"TMapObjBase::getDistance": 0x80198de8,
		"getDistance": 0x80198de8,
		"TMapObjBase::getDistanceXZ": 0x80198e64,
		"getDistanceXZ": 0x80198e64,
		"TMapObjBase::getRotYFromAxisZ": 0x80198ec8,
		"getRotYFromAxisZ": 0x80198ec8,
		"TMapObjBase::getRotYFromAxisX": 0x80198f04,
		"getRotYFromAxisX": 0x80198f04,
		"TMapObjBase::makeVecToLocalZ": 0x80198f40,
		"makeVecToLocalZ": 0x80198f40,
		"TMapObjBase::getNormalVecFromTarget": 0x80198fac,
		"getNormalVecFromTarget": 0x80198fac,
		"TMapObjBase::getNormalVecFromTargetXZ": 0x80198ff0,
		"getNormalVecFromTargetXZ": 0x80198ff0,
		"TMapObjBase::rotateVecByAxisY": 0x80199034,
		"rotateVecByAxisY": 0x80199034,
		"TMapObjBase::getVerticalVecToTargetXZ": 0x80199250,
		"getVerticalVecToTargetXZ": 0x80199250,
		"JGeometry::SMatrix33C<float><float>::at": 0x801993bc,
		"at": 0x801993bc,
		"JGeometry::SMatrix33C<float><float>::SMatrix33C": 0x801993d0,
		"SMatrix33C": 0x801993d0,
		"TMapObjBase::calcReflectingVelocity": 0x801993d4,
		"calcReflectingVelocity": 0x801993d4,
		"TMapObjBase::makeObjMtxRotByAxis": 0x80199440,
		"makeObjMtxRotByAxis": 0x80199440,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setRotate": 0x801995d4,
		"TMapObjBase::makeMtxRotByAxis": 0x80199728,
		"makeMtxRotByAxis": 0x80199728,
		"TMapObjBase::concatOnlyRotFromRight": 0x801998cc,
		"concatOnlyRotFromRight": 0x801998cc,
		"TMapObjBase::concatOnlyRotFromLeft": 0x80199938,
		"concatOnlyRotFromLeft": 0x80199938,
		"TMapObjBase::updateObjMtx": 0x801999a4,
		"updateObjMtx": 0x801999a4,
		"TMapObjBase::updateRootMtxTrans": 0x80199a5c,
		"updateRootMtxTrans": 0x80199a5c,
		"TMapObjBase::makeRootMtxRotX": 0x80199aac,
		"makeRootMtxRotX": 0x80199aac,
		"TMapObjBase::setRootMtxRotY": 0x80199b5c,
		"setRootMtxRotY": 0x80199b5c,
		"TMapObjBase::makeRootMtxRotY": 0x80199c10,
		"makeRootMtxRotY": 0x80199c10,
		"TMapObjBase::setRootMtxRotZ": 0x80199cc0,
		"setRootMtxRotZ": 0x80199cc0,
		"TMapObjBase::makeRootMtxRotZ": 0x80199d74,
		"makeRootMtxRotZ": 0x80199d74,
		"TMapObjBase::makeLowerStr": 0x80199e24,
		"makeLowerStr": 0x80199e24,
		"TMapObjBase::moveJoint": 0x80199e78,
		"moveJoint": 0x80199e78,
		"TMapObjBase::getJointTransX": 0x80199ee8,
		"getJointTransX": 0x80199ee8,
		"TMapObjBase::getJointTransZ": 0x80199ef0,
		"getJointTransZ": 0x80199ef0,
		"TMapObjBase::setJointTransX": 0x80199ef8,
		"setJointTransX": 0x80199ef8,
		"TMapObjBase::setJointTransY": 0x80199f48,
		"setJointTransY": 0x80199f48,
		"TMapObjBase::setJointTransZ": 0x80199f98,
		"setJointTransZ": 0x80199f98,
		"TMapObjBase::getJointScaleY": 0x80199fe8,
		"getJointScaleY": 0x80199fe8,
		"TMapObjBase::setJointScaleY": 0x80199ff0,
		"setJointScaleY": 0x80199ff0,
		"TMapObjBase::calcMap": 0x8019a040,
		"calcMap": 0x8019a040,
		"TMapObjBase::getBuildingJointObj": 0x8019a080,
		"getBuildingJointObj": 0x8019a080,
		"TMapObjBase::getBuildingJoint": 0x8019a0a8,
		"getBuildingJoint": 0x8019a0a8,
		"TMapObjBase::newAndInitBuildingCollisionMove": 0x8019a0d4,
		"newAndInitBuildingCollisionMove": 0x8019a0d4,
		"TMapObjBase::newAndInitBuildingCollisionWarp": 0x8019a168,
		"newAndInitBuildingCollisionWarp": 0x8019a168,
		"TMapObjBase::joinToGroup": 0x8019a1fc,
		"joinToGroup": 0x8019a1fc,
		"TMapObjBase::startAllAnim": 0x8019a2a0,
		"startAllAnim": 0x8019a2a0,
		"TMapObjBase::initPacketMatColor": 0x8019a3d0,
		"initPacketMatColor": 0x8019a3d0,
		"TMapObjBase::isFruit": 0x8019a44c,
		"isFruit": 0x8019a44c,
		"TMapObjBase::isCoin": 0x8019a520,
		"isCoin": 0x8019a520,
		"TMapObjBase::throwObjFromPointWithRot": 0x8019a594,
		"throwObjFromPointWithRot": 0x8019a594,
		"TMapObjBase::throwObjToFrontFromPoint": 0x8019a658,
		"throwObjToFrontFromPoint": 0x8019a658,
		"TMapObjBase::throwObjToFront": 0x8019a76c,
		"throwObjToFront": 0x8019a76c,
		"TMapObjBase::checkOnManhole": 0x8019a884,
		"checkOnManhole": 0x8019a884,
		"TMapObjBase::loadHideObjInfo": 0x8019a90c,
		"loadHideObjInfo": 0x8019a90c,
		"TMapObjBase::isDemo": 0x8019a9e8,
		"isDemo": 0x8019a9e8,
		"TMapObjBase::isHideObj": 0x8019aa40,
		"isHideObj": 0x8019aa40,
		"MoveBG::__sinit_MapObjLib_cpp": 0x8019abd8,
		"__sinit_MapObjLib_cpp": 0x8019abd8,
		"TNozzleBox::TNozzleBox": 0x8019af80,
		"TNozzleBox::load": 0x8019b004,
		"TNozzleBox::loadAfter": 0x8019b21c,
		"TNozzleBox::control": 0x8019b3f4,
		"TNozzleBox::touchPlayer": 0x8019b44c,
		"TNozzleBox::receiveMessage": 0x8019b51c,
		"TNozzleBox::breaking": 0x8019b68c,
		"TNozzleBox::makeModelValid": 0x8019b6d4,
		"makeModelValid": 0x8019b6d4,
		"TItemNozzle::load": 0x8019b764,
		"TItemNozzle::initMapObj": 0x8019b828,
		"TItemNozzle::control": 0x8019b974,
		"TItemNozzle::appearing": 0x8019b994,
		"TItemNozzle::receiveMessage": 0x8019b9b8,
		"TItemNozzle::put": 0x8019ba7c,
		"TItemNozzle::touchPlayer": 0x8019ba94,
		"TEggYoshi::TEggYoshi": 0x8019bc24,
		"TEggYoshi::load": 0x8019bc78,
		"TEggYoshi::receiveMessage": 0x8019beb4,
		"TEggYoshi::startFruit": 0x8019c120,
		"startFruit": 0x8019c120,
		"TEggYoshi::perform": 0x8019c1f0,
		"TEggYoshi::control": 0x8019c330,
		"TEggYoshi::touchActor": 0x8019c54c,
		"TEggYoshi::touchFruit": 0x8019c620,
		"TEggYoshi::decideRandomLoveFruit": 0x8019c7a4,
		"decideRandomLoveFruit": 0x8019c7a4,
		"TShine::TShine": 0x8019c8dc,
		"TShine::loadBeforeInit": 0x8019c9a0,
		"TShine::loadAfter": 0x8019ca90,
		"TShine::initMapObj": 0x8019caf8,
		"TShine::makeMActors": 0x8019cb5c,
		"TShine::kill": 0x8019cc58,
		"TShine::appearWithDemo": 0x8019cc8c,
		"appearWithDemo": 0x8019cc8c,
		"TShine::appearSimple": 0x8019cd38,
		"appearSimple": 0x8019cd38,
		"TShine::appearWithTimeCallback": 0x8019ce40,
		"appearWithTimeCallback": 0x8019ce40,
		"TShine::appearWithTime": 0x8019cea8,
		"appearWithTime": 0x8019cea8,
		"TShine::touchPlayer": 0x8019d0bc,
		"TShine::receiveMessage": 0x8019d164,
		"TShine::perform": 0x8019d318,
		"TShine::control": 0x8019d378,
		"TShine::movingCircle": 0x8019d9c0,
		"movingCircle": 0x8019d9c0,
		"TShine::calc": 0x8019db30,
		"TCoinBlue::TCoinBlue": 0x8019de10,
		"TCoinBlue::load": 0x8019df2c,
		"TCoinBlue::loadBeforeInit": 0x8019df98,
		"TCoinBlue::taken": 0x8019dfec,
		"TCoinBlue::makeObjAppeared": 0x8019e0b8,
		"TCoinRed::TCoinRed": 0x8019e120,
		"TCoinRed::taken": 0x8019e1b0,
		"TCoinEmpty::TCoinEmpty": 0x8019e2b0,
		"TCoinEmpty::kill": 0x8019e330,
		"TCoinEmpty::makeObjAppeared": 0x8019e334,
		"TCoinEmpty::appear": 0x8019e338,
		"TFlowerCoin::load": 0x8019e33c,
		"TCoin::TCoin": 0x8019e390,
		"TCoin::initMapObj": 0x8019e3fc,
		"TCoin::loadAfter": 0x8019e46c,
		"TCoin::perform": 0x8019e554,
		"TCoin::makeObjAppeared": 0x8019e7b4,
		"TCoin::appear": 0x8019e7f8,
		"TCoin::appearWithoutSound": 0x8019e930,
		"appearWithoutSound": 0x8019e930,
		"TCoin::makeObjDead": 0x8019e9cc,
		"TCoin::taken": 0x8019ea10,
		"TItem::TItem": 0x8019eb9c,
		"TItem::load": 0x8019ebf0,
		"TItem::initMapObj": 0x8019ec28,
		"TItem::perform": 0x8019ec64,
		"TItem::appear": 0x8019ecf0,
		"TItem::killByTimer": 0x8019ed3c,
		"TItem::appearing": 0x8019ed70,
		"TItem::calc": 0x8019ee54,
		"TItem::calcRootMatrix": 0x8019efcc,
		"TItem::receiveMessage": 0x8019eff8,
		"TItem::touchPlayer": 0x8019f048,
		"TItem::taken": 0x8019f0c4,
		"TItem::appeared": 0x8019f150,
		"TEggYoshi::getHitObjNumMax": 0x8019f37c,
		"MoveBG::__sinit_Item_cpp": 0x8019f690,
		"__sinit_Item_cpp": 0x8019f690,
		"TItemManager::~TItemManager": 0x8019f9dc,
		"TItemManager::hasMapCollision": 0x8019fa70,
		"TItemManager::TItemManager": 0x8019fa78,
		"TItemManager::load": 0x8019fb04,
		"TItemManager::loadAfter": 0x8019fb84,
		"TItemManager::newAndRegisterCoinReal": 0x8019fc58,
		"newAndRegisterCoinReal": 0x8019fc58,
		"TItemManager::perform": 0x8019fca8,
		"TItemManager::newAndRegisterCoin": 0x8019fd6c,
		"newAndRegisterCoin": 0x8019fd6c,
		"TItemManager::makeShineAppearWithDemoOffset": 0x8019fe54,
		"makeShineAppearWithDemoOffset": 0x8019fe54,
		"TItemManager::makeShineAppearWithDemo": 0x8019ff14,
		"makeShineAppearWithDemo": 0x8019ff14,
		"TItemManager::makeShineAppearWithTime": 0x8019ffbc,
		"makeShineAppearWithTime": 0x8019ffbc,
		"TItemManager::resetNozzleBoxesModel": 0x801a006c,
		"resetNozzleBoxesModel": 0x801a006c,
		"MoveBG::__sinit_ItemManager_cpp": 0x801a014c,
		"__sinit_ItemManager_cpp": 0x801a014c,
		"TBasketReverse::initMapObj": 0x801a04cc,
		"TBasketReverse::kill": 0x801a04fc,
		"TRedCoinSwitch::TRedCoinSwitch": 0x801a05b4,
		"TRedCoinSwitch::load": 0x801a0614,
		"TRedCoinSwitch::loadAfter": 0x801a06c8,
		"TRedCoinSwitch::control": 0x801a076c,
		"TRedCoinSwitch::receiveMessage": 0x801a0824,
		"TMapObjSwitch::TMapObjSwitch": 0x801a08e4,
		"TMapObjSwitch::load": 0x801a0978,
		"TMapObjSwitch::receiveMessage": 0x801a0a80,
		"TMapObjSwitch::control": 0x801a0ba0,
		"THideObjInfo::THideObjInfo": 0x801a0bf8,
		"THideObjInfo::load": 0x801a0d08,
		"THideObjInfo::action": 0x801a0d84,
		"TMapObjWaterSpray::TMapObjWaterSpray": 0x801a0e24,
		"TMapObjWaterSpray::load": 0x801a0ea0,
		"TMapObjWaterSpray::calc": 0x801a105c,
		"TDamageObj::load": 0x801a116c,
		"TDamageObj::init": 0x801a1288,
		"TDamageObj::perform": 0x801a12f8,
		"TMapObjStartDemo::load": 0x801a1350,
		"TMapObjStartDemo::touchPlayer": 0x801a13a0,
		"TMapObjChangeStageHipDrop::initMapObj": 0x801a13d0,
		"TMapObjChangeStageHipDrop::touchPlayer": 0x801a142c,
		"TMapObjChangeStage::load": 0x801a14a8,
		"TMapObjChangeStage::touchPlayer": 0x801a14f8,
		"TMapObjBillboard::touchWater": 0x801a1574,
		"TMapObjBillboard::touchActor": 0x801a1780,
		"TManhole::TManhole": 0x801a1868,
		"TManhole::initMapObj": 0x801a18d4,
		"TManhole::loadAfter": 0x801a1948,
		"TManhole::makeManholeUnuseful": 0x801a1988,
		"makeManholeUnuseful": 0x801a1988,
		"TManhole::setGroundCollision": 0x801a19ec,
		"TManhole::calc": 0x801a1ad8,
		"TManhole::appeared": 0x801a1bb0,
		"TManhole::animationFinished": 0x801a1d70,
		"animationFinished": 0x801a1d70,
		"TManhole::touchPlayer": 0x801a1ef4,
		"TDoor::TDoor": 0x801a2208,
		"TDoor::load": 0x801a2254,
		"TDoor::touchPlayer": 0x801a22b0,
		"MoveBG::__sinit_MapObjTown_cpp": 0x801a28fc,
		"__sinit_MapObjTown_cpp": 0x801a28fc,
		"TSuperHipDropBlock::loadAfter": 0x801a2cf4,
		"TSuperHipDropBlock::receiveMessage": 0x801a2d78,
		"TTelesaBlock::setGroundCollision": 0x801a2e18,
		"TTelesaBlock::perform": 0x801a2e6c,
		"TTelesaBlock::initMapObj": 0x801a3008,
		"TJuiceBlock::kill": 0x801a3094,
		"TJuiceBlock::moveObject": 0x801a30c8,
		"TJuiceBlock::initMapObj": 0x801a3120,
		"TBrickBlock::initMapObj": 0x801a3174,
		"TBrickBlock::receiveMessage": 0x801a323c,
		"TBrickBlock::kill": 0x801a3318,
		"TIceBlock::initMapObj": 0x801a33e8,
		"TIceBlock::calc": 0x801a3478,
		"TIceBlock::control": 0x801a34dc,
		"TIceBlock::touchWater": 0x801a36bc,
		"TIceBlock::getSDLModelFlag": 0x801a3844,
		"TLeanBlock::TLeanBlock": 0x801a384c,
		"TLeanBlock::initMapObj": 0x801a38f4,
		"TLeanBlock::calcDefaultMtx": 0x801a3974,
		"TLeanBlock::calcLeanMtx": 0x801a39ac,
		"calcLeanMtx": 0x801a39ac,
		"TLeanBlock::control": 0x801a3afc,
		"TLeanBlock::touchPlayer": 0x801a3c68,
		"TSandBlock::initMapObj": 0x801a3d0c,
		"TSandBlock::control": 0x801a3dc0,
		"TSandBlock::touchPlayer": 0x801a401c,
		"TBreakableBlock::touchPlayer": 0x801a406c,
		"MoveBG::__sinit_MapObjBlock_cpp": 0x801a43a4,
		"__sinit_MapObjBlock_cpp": 0x801a43a4,
		"TWoodLog::control": 0x801a477c,
		"TBellWatermill::TBellWatermill": 0x801a4874,
		"TBellWatermill::loadAfter": 0x801a48f0,
		"TBellWatermill::control": 0x801a4a20,
		"TBellWatermill::touchWater": 0x801a51fc,
		"TBiancoBell::TBiancoBell": 0x801a5264,
		"TBiancoBell::initMapObj": 0x801a52b4,
		"TBiancoBell::touchPlayer": 0x801a5348,
		"TBiancoBell::touchWater": 0x801a5468,
		"TLampSeesawMain::TLampSeesawMain": 0x801a558c,
		"TLampSeesawMain::loadAfter": 0x801a5698,
		"TLampSeesawMain::control": 0x801a575c,
		"TLampSeesawMain::touchPlayer": 0x801a5948,
		"TLampSeesawMain::pushDown": 0x801a5994,
		"TLampSeesaw::TLampSeesaw": 0x801a59ac,
		"TLampSeesaw::load": 0x801a5a00,
		"TLampSeesaw::touchPlayer": 0x801a5a78,
		"TLampSeesaw::pushDown": 0x801a5ac8,
		"TLeafBoatRotten::TLeafBoatRotten": 0x801a5acc,
		"TLeafBoatRotten::load": 0x801a5bb0,
		"TLeafBoatRotten::perform": 0x801a5c1c,
		"TLeafBoatRotten::control": 0x801a5c3c,
		"TLeafBoat::TLeafBoat": 0x801a5ef8,
		"TLeafBoat::initMapObj": 0x801a5f90,
		"TLeafBoat::calc": 0x801a5fd8,
		"TLeafBoat::control": 0x801a60b0,
		"TLeafBoat::bind": 0x801a6274,
		"TLeafBoat::touchWall": 0x801a64bc,
		"TLeafBoat::touchActor": 0x801a65f4,
		"TBiancoMiniWindmill::TBiancoMiniWindmill": 0x801a67a4,
		"TBiancoMiniWindmill::initMapObj": 0x801a6870,
		"TBiancoMiniWindmill::control": 0x801a698c,
		"TBiancoMiniWindmill::calc": 0x801a69fc,
		"TBiancoMiniWindmill::touchWater": 0x801a6b98,
		"TBiancoWatermillVertical::TBiancoWatermillVertical": 0x801a6cb4,
		"TBiancoWatermillVertical::load": 0x801a6d18,
		"TBiancoWatermillVertical::loadAfter": 0x801a6d78,
		"TBiancoWatermillVertical::control": 0x801a6e3c,
		"TBiancoWatermillVertical::setGroundCollision": 0x801a7004,
		"TBiancoWatermillVertical::touchWater": 0x801a7078,
		"TBiancoWatermill::TBiancoWatermill": 0x801a71f0,
		"TBiancoWatermill::initMapObj": 0x801a7244,
		"TBiancoWatermill::control": 0x801a72b4,
		"TBiancoWatermill::touchWater": 0x801a7338,
		"TBiancoWatermill::turnByEnemy": 0x801a7340,
		"turnByEnemy": 0x801a7340,
		"TMapObjRootPakkun::initMapObj": 0x801a7344,
		"TMapObjRootPakkun::drawObject": 0x801a73a4,
		"TBigWindmill::load": 0x801a7438,
		"TBigWindmill::control": 0x801a7518,
		"MoveBG::__sinit_MapObjBianco_cpp": 0x801a7bc0,
		"__sinit_MapObjBianco_cpp": 0x801a7bc0,
		"TWaterHitPictureHideObj::getObjAppearPos": 0x801a7fb8,
		"TPictureTelesa::control": 0x801a7fc0,
		"TPictureTelesa::touchActor": 0x801a800c,
		"TPictureTelesa::afterFinishedAnim": 0x801a8170,
		"TPanelRevolve::control": 0x801a8218,
		"TPanelRevolve::touchPlayer": 0x801a8284,
		"TPanelRevolve::receiveMessage": 0x801a8324,
		"TChestRevolve::control": 0x801a83bc,
		"TChestRevolve::touchWater": 0x801a8420,
		"TWarpAreaActor::TWarpAreaActor": 0x801a848c,
		"TWarpAreaActor::load": 0x801a84dc,
		"TWarpAreaActor::perform": 0x801a8598,
		"TSirenaCasinoRoof::getSDLModelFlag": 0x801a8634,
		"TSirenaCasinoRoof::perform": 0x801a863c,
		"TSirenaCasinoRoof::initMapObj": 0x801a869c,
		"TSirenabossWall::getSDLModelFlag": 0x801a8770,
		"TSirenabossWall::drawObject": 0x801a8778,
		"TSirenabossWall::perform": 0x801a87ac,
		"TSirenabossWall::initMapObj": 0x801a880c,
		"TSakuCasino::calcRootMatrix": 0x801a88d0,
		"TSakuCasino::loadAfter": 0x801a8a04,
		"TSakuCasino::initMapObj": 0x801a8a68,
		"TSakuCasino::TSakuCasino": 0x801a8b78,
		"TCloset::touchWater": 0x801a8bd4,
		"TCloset::calcRootMatrix": 0x801a8d34,
		"TCloset::moveObject": 0x801a8e60,
		"TCloset::initMapObj": 0x801a91ec,
		"TCloset::TCloset": 0x801a93e4,
		"TDonchou::touchWater": 0x801a9490,
		"TDonchou::calcRootMatrix": 0x801a94bc,
		"TDonchou::loadAfter": 0x801a9730,
		"TDonchou::initMapObj": 0x801a97f8,
		"TDonchou::TDonchou": 0x801a9910,
		"TCasinoPanelGate::touchWater": 0x801a996c,
		"TCasinoPanelGate::calcRootMatrix": 0x801a9bf0,
		"TCasinoPanelGate::moveObject": 0x801a9cbc,
		"TCasinoPanelGate::initMapObj": 0x801aa0d0,
		"TCasinoPanelGate::TCasinoPanelGate": 0x801aa1d0,
		"TItemSlotDrum::getResultFromAng": 0x801aa27c,
		"TItemSlotDrum::getForcastResult": 0x801aa2c0,
		"TItemSlotDrum::generateItem": 0x801aa41c,
		"TItemSlotDrum::touchWater": 0x801aa908,
		"TItemSlotDrum::calcRootMatrix": 0x801aaa98,
		"TItemSlotDrum::moveObject": 0x801aabc8,
		"TItemSlotDrum::loadAfter": 0x801ab134,
		"TItemSlotDrum::TItemSlotDrum": 0x801ab1e0,
		"TSlotDrum::touchWater": 0x801ab30c,
		"TSlotDrum::calcRootMatrix": 0x801ab434,
		"TSlotDrum::moveObject": 0x801ab4e4,
		"TSlotDrum::initNeonMatColor": 0x801ab9b0,
		"TSlotDrum::initMapObj": 0x801aba70,
		"TSlotDrum::TSlotDrum": 0x801abc00,
		"TSirenaRollMapObj::TSirenaRollMapObj": 0x801abca4,
		"MoveBG::partsRollCallback": 0x801abd30,
		"partsRollCallback": 0x801abd30,
		"TRoulette::switchStop": 0x801abe90,
		"switchStop": 0x801abe90,
		"TRoulette::setRollSp": 0x801abfb0,
		"setRollSp": 0x801abfb0,
		"TRoulette::calcRootMatrix": 0x801abfd4,
		"TRoulette::moveObject": 0x801ac078,
		"TRoulette::perform": 0x801ac16c,
		"TRoulette::initMapObj": 0x801ac1cc,
		"TRoulette::TRoulette": 0x801ac390,
		"TRouletteSw::perform": 0x801ac464,
		"TRouletteSw::receiveMessage": 0x801ac498,
		"TCloset::getRollAngY": 0x801ac86c,
		"TCasinoPanelGate::getRollAngX": 0x801ac99c,
		"MoveBG::__sinit_MapObjSirena_cpp": 0x801acb50,
		"__sinit_MapObjSirena_cpp": 0x801acb50,
		"TFruitLauncher::loadAfter": 0x801acf40,
		"TFruitLauncher::fireObj": 0x801ad194,
		"fireObj": 0x801ad194,
		"TLiveActor::getMActor": 0x801ad760,
		"TFruitSwitch::receiveMessage": 0x801ad768,
		"TSurfGesoObj::initMapObj": 0x801ad7e8,
		"TRiccoWatermill::TRiccoWatermill": 0x801ad8f8,
		"TRiccoWatermill::loadAfter": 0x801ad964,
		"TRiccoWatermill::calc": 0x801ada44,
		"TRiccoWatermill::control": 0x801ada64,
		"TRiccoWatermill::touchWater": 0x801ade6c,
		"TCraneCargo::calc": 0x801adf5c,
		"TCraneCargo::control": 0x801adfa0,
		"TCraneUpDown::initMapObj": 0x801adfd0,
		"TCraneUpDown::control": 0x801ae0f0,
		"TCraneRotY::load": 0x801ae3f4,
		"TCraneRotY::control": 0x801ae4b0,
		"TCraneRotY::calc": 0x801ae64c,
		"MoveBG::__sinit_MapObjRicco_cpp": 0x801ae9b4,
		"__sinit_MapObjRicco_cpp": 0x801ae9b4,
		"TSandEgg::getSDLModelFlag": 0x801aed94,
		"TMammaMirrorMapOperator::TMammaMirrorMapOperator": 0x801aed9c,
		"TMammaMirrorMapOperator::loadAfter": 0x801aef38,
		"TMammaMirrorMapOperator::perform": 0x801af1f4,
		"TGoalWatermelon::TGoalWatermelon": 0x801af444,
		"TGoalWatermelon::load": 0x801af4a4,
		"TGoalWatermelon::loadAfter": 0x801af51c,
		"TGoalWatermelon::control": 0x801af5cc,
		"TGoalWatermelon::touchActor": 0x801af64c,
		"TSandBird::TSandBird": 0x801af758,
		"TSandBird::initMapObj": 0x801af82c,
		"TSandBird::nameIsObj": 0x801af8bc,
		"TSandBird::makeObjFromJointName": 0x801af8f8,
		"TSandBird::control": 0x801af984,
		"TMammaYacht::initMapObj": 0x801afbd0,
		"TMammaYacht::control": 0x801afca4,
		"TMammaBlockRotate::TMammaBlockRotate": 0x801afd44,
		"TMammaBlockRotate::load": 0x801afd9c,
		"TMammaBlockRotate::initMapObj": 0x801afe64,
		"TMammaBlockRotate::control": 0x801affdc,
		"TMammaBlockRotate::touchWater": 0x801b023c,
		"TShiningStone::TShiningStone": 0x801b028c,
		"TShiningStone::load": 0x801b02f4,
		"TShiningStone::perform": 0x801b0544,
		"TShiningStone::putOnLight": 0x801b061c,
		"putOnLight": 0x801b061c,
		"TLeanMirror::TLeanMirror": 0x801b08bc,
		"TLeanMirror::load": 0x801b097c,
		"TLeanMirror::initMapObj": 0x801b0ab8,
		"TLeanMirror::getSDLModelFlag": 0x801b0b90,
		"TLeanMirror::loadAfter": 0x801b0b98,
		"TLeanMirror::control": 0x801b0cc0,
		"TLeanMirror::controlShake": 0x801b0ecc,
		"controlShake": 0x801b0ecc,
		"TLeanMirror::controlGoTarget": 0x801b1200,
		"controlGoTarget": 0x801b1200,
		"MoveBG::startCameraShakeSE": 0x801b13bc,
		"startCameraShakeSE": 0x801b13bc,
		"TLeanMirror::release": 0x801b13c4,
		"TLeanMirror::touchEnemy": 0x801b1614,
		"TLeanMirror::touchPlayer": 0x801b16f4,
		"TLeanMirror::receiveMessage": 0x801b1808,
		"TLeanMirror::draw": 0x801b1a24,
		"TSandCastle::TSandCastle": 0x801b1b84,
		"TSandCastle::initMapObj": 0x801b1d40,
		"TSandCastle::loadAfter": 0x801b1d84,
		"TSandCastle::findTriggerActor": 0x801b1e38,
		"TSandCastle::calcRootMatrix": 0x801b1e98,
		"TSandCastle::waitBeforeExplode": 0x801b1ed8,
		"MoveBG::SandCastleCallBack": 0x801b1f58,
		"SandCastleCallBack": 0x801b1f58,
		"TSandCastle::explode": 0x801b1fec,
		"TSandCastle::expanded": 0x801b2154,
		"TSandCastle::withering": 0x801b2248,
		"TSandBombBase::TSandBombBase": 0x801b2388,
		"TSandBombBase::initMapObj": 0x801b2408,
		"TSandBombBase::loadAfter": 0x801b2538,
		"TSandBombBase::findTriggerActor": 0x801b2590,
		"TSandBombBase::control": 0x801b25d8,
		"TSandBombBase::grow": 0x801b2870,
		"TSandBombBase::waitBeforeExplode": 0x801b287c,
		"TSandBombBase::explode": 0x801b2890,
		"TSandBombBase::exploding": 0x801b29d0,
		"exploding": 0x801b29d0,
		"TSandBombBase::expanded": 0x801b2b54,
		"TSandBombBase::withered": 0x801b2c14,
		"withered": 0x801b2c14,
		"TSandBomb::initMapObj": 0x801b2c48,
		"TSandBomb::getSDLModelFlag": 0x801b2c68,
		"TSandBomb::touchWater": 0x801b2c70,
		"TSandBomb::makeObjAppeared": 0x801b2dbc,
		"TSandLeafBase::initMapObj": 0x801b2e00,
		"TSandLeafBase::control": 0x801b2e94,
		"TSandLeafBase::grow": 0x801b3054,
		"TSandBase::TSandBase": 0x801b31e0,
		"TSandBase::withering": 0x801b3238,
		"TSandLeaf::control": 0x801b32e4,
		"TSandLeaf::touchWater": 0x801b333c,
		"TMammaMirrorMapOperator::~TMammaMirrorMapOperator": 0x801b3370,
		"TMapObjBall::getDepthAtFloating": 0x801b34ec,
		"MoveBG::__sinit_MapObjMamma_cpp": 0x801b3974,
		"__sinit_MapObjMamma_cpp": 0x801b3974,
		"TPinnaCoaster::TPinnaCoaster": 0x801b3d64,
		"TPinnaCoaster::initMapObj": 0x801b3dc0,
		"TPinnaCoaster::control": 0x801b3eb8,
		"TAmiKing::touchPlayer": 0x801b4050,
		"TAmiKing::bind": 0x801b4074,
		"TAmiKing::moveObject": 0x801b4248,
		"TAmiKing::initMapObj": 0x801b45b0,
		"TAmiKing::loadAfter": 0x801b4638,
		"TWaterRecoverObj::touchPlayer": 0x801b4694,
		"TPinnaEntrance::loadAfter": 0x801b4724,
		"TBalloonKoopaJr::load": 0x801b478c,
		"TBalloonKoopaJr::kill": 0x801b48ac,
		"TBalloonKoopaJr::touchActor": 0x801b4958,
		"TChangeStageMerrygoround::calc": 0x801b4984,
		"TChangeStageMerrygoround::touchPlayer": 0x801b49e8,
		"TMerrygoround::TMerrygoround": 0x801b4abc,
		"TMerrygoround::initMapObj": 0x801b4bb8,
		"TMerrygoround::draw": 0x801b4ea4,
		"TMerrygoround::control": 0x801b4ea8,
		"TShellCup::TShellCup": 0x801b5060,
		"TPinnaShell::TPinnaShell": 0x801b5160,
		"TShellCup::initMapObj": 0x801b5208,
		"TShellCup::loadAfter": 0x801b5458,
		"TShellCup::perform": 0x801b55d0,
		"MoveBG::MsMtxSetRotX": 0x801b571c,
		"MsMtxSetRotX": 0x801b571c,
		"TShellCup::control": 0x801b5798,
		"TPinnaShell::control": 0x801b57fc,
		"TPinnaShell::receiveMessage": 0x801b5b70,
		"TViking::TViking": 0x801b5c20,
		"TViking::initMapObj": 0x801b5d28,
		"TViking::loadAfter": 0x801b5de8,
		"TViking::reset": 0x801b5e28,
		"TViking::control": 0x801b5e5c,
		"TViking::roll": 0x801b5fc0,
		"roll": 0x801b5fc0,
		"THorizontalViking::initMapObj": 0x801b6364,
		"THorizontalViking::reset": 0x801b63bc,
		"THorizontalViking::control": 0x801b63f0,
		"TFerrisWheel::TFerrisWheel": 0x801b6514,
		"TFerrisWheel::initMapObj": 0x801b656c,
		"TFerrisWheel::control": 0x801b66b0,
		"TFerrisWheel::becomeCalmlyCallback": 0x801b6848,
		"becomeCalmlyCallback": 0x801b6848,
		"TAmiKing::touchWater": 0x801b694c,
		"MoveBG::__sinit_MapObjPinna_cpp": 0x801b6dd8,
		"__sinit_MapObjPinna_cpp": 0x801b6dd8,
		"TGateShadow::~TGateShadow": 0x801b7134,
		"TGateShadow::perform": 0x801b71a8,
		"MoveBG::__sinit_MapObjSample_cpp": 0x801b71ac,
		"__sinit_MapObjSample_cpp": 0x801b71ac,
		"TMareEventPoint::load": 0x801b752c,
		"TMareEventPoint::receiveMessage": 0x801b7580,
		"TMareCork::drawObject": 0x801b7674,
		"TMareCork::getTakingMtx": 0x801b7758,
		"TMareCork::calcRootMatrix": 0x801b776c,
		"TMareCork::moveObject": 0x801b7864,
		"TMareCork::loadAfter": 0x801b78d8,
		"TMareFall::load": 0x801b7a24,
		"TMareFall::calc": 0x801b7ab4,
		"TMuddyBoat::TMuddyBoat": 0x801b7b74,
		"TMuddyBoat::initMapObj": 0x801b7c10,
		"TMuddyBoat::getSDLModelFlag": 0x801b7ce0,
		"TMuddyBoat::calc": 0x801b7ce8,
		"TMuddyBoat::control": 0x801b7ea0,
		"TMuddyBoat::bind": 0x801b8138,
		"TMapObjBase::getObjCollisionHeightOffset": 0x801b868c,
		"getObjCollisionHeightOffset": 0x801b868c,
		"TMuddyBoat::kill": 0x801b8694,
		"TMuddyBoat::calcRootMatrix": 0x801b877c,
		"TMuddyBoat::moveByWater": 0x801b8780,
		"moveByWater": 0x801b8780,
		"TMapObjPuncher::load": 0x801b8930,
		"TMapObjPuncher::control": 0x801b89b0,
		"TMapObjPuncher::touchPlayer": 0x801b8aa4,
		"TWireBell::TWireBell": 0x801b8c18,
		"TWireBell::loadAfter": 0x801b8c94,
		"TWireBell::control": 0x801b8cd0,
		"TWireBell::draw": 0x801b8d70,
		"TWireBell::initDraw": 0x801b8ed4,
		"TMapObjGrowTree::TMapObjGrowTree": 0x801b90e0,
		"TMapObjGrowTree::initMapObj": 0x801b9140,
		"TMapObjGrowTree::loadAfter": 0x801b91a4,
		"TMapObjGrowTree::control": 0x801b91d8,
		"TMapObjGrowTree::touchWater": 0x801b94ac,
		"TMapObjElasticCode::initMapObj": 0x801b9794,
		"TMapObjElasticCode::control": 0x801b97e0,
		"TMapObjElasticCode::draw": 0x801b98f0,
		"TCogwheel::TCogwheel": 0x801b9ae4,
		"TCogwheel::initMapObj": 0x801b9b70,
		"TCogwheel::control": 0x801b9dfc,
		"TCogwheel::calc": 0x801b9fbc,
		"TCogwheel::draw": 0x801ba080,
		"TCogwheel::initDraw": 0x801ba30c,
		"TCogwheelScale::TCogwheelScale": 0x801ba518,
		"TCogwheelScale::control": 0x801ba590,
		"TCogwheelScale::touchPlayer": 0x801ba640,
		"TCogwheelScale::receiveMessage": 0x801ba748,
		"TCogwheelScale::touchWater": 0x801ba794,
		"MoveBG::__sinit_MapObjMare_cpp": 0x801bac5c,
		"__sinit_MapObjMare_cpp": 0x801bac5c,
		"TMapObjFlagManager::~TMapObjFlagManager": 0x801bafc0,
		"TMapObjFlagManager::TMapObjFlagManager": 0x801bb034,
		"TMapObjFlagManager::TMapObjFlagInfo::TMapObjFlagInfo": 0x801bb0c0,
		"TMapObjFlagManager::load": 0x801bb0d0,
		"TMapObjFlagManager::registerObj": 0x801bb164,
		"registerObj": 0x801bb164,
		"TMapObjFlagManager::perform": 0x801bb78c,
		"TMapObjFlagManager::initDraw": 0x801bb99c,
		"TMapObjFlag::TMapObjFlag": 0x801bbb64,
		"TMapObjFlag::load": 0x801bbc58,
		"TMapObjFlag::init": 0x801bbcac,
		"TMapObjFlag::updateVertex": 0x801bbf8c,
		"updateVertex": 0x801bbf8c,
		"TMapObjFlag::draw": 0x801bc0c4,
		"MoveBG::__sinit_MapObjFlag_cpp": 0x801bc400,
		"__sinit_MapObjFlag_cpp": 0x801bc400,
		"TMapObjWave::~TMapObjWave": 0x801bc704,
		"TMapObjWave::TMapObjWave": 0x801bc778,
		"TMapObjWave::load": 0x801bc980,
		"TMapObjWave::perform": 0x801bcb50,
		"TMapObjWave::updateTime": 0x801bcbd8,
		"updateTime": 0x801bcbd8,
		"TMapObjWave::updateHeightAndAlpha": 0x801bcc7c,
		"updateHeightAndAlpha": 0x801bcc7c,
		"TMapObjWave::draw": 0x801bcf94,
		"TMapObjWave::noWave": 0x801bd2c0,
		"noWave": 0x801bd2c0,
		"TMapObjWave::getHeight": 0x801bd2e0,
		"TMapObjWave::getWaveHeight": 0x801bd40c,
		"getWaveHeight": 0x801bd40c,
		"TMapObjWave::initDraw": 0x801bd498,
		"MoveBG::__sinit_MapObjWave_cpp": 0x801bd7c4,
		"__sinit_MapObjWave_cpp": 0x801bd7c4,
		"TMapObjFloatOnSea::TMapObjFloatOnSea": 0x801bdb64,
		"TMapObjFloatOnSea::initMapObj": 0x801bdbcc,
		"TMapObjFloatOnSea::calc": 0x801bdcec,
		"TMapObjFloatOnSea::control": 0x801bdd90,
		"TMapObjFloatOnSea::touchPlayer": 0x801bde10,
		"MoveBG::__sinit_MapObjFloat_cpp": 0x801bde54,
		"__sinit_MapObjFloat_cpp": 0x801bde54,
		"TMapObjPlane::hasMapCollision": 0x801be1dc,
		"TSandPlane::load": 0x801be1e4,
		"TRockPlane::load": 0x801be260,
		"TMapObjPlane::TMapObjPlane": 0x801be2dc,
		"TMapObjPlane::load": 0x801be350,
		"TMapObjPlane::makeMountain": 0x801be4bc,
		"makeMountain": 0x801be4bc,
		"TMapObjPlane::perform": 0x801be618,
		"TMapObjPlane::receiveMessage": 0x801be664,
		"TMapObjPlane::depress": 0x801be6c4,
		"depress": 0x801be6c4,
		"TMapObjPlane::calcNrm": 0x801be974,
		"calcNrm": 0x801be974,
		"TMapObjPlane::updateCheckData": 0x801bee38,
		"updateCheckData": 0x801bee38,
		"TMapObjPlane::draw": 0x801bf008,
		"TMapObjPlane::initDraw": 0x801bf1e0,
		"MoveBG::__sinit_MapObjPlane_cpp": 0x801bf568,
		"__sinit_MapObjPlane_cpp": 0x801bf568,
		"TRideCloud::perform": 0x801bf918,
		"TRideCloud::control": 0x801bf950,
		"TRideCloud::getShadowType": 0x801bfc54,
		"TRideCloud::load": 0x801bfc5c,
		"TRideCloud::initMapObj": 0x801bfda8,
		"TRideCloud::calcRootMatrix": 0x801bfddc,
		"TRideCloud::setGroundCollision": 0x801bfe88,
		"TRideCloud::touchWater": 0x801bff00,
		"TRideCloud::TRideCloud": 0x801bff28,
		"MoveBG::__sinit_MapObjCloud_cpp": 0x801c0034,
		"__sinit_MapObjCloud_cpp": 0x801c0034,
		"TBigWatermelon::TBigWatermelon": 0x801c03d4,
		"TBigWatermelon::initMapObj": 0x801c04c8,
		"TBigWatermelon::loadAfter": 0x801c061c,
		"TBigWatermelon::receiveMessage": 0x801c0698,
		"TBigWatermelon::checkWallCollision": 0x801c07d4,
		"TBigWatermelon::startEvent": 0x801c07f4,
		"TBigWatermelon::control": 0x801c0a14,
		"TBigWatermelon::appearing": 0x801c0ca4,
		"TBigWatermelon::kill": 0x801c0db4,
		"TBigWatermelon::touchActor": 0x801c0f14,
		"TBigWatermelon::touchGround": 0x801c120c,
		"TBigWatermelon::rebound": 0x801c122c,
		"TBigWatermelon::touchWall": 0x801c1430,
		"TBigWatermelon::touchWaterSurface": 0x801c1450,
		"TCoverFruit::loadAfter": 0x801c14c0,
		"TCoverFruit::receiveMessage": 0x801c1518,
		"TCoverFruit::calcRootMatrix": 0x801c15b8,
		"TRandomFruit::TRandomFruit": 0x801c16fc,
		"TRandomFruit::initMapObj": 0x801c182c,
		"TResetFruit::TResetFruit": 0x801c196c,
		"TResetFruit::initMapObj": 0x801c19d4,
		"TResetFruit::receiveMessage": 0x801c1a18,
		"TResetFruit::getLivingTime": 0x801c1df4,
		"TResetFruit::makeObjAppeared": 0x801c1dfc,
		"TResetFruit::killByTimer": 0x801c1f2c,
		"TResetFruit::perform": 0x801c1f48,
		"TResetFruit::control": 0x801c212c,
		"TResetFruit::appearing": 0x801c275c,
		"TResetFruit::breaking": 0x801c285c,
		"TResetFruit::kicked": 0x801c2978,
		"TResetFruit::makeObjLiving": 0x801c2c1c,
		"makeObjLiving": 0x801c2c1c,
		"TResetFruit::touchGround": 0x801c2c9c,
		"TResetFruit::touchActor": 0x801c2dc4,
		"TResetFruit::touchWater": 0x801c2ef8,
		"TResetFruit::touchWaterSurface": 0x801c3048,
		"TResetFruit::touchPollution": 0x801c314c,
		"TResetFruit::hold": 0x801c3278,
		"TResetFruit::thrown": 0x801c33c4,
		"TResetFruit::makeObjWaitingToAppear": 0x801c33f8,
		"makeObjWaitingToAppear": 0x801c33f8,
		"TResetFruit::waitingToAppear": 0x801c34c4,
		"TResetFruit::checkGroundCollision": 0x801c3600,
		"TMapObjBall::TMapObjBall": 0x801c3798,
		"TMapObjBall::initMapObj": 0x801c3840,
		"TMapObjBall::receiveMessage": 0x801c3d34,
		"TMapObjBall::control": 0x801c3e2c,
		"TMapObjBall::makeObjAppeared": 0x801c3f3c,
		"TMapObjBall::makeObjDefault": 0x801c4034,
		"TMapObjBall::checkWallCollision": 0x801c408c,
		"TMapObjBall::calcCurrentMtx": 0x801c4168,
		"calcCurrentMtx": 0x801c4168,
		"TMapObjBall::touchActor": 0x801c4598,
		"TMapObjBall::boundByActor": 0x801c46ec,
		"boundByActor": 0x801c46ec,
		"TMapObjBall::touchWater": 0x801c4c40,
		"TMapObjBall::kicked": 0x801c4d40,
		"TMapObjBall::hold": 0x801c4f5c,
		"TMapObjBall::put": 0x801c4ff4,
		"TMapObjBall::touchGround": 0x801c5034,
		"TMapObjBall::rebound": 0x801c5308,
		"TMapObjBall::touchWaterSurface": 0x801c5490,
		"TMapObjBall::touchPollution": 0x801c54bc,
		"TMapObjBall::touchWall": 0x801c54e8,
		"TMapObjBall::touchRoof": 0x801c584c,
		"MoveBG::__sinit_MapObjBall_cpp": 0x801c59b8,
		"__sinit_MapObjBall_cpp": 0x801c59b8,
		"TAirportEventSink::~TAirportEventSink": 0x801c5cdc,
		"TAirportEventSink::TAirportEventSink": 0x801c5d70,
		"TAirportEventSink::loadAfter": 0x801c5dd4,
		"TAirportEventSink::watch": 0x801c5e68,
		"TAirportEventSink::control": 0x801c5f38,
		"TAirportEventSink::finishControl": 0x801c5fac,
		"TAirportSwitch::TAirportSwitch": 0x801c603c,
		"TAirportSwitch::loadAfter": 0x801c6088,
		"TAirportSwitch::breaking": 0x801c60fc,
		"MoveBG::__sinit_MapObjAirport_cpp": 0x801c6264,
		"__sinit_MapObjAirport_cpp": 0x801c6264,
		"TTurboNozzleDoor::touchPlayer": 0x801c65ec,
		"TTurboNozzleDoor::loadAfter": 0x801c6758,
		"TDemoCannon::perform": 0x801c68b4,
		"TDemoCannon::startDemo": 0x801c6b5c,
		"TDemoCannon::initMapObj": 0x801c6bc8,
		"TDemoCannon::loadAfter": 0x801c6d24,
		"TMareGate::loadAfter": 0x801c6e78,
		"TMareGate::control": 0x801c6ed0,
		"TMapObjSmoke::load": 0x801c6f38,
		"TMapObjSmoke::control": 0x801c6f94,
		"TMapObjSmoke::touchWater": 0x801c6fc0,
		"TDptMonteFence::touchPlayer": 0x801c7014,
		"TBellDolpic::control": 0x801c70bc,
		"TBellDolpic::receiveMessage": 0x801c72cc,
		"TBellDolpic::touchPlayer": 0x801c7444,
		"TBellDolpic::ring": 0x801c7468,
		"ring": 0x801c7468,
		"TBellDolpic::calcRootMatrix": 0x801c7604,
		"TBellDolpic::initMapObj": 0x801c766c,
		"TBellDolpic::TBellDolpic": 0x801c773c,
		"TMonumentShine::control": 0x801c77c4,
		"TMonumentShine::receiveMessage": 0x801c7a60,
		"TMonumentShine::hitByWater": 0x801c7ba4,
		"hitByWater": 0x801c7ba4,
		"TMonumentShine::initMapObj": 0x801c7d30,
		"TMonumentShine::TMonumentShine": 0x801c7de0,
		"MoveBG::__sinit_MapObjDolpic_cpp": 0x801c8178,
		"__sinit_MapObjDolpic_cpp": 0x801c8178,
		"TMapObjRevivalPollution::~TMapObjRevivalPollution": 0x801c84ac,
		"TMapObjRevivalPollution::TMapObjRevivalPollution": 0x801c8520,
		"TMapObjRevivalPollution::load": 0x801c8590,
		"TMapObjRevivalPollution::loadAfter": 0x801c8678,
		"TMapObjRevivalPollution::perform": 0x801c8724,
		"TRevivalPolluter::TRevivalPolluter": 0x801c8784,
		"TPolluterBase::TPolluterBase": 0x801c87ac,
		"TPolluterBase::load": 0x801c87f8,
		"TPolluterBase::perform": 0x801c8918,
		"MoveBG::__sinit_MapObjPollution_cpp": 0x801c89f8,
		"__sinit_MapObjPollution_cpp": 0x801c89f8,
		"TMapObjGrassManager::~TMapObjGrassManager": 0x801c8cfc,
		"TMapObjGrassManager::TMapObjGrassManager": 0x801c8d70,
		"TMapObjGrassManager::load": 0x801c8e34,
		"TMapObjGrassManager::perform": 0x801c8e84,
		"TMapObjGrassManager::initDrawNear": 0x801c90bc,
		"initDrawNear": 0x801c90bc,
		"TMapObjGrassGroup::TMapObjGrassGroup": 0x801c9308,
		"TMapObjGrassGroup::load": 0x801c936c,
		"TMapObjGrassGroup::drawFar": 0x801c95f8,
		"drawFar": 0x801c95f8,
		"TMapObjGrassGroup::drawNear": 0x801c9720,
		"drawNear": 0x801c9720,
		"MoveBG::__sinit_MapObjGrass_cpp": 0x801c98c8,
		"__sinit_MapObjGrass_cpp": 0x801c98c8,
		"TMapObjPoleManager::~TMapObjPoleManager": 0x801c9bdc,
		"TMapObjPoleManager::TMapObjPoleManager": 0x801c9c50,
		"TMapObjPoleManager::TMapObjPoleInfo::TMapObjPoleInfo": 0x801c9cdc,
		"TMapObjPoleManager::load": 0x801c9cec,
		"TMapObjPoleManager::perform": 0x801c9d28,
		"TMapObjPoleManager::initDraw": 0x801c9dd4,
		"TMapObjPole::draw": 0x801c9fa4,
		"MoveBG::__sinit_MapObjPole_cpp": 0x801ca0fc,
		"__sinit_MapObjPole_cpp": 0x801ca0fc,
		"TMapObjWaterFilter::TMapObjWaterFilter": 0x801ca464,
		"TMapObjWaterFilter::init": 0x801ca56c,
		"TMapObjWaterFilter::perform": 0x801ca5b8,
		"TMapObjSeaIndirect::TMapObjSeaIndirect": 0x801ca74c,
		"TMapObjSeaIndirect::init": 0x801ca844,
		"TMapObjSeaIndirect::perform": 0x801ca96c,
		"MoveBG::__sinit_MapObjWater_cpp": 0x801ca9dc,
		"__sinit_MapObjWater_cpp": 0x801ca9dc,
		"TModelGate::getTakingMtx": 0x801cad84,
		"TModelGate::perform": 0x801cad8c,
		"TModelGate::receiveMessage": 0x801cb954,
		"TModelGate::screenBlur": 0x801cbafc,
		"screenBlur": 0x801cbafc,
		"TModelGate::startOpen": 0x801cbd4c,
		"startOpen": 0x801cbd4c,
		"TModelGate::loadAfter": 0x801cbdc0,
		"MoveBG::__sinit_ModelGate_cpp": 0x801cc638,
		"__sinit_ModelGate_cpp": 0x801cc638,
		"TRailFence::TRailFence": 0x801cc9d8,
		"TRailFence::load": 0x801cca64,
		"TRailFence::initMapCollisionData": 0x801ccb04,
		"TRailFence::control": 0x801ccb24,
		"TRailFence::goOnRail": 0x801ccce0,
		"goOnRail": 0x801ccce0,
		"TRailFence::receiveMessage": 0x801ccefc,
		"TFenceWaterH::changeStatusToWait": 0x801ccf88,
		"TFenceWaterH::changeStatusToGo": 0x801ccfc0,
		"TFenceWaterH::control": 0x801cd030,
		"TFenceWater::initMapObj": 0x801cd2f8,
		"TFenceWater::initMapCollisionData": 0x801cd450,
		"TFenceWater::control": 0x801cd470,
		"TFenceWater::controlRotation": 0x801cd564,
		"controlRotation": 0x801cd564,
		"TFenceWater::changeStatusToWait": 0x801cd698,
		"TFenceWater::changeStatusToGo": 0x801cd6b0,
		"TFenceWater::receiveMessage": 0x801cd714,
		"TFenceWater::draw": 0x801cd78c,
		"TRevolvingFenceInner::initMapObj": 0x801cd790,
		"TRevolvingFenceInner::initMapCollisionData": 0x801cd874,
		"TRevolvingFenceInner::control": 0x801cd924,
		"TRevolvingFenceInner::setGroundCollision": 0x801cd970,
		"TRevolvingFenceInner::controlGroundRoof": 0x801cda78,
		"controlGroundRoof": 0x801cda78,
		"TRevolvingFenceInner::controlWall": 0x801cdb7c,
		"controlWall": 0x801cdb7c,
		"MoveBG::MsMtxSetRotY": 0x801cde3c,
		"MsMtxSetRotY": 0x801cde3c,
		"TRevolvingFenceInner::receiveMessage": 0x801cdf00,
		"TRevolvingFenceOuter::initMapCollisionData": 0x801ce19c,
		"TRevolvingFenceOuter::receiveMessage": 0x801ce31c,
		"TFence::initMapObj": 0x801ce378,
		"TFence::initMapCollisionData": 0x801ce3c4,
		"TFence::receiveMessage": 0x801ce53c,
		"MoveBG::__sinit_MapObjFence_cpp": 0x801ce7e8,
		"__sinit_MapObjFence_cpp": 0x801ce7e8,
		"TMapObjOptionWall::TMapObjOptionWall": 0x801ceb98,
		"TMapObjOptionWall::init": 0x801cebe4,
		"TMapObjOptionWall::offCollision": 0x801cec54,
		"offCollision": 0x801cec54,
		"TMapObjOptionWall::onCollision": 0x801cec84,
		"onCollision": 0x801cec84,
		"TFileLoadBlock::TFileLoadBlock": 0x801cecb4,
		"TFileLoadBlock::initMapObj": 0x801ced18,
		"TFileLoadBlock::loadAfter": 0x801cee00,
		"TFileLoadBlock::receiveMessage": 0x801cef80,
		"TFileLoadBlock::touchPlayer": 0x801cf074,
		"TFileLoadBlock::makeBlockRock": 0x801cf164,
		"makeBlockRock": 0x801cf164,
		"TFileLoadBlock::makeBlockNormal": 0x801cf19c,
		"makeBlockNormal": 0x801cf19c,
		"MoveBG::__sinit_MapObjOption_cpp": 0x801cf258,
		"__sinit_MapObjOption_cpp": 0x801cf258,
		"TWoodBlock::load": 0x801cf600,
		"TWoodBlock::calcRecycle": 0x801cf734,
		"TWoodBlock::TWoodBlock": 0x801cf994,
		"TRollBlock::control": 0x801cfac8,
		"TRollBlock::calcRootMatrix": 0x801cfb3c,
		"TRollBlock::getRootJointMtx": 0x801cfc78,
		"TRollBlock::setGroundCollision": 0x801cfc9c,
		"TRollBlock::load": 0x801cfcfc,
		"TRollBlock::TRollBlock": 0x801cfda4,
		"TRailBlock::control": 0x801cfdf4,
		"TRailBlock::calcRootMatrix": 0x801d03a0,
		"TRailBlock::getRootJointMtx": 0x801d0438,
		"TRailBlock::initMapObj": 0x801d045c,
		"TRailBlock::TRailBlock": 0x801d04dc,
		"TNormalLift::perform": 0x801d0598,
		"TNormalLift::setGroundCollision": 0x801d05f4,
		"TNormalLift::control": 0x801d06b0,
		"TNormalLift::initMapObj": 0x801d0864,
		"TNormalLift::readRailFlag": 0x801d08a8,
		"TNormalLift::load": 0x801d099c,
		"TNormalLift::resetPosition": 0x801d0ad8,
		"TNormalLift::TNormalLift": 0x801d0b90,
		"TRailMapObj::perform": 0x801d0c30,
		"TRailMapObj::control": 0x801d0c68,
		"TRailMapObj::readRailFlag": 0x801d0d84,
		"TRailMapObj::getShadowType": 0x801d0ddc,
		"TRailMapObj::setGroundCollision": 0x801d0de4,
		"TRailMapObj::load": 0x801d0e80,
		"TRailMapObj::initMapObj": 0x801d0f5c,
		"TRailMapObj::resetPosition": 0x801d0fa0,
		"TRailMapObj::calcRecycle": 0x801d104c,
		"TRailMapObj::checkMarioRiding": 0x801d11a0,
		"TRailMapObj::moveToNextNode": 0x801d1298,
		"moveToNextNode": 0x801d1298,
		"TRailMapObj::resetStep": 0x801d1550,
		"resetStep": 0x801d1550,
		"TRailMapObj::initGraphTracer": 0x801d15d0,
		"initGraphTracer": 0x801d15d0,
		"TRailMapObj::TRailMapObj": 0x801d1744,
		"TFluffManager::TFluffManager": 0x801d1980,
		"TFluffManager::load": 0x801d19fc,
		"TFluffManager::loadAfter": 0x801d1b90,
		"TFluffManager::control": 0x801d1f54,
		"TFluff::TFluff": 0x801d22c0,
		"TFluff::initMapObj": 0x801d234c,
		"TFluff::appear": 0x801d2388,
		"TFluff::control": 0x801d257c,
		"TFluff::kill": 0x801d28ac,
		"TFluff::move": 0x801d2910,
		"TFluff::touchWater": 0x801d2b4c,
		"TGoalFlag::initMapObj": 0x801d2bd8,
		"TGoalFlag::touchActor": 0x801d2bf8,
		"TSwingBoard::TSwingBoard": 0x801d2cdc,
		"TSwingBoard::load": 0x801d2d84,
		"TSwingBoard::control": 0x801d2fa0,
		"TSwingBoard::draw": 0x801d3294,
		"TSwingBoard::initDraw": 0x801d33a8,
		"TSwingBoard::drawOneRope": 0x801d35b4,
		"THangingBridge::THangingBridge": 0x801d3750,
		"THangingBridge::loadAfter": 0x801d37d4,
		"THangingBridge::perform": 0x801d3d70,
		"THangingBridge::initDraw": 0x801d3e74,
		"THangingBridge::drawRopeBetweenBoards": 0x801d40c8,
		"drawRopeBetweenBoards": 0x801d40c8,
		"THangingBridge::drawUpper": 0x801d4804,
		"THangingBridge::drawLowerPlus": 0x801d49e8,
		"drawLowerPlus": 0x801d49e8,
		"THangingBridge::drawLowerMinus": 0x801d4c64,
		"drawLowerMinus": 0x801d4c64,
		"THangingBridgeBoard::THangingBridgeBoard": 0x801d4ed8,
		"THangingBridgeBoard::initMapObj": 0x801d4f74,
		"THangingBridgeBoard::setGroundCollision": 0x801d4fb8,
		"THangingBridgeBoard::calcDefaultMtx": 0x801d50ac,
		"THangingBridgeBoard::control": 0x801d5114,
		"THangingBridgeBoard::drawOneRope": 0x801d538c,
		"TJumpMushroom::load": 0x801d5518,
		"TJumpMushroom::receiveMessage": 0x801d557c,
		"TMapObjMonteRoot::initMapObj": 0x801d55a4,
		"TFluff::getRadiusAtY": 0x801d567c,
		"TGoalFlag::getRadiusAtY": 0x801d5708,
		"THangingBridge::~THangingBridge": 0x801d5794,
		"MoveBG::__sinit_MapObjMonte_cpp": 0x801d59ac,
		"__sinit_MapObjMonte_cpp": 0x801d59ac,
		"TMapObjTree::getRadiusAtY": 0x801d5d7c,
		"TMapObjTreeScale::TMapObjTreeScale": 0x801d5da8,
		"TMapObjTreeScale::loadAfter": 0x801d6030,
		"TMapObjTreeScale::control": 0x801d616c,
		"TMapObjTreeScale::touchWater": 0x801d6528,
		"TMapObjTree::TMapObjTree": 0x801d65b4,
		"TMapObjTree::initMapObj": 0x801d662c,
		"TMapObjTree::initEach": 0x801d67dc,
		"initEach": 0x801d67dc,
		"TMapObjTree::perform": 0x801d6950,
		"TMapObjTree::controlLeaf": 0x801d69ec,
		"controlLeaf": 0x801d69ec,
		"TMapObjTree::touchPlayer": 0x801d6ba8,
		"TMapObjLeaf::TMapObjLeaf": 0x801d6c6c,
		"MoveBG::__sinit_MapObjTree_cpp": 0x801d6d04,
		"__sinit_MapObjTree_cpp": 0x801d6d04,
		"TMapObjSteam::load": 0x801d70ac,
		"TMapObjSteam::control": 0x801d7108,
		"TJointCoin::TJointCoin": 0x801d7134,
		"TJointCoin::initMapObj": 0x801d718c,
		"TJointCoin::nameIsObj": 0x801d7358,
		"TJointCoin::loadAfter": 0x801d7394,
		"TJointCoin::makeObjFromJointName": 0x801d7474,
		"TJointCoin::makeObj": 0x801d7598,
		"makeObj": 0x801d7598,
		"TJointCoin::control": 0x801d773c,
		"TMapObjNail::TMapObjNail": 0x801d7858,
		"TMapObjNail::receiveMessage": 0x801d78a4,
		"MoveBG::__sinit_MapObjEx_cpp": 0x801d7a84,
		"__sinit_MapObjEx_cpp": 0x801d7a84,
		"TPoolManager::TPoolManager": 0x801d7d98,
		"TPoolManager::subWaterLevel": 0x801d7dd8,
		"subWaterLevel": 0x801d7dd8,
		"TPoolManager::getWaterLevel": 0x801d7e80,
		"getWaterLevel": 0x801d7e80,
		"TPool::TPool": 0x801d7ee8,
		"TPool::load": 0x801d7f64,
		"TPool::makeObjAppeared": 0x801d7fa8,
		"TPool::draw": 0x801d7fdc,
		"TPoolManager::~TPoolManager": 0x801d81dc,
		"MoveBG::__sinit_Pool_cpp": 0x801d8270,
		"__sinit_Pool_cpp": 0x801d8270,
		"TBathtub::getNumKillerBurstable": 0x801d85f8,
		"getNumKillerBurstable": 0x801d85f8,
		"TBathtub::isKillerAttackable": 0x801d87a4,
		"isKillerAttackable": 0x801d87a4,
		"TBathtub::getNumKillerLaunchable": 0x801d87c0,
		"getNumKillerLaunchable": 0x801d87c0,
		"TBathtub::TBathtub": 0x801d8904,
		"JGeometry::SMatrix33R<float><float>::SMatrix33R": 0x801d89f4,
		"SMatrix33R": 0x801d89f4,
		"TBathtub::load": 0x801d89f8,
		"TBathtub::updatePosture_": 0x801d8ed0,
		"updatePosture_": 0x801d8ed0,
		"TBathtub::getNextGrip": 0x801d94cc,
		"getNextGrip": 0x801d94cc,
		"TBathtub::getNextJuncture": 0x801d971c,
		"getNextJuncture": 0x801d971c,
		"TBathtub::getNearGrip": 0x801d995c,
		"getNearGrip": 0x801d995c,
		"TBathtub::calcRootMatrix": 0x801d9b28,
		"TBathtub::allowsTumble": 0x801d9c5c,
		"allowsTumble": 0x801d9c5c,
		"TBathtub::startDemo": 0x801d9ee0,
		"TBathtub::setupCollisions_": 0x801da180,
		"setupCollisions_": 0x801da180,
		"TBathtub::calcBathtubData": 0x801da614,
		"calcBathtubData": 0x801da614,
		"TBathtub::control": 0x801da9c8,
		"TBathtub::perform": 0x801dae74,
		"TBathtub::getRootJointMtx": 0x801db1a0,
		"TBathtub::receiveMessage": 0x801db1dc,
		"TBathtub::getKoopaJrMtxInDemo": 0x801db29c,
		"getKoopaJrMtxInDemo": 0x801db29c,
		"TBathtub::getPeachMtxInDemo": 0x801db2b8,
		"getPeachMtxInDemo": 0x801db2b8,
		"TBathtub::getSubmarineMtxInDemo": 0x801db2d4,
		"getSubmarineMtxInDemo": 0x801db2d4,
		"TBathtub::getTakingMtx": 0x801db2f0,
		"TBathtub::tumble": 0x801db30c,
		"tumble": 0x801db30c,
		"TBathtub::getNumGripsDead": 0x801db394,
		"getNumGripsDead": 0x801db394,
		"TBathtub::quake": 0x801db418,
		"quake": 0x801db418,
		"TBathtub::hipdrop": 0x801db554,
		"hipdrop": 0x801db554,
		"TBathtub::loadAfter": 0x801db638,
		"TBathtubGrip::control": 0x801db72c,
		"TBathtubGrip::calcRootMatrix": 0x801dbac0,
		"TBathtubGrip::getRootJointMtx": 0x801dbcbc,
		"TBathtubGrip::receiveMessage": 0x801dbce0,
		"TBathtubGrip::perform": 0x801dc004,
		"TBathtubGrip::TBathtubGrip": 0x801dc0d4,
		"TBathtubGrip::kill": 0x801dc4bc,
		"TBathtubGripPartsHard::receiveMessage": 0x801dc56c,
		"TBathtubGripPartsFragile::receiveMessage": 0x801dc5a8,
		"TBathtubGripParts::getRootJointMtx": 0x801dc5d8,
		"TBathtubParams::TBathtubParams": 0x801dc620,
		"MoveBG::__sinit_MapObjCorona_cpp": 0x801dcc94,
		"__sinit_MapObjCorona_cpp": 0x801dcc94,
		"TJumpBase::control": 0x801dd03c,
		"TJumpBase::calcRootMatrix": 0x801dd550,
		"TJumpBase::getRootJointMtx": 0x801dd600,
		"TJumpBase::receiveMessage": 0x801dd610,
		"TJumpBase::ensureTakeSituation": 0x801dd778,
		"TJumpBase::initMapObj": 0x801dd7bc,
		"TJumpBase::TJumpBase": 0x801dd82c,
		"TMushroom1up::perform": 0x801dd878,
		"TMushroom1up::control": 0x801dd958,
		"TMushroom1up::load": 0x801dddd0,
		"TMushroom1up::initMapObj": 0x801dde0c,
		"TMushroom1up::makeObjAppeared": 0x801dde8c,
		"TMushroom1up::touchPlayer": 0x801ddfa0,
		"TMushroom1up::TMushroom1up": 0x801de038,
		"MoveBG::__sinit_MapObjItem2_cpp": 0x801de128,
		"__sinit_MapObjItem2_cpp": 0x801de128,
		"TWoodBox::TWoodBox": 0x801de4d0,
		"TWoodBox::loadAfter": 0x801de5fc,
		"TWoodBox::kill": 0x801de6fc,
		"TBreakHideObj::initMapObj": 0x801de9e4,
		"TBreakHideObj::control": 0x801dea9c,
		"TBreakHideObj::receiveMessage": 0x801deb18,
		"TBreakHideObj::kill": 0x801debe4,
		"THideObjPictureTwin::THideObjPictureTwin": 0x801dec44,
		"THideObjPictureTwin::initMapObj": 0x801dedbc,
		"THideObjPictureTwin::loadAfter": 0x801dee04,
		"THideObjPictureTwin::afterFinishedAnim": 0x801deedc,
		"TWaterHitPictureHideObj::TWaterHitPictureHideObj": 0x801df090,
		"TWaterHitPictureHideObj::load": 0x801df13c,
		"TWaterHitPictureHideObj::loadAfter": 0x801df2f8,
		"TWaterHitPictureHideObj::receiveMessage": 0x801df65c,
		"TWaterHitPictureHideObj::control": 0x801df7f4,
		"TWaterHitPictureHideObj::touchActor": 0x801df8cc,
		"TWaterHitPictureHideObj::touchWater": 0x801df8fc,
		"TWaterHitPictureHideObj::forward": 0x801dfa50,
		"forward": 0x801dfa50,
		"TWaterHitPictureHideObj::afterFinishedAnim": 0x801dfb2c,
		"THipDropHideObj::touchPlayer": 0x801dfc18,
		"TFruitBasketEvent::TFruitBasketEvent": 0x801dfc78,
		"TFruitBasketEvent::reset": 0x801dfe38,
		"TFruitBasketEvent::getFruitNum": 0x801dfe54,
		"getFruitNum": 0x801dfe54,
		"TFruitBasketEvent::countFruit": 0x801dfe64,
		"TFruitBasket::loadAfter": 0x801dff48,
		"TFruitBasket::touchFruit": 0x801e0070,
		"TFruitBasket::countFruit": 0x801e010c,
		"TFruitHitHideObj::load": 0x801e02b8,
		"TFruitHitHideObj::touchActor": 0x801e0344,
		"TFruitHitHideObj::touchFruit": 0x801e03a0,
		"TWaterHitHideObj::load": 0x801e0434,
		"TWaterHitHideObj::touchWater": 0x801e04c0,
		"THideObj::touchPlayer": 0x801e0524,
		"THideObjBase::THideObjBase": 0x801e0590,
		"THideObjBase::load": 0x801e05f8,
		"THideObjBase::loadAfter": 0x801e0684,
		"THideObjBase::receiveMessage": 0x801e077c,
		"THideObjBase::emitEffect": 0x801e0810,
		"THideObjBase::appearObjFromPoint": 0x801e0848,
		"appearObjFromPoint": 0x801e0848,
		"THideObjBase::appearObj": 0x801e09a0,
		"appearObj": 0x801e09a0,
		"THideObjPictureTwin::getObjAppearPos": 0x801e0a88,
		"MoveBG::__sinit_MapObjHide_cpp": 0x801e0d04,
		"__sinit_MapObjHide_cpp": 0x801e0d04,
		"TLampTrapIron::perform": 0x801e10dc,
		"TLampTrapIron::control": 0x801e1180,
		"TLampTrapIron::receiveMessage": 0x801e1208,
		"TLampTrapIron::loadAfter": 0x801e12ac,
		"TLampTrapIron::initMapObj": 0x801e13dc,
		"TLampTrapIron::TLampTrapIron": 0x801e1424,
		"TLampTrapIronHit::perform": 0x801e1478,
		"TLampTrapIronHit::receiveMessage": 0x801e1554,
		"TLampTrapSpike::perform": 0x801e1584,
		"TLampTrapSpike::control": 0x801e15e4,
		"TLampTrapSpike::receiveMessage": 0x801e1a30,
		"TLampTrapSpike::loadAfter": 0x801e1a50,
		"TLampTrapSpike::initMapObj": 0x801e1b80,
		"TLampTrapSpike::TLampTrapSpike": 0x801e1bb8,
		"TLampTrapSpikeHit::perform": 0x801e1c10,
		"TLampTrapSpikeHit::receiveMessage": 0x801e1cf4,
		"MoveBG::__sinit_MapObjTrap_cpp": 0x801e1eb0,
		"__sinit_MapObjTrap_cpp": 0x801e1eb0,
		"TJointModel::getJ3DModelDataFlag": 0x801685b4,
		"TJointObj::newJointObj": 0x801685bc,
		"TJointModel::TJointModel": 0x801685fc,
		"TJointModel::initJointModel": 0x8016864c,
		"TJointModel::initActor": 0x80168698,
		"initActor": 0x80168698,
		"TJointModel::perform": 0x801687dc,
		"Map::__sinit_JointModel_cpp": 0x80168820,
		"__sinit_JointModel_cpp": 0x80168820,
		"TJointModelManager::~TJointModelManager": 0x80168b1c,
		"JGadget::TList<16MActorSubAnmInfo,Q27JGadget30TAllocator<16MActorSubAnmInfo>>::iterator::iterator": 0x80168ca0,
		"TJointModelManager::newJointModel": 0x80168ca8,
		"TJointModelManager::TJointModelManager": 0x80168ce8,
		"TJointModelManager::initJointModel": 0x80168dd8,
		"TJointModelManager::perform": 0x80168ec0,
		"Map::__sinit_JointModelManager_cpp": 0x80168f30,
		"__sinit_JointModelManager_cpp": 0x80168f30,
		"TJointObj::TJointObj": 0x8016922c,
		"TJointObj::initJointObj": 0x8016925c,
		"initJointObj": 0x8016925c,
		"TJointObj::initChildren": 0x80169310,
		"initChildren": 0x80169310,
		"TJointObj::kill": 0x801693f8,
		"TJointObj::alive": 0x801694e0,
		"alive": 0x801694e0,
		"TJointObj::sleep": 0x801695a8,
		"TJointObj::awake": 0x801696a0,
		"TJointObj::sit": 0x8016977c,
		"sit": 0x8016977c,
		"TJointObj::stand": 0x8016984c,
		"stand": 0x8016984c,
		"Map::__sinit_JointObj_cpp": 0x8016991c,
		"__sinit_JointObj_cpp": 0x8016991c,
		"TMap::~TMap": 0x80169c18,
		"TMap::TMap": 0x80169c8c,
		"TMap::load": 0x80169d8c,
		"TMap::loadAfter": 0x80169e10,
		"TMap::perform": 0x80169e34,
		"TMap::changeModel": 0x80169f18,
		"TMap::checkGroundExactY": 0x80169fa0,
		"checkGroundExactY": 0x80169fa0,
		"TMap::checkGroundIgnoreWaterThrough": 0x8016a034,
		"checkGroundIgnoreWaterThrough": 0x8016a034,
		"TMap::checkRoofIgnoreWaterThrough": 0x8016a0c0,
		"checkRoofIgnoreWaterThrough": 0x8016a0c0,
		"TMap::isTouchedWallsAndMoveXZ": 0x8016a0ec,
		"isTouchedWallsAndMoveXZ": 0x8016a0ec,
		"TMap::isTouchedOneWallAndMoveXZ": 0x8016a124,
		"isTouchedOneWallAndMoveXZ": 0x8016a124,
		"TMap::isTouchedOneWall": 0x8016a1d0,
		"isTouchedOneWall": 0x8016a1d0,
		"TMap::intersectLine": 0x8016a270,
		"TMap::isInArea": 0x8016a294,
		"TMap::getIllegalCheckData": 0x8016a2d8,
		"getIllegalCheckData": 0x8016a2d8,
		"TMap::update": 0x8016a2e4,
		"Map::initStage": 0x8016a548,
		"initStage": 0x8016a548,
		"Map::initStageCommon": 0x8016a6f8,
		"initStageCommon": 0x8016a6f8,
		"Map::initPinnaParco": 0x8016a9d8,
		"initPinnaParco": 0x8016a9d8,
		"Map::initMare": 0x8016aabc,
		"initMare": 0x8016aabc,
		"Map::initMonte": 0x8016adac,
		"initMonte": 0x8016adac,
		"Map::__sinit_Map_cpp": 0x8016af6c,
		"__sinit_Map_cpp": 0x8016af6c,
		"TMapCollisionData::polygonIsInGrid": 0x8016b268,
		"polygonIsInGrid": 0x8016b268,
		"Map::checkLinesCollision": 0x8016b8a0,
		"checkLinesCollision": 0x8016b8a0,
		"TMapCollisionData::intersectLine": 0x8016b978,
		"Map::bgIntersectLine": 0x8016c4d8,
		"bgIntersectLine": 0x8016c4d8,
		"TMapCollisionData::checkGround": 0x8016c8a0,
		"TMapCollisionData::checkGroundList": 0x8016ca48,
		"checkGroundList": 0x8016ca48,
		"TMapCollisionData::checkRoof": 0x8016cbe0,
		"TMapCollisionData::checkRoofList": 0x8016cd3c,
		"checkRoofList": 0x8016cd3c,
		"TMapCollisionData::checkWalls": 0x8016ce84,
		"TMapCollisionData::checkWallList": 0x8016cfa4,
		"checkWallList": 0x8016cfa4,
		"Map::__sinit_MapCheck_cpp": 0x8016d3e0,
		"__sinit_MapCheck_cpp": 0x8016d3e0,
		"TMapCollisionData::TMapCollisionData": 0x8016d6dc,
		"TMapCollisionData::init": 0x8016d7c8,
		"TBGCheckListRoot::TBGCheckListRoot": 0x8016dbf0,
		"TMapCollisionData::initMoveCollision": 0x8016dc34,
		"initMoveCollision": 0x8016dc34,
		"TBGCheckListWarp::TBGCheckListWarp": 0x8016dc70,
		"TBGCheckList::TBGCheckList": 0x8016dca4,
		"TBGCheckListWarp::setPreNode": 0x8016dcc0,
		"TBGCheckList::setPreNode": 0x8016dcc8,
		"Map::__sinit_MapCollisionData_cpp": 0x8016dccc,
		"__sinit_MapCollisionData_cpp": 0x8016dccc,
		"TMapCollisionWarp::TMapCollisionWarp": 0x8016dfd0,
		"TMapCollisionWarp::init": 0x8016e060,
		"TMapCollisionWarp::remove": 0x8016e0cc,
		"TMapCollisionWarp::setUpTrans": 0x8016e13c,
		"TMapCollisionWarp::setUp": 0x8016e1d4,
		"TMapCollisionMove::TMapCollisionMove": 0x8016e2a4,
		"TMapCollisionMove::moveTrans": 0x8016e438,
		"TMapCollisionMove::move": 0x8016e49c,
		"TMapCollisionStatic::TMapCollisionStatic": 0x8016e540,
		"TMapCollisionStatic::init": 0x8016e5cc,
		"TMapCollisionStatic::setUp": 0x8016e648,
		"TMapCollisionBase::init": 0x8016e69c,
		"TMapCollisionBase::setAllActor": 0x8016e854,
		"setAllActor": 0x8016e854,
		"TMapCollisionBase::setAllData": 0x8016e884,
		"setAllData": 0x8016e884,
		"TMapCollisionBase::setAllBGType": 0x8016e8b4,
		"setAllBGType": 0x8016e8b4,
		"TMapCollisionBase::setVertexData": 0x8016e8e0,
		"setVertexData": 0x8016e8e0,
		"TMapCollisionMove::moveSRT": 0x8016e940,
		"TMapCollisionStatic::remove": 0x8016ea2c,
		"TMapCollisionManager::TMapCollisionManager": 0x8016ea30,
		"TMapCollisionManager::init": 0x8016eaa8,
		"TMapCollisionManager::createCollision": 0x8016ec10,
		"createCollision": 0x8016ec10,
		"TMapCollisionManager::changeCollision": 0x8016ecf4,
		"changeCollision": 0x8016ecf4,
		"TMapDrawWall::~TMapDrawWall": 0x8016ed6c,
		"TMap::draw": 0x8016ede0,
		"TMapDrawWall::TMapDrawWall": 0x8016ede4,
		"TMapDrawWall::load": 0x8016ee64,
		"TMapDrawWall::perform": 0x8016eea0,
		"Map::__sinit_MapDraw_cpp": 0x8016f1c8,
		"__sinit_MapDraw_cpp": 0x8016f1c8,
		"TMapEvent::startControl": 0x8016f548,
		"TMapEvent::getBuilding": 0x8016f554,
		"TMapEvent::TMapEvent": 0x8016f570,
		"TMapEvent::load": 0x8016f630,
		"TMapEvent::perform": 0x8016f670,
		"TMapEvent::finishControl": 0x8016f75c,
		"TMapEvent::isFinishedAll": 0x8016f7b0,
		"Map::__sinit_MapEvent_cpp": 0x8016f7e0,
		"__sinit_MapEvent_cpp": 0x8016f7e0,
		"TMapEventSinkShadowMario::~TMapEventSinkShadowMario": 0x8016fadc,
		"TMapEventSink::watch": 0x8016fb70,
		"TMapEventSinkShadowMario::initWithBuildingNum": 0x8016fb78,
		"TMapEventSinkShadowMario::initBuilding": 0x8016fc48,
		"TMapEventSinkShadowMario::loadAfter": 0x8016fd08,
		"TMapEventSinkShadowMario::raiseBuilding": 0x8016fdd0,
		"raiseBuilding": 0x8016fdd0,
		"TMapEventSinkShadowMario::rising": 0x8016fe00,
		"J3DTransformInfo::operator_=": 0x8016fe8c,
		"TMapEventSinkBianco::load": 0x8016fed8,
		"TMapEventSinkBianco::loadAfter": 0x8016ffd0,
		"TMapEventSinkBianco::watch": 0x80170148,
		"TMapEventSinkBianco::startControl": 0x8017025c,
		"TMapEventSinkBianco::control": 0x801703e4,
		"TMapEventSinkBianco::rising": 0x80170468,
		"TMapEventSinkBianco::finishControl": 0x801704f4,
		"TMapEventSinkInPollutionReset::loadAfter": 0x801706c8,
		"TMapEventSinkInPollutionReset::makeBuildingRecovered": 0x801707fc,
		"TMapEventSinkInPollution::loadAfter": 0x80170998,
		"TMapEventSinkInPollution::initBuriedBuilding": 0x80170a30,
		"initBuriedBuilding": 0x80170a30,
		"TMapEventSinkInPollution::watch": 0x80170ad8,
		"TMapEventSink::TMapEventSink": 0x80170b88,
		"TMapEventSink::load": 0x80170c24,
		"TMapEventSink::initWithBuildingNum": 0x80170d30,
		"TMapEventSink::initBuilding": 0x80170de0,
		"TMapEventSink::startControl": 0x80170e90,
		"TMapEventSink::control": 0x8017104c,
		"TMapEventSink::rising": 0x801711ac,
		"TMapEventSink::finishControl": 0x80171248,
		"TMapEventSink::makeBuildingRecovered": 0x801712cc,
		"TMapEventSink::isFinishedAll": 0x801713fc,
		"TMapEventSink::getPollutionObj": 0x80171438,
		"getPollutionObj": 0x80171438,
		"TMapEventSink::getSinkOffsetY": 0x8017146c,
		"getSinkOffsetY": 0x8017146c,
		"TMapEventSink::isBuried": 0x80171480,
		"isBuried": 0x80171480,
		"TMapEventSink::getBuilding": 0x8017149c,
		"TMapEventSinkBianco::~TMapEventSinkBianco": 0x801714c0,
		"Map::__sinit_MapEventSink_cpp": 0x80171710,
		"__sinit_MapEventSink_cpp": 0x80171710,
		"TMapCollisionBase::initCheckData": 0x80171a0c,
		"initCheckData": 0x80171a0c,
		"TMapCollisionBase::initAllCheckData": 0x80171ac0,
		"initAllCheckData": 0x80171ac0,
		"TMapCollisionBase::update": 0x80171cfc,
		"TMapCollisionBase::updateTrans": 0x80171d90,
		"updateTrans": 0x80171d90,
		"TMapCollisionBase::setCheckData": 0x80171f28,
		"setCheckData": 0x80171f28,
		"TMapCollisionMove::setList": 0x8017218c,
		"setList": 0x8017218c,
		"TBGCheckData::setVertex": 0x801721f0,
		"setVertex": 0x801721f0,
		"Map::__sinit_MapMakeData_cpp": 0x801723b8,
		"__sinit_MapMakeData_cpp": 0x801723b8,
		"TMapCollisionData::removeCheckListData": 0x801726b4,
		"removeCheckListData": 0x801726b4,
		"TMapCollisionData::updateCheckListNode": 0x80172914,
		"updateCheckListNode": 0x80172914,
		"TMapCollisionData::addCheckDataToGrid": 0x80172a14,
		"addCheckDataToGrid": 0x80172a14,
		"TMapCollisionData::getGridArea": 0x80172f8c,
		"getGridArea": 0x80172f8c,
		"Map::addGroundNode": 0x8017316c,
		"addGroundNode": 0x8017316c,
		"Map::addRoofNode": 0x801731b4,
		"addRoofNode": 0x801731b4,
		"Map::addWallNode": 0x801731fc,
		"addWallNode": 0x801731fc,
		"Map::addAfterPreNode": 0x80173244,
		"addAfterPreNode": 0x80173244,
		"TMapCollisionData::allocCheckList": 0x801732d8,
		"allocCheckList": 0x801732d8,
		"TMapCollisionData::getEntryID": 0x80173344,
		"getEntryID": 0x80173344,
		"TMapCollisionData::allocCheckData": 0x80173388,
		"allocCheckData": 0x80173388,
		"TMirrorMapDrawBuf::~TMirrorMapDrawBuf": 0x801733a4,
		"TMirrorMapDrawBuf::perform": 0x80173428,
		"TMirrorModelManager::TMirrorModelManager": 0x80173474,
		"TMirrorModelManager::load": 0x801734fc,
		"TMirrorModelManager::loadAfter": 0x801736a8,
		"TMirrorModelManager::perform": 0x801737b8,
		"JGeometry::TVec3<float><float>::scaleAdd": 0x80173bf0,
		"scaleAdd": 0x80173bf0,
		"TMirrorModel::calc": 0x80173c24,
		"TMirrorModelManager::isInMirror": 0x80173c38,
		"isInMirror": 0x80173c38,
		"TMirrorModelManager::isUpperThanMirrorPlane": 0x80173c7c,
		"isUpperThanMirrorPlane": 0x80173c7c,
		"TMirrorModel::getD": 0x80173d5c,
		"getD": 0x80173d5c,
		"TMirrorModel::getNormalVec": 0x80173d64,
		"getNormalVec": 0x80173d64,
		"TMirrorModelObj::init": 0x80173d6c,
		"TMirrorModelObj::calc": 0x80173ebc,
		"TMirrorModelObj::setPlane": 0x80173ef0,
		"TMirrorModel::TMirrorModel": 0x80173fa4,
		"TMirrorModel::init": 0x80173fe0,
		"TMirrorModel::initPlaneInfo": 0x80174108,
		"initPlaneInfo": 0x80174108,
		"TMirrorModel::setPlane": 0x801742ec,
		"TMirrorCamera::TMirrorCamera": 0x8017438c,
		"TMirrorCamera::drawSetting": 0x80174634,
		"drawSetting": 0x80174634,
		"TMirrorCamera::perform": 0x801746d0,
		"TMirrorModelManager::~TMirrorModelManager": 0x80174788,
		"Map::__sinit_MapMirror_cpp": 0x80174870,
		"__sinit_MapMirror_cpp": 0x80174870,
		"TMapModel::getJ3DModelDataFlag": 0x80174ba4,
		"TMapModelManager::TMapModelManager": 0x80174bac,
		"TMapModelManager::init": 0x80174bf0,
		"TMapModel::initJointModel": 0x80174c80,
		"TMapModel::initUnderpass": 0x80174d10,
		"initUnderpass": 0x80174d10,
		"TMapModel::perform": 0x80174f90,
		"TMapModelManager::~TMapModelManager": 0x80175130,
		"TMapModelManager::newJointModel": 0x80175288,
		"Map::__sinit_MapModel_cpp": 0x801752f0,
		"__sinit_MapModel_cpp": 0x801752f0,
		"TMapWarp::TMapWarp": 0x801755ec,
		"TMapWarp::init": 0x80175608,
		"TMapWarp::TMapWarpInfo::TMapWarpInfo": 0x80175930,
		"TMapWarp::initModel": 0x80175934,
		"TMapWarp::watchToWarp": 0x801759cc,
		"watchToWarp": 0x801759cc,
		"TMapWarp::changeModel": 0x80175cec,
		"Map::__sinit_MapWarp_cpp": 0x80175d88,
		"__sinit_MapWarp_cpp": 0x80175d88,
		"TMapObjSoundGroup::~TMapObjSoundGroup": 0x80176084,
		"TMapObjSoundGroup::TMapObjSoundGroup": 0x801760f8,
		"TMapObjSoundGroup::load": 0x8017616c,
		"TMapObjSoundGroup::perform": 0x80176260,
		"TMapModelActor::perform": 0x801763f0,
		"TMapStaticObj::TMapStaticObj": 0x801764cc,
		"TMapStaticObj::load": 0x80176530,
		"TMapStaticObj::loadAfter": 0x80176574,
		"TMapStaticObj::init": 0x801765b8,
		"TMapStaticObj::initModel": 0x801769b0,
		"TMapStaticObj::initUnique": 0x80176ae0,
		"TMapStaticObj::perform": 0x80176d60,
		"TMapStaticObj::getModelData": 0x80177050,
		"getModelData": 0x80177050,
		"Map::__sinit_MapStaticObject_cpp": 0x80177168,
		"__sinit_MapStaticObject_cpp": 0x80177168,
		"TMapWire::TMapWire": 0x80177474,
		"TMapWire::init": 0x801774f0,
		"TMapWire::getPointPosOnWire": 0x80177c0c,
		"getPointPosOnWire": 0x80177c0c,
		"TMapWire::getPosInWire": 0x80177d9c,
		"TMapWire::move": 0x80177f38,
		"TMapWire::calcViewAndDBEntry": 0x801781b8,
		"calcViewAndDBEntry": 0x801781b8,
		"TMapWire::setFootPointsAtHanged": 0x80178208,
		"setFootPointsAtHanged": 0x80178208,
		"TMapWire::getPointPosAtHanged": 0x801784a0,
		"getPointPosAtHanged": 0x801784a0,
		"TMapWire::release": 0x80178544,
		"TMapWire::getPointPowerAtReleased": 0x80178988,
		"getPointPowerAtReleased": 0x80178988,
		"TMapWire::drawUpper": 0x801789c4,
		"TMapWire::drawLower": 0x80178af4,
		"drawLower": 0x80178af4,
		"TMapWirePoint::TMapWirePoint": 0x80178d00,
		"Map::__sinit_MapWire_cpp": 0x80178d28,
		"__sinit_MapWire_cpp": 0x80178d28,
		"TMapWireManager::~TMapWireManager": 0x80179024,
		"TMapWireManager::TMapWireManager": 0x80179098,
		"TMapWireManager::load": 0x8017914c,
		"TMapWireManager::loadAfter": 0x801792fc,
		"JGadget::TList_pointer<THitActor*>::insert": 0x80179404,
		"JDrama::TViewObjPtrListT<THitActor,JDrama::TViewObj>::getChildren": 0x80179450,
		"getChildren": 0x80179450,
		"JDrama::TNameRef::search": 0x80179458,
		"JDrama::TNameRefGen::getRootNameRef": 0x801794b0,
		"getRootNameRef": 0x801794b0,
		"JDrama::TNameRefGen::getInstance": 0x801794b8,
		"getInstance": 0x801794b8,
		"TMapWireManager::perform": 0x8017955c,
		"TMapWireManager::getPointPosInNthWire": 0x80179714,
		"getPointPosInNthWire": 0x80179714,
		"TMapWireManager::getWireNo": 0x80179774,
		"getWireNo": 0x80179774,
		"TMapWireActorManager::doActorToWire": 0x80179798,
		"doActorToWire": 0x80179798,
		"Map::initDraw": 0x8017997c,
		"TMapWireActor::TMapWireActor": 0x80179ac4,
		"TMapWireActor::receiveMessage": 0x80179b30,
		"TMapWireActor::getTipPoints": 0x80179b64,
		"getTipPoints": 0x80179b64,
		"TMapWireActor::getPosInWire": 0x80179ba0,
		"TMapWireActor::getTakingMtx": 0x80179d48,
		"Map::__sinit_MapWireManager_cpp": 0x80179d50,
		"__sinit_MapWireManager_cpp": 0x80179d50,
		"TMapXlu::TMapXlu": 0x8017a060,
		"TMapXlu::init": 0x8017a070,
		"TMapXlu::changeXluJoint": 0x8017a184,
		"changeXluJoint": 0x8017a184,
		"TMapXlu::changeNormalJoint": 0x8017a29c,
		"changeNormalJoint": 0x8017a29c,
		"Map::__sinit_MapXlu_cpp": 0x8017a39c,
		"__sinit_MapXlu_cpp": 0x8017a39c,
		"TPollutionLayer::action": 0x8017a698,
		"TPollutionLayer::getPlaneType": 0x8017aa64,
		"TPollutionLayer::fire": 0x8017aa6c,
		"fire": 0x8017aa6c,
		"TPollutionLayer::getPollutedPos": 0x8017abbc,
		"getPollutedPos": 0x8017abbc,
		"TPollutionLayer::getPollutedPosNear": 0x8017ace4,
		"getPollutedPosNear": 0x8017ace4,
		"TPollutionLayer::getTexPosS": 0x8017af28,
		"TPollutionLayer::isInArea": 0x8017af54,
		"Map::__sinit_PollutionAction_cpp": 0x8017af94,
		"__sinit_PollutionAction_cpp": 0x8017af94,
		"TPollutionRevivalTexStamp::TPollutionRevivalTexStamp": 0x8017b290,
		"TPollutionTexStamp::TPollutionTexStamp": 0x8017b2bc,
		"TPollutionLayerTaskInfo::TPollutionLayerTaskInfo": 0x8017b2dc,
		"TPollutionTexStamp::pushTask": 0x8017b2f8,
		"pushTask": 0x8017b2f8,
		"TPollutionCounterLayer::TPollutionCounterLayer": 0x8017b374,
		"TPollutionJointObjTaskInfo::TPollutionJointObjTaskInfo": 0x8017b444,
		"TPollutionModelTaskInfo::TPollutionModelTaskInfo": 0x8017b458,
		"TPollutionCounterLayer::init": 0x8017b468,
		"TPollutionCounterLayer::offLayer": 0x8017b6ec,
		"offLayer": 0x8017b6ec,
		"TPollutionCounterLayer::stampIsCleanType": 0x8017b70c,
		"stampIsCleanType": 0x8017b70c,
		"TPollutionCounterLayer::registerLayer": 0x8017b734,
		"registerLayer": 0x8017b734,
		"TPollutionCounterLayer::registerTexStamp": 0x8017b780,
		"registerTexStamp": 0x8017b780,
		"TPollutionCounterLayer::registerRevivalTexStamp": 0x8017b824,
		"registerRevivalTexStamp": 0x8017b824,
		"TPollutionCounterLayer::pushModelStampTask": 0x8017b86c,
		"pushModelStampTask": 0x8017b86c,
		"TPollutionCounterLayer::calcViewMtx": 0x8017b8b8,
		"calcViewMtx": 0x8017b8b8,
		"TPollutionCounterLayer::pushJointObjStampTask": 0x8017ba38,
		"pushJointObjStampTask": 0x8017ba38,
		"TPollutionCounterLayer::resetTask": 0x8017ba80,
		"resetTask": 0x8017ba80,
		"TPollutionCounterLayer::countTexDegree": 0x8017baec,
		"countTexDegree": 0x8017baec,
		"TPollutionCounterLayer::cleanProhibitArea": 0x8017bd40,
		"cleanProhibitArea": 0x8017bd40,
		"TPollutionCounterLayer::drawRevivalTexStamp": 0x8017bf24,
		"drawRevivalTexStamp": 0x8017bf24,
		"Map::initGXforStamp": 0x8017c210,
		"initGXforStamp": 0x8017c210,
		"Map::doTask": 0x8017c4dc,
		"doTask": 0x8017c4dc,
		"TPollutionCounterLayer::drawJointObjStamp": 0x8017c6cc,
		"drawJointObjStamp": 0x8017c6cc,
		"Map::initGXforPollutionLayer": 0x8017c954,
		"initGXforPollutionLayer": 0x8017c954,
		"Map::drawTex": 0x8017cd14,
		"drawTex": 0x8017cd14,
		"TPollutionCounterObj::TPollutionCounterObj": 0x8017cdf8,
		"TPollutionCounterObj::init": 0x8017ce38,
		"TPollutionCounterObj::registerPollutionObj": 0x8017d0bc,
		"registerPollutionObj": 0x8017d0bc,
		"TPollutionCounterObj::countObjDegree": 0x8017d164,
		"countObjDegree": 0x8017d164,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setEular": 0x8017d438,
		"Map::initDrawObjGX": 0x8017d4e0,
		"initDrawObjGX": 0x8017d4e0,
		"TPollutionCounterBase::drawSyncCallback": 0x8017d698,
		"Map::drawBlack": 0x8017d720,
		"drawBlack": 0x8017d720,
		"TPollutionCounterObj::getCounterNo": 0x8017d8ac,
		"TPollutionCounterObj::getTokenNo": 0x8017d8b4,
		"TPollutionCounterLayer::getCounterNo": 0x8017d8bc,
		"TPollutionCounterLayer::getTokenNo": 0x8017d8c4,
		"Map::__sinit_PollutionCount_cpp": 0x8017d8cc,
		"__sinit_PollutionCount_cpp": 0x8017d8cc,
		"TPollutionManager::~TPollutionManager": 0x8017dbc8,
		"TPollutionManager::TPollutionManager": 0x8017dc64,
		"TPollutionManager::load": 0x8017dcd8,
		"TPollutionManager::setDataAddress": 0x8017de3c,
		"setDataAddress": 0x8017de3c,
		"TPollutionManager::newJointModel": 0x8017de88,
		"TPollutionManager::perform": 0x8017e014,
		"TPollutionManager::cleanedAll": 0x8017e0ac,
		"cleanedAll": 0x8017e0ac,
		"TPollutionManager::isPolluted": 0x8017e1b8,
		"TPollutionManager::getPollutionDegree": 0x8017e26c,
		"getPollutionDegree": 0x8017e26c,
		"TPollutionManager::getPollutionType": 0x8017e364,
		"getPollutionType": 0x8017e364,
		"TPollutionManager::stampGround": 0x8017e420,
		"stampGround": 0x8017e420,
		"TPollutionManager::clean": 0x8017e500,
		"clean": 0x8017e500,
		"TPollutionManager::stamp": 0x8017e5d0,
		"TPollutionManager::stampModel": 0x8017e690,
		"TPollutionLayerWallMinusX::getPlaneType": 0x8017e730,
		"TPollutionLayerWallMinusX::getTexPosS": 0x8017e738,
		"TPollutionLayerWallPlusX::isInArea": 0x8017e764,
		"TPollutionLayerWallPlusX::isInAreaSize": 0x8017e7a4,
		"TPollutionLayerWallBase::getTexPosT": 0x8017e7f4,
		"TPollutionLayer::getTexResource": 0x8017e820,
		"TPollutionLayer::newJointObj": 0x8017e830,
		"TPollutionLayer::getJ3DModelDataFlag": 0x8017e870,
		"TPollutionLayerWallMinusZ::getPlaneType": 0x8017e878,
		"TPollutionLayerWallMinusZ::getTexPosS": 0x8017e880,
		"TPollutionLayerWallPlusZ::isInArea": 0x8017e8ac,
		"TPollutionLayerWallPlusZ::isInAreaSize": 0x8017e8ec,
		"Map::__sinit_PollutionManager_cpp": 0x8017e93c,
		"__sinit_PollutionManager_cpp": 0x8017e93c,
		"TPollutionObj::TPollutionObj": 0x8017ec38,
		"TPollutionObj::initAreaInfo": 0x8017ec90,
		"initAreaInfo": 0x8017ec90,
		"TPollutionLayer::getTexPosT": 0x8017eddc,
		"TPollutionObj::isCleaned": 0x8017ee08,
		"isCleaned": 0x8017ee08,
		"TPollutionObj::updateDepthMap": 0x8017ee28,
		"updateDepthMap": 0x8017ee28,
		"TPollutionObj::getDepthFromMap": 0x8017eecc,
		"getDepthFromMap": 0x8017eecc,
		"TPollutionObj::newJointObj": 0x8017f100,
		"Map::__sinit_PollutionObj_cpp": 0x8017f168,
		"__sinit_PollutionObj_cpp": 0x8017f168,
		"TPollutionPos::TPollutionPos": 0x8017f464,
		"TPollutionPos::init": 0x8017f494,
		"TPollutionPos::worldToTexSize": 0x8017f4dc,
		"worldToTexSize": 0x8017f4dc,
		"TPollutionPos::worldToDepth": 0x8017f4fc,
		"worldToDepth": 0x8017f4fc,
		"TPollutionPos::isProhibit": 0x8017f524,
		"isProhibit": 0x8017f524,
		"TPollutionPos::isSame": 0x8017f5a0,
		"TPollutionPos::getDepthWorld": 0x8017f674,
		"getDepthWorld": 0x8017f674,
		"TPollutionPos::getEdgeDegree": 0x8017f6f0,
		"getEdgeDegree": 0x8017f6f0,
		"Map::__sinit_PollutionPos_cpp": 0x8017f844,
		"__sinit_PollutionPos_cpp": 0x8017f844,
		"TShimmer::TShimmer": 0x8017fbac,
		"TShimmer::load": 0x8017fcf8,
		"TShimmer::loadAfter": 0x8017fe8c,
		"TShimmer::perform": 0x8017ff88,
		"Map::__sinit_Shimmer_cpp": 0x80180210,
		"__sinit_Shimmer_cpp": 0x80180210,
		"TSky::TSky": 0x80180580,
		"TSky::load": 0x80180698,
		"TSky::perform": 0x80180730,
		"Map::__sinit_Sky_cpp": 0x80180a88,
		"__sinit_Sky_cpp": 0x80180a88,
		"TMapEventSirenaSink::~TMapEventSirenaSink": 0x80180d8c,
		"TMapEventSirenaSink::initPollution": 0x80180e20,
		"initPollution": 0x80180e20,
		"TMapEventSirenaSink::makePollutionRecovered": 0x80180e24,
		"makePollutionRecovered": 0x80180e24,
		"TMapEventSirenaSink::TMapEventSirenaSink": 0x80180e28,
		"TMapEventSirenaSink::load": 0x80180e8c,
		"TMapEventSirenaSink::loadAfter": 0x80180f84,
		"TMapEventSirenaSink::watch": 0x80181028,
		"Map::__sinit_MapEventSirena_cpp": 0x80181140,
		"__sinit_MapEventSirena_cpp": 0x80181140,
		"TPollutionLayer::isInAreaSize": 0x8018143c,
		"TPollutionLayer::TPollutionLayer": 0x8018148c,
		"TPollutionLayer::initJointModel": 0x8018154c,
		"TPollutionLayer::initLayerInfo": 0x80181700,
		"TPollutionLayer::initTexImage": 0x80181800,
		"initTexImage": 0x80181800,
		"TPollutionLayer::perform": 0x801819d4,
		"TPollutionLayer::isPolluted": 0x80181a34,
		"TPollutionLayer::stamp": 0x80181b8c,
		"TPollutionLayer::cleaned": 0x80181cd8,
		"cleaned": 0x80181cd8,
		"TPollutionLayer::appearItem": 0x801820ac,
		"appearItem": 0x801820ac,
		"TPollutionLayer::stampModel": 0x801820b0,
		"TPollutionLayerWallBase::TPollutionLayerWallBase": 0x80182128,
		"TPollutionLayerWallPlusX::initLayerInfo": 0x80182170,
		"TPollutionLayerWallPlusX::stamp": 0x801821c4,
		"TPollutionLayerWallPlusX::getTexPosS": 0x801822c4,
		"TPollutionLayerWallPlusZ::initLayerInfo": 0x801822f0,
		"TPollutionLayerWallPlusZ::stamp": 0x80182334,
		"TPollutionLayerWave::initJointModel": 0x80182434,
		"TPollutionLayerWave::getTexResource": 0x80182548,
		"TPollutionLayerWave::perform": 0x80182588,
		"TPollutionLayerWave::draw": 0x801825c8,
		"TPollutionLayerWave::initGX": 0x8018274c,
		"initGX": 0x8018274c,
		"TPollutionLayerWallPlusX::getPlaneType": 0x8018296c,
		"TPollutionLayerWallPlusZ::getPlaneType": 0x80182974,
		"TPollutionLayerWave::getPlaneType": 0x8018297c,
		"Map::__sinit_PollutionLayer_cpp": 0x80182984,
		"__sinit_PollutionLayer_cpp": 0x80182984,
		"TPollutionTest::loadAfter": 0x80182c80,
		"TPollutionTest::~TPollutionTest": 0x80182ca0,
		"TPollutionTest::perform": 0x80182d14,
		"Map::__sinit_PollutionEvent_cpp": 0x80182d18,
		"__sinit_PollutionEvent_cpp": 0x80182d18,
		"TMapCheckGroundPlane::TMapCheckGroundPlane": 0x80183014,
		"TMapCheckGroundPlane::init": 0x8018303c,
		"TMapCheckGroundPlane::checkPlaneGround": 0x80183104,
		"checkPlaneGround": 0x80183104,
		"TMapCheckGroundPlane::getCheckData": 0x80183238,
		"getCheckData": 0x80183238,
		"Map::__sinit_MapCollisionPlane_cpp": 0x8018325c,
		"__sinit_MapCollisionPlane_cpp": 0x8018325c,
		"TMarineSnow::perform": 0x801835c4,
		"TMarineSnow::loadAfter": 0x80183620,
		"TMarineSnow::TMarineSnow": 0x80183678,
		"TBGCheckData::TBGCheckData": 0x80183784,
		"TBGCheckData::getPlaneType": 0x801837dc,
		"TBGCheckData::getActiveJumpPower": 0x80183870,
		"getActiveJumpPower": 0x80183870,
		"Map::__sinit_MapData_cpp": 0x801838d4,
		"__sinit_MapData_cpp": 0x801838d4,
		"TDolpicEventRiccoMammaGate::~TDolpicEventRiccoMammaGate": 0x80183bd0,
		"TDolpicEventRiccoMammaGate::TDolpicEventRiccoMammaGate": 0x80183c64,
		"TDolpicEventRiccoMammaGate::load": 0x80183cec,
		"TDolpicEventRiccoMammaGate::loadAfter": 0x80183f6c,
		"TDolpicEventRiccoMammaGate::watch": 0x80184044,
		"TDolpicEventRiccoMammaGate::control": 0x80184254,
		"TDolpicEventRiccoMammaGate::isFinishedAll": 0x80184444,
		"TDolpicEventBiancoGate::TDolpicEventBiancoGate": 0x80184474,
		"TDolpicEventBiancoGate::loadAfter": 0x801844c0,
		"TDolpicEventBiancoGate::watch": 0x8018454c,
		"TDolpicEventBiancoGate::control": 0x801845bc,
		"TDolpicEventBiancoGate::isFinishedAll": 0x80184670,
		"TDolpicEventBiancoGate::~TDolpicEventBiancoGate": 0x801846a0,
		"Map::__sinit_MapEventDolpic_cpp": 0x80184734,
		"__sinit_MapEventDolpic_cpp": 0x80184734,
		"TMareEventBumpyWall::TMareEventBumpyWall": 0x80184ab4,
		"TMareEventBumpyWall::load": 0x80184b1c,
		"TMareEventBumpyWall::control": 0x80184c28,
		"TMareEventBumpyWall::bumpUpX": 0x80184cd4,
		"bumpUpX": 0x80184cd4,
		"TMareEventBumpyWall::bumpDownX": 0x80184e24,
		"bumpDownX": 0x80184e24,
		"TMareEventBumpyWall::bumpUpZ": 0x80184f78,
		"bumpUpZ": 0x80184f78,
		"TMareEventBumpyWall::bumpDownZ": 0x801850c8,
		"bumpDownZ": 0x801850c8,
		"TMareEventBumpyWall::touchWater": 0x80185218,
		"TMareEventDepressWall::TMareEventDepressWall": 0x801852c4,
		"TMareEventDepressWall::init1stEvent": 0x80185368,
		"init1stEvent": 0x80185368,
		"TMareEventDepressWall::init2ndEvent": 0x8018541c,
		"init2ndEvent": 0x8018541c,
		"TMareEventDepressWall::init3rdEvent": 0x801854d0,
		"init3rdEvent": 0x801854d0,
		"TMareEventDepressWall::initCommon": 0x80185658,
		"initCommon": 0x80185658,
		"TMareEventDepressWall::startEvent": 0x80185ad0,
		"TMareEventDepressWall::perform": 0x80185b88,
		"TMareEventDepressWall::depressing": 0x80185ca4,
		"depressing": 0x80185ca4,
		"TMareEventDepressWall::rising": 0x801860f0,
		"TMareEventWallRock::TMareEventWallRock": 0x80186458,
		"TMareEventWallRock::load": 0x801864cc,
		"TMareWallRock::TMareWallRock": 0x8018664c,
		"TMareWallRock::load": 0x801866d8,
		"TMareWallRock::loadAfter": 0x801866f8,
		"TMareWallRock::initEffect": 0x801868b8,
		"initEffect": 0x801868b8,
		"TMareWallRock::perform": 0x80186a3c,
		"TMareWallRock::movement": 0x80186a9c,
		"TMareWallRock::appear": 0x80186e24,
		"TMareEventDepressWall::~TMareEventDepressWall": 0x80186fbc,
		"TMareEventWallRock::~TMareEventWallRock": 0x80187030,
		"TMareEventWallRock::perform": 0x801870a4,
		"Map::__sinit_MapEventMare_cpp": 0x801870a8,
		"__sinit_MapEventMare_cpp": 0x801870a8,
		"TBathWaterManager::~TBathWaterManager": 0x801873b4,
		"TBathWaterManager::perform": 0x80187460,
		"JGeometry::TBox<JGeometry::TVec3<float><float>>::operator_=": 0x801887e4,
		"TBathtubData::getPos": 0x80188818,
		"getPos": 0x80188818,
		"JMath::TRandom_fast_::get_ufloat_1": 0x801889b8,
		"get_ufloat_1": 0x801889b8,
		"JGeometry::TVec3<float><float>::setMax": 0x801889fc,
		"setMax": 0x801889fc,
		"JGeometry::TVec3<float><float>::setMin": 0x80188a48,
		"setMin": 0x80188a48,
		"TBathWater::TDrop::calcBathtub": 0x80188a94,
		"calcBathtub": 0x80188a94,
		"TBathtubData::getGravityDir": 0x80189288,
		"getGravityDir": 0x80189288,
		"TBathWaterManager::throwMario": 0x801894c4,
		"TBathWaterManager::getWaterHeight": 0x801897bc,
		"getWaterHeight": 0x801897bc,
		"TBathWaterManager::initializeIfYet_": 0x80189808,
		"initializeIfYet_": 0x80189808,
		"TBathWaterManager::loadAfter": 0x8018a4c4,
		"TBathWaterMeshRenderer::clearHeightMap": 0x8018a850,
		"clearHeightMap": 0x8018a850,
		"TBathWaterManager::load": 0x8018aa10,
		"TBathWaterManager::TBathWaterManager": 0x8018aaa0,
		"TBathWater::TDrop::TDrop": 0x8018ac24,
		"TBathWaterPreprocessor::~TBathWaterPreprocessor": 0x8018ac28,
		"TBathWaterPreprocessor::perform": 0x8018ac9c,
		"Map::init_tobj_resource": 0x8018ad04,
		"init_tobj_resource": 0x8018ad04,
		"Map::draw_mist": 0x8018adc0,
		"draw_mist": 0x8018adc0,
		"@unnamed@::clearEFB_alpha": 0x8018b58c,
		"clearEFB_alpha": 0x8018b58c,
		"Map::drawCap": 0x8018b898,
		"drawCap": 0x8018b898,
		"TBathWaterGlobalParams::TBathWaterGlobalParams": 0x8018b998,
		"TBathWaterParams::TBathWaterParams": 0x8018be84,
		"TBathWaterMeshRenderer::getHeight": 0x8018c2e0,
		"TBathWaterMeshRenderer::prerender": 0x8018c3a8,
		"JGeometry::SMatrix44C<float><float>::SMatrix44C": 0x8018cde8,
		"SMatrix44C": 0x8018cde8,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setLookDir": 0x8018cdec,
		"setLookDir": 0x8018cdec,
		"TBathWaterMeshRenderer::render": 0x8018cfcc,
		"TBathWaterMeshRenderer::calcCoord": 0x8018ddf0,
		"calcCoord": 0x8018ddf0,
		"TBathWaterMeshRenderer::makeNormalMap": 0x8018e224,
		"makeNormalMap": 0x8018e224,
		"TBathWaterMeshRenderer::makeHeightMap": 0x8018e434,
		"makeHeightMap": 0x8018e434,
		"Map::__sinit_BathWaterManager_cpp": 0x8018e544,
		"__sinit_BathWaterManager_cpp": 0x8018e544,
		"TStickyStainManager::~TStickyStainManager": 0x8018e848,
		"TStickyStainManager::perform": 0x8018e8bc,
		"GC2D::CLBCalcRatio": 0x8011fd24,
		"TCoord2D::update": 0x8011fd80,
		"TCoord2D::setValue": 0x8011fe28,
		"setValue": 0x8011fe28,
		"TCoord2D::TCoord2D": 0x8011fea0,
		"TExPane::update": 0x8011fec0,
		"TExPane::TExPane": 0x801201a4,
		"TFlashPane::~TFlashPane": 0x80120278,
		"TFlashPane::perform": 0x801202ec,
		"TMenuPlane::perform": 0x8012035c,
		"TMenuPlane::TMenuPlane": 0x801204e8,
		"TMenuBase::perform": 0x801206b8,
		"TMenuPlane::~TMenuPlane": 0x801207ac,
		"TMenuBase::~TMenuBase": 0x80120820,
		"TSMSFader::setFadeStatus": 0x80120908,
		"setFadeStatus": 0x80120908,
		"TSMSFader::setDisplaySize": 0x80120950,
		"setDisplaySize": 0x80120950,
		"TSMSFader::load": 0x80120978,
		"TSMSFader::setColor": 0x80120a90,
		"TSMSFader::startFadeoutT": 0x80120ad8,
		"startFadeoutT": 0x80120ad8,
		"TSMSFader::startFadeinT": 0x80120b04,
		"startFadeinT": 0x80120b04,
		"TSMSFader::startWipe": 0x80120b30,
		"startWipe": 0x80120b30,
		"TSMSFader::requestWipe": 0x80120b40,
		"requestWipe": 0x80120b40,
		"TSMSFader::drawFadeinout": 0x80120d24,
		"drawFadeinout": 0x80120d24,
		"TSMSFader::draw": 0x80120f58,
		"TSMSFader::update": 0x801210f4,
		"TSMSFader::perform": 0x80121250,
		"TSMSFader::TSMSFader": 0x801212d8,
		"@unnamed@::draw_wipe_box": 0x8012139c,
		"draw_wipe_box": 0x8012139c,
		"@unnamed@::fill_rect": 0x80121660,
		"fill_rect": 0x80121660,
		"GC2D::__sinit_ScrnFader_cpp": 0x8012179c,
		"__sinit_ScrnFader_cpp": 0x8012179c,
		"TGCConsole2::~TGCConsole2": 0x80121a98,
		"TGCConsole2::perform": 0x80121b0c,
		"TGCConsole2::drawWater": 0x8012556c,
		"drawWater": 0x8012556c,
		"TGCConsole2::drawJuice": 0x80125bcc,
		"drawJuice": 0x80125bcc,
		"TGCConsole2::processDisappearBalloon": 0x801261e4,
		"processDisappearBalloon": 0x801261e4,
		"TGCConsole2::processAppearBalloon": 0x801263b8,
		"processAppearBalloon": 0x801263b8,
		"TGCConsole2::processAppearTimer": 0x801264cc,
		"processAppearTimer": 0x801264cc,
		"TGCConsole2::processAppearRed": 0x80126958,
		"processAppearRed": 0x80126958,
		"TGCConsole2::processAppearJet": 0x80126c70,
		"processAppearJet": 0x80126c70,
		"TGCConsole2::checkChangeTelopArray": 0x80126f38,
		"checkChangeTelopArray": 0x80126f38,
		"TGCConsole2::processDrawTelop": 0x801270c4,
		"processDrawTelop": 0x801270c4,
		"TGCConsole2::processAppearMario": 0x8012716c,
		"processAppearMario": 0x8012716c,
		"TGCConsole2::processAppearCoin": 0x80127490,
		"processAppearCoin": 0x80127490,
		"TGCConsole2::processAppearTank": 0x801277f4,
		"processAppearTank": 0x801277f4,
		"TGCConsole2::processDownCoin": 0x80127a7c,
		"processDownCoin": 0x80127a7c,
		"TGCConsole2::processAppearStar": 0x80127dec,
		"processAppearStar": 0x80127dec,
		"TBlendPane::setPaneBlend": 0x80126110,
		"setPaneBlend": 0x80126110,
		"TExPane::setPaneOffset": 0x8012854c,
		"setPaneOffset": 0x8012854c,
		"TCoord2D::roundf": 0x80128618,
		"roundf": 0x80128618,
		"TGCConsole2::processInsertLife": 0x80128660,
		"processInsertLife": 0x80128660,
		"TGCConsole2::processAppearLife": 0x80128824,
		"processAppearLife": 0x80128824,
		"TGCConsole2::getFinishedTime": 0x8012891c,
		"getFinishedTime": 0x8012891c,
		"TGCConsole2::stopMoveTimer": 0x80128924,
		"stopMoveTimer": 0x80128924,
		"TGCConsole2::startMoveTimer": 0x8012893c,
		"startMoveTimer": 0x8012893c,
		"TGCConsole2::setTimer": 0x80129740,
		"setTimer": 0x80129740,
		"TGCConsole2::processMoveNozzle": 0x8012a204,
		"processMoveNozzle": 0x8012a204,
		"TGCConsole2::startAppearMario": 0x8012a344,
		"startAppearMario": 0x8012a344,
		"TGCConsole2::startDisappearMario": 0x8012a538,
		"startDisappearMario": 0x8012a538,
		"TGCConsole2::drawWaterBack": 0x8012a684,
		"drawWaterBack": 0x8012a684,
		"TGCConsole2::startAppearStar": 0x8012aee0,
		"startAppearStar": 0x8012aee0,
		"TGCConsole2::startDisappearStar": 0x8012b2ac,
		"startDisappearStar": 0x8012b2ac,
		"TGCConsole2::startAppearBalloon": 0x8012b5cc,
		"startAppearBalloon": 0x8012b5cc,
		"TGCConsole2::startDisappearBalloon": 0x8012b898,
		"startDisappearBalloon": 0x8012b898,
		"TGCConsole2::pauseOut": 0x8012b8f0,
		"pauseOut": 0x8012b8f0,
		"TGCConsole2::pauseIn": 0x8012bc84,
		"pauseIn": 0x8012bc84,
		"TGCConsole2::startAppearRedCoin": 0x8012bdb0,
		"startAppearRedCoin": 0x8012bdb0,
		"TGCConsole2::startInsertJetBalloon": 0x8012bf54,
		"startInsertJetBalloon": 0x8012bf54,
		"TGCConsole2::startAppearJetBalloon": 0x8012c0f8,
		"startAppearJetBalloon": 0x8012c0f8,
		"TGCConsole2::startInsertTimer": 0x8012c224,
		"startInsertTimer": 0x8012c224,
		"TGCConsole2::startAppearTimer": 0x8012c3c0,
		"startAppearTimer": 0x8012c3c0,
		"TGCConsole2::startDisappearTimer": 0x8012c5cc,
		"startDisappearTimer": 0x8012c5cc,
		"TGCConsole2::startDisappearTelop": 0x8012c6fc,
		"startDisappearTelop": 0x8012c6fc,
		"TGCConsole2::startAppearTelop": 0x8012c844,
		"startAppearTelop": 0x8012c844,
		"TGCConsole2::startDownLeftBot": 0x8012ca1c,
		"startDownLeftBot": 0x8012ca1c,
		"TGCConsole2::startAppearLife": 0x8012cde0,
		"startAppearLife": 0x8012cde0,
		"TGCConsole2::resetLife": 0x8012d348,
		"resetLife": 0x8012d348,
		"TGCConsole2::startInsertLife": 0x8012d450,
		"startInsertLife": 0x8012d450,
		"TGCConsole2::startDisappearCoin": 0x8012d90c,
		"startDisappearCoin": 0x8012d90c,
		"TGCConsole2::startAppearCoin": 0x8012dbdc,
		"startAppearCoin": 0x8012dbdc,
		"TGCConsole2::startAppearTank": 0x8012def0,
		"startAppearTank": 0x8012def0,
		"TGCConsole2::endCameraDemo": 0x8012e014,
		"endCameraDemo": 0x8012e014,
		"TGCConsole2::startCameraDemo": 0x8012e278,
		"startCameraDemo": 0x8012e278,
		"TGCConsole2::entryHelpActor": 0x8012ebb4,
		"entryHelpActor": 0x8012ebb4,
		"TGCConsole2::loadAfter": 0x8012ec94,
		"TGCConsole2::load": 0x8013010c,
		"TGCConsole2::TGCConsole2": 0x80130fcc,
		"JUTPoint::JUTPoint": 0x801314d4,
		"GC2D::__sinit_GCConsole2_cpp": 0x80131530,
		"__sinit_GCConsole2_cpp": 0x80131530,
		"TTalk2D2::~TTalk2D2": 0x801318b0,
		"TTalk2D2::openWindow": 0x80131924,
		"openWindow": 0x80131924,
		"TTalk2D2::setTagParam": 0x80131df0,
		"setTagParam": 0x80131df0,
		"TTalk2D2::setupTextBox": 0x801329a8,
		"setupTextBox": 0x801329a8,
		"TTalk2D2::setupBoardTextBox": 0x80132d20,
		"setupBoardTextBox": 0x80132d20,
		"TTalk2D2::perform": 0x80133030,
		"TTalk2D2::eraseBoardWindow": 0x80133668,
		"eraseBoardWindow": 0x80133668,
		"TTalk2D2::eraseNormalWindow": 0x80133700,
		"eraseNormalWindow": 0x80133700,
		"TTalk2D2::closeNormalWindow": 0x80133924,
		"closeNormalWindow": 0x80133924,
		"TTalk2D2::checkControler": 0x80133b04,
		"checkControler": 0x80133b04,
		"TTalk2D2::moveTalkWindow": 0x80133e20,
		"moveTalkWindow": 0x80133e20,
		"TTalk2D2::checkBoardControler": 0x801340f8,
		"checkBoardControler": 0x801340f8,
		"TTalk2D2::moveBoardWindow": 0x801342b0,
		"moveBoardWindow": 0x801342b0,
		"TTalk2D2::openNormalWindow": 0x80134358,
		"openNormalWindow": 0x80134358,
		"TTalk2D2::openBoardWindow": 0x80134604,
		"openBoardWindow": 0x80134604,
		"TTalk2D2::makeBoxLine": 0x801346e8,
		"makeBoxLine": 0x801346e8,
		"TTalk2D2::openTalkWindow": 0x80134bfc,
		"openTalkWindow": 0x80134bfc,
		"TTalk2D2::forceCloseTalk": 0x80134e5c,
		"forceCloseTalk": 0x80134e5c,
		"TTalk2D2::setMessageID": 0x80134efc,
		"setMessageID": 0x80134efc,
		"TTalk2D2::loadAfter": 0x801352f4,
		"TTalk2D2::load": 0x80135864,
		"TTalk2D2::TTalk2D2": 0x80135c0c,
		"GC2D::__sinit_Talk2D2_cpp": 0x80135dac,
		"__sinit_Talk2D2_cpp": 0x80135dac,
		"TBoundPane::update": 0x801360a8,
		"TBoundPane::setPaneSize": 0x80136428,
		"TBoundPane::setPanePosition": 0x8013649c,
		"setPanePosition": 0x8013649c,
		"TBoundPane::TBoundPane": 0x80136510,
		"TPauseMenu2::~TPauseMenu2": 0x80136614,
		"TPauseMenu2::drawAppearPane": 0x80136688,
		"drawAppearPane": 0x80136688,
		"TPauseMenu2::setDrawEnd": 0x801368b0,
		"setDrawEnd": 0x801368b0,
		"TPauseMenu2::setDrawStart": 0x80136908,
		"setDrawStart": 0x80136908,
		"TPauseMenu2::getNextState": 0x80136ae0,
		"TPauseMenu2::perform": 0x80136ba0,
		"TPauseMenu2::disappearWindow": 0x801374e8,
		"disappearWindow": 0x801374e8,
		"TPauseMenu2::appearWindow": 0x80137924,
		"appearWindow": 0x80137924,
		"TPauseMenu2::loadAfter": 0x80137cdc,
		"TPauseMenu2::load": 0x80137f2c,
		"TPauseMenu2::TPauseMenu2": 0x8013828c,
		"GC2D::__sinit_PauseMenu2_cpp": 0x801383a0,
		"__sinit_PauseMenu2_cpp": 0x801383a0,
		"TMessageLoader::getMessageEntry": 0x8013869c,
		"getMessageEntry": 0x8013869c,
		"TMessageLoader::parseBlock": 0x801386c8,
		"parseBlock": 0x801386c8,
		"JSUIosBase::JSUIosBase": 0x80138904,
		"TMessageLoader::loadMessageData": 0x8013891c,
		"loadMessageData": 0x8013891c,
		"TSwitchHelpActor::check": 0x80138aa8,
		"TSwitchHelpActor::TSwitchHelpActor": 0x80138adc,
		"THelpActor::check": 0x80138bd0,
		"THelpActor::perform": 0x80138bf0,
		"THelpActor::loadAfter": 0x80138d48,
		"THelpActor::load": 0x80138df4,
		"THelpActor::THelpActor": 0x80138e9c,
		"GC2D::SMSGetMessageData": 0x80138f08,
		"SMSGetMessageData": 0x80138f08,
		"GC2D::SMSMakeTextBuffer": 0x801391f0,
		"SMSMakeTextBuffer": 0x801391f0,
		"TCardSave::~TCardSave": 0x801392d0,
		"TCardSave::getNextState": 0x80139344,
		"TCardSave::execMovement_": 0x80139384,
		"execMovement_": 0x80139384,
		"TCardSave::waitForAnyKeyBM": 0x8013c68c,
		"TCardSave::waitForSelect3": 0x8013cec0,
		"waitForSelect3": 0x8013cec0,
		"TCardSave::waitForSelect2": 0x8013d868,
		"waitForSelect2": 0x8013d868,
		"TCardSave::waitForSelectOver": 0x8013df60,
		"waitForSelectOver": 0x8013df60,
		"TCardSave::waitForAnyKey": 0x8013e578,
		"TCardSave::drawMessageBM": 0x8013ea80,
		"TCardSave::drawMessage": 0x8013efac,
		"TCardSave::waitForChoiceBM": 0x8013f2c4,
		"TCardSave::waitForChoice": 0x80140d50,
		"TCardSave::waitForStop": 0x80142704,
		"waitForStop": 0x80142704,
		"TCardSave::perform": 0x80143094,
		"TCardSave::init": 0x80143178,
		"TCardSave::initData": 0x80143244,
		"TCardSave::load": 0x801444ac,
		"TCardSave::TCardSave": 0x801444ec,
		"TCardSave::changeMode": 0x801446ec,
		"GC2D::__sinit_CardSave_cpp": 0x8014479c,
		"__sinit_CardSave_cpp": 0x8014479c,
		"TCardLoad::~TCardLoad": 0x80144a98,
		"TCardLoad::changeScene": 0x80144b0c,
		"changeScene": 0x80144b0c,
		"TCardLoad::setSelected": 0x8014627c,
		"setSelected": 0x8014627c,
		"TCardLoad::selectFunction": 0x801462f0,
		"selectFunction": 0x801462f0,
		"TCardLoad::selectBookmark": 0x80147c40,
		"selectBookmark": 0x80147c40,
		"TCardLoad::drawMessageBM": 0x80148b7c,
		"TCardLoad::drawMessage": 0x8014939c,
		"TCardLoad::waitForStart": 0x801498a8,
		"waitForStart": 0x801498a8,
		"TCardLoad::waitForAnyKeyBM": 0x8014a230,
		"TCardLoad::waitForAnyKey": 0x8014aad8,
		"TCardLoad::waitForChoiceBM": 0x8014b034,
		"TCardLoad::waitForChoice": 0x8014c1a4,
		"TCardLoad::changeMode": 0x8014d01c,
		"TCardLoad::titleDraw": 0x8014d0f8,
		"titleDraw": 0x8014d0f8,
		"TCardLoad::perform": 0x8014da40,
		"JSUInputStream::JSUInputStream": 0x8014e7a8,
		"TCardLoad::loadAfter": 0x8014e7cc,
		"TCardLoad::setupScoreScreen": 0x8014e8d0,
		"setupScoreScreen": 0x8014e8d0,
		"TCardLoad::load": 0x8014f710,
		"TCardLoad::TCardLoad": 0x8015065c,
		"GC2D::__sinit_CardLoad_cpp": 0x801508dc,
		"__sinit_CardLoad_cpp": 0x801508dc,
		"TConsoleStr::~TConsoleStr": 0x80150bd8,
		"TConsoleStr::startOpenWipe": 0x80150c4c,
		"startOpenWipe": 0x80150c4c,
		"TConsoleStr::startCloseWipe": 0x80150e0c,
		"startCloseWipe": 0x80150e0c,
		"TConsoleStr::processScenario": 0x801513a0,
		"processScenario": 0x801513a0,
		"TConsoleStr::processMiss": 0x80151470,
		"processMiss": 0x80151470,
		"TConsoleStr::processShineGet": 0x801517d0,
		"processShineGet": 0x801517d0,
		"TConsoleStr::processGo": 0x80151ad8,
		"processGo": 0x80151ad8,
		"TConsoleStr::processReady": 0x8015216c,
		"processReady": 0x8015216c,
		"TConsoleStr::startAppearScenario": 0x801526a4,
		"startAppearScenario": 0x801526a4,
		"TConsoleStr::startAppearMiss": 0x801527e8,
		"startAppearMiss": 0x801527e8,
		"TConsoleStr::startAppearShineGet": 0x80152920,
		"startAppearShineGet": 0x80152920,
		"TConsoleStr::startAppearGo": 0x80152948,
		"startAppearGo": 0x80152948,
		"TConsoleStr::startAppearReady": 0x801529bc,
		"startAppearReady": 0x801529bc,
		"TConsoleStr::perform": 0x80152a30,
		"TConsoleStr::loadAfter": 0x8015316c,
		"TConsoleStr::load": 0x801531a8,
		"TConsoleStr::getWipeCloseTime": 0x80153568,
		"getWipeCloseTime": 0x80153568,
		"TConsoleStr::TConsoleStr": 0x80153590,
		"GC2D::__sinit_ConsoleStr_cpp": 0x80153648,
		"__sinit_ConsoleStr_cpp": 0x80153648,
		"TSelectMenu::~TSelectMenu": 0x801536b0,
		"TSelectMenu::startOpenWindow": 0x80153724,
		"startOpenWindow": 0x80153724,
		"TSelectMenu::getPrevIndex": 0x80153970,
		"getPrevIndex": 0x80153970,
		"TSelectMenu::getNextIndex": 0x801539c8,
		"getNextIndex": 0x801539c8,
		"TSelectMenu::perform": 0x80153a24,
		"TSelectMenu::startMove": 0x801551d0,
		"startMove": 0x801551d0,
		"TSelectMenu::initData": 0x80155230,
		"TSelectMenu::TSelectMenu": 0x801561fc,
		"TSelectGrad::perform": 0x8015638c,
		"TSelectGrad::setStageColor": 0x80156748,
		"setStageColor": 0x80156748,
		"TSelectGrad::TSelectGrad": 0x80156878,
		"TSelectGrad::~TSelectGrad": 0x80156980,
		"GC2D::__sinit_SelectMenu_cpp": 0x801569f4,
		"__sinit_SelectMenu_cpp": 0x801569f4,
		"TSelectDir::direct": 0x80156cf0,
		"TSelectDir::changeOrder": 0x80156fb4,
		"changeOrder": 0x80156fb4,
		"TSelectDir::rsetup": 0x80156fdc,
		"TSelectDir::setupThreadFunc": 0x80158268,
		"TSelectDir::setup": 0x80158288,
		"TSelectDir::TSelectDir": 0x801583c0,
		"GC2D::__sinit_SelectDir_cpp": 0x80158500,
		"__sinit_SelectDir_cpp": 0x80158500,
		"TSelectShine::~TSelectShine": 0x8015880c,
		"TSelectShine::move": 0x80158858,
		"TSelectShine::TSelectShine": 0x80158d28,
		"TSelectShineManager::perform": 0x80158fe0,
		"JGeometry::TVec2<float><float>::sub": 0x8015947c,
		"GC2D::JMASSin": 0x801594b0,
		"GC2D::JMASCos": 0x801594cc,
		"TSelectShineManager::startDecrease": 0x801594e8,
		"startDecrease": 0x801594e8,
		"TSelectShineManager::startIncrease": 0x801595ec,
		"startIncrease": 0x801595ec,
		"TSelectShineManager::startClose": 0x801596f0,
		"startClose": 0x801596f0,
		"TSelectShineManager::initData": 0x8015980c,
		"TSelectShineManager::TSelectShineManager": 0x80159d74,
		"TSelectShineManager::~TSelectShineManager": 0x80159e38,
		"GC2D::__sinit_SelectShine2_cpp": 0x80159eac,
		"__sinit_SelectShine2_cpp": 0x80159eac,
		"TBlendPane::update": 0x80159ecc,
		"TBlendPane::TBlendPane": 0x80159fcc,
		"TGuide::~TGuide": 0x8015a01c,
		"TGuide::perform": 0x8015a090,
		"TExPane::setPaneSize": 0x8015a6a0,
		"TExPane::setPaneAlpha": 0x8015a764,
		"setPaneAlpha": 0x8015a764,
		"TGuide::appearGuidePane": 0x8015a804,
		"appearGuidePane": 0x8015a804,
		"TGuide::placeMario": 0x8015abbc,
		"placeMario": 0x8015abbc,
		"TGuide::changeBotStatus": 0x8015ae1c,
		"changeBotStatus": 0x8015ae1c,
		"TGuide::checkPoint": 0x8015b478,
		"checkPoint": 0x8015b478,
		"TGuide::linkSelect": 0x8015b5ac,
		"linkSelect": 0x8015b5ac,
		"TGuide::startMoveCursor": 0x8015c378,
		"startMoveCursor": 0x8015c378,
		"TGuide::setup": 0x8015c38c,
		"TGuide::resetScore": 0x8015c3e8,
		"resetScore": 0x8015c3e8,
		"TGuide::resetObjects": 0x8015cd20,
		"resetObjects": 0x8015cd20,
		"TGuide::load": 0x8015d0a8,
		"TGuide::TGuide": 0x8015daac,
		"GC2D::__sinit_Guide_cpp": 0x8015dbf0,
		"__sinit_Guide_cpp": 0x8015dbf0,
		"TSunShine::~TSunShine": 0x8015deec,
		"TSunShine::loadAfter": 0x8015df70,
		"TSunShine::perform": 0x8015dfcc,
		"TSunGlass::load": 0x8015e0a8,
		"TSunGlass::loadAfter": 0x8015e0e4,
		"TSunGlass::perform": 0x8015e18c,
		"TSunGlass::draw": 0x8015e27c,
		"TSunGlass::startFade": 0x8015e49c,
		"startFade": 0x8015e49c,
		"TShineFader::~TShineFader": 0x8015e688,
		"TShineFader::load": 0x8015e71c,
		"TShineFader::registFadeout": 0x8015e73c,
		"registFadeout": 0x8015e73c,
		"TShineFader::perform": 0x8015e780,
		"TShineFader::update": 0x8015e7fc,
		"TProgSelect::~TProgSelect": 0x8015e91c,
		"TProgSelect::perform": 0x8015e990,
		"TProgSelect::TProgSelect": 0x8015eca8,
		"GC2D::Hx_Test5": 0x8015ee9c,
		"Hx_Test5": 0x8015ee9c,
		"GC2D::Hx_Test4": 0x8015f3c8,
		"Hx_Test4": 0x8015f3c8,
		"GC2D::Hxs1_Test2": 0x8015f7e4,
		"Hxs1_Test2": 0x8015f7e4,
		"GC2D::Hx_Test2R": 0x8015fac4,
		"Hx_Test2R": 0x8015fac4,
		"GC2D::Hx_Test2": 0x8015ff94,
		"Hx_Test2": 0x8015ff94,
		"GC2D::Hxs1_Test1": 0x80160428,
		"Hxs1_Test1": 0x80160428,
		"GC2D::Hx_Test1": 0x8016063c,
		"Hx_Test1": 0x8016063c,
		"GC2D::Hx_MovieStartSyncEx": 0x80160848,
		"Hx_MovieStartSyncEx": 0x80160848,
		"GC2D::Hx_Logo": 0x801608ec,
		"Hx_Logo": 0x801608ec,
		"GC2D::Hxs_PenDraw": 0x80160d4c,
		"Hxs_PenDraw": 0x80160d4c,
		"GC2D::Hxs_Logo_MagDraw": 0x80160f20,
		"Hxs_Logo_MagDraw": 0x80160f20,
		"GC2D::Hxs_Logo_TexDraw": 0x801610c8,
		"Hxs_Logo_TexDraw": 0x801610c8,
		"GC2D::Hxs_Logo_TexSetup": 0x801612f4,
		"Hxs_Logo_TexSetup": 0x801612f4,
		"GC2D::Hxs_Logo_ExtraDraw": 0x8016147c,
		"Hxs_Logo_ExtraDraw": 0x8016147c,
		"GC2D::Hx_GameOver": 0x80161604,
		"Hx_GameOver": 0x80161604,
		"GC2D::Hxs_GameOver": 0x80161afc,
		"Hxs_GameOver": 0x80161afc,
		"GC2D::Hx_Door": 0x80162058,
		"Hx_Door": 0x80162058,
		"GC2D::Hxs_FrBufferMorf2B": 0x8016223c,
		"Hxs_FrBufferMorf2B": 0x8016223c,
		"GC2D::Hxs_FrBufferMorf2": 0x80162448,
		"Hxs_FrBufferMorf2": 0x80162448,
		"GC2D::Hxs2_Circle": 0x801626ac,
		"Hxs2_Circle": 0x801626ac,
		"GC2D::Hxs1_Circle": 0x80162a7c,
		"Hxs1_Circle": 0x80162a7c,
		"GC2D::Hx_Circle": 0x80162d8c,
		"Hx_Circle": 0x80162d8c,
		"GC2D::Hx_MotionUpdate": 0x801630d8,
		"Hx_MotionUpdate": 0x801630d8,
		"GC2D::Hx_MotionSet": 0x80163144,
		"Hx_MotionSet": 0x80163144,
		"GC2D::Hx_TimerCountDown": 0x801631bc,
		"Hx_TimerCountDown": 0x801631bc,
		"GC2D::Hx_UpdateWipe": 0x801631e4,
		"Hx_UpdateWipe": 0x801631e4,
		"GC2D::Hx_GetWipeType": 0x80163324,
		"Hx_GetWipeType": 0x80163324,
		"GC2D::dummy_handler": 0x80163338,
		"dummy_handler": 0x80163338,
		"GC2D::Hx_StartWipe": 0x8016333c,
		"Hx_StartWipe": 0x8016333c,
		"GC2D::Hx_RemoveResource": 0x801633f8,
		"Hx_RemoveResource": 0x801633f8,
		"GC2D::Hx_ProvideResourceEx": 0x80163464,
		"Hx_ProvideResourceEx": 0x80163464,
		"GC2D::Hx_ProvideResource": 0x801634bc,
		"Hx_ProvideResource": 0x801634bc,
		"GC2D::Hx_ResetWipe": 0x80163544,
		"Hx_ResetWipe": 0x80163544,
		"GC2D::Hx_Warning": 0x80163580,
		"Hx_Warning": 0x80163580,
		"GC2D::Frb2_RendBox": 0x80163584,
		"Frb2_RendBox": 0x80163584,
		"GC2D::Frb2_InitBlackBox": 0x80163634,
		"Frb2_InitBlackBox": 0x80163634,
		"GC2D::Frb2_InitGx": 0x801636bc,
		"Frb2_InitGx": 0x801636bc,
		"GC2D::Hx_FrBufferMorf": 0x801637fc,
		"Hx_FrBufferMorf": 0x801637fc,
		"GC2D::__Hx_FrBufferMorf": 0x80163838,
		"__Hx_FrBufferMorf": 0x80163838,
		"GC2D::Hx_SetVFilter": 0x80163aa8,
		"Hx_SetVFilter": 0x80163aa8,
		"GC2D::Hx_GetFrBuffer": 0x80163da4,
		"Hx_GetFrBuffer": 0x80163da4,
		"GC2D::Hgx_ReadTexture": 0x80163e54,
		"Hgx_ReadTexture": 0x80163e54,
		"GC2D::Hgx_init_tobj_resource": 0x80163edc,
		"Hgx_init_tobj_resource": 0x80163edc,
		"GC2D::Hx_GxInit": 0x80163f7c,
		"Hx_GxInit": 0x80163f7c,
		"GC2D::Hx_CameraInit": 0x801640e4,
		"Hx_CameraInit": 0x801640e4,
		"TMovieSubTitle::~TMovieSubTitle": 0x801642b8,
		"TMovieSubTitle::setCurMessage": 0x8016432c,
		"setCurMessage": 0x8016432c,
		"TMovieSubTitle::perform": 0x801643c4,
		"TMovieSubTitle::setupResource": 0x80164558,
		"setupResource": 0x80164558,
		"TMovieSubTitle::TMovieSubTitle": 0x801646ec,
		"TOptionControl::resetChangedSetting": 0x80164774,
		"resetChangedSetting": 0x80164774,
		"TOptionControl::isChangedSetting": 0x801647e0,
		"isChangedSetting": 0x801647e0,
		"MSound::startSoundSystemSE": 0x80164870,
		"TOptionControl::setType": 0x801648dc,
		"setType": 0x801648dc,
		"TOptionControl::movementOption2Card": 0x801649e4,
		"movementOption2Card": 0x801649e4,
		"TOptionControl::movementOption": 0x80164adc,
		"movementOption": 0x80164adc,
		"JGeometry::TUtil<int><int>::mod": 0x80164dc8,
		"JGeometry::TUtil<long><long>::clamp": 0x80164e08,
		"clamp": 0x80164e08,
		"TOptionControl::movementCard2Option": 0x80164e28,
		"movementCard2Option": 0x80164e28,
		"TOptionControl::draw": 0x80164f4c,
		"TOptionControl::loadSetting": 0x80164f7c,
		"loadSetting": 0x80164f7c,
		"TOptionControl::load": 0x8016534c,
		"TOptionSoundUnit::setInfluencedAlphaRecursive": 0x80165518,
		"JSUTree<J2DPane>::getObject": 0x80165604,
		"getObject": 0x80165604,
		"TOptionSoundUnit::adjustSound": 0x80165614,
		"adjustSound": 0x80165614,
		"TOptionSoundUnit::adjustView": 0x801656b4,
		"TOptionSoundUnit::setState": 0x80165ac8,
		"TOptionSoundUnit::typeToFlag": 0x80165e78,
		"typeToFlag": 0x80165e78,
		"TOptionSoundUnit::flagToType": 0x80165eb4,
		"flagToType": 0x80165eb4,
		"TOptionSoundUnit::adjust": 0x80165ef0,
		"TOptionSoundUnit::update": 0x80165f4c,
		"TOptionSoundUnit::initSurroundAnm": 0x80166220,
		"initSurroundAnm": 0x80166220,
		"TOptionSoundUnit::initSteleoAnm": 0x80166598,
		"initSteleoAnm": 0x80166598,
		"TOptionSoundUnit::TOptionSoundUnit": 0x801667c8,
		"@unnamed@::ArrayWrapper<TPatternAnmControl*>::ArrayWrapper": 0x80166bc0,
		"ArrayWrapper": 0x80166bc0,
		"TOptionRumbleUnit::setInfluencedAlphaRecursive": 0x80166bd0,
		"TOptionRumbleUnit::setState": 0x80166cbc,
		"TOptionRumbleUnit::adjustView": 0x801670c4,
		"TOptionRumbleUnit::adjust": 0x801671d8,
		"TOptionRumbleUnit::update": 0x80167324,
		"TOptionRumbleUnit::TOptionRumbleUnit": 0x801676e8,
		"TToggleControl::toggle": 0x80167aec,
		"toggle": 0x80167aec,
		"TPatternAnmControl::hide": 0x80167b84,
		"hide": 0x80167b84,
		"TPatternAnmControl::show": 0x80167c00,
		"show": 0x80167c00,
		"TPatternAnmControl::update": 0x80167ca0,
		"TPatternAnmControl::setupAnm": 0x80167db0,
		"setupAnm": 0x80167db0,
		"GC2D::__sinit_Option_cpp": 0x80167edc,
		"__sinit_Option_cpp": 0x80167edc,
		"TMovieRumble::~TMovieRumble": 0x801681d8,
		"TMovieRumble::checkRumbleOff": 0x8016824c,
		"checkRumbleOff": 0x8016824c,
		"TMovieRumble::perform": 0x80168358,
		"TMovieRumble::init": 0x801683d8,
		"TMovieRumble::TMovieRumble": 0x80168538,
		"TConductor::perform": 0x80020344,
		"TConductor::searchF": 0x800207b4,
		"TConductor::genEnemyFromPollution": 0x800209c8,
		"genEnemyFromPollution": 0x800209c8,
		"TConductor::killEnemiesWithin": 0x80020d14,
		"killEnemiesWithin": 0x80020d14,
		"TConductor::makeOneEnemyAppear": 0x80020dec,
		"makeOneEnemyAppear": 0x80020dec,
		"TConductor::makeEnemyAppear": 0x80020f80,
		"makeEnemyAppear": 0x80020f80,
		"TConductor::isBossDefeated": 0x800211ac,
		"isBossDefeated": 0x800211ac,
		"TConductor::getManagerByName": 0x8002138c,
		"getManagerByName": 0x8002138c,
		"TConductor::getGraphByName": 0x80021448,
		"TConductor::init": 0x8002147c,
		"TConductor::registerEnemyInfoTable": 0x800215ac,
		"registerEnemyInfoTable": 0x800215ac,
		"TConductor::registerSDLModelData": 0x800215b4,
		"registerSDLModelData": 0x800215b4,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::insert": 0x800215fc,
		"TConductor::registerAreaCylinderManager": 0x800216b4,
		"registerAreaCylinderManager": 0x800216b4,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::insert": 0x800216fc,
		"TConductor::registerGenerator": 0x800217b4,
		"registerGenerator": 0x800217b4,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::insert": 0x800217fc,
		"TConductor::registerOtherObj": 0x800218b4,
		"registerOtherObj": 0x800218b4,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::insert": 0x800218fc,
		"TConductor::registerAloneActor": 0x800219b4,
		"registerAloneActor": 0x800219b4,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::insert": 0x800219fc,
		"TConductor::registerEnemyManager": 0x80021ab4,
		"registerEnemyManager": 0x80021ab4,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::insert": 0x80021afc,
		"TConductor::registerManager": 0x80021bb4,
		"registerManager": 0x80021bb4,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::insert": 0x80021bfc,
		"TConductor::initGraphGroup": 0x80021cb4,
		"TConductor::makeGraphGroup": 0x80021cd8,
		"makeGraphGroup": 0x80021cd8,
		"TConductor::~TConductor": 0x80021d34,
		"JGadget::TList<TLiveManager*,JGadget::TAllocator<TLiveManager*>>::erase": 0x80022158,
		"JGadget::TList<P12TLiveManager,Q27JGadget27TAllocator<P12TLiveManager>>::iterator::iterator": 0x800221c4,
		"JGadget::TList<TEnemyManager*,JGadget::TAllocator<TEnemyManager*>>::erase": 0x800221e4,
		"JGadget::TList<P13TEnemyManager,Q27JGadget28TAllocator<P13TEnemyManager>>::iterator::iterator": 0x80022250,
		"JGadget::TList<TLiveActor*,JGadget::TAllocator<TLiveActor*>>::erase": 0x80022270,
		"JGadget::TList<P10TLiveActor,Q27JGadget25TAllocator<P10TLiveActor>>::iterator::iterator": 0x800222dc,
		"JGadget::TList<JDrama::TViewObj*,JGadget::TAllocator<JDrama::TViewObj*>>::erase": 0x800222fc,
		"JGadget::TList<PQ26JDrama8TViewObj,Q27JGadget31TAllocator<PQ26JDrama8TViewObj>>::iterator::iterator": 0x80022368,
		"JGadget::TList<TAreaCylinderManager*,JGadget::TAllocator<TAreaCylinderManager*>>::erase": 0x80022388,
		"JGadget::TList<P20TAreaCylinderManager,Q27JGadget35TAllocator<P20TAreaCylinderManager>>::iterator::iterator": 0x800223f4,
		"JGadget::TList<TGenerator*,JGadget::TAllocator<TGenerator*>>::erase": 0x80022414,
		"JGadget::TList<P10TGenerator,Q27JGadget25TAllocator<P10TGenerator>>::iterator::iterator": 0x80022480,
		"JGadget::TList<SDLModelData*,JGadget::TAllocator<SDLModelData*>>::erase": 0x800224a0,
		"JGadget::TList<P12SDLModelData,Q27JGadget27TAllocator<P12SDLModelData>>::iterator::iterator": 0x8002250c,
		"TConductor::TConductor": 0x80022514,
		"TEffectModel::control": 0x80022778,
		"TEffectExplosion::generate": 0x80022800,
		"TEffectExplosion::reset": 0x80022960,
		"TEffectExplosion::init": 0x80022a84,
		"TEffectExplosionManager::createModelData": 0x80022ba8,
		"TEffectExplosionManager::createEnemyInstance": 0x80022bdc,
		"TEffectExplosionManager::loadAfter": 0x80022c4c,
		"TEffectExplosionManager::load": 0x80022d10,
		"TEffectExplosionManager::TEffectExplosionManager": 0x80022d7c,
		"TEffectModelManager::~TEffectModelManager": 0x80022dc4,
		"TEffectColumSand::generate": 0x80022e28,
		"TEffectColumSand::reset": 0x80022ee0,
		"TEffectColumSand::init": 0x80023014,
		"TEffectColumSandManager::createModelData": 0x800230dc,
		"TEffectColumSandManager::createEnemyInstance": 0x80023110,
		"TEffectColumSandManager::loadAfter": 0x80023180,
		"TEffectColumSandManager::load": 0x800231d8,
		"TEffectColumSandManager::TEffectColumSandManager": 0x80023244,
		"TEffectBombColumWater::generate": 0x8002328c,
		"TEffectBombColumWater::reset": 0x800233f0,
		"TEffectBombColumWater::init": 0x80023544,
		"TEffectBombColumWaterManager::createModelData": 0x80023618,
		"TEffectBombColumWaterManager::createEnemyInstance": 0x8002364c,
		"TEffectBombColumWaterManager::loadAfter": 0x800236bc,
		"TEffectBombColumWaterManager::load": 0x80023780,
		"TEffectBombColumWaterManager::TEffectBombColumWaterManager": 0x800237ec,
		"TEffectColumWater::generate": 0x80023834,
		"TEffectColumWater::reset": 0x8002396c,
		"TEffectColumWater::init": 0x80023ac0,
		"TEffectColumWaterManager::createModelData": 0x80023b94,
		"TEffectColumWaterManager::createEnemyInstance": 0x80023bc8,
		"TEffectColumWaterManager::loadAfter": 0x80023c38,
		"TEffectColumWaterManager::load": 0x80023cc4,
		"TEffectColumWaterManager::TEffectColumWaterManager": 0x80023d30,
		"TEffectModel::calcRootMatrix": 0x80023d78,
		"TEffectModel::moveObject": 0x80023e6c,
		"TEffectModel::reset": 0x80023ed0,
		"TEffectModel::init": 0x80023f94,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::insert": 0x80024000,
		"TEffectObjManager::perform": 0x800240b8,
		"TEffectObjManager::load": 0x8002418c,
		"TEffectObjManager::TEffectObjManager": 0x800241ac,
		"JGadget::TList<TEffectObjBase*,JGadget::TAllocator<TEffectObjBase*>>::erase": 0x800242c4,
		"TEffectObjBase::behaveToWater": 0x80024330,
		"TEffectObjBase::moveObject": 0x80024418,
		"TEffectObjBase::receiveMessage": 0x800245e8,
		"TEffectObjBase::perform": 0x80024628,
		"TEffectObjBase::reset": 0x80024680,
		"TEffectObjBase::init": 0x800246ac,
		"TEffectObjBase::load": 0x8002470c,
		"TEffectObjBase::TEffectObjBase": 0x80024794,
		"TEffectBiancoFunsui::emitEffect": 0x800247ec,
		"TEffectBiancoFunsui::loadAfter": 0x800248bc,
		"TEffectPinnaFunsui::emitEffect": 0x8002492c,
		"TEffectPinnaFunsui::loadAfter": 0x800249fc,
		"TSimpleEffect::perform": 0x80024a6c,
		"TEffectExplosionManager::~TEffectExplosionManager": 0x80024aa0,
		"TEffectColumSandManager::~TEffectColumSandManager": 0x80024b98,
		"TEffectBombColumWaterManager::~TEffectBombColumWaterManager": 0x80024c90,
		"TEffectColumWaterManager::~TEffectColumWaterManager": 0x80024d88,
		"TEffectObjManager::~TEffectObjManager": 0x80024dfc,
		"JGadget::TList<P14TEffectObjBase,Q27JGadget29TAllocator<P14TEffectObjBase>>::iterator::iterator": 0x80024f08,
		"Enemy::__sinit_effectObj_cpp": 0x80025108,
		"__sinit_effectObj_cpp": 0x80025108,
		"TEMarioManager::~TEMarioManager": 0x8002544c,
		"TEMarioManager::createEnemyInstance": 0x800254b0,
		"TEMarioManager::load": 0x8002550c,
		"TEMarioManager::TEMarioManager": 0x80025578,
		"TEMario::perform": 0x800255b4,
		"TEMario::forceDisappear": 0x800258a4,
		"forceDisappear": 0x800258a4,
		"TEMario::startGateDrawing": 0x800258cc,
		"TEMario::startMonteReplay": 0x800258f0,
		"TEMario::startRunAway": 0x80025914,
		"TEMario::isDownWaitingToTalk": 0x80025938,
		"isDownWaitingToTalk": 0x80025938,
		"TEMario::isReachedToGate": 0x80025958,
		"isReachedToGate": 0x80025958,
		"TEMario::isGoal": 0x80025978,
		"isGoal": 0x80025978,
		"TEMario::kill": 0x80025998,
		"TEMario::receiveMessage": 0x800259d8,
		"TEMario::init": 0x80025a6c,
		"TEMario::loadAfter": 0x80025c20,
		"TEMario::load": 0x80025c7c,
		"TEMario::TEMario": 0x8002601c,
		"Enemy::__sinit_emario_cpp": 0x800260cc,
		"__sinit_emario_cpp": 0x800260cc,
		"TSpineEnemy::perform": 0x800263d0,
		"TSpineEnemy::checkCurAnmEnd": 0x80026494,
		"checkCurAnmEnd": 0x80026494,
		"TSpineEnemy::getCurAnmFrameNo": 0x80026530,
		"getCurAnmFrameNo": 0x80026530,
		"TSpineEnemy::doShortCut": 0x800265cc,
		"doShortCut": 0x800265cc,
		"TSpineEnemy::zigzagToCurPathNode": 0x800268ec,
		"zigzagToCurPathNode": 0x800268ec,
		"TSpineEnemy::walkToCurPathNode": 0x80026e1c,
		"walkToCurPathNode": 0x80026e1c,
		"TSpineEnemy::turnToCurPathNode": 0x80027300,
		"turnToCurPathNode": 0x80027300,
		"TSpineEnemy::goToDirLimitedNextGraphNode": 0x800274e4,
		"goToDirLimitedNextGraphNode": 0x800274e4,
		"TSpineEnemy::goToDirectedNextGraphNode": 0x80027694,
		"goToDirectedNextGraphNode": 0x80027694,
		"TSpineEnemy::goToRandomEscapeGraphNode": 0x800277a8,
		"goToRandomEscapeGraphNode": 0x800277a8,
		"TSpineEnemy::goToRandomNextGraphNode": 0x800278b0,
		"goToRandomNextGraphNode": 0x800278b0,
		"TSpineEnemy::jumpToNextGraphNode": 0x800279b4,
		"jumpToNextGraphNode": 0x800279b4,
		"TSpineEnemy::goToShortestNextGraphNode": 0x80027ad4,
		"goToShortestNextGraphNode": 0x80027ad4,
		"TSpineEnemy::setGoalPathFromGraph": 0x80027bf8,
		"setGoalPathFromGraph": 0x80027bf8,
		"TSpineEnemy::isInSight": 0x80027ca4,
		"isInSight": 0x80027ca4,
		"TSpineEnemy::receiveMessage": 0x80027cd8,
		"TSpineEnemy::updateSquareToMario": 0x80027d38,
		"updateSquareToMario": 0x80027d38,
		"TSpineEnemy::calcTurnSpeedToReach": 0x80027d70,
		"calcTurnSpeedToReach": 0x80027d70,
		"TSpineEnemy::calcMinimumTurnRadius": 0x80027e50,
		"calcMinimumTurnRadius": 0x80027e50,
		"TSpineEnemy::resetSRTV": 0x80027ee4,
		"resetSRTV": 0x80027ee4,
		"TSpineEnemy::resetToPosition": 0x80028030,
		"resetToPosition": 0x80028030,
		"TSpineEnemy::getSaveParam": 0x8002813c,
		"TSpineEnemy::calcRootMatrix": 0x80028148,
		"TSpineEnemy::calcEnemyRootMatrix": 0x800281e4,
		"calcEnemyRootMatrix": 0x800281e4,
		"TSpineEnemy::load": 0x800285a0,
		"TSpineEnemy::reset": 0x80028664,
		"TSpineEnemy::init": 0x8002871c,
		"TSpineEnemy::TSpineEnemy": 0x8002880c,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::~TSolidStack": 0x80028998,
		"TSolidStack<TPathNode>::~TSolidStack": 0x800289e4,
		"TPathNode::TPathNode": 0x80028a30,
		"TSpineBase<TLiveActor>::~TSpineBase": 0x80028a4c,
		"~TSpineBase": 0x80028a4c,
		"Enemy::__sinit_enemy_cpp": 0x80028bb4,
		"__sinit_enemy_cpp": 0x80028bb4,
		"TEnemyPolluteModel::~TEnemyPolluteModel": 0x80028eb8,
		"TEnemyPolluteModel::setAnm": 0x80028f2c,
		"TEnemyPolluteModel::perform": 0x80028f30,
		"TEnemyPolluteModel::TEnemyPolluteModel": 0x80029014,
		"TEnemyPolluteModelManager::generatePolluteModel": 0x800290e4,
		"generatePolluteModel": 0x800290e4,
		"TEnemyPolluteModelManager::perform": 0x8002926c,
		"TEnemyPolluteModelManager::init": 0x8002937c,
		"TEnemyAttachment::perform": 0x800293b4,
		"TEnemyAttachment::behaveToHost": 0x800294d8,
		"TEnemyAttachment::calcRootMatrix": 0x800294dc,
		"TEnemyAttachment::sendMessage": 0x80029580,
		"TEnemyAttachment::moveObject": 0x80029634,
		"TEnemyAttachment::set": 0x800296d0,
		"TEnemyAttachment::kill": 0x8002970c,
		"TEnemyAttachment::rebirth": 0x80029728,
		"TEnemyAttachment::bind": 0x8002974c,
		"TEnemyAttachment::setBehavior": 0x800296cc,
		"TEnemyAttachment::getNowGravity": 0x800299cc,
		"TEnemyAttachment::recoverScale": 0x800299d4,
		"TEnemyAttachment::forceKill": 0x80029a20,
		"TEnemyAttachment::behaveToHitWall": 0x80029ad8,
		"TEnemyAttachment::behaveToHitGround": 0x80029b04,
		"TEnemyAttachment::loadInit": 0x80029b58,
		"TEnemyAttachment::TEnemyAttachment": 0x80029bd4,
		"TEnemyPolluteModelManager::~TEnemyPolluteModelManager": 0x80029c34,
		"TEnemyAttachment::appear": 0x80029d14,
		"TEnemyAttachment::receiveMessage": 0x80029d30,
		"TEnemyManager::copyAnmMtx": 0x80029df4,
		"copyAnmMtx": 0x80029df4,
		"TEnemyManager::countLivingEnemy": 0x80029fa8,
		"countLivingEnemy": 0x80029fa8,
		"TEnemyManager::killChildrenWithin": 0x8002a010,
		"killChildrenWithin": 0x8002a010,
		"TEnemyManager::killChildren": 0x8002a0e8,
		"killChildren": 0x8002a0e8,
		"TEnemyManager::getFarOutEnemy": 0x8002a120,
		"getFarOutEnemy": 0x8002a120,
		"TEnemyManager::getDeadEnemy": 0x8002a1c0,
		"getDeadEnemy": 0x8002a1c0,
		"TEnemyManager::getNearestEnemy": 0x8002a228,
		"getNearestEnemy": 0x8002a228,
		"TEnemyManager::perform": 0x8002a2e8,
		"TEnemyManager::performShared": 0x8002a56c,
		"performShared": 0x8002a56c,
		"TEnemyManager::copyFromShared": 0x8002a960,
		"copyFromShared": 0x8002a960,
		"TEnemyManager::updateAnmSoundShared": 0x8002abd0,
		"updateAnmSoundShared": 0x8002abd0,
		"TEnemyManager::setSharedFlags": 0x8002ad28,
		"setSharedFlags": 0x8002ad28,
		"TEnemyManager::clipEnemies": 0x8002ae08,
		"TEnemyManager::createEnemies": 0x8002ae4c,
		"TEnemyManager::createEnemyInstance": 0x8002afb8,
		"TEnemyManager::load": 0x8002afc0,
		"TEnemyManager::getSharedMActorSet": 0x8002b01c,
		"getSharedMActorSet": 0x8002b01c,
		"TEnemyManager::createSharedMActorSet": 0x8002b064,
		"createSharedMActorSet": 0x8002b064,
		"TSharedMActorSet::TSharedMActorSet": 0x8002b150,
		"TEnemyManager::~TEnemyManager": 0x8002b164,
		"TEnemyManager::TEnemyManager": 0x8002b1f8,
		"TSharedMActorSet::init": 0x8002b2f4,
		"TSpineEnemyParams::TSpineEnemyParams": 0x8002b45c,
		"Enemy::__sinit_enemymanager_cpp": 0x8002b640,
		"__sinit_enemymanager_cpp": 0x8002b640,
		"TEnemyMario::perform": 0x8002ba18,
		"TEnemyMario::drawHPMeter": 0x8002bfc8,
		"drawHPMeter": 0x8002bfc8,
		"TEnemyMario::damageExec": 0x8002c26c,
		"TEnemyMario::playerControl": 0x8002c270,
		"TEnemyMario::checkController": 0x8002c310,
		"TEnemyMario::checkReturn": 0x8002c8d0,
		"TEnemyMario::reachGoal": 0x8002ca10,
		"reachGoal": 0x8002ca10,
		"TEnemyMario::thinkTrample": 0x8002ca30,
		"thinkTrample": 0x8002ca30,
		"TEnemyMario::hitWater": 0x8002ca8c,
		"TEnemyMario::consider": 0x8002cc40,
		"consider": 0x8002cc40,
		"JGeometry::TRotation3<JGeometry::TMatrix44<JGeometry::SMatrix44C<float><float>>>::TRotation3": 0x8002d494,
		"TPathNode::getPoint": 0x8002d4a0,
		"TEnemyMario::startGateDrawing": 0x8002d4c0,
		"TEnemyMario::emWaitingToInviteMario": 0x8002d524,
		"emWaitingToInviteMario": 0x8002d524,
		"TEnemyMario::decideDoingAfterCarry": 0x8002d6c0,
		"decideDoingAfterCarry": 0x8002d6c0,
		"TEnemyMario::emRunAwayToNearestNode": 0x8002d824,
		"emRunAwayToNearestNode": 0x8002d824,
		"TEnemyMario::findRunAwayNearestNode": 0x8002dd04,
		"findRunAwayNearestNode": 0x8002dd04,
		"TEnemyMario::startRunAway": 0x8002dfa8,
		"TEnemyMario::emDownAnimation": 0x8002dfbc,
		"emDownAnimation": 0x8002dfbc,
		"TEnemyMario::emReplayJumpToNearestNode": 0x8002e0e8,
		"emReplayJumpToNearestNode": 0x8002e0e8,
		"TEnemyMario::emReplay": 0x8002e8cc,
		"emReplay": 0x8002e8cc,
		"TEnemyMario::emDisappearToGate": 0x8002eb00,
		"emDisappearToGate": 0x8002eb00,
		"TEnemyMario::startDisappear": 0x8002ec6c,
		"startDisappear": 0x8002ec6c,
		"TEnemyMario::emWalkAround": 0x8002ed28,
		"emWalkAround": 0x8002ed28,
		"TEnemyMario::emJumping": 0x8002eef0,
		"emJumping": 0x8002eef0,
		"TEnemyMario::emWaiting": 0x8002f04c,
		"emWaiting": 0x8002f04c,
		"TEnemyMario::tryTake": 0x8002f164,
		"tryTake": 0x8002f164,
		"TEnemyMario::startMonteReplay": 0x8002f254,
		"TEnemyMario::initEnemyValues": 0x8002f39c,
		"initEnemyValues": 0x8002f39c,
		"TEnemyMario::initModel": 0x80030610,
		"TEnemyMario::initValues": 0x80030ef4,
		"Enemy::__sinit_enemyMario_cpp": 0x80031224,
		"__sinit_enemyMario_cpp": 0x80031224,
		"TNerveGessoTurn::~TNerveGessoTurn": 0x80031850,
		"TNerveGessoTurn::execute": 0x800318ac,
		"TNerveGessoLand::execute": 0x800319b0,
		"TNerveGessoLand::~TNerveGessoLand": 0x80031a24,
		"TNerveGessoFindMario::execute": 0x80031a80,
		"TNerveGessoFindMario::~TNerveGessoFindMario": 0x80031aec,
		"TNerveGessoRolling::execute": 0x80031b48,
		"TNerveGessoRolling::~TNerveGessoRolling": 0x80031c1c,
		"TNerveGessoFall::execute": 0x80031c78,
		"TNerveGessoFall::~TNerveGessoFall": 0x80032388,
		"TNerveGessoPollute::execute": 0x800323e4,
		"TNerveGessoPollute::~TNerveGessoPollute": 0x80032540,
		"TNerveGessoPunch::execute": 0x8003259c,
		"TNerveGessoPunch::~TNerveGessoPunch": 0x80032608,
		"TNerveGessoFreeze::execute": 0x80032664,
		"TNerveGessoFreeze::~TNerveGessoFreeze": 0x80032ab0,
		"TNerveGessoStay::execute": 0x80032b0c,
		"TNerveGessoStay::~TNerveGessoStay": 0x80032d18,
		"TGessoPolluteObj::sendMessage": 0x80032d74,
		"TGessoPolluteObj::calcRootMatrix": 0x80032e18,
		"TGessoPolluteObj::set": 0x80032e98,
		"TGessoPolluteObj::rebirth": 0x80032fd8,
		"TGessoPolluteObj::pollute": 0x80033120,
		"TGessoPolluteObj::getNowGravity": 0x80033194,
		"TGessoPolluteObj::loadInit": 0x800331b4,
		"TLandGesso::load": 0x800332c0,
		"TSurfGesso::perform": 0x80033308,
		"TSurfGesso::load": 0x8003333c,
		"TGesso::getBasNameTable": 0x80033384,
		"TGesso::initAttacker": 0x80033390,
		"TGesso::rollCheck": 0x800333e0,
		"rollCheck": 0x800333e0,
		"TGesso::behaveToFindMario": 0x800336f8,
		"TGesso::genRandomItem": 0x80033958,
		"TGesso::calcRootMatrix": 0x800339cc,
		"TGesso::kill": 0x80033b34,
		"TGesso::bind": 0x80033b84,
		"TGesso::setWaitAnm": 0x80033e3c,
		"TGesso::setWalkAnm": 0x80033ec0,
		"TGesso::getGravityY": 0x80033ef0,
		"TGesso::setDeadAnm": 0x80033f24,
		"TGesso::setAfterDeadEffect": 0x80033fec,
		"TGesso::pollute": 0x80034030,
		"TGesso::setPolluteGoal": 0x80034214,
		"setPolluteGoal": 0x80034214,
		"TGesso::setBehavior": 0x800343f0,
		"TGesso::attackToMario": 0x800345b4,
		"TGesso::doKeepDistance": 0x80034870,
		"TGesso::isResignationAttack": 0x800348bc,
		"TGesso::walkBehavior": 0x800348f0,
		"TGesso::behaveToWater": 0x80034b3c,
		"TGesso::load": 0x80034f10,
		"TGesso::reset": 0x80034fe8,
		"TGesso::init": 0x80035184,
		"TGesso::TGesso": 0x800352ec,
		"Enemy::GessoBodyCallback": 0x80035400,
		"GessoBodyCallback": 0x80035400,
		"TGessoManager::createModelData": 0x800355b0,
		"TGessoManager::initSetEnemies": 0x800355e4,
		"TGessoManager::perform": 0x800356f0,
		"TGessoManager::clipEnemies": 0x800357b0,
		"TGessoManager::createEnemyInstance": 0x800358d8,
		"TGessoManager::loadAfter": 0x80035920,
		"TGessoManager::load": 0x80035940,
		"TGessoManager::TGessoManager": 0x80035998,
		"TGessoPolluteModel::setAnm": 0x80035a44,
		"TGessoPolluteModelManager::init": 0x80035a94,
		"TGessoSaveLoadParams::TGessoSaveLoadParams": 0x80035b5c,
		"TGesso::setRunAnm": 0x80035ef8,
		"TSmallEnemy::isEatenByYosshi": 0x80035f24,
		"TSmallEnemy::jumpBehavior": 0x80035f2c,
		"jumpBehavior": 0x80035f2c,
		"TSmallEnemy::behaveToTaken": 0x80035f30,
		"TSmallEnemy::behaveToRelease": 0x80035f34,
		"TSmallEnemy::setGenerateAnm": 0x80035f38,
		"TSmallEnemy::setFreezeAnm": 0x80035f3c,
		"TSmallEnemy::setMeltAnm": 0x80035f40,
		"TSmallEnemy::isHitValid": 0x80035f44,
		"TSmallEnemy::isInhibitedForceMove": 0x80035f70,
		"TSmallEnemy::endHitWaterJump": 0x80035f78,
		"TSmallEnemy::setDeadEffect": 0x80035f7c,
		"setDeadEffect": 0x80035f7c,
		"TSurfGesso::isFindMario": 0x80036088,
		"TGessoManager::~TGessoManager": 0x800361c8,
		"TGessoPolluteModel::~TGessoPolluteModel": 0x8003623c,
		"TGessoPolluteModelManager::~TGessoPolluteModelManager": 0x800362c0,
		"Enemy::__sinit_gesso_cpp": 0x80036344,
		"__sinit_gesso_cpp": 0x80036344,
		"TGraphTracer::traceSpline": 0x80036660,
		"traceSpline": 0x80036660,
		"TGraphTracer::calcSplineSpeed": 0x80036824,
		"calcSplineSpeed": 0x80036824,
		"TGraphTracer::moveTo": 0x80036a94,
		"moveTo": 0x80036a94,
		"TGraphTracer::setTo": 0x80036b54,
		"setTo": 0x80036b54,
		"TGraphTracer::TGraphTracer": 0x80036c00,
		"TGraphGroup::perform": 0x80036c30,
		"TGraphGroup::getGraphByName": 0x80036c88,
		"TGraphGroup::initGraphGroup": 0x80036d2c,
		"TGraphGroup::TGraphGroup": 0x80036f10,
		"TGraphWeb::getNeighborNodeIndexByFlag": 0x8003705c,
		"getNeighborNodeIndexByFlag": 0x8003705c,
		"TGraphWeb::getNearestPosOnGraphLink": 0x80037150,
		"getNearestPosOnGraphLink": 0x80037150,
		"TGraphWeb::isDummy": 0x80037418,
		"isDummy": 0x80037418,
		"TGraphWeb::indexToPoint": 0x8003743c,
		"indexToPoint": 0x8003743c,
		"TGraphWeb::startIsEnd": 0x800374c8,
		"startIsEnd": 0x800374c8,
		"TGraphWeb::initGoalIndex": 0x80037540,
		"initGoalIndex": 0x80037540,
		"TGraphWeb::calcGraphDirection": 0x80037604,
		"calcGraphDirection": 0x80037604,
		"TGraphWeb::findNearestVisibleIndex": 0x800376b8,
		"findNearestVisibleIndex": 0x800376b8,
		"TGraphWeb::findNearestNodeIndex": 0x80037870,
		"findNearestNodeIndex": 0x80037870,
		"TGraphWeb::getEscapeDirLimited": 0x8003796c,
		"getEscapeDirLimited": 0x8003796c,
		"TGraphWeb::getRandomButDirLimited": 0x80037de8,
		"getRandomButDirLimited": 0x80037de8,
		"TGraphWeb::getAimToDirNextIndex": 0x80038214,
		"getAimToDirNextIndex": 0x80038214,
		"TGraphWeb::getEscapeFromMarioIndex": 0x80038434,
		"getEscapeFromMarioIndex": 0x80038434,
		"TGraphWeb::getRandomNextIndex": 0x80038684,
		"getRandomNextIndex": 0x80038684,
		"TGraphWeb::getShortestNextIndex": 0x800387dc,
		"getShortestNextIndex": 0x800387dc,
		"TGraphWeb::translateNodes": 0x800389b8,
		"translateNodes": 0x800389b8,
		"TGraphWeb::filterRailNode": 0x80038bac,
		"filterRailNode": 0x80038bac,
		"TGraphWeb::~TGraphWeb": 0x80038cf8,
		"TGraphWeb::TGraphWeb": 0x80038d44,
		"TSplineRail::getPosAndRot": 0x80038ea8,
		"getPosAndRot": 0x80038ea8,
		"TSplinePath::getPoint": 0x800390dc,
		"TSplineRail::TSplineRail": 0x800391bc,
		"TGraphNode::getPoint": 0x80039768,
		"TGraphNode::TGraphNode": 0x800397dc,
		"TNerveDoroHanePrepareAttack::~TNerveDoroHanePrepareAttack": 0x800397fc,
		"TNerveDoroHanePrepareAttack::execute": 0x80039858,
		"TNerveDoroHaneHitWater::execute": 0x800398d8,
		"TNerveDoroHaneHitWater::~TNerveDoroHaneHitWater": 0x80039a50,
		"TNerveDoroHaneRise::execute": 0x80039aac,
		"TNerveDoroHaneRise::~TNerveDoroHaneRise": 0x80039c48,
		"TNerveFireHamuKuriRecover::execute": 0x80039ca4,
		"TFireHamuKuri::setBckAnm": 0x80039d88,
		"TNerveFireHamuKuriRecover::~TNerveFireHamuKuriRecover": 0x80039da8,
		"TNerveDoroHamuKuriRobCap::execute": 0x80039e04,
		"TNerveDoroHamuKuriRobCap::~TNerveDoroHamuKuriRobCap": 0x80039fa8,
		"TNerveHaneHamuKuriMoveOnGraph::execute": 0x8003a004,
		"TNerveHaneHamuKuriMoveOnGraph::~TNerveHaneHamuKuriMoveOnGraph": 0x8003a304,
		"TNerveHaneHamuKuriUpWait::execute": 0x8003a360,
		"TNerveHaneHamuKuriUpWait::~TNerveHaneHamuKuriUpWait": 0x8003a4e8,
		"TNerveDangoHamuKuriWait::execute": 0x8003a544,
		"TNerveDangoHamuKuriWait::~TNerveDangoHamuKuriWait": 0x8003a5f8,
		"TNerveHamuKuriJitabata::execute": 0x8003a654,
		"TNerveHamuKuriJitabata::~TNerveHamuKuriJitabata": 0x8003a784,
		"TNerveHamuKuriLand::execute": 0x8003a7e0,
		"TNerveHamuKuriLand::~TNerveHamuKuriLand": 0x8003a860,
		"TNerveHamuKuriWallDie::execute": 0x8003a8bc,
		"TNerveHamuKuriWallDie::~TNerveHamuKuriWallDie": 0x8003ab5c,
		"TNerveHamuKuriBoundFreeze::execute": 0x8003abb8,
		"TNerveHamuKuriBoundFreeze::~TNerveHamuKuriBoundFreeze": 0x8003aecc,
		"TNerveHamuKuriGoForSearchActor::execute": 0x8003af28,
		"TNerveHamuKuriGoForSearchActor::~TNerveHamuKuriGoForSearchActor": 0x8003b114,
		"TDoroHamuKuri::isCollidMove": 0x8003b170,
		"TDoroHamuKuri::onHaveCap": 0x8003b52c,
		"TDoroHamuKuri::setBehavior": 0x8003b54c,
		"TDoroHamuKuri::attackToMario": 0x8003b7bc,
		"TDoroHamuKuri::setMActorAndKeeper": 0x8003b8a0,
		"TDoroHamuKuri::kill": 0x8003b90c,
		"TDoroHamuKuri::reset": 0x8003b92c,
		"TDoroHamuKuri::init": 0x8003b9a4,
		"TDoroHamuKuri::TDoroHamuKuri": 0x8003bb74,
		"TFireHamuKuri::changeTevColor": 0x8003bc54,
		"changeTevColor": 0x8003bc54,
		"TFireHamuKuri::sendAttackMsgToMario": 0x8003be20,
		"TFireHamuKuri::setWalkAnm": 0x8003be5c,
		"TFireHamuKuri::isHitValid": 0x8003be8c,
		"TFireHamuKuri::walkBehavior": 0x8003bf2c,
		"TFireHamuKuri::calcRootMatrix": 0x8003c0a8,
		"TFireHamuKuri::moveObject": 0x8003c27c,
		"TFireHamuKuri::setMActorAndKeeper": 0x8003c2b0,
		"TFireHamuKuri::reset": 0x8003c350,
		"TFireHamuKuri::behaveToWater": 0x8003c408,
		"THamuKuri::canDoJitabata": 0x8003c7e8,
		"TFireHamuKuri::init": 0x8003c80c,
		"TFireHamuKuri::TFireHamuKuri": 0x8003c8e8,
		"TBossDangoHamuKuri::generateBody": 0x8003c93c,
		"generateBody": 0x8003c93c,
		"TBossDangoHamuKuri::genEventCoin": 0x8003cac8,
		"TBossDangoHamuKuri::moveObject": 0x8003cba4,
		"TBossDangoHamuKuri::setGenerateAnm": 0x8003cbfc,
		"TBossDangoHamuKuri::reset": 0x8003cc6c,
		"TBossDangoHamuKuri::perform": 0x8003cd40,
		"TBossDangoHamuKuri::init": 0x8003cd60,
		"TBossDangoHamuKuri::TBossDangoHamuKuri": 0x8003ce9c,
		"TDangoHamuKuri::swingBody": 0x8003cfc8,
		"swingBody": 0x8003cfc8,
		"TDangoHamuKuri::behaveToWater": 0x8003d19c,
		"TDangoHamuKuri::forceKill": 0x8003d63c,
		"TDangoHamuKuri::isHitValid": 0x8003d79c,
		"TDangoHamuKuri::receiveMessage": 0x8003d7c4,
		"TDangoHamuKuri::reset": 0x8003d9c4,
		"TDangoHamuKuri::calcRootMatrix": 0x8003da88,
		"TDangoHamuKuri::setRunAnm": 0x8003dc64,
		"TDangoHamuKuri::getTakingMtx": 0x8003dcb8,
		"TDangoHamuKuri::attackToMario": 0x8003dd80,
		"TDangoHamuKuri::isCollidMove": 0x8003dee0,
		"TDangoHamuKuri::updateAnmSound": 0x8003df00,
		"TDangoHamuKuri::moveObject": 0x8003df44,
		"TDangoHamuKuri::changeByJuice": 0x8003df9c,
		"TDangoHamuKuri::perform": 0x8003dfd0,
		"TDangoHamuKuri::init": 0x8003e05c,
		"TDangoHamuKuri::TDangoHamuKuri": 0x8003e15c,
		"THaneHamuKuri2::isReachedToGoal": 0x8003e1d4,
		"THaneHamuKuri2::walkBehavior": 0x8003e27c,
		"THaneHamuKuri2::sendAttackMsgToMario": 0x8003e3e8,
		"THaneHamuKuri2::reset": 0x8003e408,
		"THaneHamuKuri2::THaneHamuKuri2": 0x8003e4f4,
		"TDoroHaneKuri::isCollidMove": 0x8003e604,
		"TDoroHaneKuri::setBehavior": 0x8003e6cc,
		"TDoroHaneKuri::behaveToWater": 0x8003e794,
		"TDoroHaneKuri::setMActorAndKeeper": 0x8003e8b4,
		"TDoroHaneKuri::attackToMario": 0x8003e920,
		"TDoroHaneKuri::onHaveCap": 0x8003eadc,
		"TDoroHaneKuri::reset": 0x8003eaf8,
		"TDoroHaneKuri::init": 0x8003eb88,
		"TDoroHaneKuri::TDoroHaneKuri": 0x8003ed58,
		"THaneHamuKuri::getBasNameTable": 0x8003edd4,
		"THaneHamuKuri::isHitValid": 0x8003ede0,
		"THaneHamuKuri::isCollidMove": 0x8003ee0c,
		"THaneHamuKuri::setDeadAnm": 0x8003ee2c,
		"THaneHamuKuri::setBckAnm": 0x8003ef04,
		"THaneHamuKuri::setCrashAnm": 0x8003ef24,
		"THaneHamuKuri::behaveToWater": 0x8003ef54,
		"THaneHamuKuri::setRollAnm": 0x8003ef98,
		"THaneHamuKuri::setRunAnm": 0x8003efc8,
		"THaneHamuKuri::setWalkAnm": 0x8003eff8,
		"THaneHamuKuri::setWaitAnm": 0x8003f028,
		"THaneHamuKuri::setMActorAndKeeper": 0x8003f058,
		"THaneHamuKuri::attackToMario": 0x8003f0c4,
		"THaneHamuKuri::isReachedToGoal": 0x8003f134,
		"THaneHamuKuri::bind": 0x8003f1dc,
		"THaneHamuKuri::walkBehavior": 0x8003f3bc,
		"THaneHamuKuri::reset": 0x8003fc5c,
		"THaneHamuKuri::moveObject": 0x8003fcd0,
		"THaneHamuKuri::init": 0x8003fcf0,
		"THaneHamuKuri::THaneHamuKuri": 0x8003fdd4,
		"THamuKuri::forceRoll": 0x8003fe34,
		"forceRoll": 0x8003fe34,
		"THamuKuri::isCollidMove": 0x80040038,
		"THamuKuri::isHitValid": 0x800404f0,
		"THamuKuri::isResignationAttack": 0x8004062c,
		"THamuKuri::getTakingMtx": 0x80040718,
		"THamuKuri::getBasNameTable": 0x80040818,
		"THamuKuri::initAttacker": 0x80040824,
		"THamuKuri::walkBehavior": 0x800408a8,
		"THamuKuri::setCrashAnm": 0x800408e8,
		"THamuKuri::setRollAnm": 0x800409ec,
		"THamuKuri::setRunAnm": 0x80040a1c,
		"THamuKuri::setWaitAnm": 0x80040a4c,
		"THamuKuri::setDeadAnm": 0x80040a7c,
		"THamuKuri::setWalkAnm": 0x80040bcc,
		"THamuKuri::setGenerateAnm": 0x80040bfc,
		"THamuKuri::setBckAnm": 0x80040c2c,
		"THamuKuri::endHitWaterJump": 0x80040c4c,
		"THamuKuri::setAfterDeadEffect": 0x80040c98,
		"THamuKuri::genRandomItem": 0x80040e80,
		"THamuKuri::getGravityY": 0x80040ea0,
		"THamuKuri::makeCapFly": 0x80040f10,
		"makeCapFly": 0x80040f10,
		"THamuKuri::onHaveCap": 0x80041274,
		"THamuKuri::selectCapHolder": 0x80041280,
		"selectCapHolder": 0x80041280,
		"THamuKuri::setBehavior": 0x80041330,
		"THamuKuri::moveObject": 0x800414a4,
		"THamuKuri::attackToMario": 0x80041664,
		"THamuKuri::behaveToFindMario": 0x80041748,
		"THamuKuri::jumpToSearchActor": 0x800417a4,
		"jumpToSearchActor": 0x800417a4,
		"THamuKuri::isFindMario": 0x80041958,
		"THamuKuri::behaveToWater": 0x800419e0,
		"THamuKuri::bind": 0x80041c1c,
		"THamuKuri::reset": 0x80041e7c,
		"THamuKuri::setMActorAndKeeper": 0x80041ed0,
		"THamuKuri::init": 0x80041fb4,
		"THamuKuri::THamuKuri": 0x80042044,
		"TDoroHamuKuriManager::perform": 0x800420c4,
		"TDoroHamuKuriManager::createModelData": 0x80042170,
		"TDoroHamuKuriManager::createEnemyInstance": 0x800421a4,
		"TDoroHamuKuriManager::loadAfter": 0x80042200,
		"TDoroHamuKuriManager::load": 0x80042358,
		"TDoroHamuKuriManager::TDoroHamuKuriManager": 0x800423c4,
		"THamuKuriManager::~THamuKuriManager": 0x80042428,
		"TDoroHige::perform": 0x8004249c,
		"TFireHamuKuriManager::createModelData": 0x800424f0,
		"TFireHamuKuriManager::initSetEnemies": 0x80042524,
		"TFireHamuKuriManager::createEnemyInstance": 0x800426b8,
		"TFireHamuKuriManager::load": 0x80042724,
		"TFireHamuKuriManager::TFireHamuKuriManager": 0x800427d4,
		"TBossDangoHamuKuriManager::createEnemyInstance": 0x80042834,
		"TBossDangoHamuKuriManager::load": 0x80042898,
		"TBossDangoHamuKuriManager::TBossDangoHamuKuriManager": 0x80042948,
		"TDangoHamuKuriManager::~TDangoHamuKuriManager": 0x800429b8,
		"TDoroHaneKuriManager::perform": 0x80042a3c,
		"TDangoHamuKuriManager::createModelDataArray": 0x80042ae8,
		"TDangoHamuKuriManager::createEnemyInstance": 0x80042b58,
		"TDangoHamuKuriManager::load": 0x80042ba0,
		"TDangoHamuKuriManager::TDangoHamuKuriManager": 0x80042c0c,
		"TDoroHaneKuriManager::createModelData": 0x80042c6c,
		"TDoroHaneKuriManager::createEnemyInstance": 0x80042ca0,
		"TDoroHaneKuriManager::loadAfter": 0x80042d04,
		"TDoroHaneKuriManager::load": 0x80042e5c,
		"TDoroHaneKuriManager::TDoroHaneKuriManager": 0x80042fbc,
		"THaneHamuKuriManager::~THaneHamuKuriManager": 0x8004302c,
		"THaneHamuKuriManager::createAnmData": 0x800430b0,
		"THaneHamuKuriManager::createModelData": 0x800430d0,
		"THaneHamuKuriManager::createEnemyInstance": 0x80043104,
		"THaneHamuKuriManager::load": 0x8004314c,
		"THaneHamuKuriManager::THaneHamuKuriManager": 0x800432ac,
		"THamuKuriManager::createEnemyInstance": 0x8004330c,
		"THamuKuriManager::checkSerialKill": 0x80043354,
		"checkSerialKill": 0x80043354,
		"THamuKuriManager::requestSerialKill": 0x800434c4,
		"requestSerialKill": 0x800434c4,
		"THamuKuriManager::setSearchHamuKuri": 0x800435b4,
		"setSearchHamuKuri": 0x800435b4,
		"THamuKuriManager::perform": 0x80043878,
		"THamuKuriManager::createAnmData": 0x80043900,
		"THamuKuriManager::createModelData": 0x80043960,
		"THamuKuriManager::loadAfter": 0x80043994,
		"THamuKuriManager::load": 0x80043aa8,
		"THamuKuriManager::THamuKuriManager": 0x80043b14,
		"THamuKuriSaveLoadParams::THamuKuriSaveLoadParams": 0x80043b68,
		"THamuKuriLauncher::stateLaunch": 0x80043e2c,
		"THamuKuriLauncher::drawObject": 0x80043ffc,
		"TBossDangoHamuKuri::changeByJuice": 0x8004415c,
		"TBossDangoHamuKuri::isFindMario": 0x80044164,
		"THaneHamuKuri2::forceKill": 0x80044208,
		"THaneHamuKuri2::isHitValid": 0x8004420c,
		"THaneHamuKuri2::behaveToWater": 0x80044214,
		"THaneHamuKuri::setBehavior": 0x80044218,
		"THaneHamuKuri::setGenerateAnm": 0x8004421c,
		"THaneHamuKuri::canDoJitabata": 0x80044220,
		"TDoroHamuKuriManager::~TDoroHamuKuriManager": 0x80044360,
		"TSmallEnemyManager::initSetEnemies": 0x800443e4,
		"TDoroHige::~TDoroHige": 0x800443e8,
		"TFireHamuKuriManager::~TFireHamuKuriManager": 0x8004446c,
		"TBossDangoHamuKuriManager::~TBossDangoHamuKuriManager": 0x800444f0,
		"TBossDangoHamuKuriManager::clipEnemies": 0x80044584,
		"TDangoHamuKuriManager::clipEnemies": 0x80044588,
		"TDoroHaneKuriManager::~TDoroHaneKuriManager": 0x8004458c,
		"Enemy::__sinit_hamukuri_cpp": 0x800446a4,
		"__sinit_hamukuri_cpp": 0x800446a4,
		"Enemy::__sinit_hinokuri2_cpp": 0x80044a88,
		"__sinit_hinokuri2_cpp": 0x80044a88,
		"TNerveMameGessoWait::~TNerveMameGessoWait": 0x80044d84,
		"TNerveMameGessoWait::execute": 0x80044de0,
		"TNerveMameGessoGraphJumpWander::~TNerveMameGessoGraphJumpWander": 0x80044f34,
		"TNerveMameGessoObject::execute": 0x80044f90,
		"TNerveMameGessoObject::~TNerveMameGessoObject": 0x800452bc,
		"TNerveMameGessoThrown::execute": 0x80045318,
		"TNerveMameGessoThrown::~TNerveMameGessoThrown": 0x80045560,
		"TNerveMameGessoPickUp::execute": 0x800455bc,
		"TNerveMameGessoPickUp::~TNerveMameGessoPickUp": 0x80045670,
		"TNerveMameGessoTrample::execute": 0x800456cc,
		"TNerveMameGessoTrample::~TNerveMameGessoTrample": 0x800457c0,
		"TNerveMameGessoJitabata::execute": 0x8004581c,
		"TNerveMameGessoJitabata::~TNerveMameGessoJitabata": 0x80045a18,
		"TNerveMameGessoDamage::execute": 0x80045a74,
		"TNerveMameGessoDamage::~TNerveMameGessoDamage": 0x80045db0,
		"TNerveMameGessoGraphJumpWander::execute": 0x80045e0c,
		"TMameGesso::getBasNameTable": 0x80046458,
		"TMameGesso::doKeepDistance": 0x80046464,
		"TMameGesso::isInhibitedForceMove": 0x80046494,
		"TMameGesso::calcObjCollision": 0x8004649c,
		"calcObjCollision": 0x8004649c,
		"TMameGesso::isCollidMove": 0x8004660c,
		"TMameGesso::behaveToRelease": 0x800466b8,
		"TMameGesso::behaveToTaken": 0x800467dc,
		"TMameGesso::behaveToWater": 0x800468f4,
		"TMameGesso::setDeadAnm": 0x80046a6c,
		"TMameGesso::setFreezeAnm": 0x80046a78,
		"TMameGesso::setWaitAnm": 0x80046ab0,
		"TMameGesso::getGravityY": 0x80046b58,
		"TMameGesso::kill": 0x80046c50,
		"TMameGesso::isHitValid": 0x80047004,
		"TMameGesso::reset": 0x80047120,
		"TMameGesso::calcRootMatrix": 0x80047210,
		"TMameGesso::attackToMario": 0x8004732c,
		"TMameGesso::setMActorAndKeeper": 0x800473c4,
		"TMameGesso::moveObject": 0x80047430,
		"TMameGesso::init": 0x800474c4,
		"TMameGesso::load": 0x800475e0,
		"TMameGesso::TMameGesso": 0x80047628,
		"TMameGessoManager::perform": 0x800476c0,
		"TMameGessoManager::initSetEnemies": 0x8004777c,
		"TMameGessoManager::createEnemyInstance": 0x80047780,
		"TMameGessoManager::loadAfter": 0x800477c8,
		"TMameGessoManager::load": 0x800477e8,
		"TMameGessoManager::TMameGessoManager": 0x80047840,
		"TMameGessoSaveLoadParams::TMameGessoSaveLoadParams": 0x8004787c,
		"TMameGesso::changeByJuice": 0x80047b50,
		"TMameGesso::isEatenByYosshi": 0x80047b58,
		"TMameGesso::forceKill": 0x80047b60,
		"TSmallEnemy::setBehavior": 0x80047b64,
		"TSmallEnemy::setWalkAnm": 0x80047b68,
		"TSmallEnemy::setRunAnm": 0x80047b6c,
		"TMameGessoManager::~TMameGessoManager": 0x80047c0c,
		"Enemy::__sinit_mameGesso_cpp": 0x80047c80,
		"__sinit_mameGesso_cpp": 0x80047c80,
		"TNerveNKFollowMario::~TNerveNKFollowMario": 0x80047ef4,
		"TNerveNKFollowMario::execute": 0x80047f50,
		"TNerveNameKuriJumpAttackPrepare::~TNerveNameKuriJumpAttackPrepare": 0x800480dc,
		"TNerveNKFollowMario::theNerve": 0x80048138,
		"TNerveNameKuriDrawPollute::execute": 0x8004819c,
		"TNerveNameKuriDrawPollute::theNerve": 0x800481a4,
		"TNerveNameKuriDrawPollute::~TNerveNameKuriDrawPollute": 0x80048208,
		"TNerveNameKuriDiffuse::execute": 0x80048264,
		"TNerveNameKuriDiffuse::theNerve": 0x80048298,
		"TNerveNameKuriDiffuse::~TNerveNameKuriDiffuse": 0x800482fc,
		"TNerveNameKuriExplosion::execute": 0x80048358,
		"TNerveNameKuriExplosion::theNerve": 0x800483cc,
		"TNerveNameKuriExplosion::~TNerveNameKuriExplosion": 0x80048430,
		"TNerveNameKuriJumpAttackPrepare::execute": 0x8004848c,
		"TNerveNameKuriJumpAttack::~TNerveNameKuriJumpAttack": 0x80048678,
		"TNerveNameKuriJumpAttackPrepare::theNerve": 0x800486d4,
		"TNerveNameKuriJumpAttack::execute": 0x80048738,
		"TNerveNameKuriJumpAttack::theNerve": 0x80048c20,
		"TNerveNameKuriLand::execute": 0x80048c84,
		"TNerveNameKuriLand::theNerve": 0x80048d14,
		"TNerveNameKuriLand::~TNerveNameKuriLand": 0x80048d78,
		"TDiffusionNameKuriManager::createEnemyInstance": 0x80048dd4,
		"TDiffusionNameKuriManager::load": 0x80048ecc,
		"TNameKuri::getBasNameTable": 0x80049170,
		"TNameKuri::isCollidMove": 0x8004917c,
		"TNameKuri::isHitValid": 0x80049278,
		"TNameKuri::endHitWaterJump": 0x800492bc,
		"TNameKuri::behaveToFindMario": 0x800492d0,
		"TNameKuri::attackToMario": 0x800493ac,
		"TNameKuri::reset": 0x8004947c,
		"TNameKuri::setMActorAndKeeper": 0x800495b4,
		"TNameKuri::setMeltAnm": 0x80049620,
		"TNameKuri::setWaitAnm": 0x80049778,
		"TNameKuri::setAfterDeadEffect": 0x800497a8,
		"TNameKuri::setDeadAnm": 0x80049824,
		"TNameKuri::setWalkAnm": 0x8004997c,
		"TNameKuri::setGenerateAnm": 0x800499ac,
		"TNameKuri::setBckAnm": 0x80049a10,
		"TNameKuri::getGravityY": 0x80049a30,
		"TNameKuri::behaveToWater": 0x80049ad4,
		"TNameKuri::setBehavior": 0x80049c14,
		"TNameKuri::moveObject": 0x80049c18,
		"TNameKuri::perform": 0x80049e44,
		"TNameKuri::calcRootMatrix": 0x80049f64,
		"TNameKuri::init": 0x8004a304,
		"TNameKuri::TNameKuri": 0x8004a4b8,
		"Enemy::NameKuriScaleCallback": 0x8004a52c,
		"NameKuriScaleCallback": 0x8004a52c,
		"Enemy::NameKuriAttackCallback": 0x8004a61c,
		"NameKuriAttackCallback": 0x8004a61c,
		"TNameIndParCallback::draw": 0x8004a7b0,
		"TNameIndParCallback::execute": 0x8004a7b4,
		"TNameKuriManager::perform": 0x8004ab6c,
		"TNameKuriManager::createModelData": 0x8004ab8c,
		"TNameKuriManager::createEnemyInstance": 0x8004abc0,
		"TNameKuriManager::initSetEnemies": 0x8004ac4c,
		"TNameKuriManager::loadAfter": 0x8004adc0,
		"TNameKuriManager::load": 0x8004ae24,
		"TNameKuriManager::TNameKuriManager": 0x8004b0c8,
		"TNameKuriLauncher::stateLaunch": 0x8004b114,
		"TDiffusionNameKuriManager::~TDiffusionNameKuriManager": 0x8004b2a4,
		"Enemy::__sinit_namekuri_cpp": 0x8004b428,
		"__sinit_namekuri_cpp": 0x8004b428,
		"TNerveStayPakkunAppear::~TNerveStayPakkunAppear": 0x8004b73c,
		"TNerveStayPakkunAppear::execute": 0x8004b798,
		"TNervePakkunStay::~TNervePakkunStay": 0x8004b94c,
		"TNerveStayPakkunHide::execute": 0x8004b9a8,
		"TNerveStayPakkunHide::~TNerveStayPakkunHide": 0x8004bc58,
		"TNervePakkunFreeze::execute": 0x8004bcb4,
		"TNervePakkunFreeze::~TNervePakkunFreeze": 0x8004bdec,
		"TNervePakkunShoot::execute": 0x8004be48,
		"TNervePakkunShoot::~TNervePakkunShoot": 0x8004bfa8,
		"TNervePakkunHide::execute": 0x8004c004,
		"TNervePakkunAppear::~TNervePakkunAppear": 0x8004c16c,
		"TNervePakkunHide::~TNervePakkunHide": 0x8004c1c8,
		"TNervePakkunAppear::execute": 0x8004c224,
		"TNervePakkunStay::execute": 0x8004c338,
		"TNervePakkunGenerate::execute": 0x8004cdec,
		"TNervePakkunGenerate::~TNervePakkunGenerate": 0x8004cfe8,
		"TStayPakkun::getSaveParam": 0x8004d044,
		"TStayPakkun::shoot": 0x8004d050,
		"TStayPakkun::kill": 0x8004d080,
		"TStayPakkun::shootIn": 0x8004d100,
		"TStayPakkun::isHitValid": 0x8004d220,
		"TStayPakkun::setBehavior": 0x8004d430,
		"TStayPakkun::calcRootMatrix": 0x8004d56c,
		"TStayPakkun::genRandomItem": 0x8004d590,
		"TStayPakkun::setDeadAnm": 0x8004d6ec,
		"TStayPakkun::reset": 0x8004d71c,
		"TStayPakkun::init": 0x8004d784,
		"TStayPakkun::load": 0x8004d8b8,
		"TPakkunSeed::forceKill": 0x8004d99c,
		"TPakkunSeed::set": 0x8004da84,
		"TPakkunSeed::rebirth": 0x8004db2c,
		"TPakkunSeed::shoot": 0x8004dd50,
		"TPakkunSeed::appear": 0x8004ddac,
		"TPakkunSeed::getNowGravity": 0x8004ddd4,
		"TPakkunSeed::behaveToHitGround": 0x8004de24,
		"TPakkunSeed::calcRootMatrix": 0x8004df40,
		"TPakkunSeed::behaveToHitWall": 0x8004dfa8,
		"TPakkunSeed::behaveToHost": 0x8004e02c,
		"TPakkunSeed::moveObject": 0x8004e050,
		"TPakkunSeed::loadInit": 0x8004e154,
		"TPakkun::getBasNameTable": 0x8004e2d4,
		"TPakkun::shoot": 0x8004e2e0,
		"TPakkun::shootIn": 0x8004e310,
		"TPakkun::reset": 0x8004e360,
		"TPakkun::setMActorAndKeeper": 0x8004e3a8,
		"TPakkun::behaveToWater": 0x8004e414,
		"TPakkun::onShootLiner": 0x8004e650,
		"onShootLiner": 0x8004e650,
		"TPakkun::perform": 0x8004e7ac,
		"TPakkun::setDeadAnm": 0x8004e914,
		"TPakkun::setFreezeAnm": 0x8004e950,
		"TPakkun::setWaitAnm": 0x8004e980,
		"TPakkun::kill": 0x8004e9b0,
		"TPakkun::isInhibitedForceMove": 0x8004e9f0,
		"TPakkun::init": 0x8004e9f8,
		"TPakkun::load": 0x8004eca0,
		"TPakkun::TPakkun": 0x8004ed60,
		"TPakkunManager::clipEnemies": 0x8004edc4,
		"TPakkunManager::createEnemyInstance": 0x8004efb0,
		"TPakkunManager::createModelData": 0x8004eff8,
		"TPakkunManager::loadAfter": 0x8004f02c,
		"TPakkunManager::load": 0x8004f04c,
		"TPakkunManager::TPakkunManager": 0x8004f580,
		"Enemy::PakkunRootCallback2": 0x8004f5d4,
		"PakkunRootCallback2": 0x8004f5d4,
		"Enemy::PakkunRootCallback": 0x8004f688,
		"PakkunRootCallback": 0x8004f688,
		"Enemy::PakkunSeedCallback": 0x8004f7ec,
		"PakkunSeedCallback": 0x8004f7ec,
		"TStayPakkun::setAfterDeadEffect": 0x8004f8fc,
		"TPakkun::isCollidMove": 0x8004f900,
		"TPakkun::decHpByWater": 0x8004f908,
		"TSmallEnemy::initAttacker": 0x8004f90c,
		"TPakkunManager::~TPakkunManager": 0x8004fabc,
		"Enemy::__sinit_pakkun_cpp": 0x8004fb30,
		"__sinit_pakkun_cpp": 0x8004fb30,
		"TNerveSmallEnemyChange::~TNerveSmallEnemyChange": 0x8004fe44,
		"TNerveSmallEnemyChange::execute": 0x8004fea0,
		"TNerveSmallEnemyChange::theNerve": 0x8004ff94,
		"TNerveSmallEnemyWait::execute": 0x8004fff8,
		"TSmallEnemy::setWaitAnm": 0x80050090,
		"TNerveSmallEnemyWait::theNerve": 0x80050094,
		"TNerveSmallEnemyWait::~TNerveSmallEnemyWait": 0x800500f8,
		"TNerveSmallEnemyHitWaterJump::execute": 0x80050154,
		"TNerveSmallEnemyHitWaterJump::theNerve": 0x8005035c,
		"TNerveSmallEnemyHitWaterJump::~TNerveSmallEnemyHitWaterJump": 0x800503c0,
		"TNerveSmallEnemyJump::execute": 0x8005041c,
		"TNerveSmallEnemyJump::theNerve": 0x8005052c,
		"TNerveSmallEnemyJump::~TNerveSmallEnemyJump": 0x80050590,
		"TNerveSmallEnemyFreeze::execute": 0x800505ec,
		"TNerveSmallEnemyFreeze::theNerve": 0x8005068c,
		"TNerveSmallEnemyFreeze::~TNerveSmallEnemyFreeze": 0x800506f0,
		"TNerveSmallEnemyDie::execute": 0x8005074c,
		"TNerveSmallEnemyDie::~TNerveSmallEnemyDie": 0x80050a94,
		"TSmallEnemy::setDeadAnm": 0x80050af0,
		"TNerveSmallEnemyDie::theNerve": 0x80050af4,
		"TSmallEnemy::perform": 0x80050b58,
		"TSmallEnemy::behaveToHitOthers": 0x80050bd4,
		"behaveToHitOthers": 0x80050bd4,
		"TSmallEnemy::isHitWallInBound": 0x80050d1c,
		"isHitWallInBound": 0x80050d1c,
		"TSmallEnemy::isEaten": 0x80050e54,
		"isEaten": 0x80050e54,
		"TSmallEnemy::expandCollision": 0x80050ef0,
		"expandCollision": 0x80050ef0,
		"TSmallEnemy::setBckAnm": 0x8005102c,
		"TSmallEnemy::generateEffectColumWater": 0x800510a0,
		"TSmallEnemy::isFindMarioFromParam": 0x80051130,
		"isFindMarioFromParam": 0x80051130,
		"TSmallEnemy::isMarioInWater": 0x800511ec,
		"isMarioInWater": 0x800511ec,
		"TSmallEnemy::isFindMario": 0x800512bc,
		"TSmallEnemy::kill": 0x80051428,
		"TSmallEnemy::decHpByWater": 0x800515b8,
		"TSmallEnemy::changeOut": 0x80051604,
		"TSmallEnemy::scalingChangeActor": 0x800516e0,
		"TSmallEnemy::changeMove": 0x80051774,
		"changeMove": 0x80051774,
		"TSmallEnemy::getChangeBlockTime": 0x80051bd0,
		"TSmallEnemy::changeByJuice": 0x80051bd8,
		"TSmallEnemy::receiveMessage": 0x80051e40,
		"TSmallEnemy::updateAnmSound": 0x80052070,
		"TSmallEnemy::moveObject": 0x80052090,
		"TSmallEnemy::isCollidMove": 0x800524f0,
		"TSmallEnemy::generateItem": 0x8005255c,
		"TSmallEnemy::setAfterDeadEffect": 0x80052664,
		"TSmallEnemy::genEventCoin": 0x8005275c,
		"TSmallEnemy::genRandomItem": 0x80052a60,
		"TSmallEnemy::forceKill": 0x80052af0,
		"TSmallEnemy::reset": 0x80052d14,
		"TSmallEnemy::attackToMario": 0x80053148,
		"TSmallEnemy::sendAttackMsgToMario": 0x80053258,
		"TSmallEnemy::behaveToWater": 0x8005327c,
		"TSmallEnemy::loadAfter": 0x800533f4,
		"TSmallEnemy::load": 0x80053428,
		"TSmallEnemy::init": 0x80053498,
		"TSmallEnemy::setMActorAndKeeper": 0x80053824,
		"TSmallEnemy::TSmallEnemy": 0x8005388c,
		"TSmallEnemyManager::getHolder": 0x80053918,
		"getHolder": 0x80053918,
		"TSmallEnemyManager::createEnemies": 0x8005398c,
		"TSmallEnemyManager::loadAfter": 0x800539cc,
		"TSmallEnemyManager::load": 0x80053a24,
		"TSmallEnemyManager::createModelData": 0x80053a44,
		"TSmallEnemyManager::TSmallEnemyManager": 0x80053a78,
		"TSmallEnemyParams::TSmallEnemyParams": 0x80053ac4,
		"Enemy::__sinit_smallEnemy_cpp": 0x80054008,
		"__sinit_smallEnemy_cpp": 0x80054008,
		"TSpider::bind": 0x8005430c,
		"TSpider::~TSpider": 0x80054880,
		"TSpider::TSpider": 0x800548e4,
		"TSplinePath::calcSpline": 0x80054938,
		"calcSpline": 0x80054938,
		"TSplinePath::calcTable": 0x80054a1c,
		"calcTable": 0x80054a1c,
		"TSplinePath::makeTable": 0x80054b7c,
		"makeTable": 0x80054b7c,
		"TSplinePath::TSplinePath": 0x80054ee0,
		"TNerveTypicalGraphWander::~TNerveTypicalGraphWander": 0x80054ff8,
		"TNerveTypicalGraphWander::execute": 0x80055054,
		"TNerveTypicalGraphWander::theNerve": 0x80055158,
		"TTypicalManager::createEnemyInstance": 0x800551bc,
		"TTypicalManager::load": 0x80055244,
		"TTypicalManager::TTypicalManager": 0x80055304,
		"TTypicalEnemy::init": 0x80055340,
		"TTypicalEnemy::TTypicalEnemy": 0x800553f8,
		"TTypicalManager::~TTypicalManager": 0x80055460,
		"TWalker::setMode": 0x80055538,
		"setMode": 0x80055538,
		"TWalker::bind": 0x800555a4,
		"TWalker::reset": 0x80056208,
		"TWalker::~TWalker": 0x80056228,
		"TWalker::TWalker": 0x800562a0,
		"TSolidStack<TBGCheckData_const*>::~TSolidStack": 0x8005635c,
		"Enemy::calcFarthestVertex": 0x800563a8,
		"calcFarthestVertex": 0x800563a8,
		"TNerveWalkerTraceMario::~TNerveWalkerTraceMario": 0x80056570,
		"TNerveWalkerTraceMario::execute": 0x800565cc,
		"TNerveWalkerTraceMario::theNerve": 0x80056888,
		"TNerveWalkerEscape::execute": 0x800568ec,
		"TNerveWalkerEscape::theNerve": 0x80056a4c,
		"TNerveWalkerEscape::~TNerveWalkerEscape": 0x80056ab0,
		"TNerveWalkerPostAttack::execute": 0x80056b0c,
		"TNerveWalkerPostAttack::theNerve": 0x80056ba4,
		"TNerveWalkerPostAttack::~TNerveWalkerPostAttack": 0x80056c08,
		"TNerveWalkerAttack::execute": 0x80056c64,
		"TNerveWalkerAttack::theNerve": 0x80056de0,
		"TNerveWalkerAttack::~TNerveWalkerAttack": 0x80056e44,
		"TNerveWalkerGraphWander::execute": 0x80056ea0,
		"TNerveWalkerGraphWander::theNerve": 0x80056f7c,
		"TNerveWalkerGraphWander::~TNerveWalkerGraphWander": 0x80056fe0,
		"TNerveWalkerGenerate::execute": 0x8005703c,
		"TNerveWalkerGenerate::theNerve": 0x8005711c,
		"TNerveWalkerGenerate::~TNerveWalkerGenerate": 0x80057180,
		"TWalkerEnemy::initialGraphNode": 0x800571dc,
		"initialGraphNode": 0x800571dc,
		"TWalkerEnemy::isReachedToGoalXZ": 0x80057208,
		"TWalkerEnemy::isResignationAttack": 0x800572d0,
		"TWalkerEnemy::initAttacker": 0x800573ac,
		"TWalkerEnemy::behaveToFindMario": 0x800573d0,
		"TWalkerEnemy::walkBehavior": 0x800576e8,
		"TWalkerEnemy::reset": 0x800577fc,
		"TWalkerEnemy::attackToMario": 0x80057960,
		"TWalkerEnemy::moveObject": 0x80057b14,
		"TWalkerEnemy::init": 0x80057ce4,
		"TWalkerEnemy::TWalkerEnemy": 0x80057e10,
		"TWalkerEnemyParams::TWalkerEnemyParams": 0x80057e54,
		"Enemy::__sinit_walkerEnemy_cpp": 0x80057f98,
		"__sinit_walkerEnemy_cpp": 0x80057f98,
		"TNerveBGRoll::~TNerveBGRoll": 0x8005829c,
		"TNerveBGRoll::execute": 0x800582f8,
		"MActorAnmEach<J3DAnmTransformKey>::setFrameCtrl": 0x80058a14,
		"setFrameCtrl": 0x80058a14,
		"MActorAnmDataEach<J3DAnmTransformKey>::getAnmPtr": 0x80058aa0,
		"getAnmPtr": 0x80058aa0,
		"TMActorKeeper::getMActorAnmData": 0x80058ac4,
		"TNerveBGRoll::theNerve": 0x80058acc,
		"TNerveBGPolDrop::execute": 0x80058b30,
		"TNerveBGPolDrop::~TNerveBGPolDrop": 0x80058e6c,
		"TNerveBGPolDrop::theNerve": 0x80058ec8,
		"TNerveBGPollute::execute": 0x80058f2c,
		"TNerveBGPollute::theNerve": 0x8005919c,
		"TNerveBGPollute::~TNerveBGPollute": 0x80059200,
		"TNerveBGDie::execute": 0x8005925c,
		"TNerveBGDie::theNerve": 0x80059970,
		"TNerveBGDie::~TNerveBGDie": 0x800599d4,
		"TNerveBGTug::execute": 0x80059a30,
		"TNerveBGTug::theNerve": 0x80059ecc,
		"TNerveBGTug::~TNerveBGTug": 0x80059f30,
		"TNerveBGTentacleDamage::execute": 0x80059f8c,
		"TNerveBGTentacleDamage::~TNerveBGTentacleDamage": 0x8005a254,
		"TNerveBGTentacleDamage::theNerve": 0x8005a2b0,
		"TNerveBGBeakDamage::execute": 0x8005a314,
		"TNerveBGBeakDamage::theNerve": 0x8005a894,
		"TNerveBGBeakDamage::~TNerveBGBeakDamage": 0x8005a8f8,
		"TNerveBGEyeDamage::execute": 0x8005a954,
		"TNerveBGEyeDamage::theNerve": 0x8005abf8,
		"TNerveBGEyeDamage::~TNerveBGEyeDamage": 0x8005ac5c,
		"TNerveBGWait::execute": 0x8005acb8,
		"TNerveBGWait::theNerve": 0x8005b0bc,
		"TNerveBGWait::~TNerveBGWait": 0x8005b120,
		"TBossGessoManager::load": 0x8005b17c,
		"TBossGessoManager::initJParticle": 0x8005b1f0,
		"TBossGessoManager::createModelData": 0x8005b6d4,
		"TBossGessoManager::TBossGessoManager": 0x8005b708,
		"TBossGesso::perform": 0x8005b744,
		"TBossGesso::calcRootMatrix": 0x8005c118,
		"TBossGesso::reset": 0x8005c2e0,
		"TBossGesso::moveObject": 0x8005c3a8,
		"Enemy::MsGetRotFromZaxisY": 0x8005caac,
		"MsGetRotFromZaxisY": 0x8005caac,
		"Enemy::SMS_GetMarioPos": 0x8005cb74,
		"SMS_GetMarioPos": 0x8005cb74,
		"TBossGesso::doAttackShoot": 0x8005cb7c,
		"doAttackShoot": 0x8005cb7c,
		"TBossGesso::doAttackUnison": 0x8005cd88,
		"doAttackUnison": 0x8005cd88,
		"TBossGesso::doAttackSkipRope": 0x8005d038,
		"doAttackSkipRope": 0x8005d038,
		"TBossGesso::doAttackDouble": 0x8005d214,
		"doAttackDouble": 0x8005d214,
		"TBossGesso::doAttackSingle": 0x8005d4c8,
		"doAttackSingle": 0x8005d4c8,
		"TBossGesso::receiveMessage": 0x8005df20,
		"TBossGesso::getBasNameTable": 0x8005df78,
		"TBossGesso::beakHeld": 0x8005df84,
		"beakHeld": 0x8005df84,
		"TBossGesso::tentacleHeld": 0x8005dfa0,
		"tentacleHeld": 0x8005dfa0,
		"TBossGesso::launchPolDrop": 0x8005e008,
		"TBossGesso::changeAllTentacleState": 0x8005e104,
		"changeAllTentacleState": 0x8005e104,
		"TBossGesso::gotTentacleDamage": 0x8005e1a8,
		"gotTentacleDamage": 0x8005e1a8,
		"TBossGesso::changeAttackMode": 0x8005e33c,
		"changeAttackMode": 0x8005e33c,
		"TBossGesso::stopIfRoll": 0x8005e958,
		"stopIfRoll": 0x8005e958,
		"TBossGesso::is2ndFightNow": 0x8005ea74,
		"is2ndFightNow": 0x8005ea74,
		"TBossGesso::showMessage": 0x8005ea94,
		"TBossGesso::lenFromToeToMario": 0x8005eb20,
		"lenFromToeToMario": 0x8005eb20,
		"TBossGesso::rumblePad": 0x8005ecbc,
		"TBossGesso::init": 0x8005ee1c,
		"TBossGesso::TBossGesso": 0x8005f6dc,
		"TBGBinder::bind": 0x8005f7b0,
		"TBGBodyHit::perform": 0x8005fe04,
		"TBGBodyHit::receiveMessage": 0x8005fe6c,
		"TBGEyeHit::perform": 0x8005fed4,
		"TBGEyeHit::receiveMessage": 0x8005ff24,
		"TBGBeakHit::perform": 0x800601e0,
		"TBGBeakHit::receiveMessage": 0x80060838,
		"TBGBeakHit::moveRequest": 0x80060f9c,
		"TBGBeakHit::getTakingMtx": 0x8006114c,
		"TBossGessoParams::TBossGessoParams": 0x80061154,
		"TBossGessoManager::~TBossGessoManager": 0x80061700,
		"TBGBinder::~TBGBinder": 0x800617d0,
		"TBossGessoMtxCalc::~TBossGessoMtxCalc": 0x80061834,
		"Enemy::__sinit_bossgesso_cpp": 0x80061a84,
		"__sinit_bossgesso_cpp": 0x80061a84,
		"TNerveElecCarapaceReturn::~TNerveElecCarapaceReturn": 0x80061ddc,
		"TNerveElecCarapaceReturn::execute": 0x80061e38,
		"TNerveElecNokonokoFreeze::~TNerveElecNokonokoFreeze": 0x800621c8,
		"TNerveElecCarapaceWait::execute": 0x80062224,
		"TNerveElecCarapaceWait::~TNerveElecCarapaceWait": 0x80062240,
		"TNerveElecCarapaceMove::execute": 0x8006229c,
		"TNerveElecNokonokoCollect::~TNerveElecNokonokoCollect": 0x80062794,
		"TNerveElecCarapaceMove::~TNerveElecCarapaceMove": 0x800627f0,
		"TNerveElecNokonokoAttack::execute": 0x8006284c,
		"TNerveElecNokonokoAttack::~TNerveElecNokonokoAttack": 0x800628d8,
		"TNerveElecNokonokoRebirth::execute": 0x80062934,
		"TNerveElecNokonokoRebirth::~TNerveElecNokonokoRebirth": 0x80062a4c,
		"TNerveElecNokonokoFreeze::execute": 0x80062aa8,
		"TNerveElecNokonokoTurn::execute": 0x80062dac,
		"TNerveElecNokonokoTurn::~TNerveElecNokonokoTurn": 0x80062fd0,
		"TNerveElecNokonokoCollect::execute": 0x8006302c,
		"TNerveElecNokonokoShoot::execute": 0x80063308,
		"TNerveElecNokonokoShoot::~TNerveElecNokonokoShoot": 0x80063500,
		"TElecCarapace::reflect": 0x8006355c,
		"reflect": 0x8006355c,
		"TElecCarapace::receiveMessage": 0x80063770,
		"TElecCarapace::sendMessage": 0x80063800,
		"TElecCarapace::calcRootMatrix": 0x800639f8,
		"TElecCarapace::bind": 0x80063bf4,
		"TElecCarapace::shoot": 0x80063c34,
		"TElecCarapace::appear": 0x80063f28,
		"TElecCarapace::getNowGravity": 0x80063f90,
		"TElecCarapace::behaveToHitWall": 0x80063fc4,
		"TElecCarapace::kill": 0x800640c4,
		"TElecCarapace::behaveToHitGround": 0x800640e4,
		"TElecCarapace::setBehavior": 0x800641a4,
		"TElecCarapace::perform": 0x8006420c,
		"TElecCarapace::loadInit": 0x8006435c,
		"TElecCarapace::TElecCarapace": 0x8006454c,
		"TElecNokonoko::genRandomItem": 0x800645c8,
		"TElecNokonoko::setMeltAnm": 0x8006467c,
		"TElecNokonoko::setDeadAnm": 0x80064750,
		"TElecNokonoko::setRunAnm": 0x80064780,
		"TElecNokonoko::setWalkAnm": 0x800647d0,
		"TElecNokonoko::setWaitAnm": 0x80064820,
		"TElecNokonoko::getBasNameTable": 0x80064858,
		"TElecNokonoko::behaveToWater": 0x80064864,
		"TElecNokonoko::behaveToFindMario": 0x80064a0c,
		"TElecNokonoko::isResignationAttack": 0x80064ba0,
		"TElecNokonoko::receiveMessage": 0x80064cf8,
		"TElecNokonoko::sendAttackMsgToMario": 0x80064e7c,
		"TElecNokonoko::calcRootMatrix": 0x80064eb8,
		"TElecNokonoko::attackToMario": 0x80065254,
		"TElecNokonoko::moveObject": 0x80065464,
		"TElecNokonoko::setMActorAndKeeper": 0x800654dc,
		"TElecNokonoko::load": 0x80065574,
		"TElecNokonoko::rest": 0x800655b4,
		"rest": 0x800655b4,
		"TElecNokonoko::init": 0x800655e8,
		"TElecNokonoko::TElecNokonoko": 0x80065760,
		"TElecNokonokoManager::perform": 0x800657b4,
		"TElecNokonokoManager::clipEnemies": 0x80065854,
		"TElecNokonokoManager::createModelData": 0x8006597c,
		"TElecNokonokoManager::createEnemyInstance": 0x800659b0,
		"TElecNokonokoManager::initSetEnemies": 0x80065a1c,
		"TElecNokonokoManager::load": 0x80065a20,
		"TElecNokonokoManager::TElecNokonokoManager": 0x80065bec,
		"TElecCarapace::rebirth": 0x80065cac,
		"TElecCarapace::recoverScale": 0x80065cb0,
		"TElecCarapace::getPhaseShift": 0x80065cb4,
		"TElecNokonokoManager::~TElecNokonokoManager": 0x80065d6c,
		"Enemy::__sinit_elecNokonoko_cpp": 0x80065de0,
		"__sinit_elecNokonoko_cpp": 0x80065de0,
		"TNerveKageMarioModokiWait::~TNerveKageMarioModokiWait": 0x800660ec,
		"TNerveKageMarioModokiWait::execute": 0x80066148,
		"TKageMarioModoki::init": 0x800662e4,
		"TKageMarioModoki::load": 0x800663e8,
		"TKageMarioModokiManager::createModelData": 0x80066428,
		"TKageMarioModokiManager::createEnemyInstance": 0x8006645c,
		"TKageMarioModokiManager::load": 0x800664b8,
		"TNerveTelesaTrample::execute": 0x80066524,
		"TNerveTelesaTrample::~TNerveTelesaTrample": 0x80066584,
		"TNerveTelesaAttackMario::execute": 0x800665e0,
		"TNerveTelesaAttackMario::~TNerveTelesaAttackMario": 0x800668ac,
		"TNerveTelesaFreeze::execute": 0x80066908,
		"TNerveTelesaFreeze::~TNerveTelesaFreeze": 0x80066b28,
		"TNerveTelesaDie::execute": 0x80066b84,
		"TNerveTelesaDie::~TNerveTelesaDie": 0x80066de8,
		"TNerveTelesaImitate::execute": 0x80066e44,
		"TNerveTelesaImitate::~TNerveTelesaImitate": 0x800671f4,
		"TMarioModokiTelesa::init": 0x80067250,
		"TMarioModokiTelesa::load": 0x800672e4,
		"TMarioModokiTelesa::TMarioModokiTelesa": 0x800676a0,
		"TBoxTelesa::isHitValid": 0x80067788,
		"TBoxTelesa::reset": 0x800678c0,
		"TBoxTelesa::load": 0x80067b6c,
		"TBoxTelesa::TBoxTelesa": 0x80067c74,
		"TLoopTelesa::load": 0x80067cb8,
		"TLoopTelesa::TLoopTelesa": 0x80067d30,
		"TSeeTelesa::load": 0x80067d74,
		"TSeeTelesa::TSeeTelesa": 0x80067dfc,
		"TTelesa::changeTevKColor": 0x80067e40,
		"changeTevKColor": 0x80067e40,
		"TTelesa::isCollidMove": 0x80068058,
		"TTelesa::setAttacker": 0x80068078,
		"setAttacker": 0x80068078,
		"TTelesa::initItemAttacker": 0x800681ec,
		"initItemAttacker": 0x800681ec,
		"TTelesa::initAttacker": 0x80068458,
		"TTelesa::kill": 0x8006873c,
		"TTelesa::forceKill": 0x80068878,
		"TTelesa::getGravityY": 0x80068950,
		"TTelesa::reduceFlyForce": 0x80068974,
		"reduceFlyForce": 0x80068974,
		"TTelesa::setWaitAnm": 0x80068a10,
		"TTelesa::setWalkAnm": 0x80068a40,
		"TTelesa::getBasNameTable": 0x80068ab4,
		"TTelesa::changeOut": 0x80068ac0,
		"TTelesa::scalingChangeActor": 0x80068b9c,
		"TTelesa::changeByJuice": 0x80068c18,
		"TTelesa::isReachedToGoal": 0x80068e38,
		"TTelesa::bind": 0x80068f00,
		"TTelesa::moveObject": 0x80069244,
		"TTelesa::calcRootMatrix": 0x80069278,
		"TTelesa::walkBehavior": 0x80069480,
		"TTelesa::behaveToWater": 0x80069640,
		"TTelesa::attackToMario": 0x800698d0,
		"TTelesa::setBehavior": 0x8006994c,
		"TTelesa::drawObject": 0x80069ab0,
		"TTelesa::perform": 0x80069adc,
		"TTelesa::reset": 0x80069c38,
		"TTelesa::setMActorAndKeeper": 0x80069edc,
		"TTelesa::init": 0x80069f48,
		"TTelesa::load": 0x8006a1e0,
		"TTelesa::TTelesa": 0x8006a240,
		"TTelesaManager::setFlagOutOfCube": 0x8006a2e0,
		"TTelesaManager::telesaForceKill": 0x8006a3b4,
		"telesaForceKill": 0x8006a3b4,
		"TTelesaManager::createModelData": 0x8006a47c,
		"TTelesaManager::createEnemies": 0x8006a4b0,
		"TTelesaManager::createEnemyInstance": 0x8006a590,
		"TTelesaManager::load": 0x8006a5d4,
		"TTelesaManager::TTelesaManager": 0x8006a684,
		"TTelesaSaveLoadParams::TTelesaSaveLoadParams": 0x8006a6d0,
		"TKageMarioModokiManager::~TKageMarioModokiManager": 0x8006aab0,
		"TTelesa::isFindMario": 0x8006ab24,
		"TTelesa::decHpByWater": 0x8006ab2c,
		"TTelesa::isInhibitedForceMove": 0x8006ab30,
		"TTelesa::getChangeBlockTime": 0x8006ab38,
		"TBoxTelesa::isEatenByYosshi": 0x8006abdc,
		"TTelesaManager::~TTelesaManager": 0x8006adb8,
		"Enemy::__sinit_telesa_cpp": 0x8006ae2c,
		"__sinit_telesa_cpp": 0x8006ae2c,
		"TNerveFireWanwanEscape::~TNerveFireWanwanEscape": 0x8006b158,
		"TNerveFireWanwanEscape::execute": 0x8006b1b4,
		"TNerveFireWanwanRecover::~TNerveFireWanwanRecover": 0x8006b454,
		"TNerveFireWanwanEscape::theNerve": 0x8006b4b0,
		"TNerveFireWanwanFreeze::execute": 0x8006b514,
		"TNerveFireWanwanFreeze::theNerve": 0x8006b684,
		"TNerveFireWanwanFreeze::~TNerveFireWanwanFreeze": 0x8006b6e8,
		"TNerveFireWanwanFly::execute": 0x8006b744,
		"TNerveFireWanwanFly::~TNerveFireWanwanFly": 0x8006ba40,
		"TNerveFireWanwanHungTail::execute": 0x8006ba9c,
		"TNerveFireWanwanHungTail::~TNerveFireWanwanHungTail": 0x8006bd04,
		"TNerveFireWanwanDie::execute": 0x8006bd60,
		"TNerveFireWanwanDie::theNerve": 0x8006bfc4,
		"TNerveFireWanwanDie::~TNerveFireWanwanDie": 0x8006c028,
		"TNerveFireWanwanRecover::execute": 0x8006c084,
		"TNerveFireWanwanRecover::theNerve": 0x8006c2c8,
		"TNerveFireWanwanRecoverGraph::execute": 0x8006c32c,
		"TNerveFireWanwanGraphWander::~TNerveFireWanwanGraphWander": 0x8006c8d0,
		"JGeometry::TQuat4<float><float>::slerp": 0x8006c974,
		"slerp": 0x8006c974,
		"TNerveFireWanwanRecoverGraph::~TNerveFireWanwanRecoverGraph": 0x8006cbbc,
		"TNerveFireWanwanTired::execute": 0x8006cc18,
		"TNerveFireWanwanFindMario::~TNerveFireWanwanFindMario": 0x8006cde0,
		"TNerveFireWanwanTired::~TNerveFireWanwanTired": 0x8006ce3c,
		"TNerveFireWanwanAttack::execute": 0x8006ce98,
		"TNerveFireWanwanAttack::~TNerveFireWanwanAttack": 0x8006d148,
		"TNerveFireWanwanFindMario::execute": 0x8006d1a4,
		"TNerveFireWanwanTurn::execute": 0x8006d6b8,
		"TNerveFireWanwanTurn::theNerve": 0x8006d8d4,
		"TNerveFireWanwanTurn::~TNerveFireWanwanTurn": 0x8006d938,
		"TNerveFireWanwanGraphWander::execute": 0x8006d994,
		"TNerveFireWanwanGraphWander::theNerve": 0x8006db2c,
		"TFireWanwan::isCollidMove": 0x8006db90,
		"TFireWanwan::doKeepDistance": 0x8006db98,
		"TFireWanwan::getBasNameTable": 0x8006dbac,
		"TFireWanwan::getGravityY": 0x8006dbb8,
		"TFireWanwan::checkWalls": 0x8006dce0,
		"TFireWanwan::bindPoint": 0x8006defc,
		"bindPoint": 0x8006defc,
		"TFireWanwan::bindBody": 0x8006e2d4,
		"bindBody": 0x8006e2d4,
		"TFireWanwan::bind": 0x8006e64c,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setQuat": 0x8006ee50,
		"setQuat": 0x8006ee50,
		"TFireWanwan::attackToMario": 0x8006eef0,
		"TFireWanwan::sendAttackMsgToMario": 0x8006f0cc,
		"TTakeActor::isTaken": 0x8006f0d0,
		"isTaken": 0x8006f0d0,
		"TFireWanwan::initEscapeNextGraphNode": 0x8006f0ec,
		"initEscapeNextGraphNode": 0x8006f0ec,
		"TFireWanwan::checkHitActors": 0x8006f2f0,
		"TFireWanwan::emitEffects": 0x8006f5bc,
		"TFireWanwan::updatePollute": 0x8006fb18,
		"updatePollute": 0x8006fb18,
		"TFireWanwan::updateRumble": 0x8006fce0,
		"updateRumble": 0x8006fce0,
		"TFireWanwan::moveObject": 0x8006fed8,
		"TFireWanwan::calcRootMatrix": 0x800705c0,
		"TFireWanwan::perform": 0x80070788,
		"TFireWanwan::isHitValid": 0x800708d0,
		"TFireWanwan::kill": 0x800708d8,
		"TFireWanwan::behaveToWater": 0x800709f0,
		"TFireWanwan::receiveMessage": 0x80070d78,
		"TFireWanwan::isMissMario": 0x80070ed0,
		"isMissMario": 0x80070ed0,
		"TFireWanwan::isFindMario": 0x80071090,
		"TFireWanwan::reset": 0x800710fc,
		"TFireWanwan::setMActorAndKeeper": 0x80071250,
		"TFireWanwan::init": 0x800712bc,
		"TFireWanwan::TFireWanwan": 0x800715b4,
		"TFireWanwanTailHit::getHostPos": 0x80071610,
		"getHostPos": 0x80071610,
		"TFireWanwanTailHit::moveRequest": 0x8007161c,
		"TFireWanwanTailHit::getTakingMtx": 0x80071740,
		"TFireWanwanTailHit::movementBody": 0x80071748,
		"movementBody": 0x80071748,
		"TFireWanwanTailHit::performNodes": 0x80071b5c,
		"performNodes": 0x80071b5c,
		"TFireWanwanTailHit::perform": 0x80071e24,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::operator_[]": 0x80072480,
		"operator_[]": 0x80072480,
		"@unnamed@::ArrayWrapper<TTailRubber::Node>::size": 0x80072490,
		"size": 0x80072490,
		"TFireWanwanTailHit::init": 0x80072498,
		"TTailRubber::Node::Node": 0x80072970,
		"TFireWanwanTailHit::receiveMessage": 0x80072974,
		"TFireWanwanTailNode::perform": 0x80072bf8,
		"TFireWanwanManager::perform": 0x80072de8,
		"TFireWanwanManager::createModelData": 0x80073090,
		"TFireWanwanManager::load": 0x800730c4,
		"TFireWanwanManager::TFireWanwanManager": 0x8007311c,
		"TFireWanwanSaveLoadParams::TFireWanwanSaveLoadParams": 0x80073178,
		"TTailRubber::getLength": 0x80073730,
		"TTailRubber::restrict": 0x80073810,
		"restrict": 0x80073810,
		"TTailRubber::adjust": 0x80073c84,
		"TTailRubber::bindOne": 0x8007413c,
		"bindOne": 0x8007413c,
		"TFireWanwanManager::~TFireWanwanManager": 0x80074390,
		"MyUtil::value_lerp": 0x80074404,
		"value_lerp": 0x80074404,
		"Enemy::__sinit_fireWanwan_cpp": 0x800746dc,
		"__sinit_fireWanwan_cpp": 0x800746dc,
		"TStageEnemyInfo::~TStageEnemyInfo": 0x800749e8,
		"TStageEnemyInfoTable::getMatchedInfo": 0x80074a4c,
		"getMatchedInfo": 0x80074a4c,
		"TStageEnemyInfoTable::TStageEnemyInfoTable": 0x80074b60,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::~TNameRefPtrAryT": 0x80074bec,
		"TStageEnemyInfo::load": 0x80074c64,
		"TStageEnemyInfoTable::~TStageEnemyInfoTable": 0x80074cf0,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::loadAfter": 0x80074d78,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::searchF": 0x80074dd8,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::load": 0x80074e74,
		"TOneShotGenerator::receiveMessage": 0x80075008,
		"TOneShotGenerator::loadAfter": 0x80075100,
		"TOneShotGenerator::load": 0x80075234,
		"TOneShotGenerator::TOneShotGenerator": 0x80075284,
		"TGenerator::perform": 0x800752e4,
		"TGenerator::load": 0x80075404,
		"TGenerator::TGenerator": 0x800755ac,
		"TGenerator::~TGenerator": 0x80075630,
		"TNerveBPCannonL::~TNerveBPCannonL": 0x800756ac,
		"TNerveBPCannonL::execute": 0x80075708,
		"TNerveBPWaitL::~TNerveBPWaitL": 0x80075840,
		"TNerveBPCannonL::theNerve": 0x8007589c,
		"TNerveBPWaitL::execute": 0x80075900,
		"TNerveBPWaitL::theNerve": 0x80075b34,
		"TNerveBPBreakSleep::execute": 0x80075b98,
		"TNerveBPTakeOff::~TNerveBPTakeOff": 0x80075c8c,
		"TNerveBPBreakSleep::theNerve": 0x80075ce8,
		"TNerveBPBreakSleep::~TNerveBPBreakSleep": 0x80075d4c,
		"TNerveBPSleep::execute": 0x80075da8,
		"TNerveBPSleep::theNerve": 0x80075de0,
		"TNerveBPSleep::~TNerveBPSleep": 0x80075e44,
		"TNerveBPFall::execute": 0x80075ea0,
		"TNerveBPTornado::~TNerveBPTornado": 0x800763bc,
		"TNerveBPWait::~TNerveBPWait": 0x80076418,
		"TNerveBPVomit::~TNerveBPVomit": 0x80076474,
		"TNerveBPFall::theNerve": 0x800764d0,
		"TNerveBPFall::~TNerveBPFall": 0x80076534,
		"TNerveBPHover::execute": 0x80076590,
		"TNerveBPFly::~TNerveBPFly": 0x80076918,
		"TNerveBPFlyPivot::~TNerveBPFlyPivot": 0x80076974,
		"TNerveBPFlyCannon::~TNerveBPFlyCannon": 0x800769d0,
		"TNerveBPHover::~TNerveBPHover": 0x80076a2c,
		"TNerveBPHover::theNerve": 0x80076a88,
		"TNerveBPFlyPivot::execute": 0x80076aec,
		"TNerveBPFlyPivot::theNerve": 0x80076b98,
		"TNerveBPFlyCannon::execute": 0x80076bfc,
		"TNerveBPFlyCannon::theNerve": 0x80076c90,
		"TNerveBPTouchDown::execute": 0x80076cf4,
		"TNerveBPTouchDown::theNerve": 0x80076e84,
		"TNerveBPTouchDown::~TNerveBPTouchDown": 0x80076ee8,
		"TNerveBPFly::execute": 0x80076f44,
		"TNerveBPFly::theNerve": 0x80077210,
		"TNerveBPTakeOff::execute": 0x80077274,
		"TNerveBPTakeOff::theNerve": 0x8007749c,
		"TNerveBPDie::execute": 0x80077500,
		"TNerveBPDie::theNerve": 0x80077618,
		"TNerveBPDie::~TNerveBPDie": 0x8007767c,
		"TNerveBPPreDie::execute": 0x800776d8,
		"TNerveBPPreDie::theNerve": 0x800778b0,
		"TNerveBPPreDie::~TNerveBPPreDie": 0x80077914,
		"TNerveBPJumpReact::execute": 0x80077970,
		"TNerveBPJumpReact::theNerve": 0x800779d4,
		"TNerveBPJumpReact::~TNerveBPJumpReact": 0x80077a38,
		"TNerveBPStompReact::execute": 0x80077a94,
		"TNerveBPStompReact::theNerve": 0x80077bd0,
		"TNerveBPStompReact::~TNerveBPStompReact": 0x80077c34,
		"TNerveBPSwing::execute": 0x80077c90,
		"TNerveBPSwing::theNerve": 0x80077d40,
		"TNerveBPSwing::~TNerveBPSwing": 0x80077da4,
		"TNerveBPGetUp::execute": 0x80077e00,
		"TNerveBPGetUp::theNerve": 0x80077eb8,
		"TNerveBPGetUp::~TNerveBPGetUp": 0x80077f1c,
		"TNerveBPTumbleOut::execute": 0x80077f78,
		"TNerveBPTumbleOut::theNerve": 0x800781f0,
		"TNerveBPTumbleOut::~TNerveBPTumbleOut": 0x80078254,
		"TNerveBPTumble::execute": 0x800782b0,
		"TNerveBPTumble::theNerve": 0x80078428,
		"TNerveBPTumble::~TNerveBPTumble": 0x8007848c,
		"TNerveBPTumbleIn::execute": 0x800784e8,
		"TNerveBPTumbleIn::theNerve": 0x8007863c,
		"TNerveBPTumbleIn::~TNerveBPTumbleIn": 0x800786a0,
		"TNerveBPSwallow::execute": 0x800786fc,
		"TNerveBPSwallow::theNerve": 0x800788ec,
		"TNerveBPSwallow::~TNerveBPSwallow": 0x80078950,
		"TNerveBPPivot::execute": 0x800789ac,
		"TNerveBPPivot::theNerve": 0x80078b04,
		"TNerveBPPivot::~TNerveBPPivot": 0x80078b68,
		"TNerveBPTornado::execute": 0x80078bc4,
		"TNerveBPTornado::theNerve": 0x80078d40,
		"TNerveBPVomit::execute": 0x80078da4,
		"TNerveBPVomit::theNerve": 0x80079114,
		"TNerveBPCannon::execute": 0x80079178,
		"TNerveBPCannon::theNerve": 0x8007929c,
		"TNerveBPCannon::~TNerveBPCannon": 0x80079300,
		"TNerveBPWait::execute": 0x8007935c,
		"TNerveBPWait::theNerve": 0x80079fb4,
		"TBossPakkunManager::load": 0x8007a018,
		"TBossPakkunManager::createModelData": 0x8007a2dc,
		"TBossPakkunManager::TBossPakkunManager": 0x8007a338,
		"TBossPakkun::perform": 0x8007a384,
		"TBossPakkun::receiveMessage": 0x8007ab54,
		"TBossPakkun::kill": 0x8007ada4,
		"TBossPakkun::setGroundCollision": 0x8007ae24,
		"TBossPakkun::getBasNameTable": 0x8007afa8,
		"TBossPakkun::changeBck": 0x8007afb4,
		"TBossPakkun::launchPolDrop": 0x8007b32c,
		"TBossPakkun::gotHipDropDamage": 0x8007b534,
		"gotHipDropDamage": 0x8007b534,
		"TBossPakkun::showMessage": 0x8007badc,
		"TBossPakkun::rumblePad": 0x8007bb50,
		"TBossPakkun::checkMarioRiding": 0x8007bcb0,
		"TBossPakkun::init": 0x8007bd58,
		"TBossPakkun::TBossPakkun": 0x8007c528,
		"TBossPakkunMtxCalc::calcHeadDir": 0x8007c64c,
		"calcHeadDir": 0x8007c64c,
		"TBossPakkunMtxCalc::calcBellyScale": 0x8007ca10,
		"calcBellyScale": 0x8007ca10,
		"TBPNavel::perform": 0x8007cc80,
		"TBPNavel::receiveMessage": 0x8007cce8,
		"TBPHeadHit::perform": 0x8007cdf8,
		"TBPHeadHit::throwActor": 0x8007cebc,
		"throwActor": 0x8007cebc,
		"TBPHeadHit::receiveMessage": 0x8007d10c,
		"TBPTornado::perform": 0x8007d6d8,
		"TBPTornado::TBPTornado": 0x8007de04,
		"TBPVomit::perform": 0x8007def8,
		"TBPPolDrop::perform": 0x8007dfc8,
		"TBPPolDrop::move": 0x8007e23c,
		"TBPPolDrop::TBPPolDrop": 0x8007e548,
		"TBossPakkunParams::TBossPakkunParams": 0x8007e684,
		"TBossPakkunManager::~TBossPakkunManager": 0x8007eadc,
		"TBossPakkunMtxCalc::~TBossPakkunMtxCalc": 0x8007ebac,
		"TBPVomit::~TBPVomit": 0x8007ede4,
		"Enemy::__sinit_bosspakkun_cpp": 0x8007eedc,
		"__sinit_bosspakkun_cpp": 0x8007eedc,
		"TNerveTobiPukuSwimWander::~TNerveTobiPukuSwimWander": 0x8007f214,
		"TNerveTobiPukuSwimWander::execute": 0x8007f270,
		"TNerveTobiPukuReturnLaunch::execute": 0x8007f324,
		"TNerveTobiPukuPrepareFly::~TNerveTobiPukuPrepareFly": 0x8007f578,
		"TNerveTobiPukuReturnLaunch::~TNerveTobiPukuReturnLaunch": 0x8007f5d4,
		"TNerveTobiPukuPrepareFly::execute": 0x8007f630,
		"TNerveTobiPukuBound::execute": 0x8007f7d8,
		"TNerveTobiPukuLand::~TNerveTobiPukuLand": 0x8007f9a0,
		"TNerveTobiPukuBound::~TNerveTobiPukuBound": 0x8007f9fc,
		"TNerveTobiPukuLand::execute": 0x8007fa58,
		"TNerveTobiPukuPitiPiti::~TNerveTobiPukuPitiPiti": 0x80080000,
		"TNerveTobiPukuDie::execute": 0x8008005c,
		"TNerveTobiPukuDie::~TNerveTobiPukuDie": 0x80080258,
		"TNerveTobiPukuPitiPiti::execute": 0x800802b4,
		"TNerveTobiPukuFall::execute": 0x800803cc,
		"TNerveTobiPukuFall::~TNerveTobiPukuFall": 0x800805b0,
		"TNerveTobiPukuHitWater::execute": 0x8008060c,
		"TNerveTobiPukuHitWater::~TNerveTobiPukuHitWater": 0x8008085c,
		"TNerveTobiPukuAttack::execute": 0x800808b8,
		"TNerveTobiPukuAttack::~TNerveTobiPukuAttack": 0x80080a50,
		"TNerveTobiPukuFly::execute": 0x80080aac,
		"TNerveTobiPukuFly::~TNerveTobiPukuFly": 0x80080c40,
		"TNerveTobiPukuGenerate::execute": 0x80080c9c,
		"TNerveTobiPukuGenerate::~TNerveTobiPukuGenerate": 0x80080e48,
		"TMoePuku::getBasNameTable": 0x80080ea4,
		"TMoePuku::generateEffectColumWater": 0x80080eb0,
		"TMoePuku::setJumpStartAnm": 0x8008101c,
		"TMoePuku::setFallEndLandAnm": 0x8008106c,
		"TMoePuku::setDeadAnm": 0x8008109c,
		"TMoePuku::setDownLandAnm": 0x800810cc,
		"TMoePuku::setDownAirAnm": 0x800810fc,
		"TMoePuku::setFallAnm": 0x8008112c,
		"TMoePuku::setPichiAnm": 0x8008115c,
		"TMoePuku::setAttackAnm": 0x8008118c,
		"TMoePuku::setSwimAnm": 0x800811bc,
		"TMoePuku::setJumpAnm": 0x800811ec,
		"TMoePuku::isJumpStartBck": 0x8008121c,
		"TMoePuku::isFallEndLandBck": 0x8008124c,
		"TMoePuku::isAttackBck": 0x8008127c,
		"TMoePuku::isDeadBck": 0x800812ac,
		"TMoePuku::isJumpBck": 0x800812dc,
		"TMoePuku::isPichiEffect": 0x8008130c,
		"TMoePuku::hitWater": 0x8008133c,
		"TMoePuku::calcRootMatrix": 0x800813fc,
		"TPukuPuku::reset": 0x80081644,
		"TPukuPuku::init": 0x80081780,
		"TPukuPuku::load": 0x80081854,
		"TPukuPuku::TPukuPuku": 0x8008189c,
		"TTobiPuku::getBasNameTable": 0x8008197c,
		"TTobiPuku::scalingChangeActor": 0x80081988,
		"TTobiPuku::initAttacker": 0x80081a1c,
		"TTobiPuku::changeOut": 0x80081b00,
		"TTobiPuku::genEventCoin": 0x80081ba0,
		"TTobiPuku::forceKill": 0x80081bcc,
		"TTobiPuku::kill": 0x80081d24,
		"TTobiPuku::hitWater": 0x80081ea0,
		"TTobiPuku::getGravityY": 0x80081ff4,
		"TTobiPuku::attackToMario": 0x80082014,
		"TTobiPuku::generateEffectColumWater": 0x80082190,
		"TTobiPuku::isReachedToGoalXZ": 0x800822ac,
		"TTobiPuku::swimEffect": 0x80082374,
		"TTobiPuku::walkBehavior": 0x80082424,
		"TTobiPuku::behaveToWater": 0x800824f4,
		"TTobiPuku::setJumpStartAnm": 0x80082640,
		"TTobiPuku::setFallEndLandAnm": 0x80082690,
		"TTobiPuku::setDeadAnm": 0x800826c0,
		"TTobiPuku::setDownLandAnm": 0x800826f0,
		"TTobiPuku::setDownAirAnm": 0x80082720,
		"TTobiPuku::setFallAnm": 0x80082750,
		"TTobiPuku::setPichiAnm": 0x80082780,
		"TTobiPuku::setAttackAnm": 0x800827b0,
		"TTobiPuku::setSwimAnm": 0x800827e0,
		"TTobiPuku::setJumpAnm": 0x80082810,
		"TTobiPuku::isJumpStartBck": 0x80082840,
		"TTobiPuku::isFallEndLandBck": 0x80082870,
		"TTobiPuku::isAttackBck": 0x800828a0,
		"TTobiPuku::isDeadBck": 0x800828d0,
		"TTobiPuku::isJumpBck": 0x80082900,
		"TTobiPuku::isPichiEffect": 0x80082930,
		"TTobiPuku::calcRootMatrix": 0x80082960,
		"TTobiPuku::hitWall": 0x80082ab4,
		"hitWall": 0x80082ab4,
		"TTobiPuku::moveObject": 0x80082c10,
		"TTobiPuku::reset": 0x80082c80,
		"TTobiPuku::init": 0x80082d58,
		"TTobiPuku::TTobiPuku": 0x80082dc4,
		"TMoePukuLaunchPad::launch": 0x80082e78,
		"TTobiPukuLaunchPad::forceLaunch": 0x80082ed8,
		"forceLaunch": 0x80082ed8,
		"TTobiPukuLaunchPad::launch": 0x800830bc,
		"TTobiPukuLaunchPad::reset": 0x8008311c,
		"TTobiPukuLaunchPad::load": 0x80083154,
		"TTobiPukuLaunchPad::init": 0x800831d4,
		"TTobiPukuLaunchPad::perform": 0x80083224,
		"TTobiPukuLaunchPad::TTobiPukuLaunchPad": 0x800832e0,
		"TMoePukuManager::createEnemyInstance": 0x80083338,
		"TTobiPukuManager::createEnemyInstance": 0x80083394,
		"TTobiPukuManager::load": 0x800833dc,
		"TTobiPukuManager::TTobiPukuManager": 0x8008354c,
		"TMoePukuLaunchPadManager::createEnemyInstance": 0x80083588,
		"TTobiPukuLaunchPadManager::perform": 0x80083690,
		"TTobiPukuLaunchPadManager::createEnemyInstance": 0x80083728,
		"TTobiPukuLaunchPadManager::load": 0x80083798,
		"TTobiPukuLaunchPadManager::TTobiPukuLaunchPadManager": 0x80083908,
		"Enemy::TobiPukuRollCallback": 0x8008394c,
		"TobiPukuRollCallback": 0x8008394c,
		"TMoePuku::swimEffect": 0x80083b70,
		"TTobiPuku::isInhibitedForceMove": 0x80083b74,
		"TMoePukuManager::~TMoePukuManager": 0x80083d64,
		"TMoePukuLaunchPadManager::~TMoePukuLaunchPadManager": 0x80083e5c,
		"Enemy::__sinit_tobiPuku_cpp": 0x80083f54,
		"__sinit_tobiPuku_cpp": 0x80083f54,
		"TNerveTinKoopaBreak::~TNerveTinKoopaBreak": 0x80084278,
		"TNerveTinKoopaBreak::execute": 0x800842d4,
		"TNerveTinKoopaDamage::execute": 0x800846cc,
		"TNerveTinKoopaDamage::~TNerveTinKoopaDamage": 0x80084848,
		"TNerveTinKoopaWait::execute": 0x800848a4,
		"TNerveTinKoopaWait::~TNerveTinKoopaWait": 0x80084984,
		"TTinKoopaManager::createEnemyInstance": 0x800849e0,
		"TTinKoopaManager::loadAfter": 0x800849e8,
		"TTinKoopaManager::load": 0x80084aec,
		"TTinKoopaManager::createModelData": 0x80084b44,
		"TTinKoopaManager::TTinKoopaManager": 0x80084b78,
		"TTinKoopa::emitTinKoopaEffects": 0x80084bb4,
		"emitTinKoopaEffects": 0x80084bb4,
		"TTinKoopa::checkTinKoopaFirstFlameMessage": 0x800857b8,
		"checkTinKoopaFirstFlameMessage": 0x800857b8,
		"TTinKoopa::checkTinKoopaKillerApproachingMessage": 0x800858cc,
		"checkTinKoopaKillerApproachingMessage": 0x800858cc,
		"TTinKoopa::launchKiller": 0x80085a50,
		"TTinKoopa::hitParts": 0x80085b54,
		"hitParts": 0x80085b54,
		"TTinKoopa::receiveMessage": 0x80085dac,
		"TTinKoopa::getBasNameTable": 0x80085de8,
		"TTinKoopa::perform": 0x80085df4,
		"TTinKoopa::resetTinKoopa": 0x80086084,
		"resetTinKoopa": 0x80086084,
		"TTinKoopa::reset": 0x80086198,
		"TTinKoopa::calcCoasterDistance": 0x80086414,
		"calcCoasterDistance": 0x80086414,
		"TTinKoopa::TTinKoopa": 0x800864c0,
		"TTinKoopaPartsBase::perform": 0x80086550,
		"TTinKoopaPartsBase::receiveMessage": 0x80086680,
		"TTinKoopaPartsBase::emitPartsTrackEffects": 0x80086900,
		"emitPartsTrackEffects": 0x80086900,
		"TTinKoopaPartsBase::startBreaking": 0x800869dc,
		"startBreaking": 0x800869dc,
		"TTinKoopaPartsBase::reset": 0x80086be8,
		"TTinKoopaPartsBase::initTinKoopaPartsBase": 0x80086c34,
		"initTinKoopaPartsBase": 0x80086c34,
		"TTinKoopaLaunchOrder::checkOrder": 0x80086e14,
		"checkOrder": 0x80086e14,
		"TTinKoopaFlame::emitFlameEffects": 0x80086f80,
		"emitFlameEffects": 0x80086f80,
		"TTinKoopaFlame::perform": 0x800871b4,
		"TTinKoopaFlame::receiveMessage": 0x800872fc,
		"TTinKoopa::makeLaunchSchedule": 0x800873e4,
		"makeLaunchSchedule": 0x800873e4,
		"TTinKoopa::init": 0x800875c0,
		"TTinKoopaParams::TTinKoopaParams": 0x80087ba4,
		"TTinKoopaManager::~TTinKoopaManager": 0x80087ea8,
		"TTinKoopaManager::hasMapCollision": 0x80087f0c,
		"TTinKoopaMtxCalc::~TTinKoopaMtxCalc": 0x80087f14,
		"TTinKoopa::hasMapCollision": 0x8008811c,
		"Enemy::__sinit_tinkoopa_cpp": 0x80088124,
		"__sinit_tinkoopa_cpp": 0x80088124,
		"TCommonLauncherManager::~TCommonLauncherManager": 0x8008844c,
		"TCommonLauncherManager::load": 0x800884c0,
		"TCommonLauncherManager::createModelData": 0x800884e0,
		"TCommonLauncherManager::TCommonLauncherManager": 0x80088514,
		"TCommonLauncher::perform": 0x800885c0,
		"TCommonLauncher::getBasNameTable": 0x8008872c,
		"TCommonLauncher::stateDie": 0x80088738,
		"TCommonLauncher::stateLaunch": 0x8008892c,
		"TCommonLauncher::stateNormal": 0x80088acc,
		"TCommonLauncher::stateHitByWater": 0x80088b74,
		"TCommonLauncher::stateInitial": 0x80088c28,
		"TCommonLauncher::load": 0x80088c58,
		"TCommonLauncher::init": 0x80088cac,
		"TCommonLauncher::TCommonLauncher": 0x80088f98,
		"TLauncherManager::load": 0x80089084,
		"TLauncherManager::TLauncherManager": 0x80089144,
		"TLauncher::stateDie": 0x80089180,
		"TLauncher::stateLaunch": 0x80089210,
		"TLauncher::stateNormal": 0x8008928c,
		"TLauncher::stateHitByWater": 0x800892d4,
		"TLauncher::stateInitial": 0x80089354,
		"TLauncher::changeState": 0x80089390,
		"TLauncher::getProperEnemy": 0x80089398,
		"getProperEnemy": 0x80089398,
		"TLauncher::resetLaunchTimer": 0x800893fc,
		"resetLaunchTimer": 0x800893fc,
		"TLauncher::control": 0x80089450,
		"TLauncher::bind": 0x80089548,
		"TLauncher::receiveMessage": 0x8008954c,
		"TLauncher::init": 0x80089634,
		"TLauncher::TLauncher": 0x80089780,
		"Enemy::__sinit_launcher_cpp": 0x80089864,
		"__sinit_launcher_cpp": 0x80089864,
		"TNerveBWFall::~TNerveBWFall": 0x80089b70,
		"TNerveBWFall::execute": 0x80089bcc,
		"TNerveBWGraphWander::~TNerveBWGraphWander": 0x80089dcc,
		"TNerveBWFall::theNerve": 0x80089e28,
		"TNerveBWShake::execute": 0x80089e8c,
		"TNerveBWShake::theNerve": 0x8008a024,
		"TNerveBWShake::~TNerveBWShake": 0x8008a088,
		"TNerveBWJumpAway::execute": 0x8008a0e4,
		"TNerveBWJumpAway::theNerve": 0x8008a370,
		"TNerveBWJumpAway::~TNerveBWJumpAway": 0x8008a3d4,
		"TNerveBWDie::execute": 0x8008a430,
		"TNerveBWDie::~TNerveBWDie": 0x8008a890,
		"TNerveBWDie::theNerve": 0x8008a8ec,
		"TNerveBWJumpToBath::execute": 0x8008a950,
		"TNerveBWJumpToBath::theNerve": 0x8008ac84,
		"TNerveBWJumpToBath::~TNerveBWJumpToBath": 0x8008ace8,
		"TNerveBWWakeup::execute": 0x8008ad44,
		"TNerveBWWakeup::theNerve": 0x8008aed8,
		"TNerveBWWakeup::~TNerveBWWakeup": 0x8008af3c,
		"TNerveBWStun::execute": 0x8008af98,
		"TNerveBWStun::theNerve": 0x8008b2ac,
		"TNerveBWStun::~TNerveBWStun": 0x8008b310,
		"TNerveBWJump::execute": 0x8008b36c,
		"TNerveBWJump::theNerve": 0x8008b4ec,
		"TNerveBWJump::~TNerveBWJump": 0x8008b550,
		"TNerveBWBark::execute": 0x8008b5ac,
		"TNerveBWBark::theNerve": 0x8008b82c,
		"TNerveBWBark::~TNerveBWBark": 0x8008b890,
		"TNerveBWRoll::execute": 0x8008b8ec,
		"TNerveBWRoll::~TNerveBWRoll": 0x8008ba2c,
		"TNerveBWRoll::theNerve": 0x8008ba98,
		"TNerveBWGraphWander::execute": 0x8008bafc,
		"TNerveBWGraphWander::theNerve": 0x8008c4ec,
		"TBossWanwanManager::load": 0x8008c550,
		"TBossWanwanManager::createModelData": 0x8008c748,
		"TBossWanwanManager::createEnemyInstance": 0x8008c77c,
		"TBossWanwanManager::TBossWanwanManager": 0x8008c7c4,
		"TBossWanwan::perform": 0x8008c800,
		"TBossWanwan::emitEffects": 0x8008d06c,
		"TBossWanwan::control": 0x8008d4f0,
		"TBossWanwan::slideToCurPathNode": 0x8008d80c,
		"slideToCurPathNode": 0x8008d80c,
		"TBossWanwan::calcRootMatrix": 0x8008dac4,
		"TBossWanwan::receiveMessage": 0x8008dba8,
		"TBossWanwan::shakeCamera": 0x8008ddf8,
		"shakeCamera": 0x8008ddf8,
		"TBossWanwan::init": 0x8008df74,
		"TBossWanwan::TBossWanwan": 0x8008e704,
		"TBWBinder::bind": 0x8008ea0c,
		"TBWHit::perform": 0x8008f55c,
		"TBWHit::receiveMessage": 0x8008f618,
		"TBWPicket::perform": 0x8008f648,
		"TBWPicket::getTakingMtx": 0x8008fb78,
		"TBWPicket::moveRequest": 0x8008fb80,
		"TBWPicket::receiveMessage": 0x8008fd38,
		"TBWLeash::perform": 0x8008fe6c,
		"TBWLeash::TBWLeash": 0x800903a0,
		"TBWLeashNode::perform": 0x800906dc,
		"TBWLeashNode::calcMatrix": 0x80090908,
		"calcMatrix": 0x80090908,
		"TBWLeashNode::calcTemperature": 0x80090bcc,
		"calcTemperature": 0x80090bcc,
		"TBWParams::TBWParams": 0x80090c70,
		"TBossWanwanManager::~TBossWanwanManager": 0x80090fe8,
		"TBossWanwan::kill": 0x800910b8,
		"TBossWanwanMtxCalc::~TBossWanwanMtxCalc": 0x800910bc,
		"TBWBinder::~TBWBinder": 0x80091168,
		"TBWLeash::~TBWLeash": 0x800912ec,
		"Enemy::__sinit_bosswanwan_cpp": 0x800913e4,
		"__sinit_bosswanwan_cpp": 0x800913e4,
		"TNerveChuuHanaWait::~TNerveChuuHanaWait": 0x8009175c,
		"TNerveChuuHanaWait::execute": 0x800917b8,
		"TNerveChuuHanaJumpPrepare::execute": 0x80091824,
		"TNerveChuuHanaJumpPrepare::~TNerveChuuHanaJumpPrepare": 0x800919c8,
		"TNerveChuuHanaAttack::execute": 0x80091a24,
		"TNerveChuuHanaFall2::~TNerveChuuHanaFall2": 0x80091e24,
		"TNerveChuuHanaWalkOnPanel::~TNerveChuuHanaWalkOnPanel": 0x80091e80,
		"TNerveChuuHanaAttack::~TNerveChuuHanaAttack": 0x80091edc,
		"TNerveChuuHanaObject::execute": 0x80091f38,
		"TNerveChuuHanaObject::~TNerveChuuHanaObject": 0x80091f40,
		"TNerveChuuHanaFall2::execute": 0x80091f9c,
		"TNerveChuuHanaFall::execute": 0x800920c8,
		"TNerveChuuHanaFall::~TNerveChuuHanaFall": 0x800920d0,
		"TNerveChuuHanaRoll::execute": 0x8009212c,
		"TNerveChuuHanaKeepBalance::~TNerveChuuHanaKeepBalance": 0x8009234c,
		"TNerveChuuHanaRoll::~TNerveChuuHanaRoll": 0x800923a8,
		"TNerveChuuHanaStick::execute": 0x80092404,
		"TNerveChuuHanaStick::~TNerveChuuHanaStick": 0x800926ac,
		"TNerveChuuHanaKeepBalance::execute": 0x80092708,
		"TNerveChuuHanaForceJumped::execute": 0x80092af4,
		"TNerveChuuHanaForceJumped::~TNerveChuuHanaForceJumped": 0x80092da4,
		"TNerveChuuHanaWalkOnPanel::execute": 0x80092e00,
		"TChuuHana::getBasNameTable": 0x80093088,
		"TChuuHana::checkStretchType": 0x80093094,
		"checkStretchType": 0x80093094,
		"TChuuHana::setGoal": 0x80093564,
		"setGoal": 0x80093564,
		"TChuuHana::willFall": 0x800936cc,
		"willFall": 0x800936cc,
		"TChuuHana::getGravityY": 0x800938cc,
		"TChuuHana::forceKill": 0x80093b30,
		"TChuuHana::kill": 0x80093c54,
		"TChuuHana::setWalkAnm": 0x80093cc8,
		"TChuuHana::receiveMessage": 0x80093d6c,
		"TChuuHana::bind": 0x80093efc,
		"TChuuHana::calcRootMatrix": 0x800941e4,
		"TChuuHana::isCollidMove": 0x80094468,
		"TChuuHana::moveObject": 0x80094864,
		"TChuuHana::attackToMario": 0x80094bf0,
		"TChuuHana::behaveToWater": 0x80094e54,
		"TChuuHana::setBckAnm": 0x8009546c,
		"TChuuHana::reset": 0x800954f8,
		"TChuuHana::perform": 0x8009567c,
		"TChuuHana::setMActorAndKeeper": 0x80095738,
		"TChuuHana::init": 0x800957a4,
		"TChuuHana::TChuuHana": 0x800958f4,
		"TChuuHanaAseParCallback::draw": 0x800959a8,
		"TChuuHanaAseParCallback::execute": 0x800959ac,
		"Enemy::ChuuHanaBodyCallback": 0x80095a20,
		"ChuuHanaBodyCallback": 0x80095a20,
		"TChuuHanaManager::initSetEnemies": 0x80095cc4,
		"TChuuHanaManager::createEnemyInstance": 0x80095e4c,
		"TChuuHanaManager::perform": 0x80095e94,
		"TChuuHanaManager::load": 0x80095ff4,
		"TChuuHanaManager::TChuuHanaManager": 0x8009604c,
		"TChuuHanaSaveLoadParams::TChuuHanaSaveLoadParams": 0x800960ac,
		"TChuuHana::isFindMario": 0x80096590,
		"TChuuHanaManager::~TChuuHanaManager": 0x80096634,
		"Enemy::__sinit_chuuhana_cpp": 0x800966a8,
		"__sinit_chuuhana_cpp": 0x800966a8,
		"TNerveGorogoroDie::~TNerveGorogoroDie": 0x800969ac,
		"TNerveGorogoroDie::execute": 0x80096a08,
		"TNerveGorogoroRollOnGraph::execute": 0x80096c3c,
		"TNerveGorogoroRollOnGraph::~TNerveGorogoroRollOnGraph": 0x80096cfc,
		"TGorogoro::generateByGateKeeper": 0x80096d58,
		"generateByGateKeeper": 0x80096d58,
		"TGorogoro::setMActorAndKeeper": 0x800972dc,
		"TGorogoro::isRolling": 0x80097348,
		"TGorogoro::getBasNameTable": 0x800973f4,
		"TGorogoro::bound": 0x80097400,
		"TGorogoro::setMeltAnm": 0x80097468,
		"TGorogoro::setDeadAnm": 0x80097560,
		"TGorogoro::flagJump": 0x8009762c,
		"TGorogoro::walkBehavior": 0x80097704,
		"TGorogoro::boundSE": 0x800979f8,
		"TGorogoro::rollSE": 0x80097a70,
		"TGorogoro::behaveToWater": 0x80097ae8,
		"TGorogoro::forceKill": 0x80097d3c,
		"TGorogoro::kill": 0x80097f28,
		"TGorogoro::reset": 0x8009807c,
		"TGorogoro::calcRootMatrix": 0x800980d4,
		"TGorogoro::perform": 0x800982c8,
		"TGorogoro::init": 0x80098354,
		"TGorogoroManager::perform": 0x800985b4,
		"TGorogoroManager::createModelData": 0x80098ad8,
		"TGorogoroManager::initSetEnemies": 0x80098b0c,
		"TGorogoroManager::createEnemyInstance": 0x80098c74,
		"TGorogoroManager::loadAfter": 0x80098cfc,
		"TGorogoroManager::load": 0x80098d98,
		"TGorogoroManager::TGorogoroManager": 0x80098f08,
		"TGorogoroPolluteModel::setAnm": 0x80098f60,
		"TGorogoroPolluteModelManager::init": 0x80098fb0,
		"TNerveIgaigaShootFromCannon::execute": 0x80099080,
		"TNerveIgaigaRollOnGraph::~TNerveIgaigaRollOnGraph": 0x800991f8,
		"TNerveIgaigaShootFromCannon::~TNerveIgaigaShootFromCannon": 0x80099254,
		"TNerveIgaigaWaterHit::execute": 0x800992b0,
		"TNerveIgaigaWaterHit::~TNerveIgaigaWaterHit": 0x80099520,
		"TNerveIgaigaRollOnGraph::execute": 0x8009957c,
		"TIgaiga::shoot": 0x8009969c,
		"TIgaiga::bound": 0x80099764,
		"TIgaiga::isHitValid": 0x80099808,
		"TIgaiga::getBasNameTable": 0x80099828,
		"TIgaiga::setMeltAnm": 0x80099834,
		"TIgaiga::setDeadAnm": 0x80099a98,
		"TIgaiga::setWalkAnm": 0x80099c00,
		"TIgaiga::isReachedToGoalXZ": 0x80099c30,
		"TIgaiga::walkBehavior": 0x80099cec,
		"TIgaiga::boundSE": 0x80099e88,
		"TIgaiga::rollSE": 0x80099f00,
		"TIgaiga::moveObject": 0x80099f48,
		"TIgaiga::kill": 0x8009a1d4,
		"TIgaiga::reset": 0x8009a1fc,
		"TIgaiga::behaveToWater": 0x8009a33c,
		"TIgaiga::isRolling": 0x8009a488,
		"TIgaiga::calcRootMatrix": 0x8009a5c8,
		"TIgaiga::perform": 0x8009a5ec,
		"TIgaiga::setMActorAndKeeper": 0x8009a60c,
		"TIgaiga::init": 0x8009a678,
		"TIgaiga::TIgaiga": 0x8009a780,
		"Enemy::RollEnemyBodyCallback": 0x8009a824,
		"RollEnemyBodyCallback": 0x8009a824,
		"TRollEnemy::isRolling": 0x8009a954,
		"TIgaigaManager::perform": 0x8009a95c,
		"TIgaigaManager::initSetEnemies": 0x8009a9bc,
		"TIgaigaManager::createEnemyInstance": 0x8009aa78,
		"TIgaigaManager::createModelData": 0x8009aac0,
		"TIgaigaManager::load": 0x8009aaf4,
		"TIgaigaManager::TIgaigaManager": 0x8009ac78,
		"TIgaigaPolluteModel::setAnm": 0x8009acc4,
		"TIgaigaPolluteModelManager::init": 0x8009ad14,
		"TRollEnemy::setBehavior": 0x8009ade4,
		"TRollEnemy::isReachedToGoalXZ": 0x8009b00c,
		"TRollEnemy::isCollidMove": 0x8009b0c0,
		"TRollEnemy::flagJump": 0x8009b140,
		"TRollEnemy::attackToMario": 0x8009b218,
		"TRollEnemy::behaveToWater": 0x8009b23c,
		"TRollEnemy::walkBehavior": 0x8009b3d4,
		"TRollEnemy::rollSE": 0x8009b5e0,
		"TRollEnemy::boundSE": 0x8009b5e4,
		"TRollEnemy::bound": 0x8009b5e8,
		"TRollEnemy::reset": 0x8009b5ec,
		"TRollEnemy::TRollEnemy": 0x8009b7e4,
		"TRollEnemy::setAfterDeadEffect": 0x8009b854,
		"TGorogoroManager::~TGorogoroManager": 0x8009b8f4,
		"TGorogoroPolluteModel::~TGorogoroPolluteModel": 0x8009b968,
		"TGorogoroPolluteModelManager::~TGorogoroPolluteModelManager": 0x8009b9ec,
		"TIgaigaManager::~TIgaigaManager": 0x8009bb0c,
		"TIgaigaPolluteModel::~TIgaigaPolluteModel": 0x8009bb80,
		"TIgaigaPolluteModelManager::~TIgaigaPolluteModelManager": 0x8009bc04,
		"Enemy::__sinit_igaiga_cpp": 0x8009bc88,
		"__sinit_igaiga_cpp": 0x8009bc88,
		"TNervePoihanaTrapped::~TNervePoihanaTrapped": 0x8009bf9c,
		"TNervePoihanaTrapped::execute": 0x8009bff8,
		"TNervePoihanaFreeze::~TNervePoihanaFreeze": 0x8009c4c8,
		"TNervePoihanaThrow::execute": 0x8009c524,
		"TNervePoihanaThrow::~TNervePoihanaThrow": 0x8009c6f0,
		"TNervePoihanaFreeze::execute": 0x8009c74c,
		"TNervePoihanaSleep::execute": 0x8009c94c,
		"TNervePoihanaSleep::~TNervePoihanaSleep": 0x8009cc80,
		"TSleepPoiHana::load": 0x8009ccdc,
		"TSleepPoiHana::TSleepPoiHana": 0x8009cd24,
		"TPoiHanaRed::attackToMario": 0x8009ce48,
		"TPoiHanaRed::init": 0x8009d070,
		"TPoiHana::getBasNameTable": 0x8009d0bc,
		"TPoiHana::changeByJuice": 0x8009d0c8,
		"TPoiHana::genEventCoin": 0x8009d118,
		"TPoiHana::isMoving": 0x8009d248,
		"isMoving": 0x8009d248,
		"TPoiHana::getGravityY": 0x8009d32c,
		"TPoiHana::generateItem": 0x8009d3c8,
		"TPoiHana::calcRootMatrix": 0x8009d3e0,
		"TPoiHana::doKeepDistance": 0x8009d770,
		"TPoiHana::isInhibitedForceMove": 0x8009d7a4,
		"TPoiHana::walkBehavior": 0x8009d7c0,
		"TPoiHana::isCollidMove": 0x8009d938,
		"TPoiHana::isHitValid": 0x8009db34,
		"TPoiHana::setDeadAnm": 0x8009dc00,
		"TPoiHana::setFreezeAnm": 0x8009de48,
		"TPoiHana::setRunAnm": 0x8009de78,
		"TPoiHana::setWaitAnm": 0x8009dea8,
		"TPoiHana::setWalkAnm": 0x8009ded8,
		"TPoiHana::attackToMario": 0x8009df08,
		"TPoiHana::behaveToWater": 0x8009e114,
		"TPoiHana::bind": 0x8009e224,
		"TPoiHana::perform": 0x8009e344,
		"TPoiHana::moveObject": 0x8009e398,
		"TPoiHana::reset": 0x8009e674,
		"TPoiHana::setMActorAndKeeper": 0x8009e6c4,
		"TPoiHana::init": 0x8009e730,
		"TPoiHana::load": 0x8009e9b4,
		"TPoiHana::TPoiHana": 0x8009e9f4,
		"TPoiHanaCollision::receiveMessage": 0x8009ea68,
		"TPoiHanaManager::initSetEnemies": 0x8009ea98,
		"TPoiHanaManager::perform": 0x8009eb38,
		"TPoiHanaManager::createEnemyInstance": 0x8009eb58,
		"TPoiHanaManager::load": 0x8009ebbc,
		"TPoiHanaManager::TPoiHanaManager": 0x8009edd0,
		"TPoiHanaManager::~TPoiHanaManager": 0x8009efc8,
		"Enemy::__sinit_poihana_cpp": 0x8009f03c,
		"__sinit_poihana_cpp": 0x8009f03c,
		"TNerveTamaNokoWait::~TNerveTamaNokoWait": 0x8009f358,
		"TNerveTamaNokoWait::execute": 0x8009f3b4,
		"TNerveTamaNokoHitWater::execute": 0x8009f53c,
		"TNerveTamaNokoSleep::~TNerveTamaNokoSleep": 0x8009f874,
		"TNerveTamaNokoHitWater::~TNerveTamaNokoHitWater": 0x8009f8d0,
		"TNerveTamaNokoSink::execute": 0x8009f92c,
		"TNerveTamaNokoSink::~TNerveTamaNokoSink": 0x8009fb44,
		"TNerveTamaNokoThrown::execute": 0x8009fba0,
		"TNerveTamaNokoThrown::~TNerveTamaNokoThrown": 0x8009fcac,
		"TNerveTamaNokoPickUp::execute": 0x8009fd08,
		"TNerveTamaNokoPickUp::~TNerveTamaNokoPickUp": 0x8009fdbc,
		"TNerveTamaNokoDown::execute": 0x8009fe18,
		"TNerveTamaNokoDown::~TNerveTamaNokoDown": 0x800a009c,
		"TNerveTamaNokoAttack::execute": 0x800a00f8,
		"TNerveTamaNokoAttack::~TNerveTamaNokoAttack": 0x800a08a8,
		"TNerveTamaNokoSleep::execute": 0x800a0904,
		"TTamaNoko::isCollidMove": 0x800a09ac,
		"TTamaNoko::isReachedToGoal": 0x800a0a78,
		"TTamaNoko::setDeadAnm": 0x800a0b40,
		"TTamaNoko::setWalkAnm": 0x800a0b70,
		"TTamaNoko::getGravityY": 0x800a0ba0,
		"TTamaNoko::getBasNameTable": 0x800a0c94,
		"TTamaNoko::setAfterDeadEffect": 0x800a0ca0,
		"TTamaNoko::landEffect": 0x800a0da0,
		"landEffect": 0x800a0da0,
		"TTamaNoko::requestShadow": 0x800a10c8,
		"TTamaNoko::calcRootMatrix": 0x800a12a4,
		"TTamaNoko::doKeepDistance": 0x800a16cc,
		"TTamaNoko::attackToMario": 0x800a1758,
		"TTamaNoko::isHitValid": 0x800a1818,
		"TTamaNoko::receiveMessage": 0x800a18ac,
		"TTamaNoko::changeByJuice": 0x800a1a04,
		"TTamaNoko::behaveToRelease": 0x800a1a0c,
		"TTamaNoko::behaveToTaken": 0x800a1b30,
		"TTamaNoko::walkBehavior": 0x800a1c48,
		"TTamaNoko::behaveToWater": 0x800a2174,
		"TTamaNoko::behaveToFindMario": 0x800a2354,
		"TTamaNoko::moveObject": 0x800a23f8,
		"TTamaNoko::perform": 0x800a248c,
		"TTamaNoko::reset": 0x800a24f8,
		"TTamaNoko::setMActorAndKeeper": 0x800a2550,
		"TTamaNoko::init": 0x800a25bc,
		"TTamaNoko::load": 0x800a26b4,
		"TTamaNoko::TTamaNoko": 0x800a26f4,
		"TTamaNokoManager::createModelData": 0x800a2754,
		"TTamaNokoManager::createEnemyInstance": 0x800a2788,
		"TTamaNokoManager::initSetEnemies": 0x800a27d0,
		"TTamaNokoManager::loadAfter": 0x800a28fc,
		"TTamaNokoManager::load": 0x800a2958,
		"TTamaNokoManager::TTamaNokoManager": 0x800a2b6c,
		"TTamaNokoFlower::perform": 0x800a2ba8,
		"TTamaNoko::forceKill": 0x800a2f50,
		"TTamaNokoManager::~TTamaNokoManager": 0x800a2ff0,
		"TTamaNokoFlower::~TTamaNokoFlower": 0x800a3064,
		"Enemy::__sinit_tamaNoko_cpp": 0x800a30e8,
		"__sinit_tamaNoko_cpp": 0x800a30e8,
		"TNerveBossTelesaFallDemo::~TNerveBossTelesaFallDemo": 0x800a33ec,
		"TNerveBossTelesaFallDemo::execute": 0x800a3448,
		"TNerveBossTelesaHideWait::~TNerveBossTelesaHideWait": 0x800a3634,
		"TNerveBossTelesaFreeze::execute": 0x800a3690,
		"TNerveBossTelesaFreeze::~TNerveBossTelesaFreeze": 0x800a3840,
		"TNerveBossTelesaPrepareSlot::execute": 0x800a389c,
		"TNerveBossTelesaHide::~TNerveBossTelesaHide": 0x800a3f04,
		"TNerveBossTelesaPrepareSlot::~TNerveBossTelesaPrepareSlot": 0x800a3f60,
		"TNerveBossTelesaSpitSlotItem::execute": 0x800a3fbc,
		"TNerveBossTelesaSpitSlotItem::~TNerveBossTelesaSpitSlotItem": 0x800a420c,
		"TNerveBossTelesaSlotStart::execute": 0x800a4268,
		"TNerveBossTelesaSlotStart::~TNerveBossTelesaSlotStart": 0x800a451c,
		"TNerveBossTelesaAppear::execute": 0x800a4578,
		"TNerveBossTelesaAppear::~TNerveBossTelesaAppear": 0x800a4944,
		"TNerveBossTelesaHideWait::execute": 0x800a49a0,
		"TNerveBossTelesaHide::execute": 0x800a4ba0,
		"TNerveBossTelesaSpit::execute": 0x800a4d78,
		"TNerveBossTelesaSpit::~TNerveBossTelesaSpit": 0x800a4ea8,
		"TNerveBossTelesaDie::execute": 0x800a4f04,
		"TNerveBossTelesaDie::~TNerveBossTelesaDie": 0x800a57cc,
		"TBossTelesa::forceHide": 0x800a5828,
		"forceHide": 0x800a5828,
		"TBossTelesa::forceAllItemKill": 0x800a59c4,
		"forceAllItemKill": 0x800a59c4,
		"TBossTelesa::generateSlotItem": 0x800a5ab8,
		"generateSlotItem": 0x800a5ab8,
		"TBossTelesa::rouletteStart": 0x800a660c,
		"rouletteStart": 0x800a660c,
		"TBossTelesa::genAttacker": 0x800a68c8,
		"genAttacker": 0x800a68c8,
		"TBossTelesa::getBasNameTable": 0x800a6c3c,
		"TBossTelesa::flashItem": 0x800a6c48,
		"flashItem": 0x800a6c48,
		"TBossTelesa::slotFall": 0x800a6ecc,
		"slotFall": 0x800a6ecc,
		"TBossTelesa::rouletteFall": 0x800a7014,
		"rouletteFall": 0x800a7014,
		"TBossTelesa::damageRecover": 0x800a717c,
		"damageRecover": 0x800a717c,
		"TBossTelesa::setSpicy": 0x800a73fc,
		"setSpicy": 0x800a73fc,
		"TBossTelesa::checkHitObject": 0x800a7598,
		"checkHitObject": 0x800a7598,
		"TBossTelesa::receiveMessage": 0x800a7868,
		"TBossTelesa::perform": 0x800a7870,
		"TBossTelesa::calcRootMatrix": 0x800a79c4,
		"TBossTelesa::getTakingMtx": 0x800a7f38,
		"TBossTelesa::kill": 0x800a7fa0,
		"TBossTelesa::moveObject": 0x800a80b8,
		"TBossTelesa::reset": 0x800a89b8,
		"TBossTelesa::loadAfter": 0x800a8ae0,
		"TBossTelesa::init": 0x800a97ec,
		"TBossTelesa::TBossTelesa": 0x800a9f78,
		"TTelesaSlot::getResultFromAng": 0x800aa034,
		"TTelesaSlot::getForcastResult": 0x800aa0dc,
		"TTelesaSlot::getSlotResult": 0x800aa20c,
		"getSlotResult": 0x800aa20c,
		"TTelesaSlot::isRollDrum": 0x800aa298,
		"isRollDrum": 0x800aa298,
		"TTelesaSlot::forceStopSlot": 0x800aa2e4,
		"forceStopSlot": 0x800aa2e4,
		"TTelesaSlot::touchWater": 0x800aa460,
		"TTelesaSlot::moveStart": 0x800aa468,
		"moveStart": 0x800aa468,
		"TTelesaSlot::moveObject": 0x800aa50c,
		"TTelesaSlot::calcRootMatrix": 0x800aa964,
		"TTelesaSlot::randomReset": 0x800aaa28,
		"randomReset": 0x800aaa28,
		"TTelesaSlot::initMapObj": 0x800aab14,
		"TBossTelesaKillSmallEnemy::checkHit": 0x800aac98,
		"TBossTelesaTongue::receiveMessage": 0x800aadd0,
		"TBossTelesaBody::receiveMessage": 0x800aaef4,
		"TBossTelesaManager::perform": 0x800ab13c,
		"TBossTelesaManager::createModelData": 0x800ab15c,
		"TBossTelesaManager::createEnemyInstance": 0x800ab190,
		"TBossTelesaManager::load": 0x800ab1d8,
		"TBossTelesaManager::TBossTelesaManager": 0x800ab244,
		"TBossTelesaSaveLoadParams::TBossTelesaSaveLoadParams": 0x800ab280,
		"TNerveBubbleSplit::execute": 0x800ab620,
		"TNerveBubbleSplit::~TNerveBubbleSplit": 0x800ab6e0,
		"TNerveBubbleLive::execute": 0x800ab73c,
		"TBubble::appendEnemy": 0x800abb24,
		"appendEnemy": 0x800abb24,
		"TNerveBubbleLive::~TNerveBubbleLive": 0x800abd38,
		"TBubble::getBasNameTable": 0x800abd94,
		"TBubble::getTakingMtx": 0x800abda0,
		"TBubble::setDeadAnm": 0x800abdb0,
		"TBubble::calcRootMatrix": 0x800abde0,
		"TBubble::attackToMario": 0x800abea8,
		"TBubble::behaveToWater": 0x800abef4,
		"TBubble::kill": 0x800abfe0,
		"TBubble::getGravityY": 0x800ac104,
		"TBubble::split": 0x800ac134,
		"split": 0x800ac134,
		"TBubble::reset": 0x800ac2ec,
		"TBubble::init": 0x800ac400,
		"TBubbleManager::createModelData": 0x800ac528,
		"TBubbleManager::createEnemyInstance": 0x800ac55c,
		"TBubbleManager::load": 0x800ac5ec,
		"TBubbleManager::TBubbleManager": 0x800ac788,
		"TTelesaSlot::initNeonMatColor": 0x800ac9bc,
		"TBossTelesaManager::~TBossTelesaManager": 0x800acc3c,
		"TBossTelesaManager::clipEnemies": 0x800acca0,
		"TBubble::setAfterDeadEffect": 0x800acca4,
		"TBubbleManager::~TBubbleManager": 0x800acd44,
		"Enemy::__sinit_bosstelesa_cpp": 0x800acdb8,
		"__sinit_bosstelesa_cpp": 0x800acdb8,
		"TNerveRHGraphWander::~TNerveRHGraphWander": 0x800ad0ec,
		"TNerveRHGraphWander::execute": 0x800ad148,
		"TRiccoHookManager::createEnemyInstance": 0x800ad428,
		"TRiccoHookManager::load": 0x800ad430,
		"TRiccoHookManager::createModelData": 0x800ad55c,
		"TRiccoHookManager::TRiccoHookManager": 0x800ad590,
		"TRiccoHook::perform": 0x800ad5cc,
		"TRiccoHook::receiveMessage": 0x800ad6bc,
		"TRiccoHook::kill": 0x800ad6c4,
		"TRiccoHook::init": 0x800ad6c8,
		"TRiccoHook::TRiccoHook": 0x800ad924,
		"THookTake::perform": 0x800ad974,
		"THookTake::receiveMessage": 0x800ada58,
		"THookTake::getRadiusAtY": 0x800adaa0,
		"THookTake::getTakingMtx": 0x800adad4,
		"TRiccoHookManager::~TRiccoHookManager": 0x800adadc,
		"TNerveBombHeiExplosion::~TNerveBombHeiExplosion": 0x800adf54,
		"TNerveBombHeiExplosion::execute": 0x800adfb0,
		"TNerveBombHeiThrown::execute": 0x800ae238,
		"TNerveBombHeiThrown::~TNerveBombHeiThrown": 0x800ae3ec,
		"TNerveBombHeiPickUp::execute": 0x800ae448,
		"TNerveBombHeiPickUp::~TNerveBombHeiPickUp": 0x800ae474,
		"TNerveBombHeiWaitExplosion::execute": 0x800ae4d0,
		"TNerveBombHeiWaitExplosion::~TNerveBombHeiWaitExplosion": 0x800ae740,
		"TNerveBombHeiWalkExplosion::execute": 0x800ae79c,
		"TNerveBombHeiWalkExplosion::~TNerveBombHeiWalkExplosion": 0x800ae94c,
		"TNerveBombHeiAttack::execute": 0x800ae9a8,
		"TNerveBombHeiAttack::~TNerveBombHeiAttack": 0x800aea98,
		"TNerveBombHeiGenerate::execute": 0x800aeaf4,
		"TNerveBombHeiGenerate::~TNerveBombHeiGenerate": 0x800aed28,
		"TBombHei::getBasNameTable": 0x800aed84,
		"TBombHei::isDamageToCannon": 0x800aed90,
		"isDamageToCannon": 0x800aed90,
		"TBombHei::forceKill": 0x800aee80,
		"TBombHei::isCollidMove": 0x800af08c,
		"TBombHei::moveObject": 0x800af3d0,
		"TBombHei::walkBehavior": 0x800af634,
		"TBombHei::getGravityY": 0x800af6b8,
		"TBombHei::reset": 0x800af748,
		"TBombHei::behaveToRelease": 0x800af7a0,
		"TBombHei::behaveToTaken": 0x800af920,
		"TBombHei::attackToMario": 0x800afa74,
		"TBombHei::calcRootMatrix": 0x800afb00,
		"TBombHei::setDeadAnm": 0x800afbbc,
		"TBombHei::setFreezeAnm": 0x800afc98,
		"TBombHei::setWalkAnm": 0x800afcc8,
		"TBombHei::genEventCoin": 0x800afcf8,
		"TBombHei::kill": 0x800afe08,
		"TBombHei::isHitValid": 0x800aff9c,
		"TBombHei::changeOut": 0x800afff4,
		"TBombHei::behaveToWater": 0x800b00e8,
		"TBombHei::setMActorAndKeeper": 0x800b01fc,
		"TBombHei::init": 0x800b027c,
		"TBombHei::TBombHei": 0x800b0374,
		"TBombHeiManager::createEnemyInstance": 0x800b03d0,
		"TBombHeiManager::createModelData": 0x800b0440,
		"TBombHeiManager::load": 0x800b0474,
		"TBombHeiManager::TBombHeiManager": 0x800b0604,
		"TBombHei::setAfterDeadEffect": 0x800b0648,
		"TBombHei::doKeepDistance": 0x800b064c,
		"TBombHeiManager::~TBombHeiManager": 0x800b0700,
		"Enemy::__sinit_bombhei_cpp": 0x800b0778,
		"__sinit_bombhei_cpp": 0x800b0778,
		"TNerveCannonObject::~TNerveCannonObject": 0x800b0a7c,
		"TNerveCannonObject::execute": 0x800b0ad8,
		"TNerveCannonDamageDemo::execute": 0x800b0cb8,
		"TNerveCannonDamageDemo::~TNerveCannonDamageDemo": 0x800b0ee4,
		"TNerveCannonDamage::execute": 0x800b0f40,
		"TNerveCannonSearch::~TNerveCannonSearch": 0x800b1554,
		"TNerveCannonDamage::~TNerveCannonDamage": 0x800b15b0,
		"TNerveCannonClose::execute": 0x800b160c,
		"TNerveCannonOpen::~TNerveCannonOpen": 0x800b1944,
		"TNerveCannonClose::~TNerveCannonClose": 0x800b19a0,
		"TNerveCannonForceBombShoot::execute": 0x800b19fc,
		"TNerveCannonForceBombShoot::~TNerveCannonForceBombShoot": 0x800b1ca8,
		"TNerveCannonShoot::execute": 0x800b1d04,
		"TNerveCannonShoot::~TNerveCannonShoot": 0x800b20a0,
		"TNerveCannonSearch::execute": 0x800b20fc,
		"TNerveCannonOpen::execute": 0x800b27c0,
		"TCannon::startChorobeiShout": 0x800b2988,
		"startChorobeiShout": 0x800b2988,
		"TCannon::isObject": 0x800b298c,
		"isObject": 0x800b298c,
		"TCannon::setKillerGoalPoint": 0x800b29e4,
		"setKillerGoalPoint": 0x800b29e4,
		"TCannon::killerShoot": 0x800b2c24,
		"killerShoot": 0x800b2c24,
		"TCannon::bombShoot": 0x800b351c,
		"bombShoot": 0x800b351c,
		"TCannon::bombSet": 0x800b36e8,
		"bombSet": 0x800b36e8,
		"TCannon::getTakingMtx": 0x800b394c,
		"TCannon::calcRootMatrix": 0x800b3a10,
		"TCannon::perform": 0x800b3e9c,
		"TCannon::getBasNameTable": 0x800b4338,
		"TCannon::receiveMessage": 0x800b4344,
		"TCannon::moveObject": 0x800b438c,
		"TCannon::reset": 0x800b4668,
		"TCannon::init": 0x800b4790,
		"TCannon::loadAfter": 0x800b4d74,
		"TCannon::load": 0x800b4f24,
		"TCannon::TCannon": 0x800b4fcc,
		"TCannonDom::perform": 0x800b5094,
		"TCannonDom::TCannonDom": 0x800b518c,
		"TChorobei::receiveMessage": 0x800b529c,
		"TChorobei::checkHit": 0x800b52a4,
		"TChorobei::perform": 0x800b5530,
		"TChorobei::TChorobei": 0x800b5658,
		"TCannonManager::createEnemyInstance": 0x800b576c,
		"TCannonManager::load": 0x800b57b0,
		"TCannonManager::TCannonManager": 0x800b5808,
		"TCannonSaveLoadParams::TCannonSaveLoadParams": 0x800b5844,
		"TCannon::isCollidMove": 0x800b5ae8,
		"TCannon::isHitVallid": 0x800b5af0,
		"isHitVallid": 0x800b5af0,
		"TCannon::isInhibitedForceMove": 0x800b5af8,
		"TCannonDom::~TCannonDom": 0x800b5b84,
		"TCannonManager::~TCannonManager": 0x800b5c8c,
		"TCannonManager::clipEnemies": 0x800b5d00,
		"Enemy::__sinit_cannon_cpp": 0x800b5d04,
		"__sinit_cannon_cpp": 0x800b5d04,
		"TNerveBossEelSleepOnBottom::~TNerveBossEelSleepOnBottom": 0x800b6010,
		"TNerveBossEelSleepOnBottom::execute": 0x800b606c,
		"TNerveBossEelSleepOnBottom::theNerve": 0x800b6200,
		"TNerveBossEelMouthOpenWait::execute": 0x800b6264,
		"TNerveBossEelEat::~TNerveBossEelEat": 0x800b676c,
		"TNerveBossEelMouthOpenWait::theNerve": 0x800b67c8,
		"TNerveBossEelMouthOpenWait::~TNerveBossEelMouthOpenWait": 0x800b682c,
		"TNerveBossEelDie::execute": 0x800b6888,
		"TNerveBossEelDie::theNerve": 0x800b6d0c,
		"TNerveBossEelDie::~TNerveBossEelDie": 0x800b6d70,
		"TNerveBossEelEat::execute": 0x800b6dcc,
		"TNerveBossEelQuickBack::~TNerveBossEelQuickBack": 0x800b7408,
		"TNerveBossEelEat::theNerve": 0x800b7464,
		"TNerveBossEelQuickBack::execute": 0x800b74c8,
		"TNerveBossEelQuickBack::theNerve": 0x800b75ec,
		"TNerveBossEelSlowBack::execute": 0x800b7650,
		"TNerveBossEelSlowBack::theNerve": 0x800b7678,
		"TNerveBossEelSlowBack::~TNerveBossEelSlowBack": 0x800b76dc,
		"Enemy::ExecBackNerve_Sub": 0x800b7738,
		"ExecBackNerve_Sub": 0x800b7738,
		"TNerveBossEelSecondSpin::~TNerveBossEelSecondSpin": 0x800b7ae0,
		"TNerveBossEelOutWait::execute": 0x800b7b3c,
		"TNerveBossEelOutWait::~TNerveBossEelOutWait": 0x800b80f0,
		"TNerveBossEelOutWait::theNerve": 0x800b814c,
		"TNerveBossEelAppear::execute": 0x800b81b0,
		"TNerveBossEelAppear::theNerve": 0x800b8500,
		"TNerveBossEelAppear::~TNerveBossEelAppear": 0x800b8564,
		"TNerveBossEelSecondSpin::execute": 0x800b85c0,
		"TNerveBossEelSecondSpin::theNerve": 0x800b89d0,
		"TNerveBossEelFirstSpin::execute": 0x800b8a34,
		"TNerveBossEelFirstSpin::theNerve": 0x800b8d7c,
		"TNerveBossEelFirstSpin::~TNerveBossEelFirstSpin": 0x800b8de0,
		"TNerveBossEelWaitAppear::execute": 0x800b8e3c,
		"TNerveBossEelWaitAppear::theNerve": 0x800b902c,
		"TNerveBossEelWaitAppear::~TNerveBossEelWaitAppear": 0x800b9090,
		"TBossEel::getBasNameTable": 0x800b90ec,
		"Enemy::hoseiDiveCameraCallback": 0x800b90f8,
		"hoseiDiveCameraCallback": 0x800b90f8,
		"TBossEel::isInBossEelMoguDemo": 0x800b9158,
		"isInBossEelMoguDemo": 0x800b9158,
		"TBossEel::perform": 0x800b91b4,
		"TBossEel::collideToMario": 0x800b9dec,
		"collideToMario": 0x800b9dec,
		"TBossEel::forceShedTears": 0x800ba1bc,
		"forceShedTears": 0x800ba1bc,
		"TBossEel::shedTears": 0x800ba2e0,
		"shedTears": 0x800ba2e0,
		"TBossEel::updateTearsCnt": 0x800ba448,
		"updateTearsCnt": 0x800ba448,
		"TBossEel::getTakingMtx": 0x800ba6dc,
		"TBossEel::init": 0x800ba6f0,
		"TBossEelTearsRecoverCollision::perform": 0x800bb274,
		"TBossEelTearsRecoverCollision::behaveToMario": 0x800bb324,
		"TBossEelTearsRecoverCollision::initCollision": 0x800bb368,
		"TBossEelBarrierCollision::behaveToMario": 0x800bb3bc,
		"TBossEelBarrierCollision::initCollision": 0x800bb428,
		"TBossEelAwaCollision::perform": 0x800bb47c,
		"TBossEelAwaCollision::behaveToMario": 0x800bb5b8,
		"TBossEelAwaCollision::initCollision": 0x800bb634,
		"TBossEelBodyCollision::initCollision": 0x800bb688,
		"TBossEelCollision::behaveToMario": 0x800bb6e4,
		"TBossEelCollision::initCollision": 0x800bb90c,
		"TBossEelCollision::perform": 0x800bb94c,
		"TNerveBEelTearsMarioRecover::~TNerveBEelTearsMarioRecover": 0x800bba28,
		"TBossEel::TBossEel": 0x800bba84,
		"TBossEelHeartCoin::generate": 0x800bbb6c,
		"TBossEelHeartCoin::perform": 0x800bbc38,
		"TBossEelEye::perform": 0x800bbe90,
		"TBossEelEye::TBossEelEye": 0x800bc140,
		"TBossEelVortex::reset": 0x800bc288,
		"TBossEelVortex::perform": 0x800bc2ac,
		"TBossEelTooth::perform": 0x800bc5fc,
		"TBossEelTooth::receiveMessage": 0x800bcc0c,
		"TBossEelTooth::TBossEelTooth": 0x800bcf40,
		"TBossEelManager::clipEnemies": 0x800bd168,
		"TBossEelManager::createModelData": 0x800bd190,
		"TBossEelManager::loadAfter": 0x800bd1c4,
		"TBossEelSaveParams::TBossEelSaveParams": 0x800bd468,
		"TNerveOilBallStay::execute": 0x800bdadc,
		"TNerveOilBallStay::theNerve": 0x800bdb68,
		"TNerveOilBallStay::~TNerveOilBallStay": 0x800bdbcc,
		"TOilBall::calcRootMatrix": 0x800bdc28,
		"TOilBall::moveObject": 0x800bdc48,
		"TNerveBEelTearsSplit::~TNerveBEelTearsSplit": 0x800bdfb4,
		"TNerveBEelTearsMoveUp::~TNerveBEelTearsMoveUp": 0x800be010,
		"TOilBall::reset": 0x800be06c,
		"TNerveBEelTearsGenerate::~TNerveBEelTearsGenerate": 0x800be1fc,
		"TOilBall::load": 0x800be258,
		"TNerveBEelTearsSplit::execute": 0x800be2b8,
		"TNerveBEelTearsSplit::theNerve": 0x800be508,
		"TNerveBEelTearsMarioRecover::execute": 0x800be56c,
		"TNerveBEelTearsMarioRecover::theNerve": 0x800be6cc,
		"TNerveBEelTearsWaterHit::execute": 0x800be730,
		"TNerveBEelTearsWaterHit::theNerve": 0x800be9f4,
		"TNerveBEelTearsWaterHit::~TNerveBEelTearsWaterHit": 0x800bea58,
		"TNerveBEelTearsMoveUp::execute": 0x800beab4,
		"TNerveBEelTearsMoveUp::theNerve": 0x800beb20,
		"TNerveBEelTearsGenerate::execute": 0x800beb84,
		"TNerveBEelTearsGenerate::theNerve": 0x800bec7c,
		"TBEelTears::getBasNameTable": 0x800bece0,
		"TBEelTears::reset": 0x800becec,
		"TBEelTears::kill": 0x800bedd8,
		"TBEelTears::receiveMessage": 0x800bee04,
		"TBEelTears::perform": 0x800bf000,
		"TBEelTears::calcRootMatrix": 0x800bf14c,
		"TBEelTears::moveObject": 0x800bf2b4,
		"TBEelTears::setMActorAndKeeper": 0x800bf67c,
		"TBEelTears::init": 0x800bf6fc,
		"TBEelTears::TBEelTears": 0x800bfa18,
		"TBEelTearsManager::splitTears": 0x800bfa78,
		"splitTears": 0x800bfa78,
		"TBEelTearsManager::createEnemies": 0x800bfcf4,
		"TBEelTearsManager::createEnemyInstance": 0x800bfdac,
		"TBEelTearsManager::perform": 0x800bfe24,
		"TBEelTearsManager::createModelData": 0x800bff20,
		"TBEelTearsManager::loadAfter": 0x800bff54,
		"TBEelTearsManager::load": 0x800c0018,
		"TBEelTearsManager::TBEelTearsManager": 0x800c0084,
		"TBEelTearsSaveLoadParams::TBEelTearsSaveLoadParams": 0x800c00c0,
		"TBEelTearsDrop::perform": 0x800c0468,
		"TBEelTearsDrop::TBEelTearsDrop": 0x800c05b8,
		"TBossEel::hasMapCollision": 0x800c0850,
		"TBossEel::receiveMessage": 0x800c0858,
		"TBossEelHeartCoin::~TBossEelHeartCoin": 0x800c0ad0,
		"TBossEelEye::~TBossEelEye": 0x800c0b54,
		"TBossEelManager::~TBossEelManager": 0x800c0ce0,
		"TBEelTearsManager::~TBEelTearsManager": 0x800c0e34,
		"Enemy::__sinit_bosseel_cpp": 0x800c0f1c,
		"__sinit_bosseel_cpp": 0x800c0f1c,
		"TNerveKillerExplosion::~TNerveKillerExplosion": 0x800c1270,
		"TNerveKillerExplosion::execute": 0x800c12cc,
		"TKiller::isFindMario": 0x800c1570,
		"TKiller::calcRootMatrix": 0x800c1628,
		"TKiller::bind": 0x800c19f0,
		"TNerveFlyEnemyChaseFly::~TNerveFlyEnemyChaseFly": 0x800c1de8,
		"TKiller::setColorType": 0x800c1e44,
		"setColorType": 0x800c1e44,
		"TKiller::reset": 0x800c1e88,
		"TKiller::changeOut": 0x800c1f9c,
		"TKiller::flyBehavior": 0x800c2090,
		"TKiller::isCollidMove": 0x800c2148,
		"TKiller::isRollFly": 0x800c22ac,
		"isRollFly": 0x800c22ac,
		"TKiller::setChaseFlyAnm": 0x800c2358,
		"TKiller::setNormalFlyAnm": 0x800c2388,
		"TKiller::getBasNameTable": 0x800c23ec,
		"TKiller::attackToMario": 0x800c23f8,
		"TKiller::setDeadAnm": 0x800c2548,
		"TKiller::isHitValid": 0x800c25ec,
		"TKiller::genEventCoin": 0x800c2660,
		"TKiller::behaveToWater": 0x800c2844,
		"TNerveFlyEnemyNormalFly::~TNerveFlyEnemyNormalFly": 0x800c2a54,
		"TKiller::setMActorAndKeeper": 0x800c2ab0,
		"TKiller::init": 0x800c2c04,
		"TKiller::TKiller": 0x800c2da4,
		"Enemy::KillerBodyCallback": 0x800c2eb4,
		"KillerBodyCallback": 0x800c2eb4,
		"TKillerManager::createEnemyInstance": 0x800c30ac,
		"TFlyEnemy::TFlyEnemy": 0x800c3114,
		"TKillerManager::createModelData": 0x800c3174,
		"TKillerManager::load": 0x800c31a8,
		"TKillerManager::TKillerManager": 0x800c33c8,
		"TNerveFlyEnemyChaseFly::execute": 0x800c340c,
		"TFlyEnemy::flyBehavior": 0x800c3954,
		"Enemy::MsSin": 0x800c3968,
		"MsSin": 0x800c3968,
		"Enemy::MsCos": 0x800c39a0,
		"MsCos": 0x800c39a0,
		"TFlyEnemy::setChaseFlyAnm": 0x800c3a20,
		"TNerveFlyEnemyNormalFly::execute": 0x800c3a24,
		"TFlyEnemy::setNormalFlyAnm": 0x800c3c74,
		"TFlyEnemy::bind": 0x800c3c78,
		"TFlyEnemy::calcChaseParam": 0x800c3d1c,
		"calcChaseParam": 0x800c3d1c,
		"TFlyEnemy::fly": 0x800c3f4c,
		"fly": 0x800c3f4c,
		"TFlyEnemy::reset": 0x800c4190,
		"TFlyEnemy::getGravityY": 0x800c41e0,
		"TFlyEnemy::init": 0x800c4270,
		"TKiller::forceKill": 0x800c42b4,
		"TFlyEnemy::setAfterDeadEffect": 0x800c42b8,
		"TKillerManager::~TKillerManager": 0x800c4358,
		"Enemy::__sinit_killer_cpp": 0x800c43cc,
		"__sinit_killer_cpp": 0x800c43cc,
		"TBeamManager::~TBeamManager": 0x800c46d8,
		"TBeamManager::perform": 0x800c474c,
		"TBeamManager::requestCone": 0x800c487c,
		"requestCone": 0x800c487c,
		"TBeamManager::setupMaterial": 0x800c4974,
		"setupMaterial": 0x800c4974,
		"TBeamManager::TBeamManager": 0x800c4a4c,
		"TConeBeam::drawConeBeam": 0x800c4af8,
		"drawConeBeam": 0x800c4af8,
		"TConeBeam::calcVertices": 0x800c4c74,
		"calcVertices": 0x800c4c74,
		"TConeBeam::drawConeBeamAux": 0x800c5304,
		"drawConeBeamAux": 0x800c5304,
		"TConeBeam::TConeBeam": 0x800c54d0,
		"TNerveSamboHeadHitWall::~TNerveSamboHeadHitWall": 0x800c5550,
		"TNerveSamboHeadHitWall::execute": 0x800c55ac,
		"TNerveSamboHeadRecoverWater::execute": 0x800c57c0,
		"TNerveSamboHeadRecoverWater::~TNerveSamboHeadRecoverWater": 0x800c584c,
		"TNerveSamboHeadHitWater::execute": 0x800c58a8,
		"TNerveSamboHeadAttack::~TNerveSamboHeadAttack": 0x800c5da8,
		"TNerveSamboHeadHitWater::~TNerveSamboHeadHitWater": 0x800c5e04,
		"TNerveSamboHeadHide::execute": 0x800c5e60,
		"TNerveSamboHeadAppear::~TNerveSamboHeadAppear": 0x800c60a0,
		"TNerveSamboHeadHide::~TNerveSamboHeadHide": 0x800c60fc,
		"TNerveSamboHeadAttack::execute": 0x800c6158,
		"TNerveSamboHeadAppear::execute": 0x800c64d8,
		"TSamboHead::getBasNameTable": 0x800c6758,
		"TSamboHead::genEventCoin": 0x800c6764,
		"TSamboHead::calcRootMatrix": 0x800c6a30,
		"TSamboHead::setAfterDeadEffect": 0x800c6a54,
		"TSamboHead::setDeadAnm": 0x800c6b84,
		"TSamboHead::getGravityY": 0x800c6bb4,
		"TSamboHead::attackToMario": 0x800c6cac,
		"TSamboHead::behaveToWater": 0x800c6e30,
		"TSamboHead::kill": 0x800c7158,
		"TSamboHead::reset": 0x800c7218,
		"TSamboHead::setMActorAndKeeper": 0x800c726c,
		"TSamboHead::init": 0x800c72d8,
		"TSamboHead::load": 0x800c7428,
		"TSamboHead::TSamboHead": 0x800c74e8,
		"TSamboHeadManager::createEnemyInstance": 0x800c7548,
		"TSamboHeadManager::createModelData": 0x800c75c0,
		"TSamboHeadManager::load": 0x800c75f4,
		"TSamboHeadManager::TSamboHeadManager": 0x800c788c,
		"Enemy::SamboHeadRollCallback": 0x800c78d0,
		"SamboHeadRollCallback": 0x800c78d0,
		"TNerveHanaSamboFreeze::execute": 0x800c7bd4,
		"TNerveHanaSamboFreeze::~TNerveHanaSamboFreeze": 0x800c7cd0,
		"TNerveHanaSamboDie::execute": 0x800c7d2c,
		"TNerveHanaSamboDie::~TNerveHanaSamboDie": 0x800c7f68,
		"TNerveHanaSamboHide::execute": 0x800c7fc4,
		"TNerveHanaSamboAppear::~TNerveHanaSamboAppear": 0x800c8258,
		"TNerveHanaSamboHide::~TNerveHanaSamboHide": 0x800c82b4,
		"TNerveHanaSamboAttack::execute": 0x800c8310,
		"TNerveHanaSamboWait::~TNerveHanaSamboWait": 0x800c8504,
		"TNerveHanaSamboAttack::~TNerveHanaSamboAttack": 0x800c8560,
		"TNerveHanaSamboWait::execute": 0x800c85bc,
		"TNerveHanaSamboAppear::execute": 0x800c87c8,
		"THanaSambo::createPollen": 0x800c8a18,
		"createPollen": 0x800c8a18,
		"THanaSambo::perform": 0x800c8bc0,
		"THanaSambo::getBasNameTable": 0x800c8c20,
		"THanaSambo::setDeadAnm": 0x800c8c2c,
		"THanaSambo::setWaitAnm": 0x800c8ccc,
		"THanaSambo::reset": 0x800c8d10,
		"THanaSambo::kill": 0x800c8d5c,
		"THanaSambo::drawObject": 0x800c8f1c,
		"THanaSambo::moveObject": 0x800c8f5c,
		"THanaSambo::setMActorAndKeeper": 0x800c90d8,
		"THanaSambo::init": 0x800c9158,
		"THanaSambo::load": 0x800c9408,
		"THanaSambo::THanaSambo": 0x800c94c8,
		"THanaSamboHead::receiveMessage": 0x800c9544,
		"THanaSamboManager::createModelData": 0x800c96bc,
		"THanaSamboManager::createEnemyInstance": 0x800c96f0,
		"THanaSamboManager::load": 0x800c9784,
		"THanaSamboManager::THanaSamboManager": 0x800c9998,
		"TSamboFlower::drawObject": 0x800c99d4,
		"TSamboFlower::moveObject": 0x800c9a8c,
		"TSamboFlower::reset": 0x800c9c34,
		"TSamboFlower::receiveMessage": 0x800c9ca0,
		"TSamboFlower::setMActorAndKeeper": 0x800c9d8c,
		"TSamboFlower::init": 0x800c9e24,
		"TSamboFlower::loadAfter": 0x800c9f38,
		"TSamboFlower::load": 0x800c9fbc,
		"TSamboFlowerManager::dropLeaf": 0x800ca03c,
		"dropLeaf": 0x800ca03c,
		"TSamboFlowerManager::perform": 0x800ca26c,
		"TSamboFlowerManager::loadAfter": 0x800ca324,
		"TSamboFlowerManager::createEnemyInstance": 0x800ca6dc,
		"TSamboFlowerManager::createModelData": 0x800ca78c,
		"TSamboFlowerManager::load": 0x800ca7c0,
		"TSamboFlowerSaveLoadParams::TSamboFlowerSaveLoadParams": 0x800ca82c,
		"TSamboLeaf::perform": 0x800caacc,
		"TSamboFlowerCoinUnit::checkGenCoin": 0x800cacf0,
		"checkGenCoin": 0x800cacf0,
		"TSamboHeadManager::~TSamboHeadManager": 0x800cb0e0,
		"THanaSambo::behaveToWater": 0x800cb154,
		"THanaSambo::isHitValid": 0x800cb158,
		"THanaSambo::isCollidMove": 0x800cb17c,
		"THanaSamboManager::~THanaSamboManager": 0x800cb28c,
		"TSamboFlower::control": 0x800cb300,
		"TSamboFlowerManager::~TSamboFlowerManager": 0x800cb370,
		"TSamboLeaf::~TSamboLeaf": 0x800cb3d4,
		"Enemy::__sinit_hanasambo_cpp": 0x800cb448,
		"__sinit_hanasambo_cpp": 0x800cb448,
		"TNervePopoThrown::~TNervePopoThrown": 0x800cb764,
		"TNervePopoThrown::execute": 0x800cb7c0,
		"TNervePopoWait::execute": 0x800cb858,
		"TNervePopoWait::~TNervePopoWait": 0x800cb948,
		"TNervePopoExplosion::execute": 0x800cb9a4,
		"TNervePopoExplosion::~TNervePopoExplosion": 0x800cbba8,
		"TNervePopoFly::execute": 0x800cbc04,
		"TNervePopoFly::~TNervePopoFly": 0x800cbee8,
		"TNervePopoAttack::execute": 0x800cbf44,
		"TNervePopoAttack::~TNervePopoAttack": 0x800cc0dc,
		"TNervePopoPossessedNozzle::execute": 0x800cc138,
		"TNervePopoPossessedNozzle::~TNervePopoPossessedNozzle": 0x800cc308,
		"TPopo::getBasNameTable": 0x800cc364,
		"TPopo::thrownByChorobei": 0x800cc370,
		"thrownByChorobei": 0x800cc370,
		"TPopo::possessedIn": 0x800cc3fc,
		"possessedIn": 0x800cc3fc,
		"TPopo::explosion": 0x800cc510,
		"explosion": 0x800cc510,
		"TPopo::flyBehavior": 0x800cc65c,
		"TPopo::isCollidMove": 0x800cc820,
		"TPopo::isFindMario": 0x800cc970,
		"TPopo::isHitValid": 0x800cca40,
		"TPopo::bind": 0x800ccb20,
		"TPopo::forceKill": 0x800ccf0c,
		"TPopo::kill": 0x800cd130,
		"TPopo::calcRootMatrix": 0x800cd190,
		"TPopo::attackToMario": 0x800cd654,
		"TPopo::walkBehavior": 0x800cd8fc,
		"TPopo::behaveToFindMario": 0x800cdddc,
		"TPopo::getGravityY": 0x800cdfc8,
		"TPopo::behaveToWater": 0x800ce17c,
		"TPopo::checkTrigger": 0x800ce424,
		"checkTrigger": 0x800ce424,
		"TPopo::reset": 0x800ce734,
		"TPopo::setMActorAndKeeper": 0x800ce878,
		"TPopo::perform": 0x800ce8f8,
		"TPopo::init": 0x800ce94c,
		"TPopo::load": 0x800ceb98,
		"TPopo::TPopo": 0x800cebf8,
		"Enemy::PopoNonScaleCallback": 0x800cec74,
		"PopoNonScaleCallback": 0x800cec74,
		"Enemy::PopoPossessedCallback": 0x800cee10,
		"PopoPossessedCallback": 0x800cee10,
		"Enemy::PopoRollCallback": 0x800cf1c0,
		"PopoRollCallback": 0x800cf1c0,
		"TPopoCollision::receiveMessage": 0x800cf3f0,
		"TPopoManager::perform": 0x800cf4cc,
		"TPopoManager::createModelData": 0x800cf58c,
		"TPopoManager::initSetEnemies": 0x800cf5c0,
		"TPopoManager::createEnemyInstance": 0x800cf600,
		"TPopoManager::load": 0x800cf644,
		"TPopoManager::TPopoManager": 0x800cf6e8,
		"TPopoSaveLoadParams::TPopoSaveLoadParams": 0x800cf740,
		"TPopoManager::~TPopoManager": 0x800cfb60,
		"Enemy::__sinit_popo_cpp": 0x800cfbd4,
		"__sinit_popo_cpp": 0x800cfbd4,
		"TNerveSBH_Fall::~TNerveSBH_Fall": 0x800cfee0,
		"TNerveSBH_Fall::execute": 0x800cff3c,
		"TNerveSBH_SleepContinue::~TNerveSBH_SleepContinue": 0x800d0078,
		"TNerveSBH_Fall::theNerve": 0x800d00d4,
		"TNerveSBH_SleepContinue::execute": 0x800d0138,
		"TNerveSBH_SleepContinue::theNerve": 0x800d0140,
		"TSleepBossHanachan::startFall": 0x800d01a4,
		"startFall": 0x800d01a4,
		"TSleepBossHanachan::getBasNameTable": 0x800d0290,
		"TSleepBossHanachan::calcRootMatrix": 0x800d0298,
		"TSleepBossHanachan::init": 0x800d029c,
		"TSleepBossHanachanManager::createModelData": 0x800d045c,
		"TSleepBossHanachanManager::~TSleepBossHanachanManager": 0x800d0514,
		"TDemoBossHanachan::receiveMessage": 0x800d05fc,
		"TDemoBossHanachan::initBase": 0x800d0604,
		"initBase": 0x800d0604,
		"TDemoBossHanachanManager::clipEnemies": 0x800d0704,
		"TDemoBossHanachanSaveParams::TDemoBossHanachanSaveParams": 0x800d0730,
		"TNerveFruitsBoatBckTrace::~TNerveFruitsBoatBckTrace": 0x800d0868,
		"TNerveFruitsBoatBckTrace::execute": 0x800d08c4,
		"TNerveFruitsBoatGraphWander::execute": 0x800d0a54,
		"TNerveFruitsBoatGraphWander::~TNerveFruitsBoatGraphWander": 0x800d0e78,
		"TFruitsBoatManager::createEnemyInstance": 0x800d0f1c,
		"TFruitsBoatManager::load": 0x800d0f24,
		"TFruitsBoatManager::createModelData": 0x800d1024,
		"TFruitsBoatManager::TFruitsBoatManager": 0x800d10c8,
		"TFruitsBoat::requestShadow": 0x800d1118,
		"TFruitsBoat::moveObject": 0x800d1278,
		"TFruitsBoat::calcRootMatrix": 0x800d1ab0,
		"TFruitsBoat::setGroundCollision": 0x800d1b60,
		"TFruitsBoat::receiveMessage": 0x800d1d04,
		"TFruitsBoat::init": 0x800d1d0c,
		"TFruitsBoat::load": 0x800d21b0,
		"TFruitsBoat::getRootJointMtx": 0x800d2308,
		"TFruitsBoat::setBckTrack": 0x800d2318,
		"setBckTrack": 0x800d2318,
		"TFruitsBoat::TFruitsBoat": 0x800d2430,
		"TFruitsBoatManager::~TFruitsBoatManager": 0x800d24b8,
		"Enemy::__sinit_fruitsboat_cpp": 0x800d2588,
		"__sinit_fruitsboat_cpp": 0x800d2588,
		"TSphereLink::setDegreeZAndRevisionPosXZ": 0x800d2910,
		"setDegreeZAndRevisionPosXZ": 0x800d2910,
		"TSphereLink::moveHead": 0x800d2b2c,
		"TBGCheckData::isIllegalData": 0x800d2f00,
		"isIllegalData": 0x800d2f00,
		"TSphereLink::TSphereLink": 0x800d2f1c,
		"TSpherePoint::TSpherePoint": 0x800d30fc,
		"TWaterHitActor::receiveMessage": 0x800d3100,
		"TWaterHitActor::onWaterHitCounter": 0x800d3170,
		"onWaterHitCounter": 0x800d3170,
		"Enemy::BHSCalcRevisionDistXZByRotateZ": 0x800d317c,
		"BHSCalcRevisionDistXZByRotateZ": 0x800d317c,
		"Enemy::BHSCalcCentrifugalForce": 0x800d3208,
		"BHSCalcCentrifugalForce": 0x800d3208,
		"TBossHanachan::hasMapCollision": 0x800d3560,
		"TBossHanachan::removeAllMapCollision": 0x800d3568,
		"removeAllMapCollision": 0x800d3568,
		"TBossHanachan::execDamage": 0x800d35ec,
		"execDamage": 0x800d35ec,
		"TBossHanachan::goToInitialRecoverGraphNode": 0x800d38cc,
		"goToInitialRecoverGraphNode": 0x800d38cc,
		"TBossHanachan::execSlip": 0x800d3964,
		"execSlip": 0x800d3964,
		"TBossHanachan::execWalk": 0x800d3d04,
		"TBossHanachan::getBodyMaxRotateZ": 0x800d3f08,
		"getBodyMaxRotateZ": 0x800d3f08,
		"TBossHanachan::checkFallDecideAndSetup": 0x800d4010,
		"checkFallDecideAndSetup": 0x800d4010,
		"TBossHanachan::isTumbleCompletelyAllBody": 0x800d4118,
		"isTumbleCompletelyAllBody": 0x800d4118,
		"TBossHanachan::perform": 0x800d4214,
		"TBossHanachan::moveObject": 0x800d5a3c,
		"TBossHanachan::bind": 0x800d5b10,
		"TBossHanachan::kill": 0x800d5e1c,
		"Enemy::CalcRevisionPosByRotateZ": 0x800d5e20,
		"CalcRevisionPosByRotateZ": 0x800d5e20,
		"TBossHanachan::throwMario_": 0x800d5ef0,
		"throwMario_": 0x800d5ef0,
		"TBossHanachan::init": 0x800d6270,
		"TBossHanachan::setRandomWeakBodyIndex": 0x800d67b8,
		"setRandomWeakBodyIndex": 0x800d67b8,
		"TBossHanachan::TBossHanachan": 0x800d6820,
		"TBossHanachanManager::hasMapCollision": 0x800d6908,
		"TBossHanachanManager::clipEnemies": 0x800d6910,
		"TBossHanachanManager::loadAfter": 0x800d693c,
		"TBossHanachanManager::createModelData": 0x800d69c8,
		"TBossHanachanManager::TBossHanachanManager": 0x800d6a20,
		"TBossHanachanManager::~TBossHanachanManager": 0x800d6b08,
		"Enemy::__sinit_BossHanachanMain_cpp": 0x800d6b74,
		"__sinit_BossHanachanMain_cpp": 0x800d6b74,
		"TNerveBossHanachanDead::~TNerveBossHanachanDead": 0x800d6e78,
		"TNerveBossHanachanDead::execute": 0x800d6ed4,
		"TNerveBossHanachanDead::theNerve": 0x800d6f40,
		"TNerveBossHanachanSnort::execute": 0x800d6fa4,
		"TNerveBossHanachanGraphWander::~TNerveBossHanachanGraphWander": 0x800d70fc,
		"TNerveBossHanachanSnort::theNerve": 0x800d7158,
		"TNerveBossHanachanSnort::~TNerveBossHanachanSnort": 0x800d71bc,
		"TNerveBossHanachanDamage::execute": 0x800d7218,
		"TNerveBossHanachanGetUp::~TNerveBossHanachanGetUp": 0x800d7310,
		"TNerveBossHanachanDamage::theNerve": 0x800d736c,
		"TNerveBossHanachanDamage::~TNerveBossHanachanDamage": 0x800d73d0,
		"TNerveBossHanachanGetUp::execute": 0x800d742c,
		"TNerveBossHanachanGetUp::theNerve": 0x800d7510,
		"TNerveBossHanachanDown::execute": 0x800d7574,
		"TNerveBossHanachanDown::theNerve": 0x800d7654,
		"TNerveBossHanachanDown::~TNerveBossHanachanDown": 0x800d76b8,
		"TNerveBossHanachanTumble::execute": 0x800d7714,
		"TNerveBossHanachanTumble::theNerve": 0x800d7834,
		"TNerveBossHanachanTumble::~TNerveBossHanachanTumble": 0x800d7898,
		"TNerveBossHanachanGraphWander::execute": 0x800d78f4,
		"TNerveBossHanachanGraphWander::theNerve": 0x800d79e4,
		"Enemy::__sinit_BossHanachanNerve_cpp": 0x800d7a48,
		"__sinit_BossHanachanNerve_cpp": 0x800d7a48,
		"TBossHanachan::changeAnmRateAndFrameUpdate_": 0x800d7d44,
		"changeAnmRateAndFrameUpdate_": 0x800d7d44,
		"TBossHanachan::isAllBckAlreadyEnd": 0x800d83b0,
		"isAllBckAlreadyEnd": 0x800d83b0,
		"TBossHanachan::isFinishedGetUp": 0x800d8468,
		"isFinishedGetUp": 0x800d8468,
		"TBossHanachan::considerSetAnm": 0x800d84c4,
		"considerSetAnm": 0x800d84c4,
		"TBossHanachan::setAnmTimerWhenDead": 0x800d8538,
		"setAnmTimerWhenDead": 0x800d8538,
		"TBossHanachan::setAnmTimerWhenDamage": 0x800d8684,
		"setAnmTimerWhenDamage": 0x800d8684,
		"TBossHanachan::setAnmTimerWhenSnort": 0x800d87d0,
		"setAnmTimerWhenSnort": 0x800d87d0,
		"TBossHanachan::setAnmTimerWhenGetUp": 0x800d8848,
		"setAnmTimerWhenGetUp": 0x800d8848,
		"TBossHanachan::setTumbleAnm": 0x800d88bc,
		"setTumbleAnm": 0x800d88bc,
		"TBossHanachan::setHeadAndBodyAnm": 0x800d8a60,
		"setHeadAndBodyAnm": 0x800d8a60,
		"TBossHanachanPartsHead::receiveMessage": 0x800d8c2c,
		"TBossHanachanPartsBody::receiveMessage": 0x800d8dc4,
		"TBossHanachanPartsHead::setAnm_": 0x800d8fe8,
		"TBossHanachanPartsBody::setAnm_": 0x800d9104,
		"TBossHanachanPartsBase::considerSetAnm_": 0x800d9238,
		"considerSetAnm_": 0x800d9238,
		"TBossHanachanPartsBase::calcRotateZWhenGetUp_": 0x800d996c,
		"calcRotateZWhenGetUp_": 0x800d996c,
		"TBossHanachanPartsBase::getSandActor_": 0x800d9a20,
		"getSandActor_": 0x800d9a20,
		"TBossHanachanPartsBase::copyFrameFromOldAnmToNewAnm_": 0x800d9a74,
		"copyFrameFromOldAnmToNewAnm_": 0x800d9a74,
		"TBossHanachanPartsBase::isCurBckAlreadyEnd_": 0x800d9b08,
		"isCurBckAlreadyEnd_": 0x800d9b08,
		"TBossHanachanPartsBase::setDamageFog_": 0x800d9be0,
		"setDamageFog_": 0x800d9be0,
		"TBossHanachanPartsBase::entryCircleShadow_": 0x800d9cd0,
		"entryCircleShadow_": 0x800d9cd0,
		"TBossHanachanPartsBase::moveMapCollision_": 0x800d9d98,
		"moveMapCollision_": 0x800d9d98,
		"TBossHanachanPartsBase::changeTumbleAnmRate_": 0x800d9de8,
		"changeTumbleAnmRate_": 0x800d9de8,
		"TBossHanachanPartsBody::initFootHitActor_": 0x800d9ea4,
		"initFootHitActor_": 0x800d9ea4,
		"TBossHanachanPartsBase::initMapCollisionAndHitActor_": 0x800da048,
		"initMapCollisionAndHitActor_": 0x800da048,
		"TBossHanachanPartsHead::TBossHanachanPartsHead": 0x800da268,
		"TBossHanachanPartsBody::TBossHanachanPartsBody": 0x800da394,
		"TBossHanachanPartsBase::TBossHanachanPartsBase": 0x800da498,
		"Enemy::CLBPalFrame": 0x800da7bc,
		"Enemy::__sinit_BossHanachanParts_cpp": 0x800da818,
		"__sinit_BossHanachanParts_cpp": 0x800da818,
		"TBossHanachanChangeSaveParams::TBossHanachanChangeSaveParams": 0x800dab2c,
		"TBossHanachanCommonSaveParams::TBossHanachanCommonSaveParams": 0x800db174,
		"TNerveAmiNokoFreeze::~TNerveAmiNokoFreeze": 0x800db6f4,
		"TNerveAmiNokoFreeze::execute": 0x800db750,
		"TNerveAmiNokoDie::execute": 0x800db86c,
		"TNerveAmiNokoDie::~TNerveAmiNokoDie": 0x800dbd14,
		"TNerveAmiNokoTurn::execute": 0x800dbd70,
		"TNerveAmiNokoWalkOnFence::~TNerveAmiNokoWalkOnFence": 0x800dc280,
		"TNerveAmiNokoTurn::~TNerveAmiNokoTurn": 0x800dc2dc,
		"TNerveAmiNokoWalkOnFence::execute": 0x800dc338,
		"TAmiNoko::getBasNameTable": 0x800dc7b0,
		"TAmiNoko::getGravityY": 0x800dc7bc,
		"TAmiNoko::perform": 0x800dc848,
		"TAmiNoko::bind": 0x800dc8c4,
		"TAmiNoko::calcRootMatrix": 0x800dcaf0,
		"TAmiNoko::isHitValid": 0x800dd6a8,
		"TAmiNoko::setWalkAnm": 0x800dd800,
		"TAmiNoko::attackToMario": 0x800dd854,
		"TAmiNoko::behaveToWater": 0x800dda7c,
		"TAmiNoko::reset": 0x800ddb9c,
		"TAmiNoko::setMActorAndKeeper": 0x800ddbbc,
		"TAmiNoko::init": 0x800ddc28,
		"TAmiNoko::load": 0x800dde4c,
		"TAmiNoko::TAmiNoko": 0x800dde94,
		"TAmiHit::perform": 0x800ddf3c,
		"TAmiHit::receiveMessage": 0x800de0f8,
		"TAmiNokoManager::createEnemyInstance": 0x800de128,
		"TAmiNokoManager::createModelData": 0x800de130,
		"TAmiNokoManager::load": 0x800de164,
		"TAmiNokoManager::TAmiNokoManager": 0x800de240,
		"TAmiNoko::isCollidMove": 0x800de318,
		"TAmiNokoManager::~TAmiNokoManager": 0x800de3a4,
		"Enemy::__sinit_amiNoko_cpp": 0x800de418,
		"__sinit_amiNoko_cpp": 0x800de418,
		"TNerveBGKLaunchName::~TNerveBGKLaunchName": 0x800de724,
		"TNerveBGKLaunchName::execute": 0x800de780,
		"TNerveBGKAppear::~TNerveBGKAppear": 0x800de8a4,
		"TNerveBGKLaunchGoro::execute": 0x800de900,
		"TNerveBGKSleep::~TNerveBGKSleep": 0x800dead4,
		"TNerveBGKLaunchGoro::~TNerveBGKLaunchGoro": 0x800deb30,
		"TNerveBGKDive::execute": 0x800deb8c,
		"TNerveBGKDive::~TNerveBGKDive": 0x800ded94,
		"TNerveBGKDie::execute": 0x800dedf0,
		"TNerveBGKDie::~TNerveBGKDie": 0x800df1fc,
		"TNerveBGKAwakeDamage::execute": 0x800df258,
		"TNerveBGKWait::~TNerveBGKWait": 0x800df458,
		"TNerveBGKWait2::~TNerveBGKWait2": 0x800df4b4,
		"TNerveBGKAwakeDamage::~TNerveBGKAwakeDamage": 0x800df510,
		"TNerveBGKSleepDamage::execute": 0x800df56c,
		"TNerveBGKSleepDamage::~TNerveBGKSleepDamage": 0x800df740,
		"TNerveBGKWait2::execute": 0x800df79c,
		"TNerveBGKWait::execute": 0x800dfb60,
		"TNerveBGKAppear::execute": 0x800e0120,
		"TNerveBGKSleep::execute": 0x800e03bc,
		"TBiancoGateKeeper::perform": 0x800e06b0,
		"TBiancoGateKeeper::controlCollision": 0x800e0a04,
		"TBiancoGateKeeper::emitParticles": 0x800e0b80,
		"emitParticles": 0x800e0b80,
		"TBiancoGateKeeper::getBasNameTable": 0x800e0d3c,
		"TBiancoGateKeeper::isDamageFogSituation": 0x800e0d48,
		"isDamageFogSituation": 0x800e0d48,
		"TBiancoGateKeeper::isHeadHitActive": 0x800e0eb4,
		"isHeadHitActive": 0x800e0eb4,
		"TBiancoGateKeeper::getRumblePow": 0x800e0fa0,
		"getRumblePow": 0x800e0fa0,
		"TBiancoGateKeeper::launchNamekuri": 0x800e107c,
		"launchNamekuri": 0x800e107c,
		"TBiancoGateKeeper::changeBck": 0x800e1378,
		"TBiancoGateKeeper::kill": 0x800e1634,
		"TBiancoGateKeeper::init": 0x800e1670,
		"TBiancoGateKeeper::TBiancoGateKeeper": 0x800e1dd0,
		"TBiancoGateKeeperManager::createModelData": 0x800e23bc,
		"TBiancoGateKeeperManager::load": 0x800e23f0,
		"TBiancoGateKeeperManager::initJParticle": 0x800e252c,
		"TBiancoGateKeeperManager::TBiancoGateKeeperManager": 0x800e26b0,
		"TGateKeeperBase::perform": 0x800e26ec,
		"TGateKeeperBase::receiveMessage": 0x800e2824,
		"TGateKeeperBase::kill": 0x800e28c4,
		"TGKHitObj::perform": 0x800e28d4,
		"TGKHitObj::receiveMessage": 0x800e2960,
		"TBGKMtxCalc::~TBGKMtxCalc": 0x800e2b20,
		"TBiancoGateKeeperManager::~TBiancoGateKeeperManager": 0x800e2bcc,
		"Enemy::__sinit_gatekeeper_cpp": 0x800e2cb4,
		"__sinit_gatekeeper_cpp": 0x800e2cb4,
		"TBossHanachan::emitCamShake_": 0x800e2fe4,
		"emitCamShake_": 0x800e2fe4,
		"TBossHanachan::emitOneTimeSandPillar_": 0x800e3278,
		"emitOneTimeSandPillar_": 0x800e3278,
		"TBossHanachan::emitParticle_": 0x800e33ac,
		"TBossHanachan::staticLoadParticle": 0x800e37c0,
		"staticLoadParticle": 0x800e37c0,
		"Enemy::__sinit_BossHanachanEffect_cpp": 0x800e3af4,
		"__sinit_BossHanachanEffect_cpp": 0x800e3af4,
		"TEggGenManager::~TEggGenManager": 0x800e3df0,
		"TEggGenManager::load": 0x800e3e54,
		"TEggGenManager::createModelData": 0x800e3ec0,
		"TEggGenManager::TEggGenManager": 0x800e3ef4,
		"TEggGenerator::control": 0x800e3f30,
		"TEggGenerator::init": 0x800e3fa8,
		"TEggGenerator::TEggGenerator": 0x800e4098,
		"TNerveSealDie::~TNerveSealDie": 0x800e4168,
		"TNerveSealDie::execute": 0x800e41c4,
		"TNerveSealSleep::~TNerveSealSleep": 0x800e43b0,
		"TNerveSealWait::execute": 0x800e440c,
		"TNerveSealWait::~TNerveSealWait": 0x800e4548,
		"TNerveSealSleep::execute": 0x800e45a4,
		"TSealManager::load": 0x800e46d0,
		"TSealManager::createModelData": 0x800e46f0,
		"TSealManager::TSealManager": 0x800e4724,
		"TSeal::perform": 0x800e4760,
		"TSeal::calcRootMatrix": 0x800e4884,
		"TSeal::receiveMessage": 0x800e4928,
		"TSeal::init": 0x800e4b28,
		"TSeal::TSeal": 0x800e4e00,
		"TSealManager::~TSealManager": 0x800e4e58,
		"Enemy::__sinit_seal_cpp": 0x800e4f28,
		"__sinit_seal_cpp": 0x800e4f28,
		"TBGPolDrop::perform": 0x800e5298,
		"TBGPolDrop::launch": 0x800e54cc,
		"TBGPolDrop::move": 0x800e5528,
		"TBGPolDrop::TBGPolDrop": 0x800e5778,
		"Enemy::__sinit_bgpoldrop_cpp": 0x800e5908,
		"__sinit_bgpoldrop_cpp": 0x800e5908,
		"TBGTentacle::~TBGTentacle": 0x800e5c0c,
		"TBGTentacle::perform": 0x800e5c80,
		"TBGTentacle::resetAllNodes": 0x800e6000,
		"resetAllNodes": 0x800e6000,
		"TBGTentacle::calcAttackGuideAnm": 0x800e6174,
		"calcAttackGuideAnm": 0x800e6174,
		"TBGTentacle::decideAtkColExists": 0x800e65f4,
		"decideAtkColExists": 0x800e65f4,
		"TBGTentacle::calcAtkParticleAndSE": 0x800e67b4,
		"calcAtkParticleAndSE": 0x800e67b4,
		"TBGTentacle::decideOwnState": 0x800e6c44,
		"decideOwnState": 0x800e6c44,
		"TBGTentacle::moveConstraint": 0x800e6f74,
		"moveConstraint": 0x800e6f74,
		"TBGTentacle::moveNode": 0x800e7400,
		"moveNode": 0x800e7400,
		"TBGTentacle::changeStateAndFixNodes": 0x800e7d60,
		"changeStateAndFixNodes": 0x800e7d60,
		"TBGTentacle::setAttackTarget": 0x800e802c,
		"setAttackTarget": 0x800e802c,
		"TBGTentacle::beatNode": 0x800e8498,
		"beatNode": 0x800e8498,
		"TBGTentacle::TBGTentacle": 0x800e8634,
		"TBGTentacle::TNode::calcPosition": 0x800e8ca4,
		"calcPosition": 0x800e8ca4,
		"TBGTentacle::TNode::calcVelocity": 0x800e8fec,
		"TBGTentacle::TNode::TNode": 0x800e93d4,
		"TBGAttackHit::perform": 0x800e9408,
		"TBGTakeHit::perform": 0x800e9820,
		"TBGTakeHit::receiveMessage": 0x800e9f58,
		"TBGTakeHit::moveRequest": 0x800ea0bc,
		"TBGTakeHit::getTakingMtx": 0x800ea3a4,
		"TBGTentacle::TTentacleParams::TTentacleParams": 0x800eab68,
		"Enemy::__sinit_bgtentacle_cpp": 0x800eb11c,
		"__sinit_bgtentacle_cpp": 0x800eb11c,
		"TEffectEnemy::setDeadAnm": 0x800eb54c,
		"TEffectEnemy::sendAttackMsgToMario": 0x800eb5c8,
		"TEffectEnemy::behaveToWater": 0x800eb64c,
		"TEffectEnemy::reset": 0x800eb68c,
		"TEffectEnemy::perform": 0x800eb6ac,
		"TEffectEnemy::forceKill": 0x800eb7fc,
		"TEffectEnemy::kill": 0x800eb924,
		"TEffectEnemy::setMActorAndKeeper": 0x800eb974,
		"TEffectEnemy::init": 0x800eb9e0,
		"TEffectEnemy::TEffectEnemy": 0x800eba18,
		"TEffectEnemyManager::initSetEnemies": 0x800eba64,
		"TEffectEnemyManager::createEnemyInstance": 0x800eba68,
		"TEffectEnemyManager::loadAfter": 0x800ebacc,
		"TEffectEnemyManager::load": 0x800ebaec,
		"TEffectEnemyManager::~TEffectEnemyManager": 0x800ebb44,
		"Enemy::__sinit_effectEnemy_cpp": 0x800ebbb8,
		"__sinit_effectEnemy_cpp": 0x800ebbb8,
		"TNerveHauntLegHaunt::~TNerveHauntLegHaunt": 0x800ebebc,
		"TNerveHauntLegHaunt::execute": 0x800ebf18,
		"THauntLeg::getTakingMtx": 0x800ec20c,
		"THauntLeg::getBasNameTable": 0x800ec2ac,
		"THauntLeg::isCollidMove": 0x800ec2b8,
		"THauntLeg::attackToMario": 0x800ec40c,
		"THauntLeg::setDeadAnm": 0x800ec45c,
		"THauntLeg::setRunAnm": 0x800ec4c4,
		"THauntLeg::setWalkAnm": 0x800ec4f4,
		"THauntLeg::setWaitAnm": 0x800ec524,
		"THauntLeg::setGenerateAnm": 0x800ec554,
		"THauntLeg::calcRootMatrix": 0x800ec584,
		"THauntLeg::reset": 0x800ec98c,
		"THauntLeg::setMActorAndKeeper": 0x800ec9c0,
		"THauntLeg::init": 0x800eca2c,
		"THauntedObject::receiveMessage": 0x800ecb98,
		"THauntLegManager::createModelData": 0x800ecbec,
		"THauntLegManager::initSetEnemies": 0x800ecc20,
		"THauntLegManager::createEnemyInstance": 0x800ecde4,
		"THauntLegManager::load": 0x800ece58,
		"THauntLegManager::THauntLegManager": 0x800eceb0,
		"Enemy::HauntLegCallback": 0x800ecef4,
		"HauntLegCallback": 0x800ecef4,
		"THauntLegManager::~THauntLegManager": 0x800ed184,
		"Enemy::__sinit_hauntLeg_cpp": 0x800ed1f8,
		"__sinit_hauntLeg_cpp": 0x800ed1f8,
		"TAreaCylinderManager::~TAreaCylinderManager": 0x800ed504,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::erase": 0x800ed610,
		"JGadget::TList<P13TAreaCylinder,Q27JGadget28TAllocator<P13TAreaCylinder>>::iterator::iterator": 0x800ed67c,
		"TAreaCylinderManager::perform": 0x800ed684,
		"TAreaCylinderManager::getCylinderContains": 0x800ed688,
		"getCylinderContains": 0x800ed688,
		"TAreaCylinderManager::contain": 0x800ed750,
		"contain": 0x800ed750,
		"JGadget::TList<TAreaCylinder*,JGadget::TAllocator<TAreaCylinder*>>::insert": 0x800ed81c,
		"TAreaCylinder::perform": 0x800ed8d4,
		"TAreaCylinder::load": 0x800ed8d8,
		"TAreaCylinder::TAreaCylinder": 0x800edb34,
		"TAreaCylinder::~TAreaCylinder": 0x800edbb0,
		"TNerveWireTrapGoWait::~TNerveWireTrapGoWait": 0x800edc24,
		"TNerveWireTrapGoWait::execute": 0x800edc80,
		"TNerveWireTrapWait::execute": 0x800edcd8,
		"TNerveWireTrapWait::~TNerveWireTrapWait": 0x800edcfc,
		"TNerveWireTrapSearch::execute": 0x800edd58,
		"TNerveWireTrapSearch::~TNerveWireTrapSearch": 0x800edfe0,
		"TNerveWireTrapOnewayMoveEnd::execute": 0x800ee03c,
		"TNerveWireTrapOnewayMoveEnd::~TNerveWireTrapOnewayMoveEnd": 0x800ee128,
		"TNerveWireTrapOnewayMove::execute": 0x800ee184,
		"TNerveWireTrapOnewayMoveStart::~TNerveWireTrapOnewayMoveStart": 0x800ee514,
		"TNerveWireTrapOnewayMove::~TNerveWireTrapOnewayMove": 0x800ee570,
		"TNerveWireTrapOnewayMoveStart::execute": 0x800ee5cc,
		"TNerveWireTrapReturnMove::execute": 0x800ee688,
		"TNerveWireTrapReturnMove::~TNerveWireTrapReturnMove": 0x800ee870,
		"TWireTrapManager::createModelData": 0x800ee8cc,
		"TWireTrapManager::load": 0x800ee900,
		"TWireTrapManager::TWireTrapManager": 0x800eea10,
		"TWireTrap::getWireBinder": 0x800eea4c,
		"getWireBinder": 0x800eea4c,
		"TWireTrap::getNerveFromMode": 0x800eea54,
		"getNerveFromMode": 0x800eea54,
		"TWireTrap::getWireDir": 0x800eeb78,
		"getWireDir": 0x800eeb78,
		"TWireTrap::checkHitActors": 0x800eeb84,
		"TWireBinder::getDir": 0x800ef124,
		"getDir": 0x800ef124,
		"TWireTrap::moveObject": 0x800ef12c,
		"TWireTrap::calcRootMatrix": 0x800ef1fc,
		"TWireTrap::kill": 0x800ef834,
		"TWireTrap::receiveMessage": 0x800ef93c,
		"TWireTrap::load": 0x800efb48,
		"TWireTrap::init": 0x800efd78,
		"TWireTrap::TWireTrap": 0x800eff20,
		"TWireTrapManager::~TWireTrapManager": 0x800eff70,
		"Enemy::__sinit_wireTrap_cpp": 0x800f0040,
		"__sinit_wireTrap_cpp": 0x800f0040,
		"TBossHanachanPartsBase::getBasNameTable": 0x800f0344,
		"TNerveRocketWait::~TNerveRocketWait": 0x800f0358,
		"TNerveRocketWait::execute": 0x800f03b4,
		"TNerveRocketFly::execute": 0x800f0404,
		"TNerveRocketFly::~TNerveRocketFly": 0x800f069c,
		"TNerveRocketPossessedNozzle::execute": 0x800f06f8,
		"TNerveRocketPossessedNozzle::~TNerveRocketPossessedNozzle": 0x800f0994,
		"TRocket::getBasNameTable": 0x800f09f0,
		"TRocket::isAttack": 0x800f09fc,
		"TRocket::isCollidMove": 0x800f0a88,
		"TRocket::getGravityY": 0x800f0b90,
		"TRocket::setDeadAnm": 0x800f0c28,
		"TRocket::bind": 0x800f0d14,
		"TRocket::behaveToWater": 0x800f0f5c,
		"TRocket::attackToMario": 0x800f0f88,
		"TRocket::reset": 0x800f10b4,
		"TRocket::setMActorAndKeeper": 0x800f1194,
		"TRocket::calcRootMatrix": 0x800f1200,
		"TRocket::init": 0x800f15cc,
		"TRocket::load": 0x800f1694,
		"TRocket::TRocket": 0x800f16f4,
		"TRocketManager::perform": 0x800f1744,
		"TRocketManager::createModelData": 0x800f17f8,
		"TRocketManager::initSetEnemies": 0x800f182c,
		"TRocketManager::createEnemyInstance": 0x800f1990,
		"TRocketManager::loadAfter": 0x800f19f8,
		"TRocketManager::load": 0x800f1a18,
		"TRocketManager::TRocketManager": 0x800f1b44,
		"TRocketManager::~TRocketManager": 0x800f1c18,
		"TRocketManager::clipEnemies": 0x800f1c8c,
		"Enemy::__sinit_rocket_cpp": 0x800f1c90,
		"__sinit_rocket_cpp": 0x800f1c90,
		"TNerveKazekunHitWater::~TNerveKazekunHitWater": 0x800f1f94,
		"TNerveKazekunHitWater::execute": 0x800f1ff0,
		"TNerveKazekunDisappear::~TNerveKazekunDisappear": 0x800f2154,
		"TNerveKazekunHitWater::theNerve": 0x800f21b0,
		"TNerveKazekunWait::execute": 0x800f2214,
		"TNerveKazekunSearch::~TNerveKazekunSearch": 0x800f2300,
		"TNerveKazekunWait::~TNerveKazekunWait": 0x800f235c,
		"TNerveKazekunDisappear::execute": 0x800f23b8,
		"TNerveKazekunAttack::execute": 0x800f24f4,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::getQuat": 0x800f2a88,
		"TNerveKazekunAttack::theNerve": 0x800f2d48,
		"TNerveKazekunAttack::~TNerveKazekunAttack": 0x800f2dac,
		"TNerveKazekunPreAttack::execute": 0x800f2e08,
		"TNerveKazekunPreAttack::theNerve": 0x800f3040,
		"TNerveKazekunPreAttack::~TNerveKazekunPreAttack": 0x800f30a4,
		"TNerveKazekunTurn::execute": 0x800f3100,
		"TNerveKazekunTurn::~TNerveKazekunTurn": 0x800f3338,
		"TNerveKazekunAppear::execute": 0x800f3394,
		"TNerveKazekunAppear::~TNerveKazekunAppear": 0x800f34ac,
		"TNerveKazekunSearch::execute": 0x800f3508,
		"TKazekunManager::createModelData": 0x800f3614,
		"TKazekunManager::load": 0x800f3648,
		"TKazekunManager::TKazekunManager": 0x800f36dc,
		"TKazekunParams::TKazekunParams": 0x800f3718,
		"TKazekun::doAttackPose": 0x800f3a18,
		"doAttackPose": 0x800f3a18,
		"TKazekun::flyAroundMario": 0x800f3f3c,
		"flyAroundMario": 0x800f3f3c,
		"TKazekun::setDeadAnm": 0x800f42d0,
		"TKazekun::isCollidMove": 0x800f4320,
		"TKazekun::attackToMario": 0x800f4328,
		"TKazekun::getBasNameTable": 0x800f4410,
		"TKazekun::behaveToWater": 0x800f441c,
		"TKazekun::bind": 0x800f4570,
		"TKazekun::calcRootMatrix": 0x800f45a4,
		"TKazekun::reset": 0x800f47e8,
		"TKazekun::init": 0x800f4860,
		"TKazekun::TKazekun": 0x800f4a64,
		"Enemy::SMS_CalcToDirMatrix": 0x800f4abc,
		"SMS_CalcToDirMatrix": 0x800f4abc,
		"TKazekunManager::~TKazekunManager": 0x800f4cf8,
		"Enemy::__sinit_Kazekun_cpp": 0x800f4df0,
		"__sinit_Kazekun_cpp": 0x800f4df0,
		"TBossMantaManager::~TBossMantaManager": 0x800f50f4,
		"TBossMantaParams::TBossMantaParams": 0x800f5158,
		"TBossMantaManager::spawn": 0x800f54a0,
		"spawn": 0x800f54a0,
		"TBossMantaManager::createEnemies": 0x800f569c,
		"TBossMantaManager::setupEfbAlpha": 0x800f57f0,
		"setupEfbAlpha": 0x800f57f0,
		"TBossMantaManager::perform": 0x800f5aa4,
		"TBossMantaManager::updateMantaEscape": 0x800f5b38,
		"updateMantaEscape": 0x800f5b38,
		"TBossMantaManager::drawMantaShadow": 0x800f5c90,
		"drawMantaShadow": 0x800f5c90,
		"TBossMantaManager::createEnemyInstance": 0x800f6340,
		"TBossMantaManager::createModelData": 0x800f6388,
		"TBossMantaManager::loadAfter": 0x800f63bc,
		"TBossMantaManager::load": 0x800f6568,
		"TBossMantaManager::TBossMantaManager": 0x800f65d4,
		"TBossMantaAdditionalCollision::perform": 0x800f66a8,
		"TBossMantaAdditionalCollision::receiveMessage": 0x800f6848,
		"TBossMantaAdditionalCollisionSet::update": 0x800f6888,
		"TBossMantaAdditionalCollisionSet::adapt": 0x800f6a68,
		"adapt": 0x800f6a68,
		"TBossMantaAdditionalCollisionSet::TBossMantaAdditionalCollisionSet": 0x800f6b3c,
		"TBossMantaManager::TMantaMessageState::update": 0x800f6ca4,
		"TNerveMantaSpawn::~TNerveMantaSpawn": 0x800f6e64,
		"TBossMantaManager::TMantaBattleState::update": 0x800f6ec0,
		"TBossManta::updateAttractor": 0x800f71d4,
		"updateAttractor": 0x800f71d4,
		"TBossManta::getPolluteRadius": 0x800f78a4,
		"getPolluteRadius": 0x800f78a4,
		"TNerveMantaMove::~TNerveMantaMove": 0x800f7920,
		"TBossManta::calcRootMatrix": 0x800f797c,
		"TBossManta::control": 0x800f7a9c,
		"TBossManta::initNthGeneration": 0x800f7cf8,
		"initNthGeneration": 0x800f7cf8,
		"TNerveMantaAppearDemo::~TNerveMantaAppearDemo": 0x800f84a0,
		"TBossManta::receiveMessage": 0x800f84fc,
		"TBossManta::collidedWithWater": 0x800f854c,
		"collidedWithWater": 0x800f854c,
		"TNerveMantaDeath::~TNerveMantaDeath": 0x800f89d8,
		"TNerveMantaHitWater::~TNerveMantaHitWater": 0x800f8a34,
		"TBossManta::moveObject": 0x800f8a90,
		"TBossManta::init": 0x800f8c70,
		"TBossManta::getIntoGraphVec": 0x800f8f04,
		"getIntoGraphVec": 0x800f8f04,
		"TBossManta::TBossManta": 0x800f9194,
		"TNerveMantaAppearDemo::execute": 0x800f9230,
		"TNerveMantaDeath::execute": 0x800f93dc,
		"TNerveMantaSpawn::execute": 0x800f94c8,
		"TNerveMantaHitWater::execute": 0x800f9664,
		"TNerveMantaMove::execute": 0x800f9854,
		"TNerveMantaHitWater::theNerve": 0x800fa208,
		"TBossManta::drawObject": 0x800fa35c,
		"TBossManta::reset": 0x800fa360,
		"Enemy::__sinit_bossManta_cpp": 0x800fa364,
		"__sinit_bossManta_cpp": 0x800fa364,
		"TWireBinder::~TWireBinder": 0x800fa670,
		"TWireBinder::isEndWire": 0x800fa6d4,
		"isEndWire": 0x800fa6d4,
		"TWireBinder::isOnWire": 0x800fa73c,
		"isOnWire": 0x800fa73c,
		"TWireBinder::getDirAtPos": 0x800fa810,
		"getDirAtPos": 0x800fa810,
		"TWireBinder::bind": 0x800fa94c,
		"TMapWireManager::getWire": 0x800fac04,
		"getWire": 0x800fac04,
		"TWireBinder::init": 0x800fac14,
		"TNerveYumboFreeze::~TNerveYumboFreeze": 0x800fad20,
		"TNerveYumboFreeze::execute": 0x800fad7c,
		"TNerveYumboDancing::~TNerveYumboDancing": 0x800faeac,
		"TNerveYumboAttack::execute": 0x800faf08,
		"TNerveYumboAppearing::~TNerveYumboAppearing": 0x800fb138,
		"TNerveYumboAttack::theNerve": 0x800fb194,
		"TNerveYumboAttack::~TNerveYumboAttack": 0x800fb1f8,
		"TNerveYumboAppearing::execute": 0x800fb254,
		"TNerveYumboHiding::execute": 0x800fb484,
		"TNerveYumboHiding::theNerve": 0x800fb630,
		"TNerveYumboHiding::~TNerveYumboHiding": 0x800fb694,
		"TNerveYumboDancing::execute": 0x800fb6f0,
		"TYumbo::getBasNameTable": 0x800fb9a0,
		"TYumboManager::createModelData": 0x800fb9ac,
		"TYumboManager::load": 0x800fb9e0,
		"TYumboManager::TYumboManager": 0x800fbbac,
		"TYumbo::attackToMario": 0x800fbbf0,
		"TYumbo::doKeepDistance": 0x800fbc9c,
		"TYumbo::setDeadAnm": 0x800fbd2c,
		"TYumbo::shotSeeds": 0x800fbd5c,
		"shotSeeds": 0x800fbd5c,
		"TYumbo::behaveToWater": 0x800fc254,
		"TYumbo::perform": 0x800fc3ac,
		"TYumbo::moveObject": 0x800fc42c,
		"TYumbo::receiveMessage": 0x800fc630,
		"TYumbo::reset": 0x800fc738,
		"TYumbo::init": 0x800fc73c,
		"TYumbo::TYumbo": 0x800fc978,
		"TYumboSeed::perform": 0x800fc9c8,
		"TYumboSeed::init": 0x800fcbcc,
		"TYumboManager::~TYumboManager": 0x800fcd24,
		"Enemy::__sinit_yunbo_cpp": 0x800fce1c,
		"__sinit_yunbo_cpp": 0x800fce1c,
		"TKoopaJrSubmarineManager::~TKoopaJrSubmarineManager": 0x800fd128,
		"TKoopaJrSubmarineManager::createEnemyInstance": 0x800fd18c,
		"TKoopaJrSubmarineManager::loadAfter": 0x800fd1d4,
		"TKoopaJrSubmarineManager::load": 0x800fd208,
		"TKoopaJrSubmarineManager::createModelData": 0x800fd274,
		"TKoopaJrSubmarineManager::TKoopaJrSubmarineManager": 0x800fd2a8,
		"TNerveKoopaJrSubmarineLaunchKiller::execute": 0x800fd2e4,
		"TNerveKoopaJrSubmarineLaunchKiller::~TNerveKoopaJrSubmarineLaunchKiller": 0x800fd348,
		"TNerveKoopaJrSubmarineCannonOpenClose::execute": 0x800fd3a4,
		"TNerveKoopaJrSubmarineCannonOpenClose::~TNerveKoopaJrSubmarineCannonOpenClose": 0x800fd40c,
		"TNerveKoopaJrSubmarineWait::execute": 0x800fd468,
		"TNerveKoopaJrSubmarineWait::~TNerveKoopaJrSubmarineWait": 0x800fd4f0,
		"TKoopaJrSubmarine::checkNerve": 0x800fd54c,
		"checkNerve": 0x800fd54c,
		"TNerveKoopaJrWait::~TNerveKoopaJrWait": 0x800fd8c4,
		"JGeometry::TUtil<float><float>::mod": 0x800fd920,
		"TKoopaJrSubmarine::makeRoundVelocity": 0x800fd97c,
		"makeRoundVelocity": 0x800fd97c,
		"TKoopaJrSubmarine::makeRelativeAngle": 0x800fdc58,
		"makeRelativeAngle": 0x800fdc58,
		"TKoopaJrSubmarine::getBasNameTable": 0x800fde50,
		"TKoopaJrSubmarine::makeKillerVelocity": 0x800fde58,
		"makeKillerVelocity": 0x800fde58,
		"TKoopaJrSubmarine::launchKiller": 0x800fe564,
		"TKoopaJrSubmarine::appearShineKiller": 0x800fe69c,
		"appearShineKiller": 0x800fe69c,
		"TKoopaJrSubmarine::receiveMessage": 0x800fe7e0,
		"TKoopaJrSubmarine::calcRootMatrix": 0x800fe860,
		"TKoopaJrSubmarine::bind": 0x800fecec,
		"TKoopaJrSubmarine::moveSwing": 0x800fede0,
		"moveSwing": 0x800fede0,
		"TKoopaJrSubmarine::makeCollisionPositions": 0x800ff0b8,
		"makeCollisionPositions": 0x800ff0b8,
		"TKoopaJrSubmarine::perform": 0x800ff194,
		"TKoopaJrSubmarine::resetKoopaJrSubmarine": 0x800ff334,
		"resetKoopaJrSubmarine": 0x800ff334,
		"TKoopaJrSubmarine::reset": 0x800ff458,
		"TKoopaJrSubmarine::init": 0x800ff48c,
		"TKoopaJrSubmarine::TKoopaJrSubmarine": 0x800ff8d4,
		"TKoopaJrManager::createEnemyInstance": 0x800ff948,
		"TKoopaJrManager::loadAfter": 0x800ff950,
		"TKoopaJrManager::load": 0x800ff9ac,
		"TKoopaJrManager::createModelData": 0x800ffa04,
		"TKoopaJrManager::TKoopaJrManager": 0x800ffa38,
		"TNerveKoopaJrYahoo::execute": 0x800ffa74,
		"TNerveKoopaJrYahoo::~TNerveKoopaJrYahoo": 0x800ffb04,
		"TNerveKoopaJrLaunch::execute": 0x800ffb60,
		"TNerveKoopaJrLaunch::~TNerveKoopaJrLaunch": 0x800ffbf0,
		"TNerveKoopaJrDemo::execute": 0x800ffc4c,
		"TNerveKoopaJrDemo::~TNerveKoopaJrDemo": 0x800ffcc0,
		"TNerveKoopaJrDamage::execute": 0x800ffd1c,
		"TNerveKoopaJrDamage::theNerve": 0x800ffdb8,
		"TNerveKoopaJrDamage::~TNerveKoopaJrDamage": 0x800ffe1c,
		"TNerveKoopaJrWait::execute": 0x800ffe78,
		"TKoopaJr::checkNerveKillerHit": 0x800fff24,
		"checkNerveKillerHit": 0x800fff24,
		"TKoopaJr::checkNerveKillerLaunchFast": 0x80100050,
		"checkNerveKillerLaunchFast": 0x80100050,
		"TKoopaJr::checkNerveKillerLaunchNormal": 0x80100274,
		"checkNerveKillerLaunchNormal": 0x80100274,
		"TSpineBase<TLiveActor>::pushNerve": 0x80100498,
		"pushNerve": 0x80100498,
		"TKoopaJr::receiveMessage": 0x801004ec,
		"TKoopaJr::getBasNameTable": 0x801006ec,
		"TKoopaJr::calcRootMatrix": 0x801006f8,
		"TKoopaJr::perform": 0x801007f4,
		"TKoopaJr::reset": 0x80100cc4,
		"TKoopaJr::init": 0x80100d30,
		"TKoopaJr::TKoopaJr": 0x80100f78,
		"TCallbackHitActor::receiveMessage": 0x80100fec,
		"TKoopaJrSubmarineParams::TKoopaJrSubmarineParams": 0x8010101c,
		"TKoopaJrParams::TKoopaJrParams": 0x80101588,
		"TDirectionCalc::d2r": 0x80101788,
		"d2r": 0x80101788,
		"TDirectionCalc::absDirection": 0x8010179c,
		"absDirection": 0x8010179c,
		"TDirectionCalc::calcTurnDirection": 0x80101840,
		"calcTurnDirection": 0x80101840,
		"TDirectionCalc::calcNearerDirection": 0x80101944,
		"calcNearerDirection": 0x80101944,
		"TKoopaJrManager::~TKoopaJrManager": 0x80101aa4,
		"Enemy::__sinit_koopajr_cpp": 0x80101bf8,
		"__sinit_koopajr_cpp": 0x80101bf8,
		"TNerveKumokunPreFly::~TNerveKumokunPreFly": 0x80101f0c,
		"TNerveKumokunPreFly::execute": 0x80101f68,
		"TNerveKumokunFly::~TNerveKumokunFly": 0x801020a4,
		"TNerveKumokunFly::execute": 0x80102100,
		"TBGCheckData::getNormal": 0x8010253c,
		"getNormal": 0x8010253c,
		"TNerveKumokunPostFreeze::execute": 0x80102544,
		"TNerveKumokunSearch::~TNerveKumokunSearch": 0x80102704,
		"TNerveKumokunPostFreeze::~TNerveKumokunPostFreeze": 0x80102760,
		"TNerveKumokunFreeze::execute": 0x801027bc,
		"TNerveKumokunFreeze::~TNerveKumokunFreeze": 0x80102a2c,
		"TNerveKumokunWait::execute": 0x80102a88,
		"JGeometry::TQuat4<float><float>::rotate": 0x80102e8c,
		"rotate": 0x80102e8c,
		"JGeometry::TVec3<float><float>::negate": 0x80102f24,
		"negate": 0x80102f24,
		"JGeometry::TVec4<float><float>::xyz": 0x80102f4c,
		"xyz": 0x80102f4c,
		"TKumokun::getQuat": 0x80102f74,
		"TNerveKumokunWait::theNerve": 0x80102f7c,
		"TNerveKumokunWait::~TNerveKumokunWait": 0x80102fe0,
		"TNerveKumokunSearch::execute": 0x8010303c,
		"TNerveKumokunPreWalk::~TNerveKumokunPreWalk": 0x80103614,
		"TNerveKumokunSearch::theNerve": 0x80103684,
		"TNerveKumokunPostWalk::execute": 0x801036e8,
		"TNerveKumokunPostWalk::theNerve": 0x801038a8,
		"TNerveKumokunPostWalk::~TNerveKumokunPostWalk": 0x8010390c,
		"TNerveKumokunWalk::execute": 0x80103968,
		"TNerveKumokunWalk::~TNerveKumokunWalk": 0x80103b6c,
		"TNerveKumokunPreWalk::execute": 0x80103bc8,
		"TNerveKumokunPreWalk::theNerve": 0x80103da4,
		"TKumokunManager::createModelData": 0x80103e08,
		"TKumokunManager::load": 0x80103e3c,
		"TKumokunManager::TKumokunManager": 0x80104024,
		"TKumokun::getPlaneNormal": 0x80104060,
		"getPlaneNormal": 0x80104060,
		"TKumokun::isCollidMove": 0x8010409c,
		"TKumokun::doKeepDistance": 0x801040a4,
		"TKumokun::isAttack": 0x80104444,
		"TKumokun::isOnSamePlaneWithMario": 0x801045d4,
		"isOnSamePlaneWithMario": 0x801045d4,
		"TKumokun::rotateGoalDirToLocal": 0x80104958,
		"rotateGoalDirToLocal": 0x80104958,
		"TKumokun::decideTargetAtDir": 0x80104a9c,
		"decideTargetAtDir": 0x80104a9c,
		"TKumokun::attackToMario": 0x80104dc4,
		"TKumokun::calcRootMatrix": 0x80104f84,
		"TKumokun::setDeadAnm": 0x8010531c,
		"TKumokun::changeBck": 0x8010555c,
		"TKumokun::behaveToWater": 0x80105664,
		"TKumokun::receiveMessage": 0x80105710,
		"TKumokun::control": 0x80105b94,
		"TKumokun::moveObject": 0x80105bdc,
		"TKumokun::bindOnFlying": 0x80105cc0,
		"bindOnFlying": 0x80105cc0,
		"TKumokun::checkOnMovingRoof": 0x80105f7c,
		"checkOnMovingRoof": 0x80105f7c,
		"TKumokun::checkOnMovingFloor": 0x80106314,
		"checkOnMovingFloor": 0x80106314,
		"TKumokun::checkOnMovingWall": 0x801065a8,
		"checkOnMovingWall": 0x801065a8,
		"TKumokun::bind": 0x8010691c,
		"TKumokun::reset": 0x80107010,
		"TKumokun::initAttachPlane": 0x80107014,
		"initAttachPlane": 0x80107014,
		"TKumokun::init": 0x8010742c,
		"TKumokun::getBasNameTable": 0x8010760c,
		"TKumokun::TKumokun": 0x80107684,
		"TSolidStack<char_const*>::~TSolidStack": 0x80107714,
		"TWallAtGraph::init": 0x80107760,
		"JGeometry::TPartition3<float><float>::TPartition3": 0x80107a80,
		"TPartition3": 0x80107a80,
		"TKumokunManager::~TKumokunManager": 0x80107a84,
		"TKoopaManager::~TKoopaManager": 0x80107b9c,
		"TKoopaManager::loadAfter": 0x80107c00,
		"TKoopaManager::load": 0x80107d58,
		"TKoopaManager::createModelData": 0x80108354,
		"TKoopaManager::createEnemyInstance": 0x80108388,
		"TKoopaManager::TKoopaManager": 0x80108390,
		"TKoopa::calcRootMatrix": 0x801083cc,
		"TKoopa::receiveMessage": 0x801086d8,
		"TKoopa::perform": 0x801086f8,
		"TNerveKoopaTumble::~TNerveKoopaTumble": 0x80108bbc,
		"TNerveKoopaTurn::~TNerveKoopaTurn": 0x80108c28,
		"TKoopa::reset": 0x80108c84,
		"TKoopa::getBasNameTable": 0x80108d68,
		"TKoopa::init": 0x80108d74,
		"TNerveKoopaProvoke::~TNerveKoopaProvoke": 0x801091b0,
		"TKoopa::loadAfter": 0x8010920c,
		"TKoopa::load": 0x8010942c,
		"TKoopa::TKoopa": 0x8010944c,
		"TKoopa::updateAnmSound": 0x801094b4,
		"TKoopa::fall": 0x8010957c,
		"fall": 0x8010957c,
		"TNerveKoopaFall::~TNerveKoopaFall": 0x80109614,
		"TKoopa::getTargetDir": 0x80109670,
		"getTargetDir": 0x80109670,
		"TKoopa::stagger": 0x8010976c,
		"stagger": 0x8010976c,
		"TNerveKoopaStagger::~TNerveKoopaStagger": 0x80109a60,
		"TNerveKoopaGetShowered::~TNerveKoopaGetShowered": 0x80109abc,
		"TNerveKoopaGetDown::~TNerveKoopaGetDown": 0x80109b18,
		"TNerveKoopaFlame::~TNerveKoopaFlame": 0x80109b74,
		"TKoopa::getShowered": 0x80109be0,
		"getShowered": 0x80109be0,
		"TNerveKoopaWait::~TNerveKoopaWait": 0x8010a020,
		"TKoopa::effectsTumble": 0x8010a08c,
		"effectsTumble": 0x8010a08c,
		"TKoopa::getDown": 0x8010a138,
		"getDown": 0x8010a138,
		"TKoopa::allowsLaunch": 0x8010a480,
		"allowsLaunch": 0x8010a480,
		"TKoopa::getNeckFocus": 0x8010a518,
		"getNeckFocus": 0x8010a518,
		"TKoopa::isFlaming": 0x8010a804,
		"isFlaming": 0x8010a804,
		"TKoopa::getFlameDirRate": 0x8010a84c,
		"getFlameDirRate": 0x8010a84c,
		"TKoopa::changeAnm": 0x8010a9ac,
		"changeAnm": 0x8010a9ac,
		"TKoopa::setUpHitActors": 0x8010aa8c,
		"TKoopa::getFlameDirDegree": 0x8010b8f8,
		"getFlameDirDegree": 0x8010b8f8,
		"TKoopaBody::attack_": 0x8010b954,
		"TKoopaBody::receiveMessage": 0x8010b9cc,
		"TKoopaHead::attack_": 0x8010bc80,
		"TKoopaHead::receiveMessage": 0x8010bcf8,
		"TKoopaHand::attack_": 0x8010c010,
		"TKoopaHand::receiveMessage": 0x8010c04c,
		"TKoopaFlame::attack_": 0x8010c054,
		"TKoopaFlame::receiveMessage": 0x8010c118,
		"TKoopaFlame::control": 0x8010c134,
		"TKoopaParts::perform": 0x8010c224,
		"TKoopaParts::control": 0x8010c2bc,
		"TKoopaParts::TKoopaParts": 0x8010c2c0,
		"TNerveKoopaGetDown::execute": 0x8010c418,
		"TNerveKoopaGetShowered::execute": 0x8010c7a0,
		"TNerveKoopaStagger::execute": 0x8010c89c,
		"TNerveKoopaProvoke::execute": 0x8010c998,
		"TNerveKoopaFlame::execute": 0x8010cb00,
		"TNerveKoopaTurnR::~TNerveKoopaTurnR": 0x8010d5b4,
		"TNerveKoopaTurnL::~TNerveKoopaTurnL": 0x8010d620,
		"TEnemyManager::getSaveParam": 0x8010d68c,
		"TNerveKoopaFall::execute": 0x8010d6a4,
		"TNerveKoopaTumble::execute": 0x8010d778,
		"TNerveKoopaWait::execute": 0x8010d92c,
		"TNerveKoopaTurnR::execute": 0x8010e208,
		"TNerveKoopaTurnL::execute": 0x8010e398,
		"Enemy::__sinit_Koopa_cpp": 0x8010e80c,
		"__sinit_Koopa_cpp": 0x8010e80c,
		"TNerveKukkuRecoverGraph::~TNerveKukkuRecoverGraph": 0x8010eb38,
		"TNerveKukkuRecoverGraph::execute": 0x8010eb94,
		"TNerveKukkuGraphWander::~TNerveKukkuGraphWander": 0x8010ed00,
		"TNerveKukkuPostFall::execute": 0x8010ed5c,
		"TNerveKukkuPostFall::theNerve": 0x8010ee98,
		"TNerveKukkuPostFall::~TNerveKukkuPostFall": 0x8010eefc,
		"TNerveKukkuFall::execute": 0x8010ef58,
		"TNerveKukkuFall::theNerve": 0x8010f1f0,
		"TNerveKukkuFall::~TNerveKukkuFall": 0x8010f254,
		"TNerveKukkuGraphWander::execute": 0x8010f2b0,
		"TKukku::getBasNameTable": 0x8010f698,
		"TKukkuManager::createModelData": 0x8010f6a4,
		"TKukkuManager::load": 0x8010f6d8,
		"TKukkuManager::TKukkuManager": 0x8010f978,
		"TKukku::setAfterDeadEffect": 0x8010f9b4,
		"TKukku::setDeadAnm": 0x8010fa00,
		"TKukku::dropCoins": 0x8010fa40,
		"dropCoins": 0x8010fa40,
		"TKukku::calcMomentum": 0x8010fe80,
		"calcMomentum": 0x8010fe80,
		"TKukku::updateRotation": 0x8010ff9c,
		"updateRotation": 0x8010ff9c,
		"TKukku::behaveToWater": 0x801101e4,
		"TKukku::perform": 0x80110394,
		"TKukku::bind": 0x80110414,
		"TKukku::calcRootMatrix": 0x80110434,
		"TKukku::control": 0x8011080c,
		"TKukku::receiveMessage": 0x80110844,
		"TKukku::reset": 0x801108d4,
		"TKukku::init": 0x80110904,
		"TKukku::TKukku": 0x80110b80,
		"TKukkuBall::perform": 0x80110bcc,
		"TKukkuBall::init": 0x80110e70,
		"TKukkuManager::~TKukkuManager": 0x80111014,
		"Enemy::__sinit_Kukku_cpp": 0x8011110c,
		"__sinit_Kukku_cpp": 0x8011110c,
		"TNerveAmenboHitWater::~TNerveAmenboHitWater": 0x80111418,
		"TNerveAmenboHitWater::execute": 0x80111474,
		"TNerveAmenboSearch::~TNerveAmenboSearch": 0x8011170c,
		"TNerveAmenboWalk::execute": 0x80111768,
		"TNerveAmenboWalk::~TNerveAmenboWalk": 0x80111ac0,
		"TNerveAmenboPreAttack::execute": 0x80111b1c,
		"TNerveAmenboPreAttack::~TNerveAmenboPreAttack": 0x80111c9c,
		"TNerveAmenboTurn::execute": 0x80111cf8,
		"TNerveAmenboTurn::~TNerveAmenboTurn": 0x80111fb8,
		"TNerveAmenboSearch::execute": 0x80112014,
		"JGeometry::TVec4<float><float>::operator_=": 0x801125a8,
		"TAmenbo::getQuat": 0x801125cc,
		"TAmenbo::getBasNameTable": 0x80112688,
		"TAmenboManager::createModelData": 0x80112694,
		"TAmenboManager::load": 0x801126c8,
		"TAmenboManager::TAmenboManager": 0x8011293c,
		"TAmenbo::deactivateJumpBase": 0x80112978,
		"deactivateJumpBase": 0x80112978,
		"TAmenbo::isFindOutMario": 0x80112a18,
		"isFindOutMario": 0x80112a18,
		"TAmenbo::changeByJuice": 0x80112b9c,
		"TAmenbo::setDeadAnm": 0x80112bec,
		"TAmenbo::attackToMario": 0x80112c3c,
		"TAmenbo::doKeepDistance": 0x80112d20,
		"TAmenbo::isCollidMove": 0x80112df4,
		"TAmenbo::forceKill": 0x80112e04,
		"TAmenbo::calcRootMatrix": 0x80112e84,
		"TAmenbo::behaveToWater": 0x80112fe4,
		"TAmenbo::receiveMessage": 0x801130b0,
		"TMapCollisionBase::isSetUp": 0x80113100,
		"isSetUp": 0x80113100,
		"TAmenbo::perform": 0x80113130,
		"TAmenbo::control": 0x801131bc,
		"TAmenbo::bind": 0x801135b0,
		"TAmenbo::kill": 0x80113888,
		"TAmenbo::reset": 0x801138b8,
		"TAmenbo::init": 0x801138bc,
		"TAmenbo::TAmenbo": 0x80113b1c,
		"TAmenbo::EffectOnJoint::EffectOnJoint": 0x80113b90,
		"TAmenboManager::~TAmenboManager": 0x80113c18,
		"TBathtubPeachManager::~TBathtubPeachManager": 0x80113c94,
		"TBathtubPeachManager::load": 0x80113cf8,
		"TBathtubPeachManager::createModelData": 0x80113e70,
		"TBathtubPeachManager::createEnemyInstance": 0x80113ea4,
		"TBathtubPeachManager::TBathtubPeachManager": 0x80113eac,
		"TBathtubPeach::calcRootMatrix": 0x80113ee8,
		"TBathtubPeach::receiveMessage": 0x80113f94,
		"TBathtubPeach::getRootJointMtx": 0x80113fb4,
		"TBathtubPeach::perform": 0x80113fd8,
		"TBathtubPeach::reset": 0x80113ff8,
		"TBathtubPeach::init": 0x8011412c,
		"TNervePeachEscape::~TNervePeachEscape": 0x801141e8,
		"TBathtubPeach::getBasNameTable": 0x80114244,
		"TBathtubPeach::TBathtubPeach": 0x80114250,
		"TNervePeachEscape::execute": 0x801142c8,
		"JGeometry::TVec2<float><float>::dot": 0x801147f4,
		"TNervePeachStagger::~TNervePeachStagger": 0x80114810,
		"TNervePeachStagger::execute": 0x8011486c,
		"Enemy::__sinit_BathtubPeach_cpp": 0x801149d4,
		"__sinit_BathtubPeach_cpp": 0x801149d4,
		"TBathtubKillerManager::~TBathtubKillerManager": 0x80114cd8,
		"TBathtubKillerManager::createEnemyInstance": 0x80114d4c,
		"TBathtubKillerManager::createModelData": 0x80114dc0,
		"TBathtubKillerManager::countActiveKillers": 0x80114df4,
		"countActiveKillers": 0x80114df4,
		"TBathtubKillerManager::loadAfter": 0x80114e60,
		"TBathtubKillerManager::load": 0x80114f7c,
		"TBathtubKillerManager::TBathtubKillerManager": 0x80114fe8,
		"TNerveBathtubKillerExplosion::execute": 0x80115024,
		"TNerveBathtubKillerExplosion::theNerve": 0x801151c0,
		"TNerveBathtubKillerExplosion::~TNerveBathtubKillerExplosion": 0x80115224,
		"TNerveBathtubKillerBreak::execute": 0x80115280,
		"TNerveBathtubKillerBreak::theNerve": 0x8011539c,
		"TNerveBathtubKillerBreak::~TNerveBathtubKillerBreak": 0x80115400,
		"TNerveBathtubKillerStraight::execute": 0x8011545c,
		"TNerveBathtubKillerStraight::~TNerveBathtubKillerStraight": 0x801155ec,
		"TNerveBathtubKillerChaseStraight::execute": 0x80115648,
		"TNerveBathtubKillerChase::~TNerveBathtubKillerChase": 0x80115a88,
		"TNerveBathtubKillerChaseStraight::~TNerveBathtubKillerChaseStraight": 0x80115ae4,
		"TNerveBathtubKillerChase::execute": 0x80115b40,
		"TNerveBathtubKillerWander::execute": 0x80115ed0,
		"TNerveBathtubKillerWander::~TNerveBathtubKillerWander": 0x80116288,
		"TBathtubKiller::isAboided": 0x801162e4,
		"isAboided": 0x801162e4,
		"TBathtubKiller::getBasNameTable": 0x80116628,
		"TBathtubKiller::behaveToWater": 0x80116634,
		"TBathtubKiller::isCollidMove": 0x8011674c,
		"TBathtubKiller::attackToMario": 0x80116b78,
		"TBathtubKiller::receiveMessage": 0x80116d0c,
		"TBathtubKiller::calcRootMatrix": 0x80116f78,
		"TBathtubKiller::getGravityY": 0x80117008,
		"TBathtubKiller::makeQuat": 0x80117038,
		"makeQuat": 0x80117038,
		"TBathtubKiller::moveChasing": 0x80117634,
		"moveChasing": 0x80117634,
		"TBathtubKiller::makeInitialVelocity": 0x80117890,
		"makeInitialVelocity": 0x80117890,
		"TBathtubKiller::perform": 0x80117c34,
		"TBathtubKiller::bind": 0x801180c0,
		"TBathtubKiller::generateItemBathtubKiller": 0x801184ac,
		"generateItemBathtubKiller": 0x801184ac,
		"TBathtubKiller::resetBathtubKiller": 0x80118738,
		"resetBathtubKiller": 0x80118738,
		"TBathtubKiller::reset": 0x80118aa0,
		"TBathtubKiller::setMActorAndKeeper": 0x80118b10,
		"TBathtubKiller::init": 0x80118c80,
		"TBathtubKiller::TBathtubKiller": 0x80118d00,
		"TBathtubKillerParams::TBathtubKillerParams": 0x80118d4c,
		"Enemy::__sinit_BathtubKiller_cpp": 0x801194f8,
		"__sinit_BathtubKiller_cpp": 0x801194f8,
		"TCoasterKillerManager::~TCoasterKillerManager": 0x801197fc,
		"TCoasterKillerManager::createEnemyInstance": 0x80119870,
		"TCoasterKillerManager::createModelData": 0x801199a4,
		"TCoasterKillerManager::loadAfter": 0x801199d8,
		"TCoasterKillerManager::load": 0x80119a0c,
		"TCoasterKillerManager::TCoasterKillerManager": 0x80119b30,
		"TNerveCoasterKillerExplosion::execute": 0x80119b74,
		"TNerveCoasterKillerExplosion::~TNerveCoasterKillerExplosion": 0x80119cf4,
		"TCoasterKiller::setDeadAnm": 0x80119d50,
		"TCoasterKiller::setNormalFlyAnm": 0x80119e04,
		"TCoasterKiller::getBasNameTable": 0x80119e58,
		"TCoasterKiller::behaveToWater": 0x80119e64,
		"TCoasterKiller::isCollidMove": 0x80119f7c,
		"TCoasterKiller::attackToMario": 0x8011a1a8,
		"TCoasterKiller::setMActorAndKeeper": 0x8011a2dc,
		"TCoasterKiller::perform": 0x8011a430,
		"TCoasterKiller::reset": 0x8011a598,
		"TCoasterKiller::init": 0x8011a5e8,
		"TNerveCoasterEnemyWander::~TNerveCoasterEnemyWander": 0x8011a728,
		"TCoasterKiller::TCoasterKiller": 0x8011a784,
		"TNerveCoasterEnemyWander::execute": 0x8011a7e4,
		"TCoasterEnemy::setWalkAnm": 0x8011a91c,
		"TCoasterEnemy::setNormalFlyAnm": 0x8011a948,
		"TCoasterEnemy::calcRootMatrix": 0x8011a94c,
		"TCoasterEnemy::moveCoaster": 0x8011a9dc,
		"moveCoaster": 0x8011a9dc,
		"TCoasterEnemy::makeCoasterGoalPath": 0x8011b08c,
		"makeCoasterGoalPath": 0x8011b08c,
		"TCoasterEnemy::getGravityY": 0x8011b0c8,
		"TCoasterEnemy::perform": 0x8011b0d0,
		"TCoasterEnemy::reset": 0x8011b0fc,
		"TCoasterEnemy::bind": 0x8011b14c,
		"TCoasterEnemy::moveObject": 0x8011b228,
		"TCoasterEnemy::init": 0x8011b248,
		"Enemy::__sinit_coasterkiller_cpp": 0x8011b3cc,
		"__sinit_coasterkiller_cpp": 0x8011b3cc,
		"TNerveDebuTelesaWait::~TNerveDebuTelesaWait": 0x8011b6d8,
		"TNerveDebuTelesaWait::execute": 0x8011b734,
		"TDebuTelesaManager::clipEnemies": 0x8011b784,
		"TDebuTelesaManager::createModelData": 0x8011b86c,
		"TDebuTelesaManager::load": 0x8011b8a0,
		"TDebuTelesaManager::TDebuTelesaManager": 0x8011b950,
		"TDebuTelesa::setDeadAnm": 0x8011b98c,
		"TDebuTelesa::doKeepDistance": 0x8011b9bc,
		"TDebuTelesa::isCollidMove": 0x8011b9c4,
		"TDebuTelesa::attackToMario": 0x8011b9cc,
		"TDebuTelesa::behaveToWater": 0x8011b9f8,
		"TDebuTelesa::getBasNameTable": 0x8011b9fc,
		"TDebuTelesa::receiveMessage": 0x8011ba04,
		"TDebuTelesa::kill": 0x8011bab4,
		"TDebuTelesa::calcRootMatrix": 0x8011bad4,
		"TDebuTelesa::reset": 0x8011bbe4,
		"TDebuTelesa::init": 0x8011bbe8,
		"TDebuTelesa::TDebuTelesa": 0x8011bd14,
		"TDebuTelesaManager::~TDebuTelesaManager": 0x8011bd64,
		"TDebuTelesa::changeByJuice": 0x8011be5c,
		"Enemy::__sinit_DebuTelesa_cpp": 0x8011be64,
		"__sinit_DebuTelesa_cpp": 0x8011be64,
		"TNerveTabePukuDrag::~TNerveTabePukuDrag": 0x8011c168,
		"TNerveTabePukuDrag::execute": 0x8011c1c4,
		"TNerveTabePukuRecoverGraph::~TNerveTabePukuRecoverGraph": 0x8011c524,
		"TNerveTabePukuDrag::theNerve": 0x8011c590,
		"TNerveTabePukuDive::execute": 0x8011c5f4,
		"TNerveTabePukuDive::theNerve": 0x8011c7b8,
		"TNerveTabePukuDive::~TNerveTabePukuDive": 0x8011c81c,
		"TNerveTabePukuBite::execute": 0x8011c878,
		"TNerveTabePukuBite::theNerve": 0x8011c970,
		"TNerveTabePukuBite::~TNerveTabePukuBite": 0x8011c9d4,
		"TNerveTabePukuAttack::execute": 0x8011ca30,
		"TNerveTabePukuAttack::~TNerveTabePukuAttack": 0x8011cdc0,
		"TNerveTabePukuRecoverGraph::execute": 0x8011ce1c,
		"TNerveTabePukuGraphWander::~TNerveTabePukuGraphWander": 0x8011d020,
		"TNerveTabePukuRecoverGraph::theNerve": 0x8011d07c,
		"TNerveTabePukuFound::execute": 0x8011d0e0,
		"TNerveTabePukuFound::~TNerveTabePukuFound": 0x8011d388,
		"TNerveTabePukuGraphWander::execute": 0x8011d3e4,
		"TTabePukuManager::createModelData": 0x8011d5cc,
		"TTabePukuManager::load": 0x8011d600,
		"TTabePukuManager::TTabePukuManager": 0x8011d83c,
		"TTabePuku::swimTo": 0x8011d878,
		"swimTo": 0x8011d878,
		"TTabePuku::doKeepDistance": 0x8011e08c,
		"TTabePuku::isFindMario": 0x8011e198,
		"TTabePuku::forceKill": 0x8011e1b8,
		"TTabePuku::behaveToWater": 0x8011e1bc,
		"TTabePuku::attackToMario": 0x8011e1c0,
		"TTabePuku::getBasNameTable": 0x8011e398,
		"TTabePuku::getTakingMtx": 0x8011e3a4,
		"TTabePuku::receiveMessage": 0x8011e528,
		"TTabePuku::calcRootMatrix": 0x8011e564,
		"TTabePuku::bind": 0x8011e724,
		"TTabePuku::control": 0x8011e8d0,
		"TTabePuku::perform": 0x8011ea1c,
		"TTabePuku::reset": 0x8011ea80,
		"TTabePuku::init": 0x8011ea8c,
		"TTabePuku::TTabePuku": 0x8011ec3c,
		"TTPHitActor::bind": 0x8011ec8c,
		"TTPHitActor::updateTerrainCollsion": 0x8011ef2c,
		"updateTerrainCollsion": 0x8011ef2c,
		"TTPHitActor::receiveMessage": 0x8011f0d0,
		"TTPHitActor::init": 0x8011f100,
		"TTabePukuManager::~TTabePukuManager": 0x8011f1f0,
		"Enemy::__sinit_TabePuku_cpp": 0x8011f36c,
		"__sinit_TabePuku_cpp": 0x8011f36c,
		"TBathtubBinder::float_": 0x8011f690,
		"float_": 0x8011f690,
		"TBathtubBinder::bind": 0x8011fb0c,
		"TBathtubBinder::init": 0x8011fb44,
		"TBathtubBinder::~TBathtubBinder": 0x8011fc6c,
		"TBathtubBinder::TBathtubBinder": 0x8011fcd0,
		"CPolarSubCamera::execGroundCheck_": 0x803529b4,
		"execGroundCheck_": 0x803529b4,
		"CPolarSubCamera::execRoofCheck_": 0x80352b04,
		"execRoofCheck_": 0x80352b04,
		"CPolarSubCamera::execWallCheck_": 0x80352c48,
		"execWallCheck_": 0x80352c48,
		"CPolarSubCamera::isNeedWallCheck_": 0x80352e7c,
		"isNeedWallCheck_": 0x80352e7c,
		"CPolarSubCamera::isNeedRoofCheck_": 0x80352f3c,
		"isNeedRoofCheck_": 0x80352f3c,
		"CPolarSubCamera::isNeedGroundCheck_": 0x80352ffc,
		"isNeedGroundCheck_": 0x80352ffc,
		"CPolarSubCamera::calcInHouseNo_": 0x80353168,
		"calcInHouseNo_": 0x80353168,
		"CPolarSubCamera::execCameraModeChangeProc_": 0x803537a8,
		"execCameraModeChangeProc_": 0x803537a8,
		"CPolarSubCamera::isChangeToParallelCameraCByMoveBG_": 0x80354198,
		"isChangeToParallelCameraCByMoveBG_": 0x80354198,
		"CPolarSubCamera::isChangeToParallelCameraByMoveBG_": 0x803541e0,
		"isChangeToParallelCameraByMoveBG_": 0x803541e0,
		"CPolarSubCamera::isChangeToCancanCamera_": 0x803542dc,
		"isChangeToCancanCamera_": 0x803542dc,
		"CPolarSubCamera::isChangeToBossGesoCamera_": 0x80354308,
		"isChangeToBossGesoCamera_": 0x80354308,
		"CPolarSubCamera::doLButtonCameraOff_": 0x80354398,
		"doLButtonCameraOff_": 0x80354398,
		"CPolarSubCamera::execFrontRotate_": 0x803544c0,
		"execFrontRotate_": 0x803544c0,
		"CPolarSubCamera::changeCamModeSpecifyCamMapToolAndFrame_": 0x803545a4,
		"changeCamModeSpecifyCamMapToolAndFrame_": 0x803545a4,
		"CPolarSubCamera::changeCamModeSpecifyCamMapTool_": 0x803545f8,
		"changeCamModeSpecifyCamMapTool_": 0x803545f8,
		"CPolarSubCamera::changeCamModeSpecifyFrame_": 0x80354674,
		"changeCamModeSpecifyFrame_": 0x80354674,
		"CPolarSubCamera::changeCamModeSub_": 0x803546a8,
		"changeCamModeSub_": 0x803546a8,
		"TTargetCamera::operator_=": 0x80354d1c,
		"CPolarSubCamera::setUpFromLButtonCamera_": 0x80354db0,
		"setUpFromLButtonCamera_": 0x80354db0,
		"CPolarSubCamera::setUpToLButtonCamera_": 0x80354dc0,
		"setUpToLButtonCamera_": 0x80354dc0,
		"CPolarSubCamera::getCameraInbetweenFrame_": 0x80354e44,
		"getCameraInbetweenFrame_": 0x80354e44,
		"Camera::__sinit_CameraChange_cpp": 0x80355108,
		"__sinit_CameraChange_cpp": 0x80355108,
		"CPolarSubCamera::controlByCameraCode_": 0x80355404,
		"controlByCameraCode_": 0x80355404,
		"CPolarSubCamera::getFinalAngleZ": 0x803555f0,
		"getFinalAngleZ": 0x803555f0,
		"CPolarSubCamera::getOffsetAngleY": 0x80355604,
		"getOffsetAngleY": 0x80355604,
		"CPolarSubCamera::getOffsetAngleX": 0x80355610,
		"getOffsetAngleX": 0x80355610,
		"CPolarSubCamera::perform": 0x8035561c,
		"JGeometry::TUtil<float><float>::one": 0x80355a00,
		"one": 0x80355a00,
		"Camera::MsSqrtf": 0x80355a18,
		"MsSqrtf": 0x80355a18,
		"CPolarSubCamera::ctrlGameCamera_": 0x80355a5c,
		"ctrlGameCamera_": 0x80355a5c,
		"CPolarSubCamera::calcFinalPosAndAt_": 0x80355ec4,
		"calcFinalPosAndAt_": 0x80355ec4,
		"CPolarSubCamera::calcPosAndAt_": 0x80356054,
		"calcPosAndAt_": 0x80356054,
		"CPolarSubCamera::calcSlopeAngleX_": 0x80356ff8,
		"calcSlopeAngleX_": 0x80356ff8,
		"TMario::checkStatusType": 0x803572f0,
		"checkStatusType": 0x803572f0,
		"CPolarSubCamera::isMomentDefinite_": 0x8035730c,
		"isMomentDefinite_": 0x8035730c,
		"CPolarSubCamera::execInvalidAutoChase_": 0x80357394,
		"execInvalidAutoChase_": 0x80357394,
		"CPolarSubCamera::isMarioCrabWalk_": 0x803573a4,
		"isMarioCrabWalk_": 0x803573a4,
		"CPolarSubCamera::isMarioAimWithGun_": 0x80357444,
		"isMarioAimWithGun_": 0x80357444,
		"CPolarSubCamera::onMoveApproach_": 0x803574e4,
		"onMoveApproach_": 0x803574e4,
		"CPolarSubCamera::offMoveApproach_": 0x803575a4,
		"offMoveApproach_": 0x803575a4,
		"CPolarSubCamera::rotateY_ByStickX_": 0x803575b4,
		"rotateY_ByStickX_": 0x803575b4,
		"CPolarSubCamera::rotateX_ByStickY_": 0x80357644,
		"rotateX_ByStickY_": 0x80357644,
		"CPolarSubCamera::calcNowTargetFromPosAndAt_": 0x80357708,
		"calcNowTargetFromPosAndAt_": 0x80357708,
		"CPolarSubCamera::calcDistFromXRotRatio_": 0x8035784c,
		"calcDistFromXRotRatio_": 0x8035784c,
		"CPolarSubCamera::calcAngleXFromXRotRatio_": 0x8035787c,
		"calcAngleXFromXRotRatio_": 0x8035787c,
		"CPolarSubCamera::getUsualLookat": 0x803578ac,
		"getUsualLookat": 0x803578ac,
		"CPolarSubCamera::getToroccoMtx_": 0x80357918,
		"getToroccoMtx_": 0x80357918,
		"CPolarSubCamera::isNowInbetween": 0x80357930,
		"isNowInbetween": 0x80357930,
		"CPolarSubCamera::loadAfter": 0x80357950,
		"Camera::JetCoasterDemoCallBack": 0x80358180,
		"JetCoasterDemoCallBack": 0x80358180,
		"CPolarSubCamera::CPolarSubCamera": 0x803581f8,
		"CPolarSubCamera::killHeightPan_": 0x803586d8,
		"killHeightPan_": 0x803586d8,
		"CPolarSubCamera::execHeightPan_": 0x80358704,
		"execHeightPan_": 0x80358704,
		"CPolarSubCamera::isNotHeightPanCamMode_": 0x80358950,
		"isNotHeightPanCamMode_": 0x80358950,
		"CPolarSubCamera::killHeightPanWhenChangeCamMode_": 0x803589e0,
		"killHeightPanWhenChangeCamMode_": 0x803589e0,
		"TCameraInbetween::execCameraInbetween": 0x80358ad4,
		"execCameraInbetween": 0x80358ad4,
		"TCameraInbetween::initCameraInbetween": 0x80358e6c,
		"initCameraInbetween": 0x80358e6c,
		"TCameraInbetween::startCameraInbetween": 0x80358f0c,
		"startCameraInbetween": 0x80358f0c,
		"TCameraInbetween::addMoveCameraAndMario": 0x80358f74,
		"TCameraInbetween::warpPosAndAt": 0x8035905c,
		"TCameraInbetween::TCameraInbetween": 0x803590e4,
		"TCameraKindParam::inbetweenData": 0x8035912c,
		"inbetweenData": 0x8035912c,
		"TCameraKindParam::copySaveParam": 0x8035964c,
		"copySaveParam": 0x8035964c,
		"Camera::CLBCalcNearNinePos": 0x803597c8,
		"CLBCalcNearNinePos": 0x803597c8,
		"JGeometry::TRotation3<JGeometry::TMatrix33<JGeometry::SMatrix33C<float><float>>>::setRotate": 0x80359ef4,
		"Camera::CLBCalcScaleTranslateMatrix": 0x8035a048,
		"CLBCalcScaleTranslateMatrix": 0x8035a048,
		"Camera::CLBCalcRotateZXYTranslateMatrix": 0x8035a098,
		"CLBCalcRotateZXYTranslateMatrix": 0x8035a098,
		"Camera::CLBCalcPointInCubeRatio": 0x8035a1e8,
		"CLBCalcPointInCubeRatio": 0x8035a1e8,
		"Camera::CLBIsPointInCube": 0x8035a3bc,
		"CLBIsPointInCube": 0x8035a3bc,
		"Camera::CLBRotatePosAndUp": 0x8035a5b8,
		"CLBRotatePosAndUp": 0x8035a5b8,
		"Camera::CLBRevisionLookatByAngleX": 0x8035aa30,
		"CLBRevisionLookatByAngleX": 0x8035aa30,
		"Camera::CLBPolarToCross": 0x8035abf8,
		"CLBPolarToCross": 0x8035abf8,
		"Camera::CLBCrossToPolar": 0x8035ac90,
		"CLBCrossToPolar": 0x8035ac90,
		"Camera::CLBChaseSpecialDecrease": 0x8035ad98,
		"CLBChaseSpecialDecrease": 0x8035ad98,
		"Camera::CLBChaseDecrease": 0x8035ae18,
		"CLBChaseDecrease": 0x8035ae18,
		"Camera::CLBChaseAngleDecrease": 0x8035ae8c,
		"CLBChaseAngleDecrease": 0x8035ae8c,
		"Camera::CLBCalc2DFPos": 0x8035aef0,
		"CLBCalc2DFPos": 0x8035aef0,
		"Camera::__sinit_cameralib_cpp": 0x8035b060,
		"__sinit_cameralib_cpp": 0x8035b060,
		"TCameraMarioData::isMarioClimb": 0x8035b07c,
		"isMarioClimb": 0x8035b07c,
		"TCameraMarioData::isMarioLeanMirror": 0x8035b0b8,
		"isMarioLeanMirror": 0x8035b0b8,
		"TCameraMarioData::isMarioSlider": 0x8035b114,
		"isMarioSlider": 0x8035b114,
		"TCameraMarioData::isMarioIndoor": 0x8035b17c,
		"isMarioIndoor": 0x8035b17c,
		"TCameraMarioData::isMarioRocketing": 0x8035b1ec,
		"isMarioRocketing": 0x8035b1ec,
		"TCameraMarioData::isMarioGoDown": 0x8035b240,
		"isMarioGoDown": 0x8035b240,
		"TCameraMarioData::calcAndSetMarioData": 0x8035b27c,
		"calcAndSetMarioData": 0x8035b27c,
		"TCameraMarioData::TCameraMarioData": 0x8035b3e0,
		"CPolarSubCamera::ctrlLButtonCamera_": 0x8035b40c,
		"ctrlLButtonCamera_": 0x8035b40c,
		"CPolarSubCamera::getNozzleTopPos_": 0x8035b61c,
		"getNozzleTopPos_": 0x8035b61c,
		"CPolarSubCamera::calcNoticeTargetYrot_": 0x8035b72c,
		"calcNoticeTargetYrot_": 0x8035b72c,
		"CPolarSubCamera::execNoticeOnOffProc_": 0x8035b930,
		"execNoticeOnOffProc_": 0x8035b930,
		"CPolarSubCamera::getNoticeActor_": 0x8035b9f4,
		"getNoticeActor_": 0x8035b9f4,
		"CPolarSubCamera::setNoticeInfo": 0x8035bd2c,
		"setNoticeInfo": 0x8035bd2c,
		"CPolarSubCamera::ctrlNormalOrTowerCamera_": 0x8035bf90,
		"ctrlNormalOrTowerCamera_": 0x8035bf90,
		"CPolarSubCamera::calcTowerCenterPos_": 0x8035c444,
		"calcTowerCenterPos_": 0x8035c444,
		"TCamSaveKindParam::TCamSaveKindParam": 0x8035c5b4,
		"TCamSaveEx::TCamSaveEx": 0x8035d994,
		"TCamSaveJetCoaster::TCamSaveJetCoaster": 0x8035de84,
		"TCamSaveShake::TCamSaveShake": 0x8035dfe0,
		"TCamSaveNotice::TCamSaveNotice": 0x8035e178,
		"TCameraShake::execShake": 0x8035e38c,
		"execShake": 0x8035e38c,
		"TCameraShake::keepShake": 0x8035e8e4,
		"keepShake": 0x8035e8e4,
		"TCameraShake::startShake": 0x8035eb68,
		"startShake": 0x8035eb68,
		"TCameraShake::getUseShakeData_": 0x8035ec94,
		"getUseShakeData_": 0x8035ec94,
		"TCameraShake::TCameraShake": 0x8035ef58,
		"CPolarSubCamera::ctrlTalkCamera_": 0x8035f0ec,
		"ctrlTalkCamera_": 0x8035f0ec,
		"CPolarSubCamera::makeMtxForPrevTalk": 0x8035f134,
		"makeMtxForPrevTalk": 0x8035f134,
		"CPolarSubCamera::makeMtxForTalk": 0x8035f1cc,
		"makeMtxForTalk": 0x8035f1cc,
		"TLensFlare::~TLensFlare": 0x8035f2ac,
		"TLensFlare::perform": 0x8035f320,
		"TLensFlare::TLensFlare": 0x8035f908,
		"Camera::CLBEaseOutInbetween": 0x8035fa50,
		"TLensGlow::~TLensGlow": 0x8035fa74,
		"TLensGlow::perform": 0x8035fb14,
		"TLensGlow::TLensGlow": 0x80360044,
		"TSunMgr::~TSunMgr": 0x80360320,
		"TSunMgr::getAddColor": 0x803603cc,
		"getAddColor": 0x803603cc,
		"TSunMgr::perform": 0x803603fc,
		"TSunMgr::load": 0x803605a8,
		"TSunMgr::TSunMgr": 0x80360770,
		"Camera::__sinit_sunmgr_cpp": 0x80360818,
		"__sinit_sunmgr_cpp": 0x80360818,
		"TSunModel::getZBufValue": 0x80360b9c,
		"getZBufValue": 0x80360b9c,
		"TSunModel::perform": 0x80360c38,
		"TSunModel::calcDispRatioAndScreenPos_": 0x80361058,
		"calcDispRatioAndScreenPos_": 0x80361058,
		"Camera::CLBScreenFPosToSPos": 0x8036117c,
		"CLBScreenFPosToSPos": 0x8036117c,
		"TSunModel::calcOtherFPosFromCenterAndRadius_": 0x80361290,
		"calcOtherFPosFromCenterAndRadius_": 0x80361290,
		"TSunModel::load": 0x8036134c,
		"TSunModel::TSunModel": 0x8036169c,
		"JGeometry::TVec2<short><short>::TVec2": 0x803618f0,
		"Camera::SMS_IsInSameCameraCube": 0x8036190c,
		"SMS_IsInSameCameraCube": 0x8036190c,
		"Camera::SMS_IsInOtherFastCube": 0x80361a24,
		"SMS_IsInOtherFastCube": 0x80361a24,
		"TCubeManagerArea::isInAreaCube": 0x80361b4c,
		"isInAreaCube": 0x80361b4c,
		"TCubeManagerBase::calcPointInCubeRatio": 0x80361c98,
		"calcPointInCubeRatio": 0x80361c98,
		"TCubeManagerBase::isInCube": 0x80361ce4,
		"isInCube": 0x80361ce4,
		"TCubeManagerBase::getInCubeNo": 0x80361d54,
		"getInCubeNo": 0x80361d54,
		"TCubeManagerBase::getDataNo": 0x80361dec,
		"getDataNo": 0x80361dec,
		"TCubeManagerBase::perform": 0x80361e20,
		"TCubeManagerBase::load": 0x80361e24,
		"TCameraMapTool::calcPosAndAt": 0x80362108,
		"calcPosAndAt": 0x80362108,
		"TCameraMapTool::load": 0x803621dc,
		"TCubeStreamInfo::~TCubeStreamInfo": 0x803622b8,
		"TCubeStreamInfo::load": 0x8036232c,
		"TCubeCameraInfo::load": 0x803624cc,
		"TCubeGeneralInfo::load": 0x80362630,
		"TCubeCameraInfo::~TCubeCameraInfo": 0x80362764,
		"CPolarSubCamera::ctrlMultiPlayerCamera_": 0x803627d8,
		"ctrlMultiPlayerCamera_": 0x803627d8,
		"CPolarSubCamera::removeMultiPlayer": 0x80362b4c,
		"removeMultiPlayer": 0x80362b4c,
		"CPolarSubCamera::addMultiPlayer": 0x80362be4,
		"addMultiPlayer": 0x80362be4,
		"CPolarSubCamera::createMultiPlayer": 0x80362c40,
		"createMultiPlayer": 0x80362c40,
		"TMultiPlayerData::TMultiPlayerData": 0x80362cd8,
		"TCameraJetCoaster::TCameraJetCoaster": 0x80362cf0,
		"CPolarSubCamera::ctrlJetCoasterCamera_": 0x80362d98,
		"ctrlJetCoasterCamera_": 0x80362d98,
		"Camera::__sinit_CameraJetCoaster_cpp": 0x8036388c,
		"__sinit_CameraJetCoaster_cpp": 0x8036388c,
		"TCameraBck::setFrame": 0x80363b88,
		"setFrame": 0x80363b88,
		"TCameraBck::updateDemo": 0x80363bfc,
		"updateDemo": 0x80363bfc,
		"TCameraBck::endDemo": 0x80363dc0,
		"endDemo": 0x80363dc0,
		"TCameraBck::getTotalDemoFrames": 0x80363de8,
		"getTotalDemoFrames": 0x80363de8,
		"TCameraBck::startDemo": 0x80363e48,
		"TCameraBck::isFileExist": 0x80363e88,
		"isFileExist": 0x80363e88,
		"TCameraBck::TCameraBck": 0x80363eb0,
		"TCameraOption::moveToDown": 0x80363fb4,
		"moveToDown": 0x80363fb4,
		"TCameraOption::moveToUp": 0x80363fdc,
		"moveToUp": 0x80363fdc,
		"TCameraOption::moveToLoadFromTitle": 0x80364004,
		"moveToLoadFromTitle": 0x80364004,
		"TCameraOption::TCameraOption": 0x80364038,
		"CPolarSubCamera::ctrlOptionCamera_": 0x803641ac,
		"ctrlOptionCamera_": 0x803641ac,
		"CPolarSubCamera::isNormalDeadDemo": 0x80364534,
		"isNormalDeadDemo": 0x80364534,
		"CPolarSubCamera::isHellDeadDemo": 0x80364554,
		"isHellDeadDemo": 0x80364554,
		"CPolarSubCamera::execDeadDemoProc_": 0x80364574,
		"execDeadDemoProc_": 0x80364574,
		"CPolarSubCamera::ctrlNormalDeadDemo_": 0x80364648,
		"ctrlNormalDeadDemo_": 0x80364648,
		"CPolarSubCamera::getRestDemoFrames": 0x803647ec,
		"getRestDemoFrames": 0x803647ec,
		"CPolarSubCamera::isSimpleDemoCamera": 0x803647f8,
		"isSimpleDemoCamera": 0x803647f8,
		"CPolarSubCamera::endDemoCamera": 0x80364844,
		"endDemoCamera": 0x80364844,
		"CPolarSubCamera::startDemoCamera": 0x8036498c,
		"startDemoCamera": 0x8036498c,
		"CPolarSubCamera::startGateDemoCamera": 0x80364ae4,
		"startGateDemoCamera": 0x80364ae4,
		"CPolarSubCamera::updateGateDemoCamera_": 0x80364bfc,
		"updateGateDemoCamera_": 0x80364bfc,
		"CPolarSubCamera::updateDemoCamera_": 0x80364ce0,
		"updateDemoCamera_": 0x80364ce0,
		"CPolarSubCamera::addMoveCameraAndMario": 0x80365034,
		"CPolarSubCamera::isSlopeCameraMode": 0x80365640,
		"isSlopeCameraMode": 0x80365640,
		"CPolarSubCamera::isOverHipAttackSpecifyMode": 0x80365670,
		"isOverHipAttackSpecifyMode": 0x80365670,
		"CPolarSubCamera::isDefiniteCameraSpecifyMode": 0x8036571c,
		"isDefiniteCameraSpecifyMode": 0x8036571c,
		"CPolarSubCamera::isFixCameraSpecifyMode": 0x80365750,
		"isFixCameraSpecifyMode": 0x80365750,
		"CPolarSubCamera::isRailCameraSpecifyMode": 0x80365778,
		"isRailCameraSpecifyMode": 0x80365778,
		"CPolarSubCamera::isFollowCameraSpecifyMode": 0x80365780,
		"isFollowCameraSpecifyMode": 0x80365780,
		"CPolarSubCamera::isTowerCameraSpecifyMode": 0x803657bc,
		"isTowerCameraSpecifyMode": 0x803657bc,
		"CPolarSubCamera::isNormalCameraCompletely": 0x803657f0,
		"isNormalCameraCompletely": 0x803657f0,
		"CPolarSubCamera::isNormalCameraSpecifyMode": 0x80365880,
		"isNormalCameraSpecifyMode": 0x80365880,
		"CPolarSubCamera::isTalkCameraInbetween": 0x803658ac,
		"isTalkCameraInbetween": 0x803658ac,
		"CPolarSubCamera::isTalkCameraSpecifyMode": 0x803659a4,
		"isTalkCameraSpecifyMode": 0x803659a4,
		"CPolarSubCamera::isJetCoaster1stCamera": 0x803659f0,
		"isJetCoaster1stCamera": 0x803659f0,
		"CPolarSubCamera::isLButtonCameraInbetween": 0x80365a24,
		"isLButtonCameraInbetween": 0x80365a24,
		"CPolarSubCamera::isLButtonCameraSpecifyMode": 0x80365aac,
		"isLButtonCameraSpecifyMode": 0x80365aac,
		"CPolarSubCamera::execSecureView_": 0x80365ac0,
		"execSecureView_": 0x80365ac0,
		"CPolarSubCamera::calcSecureViewTarget_": 0x80365cc0,
		"calcSecureViewTarget_": 0x80365cc0,
		"TBoidLeader::~TBoidLeader": 0x8000566c,
		"TBoidLeader::calcForces": 0x800056e0,
		"calcForces": 0x800056e0,
		"TBoidLeader::calcGoalForce": 0x80005ab0,
		"calcGoalForce": 0x80005ab0,
		"TBoidLeader::perform": 0x80005d14,
		"TBoidLeader::setGraph": 0x80005e7c,
		"setGraph": 0x80005e7c,
		"TBoidLeader::calcBoids": 0x80005f60,
		"calcBoids": 0x80005f60,
		"JGeometry::TVec3<float><float>::div": 0x80006890,
		"div": 0x80006890,
		"TBoidLeader::TBoidLeader": 0x800068c0,
		"TBoid::TBoid": 0x80006ad0,
		"TFishoidManager::~TFishoidManager": 0x80006b60,
		"TFishoidManager::createModelData": 0x80006bcc,
		"TFishoidManager::TFishoidManager": 0x80006c00,
		"TFishoid::createRealoidActor": 0x80006c3c,
		"TFishoid::load": 0x80006e7c,
		"TFishoid::init": 0x800070a4,
		"TFishoid::perform": 0x80007218,
		"TFishoid::TFishoid": 0x800073a0,
		"TFish::init": 0x80007490,
		"TRealoid::perform": 0x800074a0,
		"TRealoid::clipBoids": 0x80007618,
		"clipBoids": 0x80007618,
		"TRealoid::loadDefault": 0x800076ec,
		"loadDefault": 0x800076ec,
		"TRealoid::TRealoid": 0x80007898,
		"TRealoidActor::getTakingMtx": 0x800078f0,
		"TRealoidActor::checkHitActors": 0x800078f8,
		"TRealoidActor::calcRootMatrix": 0x800079ec,
		"TRealoidActor::perform": 0x80007c64,
		"TRealoidActor::TRealoidActor": 0x80007cdc,
		"TAnimalBase::execWalk": 0x80008080,
		"Animal::MsClamp": 0x80008490,
		"TAnimalBase::getRotationFlyToDir": 0x800084f8,
		"getRotationFlyToDir": 0x800084f8,
		"TAnimalBase::resetRandomCurPathNode": 0x800086e8,
		"resetRandomCurPathNode": 0x800086e8,
		"TAnimalBase::perform": 0x80008904,
		"TAnimalBase::receiveMessage": 0x80008c3c,
		"TAnimalBase::calcRootMatrix": 0x80008c44,
		"TAnimalBase::loadAfter": 0x80008c48,
		"TAnimalBase::load": 0x80008c90,
		"TAnimalBase::initNoLoad_": 0x80008d30,
		"initNoLoad_": 0x80008d30,
		"TAnimalBase::init": 0x80008fcc,
		"TAnimalBase::TAnimalBase": 0x8000925c,
		"Animal::SMS_Eular2Quat": 0x800092b4,
		"SMS_Eular2Quat": 0x800092b4,
		"Animal::__sinit_AnimalBase_cpp": 0x800094d8,
		"__sinit_AnimalBase_cpp": 0x800094d8,
		"TMewManager::~TMewManager": 0x80009d04,
		"TMewManager::createModelData": 0x80009d78,
		"TMewManager::loadAfter": 0x80009dac,
		"TMewManager::load": 0x80009de8,
		"TAnimalManagerBase::clipEnemies": 0x80009e64,
		"TAnimalManagerBase::TAnimalManagerBase": 0x80009f64,
		"Animal::__sinit_AnimalManager_cpp": 0x8000a018,
		"__sinit_AnimalManager_cpp": 0x8000a018,
		"TAnimalSaveIndividual::TAnimalSaveIndividual": 0x8000a314,
		"TNerveAnimalGraphWander::~TNerveAnimalGraphWander": 0x8000a524,
		"TNerveAnimalGraphWander::execute": 0x8000a580,
		"TNerveAnimalGraphWander::theNerve": 0x8000ab30,
		"TNerveAnimalBirdLanding::~TNerveAnimalBirdLanding": 0x8000ac20,
		"TNerveAnimalBirdLanding::execute": 0x8000ac7c,
		"TNerveAnimalBirdWaitOnGround::~TNerveAnimalBirdWaitOnGround": 0x8000af30,
		"TNerveAnimalBirdGraphWander::~TNerveAnimalBirdGraphWander": 0x8000af8c,
		"TNerveAnimalBirdPreLanding::execute": 0x8000afe8,
		"TNerveAnimalBirdPreLanding::theNerve": 0x8000b258,
		"TNerveAnimalBirdPreLanding::~TNerveAnimalBirdPreLanding": 0x8000b2bc,
		"TNerveAnimalBirdComeback::execute": 0x8000b318,
		"TNerveAnimalBirdComeback::theNerve": 0x8000b5d4,
		"TNerveAnimalBirdComeback::~TNerveAnimalBirdComeback": 0x8000b638,
		"TNerveAnimalBirdChangeToCoin::execute": 0x8000b694,
		"TNerveAnimalBirdChangeToCoin::theNerve": 0x8000b7f8,
		"TNerveAnimalBirdChangeToCoin::~TNerveAnimalBirdChangeToCoin": 0x8000b85c,
		"TNerveAnimalBirdGraphWander::execute": 0x8000b8b8,
		"TNerveAnimalBirdTakeoff::execute": 0x8000bbd8,
		"TNerveAnimalBirdTakeoff::~TNerveAnimalBirdTakeoff": 0x8000bd48,
		"TNerveAnimalBirdWalkOnGround::execute": 0x8000bda4,
		"TNerveAnimalBirdWalkOnGround::theNerve": 0x8000c17c,
		"TNerveAnimalBirdWalkOnGround::~TNerveAnimalBirdWalkOnGround": 0x8000c1e0,
		"TNerveAnimalBirdActionOnGround::execute": 0x8000c23c,
		"TNerveAnimalBirdActionOnGround::theNerve": 0x8000c4f8,
		"TNerveAnimalBirdActionOnGround::~TNerveAnimalBirdActionOnGround": 0x8000c55c,
		"TNerveAnimalBirdWaitOnGround::execute": 0x8000c5b8,
		"TNerveAnimalBirdWaitOnGround::theNerve": 0x8000c860,
		"TAnimalBirdManager::createModelData": 0x8000c8c4,
		"TAnimalBirdManager::loadAfter": 0x8000c8f8,
		"TAnimalBirdManager::load": 0x8000c944,
		"TAnimalBirdManager::TAnimalBirdManager": 0x8000c9b0,
		"TAnimalBirdParams::TAnimalBirdParams": 0x8000c9ec,
		"TAnimalBird::doLanding": 0x8000cd64,
		"doLanding": 0x8000cd64,
		"TAnimalBird::doFlyToCurPathNode": 0x8000d128,
		"doFlyToCurPathNode": 0x8000d128,
		"TAnimalBird::isFindMario": 0x8000d4c4,
		"TAnimalBird::getBasNameTable": 0x8000d5cc,
		"TAnimalBird::bind": 0x8000d5d8,
		"TAnimalBird::moveObject": 0x8000d6d4,
		"TAnimalBird::calcRootMatrix": 0x8000da90,
		"TAnimalBird::receiveMessage": 0x8000db1c,
		"TAnimalBird::loadAfter": 0x8000dec0,
		"TAnimalBird::load": 0x8000df04,
		"TAnimalBird::initParams": 0x8000e058,
		"initParams": 0x8000e058,
		"TAnimalBird::init": 0x8000e1a8,
		"TAnimalBird::TAnimalBird": 0x8000e2e0,
		"TAnimalBirdManager::~TAnimalBirdManager": 0x8000e330,
		"Animal::__sinit_Bird_cpp": 0x8000e480,
		"__sinit_Bird_cpp": 0x8000e480,
		"TNerveBeeHiveReset::~TNerveBeeHiveReset": 0x8000e784,
		"TNerveBeeHiveReset::execute": 0x8000e7e0,
		"TNerveBeeHiveWait::~TNerveBeeHiveWait": 0x8000e930,
		"TNerveBeeHiveMarioWaterIn::execute": 0x8000e98c,
		"TNerveBeeHiveAttack::~TNerveBeeHiveAttack": 0x8000ec78,
		"TNerveBeeHiveMarioWaterIn::~TNerveBeeHiveMarioWaterIn": 0x8000ed18,
		"TNerveBeeHiveAttack::execute": 0x8000ed74,
		"TNerveBeeHiveBreak::execute": 0x8000f104,
		"TNerveBeeHiveBreak::~TNerveBeeHiveBreak": 0x8000f398,
		"TNerveBeeHiveFall::execute": 0x8000f3f4,
		"TNerveBeeHiveFall::~TNerveBeeHiveFall": 0x8000f678,
		"TNerveBeeHiveWait::execute": 0x8000f6d4,
		"TBeeHiveManager::createModelData": 0x8000f954,
		"TBeeHiveManager::load": 0x8000f988,
		"TBeeHiveManager::TBeeHiveManager": 0x8000fba0,
		"TBeeHive::getCenterOfGravity": 0x8000fbdc,
		"getCenterOfGravity": 0x8000fbdc,
		"TBeeHive::appearBee": 0x8000ff08,
		"appearBee": 0x8000ff08,
		"TBeeHive::doWait": 0x8000ff6c,
		"doWait": 0x8000ff6c,
		"TBeeHive::calcRootMatrix": 0x80010660,
		"JGeometry::TRotation3<JGeometry::TMatrix34<JGeometry::SMatrix34C<float><float>>>::setSQ": 0x80010810,
		"setSQ": 0x80010810,
		"TBeeHive::controlSound": 0x80010910,
		"controlSound": 0x80010910,
		"TBeeHive::controlCollision": 0x800109dc,
		"TBeeHive::bind": 0x80010a9c,
		"TBeeHive::control": 0x80010d30,
		"TBeeHive::perform": 0x80010d6c,
		"TBeeHive::receiveMessage": 0x80010dc0,
		"TBeeHive::createRealoidActor": 0x80011310,
		"TBeeHive::load": 0x80011384,
		"TBeeHive::receiveMessageFromChild": 0x80011574,
		"receiveMessageFromChild": 0x80011574,
		"TBeeHive::reset": 0x8001166c,
		"TBeeHive::init": 0x80011a14,
		"TBeeHive::TBeeHive": 0x80011b10,
		"TBee::receiveMessage": 0x80011b5c,
		"TBee::init": 0x80011c10,
		"TBeeHiveManager::~TBeeHiveManager": 0x80011cf4,
		"Animal::__sinit_BeeHive_cpp": 0x80011e78,
		"__sinit_BeeHive_cpp": 0x80011e78,
		"TButterfloidManager::~TButterfloidManager": 0x8001218c,
		"TButterfloidManager::createModelData": 0x800121f0,
		"TButterfloidManager::TButterfloidManager": 0x80012224,
		"TButterfloid::createRealoidActor": 0x80012260,
		"TButterfloid::load": 0x800122d4,
		"TButterfloid::init": 0x80012554,
		"TButterfloid::TButterfloid": 0x80012620,
		"TButterfly::receiveMessage": 0x80012684,
		"TButterfly::init": 0x80012800,
		"Runtime.PPCEABI.H::__init_cpp_exceptions_reference": 0x80365de0,
		"__init_cpp_exceptions_reference": 0x80365de0,
		"Runtime.PPCEABI.H::__fini_cpp_exceptions_reference": 0x803661a4,
		"__fini_cpp_exceptions_reference": 0x803661a4,
		"Animal::@2234": 0x803662ac,
		"Animal::@2235": 0x803662b8,
		"Animal::@2236": 0x803662c4,
		"Animal::entry$2324": 0x803662e0,
		"entry$2324": 0x803662e0,
		"Animal::@2463": 0x8036631c,
		"Animal::@2693": 0x80366328,
		"MSound::@3445": 0x80366bc0,
		"MSound::@3446": 0x80366bd8,
		"MSound::@3447": 0x80366bf0,
		"MSound::@3448": 0x80366c04,
		"MSound::@3449": 0x80366c14,
		"MSound::@3305": 0x803670f4,
		"MSound::@3306": 0x80367104,
		"MSound::@3307": 0x80367120,
		"MSound::@3308": 0x80367138,
		"GC2D::@6904": 0x80377678,
		"GC2D::@6905": 0x803776ac,
		"GC2D::@11076": 0x803776c8,
		"@11076": 0x803776c8,
		"GC2D::@11721": 0x803776d8,
		"@11721": 0x803776d8,
		"GC2D::@11725": 0x803776e8,
		"@11725": 0x803776e8,
		"GC2D::@11726": 0x803776f4,
		"@11726": 0x803776f4,
		"GC2D::@11727": 0x80377704,
		"@11727": 0x80377704,
		"GC2D::@11942": 0x80377710,
		"@11942": 0x80377710,
		"GC2D::@11943": 0x80377720,
		"@11943": 0x80377720,
		"GC2D::@11944": 0x80377740,
		"@11944": 0x80377740,
		"GC2D::@11945": 0x80377758,
		"@11945": 0x80377758,
		"GC2D::@3538": 0x80377acc,
		"GC2D::@3539": 0x80377adc,
		"GC2D::@3540": 0x80377aec,
		"GC2D::@3541": 0x80377afc,
		"GC2D::@3606": 0x80377b0c,
		"GC2D::@4167": 0x80377b5c,
		"GC2D::@4168": 0x80377b9c,
		"GC2D::@4925": 0x80377bdc,
		"GC2D::@4926": 0x80377bec,
		"GC2D::@4927": 0x80377c0c,
		"GC2D::@4928": 0x80377c24,
		"GC2D::@4929": 0x80377c40,
		"GC2D::@6986": 0x80377d00,
		"@6986": 0x80377d00,
		"GC2D::@6988": 0x80377d10,
		"@6988": 0x80377d10,
		"GC2D::@6989": 0x80377d1c,
		"@6989": 0x80377d1c,
		"GC2D::@6990": 0x80377d40,
		"@6990": 0x80377d40,
		"GC2D::@6991": 0x80377d60,
		"@6991": 0x80377d60,
		"GC2D::@6992": 0x80377d7c,
		"@6992": 0x80377d7c,
		"GC2D::@2698": 0x80377e70,
		"GC2D::@7772": 0x80377ea8,
		"@7772": 0x80377ea8,
		"GC2D::@7773": 0x80377ebc,
		"@7773": 0x80377ebc,
		"GC2D::@7774": 0x80377ed0,
		"@7774": 0x80377ed0,
		"GC2D::@7775": 0x80377ee4,
		"@7775": 0x80377ee4,
		"GC2D::@8332": 0x80377ef4,
		"GC2D::@8333": 0x80377f0c,
		"GC2D::@8334": 0x80377f18,
		"GC2D::@8335": 0x80377f28,
		"GC2D::@8336": 0x80377f34,
		"GC2D::@8338": 0x80377f58,
		"GC2D::@1922": 0x80377f98,
		"GC2D::@3469": 0x80377fa4,
		"GC2D::@3470": 0x80377fb4,
		"GC2D::@3471": 0x80377fc8,
		"GC2D::@3472": 0x80377fe4,
		"GC2D::@1861": 0x80378670,
		"GC2D::@1870": 0x80378688,
		"@1870": 0x80378688,
		"MoveBG::@3719": 0x80381878,
		"MoveBG::@3720": 0x8038188c,
		"MoveBG::@3749": 0x803818a0,
		"MoveBG::@3874": 0x80381908,
		"MoveBG::@3875": 0x8038192c,
		"MoveBG::@4498": 0x80381a94,
		"@4498": 0x80381a94,
		"MoveBG::@4499": 0x80381aa8,
		"MoveBG::@4576": 0x80381abc,
		"MoveBG::@4577": 0x80381ad0,
		"MoveBG::@4578": 0x80381ae4,
		"MoveBG::@4797": 0x80381b10,
		"MoveBG::@4812": 0x80381b20,
		"@4812": 0x80381b20,
		"MoveBG::@4982": 0x80381ba0,
		"MoveBG::@5230": 0x80381bac,
		"System::@2572": 0x80392518,
		"System::@2259": 0x803927a0,
		"System::@2260": 0x803927d0,
		"System::@2261": 0x80392808,
		"System::@2262": 0x8039283c,
		"System::@2444": 0x8039288c,
		"System::@2445": 0x803928bc,
		"System::@3075": 0x803928e0,
		"Camera::@2163": 0x8039b510,
		"Camera::@2168": 0x8039b540,
		"Camera::@1852": 0x8039b600,
		"@1852": 0x8039b600,
		"Camera::@1853": 0x8039b61c,
		"@1853": 0x8039b61c,
		"Camera::@1849": 0x8039b680,
		"@1849": 0x8039b680,
		"Enemy::@2679": 0x803679cc,
		"Enemy::@2622": 0x80367a78,
		"Enemy::@2781": 0x80367d0c,
		"Enemy::@2782": 0x80367d18,
		"Enemy::@2784": 0x80367d30,
		"Enemy::@6427": 0x80368404,
		"@6427": 0x80368404,
		"Enemy::@6428": 0x8036842c,
		"@6428": 0x8036842c,
		"Enemy::@6429": 0x80368450,
		"@6429": 0x80368450,
		"Enemy::@6430": 0x80368490,
		"@6430": 0x80368490,
		"Enemy::@6713": 0x80368778,
		"@6713": 0x80368778,
		"Enemy::@6714": 0x80368794,
		"@6714": 0x80368794,
		"Enemy::@6715": 0x803687ac,
		"@6715": 0x803687ac,
		"Enemy::@4996": 0x80368b58,
		"Enemy::@5219": 0x80368b7c,
		"Enemy::@5243": 0x80368b9c,
		"Enemy::@5344": 0x80368cec,
		"Enemy::@2239": 0x80368dfc,
		"Enemy::@2451": 0x80368e40,
		"Enemy::@2452": 0x80368e78,
		"Enemy::@2453": 0x80368eac,
		"Enemy::tevColorData$3142": 0x8036918c,
		"tevColorData$3142": 0x8036918c,
		"Enemy::@7550": 0x80369250,
		"@7550": 0x80369250,
		"Enemy::@7734": 0x803692a0,
		"@7734": 0x803692a0,
		"Enemy::@7743": 0x803692d8,
		"@7743": 0x803692d8,
		"Enemy::@7754": 0x803692e4,
		"@7754": 0x803692e4,
		"Enemy::@7776": 0x8036930c,
		"@7776": 0x8036930c,
		"Enemy::@7820": 0x8036934c,
		"@7820": 0x8036934c,
		"Enemy::@7824": 0x80369364,
		"@7824": 0x80369364,
		"Enemy::@7827": 0x80369374,
		"@7827": 0x80369374,
		"Enemy::@7837": 0x80369390,
		"@7837": 0x80369390,
		"Enemy::@7903": 0x803693a0,
		"@7903": 0x803693a0,
		"Enemy::@7925": 0x80369414,
		"@7925": 0x80369414,
		"Enemy::@8178": 0x8036945c,
		"@8178": 0x8036945c,
		"Enemy::@2432": 0x8036965c,
		"Enemy::@2463": 0x803696ec,
		"Enemy::@2464": 0x80369714,
		"Enemy::@2485": 0x803697a4,
		"Enemy::xzTable$2561": 0x803697bc,
		"xzTable$2561": 0x803697bc,
		"Enemy::@3813": 0x803697dc,
		"Enemy::@3647": 0x80369ab8,
		"Enemy::@3649": 0x80369ad0,
		"Enemy::@4256": 0x80369b8c,
		"Enemy::@4522": 0x80369ba8,
		"Enemy::@4523": 0x80369bc4,
		"Enemy::@4524": 0x80369bd0,
		"Enemy::@4677": 0x80369c38,
		"Enemy::@4856": 0x80369e94,
		"Enemy::@5110": 0x80369eb0,
		"Enemy::@5111": 0x80369ec4,
		"Enemy::@5112": 0x80369ed4,
		"Enemy::idxarray$3678": 0x8036a790,
		"idxarray$3678": 0x8036a790,
		"Enemy::entry$3710": 0x8036a840,
		"entry$3710": 0x8036a840,
		"Enemy::@4701": 0x8036a8d4,
		"Enemy::@4702": 0x8036a8e8,
		"Enemy::@4703": 0x8036a8fc,
		"Enemy::@4709": 0x8036a928,
		"Enemy::@5588": 0x8036a960,
		"@5588": 0x8036a960,
		"Enemy::@5600": 0x8036ab30,
		"@5600": 0x8036ab30,
		"Enemy::@5601": 0x8036ab54,
		"@5601": 0x8036ab54,
		"Enemy::@5602": 0x8036ab78,
		"@5602": 0x8036ab78,
		"Enemy::@5603": 0x8036aba0,
		"@5603": 0x8036aba0,
		"Enemy::@5604": 0x8036abc4,
		"@5604": 0x8036abc4,
		"Enemy::@5605": 0x8036abec,
		"@5605": 0x8036abec,
		"Enemy::@5606": 0x8036ac14,
		"@5606": 0x8036ac14,
		"Enemy::@5607": 0x8036ac3c,
		"Enemy::@5608": 0x8036ac64,
		"@5608": 0x8036ac64,
		"Enemy::@5609": 0x8036ac88,
		"@5609": 0x8036ac88,
		"Enemy::@5610": 0x8036acac,
		"@5610": 0x8036acac,
		"Enemy::@5611": 0x8036acd0,
		"@5611": 0x8036acd0,
		"Enemy::@5612": 0x8036acf4,
		"@5612": 0x8036acf4,
		"Enemy::@8143": 0x8036ad24,
		"@8143": 0x8036ad24,
		"Enemy::@8144": 0x8036ad38,
		"@8144": 0x8036ad38,
		"Enemy::@8148": 0x8036ad44,
		"@8148": 0x8036ad44,
		"Enemy::@9198": 0x8036ae30,
		"@9198": 0x8036ae30,
		"Enemy::@9199": 0x8036ae44,
		"@9199": 0x8036ae44,
		"Enemy::@9201": 0x8036ae58,
		"@9201": 0x8036ae58,
		"Enemy::@9203": 0x8036ae6c,
		"@9203": 0x8036ae6c,
		"Enemy::@9204": 0x8036ae84,
		"@9204": 0x8036ae84,
		"Enemy::@9206": 0x8036ae9c,
		"@9206": 0x8036ae9c,
		"Enemy::@9208": 0x8036aeb4,
		"@9208": 0x8036aeb4,
		"Enemy::@9209": 0x8036aecc,
		"@9209": 0x8036aecc,
		"Enemy::@9211": 0x8036aee0,
		"@9211": 0x8036aee0,
		"Enemy::@9213": 0x8036aef4,
		"@9213": 0x8036aef4,
		"Enemy::@9214": 0x8036af08,
		"@9214": 0x8036af08,
		"Enemy::@9215": 0x8036af1c,
		"@9215": 0x8036af1c,
		"Enemy::@9216": 0x8036af28,
		"@9216": 0x8036af28,
		"Enemy::@9217": 0x8036af3c,
		"@9217": 0x8036af3c,
		"Enemy::@9219": 0x8036af4c,
		"@9219": 0x8036af4c,
		"Enemy::@9220": 0x8036af60,
		"@9220": 0x8036af60,
		"Enemy::@9221": 0x8036af74,
		"@9221": 0x8036af74,
		"Enemy::@9223": 0x8036af84,
		"@9223": 0x8036af84,
		"Enemy::@9224": 0x8036af94,
		"@9224": 0x8036af94,
		"Enemy::@9225": 0x8036afa4,
		"@9225": 0x8036afa4,
		"Enemy::@9226": 0x8036afb4,
		"@9226": 0x8036afb4,
		"Enemy::@9228": 0x8036afc4,
		"@9228": 0x8036afc4,
		"Enemy::@2142": 0x8036b38c,
		"Enemy::@2383": 0x8036b408,
		"Enemy::@3396": 0x8036b4e8,
		"Enemy::@5203": 0x8036b6e4,
		"Enemy::@5292": 0x8036b6f4,
		"Enemy::@5300": 0x8036b700,
		"Enemy::@5301": 0x8036b714,
		"Enemy::@5404": 0x8036b740,
		"@5404": 0x8036b740,
		"Enemy::@5405": 0x8036b750,
		"Enemy::@5406": 0x8036b760,
		"Enemy::@7291": 0x8036ba44,
		"@7291": 0x8036ba44,
		"Enemy::@7292": 0x8036ba70,
		"@7292": 0x8036ba70,
		"Enemy::@7431": 0x8036bab8,
		"@7431": 0x8036bab8,
		"Enemy::@7432": 0x8036bac4,
		"@7432": 0x8036bac4,
		"Enemy::@8403": 0x8036baec,
		"@8403": 0x8036baec,
		"Enemy::@8767": 0x8036bb0c,
		"@8767": 0x8036bb0c,
		"Enemy::@8952": 0x8036bb20,
		"@8952": 0x8036bb20,
		"Enemy::@9152": 0x8036bd50,
		"@9152": 0x8036bd50,
		"Enemy::entry$3613": 0x8036c254,
		"entry$3613": 0x8036c254,
		"Enemy::entry$3618": 0x8036c2d4,
		"entry$3618": 0x8036c2d4,
		"Enemy::@4135": 0x8036c360,
		"Enemy::@4136": 0x8036c370,
		"Enemy::@5868": 0x8036c4e0,
		"Enemy::@6558": 0x8036c5dc,
		"Enemy::@6559": 0x8036c5e8,
		"Enemy::@6560": 0x8036c5f8,
		"Enemy::@7227": 0x8036c694,
		"@7227": 0x8036c694,
		"Enemy::@7228": 0x8036c6a0,
		"@7228": 0x8036c6a0,
		"Enemy::@7229": 0x8036c6b0,
		"@7229": 0x8036c6b0,
		"Enemy::@7231": 0x8036c6cc,
		"@7231": 0x8036c6cc,
		"Enemy::@8204": 0x8036c6d8,
		"@8204": 0x8036c6d8,
		"Enemy::@8339": 0x8036c848,
		"@8339": 0x8036c848,
		"Enemy::@8340": 0x8036c858,
		"@8340": 0x8036c858,
		"Enemy::@8341": 0x8036c86c,
		"@8341": 0x8036c86c,
		"Enemy::@8343": 0x8036c880,
		"@8343": 0x8036c880,
		"Enemy::@4823": 0x8036cb5c,
		"@4823": 0x8036cb5c,
		"Enemy::@4902": 0x8036cbd8,
		"Enemy::@4991": 0x8036cc68,
		"Enemy::@3482": 0x8036d1e4,
		"Enemy::entry$3481": 0x8036d1f8,
		"entry$3481": 0x8036d1f8,
		"Enemy::@3525": 0x8036d620,
		"Enemy::@5220": 0x8036d67c,
		"Enemy::@6086": 0x8036d700,
		"@6086": 0x8036d700,
		"Enemy::@2488": 0x8036d9ac,
		"Enemy::entry$3473": 0x8036db4c,
		"entry$3473": 0x8036db4c,
		"Enemy::@5001": 0x8036dc18,
		"Enemy::@5002": 0x8036dc44,
		"Enemy::@5003": 0x8036dc6c,
		"Enemy::@5004": 0x8036dc94,
		"Enemy::@5005": 0x8036dcbc,
		"Enemy::@5006": 0x8036dce4,
		"Enemy::@5007": 0x8036dd0c,
		"Enemy::@7578": 0x8036ddcc,
		"Enemy::@7583": 0x8036de10,
		"Enemy::@7584": 0x8036de24,
		"Enemy::@5626": 0x8036e0b0,
		"@5626": 0x8036e0b0,
		"Enemy::@5679": 0x8036e0bc,
		"Enemy::@3331": 0x8036e4b4,
		"Enemy::@4605": 0x8036e51c,
		"Enemy::@4606": 0x8036e53c,
		"Enemy::@4639": 0x8036e580,
		"Enemy::@5388": 0x8036e60c,
		"@5388": 0x8036e60c,
		"Enemy::@4425": 0x8036e918,
		"Enemy::@2420": 0x8036e9ec,
		"Enemy::@2632": 0x8036ea30,
		"Enemy::@2634": 0x8036ea9c,
		"Enemy::@5041": 0x8036ed64,
		"Enemy::@5042": 0x8036ed78,
		"Enemy::@5043": 0x8036ed88,
		"Enemy::@5044": 0x8036ed9c,
		"Enemy::xzTable$3483": 0x8036f060,
		"xzTable$3483": 0x8036f060,
		"Enemy::@3930": 0x8036f080,
		"Enemy::@6147": 0x8036f178,
		"Enemy::@8534": 0x8036f710,
		"@8534": 0x8036f710,
		"Enemy::@8537": 0x8036f71c,
		"@8537": 0x8036f71c,
		"Enemy::@8597": 0x8036f734,
		"@8597": 0x8036f734,
		"Enemy::@9057": 0x8036f8a4,
		"@9057": 0x8036f8a4,
		"Enemy::entry$2585": 0x8036fa00,
		"entry$2585": 0x8036fa00,
		"Enemy::@2748": 0x8036fa50,
		"Enemy::@2750": 0x8036fa60,
		"Enemy::@3194": 0x8036fc44,
		"Enemy::xzTable$3109": 0x8036fed0,
		"xzTable$3109": 0x8036fed0,
		"Enemy::@5160": 0x8036ff78,
		"Enemy::@5161": 0x8036ff8c,
		"Enemy::@6075": 0x8037011c,
		"@6075": 0x8037011c,
		"Enemy::@6171": 0x80370244,
		"Enemy::@2547": 0x80370278,
		"Enemy::@2548": 0x803702a8,
		"Enemy::@2549": 0x803702e0,
		"Enemy::@2550": 0x80370314,
		"Enemy::@3087": 0x803703c4,
		"Enemy::entry$3303": 0x80370418,
		"entry$3303": 0x80370418,
		"Enemy::eyeTable$3618": 0x803704a4,
		"eyeTable$3618": 0x803704a4,
		"Enemy::@7887": 0x80370674,
		"@7887": 0x80370674,
		"Enemy::@7888": 0x80370684,
		"@7888": 0x80370684,
		"Enemy::@7946": 0x8037069c,
		"Enemy::@7947": 0x803706c4,
		"Enemy::@7948": 0x803706ec,
		"Enemy::@7949": 0x80370714,
		"Enemy::@7950": 0x80370740,
		"@7950": 0x80370740,
		"Enemy::@7951": 0x8037076c,
		"@7951": 0x8037076c,
		"Enemy::@7952": 0x80370794,
		"@7952": 0x80370794,
		"Enemy::@7953": 0x803707c0,
		"@7953": 0x803707c0,
		"Enemy::@8066": 0x803708bc,
		"@8066": 0x803708bc,
		"Enemy::@8067": 0x803708d0,
		"@8067": 0x803708d0,
		"Enemy::@8068": 0x803708e4,
		"@8068": 0x803708e4,
		"Enemy::@8069": 0x803708f8,
		"@8069": 0x803708f8,
		"Enemy::@8904": 0x80370bac,
		"@8904": 0x80370bac,
		"Enemy::@9046": 0x80370bf0,
		"@9046": 0x80370bf0,
		"Enemy::@9047": 0x80370c1c,
		"@9047": 0x80370c1c,
		"Enemy::@9048": 0x80370c48,
		"Enemy::@9051": 0x80370c70,
		"@9051": 0x80370c70,
		"Enemy::@3806": 0x80370fe8,
		"Enemy::@3091": 0x80371450,
		"Enemy::@4303": 0x8037154c,
		"Enemy::@4305": 0x80371560,
		"Enemy::@4306": 0x80371574,
		"@4306": 0x80371574,
		"Enemy::@5669": 0x80371684,
		"Enemy::@5670": 0x8037169c,
		"Enemy::@5676": 0x803716b4,
		"Enemy::@5682": 0x803716c4,
		"Enemy::@5683": 0x803716dc,
		"Enemy::@5738": 0x803717bc,
		"@5738": 0x803717bc,
		"Enemy::@5739": 0x803717cc,
		"@5739": 0x803717cc,
		"Enemy::@5740": 0x803717dc,
		"@5740": 0x803717dc,
		"Enemy::@2260": 0x803717fc,
		"Enemy::entry$2763": 0x80371e60,
		"entry$2763": 0x80371e60,
		"Enemy::entry$2766": 0x80371e88,
		"entry$2766": 0x80371e88,
		"Enemy::entry$2770": 0x80371eb0,
		"entry$2770": 0x80371eb0,
		"Enemy::entry$2991": 0x80372e50,
		"entry$2991": 0x80372e50,
		"Enemy::entry$2257": 0x80373454,
		"entry$2257": 0x80373454,
		"Enemy::@2268": 0x8037346c,
		"Enemy::idx$3289": 0x80373748,
		"idx$3289": 0x80373748,
		"Enemy::zangle$3566": 0x80373758,
		"zangle$3566": 0x80373758,
		"Enemy::zangle$3571": 0x80373768,
		"zangle$3571": 0x80373768,
		"Enemy::zangle$3577": 0x80373788,
		"zangle$3577": 0x80373788,
		"Enemy::@6640": 0x80373800,
		"@6640": 0x80373800,
		"Enemy::@6641": 0x8037380c,
		"@6641": 0x8037380c,
		"Enemy::@6643": 0x8037381c,
		"@6643": 0x8037381c,
		"Enemy::tevColorData1$2783": 0x80373a48,
		"tevColorData1$2783": 0x80373a48,
		"Enemy::tevColorData2$2784": 0x80373a88,
		"tevColorData2$2784": 0x80373a88,
		"Enemy::entry$2671": 0x80373c10,
		"entry$2671": 0x80373c10,
		"Enemy::@2591": 0x80374378,
		"Enemy::entry$2840": 0x803743a8,
		"entry$2840": 0x803743a8,
		"Enemy::@2774": 0x80374ecc,
		"Enemy::entry$2876": 0x80374f0c,
		"entry$2876": 0x80374f0c,
		"Enemy::entry$3159": 0x803751cc,
		"entry$3159": 0x803751cc,
		"Enemy::entry$3343": 0x8037522c,
		"entry$3343": 0x8037522c,
		"Enemy::@4805": 0x80375294,
		"@4805": 0x80375294,
		"Enemy::@6031": 0x8037549c,
		"Enemy::@6035": 0x803754c8,
		"Enemy::@6037": 0x803754d8,
		"Enemy::@6038": 0x803754f0,
		"Enemy::@6039": 0x80375508,
		"Enemy::@6040": 0x80375520,
		"Enemy::entry$2662": 0x80375a14,
		"entry$2662": 0x80375a14,
		"Enemy::@3397": 0x80375e38,
		"Enemy::entry$3396": 0x80375e48,
		"entry$3396": 0x80375e48,
		"Enemy::entry$3100": 0x80376310,
		"entry$3100": 0x80376310,
		"Enemy::@4520": 0x80376454,
		"Enemy::@4521": 0x80376460,
		"Enemy::@4780": 0x80376488,
		"Enemy::@2388": 0x803765b8,
		"Enemy::@2394": 0x80376628,
		"Enemy::entry$2529": 0x80376658,
		"entry$2529": 0x80376658,
		"Enemy::@4426": 0x803767d8,
		"Enemy::entry$2978": 0x80376920,
		"entry$2978": 0x80376920,
		"Enemy::@3230": 0x80376ad0,
		"Enemy::@3254": 0x80376af0,
		"Enemy::@5689": 0x80376b68,
		"Enemy::@5690": 0x80376b84,
		"Enemy::@5692": 0x80376b9c,
		"Enemy::@5694": 0x80376bac,
		"Enemy::@2623": 0x803770f0,
		"Enemy::entry$2837": 0x8037712c,
		"entry$2837": 0x8037712c,
		"Enemy::@2574": 0x803772b8,
		"Enemy::entry$2870": 0x803772f0,
		"entry$2870": 0x803772f0,
		"Enemy::@4864": 0x803773c8,
		"GC2D::@3352": 0x80377c88,
		"GC2D::@3353": 0x80377c94,
		"GC2D::@3354": 0x80377cb0,
		"GC2D::@2359": 0x80377db0,
		"GC2D::@2360": 0x80377de0,
		"GC2D::@2361": 0x80377e18,
		"GC2D::@2362": 0x80377e4c,
		"GC2D::@2741": 0x80377e8c,
		"GC2D::@3958": 0x803780a4,
		"GC2D::@3959": 0x803780bc,
		"GC2D::@3960": 0x803780dc,
		"GC2D::@3963": 0x803780fc,
		"GC2D::@3964": 0x80378118,
		"GC2D::@3965": 0x80378134,
		"GC2D::@3966": 0x80378150,
		"GC2D::@4086": 0x803784d0,
		"GC2D::@4087": 0x803784dc,
		"GC2D::@4088": 0x803784fc,
		"GC2D::@1001": 0x80378610,
		"@1001": 0x80378610,
		"GC2D::@1193": 0x80378628,
		"@1193": 0x80378628,
		"Map::@3230": 0x80378ddc,
		"Map::@3312": 0x80378e04,
		"Map::@3313": 0x80378e20,
		"Map::@3314": 0x80378e30,
		"Map::point_name_table$2630": 0x80378fd0,
		"point_name_table$2630": 0x80378fd0,
		"Map::@3022": 0x80379b20,
		"Map::@3330": 0x80379b44,
		"Map::@3331": 0x80379b50,
		"Map::@3332": 0x80379b68,
		"Map::@3358": 0x80379b8c,
		"Map::@3359": 0x80379ba4,
		"Map::@3482": 0x80379bbc,
		"Map::@3483": 0x80379bd4,
		"Map::@3034": 0x8037a114,
		"Map::@2995": 0x8037a310,
		"Map::@2996": 0x8037a328,
		"Map::@4206": 0x8037a4fc,
		"Map::@4352": 0x8037a508,
		"Map::@4353": 0x8037a520,
		"Map::@4354": 0x8037a538,
		"Map::@4355": 0x8037a554,
		"Map::@4356": 0x8037a574,
		"Map::@4357": 0x8037a594,
		"Map::@4434": 0x8037a5c4,
		"Map::@4435": 0x8037a5d4,
		"Map::@4436": 0x8037a5e0,
		"Map::@4733": 0x8037a5ec,
		"Map::@4826": 0x8037a6c8,
		"Map::@4827": 0x8037a6d8,
		"Map::@4828": 0x8037a6e8,
		"@4828": 0x8037a6e8,
		"Map::@4829": 0x8037a6f4,
		"Map::@4830": 0x8037a700,
		"Map::@4831": 0x8037a70c,
		"MoveBG::JuiceBlock_hit_data_table": 0x8037c3b0,
		"JuiceBlock_hit_data_table": 0x8037c3b0,
		"MoveBG::JuiceBlock_obj_hit_info": 0x8037c3c0,
		"JuiceBlock_obj_hit_info": 0x8037c3c0,
		"MoveBG::entry$3271": 0x803802b0,
		"entry$3271": 0x803802b0,
		"MoveBG::@3475": 0x803802bc,
		"MoveBG::@3478": 0x803802d8,
		"MoveBG::@3479": 0x803802e4,
		"MoveBG::@3480": 0x803802f0,
		"MoveBG::@3481": 0x803802fc,
		"MoveBG::@3482": 0x8038030c,
		"MoveBG::@3483": 0x80380318,
		"MoveBG::@3762": 0x80380328,
		"MoveBG::@3764": 0x80380338,
		"MoveBG::@3765": 0x80380344,
		"MoveBG::@4156": 0x803806cc,
		"MoveBG::@4157": 0x803806d8,
		"MoveBG::@4158": 0x803806f4,
		"MoveBG::@4159": 0x80380710,
		"MoveBG::@4096": 0x80380ba8,
		"MoveBG::@4097": 0x80380bc8,
		"MoveBG::@4098": 0x80380be0,
		"MoveBG::@4099": 0x80380bfc,
		"MoveBG::@4304": 0x80380c14,
		"MoveBG::@4565": 0x80380c34,
		"@4565": 0x80380c34,
		"MoveBG::@4583": 0x80380c58,
		"MoveBG::@4746": 0x80380c84,
		"MoveBG::@2694": 0x80380cc4,
		"MoveBG::@2695": 0x80380cd0,
		"MoveBG::@3683": 0x803811f4,
		"@3683": 0x803811f4,
		"MoveBG::@3684": 0x80381208,
		"MoveBG::@4029": 0x80381220,
		"MoveBG::@4239": 0x80381274,
		"MoveBG::@4293": 0x80381294,
		"MoveBG::@2226": 0x803812b4,
		"MoveBG::@2282": 0x803812c8,
		"MoveBG::@2285": 0x80381364,
		"MoveBG::@4019": 0x803813dc,
		"MoveBG::@4151": 0x8038140c,
		"MoveBG::@4200": 0x80381438,
		"MoveBG::@4624": 0x80381448,
		"MoveBG::@5221": 0x8038145c,
		"MoveBG::@4111": 0x803819c8,
		"MoveBG::@3508": 0x80381cdc,
		"MoveBG::@3509": 0x80381cf4,
		"MoveBG::@3588": 0x80381e18,
		"MoveBG::@3589": 0x80381e3c,
		"MoveBG::@3705": 0x80381e60,
		"MoveBG::@3712": 0x80381ea4,
		"MoveBG::@3863": 0x80381f24,
		"MoveBG::@4089": 0x80381f30,
		"MoveBG::@4296": 0x80381f3c,
		"MoveBG::@4127": 0x80382154,
		"MoveBG::@4128": 0x80382164,
		"MoveBG::@2502": 0x80382270,
		"MoveBG::@3554": 0x80383d98,
		"MoveBG::@3555": 0x80383dbc,
		"MoveBG::@4464": 0x80383e7c,
		"@4464": 0x80383e7c,
		"MoveBG::@4466": 0x80383e8c,
		"@4466": 0x80383e8c,
		"MoveBG::@4467": 0x80383e9c,
		"@4467": 0x80383e9c,
		"MoveBG::@5406": 0x80383ec8,
		"MoveBG::@5407": 0x80383ee8,
		"MoveBG::@5408": 0x80383f08,
		"MoveBG::@5409": 0x80383f2c,
		"MoveBG::@5836": 0x80383f50,
		"MoveBG::@5839": 0x80383f8c,
		"MoveBG::@5961": 0x80383ff4,
		"MoveBG::@5962": 0x80384008,
		"MoveBG::@5963": 0x80384014,
		"MoveBG::@5964": 0x80384024,
		"@5964": 0x80384024,
		"MoveBG::@5965": 0x80384034,
		"@5965": 0x80384034,
		"NPC::@2618": 0x80385818,
		"NPC::@2619": 0x80385828,
		"NPC::@2620": 0x80385838,
		"NPC::@2621": 0x80385848,
		"NPC::@2622": 0x80385858,
		"NPC::@2671": 0x80385868,
		"NPC::@2674": 0x80385874,
		"NPC::@2675": 0x80385888,
		"NPC::@2712": 0x803858a0,
		"NPC::@2713": 0x803858bc,
		"NPC::@2714": 0x803858d0,
		"NPC::@2715": 0x803858e8,
		"NPC::@2716": 0x803858f8,
		"NPC::@2717": 0x8038590c,
		"NPC::@2718": 0x80385920,
		"NPC::@2719": 0x8038593c,
		"NPC::@2720": 0x8038594c,
		"NPC::@2766": 0x80385a0c,
		"NPC::@2767": 0x80385a2c,
		"NPC::@2768": 0x80385a38,
		"NPC::@3121": 0x80385a54,
		"Strategic::@2840": 0x8038cda0,
		"Strategic::@2841": 0x8038cdb0,
		"Strategic::@2779": 0x8038ced0,
		"Strategic::@2780": 0x8038cef0,
		"Strategic::@2582": 0x8038d504,
		"Strategic::@2583": 0x8038d520,
		"Player::@2307": 0x8038dbe4,
		"Player::@2470": 0x8038dbf4,
		"Player::@2471": 0x8038dc0c,
		"Player::@2472": 0x8038dc24,
		"Player::@2473": 0x8038dc4c,
		"Player::@2474": 0x8038dc68,
		"Player::@2475": 0x8038dc78,
		"Player::@2429": 0x8038dc88,
		"Player::@5173": 0x8038e718,
		"Player::@5174": 0x8038e724,
		"Player::@5175": 0x8038e734,
		"Player::@5651": 0x8038e744,
		"Player::@5653": 0x8038e75c,
		"Player::@5654": 0x8038e768,
		"@5654": 0x8038e768,
		"Player::@5655": 0x8038e774,
		"@5655": 0x8038e774,
		"Player::@5656": 0x8038e780,
		"@5656": 0x8038e780,
		"Player::@5657": 0x8038e78c,
		"@5657": 0x8038e78c,
		"Player::@5658": 0x8038e798,
		"@5658": 0x8038e798,
		"Player::@5659": 0x8038e7a4,
		"Player::@2650": 0x8038ebac,
		"Player::@2651": 0x8038ebd4,
		"Player::@2652": 0x8038ebfc,
		"Player::@3043": 0x8038ecc4,
		"Player::@2685": 0x8038ee44,
		"Player::@2687": 0x8038ee50,
		"Player::@4118": 0x8038f0b8,
		"Player::@4119": 0x8038f0d0,
		"Player::@4429": 0x8038f128,
		"Player::@4430": 0x8038f138,
		"Player::@4431": 0x8038f150,
		"Player::@4436": 0x8038f1a0,
		"Player::@4437": 0x8038f1b0,
		"Player::@4438": 0x8038f1c8,
		"Player::@4439": 0x8038f1e0,
		"Player::@4483": 0x8038f1ec,
		"Player::@4484": 0x8038f1f8,
		"Player::@4485": 0x8038f21c,
		"Player::@4486": 0x8038f244,
		"Player::@4487": 0x8038f268,
		"Player::@4488": 0x8038f274,
		"Player::@4489": 0x8038f298,
		"Player::@4490": 0x8038f2a4,
		"@4490": 0x8038f2a4,
		"Player::@6089": 0x8038f314,
		"Player::@6092": 0x8038f320,
		"Player::@6094": 0x8038f32c,
		"Player::@6096": 0x8038f338,
		"Player::@6097": 0x8038f344,
		"Player::@6099": 0x8038f350,
		"Player::@6101": 0x8038f360,
		"Player::@6102": 0x8038f36c,
		"Player::@6103": 0x8038f37c,
		"@6103": 0x8038f37c,
		"Player::@6104": 0x8038f388,
		"@6104": 0x8038f388,
		"Player::@6105": 0x8038f394,
		"@6105": 0x8038f394,
		"Player::@6106": 0x8038f3a4,
		"@6106": 0x8038f3a4,
		"Player::@6107": 0x8038f3b0,
		"@6107": 0x8038f3b0,
		"Player::@6108": 0x8038f3bc,
		"@6108": 0x8038f3bc,
		"Player::@6110": 0x8038f3c8,
		"@6110": 0x8038f3c8,
		"Player::@6112": 0x8038f3d4,
		"@6112": 0x8038f3d4,
		"Player::@6113": 0x8038f3e0,
		"@6113": 0x8038f3e0,
		"Player::@6114": 0x8038f3f0,
		"@6114": 0x8038f3f0,
		"Player::@6115": 0x8038f3fc,
		"@6115": 0x8038f3fc,
		"Player::@6116": 0x8038f408,
		"@6116": 0x8038f408,
		"Player::@6117": 0x8038f418,
		"@6117": 0x8038f418,
		"Player::@6118": 0x8038f42c,
		"@6118": 0x8038f42c,
		"Player::@6120": 0x8038f440,
		"@6120": 0x8038f440,
		"Player::@6121": 0x8038f44c,
		"@6121": 0x8038f44c,
		"Player::@6122": 0x8038f45c,
		"@6122": 0x8038f45c,
		"Player::@6123": 0x8038f468,
		"@6123": 0x8038f468,
		"Player::@6124": 0x8038f474,
		"@6124": 0x8038f474,
		"Player::@6126": 0x8038f484,
		"@6126": 0x8038f484,
		"Player::@6128": 0x8038f494,
		"@6128": 0x8038f494,
		"Player::@6129": 0x8038f4a4,
		"Player::@6131": 0x8038f4b8,
		"Player::@6133": 0x8038f4cc,
		"Player::@6135": 0x8038f4dc,
		"Player::@6136": 0x8038f4f0,
		"Player::@6137": 0x8038f504,
		"Player::@6138": 0x8038f518,
		"Player::@6140": 0x8038f528,
		"Player::@2177": 0x8038f544,
		"Player::@2233": 0x8038f558,
		"Player::@2234": 0x8038f588,
		"Player::@2235": 0x8038f5c0,
		"Player::@2236": 0x8038f5f4,
		"Player::@4689": 0x8038f66c,
		"Player::@4957": 0x8038f694,
		"Player::@4961": 0x8038f6b8,
		"Player::@4962": 0x8038f6d4,
		"Player::@4963": 0x8038f6f0,
		"Player::@4964": 0x8038f708,
		"Player::@4965": 0x8038f724,
		"Player::@4975": 0x8038f730,
		"Player::@4976": 0x8038f73c,
		"Player::@4978": 0x8038f748,
		"Player::@4979": 0x8038f764,
		"Player::@4980": 0x8038f780,
		"Player::@4981": 0x8038f7a4,
		"Player::@4982": 0x8038f7c0,
		"Player::@4983": 0x8038f7e0,
		"Player::@4984": 0x8038f7fc,
		"Player::@4985": 0x8038f81c,
		"Player::@4986": 0x8038f83c,
		"Player::@4987": 0x8038f85c,
		"Player::@4991": 0x8038f8d0,
		"Player::@4992": 0x8038f8ec,
		"Player::@4993": 0x8038f90c,
		"Player::@4994": 0x8038f92c,
		"Player::@4995": 0x8038f94c,
		"Player::@4996": 0x8038f968,
		"Player::@4997": 0x8038f988,
		"Player::@4998": 0x8038f9a4,
		"Player::@2237": 0x8038f9d4,
		"Player::@2293": 0x8038f9e8,
		"Player::@2294": 0x8038fa18,
		"Player::@2759": 0x8038fb00,
		"Player::@2358": 0x8038fba4,
		"Player::@2546": 0x8038fc18,
		"Player::@2547": 0x8038fc2c,
		"Player::@2548": 0x8038fc44,
		"Player::@2549": 0x8038fc58,
		"Player::@2550": 0x8038fc6c,
		"Player::@2552": 0x8038fc7c,
		"Player::@2554": 0x8038fc8c,
		"Player::@2581": 0x8038fcac,
		"Player::@2582": 0x8038fcb8,
		"Player::@2584": 0x8038fcc4,
		"Player::@2588": 0x8038fcd0,
		"Player::@2607": 0x8038fce0,
		"Player::@2609": 0x8038fcec,
		"Player::@2611": 0x8038fcfc,
		"Player::@2613": 0x8038fd08,
		"Player::@2626": 0x8038fd14,
		"Player::@2754": 0x8038fe08,
		"Player::@2755": 0x8038fe18,
		"Player::@3073": 0x80390254,
		"Player::@3074": 0x80390264,
		"Player::@3135": 0x80390404,
		"Player::@3136": 0x80390418,
		"Player::@3137": 0x8039042c,
		"Player::@3138": 0x80390440,
		"Player::@3235": 0x803905b4,
		"Player::@3236": 0x803905c4,
		"Player::@3238": 0x803905d0,
		"Player::@3239": 0x803905dc,
		"Player::@3313": 0x80390640,
		"Player::@3314": 0x80390650,
		"Player::@3317": 0x80390684,
		"Player::@3318": 0x80390698,
		"Player::@3319": 0x803906a8,
		"Player::@3320": 0x803906b4,
		"Player::@3321": 0x803906c0,
		"Player::@3359": 0x80390774,
		"Player::@3361": 0x80390788,
		"Player::@3363": 0x803907a0,
		"Player::@3550": 0x8039094c,
		"Player::@3551": 0x8039095c,
		"Player::@3555": 0x80390978,
		"Player::@3556": 0x80390984,
		"Player::@3558": 0x80390990,
		"Player::@3962": 0x80390dc0,
		"Player::@4075": 0x803910ec,
		"Player::@4076": 0x80391108,
		"Player::@4077": 0x80391120,
		"Player::@6512": 0x80391134,
		"@6512": 0x80391134,
		"Player::@6513": 0x80391140,
		"@6513": 0x80391140,
		"Player::@6514": 0x8039115c,
		"@6514": 0x8039115c,
		"Player::@6515": 0x8039117c,
		"@6515": 0x8039117c,
		"Player::@4262": 0x80391b78,
		"System::@3448": 0x80391d10,
		"System::@3462": 0x80391d20,
		"System::@3701": 0x80391d30,
		"System::@3702": 0x80391d40,
		"System::@3703": 0x80391d50,
		"System::@3704": 0x80391d64,
		"System::@3705": 0x80391d74,
		"System::@3706": 0x80391d80,
		"System::@3707": 0x80391d94,
		"System::@3854": 0x8039238c,
		"System::@4323": 0x803923c0,
		"System::@4847": 0x803923d4,
		"System::@4869": 0x803923e0,
		"System::@5607": 0x80392410,
		"System::@5797": 0x8039241c,
		"System::@2349": 0x80392590,
		"System::@2350": 0x803925c0,
		"System::@2351": 0x803925f8,
		"System::@2352": 0x8039262c,
		"System::@2688": 0x80392650,
		"System::@2690": 0x8039265c,
		"System::@3911": 0x80392680,
		"System::@3913": 0x80392694,
		"System::@3914": 0x803926ac,
		"System::@4272": 0x80392748,
		"System::sStrMapFile": 0x80392fe0,
		"sStrMapFile": 0x80392fe0,
		"System::@2951": 0x80393110,
		"System::@4625": 0x8039311c,
		"System::@4626": 0x80393128,
		"System::@4627": 0x80393140,
		"System::@4628": 0x8039314c,
		"System::@4629": 0x8039315c,
		"System::@4630": 0x80393168,
		"System::@4631": 0x80393178,
		"System::@4632": 0x8039318c,
		"System::@4633": 0x803931a0,
		"System::@5540": 0x80393b84,
		"System::@5823": 0x80393b98,
		"System::@5353": 0x80396f70,
		"System::@5354": 0x80396f80,
		"System::@5355": 0x80396f8c,
		"System::@5356": 0x80396f9c,
		"System::@5357": 0x80396fa8,
		"System::@5358": 0x80396fbc,
		"System::@5359": 0x80396fdc,
		"System::@5360": 0x80396fe8,
		"System::@5361": 0x80396ff8,
		"System::@5362": 0x80397008,
		"System::@5363": 0x80397018,
		"System::@5364": 0x80397024,
		"System::@5365": 0x80397034,
		"System::@5366": 0x80397044,
		"System::@5367": 0x80397058,
		"@5367": 0x80397058,
		"System::@5368": 0x80397064,
		"System::@3391": 0x803986fc,
		"System::@3392": 0x80398710,
		"System::@3393": 0x80398720,
		"System::@3394": 0x80398734,
		"System::@3395": 0x8039874c,
		"System::@3396": 0x80398760,
		"System::@3397": 0x80398774,
		"System::@3398": 0x80398788,
		"System::@3399": 0x8039879c,
		"JSystem::@1727": 0x80399058,
		"@1727": 0x80399058,
		"JSystem::@1728": 0x8039906c,
		"@1728": 0x8039906c,
		"JSystem::@114": 0x80399088,
		"JSystem::@447": 0x803990b4,
		"@447": 0x803990b4,
		"JSystem::@548": 0x803990d4,
		"@548": 0x803990d4,
		"JSystem::@1809": 0x80399140,
		"JSystem::@1810": 0x80399154,
		"JSystem::@1811": 0x80399174,
		"JSystem::@438": 0x80399190,
		"@438": 0x80399190,
		"JSystem::@439": 0x803991a4,
		"@439": 0x803991a4,
		"JSystem::@302": 0x803991e8,
		"JSystem::@593": 0x803992a4,
		"@593": 0x803992a4,
		"JSystem::@594": 0x803992d0,
		"@594": 0x803992d0,
		"JSystem::@595": 0x803992fc,
		"@595": 0x803992fc,
		"JSystem::@596": 0x80399324,
		"@596": 0x80399324,
		"JSystem::@597": 0x80399354,
		"@597": 0x80399354,
		"JSystem::@606": 0x8039937c,
		"JSystem::@607": 0x8039938c,
		"JSystem::@688": 0x803993a8,
		"JSystem::@689": 0x803993cc,
		"JSystem::@720": 0x803993dc,
		"@720": 0x803993dc,
		"JSystem::@721": 0x80399414,
		"@721": 0x80399414,
		"JSystem::@723": 0x80399424,
		"@723": 0x80399424,
		"JSystem::@727": 0x80399488,
		"@727": 0x80399488,
		"JSystem::@729": 0x80399498,
		"@729": 0x80399498,
		"JSystem::@799": 0x803994e0,
		"JSystem::@800": 0x80399510,
		"JSystem::@801": 0x80399524,
		"JSystem::@802": 0x80399530,
		"JSystem::@803": 0x8039954c,
		"JSystem::@805": 0x80399574,
		"JSystem::@806": 0x80399588,
		"JSystem::@1643": 0x803995d8,
		"JSystem::@1644": 0x803995ec,
		"JSystem::@288": 0x80399608,
		"JSystem::@305": 0x80399670,
		"JSystem::@365": 0x80399740,
		"@365": 0x80399740,
		"JSystem::@366": 0x80399758,
		"@366": 0x80399758,
		"JSystem::@367": 0x8039976c,
		"@367": 0x8039976c,
		"JSystem::@368": 0x80399780,
		"@368": 0x80399780,
		"JSystem::@1545": 0x803997a0,
		"JSystem::@1558": 0x803997cc,
		"JSystem::@1560": 0x803997f0,
		"JSystem::@1495": 0x803998d8,
		"@1495": 0x803998d8,
		"JSystem::@1496": 0x803998ec,
		"@1496": 0x803998ec,
		"JSystem::@1497": 0x803998f8,
		"@1497": 0x803998f8,
		"JSystem::@1498": 0x8039990c,
		"@1498": 0x8039990c,
		"JSystem::@1499": 0x80399920,
		"@1499": 0x80399920,
		"JSystem::@1566": 0x80399960,
		"JSystem::@1567": 0x80399974,
		"JSystem::@1628": 0x80399980,
		"JSystem::@1701": 0x803999a8,
		"JSystem::@1702": 0x803999d0,
		"@1702": 0x803999d0,
		"JSystem::@1709": 0x80399a1c,
		"JSystem::@1710": 0x80399a3c,
		"JSystem::@1711": 0x80399a58,
		"JSystem::@1722": 0x80399a74,
		"@1722": 0x80399a74,
		"JSystem::@1723": 0x80399a9c,
		"JSystem::@1724": 0x80399ac4,
		"@1724": 0x80399ac4,
		"JSystem::@1757": 0x80399ae0,
		"JSystem::@1775": 0x80399af8,
		"@1775": 0x80399af8,
		"JSystem::@1776": 0x80399b24,
		"@1776": 0x80399b24,
		"JSystem::@1777": 0x80399b34,
		"@1777": 0x80399b34,
		"JSystem::@1778": 0x80399b48,
		"JSystem::@1795": 0x80399b70,
		"JSystem::@2006": 0x80399b8c,
		"JSystem::@2007": 0x80399bc4,
		"JSystem::@2193": 0x80399be8,
		"JSystem::@83": 0x80399c18,
		"JSystem::@84": 0x80399c28,
		"JSystem::@321": 0x80399c48,
		"JSystem::@1454": 0x80399ca0,
		"@1454": 0x80399ca0,
		"JSystem::@914": 0x80399cb0,
		"@914": 0x80399cb0,
		"JSystem::@1249": 0x80399cbc,
		"@1249": 0x80399cbc,
		"JSystem::@1251": 0x80399cc8,
		"@1251": 0x80399cc8,
		"JSystem::@329": 0x80399cd8,
		"JSystem::@838": 0x80399ce8,
		"@838": 0x80399ce8,
		"JSystem::@839": 0x80399cf8,
		"@839": 0x80399cf8,
		"JSystem::@885": 0x80399d20,
		"@885": 0x80399d20,
		"JSystem::@813": 0x80399d90,
		"@813": 0x80399d90,
		"JSystem::@999": 0x80399df0,
		"@999": 0x80399df0,
		"JSystem::@95": 0x80399e00,
		"JSystem::@96": 0x80399e10,
		"JSystem::@97": 0x80399e20,
		"JSystem::@98": 0x80399e34,
		"JSystem::@99": 0x80399e44,
		"JSystem::@110": 0x80399e58,
		"JSystem::@272": 0x80399e70,
		"@272": 0x80399e70,
		"JSystem::@289": 0x80399e90,
		"JSystem::halftofull$376": 0x80399ea4,
		"halftofull$376": 0x80399ea4,
		"JSystem::@258": 0x80399f68,
		"@258": 0x80399f68,
		"JSystem::@903": 0x80399fb0,
		"JSystem::@881": 0x80399fc0,
		"@881": 0x80399fc0,
		"JSystem::@882": 0x80399fd0,
		"@882": 0x80399fd0,
		"JSystem::@632": 0x80399fe8,
		"@632": 0x80399fe8,
		"JSystem::@753": 0x80399ff4,
		"JSystem::@1461": 0x8039a00c,
		"@1461": 0x8039a00c,
		"JSystem::@1462": 0x8039a018,
		"@1462": 0x8039a018,
		"JSystem::@1463": 0x8039a02c,
		"@1463": 0x8039a02c,
		"JSystem::@1464": 0x8039a038,
		"@1464": 0x8039a038,
		"JSystem::@1465": 0x8039a044,
		"@1465": 0x8039a044,
		"JSystem::@1468": 0x8039a050,
		"@1468": 0x8039a050,
		"JSystem::@1473": 0x8039a060,
		"@1473": 0x8039a060,
		"JSystem::@1474": 0x8039a06c,
		"@1474": 0x8039a06c,
		"JSystem::@1475": 0x8039a078,
		"@1475": 0x8039a078,
		"JSystem::@1476": 0x8039a084,
		"@1476": 0x8039a084,
		"JSystem::@1480": 0x8039a094,
		"@1480": 0x8039a094,
		"JSystem::@1481": 0x8039a0a0,
		"@1481": 0x8039a0a0,
		"JSystem::@1482": 0x8039a0ac,
		"@1482": 0x8039a0ac,
		"JSystem::@49": 0x8039a148,
		"@49": 0x8039a148,
		"JSystem::@50": 0x8039a15c,
		"@50": 0x8039a15c,
		"JSystem::@61": 0x8039a174,
		"JSystem::@293": 0x8039a190,
		"JSystem::@1143": 0x8039a1b0,
		"@1143": 0x8039a1b0,
		"JSystem::@1144": 0x8039a1c0,
		"@1144": 0x8039a1c0,
		"JSystem::@1578": 0x8039a1d0,
		"JSystem::@395": 0x8039a1e0,
		"@395": 0x8039a1e0,
		"JSystem::@415": 0x8039a1ec,
		"@415": 0x8039a1ec,
		"JSystem::@416": 0x8039a228,
		"@416": 0x8039a228,
		"JSystem::@417": 0x8039a238,
		"@417": 0x8039a238,
		"JSystem::@463": 0x8039a298,
		"JSystem::@530": 0x8039a2a8,
		"@530": 0x8039a2a8,
		"JSystem::@537": 0x8039a2f0,
		"@537": 0x8039a2f0,
		"JASystem::Driver::polys_table": 0x8039a310,
		"polys_table": 0x8039a310,
		"JSystem::@119": 0x8039a320,
		"@119": 0x8039a320,
		"JSystem::@211": 0x8039a32c,
		"@211": 0x8039a32c,
		"JASystem::Driver::relTableSampleCell": 0x8039a338,
		"relTableSampleCell": 0x8039a338,
		"JASystem::Driver::relTableSqRoot": 0x8039a37c,
		"relTableSqRoot": 0x8039a37c,
		"JASystem::Driver::relTableSquare": 0x8039a3c0,
		"relTableSquare": 0x8039a3c0,
		"JSystem::@197": 0x8039a408,
		"JSystem::@216": 0x8039a414,
		"@216": 0x8039a414,
		"JASystem::Arglist": 0x8039a420,
		"Arglist": 0x8039a420,
		"JSystem::@351": 0x8039a53c,
		"@351": 0x8039a53c,
		"JSystem::@442": 0x8039a580,
		"@442": 0x8039a580,
		"JSystem::@444": 0x8039a5a8,
		"@444": 0x8039a5a8,
		"JSystem::@445": 0x8039a5bc,
		"@445": 0x8039a5bc,
		"JSystem::@451": 0x8039a610,
		"@451": 0x8039a610,
		"Runtime.PPCEABI.H::__ptmf_null": 0x8039a620,
		"__ptmf_null": 0x8039a620,
		"Runtime.PPCEABI.H::__constants": 0x8039a630,
		"__constants": 0x8039a630,
		"MSL_C.PPCEABI.bare.H::__ctype_map": 0x8039a6d0,
		"__ctype_map": 0x8039a6d0,
		"MSL_C.PPCEABI.bare.H::__lower_map": 0x8039a7d0,
		"__lower_map": 0x8039a7d0,
		"MSL_C.PPCEABI.bare.H::__upper_map": 0x8039a8d0,
		"__upper_map": 0x8039a8d0,
		"MSL_C.PPCEABI.bare.H::@stringBase0": 0x8039a9d0,
		"@stringBase0": 0x8039a9d0,
		"MSL_C.PPCEABI.bare.H::atan_coeff$96": 0x8039aa78,
		"atan_coeff$96": 0x8039aa78,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_hi$97": 0x8039aa94,
		"onep_one_over_xisqr_hi$97": 0x8039aa94,
		"MSL_C.PPCEABI.bare.H::onep_one_over_xisqr_lo$98": 0x8039aaac,
		"onep_one_over_xisqr_lo$98": 0x8039aaac,
		"MSL_C.PPCEABI.bare.H::atan_xi_hi$99": 0x8039aac4,
		"atan_xi_hi$99": 0x8039aac4,
		"MSL_C.PPCEABI.bare.H::atan_xi_lo$100": 0x8039aae0,
		"atan_xi_lo$100": 0x8039aae0,
		"MSL_C.PPCEABI.bare.H::one_over_xi_hi$101": 0x8039aafc,
		"one_over_xi_hi$101": 0x8039aafc,
		"MSL_C.PPCEABI.bare.H::one_over_xi_lo$102": 0x8039ab14,
		"one_over_xi_lo$102": 0x8039ab14,
		"MSL_C.PPCEABI.bare.H::tmp_float": 0x8039ab30,
		"tmp_float": 0x8039ab30,
		"MSL_C.PPCEABI.bare.H::__two_to_log2e_m1_tI": 0x8039ab40,
		"__two_to_log2e_m1_tI": 0x8039ab40,
		"MSL_C.PPCEABI.bare.H::__one_over_F": 0x8039ae08,
		"__one_over_F": 0x8039ae08,
		"MSL_C.PPCEABI.bare.H::__sincos_on_quadrant": 0x8039b00c,
		"__sincos_on_quadrant": 0x8039b00c,
		"MSL_C.PPCEABI.bare.H::__sincos_poly": 0x8039b02c,
		"__sincos_poly": 0x8039b02c,
		"MSL_C.PPCEABI.bare.H::__log2_F": 0x8039b058,
		"__log2_F": 0x8039b058,
		"MSL_C.PPCEABI.bare.H::__two_to_x": 0x8039b25c,
		"__two_to_x": 0x8039b25c,
		"MSL_C.PPCEABI.bare.H::__exp_to_x$105": 0x8039b280,
		"__exp_to_x$105": 0x8039b280,
		"TRK_MINNOW_DOLPHIN::@40": 0x8039b2a0,
		"TRK_MINNOW_DOLPHIN::gTRKMemMap": 0x8039b2c0,
		"gTRKMemMap": 0x8039b2c0,
		"TRK_MINNOW_DOLPHIN::@233": 0x8039b2d0,
		"@233": 0x8039b2d0,
		"TRK_MINNOW_DOLPHIN::@238": 0x8039b2e4,
		"@238": 0x8039b2e4,
		"TRK_MINNOW_DOLPHIN::@243": 0x8039b2f8,
		"@243": 0x8039b2f8,
		"thp::__THPJpegNaturalOrder": 0x8039b310,
		"__THPJpegNaturalOrder": 0x8039b310,
		"MarioUtil::@2036": 0x8038d540,
		"MarioUtil::@2195": 0x8038d54c,
		"MarioUtil::@3559": 0x8038d55c,
		"MarioUtil::lightName$1906": 0x8038d58c,
		"lightName$1906": 0x8038d58c,
		"MarioUtil::ambName$1907": 0x8038d5a0,
		"ambName$1907": 0x8038d5a0,
		"MarioUtil::lightName$1917": 0x8038d5c0,
		"lightName$1917": 0x8038d5c0,
		"MarioUtil::ambName$1918": 0x8038d5d8,
		"ambName$1918": 0x8038d5d8,
		"MarioUtil::lightName$1928": 0x8038d5fc,
		"lightName$1928": 0x8038d5fc,
		"MarioUtil::ambName$1929": 0x8038d614,
		"ambName$1929": 0x8038d614,
		"MarioUtil::@1931": 0x8038d638,
		"MarioUtil::@1932": 0x8038d64c,
		"MarioUtil::lightName$1942": 0x8038d660,
		"lightName$1942": 0x8038d660,
		"MarioUtil::ambName$1943": 0x8038d678,
		"ambName$1943": 0x8038d678,
		"MarioUtil::@1945": 0x8038d69c,
		"MarioUtil::@1946": 0x8038d6b0,
		"MarioUtil::@2007": 0x8038d6c4,
		"MarioUtil::@2223": 0x8038d6dc,
		"MarioUtil::@2224": 0x8038d6f0,
		"MarioUtil::@2225": 0x8038d708,
		"MarioUtil::@2296": 0x8038d744,
		"MarioUtil::@2477": 0x8038d754,
		"MarioUtil::@2843": 0x8038d764,
		"MarioUtil::@1819": 0x8038d784,
		"MarioUtil::@1820": 0x8038d790,
		"MarioUtil::@1846": 0x8038d7a0,
		"@1846": 0x8038d7a0,
		"MarioUtil::@2544": 0x8038d7ac,
		"MarioUtil::@2545": 0x8038d7c0,
		"MarioUtil::@2546": 0x8038d7cc,
		"MarioUtil::@2547": 0x8038d7d8,
		"MarioUtil::@2548": 0x8038d7e4,
		"MarioUtil::@2549": 0x8038d7f0,
		"MarioUtil::@2556": 0x8038d7fc,
		"MarioUtil::@1831": 0x8038d808,
		"MarioUtil::@1809": 0x8038d82c,
		"MarioUtil::@1974": 0x8038d840,
		"MarioUtil::@1975": 0x8038d850,
		"MarioUtil::@2149": 0x8038d860,
		"MarioUtil::@2150": 0x8038d884,
		"MarioUtil::calctablex$2412": 0x8038d8a8,
		"calctablex$2412": 0x8038d8a8,
		"MarioUtil::calctablez$2413": 0x8038d8b8,
		"calctablez$2413": 0x8038d8b8,
		"MarioUtil::@4135": 0x8038d8c8,
		"MarioUtil::@4136": 0x8038d8e4,
		"MarioUtil::@4137": 0x8038d900,
		"MarioUtil::@4138": 0x8038d918,
		"MarioUtil::@17": 0x8038d930,
		"MarioUtil::@18": 0x8038da00,
		"MarioUtil::@19": 0x8038da10,
		"@19": 0x8038da10,
		"MarioUtil::@20": 0x8038da20,
		"@20": 0x8038da20,
		"MarioUtil::@21": 0x8038da30,
		"@21": 0x8038da30,
		"MarioUtil::@22": 0x8038da44,
		"MarioUtil::@23": 0x8038da58,
		"@23": 0x8038da58,
		"MarioUtil::@24": 0x8038da68,
		"@24": 0x8038da68,
		"MarioUtil::@25": 0x8038da78,
		"MarioUtil::@26": 0x8038da88,
		"@26": 0x8038da88,
		"MarioUtil::@27": 0x8038da98,
		"@27": 0x8038da98,
		"MarioUtil::@28": 0x8038daac,
		"MarioUtil::@29": 0x8038dabc,
		"@29": 0x8038dabc,
		"MarioUtil::@30": 0x8038dacc,
		"MarioUtil::@31": 0x8038dadc,
		"MarioUtil::@32": 0x8038daec,
		"MarioUtil::@33": 0x8038dafc,
		"MarioUtil::@34": 0x8038db0c,
		"MarioUtil::@35": 0x8038db1c,
		"MarioUtil::@36": 0x8038db2c,
		"MarioUtil::@37": 0x8038db3c,
		"MarioUtil::@38": 0x8038db4c,
		"MarioUtil::@39": 0x8038db58,
		"MarioUtil::@40": 0x8038db64,
		"MarioUtil::@66": 0x8038db7c,
		"System::@1664": 0x80391b88,
		"System::@1711": 0x80391b94,
		"System::prmarray$2214": 0x80391ba8,
		"prmarray$2214": 0x80391ba8,
		"System::envarray$2215": 0x80391bc0,
		"envarray$2215": 0x80391bc0,
		"System::@2200": 0x80391bf8,
		"System::@2201": 0x80391c28,
		"System::@2202": 0x80391c60,
		"System::@2203": 0x80391c94,
		"System::@2728": 0x80391cb8,
		"System::@3708": 0x80391da8,
		"System::@3709": 0x80391db8,
		"System::@3710": 0x80391dcc,
		"System::@3711": 0x80391ddc,
		"System::@3712": 0x80391de8,
		"System::@3713": 0x80391df8,
		"System::@3714": 0x80391e08,
		"System::@3715": 0x80391e14,
		"System::@3716": 0x80391e2c,
		"System::@3717": 0x80391e44,
		"System::@3718": 0x80391e54,
		"System::@3719": 0x80391e68,
		"System::@3720": 0x80391e7c,
		"System::@3721": 0x80391e90,
		"System::@3722": 0x80391ea4,
		"System::@3723": 0x80391eb8,
		"System::@3724": 0x80391ec8,
		"System::@3725": 0x80391edc,
		"System::@3726": 0x80391ef8,
		"System::@3727": 0x80391f04,
		"System::@3728": 0x80391f18,
		"System::@3729": 0x80391f28,
		"System::@3730": 0x80391f38,
		"System::@3731": 0x80391f44,
		"System::@3732": 0x80391f58,
		"System::@3733": 0x80391f70,
		"System::@3734": 0x80391f80,
		"System::@3735": 0x80391f98,
		"System::@3736": 0x80391fb0,
		"System::@3737": 0x80391fcc,
		"System::@3738": 0x80391fe0,
		"System::@3739": 0x80391ff8,
		"System::@3740": 0x80392010,
		"System::@3741": 0x80392024,
		"System::@3742": 0x8039203c,
		"System::@3743": 0x8039204c,
		"System::@3744": 0x8039205c,
		"System::@3745": 0x80392068,
		"System::@3746": 0x80392074,
		"System::@3747": 0x80392084,
		"System::@3748": 0x80392090,
		"System::@3750": 0x803920a4,
		"System::@3751": 0x803920b0,
		"System::@3752": 0x803920c0,
		"System::@2396": 0x8039253c,
		"System::@2397": 0x80392548,
		"System::@2399": 0x80392554,
		"System::@1491": 0x80392780,
		"System::@1701": 0x803928fc,
		"System::@1784": 0x80392910,
		"System::@1785": 0x80392940,
		"System::@1786": 0x80392978,
		"System::@1787": 0x803929ac,
		"System::@2388": 0x803929f0,
		"System::@2732": 0x80392a08,
		"System::@2733": 0x80392a1c,
		"System::@2734": 0x80392a30,
		"System::@2735": 0x80392a40,
		"System::@2736": 0x80392a4c,
		"System::@2737": 0x80392a58,
		"System::@2743": 0x80392a68,
		"System::@2744": 0x80392a74,
		"System::@2746": 0x80392a9c,
		"System::@2747": 0x80392ab0,
		"System::@2748": 0x80392abc,
		"System::@2749": 0x80392acc,
		"System::@2750": 0x80392adc,
		"System::@2751": 0x80392aec,
		"System::@2810": 0x80392afc,
		"System::@2811": 0x80392b0c,
		"System::@2971": 0x80392b18,
		"System::@2972": 0x80392b28,
		"System::@2973": 0x80392b38,
		"System::@2974": 0x80392b48,
		"System::@1615": 0x80392bac,
		"System::@1616": 0x80392bc4,
		"System::@1617": 0x80392bd8,
		"System::@1620": 0x80392c04,
		"System::@1621": 0x80392c14,
		"System::@1622": 0x80392c20,
		"System::@1623": 0x80392c30,
		"System::@1624": 0x80392c40,
		"System::@1625": 0x80392c60,
		"System::@1627": 0x80392c80,
		"System::@1628": 0x80392ca0,
		"System::@1629": 0x80392cc0,
		"System::@1630": 0x80392cd4,
		"System::@1631": 0x80392ce4,
		"System::@1638": 0x80392d60,
		"System::@1639": 0x80392d74,
		"System::@1640": 0x80392d8c,
		"System::@1641": 0x80392da4,
		"System::@1642": 0x80392db8,
		"System::@2205": 0x80392df0,
		"System::@2206": 0x80392e20,
		"System::@2207": 0x80392e58,
		"System::@2208": 0x80392e8c,
		"System::@2694": 0x80392eb0,
		"@unnamed@::cDispExceptionCommand": 0x80392fc8,
		"cDispExceptionCommand": 0x80392fc8,
		"System::@2117": 0x80392ffc,
		"System::@2174": 0x80393040,
		"System::@2175": 0x80393078,
		"System::@2176": 0x803930ac,
		"System::@4634": 0x803931ac,
		"System::@4635": 0x803931bc,
		"System::@4636": 0x803931c8,
		"System::@4637": 0x803931d8,
		"System::@4638": 0x803931e4,
		"System::@4639": 0x803931f0,
		"System::@4640": 0x80393208,
		"System::@4641": 0x80393214,
		"System::@4642": 0x80393230,
		"System::@4643": 0x80393240,
		"System::@4644": 0x8039324c,
		"System::@4645": 0x80393258,
		"System::@4646": 0x80393264,
		"System::@4647": 0x80393274,
		"System::@4648": 0x80393288,
		"System::@4649": 0x8039329c,
		"System::@4650": 0x803932a8,
		"System::@4651": 0x803932b8,
		"System::@4653": 0x803932c8,
		"System::@4654": 0x803932d4,
		"System::@4655": 0x803932e0,
		"System::@4656": 0x803932ec,
		"System::@4657": 0x803932fc,
		"System::@4658": 0x80393310,
		"System::@4659": 0x80393328,
		"System::@4660": 0x80393338,
		"System::@4662": 0x80393358,
		"System::@4663": 0x80393368,
		"System::@4671": 0x803933cc,
		"System::@4672": 0x803933dc,
		"System::@4675": 0x803933f4,
		"System::@4676": 0x80393400,
		"@4676": 0x80393400,
		"System::@4677": 0x80393410,
		"System::@4678": 0x8039341c,
		"System::@4679": 0x8039342c,
		"@4679": 0x8039342c,
		"System::@4680": 0x80393438,
		"System::@4681": 0x80393444,
		"System::@4683": 0x8039345c,
		"System::@4684": 0x8039346c,
		"System::@4685": 0x80393478,
		"System::@4686": 0x80393488,
		"System::@4687": 0x80393494,
		"System::@4688": 0x803934ac,
		"System::@4689": 0x803934b8,
		"System::@4690": 0x803934c8,
		"System::@4691": 0x803934d4,
		"System::@4692": 0x803934e4,
		"System::@4693": 0x803934f0,
		"System::@4694": 0x803934fc,
		"System::@4695": 0x80393508,
		"System::@4698": 0x80393514,
		"System::@4699": 0x80393520,
		"System::@4700": 0x8039352c,
		"System::@4701": 0x80393538,
		"System::@4702": 0x80393544,
		"System::@4704": 0x80393550,
		"System::@4707": 0x80393588,
		"System::@4708": 0x80393594,
		"System::@4709": 0x803935b0,
		"System::@4710": 0x803935bc,
		"@4710": 0x803935bc,
		"System::@4711": 0x803935d4,
		"@4711": 0x803935d4,
		"System::@4713": 0x803935f4,
		"@4713": 0x803935f4,
		"System::@4714": 0x80393600,
		"@4714": 0x80393600,
		"System::@4715": 0x80393618,
		"@4715": 0x80393618,
		"System::@4716": 0x80393624,
		"System::@4717": 0x8039363c,
		"System::@4718": 0x80393648,
		"System::@4719": 0x80393660,
		"System::@4720": 0x8039366c,
		"System::@4721": 0x80393684,
		"System::@4722": 0x80393694,
		"System::@4723": 0x803936b8,
		"System::@4724": 0x803936c8,
		"System::@4725": 0x803936ec,
		"System::@4726": 0x80393704,
		"System::@4727": 0x80393718,
		"System::@4728": 0x80393738,
		"System::@4729": 0x80393754,
		"System::@4730": 0x8039376c,
		"System::@4731": 0x80393784,
		"System::@4732": 0x80393798,
		"System::@4733": 0x803937a4,
		"System::@4734": 0x803937b8,
		"System::@4735": 0x803937d8,
		"System::@4736": 0x803937f0,
		"System::@4737": 0x8039380c,
		"System::@4738": 0x80393824,
		"System::@4739": 0x80393844,
		"System::@4740": 0x8039385c,
		"System::@4742": 0x80393870,
		"System::@4743": 0x80393884,
		"System::@4744": 0x803938a0,
		"System::@4745": 0x803938b8,
		"System::@4746": 0x803938d0,
		"System::@4747": 0x803938e0,
		"System::@4748": 0x803938f4,
		"System::@4749": 0x80393900,
		"System::@4751": 0x80393920,
		"System::@4752": 0x80393934,
		"System::@4753": 0x80393948,
		"System::@4754": 0x80393960,
		"System::@4755": 0x80393974,
		"System::@4756": 0x80393984,
		"System::@4759": 0x80393998,
		"System::@4760": 0x803939a8,
		"System::@4761": 0x803939bc,
		"System::@4762": 0x803939d4,
		"System::@4763": 0x803939e4,
		"System::@4764": 0x803939f8,
		"System::@4765": 0x80393a14,
		"System::@4768": 0x80393a48,
		"System::@4769": 0x80393a58,
		"System::@4770": 0x80393a6c,
		"System::@4771": 0x80393a80,
		"System::@4772": 0x80393a8c,
		"System::@4773": 0x80393a9c,
		"System::@4774": 0x80393ab0,
		"System::@4775": 0x80393abc,
		"System::@4776": 0x80393ac8,
		"System::@4777": 0x80393adc,
		"System::@4778": 0x80393af0,
		"System::@4779": 0x80393afc,
		"System::@4780": 0x80393b0c,
		"System::@4781": 0x80393b1c,
		"System::@4782": 0x80393b2c,
		"System::@4783": 0x80393b38,
		"System::@4784": 0x80393b48,
		"System::@4785": 0x80393b54,
		"System::@4786": 0x80393b64,
		"System::@2838": 0x80393c08,
		"System::@2842": 0x80393c14,
		"System::@2843": 0x80393c20,
		"System::@2854": 0x80393c2c,
		"System::@2857": 0x80393c48,
		"System::@2858": 0x80393c58,
		"System::SceneParamsDir": 0x80393d58,
		"SceneParamsDir": 0x80393d58,
		"System::@1525": 0x80393d74,
		"System::@2003": 0x80393e48,
		"System::@2004": 0x80393e5c,
		"System::@2005": 0x80393e7c,
		"System::@2006": 0x80393e88,
		"System::@2573": 0x80393eb8,
		"System::@1726": 0x803941cc,
		"@1726": 0x803941cc,
		"System::@1958": 0x8039427c,
		"System::@1959": 0x803942b0,
		"System::@3922": 0x803948b4,
		"System::@3924": 0x803948c0,
		"System::@3925": 0x803948d4,
		"System::@3926": 0x803948e8,
		"System::@3927": 0x803948f8,
		"System::@3928": 0x80394914,
		"System::@3929": 0x80394920,
		"System::@3930": 0x80394930,
		"System::@3933": 0x80394954,
		"System::@3934": 0x80394968,
		"System::@3935": 0x80394984,
		"System::@3936": 0x80394998,
		"System::@3938": 0x803949c0,
		"System::@3940": 0x803949cc,
		"System::@3941": 0x803949d8,
		"System::@3942": 0x803949e4,
		"System::@3943": 0x803949f4,
		"System::@3944": 0x80394a08,
		"System::@3945": 0x80394a24,
		"System::@3946": 0x80394a30,
		"System::@3947": 0x80394a3c,
		"System::@3948": 0x80394a48,
		"System::@3949": 0x80394a54,
		"System::@3950": 0x80394a60,
		"System::@3951": 0x80394a6c,
		"System::@3952": 0x80394a78,
		"System::@3956": 0x80394aa8,
		"System::@3957": 0x80394ab8,
		"System::@3959": 0x80394ae0,
		"System::@3961": 0x80394aec,
		"System::@3963": 0x80394af8,
		"System::@3965": 0x80394b04,
		"System::@3967": 0x80394b18,
		"System::@3968": 0x80394b28,
		"System::@3969": 0x80394b3c,
		"System::@3970": 0x80394b50,
		"System::@3971": 0x80394b60,
		"System::@3972": 0x80394b80,
		"System::@3973": 0x80394b98,
		"System::@3974": 0x80394bb4,
		"System::@3975": 0x80394bd0,
		"System::@3976": 0x80394bf0,
		"System::@3977": 0x80394c08,
		"System::@3978": 0x80394c24,
		"System::@3979": 0x80394c3c,
		"System::@3980": 0x80394c58,
		"System::@3981": 0x80394c6c,
		"System::@3982": 0x80394c88,
		"System::@3983": 0x80394c94,
		"System::@3984": 0x80394ca4,
		"System::@3985": 0x80394cb4,
		"System::@3986": 0x80394cd0,
		"System::@3987": 0x80394ce0,
		"System::@3991": 0x80394d24,
		"System::@3992": 0x80394d40,
		"System::@3993": 0x80394d50,
		"System::@3994": 0x80394d60,
		"System::@3995": 0x80394d70,
		"System::@3996": 0x80394d80,
		"System::@3997": 0x80394d94,
		"System::@3998": 0x80394db0,
		"System::@3999": 0x80394dc0,
		"System::@4000": 0x80394dd0,
		"System::@4001": 0x80394de8,
		"System::@4002": 0x80394e04,
		"System::@4003": 0x80394e20,
		"System::@4004": 0x80394e40,
		"System::@4005": 0x80394e54,
		"System::@4006": 0x80394e68,
		"System::@4007": 0x80394e7c,
		"System::@4008": 0x80394e94,
		"System::@4009": 0x80394ea4,
		"System::@4010": 0x80394eb0,
		"System::@4014": 0x80394f00,
		"System::@4015": 0x80394f10,
		"System::@4016": 0x80394f28,
		"System::@4017": 0x80394f34,
		"System::@4018": 0x80394f40,
		"System::@4019": 0x80394f5c,
		"System::@4021": 0x80394f88,
		"System::@4023": 0x80394fa0,
		"System::@4024": 0x80394fac,
		"System::@4025": 0x80394fb8,
		"System::@4026": 0x80394fc8,
		"System::@4027": 0x80394fdc,
		"System::@4028": 0x80394ff4,
		"System::@4029": 0x80395000,
		"System::@4030": 0x8039500c,
		"System::@4031": 0x80395020,
		"System::@4032": 0x8039503c,
		"System::@4033": 0x80395048,
		"System::@4034": 0x80395058,
		"System::@4035": 0x80395068,
		"System::@4036": 0x8039507c,
		"System::@4037": 0x80395090,
		"System::@4038": 0x803950ac,
		"System::@4039": 0x803950b8,
		"System::@4044": 0x803950e8,
		"System::@4045": 0x803950f8,
		"System::@4047": 0x80395120,
		"System::@4049": 0x80395138,
		"System::@4050": 0x80395144,
		"System::@4051": 0x80395150,
		"System::@4052": 0x80395160,
		"System::@4054": 0x8039517c,
		"System::@4055": 0x80395190,
		"System::@4056": 0x803951ac,
		"System::@4057": 0x803951b8,
		"System::@4058": 0x803951c8,
		"System::@4059": 0x803951dc,
		"System::@4060": 0x803951f8,
		"System::@4061": 0x80395208,
		"System::@4066": 0x8039523c,
		"System::@4067": 0x80395248,
		"System::@4068": 0x80395254,
		"System::@4069": 0x80395260,
		"@4069": 0x80395260,
		"System::@4070": 0x80395270,
		"System::@4071": 0x8039527c,
		"@4071": 0x8039527c,
		"System::@4072": 0x80395288,
		"System::@4073": 0x8039529c,
		"System::@4074": 0x803952b0,
		"System::@4075": 0x803952c4,
		"System::@4077": 0x803952e8,
		"System::@4079": 0x80395304,
		"System::@4088": 0x80395388,
		"System::@4089": 0x8039539c,
		"System::@4090": 0x803953bc,
		"System::@4091": 0x803953c8,
		"System::@4092": 0x803953dc,
		"System::@4093": 0x803953f8,
		"System::@4094": 0x80395414,
		"System::@4095": 0x80395428,
		"System::@4096": 0x80395438,
		"System::@4097": 0x80395450,
		"System::@4098": 0x8039546c,
		"System::@4099": 0x80395480,
		"System::@4100": 0x80395490,
		"System::@4101": 0x803954a0,
		"System::@4102": 0x803954b8,
		"System::@4103": 0x803954c8,
		"System::@4105": 0x803954ec,
		"System::@4107": 0x803954f8,
		"System::@4108": 0x80395504,
		"System::@4109": 0x80395514,
		"System::@4110": 0x80395538,
		"System::@4111": 0x80395544,
		"System::@4112": 0x8039555c,
		"System::@4113": 0x8039556c,
		"System::@4114": 0x80395588,
		"System::@4115": 0x80395594,
		"System::@4117": 0x803955b4,
		"@4117": 0x803955b4,
		"System::@4135": 0x80395654,
		"System::@4137": 0x8039566c,
		"System::@4138": 0x80395678,
		"System::@4139": 0x80395690,
		"System::@4140": 0x803956b0,
		"System::@4141": 0x803956c0,
		"System::@4142": 0x803956d4,
		"System::@4143": 0x803956e4,
		"System::@4144": 0x803956f8,
		"System::@4145": 0x80395710,
		"System::@4146": 0x80395730,
		"System::@4147": 0x8039573c,
		"System::@4148": 0x80395754,
		"System::@4150": 0x80395784,
		"System::@4152": 0x80395790,
		"System::@4153": 0x8039579c,
		"System::@4154": 0x803957b0,
		"System::@4155": 0x803957c4,
		"System::@4175": 0x8039592c,
		"System::@4177": 0x80395944,
		"System::@4179": 0x80395960,
		"System::@1723": 0x80395a24,
		"System::@1779": 0x80395a38,
		"System::@1780": 0x80395a68,
		"System::@1781": 0x80395aa0,
		"System::@1782": 0x80395ad4,
		"System::@2095": 0x80395b34,
		"System::@2096": 0x80395b40,
		"System::@2097": 0x80395b4c,
		"@2097": 0x80395b4c,
		"System::@2098": 0x80395b58,
		"System::@2099": 0x80395b68,
		"System::@2105": 0x80395ba8,
		"System::@2106": 0x80395bb4,
		"System::@2107": 0x80395bc0,
		"System::@1752": 0x80395be4,
		"System::@1808": 0x80395bf8,
		"System::@1810": 0x80395c60,
		"System::@1811": 0x80395c94,
		"System::@2364": 0x80395cb8,
		"System::@2366": 0x80395cc4,
		"System::@4994": 0x80395cd0,
		"System::@4995": 0x80395cdc,
		"System::@4996": 0x80395cf0,
		"System::@4997": 0x80395d00,
		"System::@4999": 0x80395d14,
		"System::@5001": 0x80395d20,
		"System::@5002": 0x80395d30,
		"System::@5003": 0x80395d3c,
		"System::@5004": 0x80395d48,
		"System::@5005": 0x80395d5c,
		"System::@5006": 0x80395d68,
		"System::@5007": 0x80395d78,
		"System::@5009": 0x80395d9c,
		"System::@5010": 0x80395db0,
		"System::@5011": 0x80395dc0,
		"System::@5012": 0x80395dd0,
		"System::@5014": 0x80395df8,
		"System::@5016": 0x80395e1c,
		"System::@5018": 0x80395e40,
		"System::@5020": 0x80395e64,
		"System::@5021": 0x80395e74,
		"System::@5023": 0x80395e88,
		"System::@5024": 0x80395e9c,
		"System::@5025": 0x80395ea8,
		"System::@5026": 0x80395eb4,
		"System::@5028": 0x80395ec0,
		"System::@5030": 0x80395ecc,
		"System::@5034": 0x80395eec,
		"System::@5035": 0x80395f00,
		"System::@5036": 0x80395f14,
		"@5036": 0x80395f14,
		"System::@5038": 0x80395f38,
		"System::@5040": 0x80395f68,
		"@5040": 0x80395f68,
		"System::@5041": 0x80395f8c,
		"System::@5042": 0x80395f9c,
		"System::@5047": 0x80395fdc,
		"System::@5048": 0x80395ff0,
		"System::@5049": 0x80396000,
		"System::@5050": 0x8039600c,
		"System::@5054": 0x8039602c,
		"System::@5055": 0x80396040,
		"System::@5056": 0x80396054,
		"System::@5062": 0x8039606c,
		"@5062": 0x8039606c,
		"System::@5065": 0x80396098,
		"@5065": 0x80396098,
		"System::@5067": 0x803960a8,
		"@5067": 0x803960a8,
		"System::@5068": 0x803960b4,
		"@5068": 0x803960b4,
		"System::@5069": 0x803960cc,
		"@5069": 0x803960cc,
		"System::@5070": 0x803960d8,
		"System::@5071": 0x803960f0,
		"System::@5072": 0x803960fc,
		"System::@5073": 0x8039610c,
		"System::@5076": 0x80396118,
		"System::@5079": 0x80396124,
		"@5079": 0x80396124,
		"System::@5080": 0x8039613c,
		"System::@5081": 0x80396150,
		"System::@5082": 0x80396160,
		"@5082": 0x80396160,
		"System::@5083": 0x80396174,
		"System::@5084": 0x80396184,
		"System::@5085": 0x80396198,
		"System::@5087": 0x803961b8,
		"System::@5090": 0x803961e0,
		"System::@5091": 0x803961f4,
		"System::@5092": 0x80396208,
		"System::@5093": 0x80396224,
		"System::@5094": 0x80396230,
		"System::@5095": 0x80396240,
		"System::@5096": 0x80396250,
		"System::@5097": 0x8039625c,
		"System::@5098": 0x8039626c,
		"System::@5099": 0x80396278,
		"System::@5104": 0x80396290,
		"System::@5105": 0x8039629c,
		"@5105": 0x8039629c,
		"System::@5106": 0x803962a8,
		"@5106": 0x803962a8,
		"System::@5107": 0x803962b4,
		"@5107": 0x803962b4,
		"System::@5109": 0x803962d0,
		"System::@5111": 0x803962ec,
		"System::@5112": 0x803962f8,
		"System::@5113": 0x80396308,
		"System::@5114": 0x80396318,
		"System::@5117": 0x80396324,
		"System::@5118": 0x80396338,
		"System::@5120": 0x80396354,
		"System::@5121": 0x80396360,
		"System::@5123": 0x8039636c,
		"System::@5124": 0x8039637c,
		"System::@5125": 0x80396394,
		"System::@5126": 0x803963a4,
		"System::@5128": 0x803963c8,
		"System::@5129": 0x803963d8,
		"System::@5134": 0x80396424,
		"System::@5135": 0x80396434,
		"System::@5136": 0x80396448,
		"System::@5137": 0x80396454,
		"System::@5138": 0x80396468,
		"System::@5139": 0x80396474,
		"System::@5140": 0x80396484,
		"@5140": 0x80396484,
		"System::@5142": 0x80396490,
		"System::@5143": 0x803964a0,
		"System::@5144": 0x803964ac,
		"System::@5145": 0x803964bc,
		"System::@5146": 0x803964cc,
		"System::@5148": 0x803964ec,
		"System::@5149": 0x803964f8,
		"System::@5150": 0x80396504,
		"@5150": 0x80396504,
		"System::@5151": 0x80396510,
		"System::@5152": 0x80396524,
		"System::@5157": 0x80396570,
		"System::@5158": 0x80396584,
		"System::@5159": 0x80396594,
		"System::@5160": 0x803965a8,
		"System::@5162": 0x803965bc,
		"@5162": 0x803965bc,
		"System::@5163": 0x803965c8,
		"System::@5164": 0x803965d8,
		"System::@5165": 0x803965ec,
		"System::@5166": 0x803965fc,
		"System::@5167": 0x80396614,
		"System::@5168": 0x8039662c,
		"System::@5169": 0x8039663c,
		"@5169": 0x8039663c,
		"System::@5170": 0x80396648,
		"System::@5171": 0x80396658,
		"@5171": 0x80396658,
		"System::@5172": 0x80396668,
		"System::@5173": 0x8039667c,
		"System::@5174": 0x8039668c,
		"System::@5175": 0x8039669c,
		"System::@5177": 0x803966c0,
		"System::@5179": 0x803966d8,
		"System::@5180": 0x803966e8,
		"System::@5181": 0x803966fc,
		"System::@5182": 0x8039670c,
		"System::@5183": 0x80396720,
		"System::@5184": 0x8039672c,
		"System::@5186": 0x80396748,
		"System::@5187": 0x80396754,
		"System::@5188": 0x80396760,
		"System::@5189": 0x80396770,
		"System::@5193": 0x803967a0,
		"System::@5195": 0x803967ac,
		"System::@5196": 0x803967c0,
		"System::@5197": 0x803967d4,
		"System::@5198": 0x803967e4,
		"System::@5199": 0x803967f0,
		"System::@5200": 0x80396800,
		"@5200": 0x80396800,
		"System::@5202": 0x80396810,
		"System::@5203": 0x80396820,
		"System::@5204": 0x80396830,
		"System::@5205": 0x80396844,
		"@5205": 0x80396844,
		"System::@5208": 0x80396850,
		"System::@5209": 0x8039685c,
		"System::@5210": 0x80396868,
		"System::@5211": 0x80396878,
		"@5211": 0x80396878,
		"System::@5213": 0x80396894,
		"System::@5214": 0x803968a4,
		"System::@5215": 0x803968b4,
		"System::@5216": 0x803968c8,
		"System::@5217": 0x803968d4,
		"System::@5218": 0x803968e4,
		"System::@5219": 0x803968f0,
		"System::@5220": 0x80396900,
		"System::@5222": 0x8039691c,
		"System::@5224": 0x8039692c,
		"System::@5225": 0x80396938,
		"System::@5226": 0x80396948,
		"System::@5227": 0x80396954,
		"System::@5229": 0x80396960,
		"System::@5230": 0x80396974,
		"System::@5231": 0x80396980,
		"System::@5232": 0x80396990,
		"System::@5233": 0x8039699c,
		"System::@5234": 0x803969a8,
		"System::@5235": 0x803969bc,
		"System::@5236": 0x803969c8,
		"System::@5238": 0x803969d4,
		"System::@5239": 0x803969e0,
		"System::@5240": 0x803969ec,
		"System::@5241": 0x80396a00,
		"System::@5242": 0x80396a0c,
		"System::@5243": 0x80396a18,
		"System::@5244": 0x80396a24,
		"System::@5246": 0x80396a44,
		"System::@5248": 0x80396a68,
		"System::@5249": 0x80396a7c,
		"System::@5250": 0x80396a88,
		"System::@5251": 0x80396a94,
		"System::@5252": 0x80396aa0,
		"System::@5253": 0x80396ab4,
		"System::@5254": 0x80396ac4,
		"System::@5255": 0x80396ad0,
		"System::@5257": 0x80396aec,
		"System::@5258": 0x80396b00,
		"System::@5259": 0x80396b0c,
		"System::@5260": 0x80396b1c,
		"System::@5262": 0x80396b28,
		"System::@5264": 0x80396b38,
		"System::@5266": 0x80396b54,
		"System::@5267": 0x80396b60,
		"System::@5268": 0x80396b70,
		"System::@5270": 0x80396b98,
		"System::@5271": 0x80396ba8,
		"System::@5273": 0x80396bb8,
		"System::@5274": 0x80396bc8,
		"System::@5276": 0x80396be4,
		"System::@5277": 0x80396bf0,
		"System::@5278": 0x80396c00,
		"System::@5279": 0x80396c0c,
		"System::@5280": 0x80396c1c,
		"System::@5282": 0x80396c28,
		"System::@5283": 0x80396c38,
		"System::@5288": 0x80396c70,
		"System::@5289": 0x80396c80,
		"System::@5290": 0x80396c90,
		"System::@5292": 0x80396c9c,
		"System::@5293": 0x80396ca8,
		"@5293": 0x80396ca8,
		"System::@5294": 0x80396cb8,
		"@5294": 0x80396cb8,
		"System::@5295": 0x80396cd4,
		"System::@5296": 0x80396ce4,
		"System::@5297": 0x80396cf4,
		"@5297": 0x80396cf4,
		"System::@5298": 0x80396d00,
		"@5298": 0x80396d00,
		"System::@5301": 0x80396d1c,
		"System::@5304": 0x80396d28,
		"System::@5306": 0x80396d40,
		"System::@5307": 0x80396d4c,
		"System::@5308": 0x80396d58,
		"System::@5309": 0x80396d64,
		"System::@5310": 0x80396d70,
		"System::@5314": 0x80396da0,
		"System::@5316": 0x80396dac,
		"System::@5318": 0x80396dc4,
		"System::@5319": 0x80396dd0,
		"System::@5320": 0x80396de0,
		"System::@5322": 0x80396dec,
		"System::@5323": 0x80396df8,
		"System::@5324": 0x80396e10,
		"System::@5325": 0x80396e1c,
		"System::@5326": 0x80396e2c,
		"System::@5330": 0x80396e3c,
		"System::@5331": 0x80396e48,
		"System::@5332": 0x80396e54,
		"System::@5334": 0x80396e60,
		"System::@5335": 0x80396e70,
		"System::@5336": 0x80396e80,
		"System::@5337": 0x80396e94,
		"System::@5338": 0x80396ea4,
		"System::@5339": 0x80396eb4,
		"System::@5340": 0x80396ecc,
		"System::@5341": 0x80396ee0,
		"System::@5342": 0x80396ef0,
		"System::@5343": 0x80396efc,
		"System::@5345": 0x80396f10,
		"@5345": 0x80396f10,
		"System::@5346": 0x80396f1c,
		"System::@5347": 0x80396f28,
		"System::@5348": 0x80396f38,
		"System::@5350": 0x80396f44,
		"System::@5351": 0x80396f50,
		"System::@5352": 0x80396f60,
		"System::@2577": 0x80397168,
		"System::@2578": 0x80397174,
		"System::@2594": 0x80397234,
		"System::@2595": 0x80397240,
		"System::@2596": 0x8039724c,
		"System::@2597": 0x80397258,
		"System::CardFileName": 0x80397498,
		"CardFileName": 0x80397498,
		"System::@2155": 0x803974c4,
		"System::@2384": 0x803974d8,
		"System::@3140": 0x803975ec,
		"System::@3141": 0x80397600,
		"System::@3142": 0x80397614,
		"System::@3143": 0x80397628,
		"System::@3144": 0x80397638,
		"System::@3145": 0x80397648,
		"System::@3146": 0x80397658,
		"System::@3147": 0x80397668,
		"System::@3148": 0x80397678,
		"System::@3149": 0x80397688,
		"System::@3150": 0x8039769c,
		"System::@3151": 0x803976b0,
		"System::@3152": 0x803976c4,
		"System::@3153": 0x803976d0,
		"System::@3154": 0x803976e4,
		"System::@3159": 0x80397748,
		"System::@3160": 0x8039775c,
		"System::@3161": 0x80397770,
		"System::@3162": 0x80397784,
		"System::@3163": 0x80397798,
		"System::@3164": 0x803977ac,
		"System::@3165": 0x803977c0,
		"System::@3166": 0x803977d8,
		"System::@3167": 0x803977f0,
		"System::@3168": 0x80397804,
		"System::@3169": 0x8039781c,
		"System::@3170": 0x80397830,
		"System::@3171": 0x80397848,
		"System::@3172": 0x80397860,
		"System::@3173": 0x80397874,
		"System::@3174": 0x80397888,
		"System::@3175": 0x8039789c,
		"System::@3176": 0x803978b4,
		"System::@3177": 0x803978cc,
		"System::@3178": 0x803978e0,
		"System::@3179": 0x803978f4,
		"System::@3180": 0x80397908,
		"System::@3181": 0x8039791c,
		"System::@3182": 0x80397930,
		"System::@3183": 0x80397944,
		"System::@3184": 0x80397958,
		"System::@3189": 0x803979b8,
		"System::@3190": 0x803979cc,
		"System::@3191": 0x803979e0,
		"System::@3192": 0x803979f4,
		"System::@3193": 0x80397a0c,
		"System::@3194": 0x80397a24,
		"System::@3195": 0x80397a3c,
		"System::@3218": 0x80397c00,
		"System::@3219": 0x80397c10,
		"System::@3220": 0x80397c28,
		"System::@3221": 0x80397c40,
		"System::@3222": 0x80397c50,
		"System::@3223": 0x80397c64,
		"System::@3224": 0x80397c78,
		"System::@3225": 0x80397c8c,
		"System::@3226": 0x80397ca0,
		"System::@3227": 0x80397cb0,
		"System::@3228": 0x80397cc0,
		"System::@3316": 0x80398128,
		"System::@3317": 0x8039813c,
		"System::@3318": 0x80398150,
		"System::@3319": 0x80398168,
		"System::@3320": 0x80398180,
		"System::@3321": 0x80398190,
		"System::@3322": 0x803981a0,
		"System::@3323": 0x803981b0,
		"System::@3324": 0x803981c8,
		"System::@3325": 0x803981e0,
		"System::@3326": 0x803981f8,
		"System::@3327": 0x80398208,
		"System::@3328": 0x8039821c,
		"System::@3329": 0x80398230,
		"System::@3330": 0x80398244,
		"System::@3331": 0x80398258,
		"System::@3332": 0x8039826c,
		"System::@3333": 0x80398280,
		"System::@3334": 0x80398294,
		"System::@3335": 0x803982a4,
		"System::@3336": 0x803982bc,
		"System::@3337": 0x803982d0,
		"System::@3338": 0x803982e4,
		"System::@3339": 0x803982f8,
		"System::@3340": 0x80398308,
		"System::@3341": 0x8039831c,
		"System::@3342": 0x80398330,
		"System::@3343": 0x80398348,
		"System::@3344": 0x8039835c,
		"System::@3345": 0x80398374,
		"System::@3346": 0x80398388,
		"System::@3347": 0x8039839c,
		"System::@3348": 0x803983b0,
		"System::@3349": 0x803983c4,
		"System::@3350": 0x803983d4,
		"System::@3351": 0x803983e8,
		"System::@3352": 0x803983fc,
		"System::@3353": 0x80398410,
		"System::@3354": 0x80398424,
		"System::@3355": 0x80398438,
		"System::@3356": 0x80398450,
		"System::@3357": 0x80398468,
		"System::@3358": 0x8039847c,
		"System::@3359": 0x80398490,
		"System::@3360": 0x803984a4,
		"System::@3361": 0x803984b8,
		"System::@3362": 0x803984c8,
		"System::@3363": 0x803984dc,
		"System::@3364": 0x803984f0,
		"System::@3365": 0x80398500,
		"System::@3366": 0x80398510,
		"System::@3367": 0x80398524,
		"System::@3368": 0x80398534,
		"System::@3369": 0x80398548,
		"System::@3370": 0x80398558,
		"System::@3371": 0x8039856c,
		"System::@3372": 0x80398580,
		"System::@3373": 0x80398598,
		"System::@3374": 0x803985ac,
		"System::@3375": 0x803985c0,
		"System::@3376": 0x803985d0,
		"System::@3377": 0x803985e4,
		"System::@3378": 0x803985f8,
		"System::@3379": 0x8039860c,
		"System::@3381": 0x80398630,
		"System::@3382": 0x80398644,
		"System::@3383": 0x80398658,
		"System::@3384": 0x80398668,
		"System::@3385": 0x8039867c,
		"System::@3387": 0x803986a4,
		"System::@3388": 0x803986b8,
		"System::@3389": 0x803986cc,
		"System::@3390": 0x803986e4,
		"System::@2033": 0x80398910,
		"System::@2034": 0x80398920,
		"System::@2035": 0x80398930,
		"System::@2036": 0x8039893c,
		"System::@2037": 0x8039894c,
		"System::@2038": 0x8039895c,
		"System::@2039": 0x80398970,
		"System::@2040": 0x8039897c,
		"System::@2041": 0x8039898c,
		"System::@2042": 0x80398998,
		"System::@2043": 0x803989a8,
		"System::@2044": 0x803989b8,
		"System::@2045": 0x803989c4,
		"System::@2046": 0x803989d4,
		"System::@2048": 0x803989f4,
		"System::@2049": 0x80398a04,
		"System::@2050": 0x80398a10,
		"System::@2051": 0x80398a1c,
		"System::@2554": 0x80398a38,
		"System::@2826": 0x80398a58,
		"System::@2827": 0x80398a6c,
		"System::@2828": 0x80398a7c,
		"System::@2831": 0x80398a9c,
		"System::@2832": 0x80398aa8,
		"System::@2833": 0x80398ab4,
		"System::@2834": 0x80398ac4,
		"System::@2883": 0x80398ae0,
		"System::@2884": 0x80398af0,
		"System::@2908": 0x80398afc,
		"System::@1816": 0x80398b08,
		"System::@2110": 0x80398b2c,
		"System::@3796": 0x80398e20,
		"System::@3797": 0x80398e38,
		"System::@3798": 0x80398e50,
		"System::@3799": 0x80398e68,
		"System::@3800": 0x80398e78,
		"System::@3802": 0x80398ea4,
		"System::@3803": 0x80398eb4,
		"System::@3805": 0x80398ec4,
		"System::@3806": 0x80398ed8,
		"System::@3807": 0x80398ee8,
		"System::@3808": 0x80398efc,
		"System::@3809": 0x80398f0c,
		"System::@1681": 0x80399000,
		"System::@1708": 0x8039902c,
		"System::@1709": 0x80399044,
		"Strategic::@1582": 0x8038cdf8,
		"Strategic::@1583": 0x8038ce28,
		"Strategic::@1584": 0x8038ce60,
		"Strategic::@1585": 0x8038ce94,
		"Strategic::@2148": 0x8038cf10,
		"Strategic::@1598": 0x8038cf40,
		"Strategic::@1599": 0x8038cf70,
		"Strategic::@1600": 0x8038cfa8,
		"Strategic::@1601": 0x8038cfdc,
		"Strategic::@1735": 0x8038d000,
		"Strategic::entry$1734": 0x8038d00c,
		"entry$1734": 0x8038d00c,
		"Strategic::@1948": 0x8038d028,
		"Strategic::@514": 0x8038d038,
		"@514": 0x8038d038,
		"Strategic::@515": 0x8038d054,
		"@515": 0x8038d054,
		"Strategic::@559": 0x8038d078,
		"@559": 0x8038d078,
		"Strategic::@560": 0x8038d09c,
		"@560": 0x8038d09c,
		"Strategic::@561": 0x8038d0c4,
		"@561": 0x8038d0c4,
		"Strategic::@610": 0x8038d0e8,
		"Strategic::@611": 0x8038d10c,
		"@611": 0x8038d10c,
		"Strategic::@612": 0x8038d13c,
		"@612": 0x8038d13c,
		"Strategic::@654": 0x8038d164,
		"Strategic::@655": 0x8038d180,
		"Strategic::@725": 0x8038d1a0,
		"Strategic::@834": 0x8038d1d0,
		"@834": 0x8038d1d0,
		"Strategic::@915": 0x8038d208,
		"@915": 0x8038d208,
		"Strategic::@916": 0x8038d228,
		"@916": 0x8038d228,
		"Strategic::@917": 0x8038d238,
		"@917": 0x8038d238,
		"Strategic::@918": 0x8038d248,
		"@918": 0x8038d248,
		"Strategic::@919": 0x8038d258,
		"@919": 0x8038d258,
		"Strategic::@920": 0x8038d268,
		"Strategic::@921": 0x8038d278,
		"@921": 0x8038d278,
		"Strategic::@922": 0x8038d28c,
		"@922": 0x8038d28c,
		"Strategic::@923": 0x8038d2a4,
		"@923": 0x8038d2a4,
		"Strategic::@924": 0x8038d2bc,
		"@924": 0x8038d2bc,
		"Strategic::@925": 0x8038d2d4,
		"@925": 0x8038d2d4,
		"Strategic::@1000": 0x8038d308,
		"@1000": 0x8038d308,
		"Strategic::@1071": 0x8038d324,
		"@1071": 0x8038d324,
		"Strategic::@1072": 0x8038d340,
		"Strategic::@1078": 0x8038d36c,
		"@1078": 0x8038d36c,
		"Strategic::@2481": 0x8038d38c,
		"Strategic::@2541": 0x8038d3ac,
		"Strategic::@2620": 0x8038d3d4,
		"Strategic::@1826": 0x8038d3f8,
		"@1826": 0x8038d3f8,
		"Strategic::@2112": 0x8038d424,
		"Strategic::@2302": 0x8038d438,
		"Strategic::@2303": 0x8038d468,
		"Strategic::@2304": 0x8038d4a0,
		"Strategic::@2305": 0x8038d4d4,
		"Strategic::@2581": 0x8038d4f8,
		"Player::@1763": 0x8038db9c,
		"Player::@1936": 0x8038dcd4,
		"Player::@2446": 0x8038dd18,
		"Player::@2447": 0x8038dd50,
		"Player::@2448": 0x8038dd84,
		"Player::@2902": 0x8038dedc,
		"Player::@2903": 0x8038dee8,
		"Player::@2904": 0x8038def4,
		"Player::@2911": 0x8038df30,
		"Player::@2912": 0x8038df3c,
		"Player::@2913": 0x8038df48,
		"Player::@2915": 0x8038df64,
		"Player::@2916": 0x8038df70,
		"Player::@2919": 0x8038df8c,
		"Player::@2920": 0x8038df98,
		"Player::@2921": 0x8038dfa4,
		"Player::@2922": 0x8038dfb4,
		"Player::@2923": 0x8038dfc4,
		"Player::@2924": 0x8038dfd0,
		"Player::@2925": 0x8038dfe0,
		"Player::@2926": 0x8038dfec,
		"Player::@2928": 0x8038e00c,
		"Player::@2929": 0x8038e01c,
		"Player::@2931": 0x8038e038,
		"Player::@2932": 0x8038e04c,
		"Player::@2933": 0x8038e05c,
		"Player::@2934": 0x8038e070,
		"Player::@2935": 0x8038e080,
		"Player::@2936": 0x8038e08c,
		"Player::@2937": 0x8038e098,
		"Player::@2940": 0x8038e0b8,
		"Player::@2941": 0x8038e0c4,
		"Player::@2944": 0x8038e0f0,
		"Player::@2945": 0x8038e100,
		"Player::@2946": 0x8038e10c,
		"Player::@2950": 0x8038e130,
		"Player::@2960": 0x8038e188,
		"Player::@2961": 0x8038e194,
		"Player::@2962": 0x8038e1a0,
		"Player::@5660": 0x8038e7b0,
		"Player::@5662": 0x8038e7c8,
		"@5662": 0x8038e7c8,
		"Player::@5663": 0x8038e7d4,
		"@5663": 0x8038e7d4,
		"Player::@5665": 0x8038e7e0,
		"Player::@5666": 0x8038e7f8,
		"Player::@5667": 0x8038e810,
		"Player::@5668": 0x8038e828,
		"Player::@5669": 0x8038e840,
		"Player::@5670": 0x8038e858,
		"Player::@5671": 0x8038e870,
		"@5671": 0x8038e870,
		"Player::@5672": 0x8038e888,
		"@5672": 0x8038e888,
		"Player::@5674": 0x8038e8a0,
		"@5674": 0x8038e8a0,
		"Player::@5675": 0x8038e8b8,
		"@5675": 0x8038e8b8,
		"Player::@5676": 0x8038e8dc,
		"Player::@5677": 0x8038e8f8,
		"@5677": 0x8038e8f8,
		"Player::@5678": 0x8038e924,
		"@5678": 0x8038e924,
		"Player::@5679": 0x8038e940,
		"Player::cParticleIDs": 0x8038ec24,
		"cParticleIDs": 0x8038ec24,
		"Player::warpInEffectIDs": 0x8038ec30,
		"warpInEffectIDs": 0x8038ec30,
		"Player::@1937": 0x8038ec7c,
		"Player::@2386": 0x8038ed3c,
		"Player::@2442": 0x8038ed50,
		"Player::@2443": 0x8038ed80,
		"Player::@2444": 0x8038edb8,
		"Player::bodyColor": 0x8038f64c,
		"bodyColor": 0x8038f64c,
		"Player::@2722": 0x8038fd64,
		"Player::@2725": 0x8038fd84,
		"Player::@3140": 0x8039044c,
		"Player::@3142": 0x80390460,
		"Player::@3322": 0x803906cc,
		"Player::@3324": 0x803906d8,
		"Player::@3326": 0x803906e4,
		"Player::@3327": 0x803906fc,
		"Player::@3328": 0x80390714,
		"Player::@3329": 0x80390724,
		"Player::@3330": 0x80390734,
		"Player::@3337": 0x80390754,
		"Player::@3338": 0x80390768,
		"Player::@3468": 0x80390888,
		"Player::@3469": 0x80390898,
		"Player::@3470": 0x803908a4,
		"Player::@3472": 0x803908b4,
		"Player::@3477": 0x803908ec,
		"Player::@3481": 0x80390930,
		"Player::@3483": 0x80390940,
		"Player::@3559": 0x803909a0,
		"Player::@3560": 0x803909ac,
		"Player::@3568": 0x80390a14,
		"Player::@3569": 0x80390a20,
		"Player::@3570": 0x80390a30,
		"Player::@3572": 0x80390a44,
		"Player::@3573": 0x80390a54,
		"Player::@3575": 0x80390a78,
		"Player::@3736": 0x80390bb8,
		"Player::@3737": 0x80390bc8,
		"Player::@3739": 0x80390bdc,
		"Player::@3748": 0x80390c7c,
		"Player::@3752": 0x80390cb0,
		"Player::@3753": 0x80390cc4,
		"Player::@3755": 0x80390cd4,
		"Player::@3756": 0x80390ce8,
		"Player::@3761": 0x80390d2c,
		"Player::@3762": 0x80390d3c,
		"Player::@3764": 0x80390d5c,
		"Player::@3765": 0x80390d6c,
		"Player::@3768": 0x80390da0,
		"Player::@3971": 0x80390e24,
		"Player::@3973": 0x80390e4c,
		"Player::@3975": 0x80390e70,
		"Player::@3976": 0x80390e84,
		"Player::@3977": 0x80390e98,
		"Player::@3978": 0x80390ea4,
		"Player::@3979": 0x80390eb0,
		"Player::@3980": 0x80390ec0,
		"Player::@3984": 0x80390eec,
		"Player::@3985": 0x80390efc,
		"Player::@3986": 0x80390f0c,
		"Player::@3987": 0x80390f1c,
		"Player::@3991": 0x80390f4c,
		"Player::@3993": 0x80390f70,
		"Player::@3994": 0x80390f84,
		"Player::@3995": 0x80390f98,
		"Player::@3996": 0x80390fa8,
		"Player::@3997": 0x80390fb4,
		"Player::@3999": 0x80390fc0,
		"Player::@4001": 0x80390fd0,
		"Player::@4002": 0x80390fe0,
		"Player::@4003": 0x80390ff0,
		"Player::@4008": 0x8039103c,
		"Player::@4010": 0x80391060,
		"Player::@4011": 0x80391070,
		"Player::@4012": 0x80391080,
		"Player::@4016": 0x803910d8,
		"Player::@6516": 0x80391198,
		"@6516": 0x80391198,
		"Player::@6517": 0x803911b4,
		"@6517": 0x803911b4,
		"Player::@6518": 0x803911d0,
		"Player::@6519": 0x803911f0,
		"Player::@6520": 0x8039121c,
		"Player::@6521": 0x80391240,
		"Player::@6522": 0x8039125c,
		"Player::@6523": 0x80391278,
		"Player::@6524": 0x80391298,
		"Player::@6525": 0x803912b8,
		"@6525": 0x803912b8,
		"Player::@6526": 0x803912d8,
		"@6526": 0x803912d8,
		"Player::@6527": 0x803912f8,
		"@6527": 0x803912f8,
		"Player::@6528": 0x8039130c,
		"@6528": 0x8039130c,
		"Player::@6529": 0x80391320,
		"@6529": 0x80391320,
		"Player::@6530": 0x8039133c,
		"@6530": 0x8039133c,
		"Player::@6531": 0x80391354,
		"@6531": 0x80391354,
		"Player::@6532": 0x8039136c,
		"@6532": 0x8039136c,
		"Player::@6533": 0x8039138c,
		"@6533": 0x8039138c,
		"Player::@6534": 0x803913a4,
		"@6534": 0x803913a4,
		"Player::@6535": 0x803913c4,
		"@6535": 0x803913c4,
		"Player::@6536": 0x803913e4,
		"@6536": 0x803913e4,
		"Player::@6537": 0x80391400,
		"@6537": 0x80391400,
		"Player::@6538": 0x80391418,
		"@6538": 0x80391418,
		"Player::@6539": 0x80391434,
		"@6539": 0x80391434,
		"Player::@6540": 0x8039144c,
		"@6540": 0x8039144c,
		"Player::@6541": 0x80391464,
		"@6541": 0x80391464,
		"Player::@6542": 0x8039147c,
		"@6542": 0x8039147c,
		"Player::@6543": 0x80391490,
		"@6543": 0x80391490,
		"Player::@6544": 0x803914ac,
		"@6544": 0x803914ac,
		"Player::@6545": 0x803914c4,
		"@6545": 0x803914c4,
		"Player::@6546": 0x803914e0,
		"@6546": 0x803914e0,
		"Player::@6547": 0x803914f8,
		"@6547": 0x803914f8,
		"Player::@6548": 0x80391510,
		"Player::@6549": 0x8039152c,
		"Player::@6550": 0x80391548,
		"Player::@6551": 0x80391564,
		"@6551": 0x80391564,
		"Player::@6552": 0x80391580,
		"Player::@6553": 0x8039159c,
		"Player::@6554": 0x803915bc,
		"Player::@6555": 0x803915d8,
		"Player::@6556": 0x803915f4,
		"@6556": 0x803915f4,
		"Player::@6557": 0x80391618,
		"Player::@6558": 0x80391630,
		"Player::@6559": 0x80391648,
		"Player::@6560": 0x80391660,
		"Player::@6561": 0x80391678,
		"@6561": 0x80391678,
		"Player::@6562": 0x80391690,
		"@6562": 0x80391690,
		"Player::@6563": 0x803916a8,
		"@6563": 0x803916a8,
		"Player::@6564": 0x803916c0,
		"@6564": 0x803916c0,
		"Player::@6565": 0x803916d8,
		"@6565": 0x803916d8,
		"Player::@6566": 0x803916f0,
		"@6566": 0x803916f0,
		"Player::@6567": 0x80391708,
		"@6567": 0x80391708,
		"Player::@2239": 0x8039172c,
		"Player::@2297": 0x803917a8,
		"Player::@2298": 0x803917dc,
		"Player::@2665": 0x80391800,
		"Player::@2666": 0x80391818,
		"Player::@2667": 0x80391830,
		"Player::@2668": 0x80391848,
		"Player::@2669": 0x80391864,
		"Player::@2670": 0x8039187c,
		"Player::@2671": 0x80391894,
		"Player::@2672": 0x803918ac,
		"Player::@2673": 0x803918c4,
		"Player::@2674": 0x803918dc,
		"Player::@2675": 0x803918f8,
		"Player::@2676": 0x80391910,
		"Player::@2677": 0x8039192c,
		"Player::@2678": 0x80391948,
		"Player::@2679": 0x80391960,
		"Player::@2680": 0x80391978,
		"Player::@2681": 0x80391990,
		"Player::@3162": 0x803919ac,
		"Player::@4560": 0x803919b8,
		"Player::@4628": 0x803919d0,
		"Player::@4630": 0x80391a08,
		"Player::@4635": 0x80391aa8,
		"Player::@4636": 0x80391acc,
		"Player::@4645": 0x80391af0,
		"Player::@4646": 0x80391afc,
		"Player::@4647": 0x80391b08,
		"Player::@4649": 0x80391b14,
		"Player::@4736": 0x80391b20,
		"Player::@4738": 0x80391b2c,
		"Player::@4741": 0x80391b38,
		"Player::@4742": 0x80391b48,
		"Player::@4743": 0x80391b54,
		"Player::@4746": 0x80391b60,
		"Player::@4876": 0x80391b6c,
		"NPC::@2255": 0x80384598,
		"NPC::@2256": 0x803845c8,
		"NPC::@2257": 0x80384600,
		"NPC::@2258": 0x80384634,
		"NPC::@2440": 0x80384658,
		"NPC::sIndividualPeachBck$2896": 0x80384668,
		"sIndividualPeachBck$2896": 0x80384668,
		"NPC::sIndividualPeachBtp$2897": 0x80384680,
		"sIndividualPeachBtp$2897": 0x80384680,
		"NPC::sIndividualPeachBck$2904": 0x80384690,
		"sIndividualPeachBck$2904": 0x80384690,
		"NPC::sIndividualPeachBtp$2905": 0x803846a0,
		"sIndividualPeachBtp$2905": 0x803846a0,
		"NPC::sIndividualSunflowerBck$2906": 0x803846b0,
		"sIndividualSunflowerBck$2906": 0x803846b0,
		"NPC::sIndividualSunflowerBtp$2907": 0x803846c8,
		"sIndividualSunflowerBtp$2907": 0x803846c8,
		"NPC::@2053": 0x8038479c,
		"NPC::entry$2229": 0x80384970,
		"entry$2229": 0x80384970,
		"NPC::@2236": 0x803849c8,
		"NPC::@2237": 0x803849d8,
		"NPC::entry$2231": 0x803849e8,
		"entry$2231": 0x803849e8,
		"NPC::entry$2335": 0x80384a4c,
		"entry$2335": 0x80384a4c,
		"NPC::entry$2337": 0x80384a74,
		"entry$2337": 0x80384a74,
		"NPC::entry$2339": 0x80384a9c,
		"entry$2339": 0x80384a9c,
		"NPC::entry$2341": 0x80384ac4,
		"entry$2341": 0x80384ac4,
		"NPC::entry$2343": 0x80384aec,
		"entry$2343": 0x80384aec,
		"NPC::entry$2345": 0x80384b14,
		"entry$2345": 0x80384b14,
		"NPC::entry$2347": 0x80384b2c,
		"entry$2347": 0x80384b2c,
		"NPC::entry$2348": 0x80384b44,
		"entry$2348": 0x80384b44,
		"NPC::entry$2349": 0x80384b5c,
		"entry$2349": 0x80384b5c,
		"NPC::entry$2350": 0x80384b84,
		"entry$2350": 0x80384b84,
		"NPC::entry$2352": 0x80384bac,
		"entry$2352": 0x80384bac,
		"NPC::entry$2354": 0x80384bd4,
		"entry$2354": 0x80384bd4,
		"NPC::entry$2356": 0x80384bec,
		"entry$2356": 0x80384bec,
		"NPC::entry$2357": 0x80384c10,
		"entry$2357": 0x80384c10,
		"NPC::entry$2359": 0x80384c34,
		"entry$2359": 0x80384c34,
		"NPC::entry$2361": 0x80384c60,
		"entry$2361": 0x80384c60,
		"NPC::entry$2363": 0x80384c88,
		"entry$2363": 0x80384c88,
		"NPC::entry$2365": 0x80384cb0,
		"entry$2365": 0x80384cb0,
		"NPC::entry$2367": 0x80384cd4,
		"entry$2367": 0x80384cd4,
		"NPC::entry$2369": 0x80384cfc,
		"entry$2369": 0x80384cfc,
		"NPC::entry$2371": 0x80384d24,
		"entry$2371": 0x80384d24,
		"NPC::@2416": 0x80384d3c,
		"NPC::@2459": 0x80384d4c,
		"NPC::@2467": 0x80384d5c,
		"NPC::@2475": 0x80384d6c,
		"NPC::@1968": 0x80384eec,
		"NPC::@1969": 0x80384f00,
		"NPC::@1973": 0x80384f50,
		"NPC::@1974": 0x80384f64,
		"NPC::@1978": 0x80384fb4,
		"NPC::@1979": 0x80384fc8,
		"NPC::@1982": 0x80385010,
		"NPC::@1983": 0x80385024,
		"NPC::@2160": 0x80385038,
		"NPC::@2162": 0x80385048,
		"NPC::@2164": 0x80385058,
		"NPC::@2166": 0x80385068,
		"NPC::@2168": 0x8038507c,
		"NPC::@2170": 0x80385094,
		"NPC::@2172": 0x803850a8,
		"NPC::@2174": 0x803850bc,
		"NPC::@2176": 0x803850d0,
		"NPC::@2178": 0x803850e4,
		"NPC::@2179": 0x803850f4,
		"NPC::@2181": 0x80385104,
		"NPC::@2183": 0x80385110,
		"NPC::@2185": 0x8038511c,
		"NPC::@2186": 0x8038512c,
		"NPC::@2188": 0x8038513c,
		"NPC::@2190": 0x8038514c,
		"NPC::@2191": 0x8038515c,
		"NPC::@2192": 0x8038516c,
		"NPC::@2193": 0x8038517c,
		"NPC::@2195": 0x80385190,
		"NPC::@2203": 0x803851d8,
		"NPC::@2205": 0x803851f0,
		"NPC::@2209": 0x8038521c,
		"NPC::@2228": 0x803852e0,
		"NPC::@2229": 0x803852f0,
		"NPC::@2231": 0x80385308,
		"NPC::@2334": 0x80385360,
		"NPC::@2335": 0x80385374,
		"NPC::@2337": 0x80385390,
		"NPC::@2339": 0x803853b4,
		"NPC::@2343": 0x803853f8,
		"NPC::@2345": 0x8038542c,
		"NPC::@2357": 0x803854fc,
		"NPC::@2359": 0x80385514,
		"NPC::@2361": 0x80385540,
		"NPC::@2363": 0x80385554,
		"NPC::@2365": 0x80385564,
		"NPC::@2367": 0x80385574,
		"NPC::@2369": 0x803855a0,
		"NPC::@2371": 0x803855d0,
		"NPC::@2373": 0x803855fc,
		"NPC::@2417": 0x80385620,
		"NPC::@2418": 0x80385634,
		"NPC::@2420": 0x80385644,
		"NPC::@2421": 0x80385658,
		"NPC::@2422": 0x8038566c,
		"NPC::@2423": 0x80385680,
		"NPC::@2424": 0x80385694,
		"NPC::@2426": 0x803856bc,
		"NPC::@2427": 0x803856d0,
		"NPC::@2431": 0x80385724,
		"NPC::@2721": 0x80385960,
		"NPC::@2722": 0x80385978,
		"NPC::@2723": 0x80385990,
		"NPC::@2724": 0x8038599c,
		"NPC::@1530": 0x80385a88,
		"@1530": 0x80385a88,
		"NPC::@1535": 0x80385a98,
		"NPC::@1536": 0x80385abc,
		"NPC::sMonteM_HatAColorBuf0": 0x80385ad0,
		"sMonteM_HatAColorBuf0": 0x80385ad0,
		"NPC::sMonteM_HatAColorBuf1": 0x80385b08,
		"sMonteM_HatAColorBuf1": 0x80385b08,
		"NPC::@1537": 0x80385b40,
		"NPC::sMonteM_HatAColorChange": 0x80385b4c,
		"sMonteM_HatAColorChange": 0x80385b4c,
		"NPC::sMonteM_HatABeltColorBuf": 0x80385b5c,
		"sMonteM_HatABeltColorBuf": 0x80385b5c,
		"NPC::@1538": 0x80385b94,
		"NPC::sMonteM_HatABeltColorChange": 0x80385ba0,
		"sMonteM_HatABeltColorChange": 0x80385ba0,
		"NPC::@1540": 0x80385bb0,
		"NPC::sMonteM_HatAData": 0x80385bc0,
		"sMonteM_HatAData": 0x80385bc0,
		"NPC::sMonteM_HatBColorBuf": 0x80385bec,
		"sMonteM_HatBColorBuf": 0x80385bec,
		"NPC::sMonteM_HatBColorChange": 0x80385c04,
		"sMonteM_HatBColorChange": 0x80385c04,
		"NPC::sMonteM_HatBBeltColorBuf": 0x80385c14,
		"sMonteM_HatBBeltColorBuf": 0x80385c14,
		"NPC::sMonteM_HatBBeltColorChange": 0x80385c2c,
		"sMonteM_HatBBeltColorChange": 0x80385c2c,
		"NPC::@1541": 0x80385c3c,
		"NPC::sMonteM_HatBData": 0x80385c4c,
		"sMonteM_HatBData": 0x80385c4c,
		"NPC::sMonteM_HatDColorBuf": 0x80385c78,
		"sMonteM_HatDColorBuf": 0x80385c78,
		"NPC::sMonteM_HatDColorChange": 0x80385c88,
		"sMonteM_HatDColorChange": 0x80385c88,
		"NPC::@1542": 0x80385c98,
		"NPC::sMonteM_HatDData": 0x80385ca8,
		"sMonteM_HatDData": 0x80385ca8,
		"NPC::sMonteM_HatEColorBuf0": 0x80385cd4,
		"sMonteM_HatEColorBuf0": 0x80385cd4,
		"NPC::sMonteM_HatEColorBuf1": 0x80385ce4,
		"sMonteM_HatEColorBuf1": 0x80385ce4,
		"NPC::sMonteM_HatEColorChange": 0x80385cf4,
		"sMonteM_HatEColorChange": 0x80385cf4,
		"NPC::@1543": 0x80385d04,
		"NPC::sMonteM_HatEData": 0x80385d14,
		"sMonteM_HatEData": 0x80385d14,
		"NPC::sMonteM_HatFColorBuf0": 0x80385d40,
		"sMonteM_HatFColorBuf0": 0x80385d40,
		"NPC::sMonteM_HatFColorBuf1": 0x80385d50,
		"sMonteM_HatFColorBuf1": 0x80385d50,
		"NPC::sMonteM_HatFColorChange": 0x80385d60,
		"sMonteM_HatFColorChange": 0x80385d60,
		"NPC::@1544": 0x80385d70,
		"NPC::sMonteM_HatFData": 0x80385d80,
		"sMonteM_HatFData": 0x80385d80,
		"NPC::sMonteM_HatGColorBuf0": 0x80385dac,
		"sMonteM_HatGColorBuf0": 0x80385dac,
		"NPC::sMonteM_HatGColorBuf1": 0x80385dd4,
		"sMonteM_HatGColorBuf1": 0x80385dd4,
		"NPC::sMonteM_HatGColorChange": 0x80385dfc,
		"sMonteM_HatGColorChange": 0x80385dfc,
		"NPC::@1545": 0x80385e0c,
		"NPC::sMonteM_HatGData": 0x80385e1c,
		"sMonteM_HatGData": 0x80385e1c,
		"NPC::sMonteM_MustacheAColorBuf0": 0x80385e48,
		"sMonteM_MustacheAColorBuf0": 0x80385e48,
		"NPC::@1546": 0x80385e68,
		"NPC::sMonteM_MustacheAColorChange": 0x80385e74,
		"sMonteM_MustacheAColorChange": 0x80385e74,
		"NPC::@1547": 0x80385e84,
		"NPC::sMonteM_MustacheAData": 0x80385e94,
		"sMonteM_MustacheAData": 0x80385e94,
		"NPC::@1548": 0x80385ec0,
		"NPC::sMonteM_GlassesAData": 0x80385ed4,
		"sMonteM_GlassesAData": 0x80385ed4,
		"NPC::sMonteM_GlassesBColorBuf0": 0x80385f00,
		"sMonteM_GlassesBColorBuf0": 0x80385f00,
		"NPC::@1549": 0x80385f18,
		"NPC::sMonteM_GlassesBColorChange": 0x80385f24,
		"sMonteM_GlassesBColorChange": 0x80385f24,
		"NPC::@1550": 0x80385f34,
		"NPC::sMonteM_GlassesBData": 0x80385f48,
		"sMonteM_GlassesBData": 0x80385f48,
		"NPC::sMonteM_LapelAColorBuf0": 0x80385f74,
		"sMonteM_LapelAColorBuf0": 0x80385f74,
		"NPC::sMonteM_LapelAColorBuf1": 0x80385f84,
		"sMonteM_LapelAColorBuf1": 0x80385f84,
		"NPC::@1551": 0x80385f94,
		"NPC::sMonteM_LapelAColorChange": 0x80385fa0,
		"sMonteM_LapelAColorChange": 0x80385fa0,
		"NPC::@1552": 0x80385fb0,
		"NPC::@1553": 0x80385fbc,
		"NPC::sMonteM_LapelAData": 0x80385fcc,
		"sMonteM_LapelAData": 0x80385fcc,
		"NPC::@1554": 0x80385ff8,
		"NPC::sMonteM_TieBColorChange": 0x80386004,
		"sMonteM_TieBColorChange": 0x80386004,
		"NPC::@1555": 0x80386014,
		"NPC::sMonteM_TieBData": 0x80386024,
		"sMonteM_TieBData": 0x80386024,
		"NPC::@1556": 0x80386050,
		"NPC::sMonteM_LuggageData": 0x80386064,
		"sMonteM_LuggageData": 0x80386064,
		"NPC::@1557": 0x80386090,
		"NPC::sMonteMF_TubeData": 0x803860a0,
		"sMonteMF_TubeData": 0x803860a0,
		"NPC::@1558": 0x803860cc,
		"NPC::@1559": 0x803860d8,
		"NPC::sMonteMG_MopData": 0x803860e8,
		"sMonteMG_MopData": 0x803860e8,
		"NPC::@1560": 0x80386114,
		"NPC::sMonteMH_UkleleData": 0x80386128,
		"sMonteMH_UkleleData": 0x80386128,
		"NPC::sMonteW_FlowerInColorBuf": 0x80386154,
		"sMonteW_FlowerInColorBuf": 0x80386154,
		"NPC::@1561": 0x8038616c,
		"NPC::sMonteW_FlowerInColorChange": 0x80386178,
		"sMonteW_FlowerInColorChange": 0x80386178,
		"NPC::sMonteW_FlowerOutColorBuf": 0x80386188,
		"sMonteW_FlowerOutColorBuf": 0x80386188,
		"NPC::@1562": 0x803861a0,
		"NPC::sMonteW_FlowerOutColorChange": 0x803861ac,
		"sMonteW_FlowerOutColorChange": 0x803861ac,
		"NPC::@1563": 0x803861bc,
		"NPC::@1564": 0x803861c8,
		"NPC::sMonteW_FlowerData": 0x803861dc,
		"sMonteW_FlowerData": 0x803861dc,
		"NPC::sMonteW_HatAMainColorBuf0": 0x80386208,
		"sMonteW_HatAMainColorBuf0": 0x80386208,
		"NPC::sMonteW_HatAMainColorBuf1": 0x80386228,
		"sMonteW_HatAMainColorBuf1": 0x80386228,
		"NPC::sMonteW_HatAMainColorChange": 0x80386248,
		"sMonteW_HatAMainColorChange": 0x80386248,
		"NPC::sMonteW_HatABeltColorBuf": 0x80386258,
		"sMonteW_HatABeltColorBuf": 0x80386258,
		"NPC::sMonteW_HatABeltColorChange": 0x80386278,
		"sMonteW_HatABeltColorChange": 0x80386278,
		"NPC::@1565": 0x80386288,
		"NPC::sMonteW_HatAData": 0x80386298,
		"sMonteW_HatAData": 0x80386298,
		"NPC::sMonteW_GlassBColorBuf": 0x803862c4,
		"sMonteW_GlassBColorBuf": 0x803862c4,
		"NPC::sMonteW_GlassBColorChange": 0x803862dc,
		"sMonteW_GlassBColorChange": 0x803862dc,
		"NPC::@1566": 0x803862ec,
		"NPC::sMonteW_GlassBData": 0x803862fc,
		"sMonteW_GlassBData": 0x803862fc,
		"NPC::@1567": 0x80386328,
		"NPC::sMonteW_ArrowRData": 0x8038633c,
		"sMonteW_ArrowRData": 0x8038633c,
		"NPC::@1568": 0x80386368,
		"NPC::sMonteW_ArrowLData": 0x8038637c,
		"sMonteW_ArrowLData": 0x8038637c,
		"NPC::@1569": 0x803863a8,
		"NPC::sMonteWC_HatCData": 0x803863b8,
		"sMonteWC_HatCData": 0x803863b8,
		"NPC::@1570": 0x803863e4,
		"NPC::sMonteWC_BraceletRData": 0x803863f8,
		"sMonteWC_BraceletRData": 0x803863f8,
		"NPC::@1571": 0x80386424,
		"NPC::@1572": 0x80386430,
		"NPC::sMonteWC_BraceletLData": 0x80386444,
		"sMonteWC_BraceletLData": 0x80386444,
		"NPC::sMareM_HatAColorBuf0": 0x80386470,
		"sMareM_HatAColorBuf0": 0x80386470,
		"NPC::sMareM_HatAColorBuf1": 0x803864b8,
		"sMareM_HatAColorBuf1": 0x803864b8,
		"NPC::sMareM_HatAColorChange": 0x80386500,
		"sMareM_HatAColorChange": 0x80386500,
		"NPC::@1574": 0x80386510,
		"NPC::sMareM_HatAData": 0x80386520,
		"sMareM_HatAData": 0x80386520,
		"NPC::sMareM_HatBColorBuf0": 0x8038654c,
		"sMareM_HatBColorBuf0": 0x8038654c,
		"NPC::sMareM_HatBColorBuf1": 0x8038657c,
		"sMareM_HatBColorBuf1": 0x8038657c,
		"NPC::sMareM_HatBColorChange": 0x803865ac,
		"sMareM_HatBColorChange": 0x803865ac,
		"NPC::@1575": 0x803865bc,
		"NPC::sMareM_HatBData": 0x803865cc,
		"sMareM_HatBData": 0x803865cc,
		"NPC::sMareM_HatEColorBuf0": 0x803865f8,
		"sMareM_HatEColorBuf0": 0x803865f8,
		"NPC::sMareM_HatEColorBuf1": 0x80386650,
		"sMareM_HatEColorBuf1": 0x80386650,
		"NPC::sMareM_HatEColorChange": 0x803866a8,
		"sMareM_HatEColorChange": 0x803866a8,
		"NPC::@1576": 0x803866b8,
		"NPC::sMareM_HatEData": 0x803866c8,
		"sMareM_HatEData": 0x803866c8,
		"NPC::sMareM_ShellAColorBuf0": 0x803866f4,
		"sMareM_ShellAColorBuf0": 0x803866f4,
		"NPC::sMareM_ShellAColorBuf1": 0x80386744,
		"sMareM_ShellAColorBuf1": 0x80386744,
		"NPC::sMareM_ShellAColorChange": 0x80386794,
		"sMareM_ShellAColorChange": 0x80386794,
		"NPC::@1578": 0x803867a4,
		"NPC::sMareM_ShellAData": 0x803867b8,
		"sMareM_ShellAData": 0x803867b8,
		"NPC::sMareM_ShellBColorBuf0": 0x803867e4,
		"sMareM_ShellBColorBuf0": 0x803867e4,
		"NPC::sMareM_ShellBColorBuf1": 0x80386834,
		"sMareM_ShellBColorBuf1": 0x80386834,
		"NPC::sMareM_ShellBColorChange": 0x80386884,
		"sMareM_ShellBColorChange": 0x80386884,
		"NPC::@1579": 0x80386894,
		"NPC::sMareM_ShellBData": 0x803868a8,
		"sMareM_ShellBData": 0x803868a8,
		"NPC::sMareM_BivalveBColorBuf0": 0x803868d4,
		"sMareM_BivalveBColorBuf0": 0x803868d4,
		"NPC::sMareM_BivalveBColorBuf1": 0x80386904,
		"sMareM_BivalveBColorBuf1": 0x80386904,
		"NPC::sMareM_BivalveBColorChange": 0x80386934,
		"sMareM_BivalveBColorChange": 0x80386934,
		"NPC::@1580": 0x80386944,
		"NPC::sMareM_BivalveBData": 0x80386958,
		"sMareM_BivalveBData": 0x80386958,
		"NPC::sMareM_GlassColorBuf0": 0x80386984,
		"sMareM_GlassColorBuf0": 0x80386984,
		"NPC::sMareM_GlassColorBuf1": 0x8038699c,
		"sMareM_GlassColorBuf1": 0x8038699c,
		"NPC::@1581": 0x803869b4,
		"NPC::sMareM_GlassColorChange": 0x803869c0,
		"sMareM_GlassColorChange": 0x803869c0,
		"NPC::@1582": 0x803869d0,
		"NPC::sMareM_GlassData": 0x803869e0,
		"sMareM_GlassData": 0x803869e0,
		"NPC::sMareMB_ElderMat1ColorChange": 0x80386a0c,
		"sMareMB_ElderMat1ColorChange": 0x80386a0c,
		"NPC::sMareMB_ElderMat2ColorChange": 0x80386a1c,
		"sMareMB_ElderMat2ColorChange": 0x80386a1c,
		"NPC::sMareMB_ElderMat3ColorChange": 0x80386a2c,
		"sMareMB_ElderMat3ColorChange": 0x80386a2c,
		"NPC::@1585": 0x80386a3c,
		"NPC::sMareMB_ElderData": 0x80386a4c,
		"sMareMB_ElderData": 0x80386a4c,
		"NPC::sMareMB_FishingRodMat1ColorChange": 0x80386a78,
		"sMareMB_FishingRodMat1ColorChange": 0x80386a78,
		"NPC::sMareMB_FishingRodMat2ColorChange": 0x80386a88,
		"sMareMB_FishingRodMat2ColorChange": 0x80386a88,
		"NPC::sMareMB_FishingRodMat3ColorChange": 0x80386a98,
		"sMareMB_FishingRodMat3ColorChange": 0x80386a98,
		"NPC::@1586": 0x80386aa8,
		"NPC::sMareMC_HatFColorChange": 0x80386abc,
		"sMareMC_HatFColorChange": 0x80386abc,
		"NPC::@1587": 0x80386acc,
		"NPC::sMareMC_HatFData": 0x80386adc,
		"sMareMC_HatFData": 0x80386adc,
		"NPC::sMareMC_BeardColorChange": 0x80386b08,
		"sMareMC_BeardColorChange": 0x80386b08,
		"NPC::@1588": 0x80386b18,
		"NPC::sMareMC_BeardData": 0x80386b2c,
		"sMareMC_BeardData": 0x80386b2c,
		"NPC::sMareMC_MustacheColorChange": 0x80386b58,
		"sMareMC_MustacheColorChange": 0x80386b58,
		"NPC::@1589": 0x80386b68,
		"NPC::sMareMC_MustacheData": 0x80386b7c,
		"sMareMC_MustacheData": 0x80386b7c,
		"NPC::sMareMD_PipeColorChange": 0x80386ba8,
		"sMareMD_PipeColorChange": 0x80386ba8,
		"NPC::@1591": 0x80386bb8,
		"NPC::sMareMD_PipeData": 0x80386bcc,
		"sMareMD_PipeData": 0x80386bcc,
		"NPC::sMareW_PearlAColorBuf0": 0x80386bf8,
		"sMareW_PearlAColorBuf0": 0x80386bf8,
		"NPC::sMareW_PearlAColorBuf1": 0x80386c28,
		"sMareW_PearlAColorBuf1": 0x80386c28,
		"NPC::sMareW_PearlAColorChange": 0x80386c58,
		"sMareW_PearlAColorChange": 0x80386c58,
		"NPC::@1592": 0x80386c68,
		"NPC::sMareW_PearlAData": 0x80386c7c,
		"sMareW_PearlAData": 0x80386c7c,
		"NPC::sMareW_HatAColorBuf0": 0x80386ca8,
		"sMareW_HatAColorBuf0": 0x80386ca8,
		"NPC::sMareW_HatAColorBuf1": 0x80386cd8,
		"sMareW_HatAColorBuf1": 0x80386cd8,
		"NPC::sMareW_HatAColorChange": 0x80386d08,
		"sMareW_HatAColorChange": 0x80386d08,
		"NPC::@1593": 0x80386d18,
		"NPC::sMareW_HatAData": 0x80386d28,
		"sMareW_HatAData": 0x80386d28,
		"NPC::sMareW_HatDColorBuf0": 0x80386d54,
		"sMareW_HatDColorBuf0": 0x80386d54,
		"NPC::sMareW_HatDColorBuf1": 0x80386dac,
		"sMareW_HatDColorBuf1": 0x80386dac,
		"NPC::sMareW_HatDColorChange": 0x80386e04,
		"sMareW_HatDColorChange": 0x80386e04,
		"NPC::@1594": 0x80386e14,
		"NPC::sMareW_HatDData": 0x80386e24,
		"sMareW_HatDData": 0x80386e24,
		"NPC::sMareW_ShellAColorBuf0": 0x80386e50,
		"sMareW_ShellAColorBuf0": 0x80386e50,
		"NPC::sMareW_ShellAColorBuf1": 0x80386e80,
		"sMareW_ShellAColorBuf1": 0x80386e80,
		"NPC::sMareW_ShellAColorChange": 0x80386eb0,
		"sMareW_ShellAColorChange": 0x80386eb0,
		"NPC::@1595": 0x80386ec0,
		"NPC::sMareW_ShellAData": 0x80386ed0,
		"sMareW_ShellAData": 0x80386ed0,
		"NPC::sMareW_ShellBColorBuf0": 0x80386efc,
		"sMareW_ShellBColorBuf0": 0x80386efc,
		"NPC::sMareW_ShellBColorBuf1": 0x80386f44,
		"sMareW_ShellBColorBuf1": 0x80386f44,
		"NPC::sMareW_ShellBColorChange": 0x80386f8c,
		"sMareW_ShellBColorChange": 0x80386f8c,
		"NPC::@1596": 0x80386f9c,
		"NPC::sMareW_ShellBData": 0x80386fac,
		"sMareW_ShellBData": 0x80386fac,
		"NPC::sMareW_BivalveAColorBuf0": 0x80386fd8,
		"sMareW_BivalveAColorBuf0": 0x80386fd8,
		"NPC::sMareW_BivalveAColorBuf1": 0x80387008,
		"sMareW_BivalveAColorBuf1": 0x80387008,
		"NPC::sMareW_BivalveAColorChange": 0x80387038,
		"sMareW_BivalveAColorChange": 0x80387038,
		"NPC::@1597": 0x80387048,
		"NPC::sMareW_BivalveAData": 0x8038705c,
		"sMareW_BivalveAData": 0x8038705c,
		"NPC::sMareWB_BabyBodyColorChange": 0x80387088,
		"sMareWB_BabyBodyColorChange": 0x80387088,
		"NPC::@1599": 0x80387098,
		"NPC::sMareWB_BabyHatColorChange": 0x803870a4,
		"sMareWB_BabyHatColorChange": 0x803870a4,
		"NPC::@1600": 0x803870b4,
		"NPC::sMareWB_BabyBedColorChange": 0x803870c0,
		"sMareWB_BabyBedColorChange": 0x803870c0,
		"NPC::@1601": 0x803870d0,
		"NPC::@1602": 0x803870e0,
		"NPC::sKinopio_SunGlassesData": 0x803870f8,
		"sKinopio_SunGlassesData": 0x803870f8,
		"NPC::@1603": 0x80387124,
		"NPC::@1604": 0x80387134,
		"NPC::sKinojii_StickData": 0x80387148,
		"sKinojii_StickData": 0x80387148,
		"NPC::@1605": 0x80387174,
		"NPC::sPeach_HairNormalData": 0x8038718c,
		"sPeach_HairNormalData": 0x8038718c,
		"NPC::@1606": 0x803871b8,
		"NPC::@1607": 0x803871c4,
		"NPC::sPeach_Hand1LData": 0x803871d8,
		"sPeach_Hand1LData": 0x803871d8,
		"NPC::@1608": 0x80387204,
		"NPC::@1609": 0x80387210,
		"NPC::sPeach_Hand1RData": 0x80387224,
		"sPeach_Hand1RData": 0x80387224,
		"NPC::@1610": 0x80387250,
		"NPC::sPeach_HairPonytailData": 0x80387268,
		"sPeach_HairPonytailData": 0x80387268,
		"NPC::@1611": 0x80387294,
		"NPC::sPeach_ParasolData": 0x803872a8,
		"sPeach_ParasolData": 0x803872a8,
		"NPC::@1612": 0x803872d4,
		"NPC::sPeach_Hand2LData": 0x803872e8,
		"sPeach_Hand2LData": 0x803872e8,
		"NPC::@1613": 0x80387314,
		"@1613": 0x80387314,
		"NPC::sPeach_Hand2RData": 0x80387328,
		"sPeach_Hand2RData": 0x80387328,
		"NPC::sRaccoonDog_TubeColorBuf0": 0x80387354,
		"sRaccoonDog_TubeColorBuf0": 0x80387354,
		"NPC::sRaccoonDog_TubeColorBuf1": 0x80387364,
		"sRaccoonDog_TubeColorBuf1": 0x80387364,
		"NPC::sRaccoonDog_TubeColorChange": 0x80387374,
		"sRaccoonDog_TubeColorChange": 0x80387374,
		"NPC::@1615": 0x80387384,
		"NPC::@1616": 0x80387390,
		"NPC::sRaccoonDog_TubeData": 0x8038739c,
		"sRaccoonDog_TubeData": 0x8038739c,
		"NPC::sMonteM_BodyColorBuf": 0x803873c8,
		"sMonteM_BodyColorBuf": 0x803873c8,
		"NPC::@1617": 0x80387418,
		"NPC::sMonteM_BodyColor": 0x80387424,
		"sMonteM_BodyColor": 0x80387424,
		"NPC::sMonteMA_ClothColorBuf0": 0x80387434,
		"sMonteMA_ClothColorBuf0": 0x80387434,
		"NPC::sMonteMA_ClothColorBuf1": 0x8038748c,
		"sMonteMA_ClothColorBuf1": 0x8038748c,
		"NPC::@1618": 0x803874e4,
		"NPC::sMonteMA_ClothColor": 0x803874f0,
		"sMonteMA_ClothColor": 0x803874f0,
		"NPC::sMonteMB_BodyColorBuf": 0x80387500,
		"sMonteMB_BodyColorBuf": 0x80387500,
		"NPC::sMonteMB_BodyColor": 0x80387520,
		"sMonteMB_BodyColor": 0x80387520,
		"NPC::sMonteMB_ClothColorBuf": 0x80387530,
		"sMonteMB_ClothColorBuf": 0x80387530,
		"NPC::sMonteMB_ClothColor": 0x80387560,
		"sMonteMB_ClothColor": 0x80387560,
		"NPC::sMonteMC_ClothColorBuf0": 0x80387570,
		"sMonteMC_ClothColorBuf0": 0x80387570,
		"NPC::sMonteMC_ClothColorBuf1": 0x803875c8,
		"sMonteMC_ClothColorBuf1": 0x803875c8,
		"NPC::sMonteMC_ClothColor": 0x80387620,
		"sMonteMC_ClothColor": 0x80387620,
		"NPC::sMonteMD_ClothColorBuf": 0x80387630,
		"sMonteMD_ClothColorBuf": 0x80387630,
		"NPC::sMonteMD_ClothColor": 0x80387658,
		"sMonteMD_ClothColor": 0x80387658,
		"NPC::sMonteW_ColorBuf": 0x80387668,
		"sMonteW_ColorBuf": 0x80387668,
		"NPC::sMonteW_BodyColor": 0x80387698,
		"sMonteW_BodyColor": 0x80387698,
		"NPC::sMonteWA_ClothColorBuf": 0x803876a8,
		"sMonteWA_ClothColorBuf": 0x803876a8,
		"NPC::sMonteWA_ClothColor": 0x803876d8,
		"sMonteWA_ClothColor": 0x803876d8,
		"NPC::sMonteWB_ClothColorBuf0": 0x803876e8,
		"sMonteWB_ClothColorBuf0": 0x803876e8,
		"NPC::sMonteWB_ClothColorBuf1": 0x80387730,
		"sMonteWB_ClothColorBuf1": 0x80387730,
		"NPC::sMonteWB_ClothColor": 0x80387778,
		"sMonteWB_ClothColor": 0x80387778,
		"NPC::sMareM_ColorBuf": 0x80387788,
		"sMareM_ColorBuf": 0x80387788,
		"NPC::sMareM_BodyColor": 0x803877b8,
		"sMareM_BodyColor": 0x803877b8,
		"NPC::sMareW_ColorBuf": 0x803877c8,
		"sMareW_ColorBuf": 0x803877c8,
		"NPC::sMareW_BodyColor": 0x803877f8,
		"sMareW_BodyColor": 0x803877f8,
		"NPC::sKinopio_BodyColorData0": 0x80387808,
		"sKinopio_BodyColorData0": 0x80387808,
		"NPC::sKinopio_BodyColorData1": 0x80387830,
		"sKinopio_BodyColorData1": 0x80387830,
		"NPC::@1619": 0x80387858,
		"NPC::sKinopio_BodyColor": 0x80387864,
		"sKinopio_BodyColor": 0x80387864,
		"NPC::sKinopio_ClothColorData0": 0x80387874,
		"sKinopio_ClothColorData0": 0x80387874,
		"NPC::sKinopio_ClothColorData1": 0x8038789c,
		"sKinopio_ClothColorData1": 0x8038789c,
		"NPC::@1620": 0x803878c4,
		"NPC::sKinopio_ClothColor": 0x803878d0,
		"sKinopio_ClothColor": 0x803878d0,
		"NPC::sRaccoonDog_ClothColorBuf0": 0x803878e0,
		"sRaccoonDog_ClothColorBuf0": 0x803878e0,
		"NPC::sRaccoonDog_ClothColorBuf1": 0x803878f0,
		"sRaccoonDog_ClothColorBuf1": 0x803878f0,
		"NPC::sRaccoonDog_ClothColor": 0x80387900,
		"sRaccoonDog_ClothColor": 0x80387900,
		"NPC::sMonteM_InitData": 0x80387910,
		"sMonteM_InitData": 0x80387910,
		"NPC::sMonteMA_InitData": 0x80387964,
		"sMonteMA_InitData": 0x80387964,
		"NPC::sMonteMB_InitData": 0x803879b8,
		"sMonteMB_InitData": 0x803879b8,
		"NPC::sMonteMC_InitData": 0x80387a0c,
		"sMonteMC_InitData": 0x80387a0c,
		"NPC::sMonteMD_InitData": 0x80387a60,
		"sMonteMD_InitData": 0x80387a60,
		"NPC::sMonteME_InitData": 0x80387ab4,
		"sMonteME_InitData": 0x80387ab4,
		"NPC::sMonteMF_InitData": 0x80387b08,
		"sMonteMF_InitData": 0x80387b08,
		"NPC::sMonteMG_InitData": 0x80387b5c,
		"sMonteMG_InitData": 0x80387b5c,
		"NPC::sMonteMH_InitData": 0x80387bb0,
		"sMonteMH_InitData": 0x80387bb0,
		"NPC::sMonteW_InitData": 0x80387c04,
		"sMonteW_InitData": 0x80387c04,
		"NPC::sMonteWA_InitData": 0x80387c58,
		"sMonteWA_InitData": 0x80387c58,
		"NPC::sMonteWB_InitData": 0x80387cac,
		"sMonteWB_InitData": 0x80387cac,
		"NPC::sMonteWC_InitData": 0x80387d00,
		"sMonteWC_InitData": 0x80387d00,
		"NPC::sMareM_InitData": 0x80387d54,
		"sMareM_InitData": 0x80387d54,
		"NPC::sMareMB_InitData": 0x80387da8,
		"sMareMB_InitData": 0x80387da8,
		"NPC::sMareMC_InitData": 0x80387dfc,
		"sMareMC_InitData": 0x80387dfc,
		"NPC::sMareMD_InitData": 0x80387e50,
		"sMareMD_InitData": 0x80387e50,
		"NPC::sMareW_InitData": 0x80387ea4,
		"sMareW_InitData": 0x80387ea4,
		"NPC::sMareWB_InitData": 0x80387ef8,
		"sMareWB_InitData": 0x80387ef8,
		"NPC::sKinopio_InitData": 0x80387f4c,
		"sKinopio_InitData": 0x80387f4c,
		"NPC::sKinojii_InitData": 0x80387fa0,
		"sKinojii_InitData": 0x80387fa0,
		"NPC::sPeach_InitData": 0x80387ff4,
		"sPeach_InitData": 0x80387ff4,
		"NPC::sRaccoonDog_InitData": 0x80388048,
		"sRaccoonDog_InitData": 0x80388048,
		"NPC::sSunflowerL_InitData": 0x8038809c,
		"sSunflowerL_InitData": 0x8038809c,
		"NPC::sSunflowerS_InitData": 0x803880f0,
		"sSunflowerS_InitData": 0x803880f0,
		"NPC::sBoardNpc_InitData": 0x80388144,
		"sBoardNpc_InitData": 0x80388144,
		"TBaseNPC::sMtxEffectInitData$localstatic1$setMtxEffect_": 0x80388308,
		"sMtxEffectInitData$localstatic1$setMtxEffect_": 0x80388308,
		"TBaseNPC::sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x803883e8,
		"sIndividualHoldArrowBck$localstatic0$initBaseActionFlag_": 0x803883e8,
		"TBaseNPC::sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x803883f8,
		"sIndividualKinopioBck$localstatic1$initBaseActionFlag_": 0x803883f8,
		"TBaseNPC::sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x80388430,
		"sIndividualKinopioBtp$localstatic2$initBaseActionFlag_": 0x80388430,
		"TBaseNPC::sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x80388448,
		"sIndividualKinojiiBck$localstatic3$initBaseActionFlag_": 0x80388448,
		"TBaseNPC::sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x80388478,
		"sIndividualKinojiiBtp$localstatic4$initBaseActionFlag_": 0x80388478,
		"TBaseNPC::sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80388490,
		"sIndividualParentRaccoonDogAnmBck$localstatic0$initIndividualAnm_": 0x80388490,
		"TBaseNPC::sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x803884a0,
		"sIndividualChildRaccoonDogAnmBck$localstatic1$initIndividualAnm_": 0x803884a0,
		"TBaseNPC::sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x803884b0,
		"sIndividualMareMA0Bck$localstatic2$initIndividualAnm_": 0x803884b0,
		"TBaseNPC::sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x803884c0,
		"sIndividualMareMA0Btp$localstatic3$initIndividualAnm_": 0x803884c0,
		"TBaseNPC::sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x803884d0,
		"sIndividualMareMA1Bck$localstatic4$initIndividualAnm_": 0x803884d0,
		"TBaseNPC::sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x803884e0,
		"sIndividualMareMA1Btp$localstatic5$initIndividualAnm_": 0x803884e0,
		"NPC::@2266": 0x803885d0,
		"NPC::@2275": 0x803885e0,
		"NPC::@2489": 0x80388608,
		"NPC::@1938": 0x80388708,
		"NPC::@1939": 0x80388730,
		"NPC::@1940": 0x80388758,
		"NPC::@1941": 0x80388780,
		"NPC::@1942": 0x803887a8,
		"NPC::@1943": 0x803887cc,
		"NPC::@1944": 0x803887f4,
		"NPC::@1945": 0x8038881c,
		"NPC::@1946": 0x80388840,
		"NPC::@1947": 0x80388868,
		"NPC::@1948": 0x80388890,
		"NPC::@1949": 0x803888bc,
		"NPC::@1950": 0x803888e4,
		"NPC::@1951": 0x80388908,
		"NPC::@1952": 0x80388930,
		"NPC::@1953": 0x8038895c,
		"NPC::@1954": 0x80388988,
		"NPC::@1955": 0x803889b0,
		"NPC::@1956": 0x803889d8,
		"NPC::@1957": 0x80388a00,
		"NPC::@1958": 0x80388a28,
		"NPC::@1959": 0x80388a54,
		"NPC::@1960": 0x80388a80,
		"NPC::@1984": 0x80388d00,
		"NPC::@1985": 0x80388d24,
		"NPC::@1986": 0x80388d4c,
		"NPC::@1989": 0x80388d74,
		"NPC::@1990": 0x80388d9c,
		"NPC::@1991": 0x80388dc4,
		"NPC::@1992": 0x80388dec,
		"NPC::@1993": 0x80388e14,
		"NPC::@1994": 0x80388e38,
		"NPC::@1995": 0x80388e60,
		"NPC::@1996": 0x80388e84,
		"NPC::@1997": 0x80388eac,
		"NPC::@1998": 0x80388ed4,
		"NPC::@1999": 0x80388f00,
		"NPC::@2000": 0x80388f2c,
		"NPC::@2001": 0x80388f54,
		"NPC::@2002": 0x80388f78,
		"NPC::@2003": 0x80388fa0,
		"NPC::@2004": 0x80388fcc,
		"NPC::@2005": 0x80388ff8,
		"NPC::@2006": 0x80389020,
		"NPC::@2007": 0x80389048,
		"NPC::@2008": 0x80389070,
		"NPC::@2009": 0x80389098,
		"NPC::@2010": 0x803890c4,
		"NPC::@2011": 0x803890ec,
		"NPC::@2012": 0x80389118,
		"NPC::@2013": 0x80389140,
		"NPC::@2014": 0x80389170,
		"NPC::@2015": 0x803891a0,
		"NPC::@2016": 0x803891c8,
		"NPC::@2017": 0x803891f0,
		"NPC::@2018": 0x80389218,
		"NPC::@2021": 0x80389248,
		"NPC::@2022": 0x80389268,
		"NPC::@2023": 0x80389288,
		"NPC::@2026": 0x803892ac,
		"NPC::@2027": 0x803892d0,
		"NPC::@2028": 0x803892f4,
		"NPC::@2029": 0x80389314,
		"NPC::@2030": 0x80389338,
		"NPC::@2031": 0x80389358,
		"NPC::@2032": 0x8038937c,
		"NPC::@2033": 0x8038939c,
		"NPC::@2034": 0x803893c0,
		"NPC::@2035": 0x803893e4,
		"NPC::@2036": 0x8038940c,
		"NPC::@2037": 0x8038942c,
		"NPC::@2038": 0x8038944c,
		"NPC::@2039": 0x8038946c,
		"NPC::@2040": 0x80389490,
		"NPC::@2041": 0x803894b4,
		"NPC::@2042": 0x803894d8,
		"NPC::@2043": 0x803894fc,
		"NPC::@2044": 0x80389520,
		"NPC::@2045": 0x80389544,
		"NPC::@2046": 0x8038956c,
		"NPC::@2047": 0x80389590,
		"NPC::@2048": 0x803895b4,
		"NPC::@2049": 0x803895dc,
		"NPC::@2057": 0x8038966c,
		"NPC::@2059": 0x80389690,
		"NPC::@2060": 0x803896b4,
		"NPC::@2061": 0x803896dc,
		"NPC::@2062": 0x80389700,
		"NPC::@2065": 0x80389724,
		"NPC::@2066": 0x80389748,
		"NPC::@2073": 0x803897f8,
		"NPC::@2074": 0x8038981c,
		"NPC::@2075": 0x8038983c,
		"NPC::@2076": 0x80389860,
		"NPC::@2077": 0x80389884,
		"NPC::@2078": 0x803898ac,
		"NPC::@2079": 0x803898cc,
		"NPC::@2080": 0x803898ec,
		"NPC::@2081": 0x8038990c,
		"NPC::@2083": 0x80389954,
		"NPC::@2084": 0x80389978,
		"NPC::@2085": 0x8038999c,
		"NPC::@2086": 0x803899c0,
		"NPC::@2087": 0x803899e8,
		"NPC::@2088": 0x80389a0c,
		"NPC::@2089": 0x80389a30,
		"NPC::@2090": 0x80389a58,
		"NPC::@2091": 0x80389a7c,
		"NPC::@2092": 0x80389aa0,
		"NPC::@2093": 0x80389ac4,
		"NPC::@2098": 0x80389ae8,
		"NPC::@2099": 0x80389b10,
		"NPC::@2100": 0x80389b3c,
		"NPC::@2101": 0x80389b68,
		"NPC::@2102": 0x80389b90,
		"NPC::@2113": 0x80389cf0,
		"NPC::@2117": 0x80389d8c,
		"NPC::@2120": 0x80389db8,
		"NPC::@2121": 0x80389ddc,
		"NPC::@2122": 0x80389e04,
		"NPC::@2123": 0x80389e2c,
		"NPC::@2124": 0x80389e54,
		"NPC::@2125": 0x80389e7c,
		"NPC::@2126": 0x80389ea0,
		"NPC::@2127": 0x80389ec4,
		"NPC::@2130": 0x80389ee8,
		"NPC::@2131": 0x80389f10,
		"NPC::@2132": 0x80389f34,
		"NPC::@2133": 0x80389f5c,
		"NPC::@2134": 0x80389f84,
		"NPC::@2135": 0x80389fa8,
		"NPC::@2136": 0x80389fd0,
		"NPC::@2139": 0x80389ff0,
		"NPC::@2140": 0x8038a018,
		"NPC::@2141": 0x8038a040,
		"NPC::@2144": 0x8038a068,
		"NPC::@2145": 0x8038a094,
		"NPC::@2146": 0x8038a0bc,
		"NPC::@2150": 0x8038a0e8,
		"NPC::@2151": 0x8038a114,
		"NPC::@2152": 0x8038a140,
		"NPC::@1700": 0x8038a17c,
		"NPC::@2153": 0x8038a190,
		"NPC::@2154": 0x8038a1c0,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x8038a260,
		"sCheckFrameMonte$localstatic0$isPolWaitCEffectEmitTime_": 0x8038a260,
		"TBaseNPC::sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x8038a27c,
		"sCheckFrameMare$localstatic1$isPolWaitCEffectEmitTime_": 0x8038a27c,
		"TBaseNPC::sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x8038a288,
		"sCheckFrameKino$localstatic2$isPolWaitCEffectEmitTime_": 0x8038a288,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8038a294,
		"sCheckFrameMonte$localstatic0$isPolWaitLEffectEmitTime_": 0x8038a294,
		"TBaseNPC::sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8038a2a4,
		"sCheckFrameMonte$localstatic0$isPolWaitREffectEmitTime_": 0x8038a2a4,
		"NPC::@2696": 0x8038a2b4,
		"NPC::sMonteM_AnmIndex": 0x8038a320,
		"sMonteM_AnmIndex": 0x8038a320,
		"NPC::sMonteME_AnmIndex": 0x8038a4f0,
		"sMonteME_AnmIndex": 0x8038a4f0,
		"NPC::sMonteMF_AnmIndex": 0x8038a6c0,
		"sMonteMF_AnmIndex": 0x8038a6c0,
		"NPC::sMonteMG_AnmIndex": 0x8038a890,
		"sMonteMG_AnmIndex": 0x8038a890,
		"NPC::sMonteMH_AnmIndex": 0x8038aa60,
		"sMonteMH_AnmIndex": 0x8038aa60,
		"NPC::sMonteW_AnmIndex": 0x8038ac30,
		"sMonteW_AnmIndex": 0x8038ac30,
		"NPC::sMonteWC_AnmIndex": 0x8038ae00,
		"sMonteWC_AnmIndex": 0x8038ae00,
		"NPC::sMareM_AnmIndex": 0x8038afd0,
		"sMareM_AnmIndex": 0x8038afd0,
		"NPC::sMareMA_AnmIndex": 0x8038b1a0,
		"sMareMA_AnmIndex": 0x8038b1a0,
		"NPC::sMareMB_AnmIndex": 0x8038b370,
		"sMareMB_AnmIndex": 0x8038b370,
		"NPC::sMareMC_AnmIndex": 0x8038b540,
		"sMareMC_AnmIndex": 0x8038b540,
		"NPC::sMareMD_AnmIndex": 0x8038b710,
		"sMareMD_AnmIndex": 0x8038b710,
		"NPC::sMareW_AnmIndex": 0x8038b8e0,
		"sMareW_AnmIndex": 0x8038b8e0,
		"NPC::sMareWA_AnmIndex": 0x8038bab0,
		"sMareWA_AnmIndex": 0x8038bab0,
		"NPC::sMareWB_AnmIndex": 0x8038bc80,
		"sMareWB_AnmIndex": 0x8038bc80,
		"NPC::sKinopio_AnmIndex": 0x8038be50,
		"sKinopio_AnmIndex": 0x8038be50,
		"NPC::sKinojii_AnmIndex": 0x8038c020,
		"sKinojii_AnmIndex": 0x8038c020,
		"NPC::sPeach_AnmIndex": 0x8038c1f0,
		"sPeach_AnmIndex": 0x8038c1f0,
		"NPC::sRaccoonDog_AnmIndex": 0x8038c3c0,
		"sRaccoonDog_AnmIndex": 0x8038c3c0,
		"NPC::sSunflowerL_AnmIndex": 0x8038c590,
		"sSunflowerL_AnmIndex": 0x8038c590,
		"NPC::sSunflowerS_AnmIndex": 0x8038c760,
		"sSunflowerS_AnmIndex": 0x8038c760,
		"NPC::sMonteMA_IndividualBtp": 0x8038c930,
		"sMonteMA_IndividualBtp": 0x8038c930,
		"NPC::sMonteMB_IndividualBtp": 0x8038c9a0,
		"sMonteMB_IndividualBtp": 0x8038c9a0,
		"NPC::sMonteMC_IndividualBtp": 0x8038ca10,
		"sMonteMC_IndividualBtp": 0x8038ca10,
		"NPC::sMonteMD_IndividualBtp": 0x8038ca80,
		"sMonteMD_IndividualBtp": 0x8038ca80,
		"NPC::sMonteWA_IndividualBtp": 0x8038caf0,
		"sMonteWA_IndividualBtp": 0x8038caf0,
		"NPC::sMonteWB_IndividualBtp": 0x8038cb60,
		"sMonteWB_IndividualBtp": 0x8038cb60,
		"NPC::sAllNpcInitAnmData$1577": 0x8038cbd0,
		"sAllNpcInitAnmData$1577": 0x8038cbd0,
		"NPC::sBaseActionFlagTable$1938": 0x8038ccb8,
		"sBaseActionFlagTable$1938": 0x8038ccb8,
		"NPC::sBaseActionFlagTable$1941": 0x8038cd1c,
		"sBaseActionFlagTable$1941": 0x8038cd1c,
		"NPC::sBaseActionFlagTable$1944": 0x8038cd60,
		"sBaseActionFlagTable$1944": 0x8038cd60,
		"MSound::@1912": 0x80366ba0,
		"MSound::@1501": 0x80366c28,
		"@1501": 0x80366c28,
		"MSound::@2817": 0x80366c48,
		"MSound::@2822": 0x80366c64,
		"MSound::@2826": 0x80366c80,
		"MSound::@2832": 0x80366c94,
		"MSound::@2834": 0x80366cac,
		"MSound::@2835": 0x80366cc0,
		"MSound::@2836": 0x80366cd8,
		"MSound::@2841": 0x80366ce4,
		"MSound::@2844": 0x80366cf4,
		"MSound::@2846": 0x80366d0c,
		"MSound::@2862": 0x80366d44,
		"MSound::@2872": 0x80366d9c,
		"MSound::@2876": 0x80366dc8,
		"MSound::@2882": 0x80366dfc,
		"MSound::@2887": 0x80366e2c,
		"MSound::@2888": 0x80366e50,
		"MSound::@2894": 0x80366eb0,
		"MSound::@2911": 0x80366f40,
		"MSound::@2932": 0x80366fc0,
		"MSound::@2934": 0x80366fd8,
		"MSound::@3292": 0x80367008,
		"MSound::@3293": 0x80367018,
		"MSound::@3294": 0x80367028,
		"MSound::@3295": 0x80367038,
		"MSound::@3296": 0x80367044,
		"MSound::@3297": 0x80367050,
		"MSound::@3298": 0x80367060,
		"MSound::@3299": 0x80367070,
		"MSound::@3300": 0x80367080,
		"MSound::@3301": 0x80367098,
		"MSound::@3302": 0x803670ac,
		"MSound::@3303": 0x803670bc,
		"MSound::@3304": 0x803670dc,
		"MSound::@1994": 0x80367150,
		"MSound::@2024": 0x80367180,
		"MSound::@2026": 0x8036718c,
		"MSound::@2028": 0x8036719c,
		"MSound::@2449": 0x803671ac,
		"MSound::@2450": 0x803671bc,
		"MSound::@2451": 0x803671cc,
		"MSound::@2452": 0x803671dc,
		"MSound::@2453": 0x803671e8,
		"MSound::@2454": 0x803671f4,
		"MSound::@2455": 0x80367204,
		"MSound::@2456": 0x80367214,
		"MSound::@2457": 0x80367224,
		"MSound::@2458": 0x8036723c,
		"MSound::@2461": 0x80367280,
		"MSound::@2463": 0x803672a8,
		"MSound::@2464": 0x803672c4,
		"MSound::@2465": 0x803672dc,
		"MoveBG::@2192": 0x8037a854,
		"MoveBG::no_data_obj_hit_table": 0x8037a890,
		"no_data_obj_hit_table": 0x8037a890,
		"MoveBG::no_data_obj_hit_info": 0x8037a8a0,
		"no_data_obj_hit_info": 0x8037a8a0,
		"MoveBG::@2772": 0x8037a8cc,
		"MoveBG::@2774": 0x8037a8f0,
		"MoveBG::billboard_dolphin_anim_data": 0x8037a900,
		"billboard_dolphin_anim_data": 0x8037a900,
		"MoveBG::billboard_hit_data_table": 0x8037a93c,
		"billboard_hit_data_table": 0x8037a93c,
		"MoveBG::billboard_obj_hit_info": 0x8037a94c,
		"billboard_obj_hit_info": 0x8037a94c,
		"MoveBG::@2776": 0x8037a970,
		"MoveBG::@2777": 0x8037a988,
		"MoveBG::billboard_sun_anim_data": 0x8037a99c,
		"billboard_sun_anim_data": 0x8037a99c,
		"MoveBG::billboard_restaurant_anim_data": 0x8037aa00,
		"billboard_restaurant_anim_data": 0x8037aa00,
		"MoveBG::billboard_fish_anim_data": 0x8037aa68,
		"billboard_fish_anim_data": 0x8037aa68,
		"MoveBG::HideObj_hit_data_table": 0x8037aab4,
		"HideObj_hit_data_table": 0x8037aab4,
		"MoveBG::HideObj_obj_hit_info": 0x8037aac4,
		"HideObj_obj_hit_info": 0x8037aac4,
		"MoveBG::WaterHitHideObj_hit_data_table": 0x8037aad4,
		"WaterHitHideObj_hit_data_table": 0x8037aad4,
		"MoveBG::WaterHitHideObj_obj_hit_info": 0x8037aae4,
		"WaterHitHideObj_obj_hit_info": 0x8037aae4,
		"MoveBG::FruitHitHideObj_hit_data_table": 0x8037ab04,
		"FruitHitHideObj_hit_data_table": 0x8037ab04,
		"MoveBG::FruitHitHideObj_obj_hit_info": 0x8037ab14,
		"FruitHitHideObj_obj_hit_info": 0x8037ab14,
		"MoveBG::HipDropHideObj_hit_data_table": 0x8037ab34,
		"HipDropHideObj_hit_data_table": 0x8037ab34,
		"MoveBG::HipDropHideObj_obj_hit_info": 0x8037ab44,
		"HipDropHideObj_obj_hit_info": 0x8037ab44,
		"MoveBG::MonteChair_anim_data": 0x8037ab7c,
		"MonteChair_anim_data": 0x8037ab7c,
		"MoveBG::@2797": 0x8037ac38,
		"MoveBG::door_anim_data": 0x8037ac58,
		"door_anim_data": 0x8037ac58,
		"MoveBG::door_hit_data_table": 0x8037acbc,
		"door_hit_data_table": 0x8037acbc,
		"MoveBG::door_obj_hit_info": 0x8037accc,
		"door_obj_hit_info": 0x8037accc,
		"MoveBG::doorHotel_anim_data": 0x8037acec,
		"doorHotel_anim_data": 0x8037acec,
		"MoveBG::@2800": 0x8037ad50,
		"MoveBG::manhole_anim_data": 0x8037ad68,
		"manhole_anim_data": 0x8037ad68,
		"MoveBG::manhole_hit_data_table": 0x8037ad7c,
		"manhole_hit_data_table": 0x8037ad7c,
		"MoveBG::manhole_obj_hit_info": 0x8037ad8c,
		"manhole_obj_hit_info": 0x8037ad8c,
		"MoveBG::manhole_map_collision_data": 0x8037ad9c,
		"manhole_map_collision_data": 0x8037ad9c,
		"MoveBG::FruitBasket_anim_data": 0x8037adb8,
		"FruitBasket_anim_data": 0x8037adb8,
		"MoveBG::FruitBasket_hit_data_table": 0x8037ade0,
		"FruitBasket_hit_data_table": 0x8037ade0,
		"MoveBG::FruitBasket_obj_hit_info": 0x8037adf0,
		"FruitBasket_obj_hit_info": 0x8037adf0,
		"MoveBG::@2806": 0x8037ae00,
		"MoveBG::BasketReverse_anim_data": 0x8037ae0c,
		"BasketReverse_anim_data": 0x8037ae0c,
		"MoveBG::BasketReverse_hit_data_table": 0x8037ae20,
		"BasketReverse_hit_data_table": 0x8037ae20,
		"MoveBG::BasketReverse_obj_hit_info": 0x8037ae30,
		"BasketReverse_obj_hit_info": 0x8037ae30,
		"MoveBG::CoconutJuice_hit_data_table": 0x8037ae50,
		"CoconutJuice_hit_data_table": 0x8037ae50,
		"MoveBG::CoconutJuice_obj_hit_info": 0x8037ae60,
		"CoconutJuice_obj_hit_info": 0x8037ae60,
		"MoveBG::Pile_hit_data_table": 0x8037ae80,
		"Pile_hit_data_table": 0x8037ae80,
		"MoveBG::Pile_obj_hit_info": 0x8037ae90,
		"Pile_obj_hit_info": 0x8037ae90,
		"MoveBG::ChangeStage_hit_data_table": 0x8037aec0,
		"ChangeStage_hit_data_table": 0x8037aec0,
		"MoveBG::ChangeStage_obj_hit_info": 0x8037aed0,
		"ChangeStage_obj_hit_info": 0x8037aed0,
		"MoveBG::StartDemo_hit_data_table": 0x8037af04,
		"StartDemo_hit_data_table": 0x8037af04,
		"MoveBG::StartDemo_obj_hit_info": 0x8037af14,
		"StartDemo_obj_hit_info": 0x8037af14,
		"MoveBG::ChipShine_anim_data": 0x8037af48,
		"ChipShine_anim_data": 0x8037af48,
		"MoveBG::ChipShine_hit_data_table": 0x8037af5c,
		"ChipShine_hit_data_table": 0x8037af5c,
		"MoveBG::ChipShine_obj_hit_info": 0x8037af6c,
		"ChipShine_obj_hit_info": 0x8037af6c,
		"MoveBG::KoopaJrSignM_anim_data": 0x8037af9c,
		"KoopaJrSignM_anim_data": 0x8037af9c,
		"MoveBG::KoopaJrSignM_hit_data_table": 0x8037afb0,
		"KoopaJrSignM_hit_data_table": 0x8037afb0,
		"MoveBG::KoopaJrSignM_obj_hit_info": 0x8037afc0,
		"KoopaJrSignM_obj_hit_info": 0x8037afc0,
		"MoveBG::SignCircle_anim_data": 0x8037affc,
		"SignCircle_anim_data": 0x8037affc,
		"MoveBG::SignCross_anim_data": 0x8037b02c,
		"SignCross_anim_data": 0x8037b02c,
		"MoveBG::SignTriangle_anim_data": 0x8037b05c,
		"SignTriangle_anim_data": 0x8037b05c,
		"MoveBG::ArrowBoardLR_hit_data_table": 0x8037b080,
		"ArrowBoardLR_hit_data_table": 0x8037b080,
		"MoveBG::ArrowBoardLR_obj_hit_info": 0x8037b090,
		"ArrowBoardLR_obj_hit_info": 0x8037b090,
		"MoveBG::ArrowBoardUp_hit_data_table": 0x8037b0b0,
		"ArrowBoardUp_hit_data_table": 0x8037b0b0,
		"MoveBG::ArrowBoardUp_obj_hit_info": 0x8037b0c0,
		"ArrowBoardUp_obj_hit_info": 0x8037b0c0,
		"MoveBG::@2826": 0x8037b0d0,
		"MoveBG::ArrowBoardDown_hit_data_table": 0x8037b0e0,
		"ArrowBoardDown_hit_data_table": 0x8037b0e0,
		"MoveBG::ArrowBoardDown_obj_hit_info": 0x8037b0f0,
		"ArrowBoardDown_obj_hit_info": 0x8037b0f0,
		"MoveBG::GeneralHitObj_hit_data_table": 0x8037b150,
		"GeneralHitObj_hit_data_table": 0x8037b150,
		"MoveBG::GeneralHitObj_obj_hit_info": 0x8037b160,
		"GeneralHitObj_obj_hit_info": 0x8037b160,
		"MoveBG::item_hit_data_table": 0x8037b180,
		"item_hit_data_table": 0x8037b180,
		"MoveBG::item_obj_hit_info": 0x8037b190,
		"item_obj_hit_info": 0x8037b190,
		"MoveBG::WaterRecoverObj_hit_data_table": 0x8037b1ec,
		"WaterRecoverObj_hit_data_table": 0x8037b1ec,
		"MoveBG::WaterRecoverObj_obj_hit_info": 0x8037b1fc,
		"WaterRecoverObj_obj_hit_info": 0x8037b1fc,
		"MoveBG::nozzle_item_hit_data_table": 0x8037b254,
		"nozzle_item_hit_data_table": 0x8037b254,
		"MoveBG::nozzle_item_obj_hit_info": 0x8037b264,
		"nozzle_item_obj_hit_info": 0x8037b264,
		"MoveBG::coin_hit_data_table": 0x8037b29c,
		"coin_hit_data_table": 0x8037b29c,
		"MoveBG::coin_obj_hit_info": 0x8037b2ac,
		"coin_obj_hit_info": 0x8037b2ac,
		"MoveBG::coin_sound_data": 0x8037b2bc,
		"coin_sound_data": 0x8037b2bc,
		"MoveBG::mario_cap_anim_data": 0x8037b334,
		"mario_cap_anim_data": 0x8037b334,
		"MoveBG::mario_cap_hit_data_table": 0x8037b348,
		"mario_cap_hit_data_table": 0x8037b348,
		"MoveBG::mario_cap_obj_hit_info": 0x8037b358,
		"mario_cap_obj_hit_info": 0x8037b358,
		"MoveBG::coin_anim_data": 0x8037b380,
		"coin_anim_data": 0x8037b380,
		"MoveBG::@2854": 0x8037b3a0,
		"MoveBG::eggYoshi_anim_data": 0x8037b408,
		"eggYoshi_anim_data": 0x8037b408,
		"MoveBG::eggYoshi_hit_data_table": 0x8037b458,
		"eggYoshi_hit_data_table": 0x8037b458,
		"MoveBG::eggYoshi_obj_hit_info": 0x8037b4f8,
		"eggYoshi_obj_hit_info": 0x8037b4f8,
		"MoveBG::NozzleBox_anim_data": 0x8037b56c,
		"NozzleBox_anim_data": 0x8037b56c,
		"MoveBG::NozzleBox_hit_data_table": 0x8037b5bc,
		"NozzleBox_hit_data_table": 0x8037b5bc,
		"MoveBG::NozzleBox_obj_hit_info": 0x8037b5cc,
		"NozzleBox_obj_hit_info": 0x8037b5cc,
		"MoveBG::mushroom1up_anim_data": 0x8037b5f8,
		"mushroom1up_anim_data": 0x8037b5f8,
		"MoveBG::mushroom1up_hit_data_table": 0x8037b60c,
		"mushroom1up_hit_data_table": 0x8037b60c,
		"MoveBG::mushroom1up_obj_hit_info": 0x8037b61c,
		"mushroom1up_obj_hit_info": 0x8037b61c,
		"MoveBG::@2871": 0x8037b658,
		"MoveBG::jumpbase_anim_data": 0x8037b668,
		"jumpbase_anim_data": 0x8037b668,
		"MoveBG::jumpbase_hit_data_table": 0x8037b67c,
		"jumpbase_hit_data_table": 0x8037b67c,
		"MoveBG::jumpbase_obj_hit_info": 0x8037b68c,
		"jumpbase_obj_hit_info": 0x8037b68c,
		"MoveBG::@2872": 0x8037b69c,
		"MoveBG::fruit_hit_data_table": 0x8037b6a8,
		"fruit_hit_data_table": 0x8037b6a8,
		"MoveBG::fruit_obj_hit_info": 0x8037b6b8,
		"fruit_obj_hit_info": 0x8037b6b8,
		"MoveBG::coconut_hit_data_table": 0x8037b6c8,
		"coconut_hit_data_table": 0x8037b6c8,
		"MoveBG::coconut_obj_hit_info": 0x8037b6d8,
		"coconut_obj_hit_info": 0x8037b6d8,
		"MoveBG::fruit_sound_data": 0x8037b6e8,
		"fruit_sound_data": 0x8037b6e8,
		"MoveBG::@2873": 0x8037b710,
		"MoveBG::@2874": 0x8037b720,
		"MoveBG::papaya_hit_data_table": 0x8037b72c,
		"papaya_hit_data_table": 0x8037b72c,
		"MoveBG::papaya_obj_hit_info": 0x8037b73c,
		"papaya_obj_hit_info": 0x8037b73c,
		"MoveBG::@2875": 0x8037b74c,
		"MoveBG::pine_hit_data_table": 0x8037b758,
		"pine_hit_data_table": 0x8037b758,
		"MoveBG::pine_obj_hit_info": 0x8037b768,
		"pine_obj_hit_info": 0x8037b768,
		"MoveBG::@2876": 0x8037b778,
		"MoveBG::@2877": 0x8037b784,
		"MoveBG::CoverPine_anim_data": 0x8037b794,
		"CoverPine_anim_data": 0x8037b794,
		"MoveBG::cover_pine_hit_data_table": 0x8037b820,
		"cover_pine_hit_data_table": 0x8037b820,
		"MoveBG::cover_pine_obj_hit_info": 0x8037b830,
		"cover_pine_obj_hit_info": 0x8037b830,
		"MoveBG::@2878": 0x8037b840,
		"MoveBG::durian_hit_data_table": 0x8037b850,
		"durian_hit_data_table": 0x8037b850,
		"MoveBG::durian_obj_hit_info": 0x8037b860,
		"durian_obj_hit_info": 0x8037b860,
		"MoveBG::durian_sound_data": 0x8037b870,
		"durian_sound_data": 0x8037b870,
		"MoveBG::@2879": 0x8037b898,
		"MoveBG::banana_hit_data_table": 0x8037b8a4,
		"banana_hit_data_table": 0x8037b8a4,
		"MoveBG::banana_obj_hit_info": 0x8037b8b4,
		"banana_obj_hit_info": 0x8037b8b4,
		"MoveBG::@2881": 0x8037b8d0,
		"MoveBG::@2882": 0x8037b8dc,
		"MoveBG::@2883": 0x8037b8ec,
		"MoveBG::fence3x3_anim_data": 0x8037b8fc,
		"fence3x3_anim_data": 0x8037b8fc,
		"MoveBG::@2885": 0x8037b91c,
		"MoveBG::fence_revolve_outer_anim_data": 0x8037b934,
		"fence_revolve_outer_anim_data": 0x8037b934,
		"MoveBG::@2886": 0x8037b948,
		"MoveBG::FenceInner_hit_data_table": 0x8037b958,
		"FenceInner_hit_data_table": 0x8037b958,
		"MoveBG::FenceInner_obj_hit_info": 0x8037b968,
		"FenceInner_obj_hit_info": 0x8037b968,
		"MoveBG::@2887": 0x8037b978,
		"MoveBG::FenceWaterH_map_collision_data": 0x8037b9c8,
		"FenceWaterH_map_collision_data": 0x8037b9c8,
		"MoveBG::RailFence_anim_data": 0x8037b9ec,
		"RailFence_anim_data": 0x8037b9ec,
		"MoveBG::RailFence_map_collision_data": 0x8037ba28,
		"RailFence_map_collision_data": 0x8037ba28,
		"MoveBG::BambooRailFence_anim_data": 0x8037baa8,
		"BambooRailFence_anim_data": 0x8037baa8,
		"MoveBG::wood_barrel_anim_data": 0x8037bb64,
		"wood_barrel_anim_data": 0x8037bb64,
		"MoveBG::wood_barrel_hit_data_table": 0x8037bbf0,
		"wood_barrel_hit_data_table": 0x8037bbf0,
		"MoveBG::wood_barrel_obj_hit_info": 0x8037bc20,
		"wood_barrel_obj_hit_info": 0x8037bc20,
		"MoveBG::wood_barrel_map_collision_data": 0x8037bc30,
		"wood_barrel_map_collision_data": 0x8037bc30,
		"MoveBG::wood_barrel_sound_data": 0x8037bc40,
		"wood_barrel_sound_data": 0x8037bc40,
		"MoveBG::barrel_float_hit_data_table": 0x8037bccc,
		"barrel_float_hit_data_table": 0x8037bccc,
		"MoveBG::barrel_float_obj_hit_info": 0x8037bcdc,
		"barrel_float_obj_hit_info": 0x8037bcdc,
		"MoveBG::@2914": 0x8037bd10,
		"MoveBG::@2915": 0x8037bd2c,
		"MoveBG::drum_can_anim_data": 0x8037bd3c,
		"drum_can_anim_data": 0x8037bd3c,
		"MoveBG::drum_can_hit_data_table": 0x8037bd78,
		"drum_can_hit_data_table": 0x8037bd78,
		"MoveBG::drum_can_obj_hit_info": 0x8037bd88,
		"drum_can_obj_hit_info": 0x8037bd88,
		"MoveBG::drum_can_map_collision_data": 0x8037bdb4,
		"drum_can_map_collision_data": 0x8037bdb4,
		"MoveBG::@2918": 0x8037bdc4,
		"MoveBG::@2919": 0x8037bdd4,
		"MoveBG::barrel_oil_anim_data": 0x8037bdfc,
		"barrel_oil_anim_data": 0x8037bdfc,
		"MoveBG::barrel_oil_hit_data_table": 0x8037be88,
		"barrel_oil_hit_data_table": 0x8037be88,
		"MoveBG::barrel_oil_obj_hit_info": 0x8037be98,
		"barrel_oil_obj_hit_info": 0x8037be98,
		"MoveBG::@2920": 0x8037bea8,
		"MoveBG::@2925": 0x8037bf04,
		"MoveBG::breakable_block_anim_data": 0x8037bf1c,
		"breakable_block_anim_data": 0x8037bf1c,
		"MoveBG::breakable_block_hit_data_table": 0x8037bf58,
		"breakable_block_hit_data_table": 0x8037bf58,
		"MoveBG::breakable_block_obj_hit_info": 0x8037bf68,
		"breakable_block_obj_hit_info": 0x8037bf68,
		"MoveBG::supermario_block_obj_hit_info": 0x8037bf88,
		"supermario_block_obj_hit_info": 0x8037bf88,
		"MoveBG::@2928": 0x8037bfac,
		"MoveBG::@2929": 0x8037bfb8,
		"MoveBG::expand_block_hit_data_table": 0x8037bfc8,
		"expand_block_hit_data_table": 0x8037bfc8,
		"MoveBG::expand_block_obj_hit_info": 0x8037bfd8,
		"expand_block_obj_hit_info": 0x8037bfd8,
		"MoveBG::spread_block_hit_data_table": 0x8037bff8,
		"spread_block_hit_data_table": 0x8037bff8,
		"MoveBG::spread_block_obj_hit_info": 0x8037c008,
		"spread_block_obj_hit_info": 0x8037c008,
		"MoveBG::@2931": 0x8037c018,
		"MoveBG::water_roll_block_anim_data": 0x8037c040,
		"water_roll_block_anim_data": 0x8037c040,
		"MoveBG::water_roll_block_obj_hit_info": 0x8037c054,
		"water_roll_block_obj_hit_info": 0x8037c054,
		"MoveBG::@2935": 0x8037c088,
		"MoveBG::sand_block_anim_data": 0x8037c094,
		"sand_block_anim_data": 0x8037c094,
		"MoveBG::sand_block_hit_data_table": 0x8037c0d0,
		"sand_block_hit_data_table": 0x8037c0d0,
		"MoveBG::sand_block_obj_hit_info": 0x8037c0e0,
		"sand_block_obj_hit_info": 0x8037c0e0,
		"MoveBG::sand_block_map_collision_data": 0x8037c0f0,
		"sand_block_map_collision_data": 0x8037c0f0,
		"MoveBG::@2937": 0x8037c10c,
		"MoveBG::@2941": 0x8037c164,
		"MoveBG::skate_block_hit_data_table": 0x8037c184,
		"skate_block_hit_data_table": 0x8037c184,
		"MoveBG::skate_block_obj_hit_info": 0x8037c194,
		"skate_block_obj_hit_info": 0x8037c194,
		"MoveBG::@2944": 0x8037c1b0,
		"MoveBG::@2945": 0x8037c1c4,
		"MoveBG::MoveCoin_anim_data": 0x8037c1d4,
		"MoveCoin_anim_data": 0x8037c1d4,
		"MoveBG::@2946": 0x8037c1e8,
		"MoveBG::cluster_block_anim_data": 0x8037c208,
		"cluster_block_anim_data": 0x8037c208,
		"MoveBG::@2949": 0x8037c22c,
		"MoveBG::ice_block_hit_data_table": 0x8037c238,
		"ice_block_hit_data_table": 0x8037c238,
		"MoveBG::ice_block_obj_hit_info": 0x8037c248,
		"ice_block_obj_hit_info": 0x8037c248,
		"MoveBG::@2950": 0x8037c258,
		"MoveBG::@2951": 0x8037c264,
		"MoveBG::@2952": 0x8037c274,
		"MoveBG::BrickBlock_anim_data": 0x8037c298,
		"BrickBlock_anim_data": 0x8037c298,
		"MoveBG::@2955": 0x8037c2e0,
		"MoveBG::@2956": 0x8037c2f4,
		"MoveBG::WaterMelonBlock_anim_data": 0x8037c328,
		"WaterMelonBlock_anim_data": 0x8037c328,
		"MoveBG::WoodBlockPole_hit_data_table": 0x8037c380,
		"WoodBlockPole_hit_data_table": 0x8037c380,
		"MoveBG::WoodBlockPole_obj_hit_info": 0x8037c390,
		"WoodBlockPole_obj_hit_info": 0x8037c390,
		"MoveBG::@2963": 0x8037c3ec,
		"MoveBG::@2964": 0x8037c400,
		"MoveBG::@2965": 0x8037c410,
		"MoveBG::SuperHipDropBlock_anim_data": 0x8037c434,
		"SuperHipDropBlock_anim_data": 0x8037c434,
		"MoveBG::@2966": 0x8037c470,
		"MoveBG::@2967": 0x8037c47c,
		"MoveBG::tree_sound_data": 0x8037c490,
		"tree_sound_data": 0x8037c490,
		"MoveBG::@2968": 0x8037c4b8,
		"MoveBG::PalmNormal_anim_data": 0x8037c4c8,
		"PalmNormal_anim_data": 0x8037c4c8,
		"MoveBG::palmNormal_hit_data_table": 0x8037c4dc,
		"palmNormal_hit_data_table": 0x8037c4dc,
		"MoveBG::palmNormal_obj_hit_info": 0x8037c4ec,
		"palmNormal_obj_hit_info": 0x8037c4ec,
		"MoveBG::@2969": 0x8037c4fc,
		"MoveBG::palmOugi_hit_data_table": 0x8037c518,
		"palmOugi_hit_data_table": 0x8037c518,
		"MoveBG::palmOugi_obj_hit_info": 0x8037c528,
		"palmOugi_obj_hit_info": 0x8037c528,
		"MoveBG::palmSago_hit_data_table": 0x8037c544,
		"palmSago_hit_data_table": 0x8037c544,
		"MoveBG::palmSago_obj_hit_info": 0x8037c554,
		"palmSago_obj_hit_info": 0x8037c554,
		"MoveBG::palmNatume_hit_data_table": 0x8037c570,
		"palmNatume_hit_data_table": 0x8037c570,
		"MoveBG::palmNatume_obj_hit_info": 0x8037c580,
		"palmNatume_obj_hit_info": 0x8037c580,
		"MoveBG::PalmLeaf_anim_data": 0x8037c5ac,
		"PalmLeaf_anim_data": 0x8037c5ac,
		"MoveBG::palmLeaf_hit_data_table": 0x8037c5c0,
		"palmLeaf_hit_data_table": 0x8037c5c0,
		"MoveBG::palmLeaf_obj_hit_info": 0x8037c5d0,
		"palmLeaf_obj_hit_info": 0x8037c5d0,
		"MoveBG::BananaTree_anim_data": 0x8037c5fc,
		"BananaTree_anim_data": 0x8037c5fc,
		"MoveBG::BananaTree_hit_data_table": 0x8037c610,
		"BananaTree_hit_data_table": 0x8037c610,
		"MoveBG::BananaTree_obj_hit_info": 0x8037c620,
		"BananaTree_obj_hit_info": 0x8037c620,
		"MoveBG::FruitTree_hit_data_table": 0x8037c63c,
		"FruitTree_hit_data_table": 0x8037c63c,
		"MoveBG::FruitTree_obj_hit_info": 0x8037c64c,
		"FruitTree_obj_hit_info": 0x8037c64c,
		"MoveBG::flower_hit_data_table": 0x8037c668,
		"flower_hit_data_table": 0x8037c668,
		"MoveBG::flower_obj_hit_info": 0x8037c678,
		"flower_obj_hit_info": 0x8037c678,
		"MoveBG::flowerOrange_anim_data": 0x8037c6bc,
		"flowerOrange_anim_data": 0x8037c6bc,
		"MoveBG::flowerPink_anim_data": 0x8037c714,
		"flowerPink_anim_data": 0x8037c714,
		"MoveBG::flowerPurple_anim_data": 0x8037c770,
		"flowerPurple_anim_data": 0x8037c770,
		"MoveBG::@2991": 0x8037c7b8,
		"MoveBG::flowerRed_anim_data": 0x8037c7c8,
		"flowerRed_anim_data": 0x8037c7c8,
		"MoveBG::flowerYellow_anim_data": 0x8037c824,
		"flowerYellow_anim_data": 0x8037c824,
		"MoveBG::flowerSunflower_anim_data": 0x8037c888,
		"flowerSunflower_anim_data": 0x8037c888,
		"MoveBG::pole_sound_data": 0x8037c8c0,
		"pole_sound_data": 0x8037c8c0,
		"MoveBG::telegraph_pole_l_hit_data_table": 0x8037c8e8,
		"telegraph_pole_l_hit_data_table": 0x8037c8e8,
		"MoveBG::telegraph_pole_l_obj_hit_info": 0x8037c8f8,
		"telegraph_pole_l_obj_hit_info": 0x8037c8f8,
		"MoveBG::telegraph_pole_s_hit_data_table": 0x8037c91c,
		"telegraph_pole_s_hit_data_table": 0x8037c91c,
		"MoveBG::telegraph_pole_s_obj_hit_info": 0x8037c92c,
		"telegraph_pole_s_obj_hit_info": 0x8037c92c,
		"MoveBG::dptlight_anim_data": 0x8037c98c,
		"dptlight_anim_data": 0x8037c98c,
		"MoveBG::streetlamp_hit_data_table": 0x8037ca18,
		"streetlamp_hit_data_table": 0x8037ca18,
		"MoveBG::streetlamp_obj_hit_info": 0x8037ca48,
		"streetlamp_obj_hit_info": 0x8037ca48,
		"MoveBG::streetlamp_map_collision_data": 0x8037ca74,
		"streetlamp_map_collision_data": 0x8037ca74,
		"MoveBG::PoleNormal_hit_data_table": 0x8037ca84,
		"PoleNormal_hit_data_table": 0x8037ca84,
		"MoveBG::PoleNormal_obj_hit_info": 0x8037ca94,
		"PoleNormal_obj_hit_info": 0x8037ca94,
		"MoveBG::football_anim_data": 0x8037cac0,
		"football_anim_data": 0x8037cac0,
		"MoveBG::football_hit_data_table": 0x8037cad4,
		"football_hit_data_table": 0x8037cad4,
		"MoveBG::football_obj_hit_info": 0x8037cae4,
		"football_obj_hit_info": 0x8037cae4,
		"MoveBG::football_sound_data": 0x8037caf4,
		"football_sound_data": 0x8037caf4,
		"MoveBG::football_goal_anim_data": 0x8037cb40,
		"football_goal_anim_data": 0x8037cb40,
		"MoveBG::football_goal_hit_data_table": 0x8037cb54,
		"football_goal_hit_data_table": 0x8037cb54,
		"MoveBG::football_goal_obj_hit_info": 0x8037cb64,
		"football_goal_obj_hit_info": 0x8037cb64,
		"MoveBG::football_goal_map_collision_data": 0x8037cb94,
		"football_goal_map_collision_data": 0x8037cb94,
		"MoveBG::@3013": 0x8037cbb4,
		"MoveBG::@3014": 0x8037cbc0,
		"MoveBG::@3015": 0x8037cbd0,
		"MoveBG::@3016": 0x8037cbe0,
		"MoveBG::@3017": 0x8037cbf4,
		"MoveBG::Watermelon_anim_data": 0x8037cc18,
		"Watermelon_anim_data": 0x8037cc18,
		"MoveBG::watermelon_hit_data_table": 0x8037ccb8,
		"watermelon_hit_data_table": 0x8037ccb8,
		"MoveBG::watermelon_obj_hit_info": 0x8037ccc8,
		"watermelon_obj_hit_info": 0x8037ccc8,
		"MoveBG::watermelon_sound_data": 0x8037ccd8,
		"watermelon_sound_data": 0x8037ccd8,
		"MoveBG::@3018": 0x8037cd00,
		"MoveBG::WatermelonStatic_anim_data": 0x8037cd0c,
		"WatermelonStatic_anim_data": 0x8037cd0c,
		"MoveBG::@3019": 0x8037cd20,
		"MoveBG::@3020": 0x8037cd34,
		"MoveBG::@3021": 0x8037cd40,
		"MoveBG::cloud_anim_data": 0x8037cd4c,
		"cloud_anim_data": 0x8037cd4c,
		"MoveBG::cloud_hit_data_table": 0x8037cd60,
		"cloud_hit_data_table": 0x8037cd60,
		"MoveBG::cloud_obj_hit_info": 0x8037cd70,
		"cloud_obj_hit_info": 0x8037cd70,
		"MoveBG::normallift_anim_data": 0x8037cd90,
		"normallift_anim_data": 0x8037cd90,
		"MoveBG::normallift_hit_data_table": 0x8037cda4,
		"normallift_hit_data_table": 0x8037cda4,
		"MoveBG::normallift_obj_hit_info": 0x8037cdb4,
		"normallift_obj_hit_info": 0x8037cdb4,
		"MoveBG::exrollcube_anim_data": 0x8037cde0,
		"exrollcube_anim_data": 0x8037cde0,
		"MoveBG::exrollcube_hit_data_table": 0x8037cdf4,
		"exrollcube_hit_data_table": 0x8037cdf4,
		"MoveBG::exrollcube_obj_hit_info": 0x8037ce04,
		"exrollcube_obj_hit_info": 0x8037ce04,
		"MoveBG::exkickboard_anim_data": 0x8037ce3c,
		"exkickboard_anim_data": 0x8037ce3c,
		"MoveBG::exkickboard_hit_data_table": 0x8037ce50,
		"exkickboard_hit_data_table": 0x8037ce50,
		"MoveBG::exkickboard_obj_hit_info": 0x8037ce60,
		"exkickboard_obj_hit_info": 0x8037ce60,
		"MoveBG::railblockr_anim_data": 0x8037cea0,
		"railblockr_anim_data": 0x8037cea0,
		"MoveBG::railblocky_anim_data": 0x8037cecc,
		"railblocky_anim_data": 0x8037cecc,
		"MoveBG::railblockb_anim_data": 0x8037cef8,
		"railblockb_anim_data": 0x8037cef8,
		"MoveBG::railblock_hit_data_table": 0x8037cf0c,
		"railblock_hit_data_table": 0x8037cf0c,
		"MoveBG::railblock_obj_hit_info": 0x8037cf1c,
		"railblock_obj_hit_info": 0x8037cf1c,
		"MoveBG::umaibou_anim_data": 0x8037cf90,
		"umaibou_anim_data": 0x8037cf90,
		"MoveBG::umaibou_hit_data_table": 0x8037cfa4,
		"umaibou_hit_data_table": 0x8037cfa4,
		"MoveBG::umaibou_obj_hit_info": 0x8037cfb4,
		"umaibou_obj_hit_info": 0x8037cfb4,
		"MoveBG::kamaboko_anim_data": 0x8037cfd4,
		"kamaboko_anim_data": 0x8037cfd4,
		"MoveBG::kamaboko_hit_data_table": 0x8037cfe8,
		"kamaboko_hit_data_table": 0x8037cfe8,
		"MoveBG::kamaboko_obj_hit_info": 0x8037cff8,
		"kamaboko_obj_hit_info": 0x8037cff8,
		"MoveBG::getag_anim_data": 0x8037d024,
		"getag_anim_data": 0x8037d024,
		"MoveBG::getao_anim_data": 0x8037d048,
		"getao_anim_data": 0x8037d048,
		"MoveBG::geta_hit_data_table": 0x8037d05c,
		"geta_hit_data_table": 0x8037d05c,
		"MoveBG::geta_obj_hit_info": 0x8037d06c,
		"geta_obj_hit_info": 0x8037d06c,
		"MoveBG::uirou_anim_data": 0x8037d088,
		"uirou_anim_data": 0x8037d088,
		"MoveBG::uirou_hit_data_table": 0x8037d09c,
		"uirou_hit_data_table": 0x8037d09c,
		"MoveBG::uirou_obj_hit_info": 0x8037d0ac,
		"uirou_obj_hit_info": 0x8037d0ac,
		"MoveBG::hikidashi_anim_data": 0x8037d0cc,
		"hikidashi_anim_data": 0x8037d0cc,
		"MoveBG::hikidashi_hit_data_table": 0x8037d0e0,
		"hikidashi_hit_data_table": 0x8037d0e0,
		"MoveBG::hikidashi_obj_hit_info": 0x8037d0f0,
		"hikidashi_obj_hit_info": 0x8037d0f0,
		"MoveBG::castella_anim_data": 0x8037d11c,
		"castella_anim_data": 0x8037d11c,
		"MoveBG::castella_hit_data_table": 0x8037d130,
		"castella_hit_data_table": 0x8037d130,
		"MoveBG::castella_obj_hit_info": 0x8037d140,
		"castella_obj_hit_info": 0x8037d140,
		"MoveBG::yoshiblock_anim_data": 0x8037d16c,
		"yoshiblock_anim_data": 0x8037d16c,
		"MoveBG::yoshiblock_hit_data_table": 0x8037d180,
		"yoshiblock_hit_data_table": 0x8037d180,
		"MoveBG::yoshiblock_obj_hit_info": 0x8037d190,
		"yoshiblock_obj_hit_info": 0x8037d190,
		"MoveBG::@3057": 0x8037d1a0,
		"MoveBG::@3058": 0x8037d1ac,
		"MoveBG::@3062": 0x8037d1f4,
		"MoveBG::@3063": 0x8037d204,
		"MoveBG::@3065": 0x8037d220,
		"MoveBG::normalvariant0_hit_data_table": 0x8037d230,
		"normalvariant0_hit_data_table": 0x8037d230,
		"MoveBG::normalvariant0_obj_hit_info": 0x8037d240,
		"normalvariant0_obj_hit_info": 0x8037d240,
		"MoveBG::normalvariant1_hit_data_table": 0x8037d260,
		"normalvariant1_hit_data_table": 0x8037d260,
		"MoveBG::normalvariant1_obj_hit_info": 0x8037d270,
		"normalvariant1_obj_hit_info": 0x8037d270,
		"MoveBG::@3067": 0x8037d280,
		"MoveBG::normalvariant2_hit_data_table": 0x8037d290,
		"normalvariant2_hit_data_table": 0x8037d290,
		"MoveBG::normalvariant2_obj_hit_info": 0x8037d2a0,
		"normalvariant2_obj_hit_info": 0x8037d2a0,
		"MoveBG::normalvariant3_hit_data_table": 0x8037d2c0,
		"normalvariant3_hit_data_table": 0x8037d2c0,
		"MoveBG::normalvariant3_obj_hit_info": 0x8037d2d0,
		"normalvariant3_obj_hit_info": 0x8037d2d0,
		"MoveBG::@3069": 0x8037d2e0,
		"MoveBG::normalvariant4_hit_data_table": 0x8037d2f0,
		"normalvariant4_hit_data_table": 0x8037d2f0,
		"MoveBG::normalvariant4_obj_hit_info": 0x8037d300,
		"normalvariant4_obj_hit_info": 0x8037d300,
		"MoveBG::railvariant0_hit_data_table": 0x8037d320,
		"railvariant0_hit_data_table": 0x8037d320,
		"MoveBG::railvariant0_obj_hit_info": 0x8037d330,
		"railvariant0_obj_hit_info": 0x8037d330,
		"MoveBG::railvariant1_hit_data_table": 0x8037d350,
		"railvariant1_hit_data_table": 0x8037d350,
		"MoveBG::railvariant1_obj_hit_info": 0x8037d360,
		"railvariant1_obj_hit_info": 0x8037d360,
		"MoveBG::@3072": 0x8037d370,
		"MoveBG::railvariant2_hit_data_table": 0x8037d380,
		"railvariant2_hit_data_table": 0x8037d380,
		"MoveBG::railvariant2_obj_hit_info": 0x8037d390,
		"railvariant2_obj_hit_info": 0x8037d390,
		"MoveBG::@3073": 0x8037d3a0,
		"MoveBG::railvariant3_hit_data_table": 0x8037d3b0,
		"railvariant3_hit_data_table": 0x8037d3b0,
		"MoveBG::railvariant3_obj_hit_info": 0x8037d3c0,
		"railvariant3_obj_hit_info": 0x8037d3c0,
		"MoveBG::railvariant4_hit_data_table": 0x8037d3e0,
		"railvariant4_hit_data_table": 0x8037d3e0,
		"MoveBG::railvariant4_obj_hit_info": 0x8037d3f0,
		"railvariant4_obj_hit_info": 0x8037d3f0,
		"MoveBG::rollvariant0_hit_data_table": 0x8037d410,
		"rollvariant0_hit_data_table": 0x8037d410,
		"MoveBG::rollvariant0_obj_hit_info": 0x8037d420,
		"rollvariant0_obj_hit_info": 0x8037d420,
		"MoveBG::@3076": 0x8037d430,
		"MoveBG::rollvariant1_hit_data_table": 0x8037d440,
		"rollvariant1_hit_data_table": 0x8037d440,
		"MoveBG::rollvariant1_obj_hit_info": 0x8037d450,
		"rollvariant1_obj_hit_info": 0x8037d450,
		"MoveBG::@3077": 0x8037d460,
		"MoveBG::rollvariant2_hit_data_table": 0x8037d470,
		"rollvariant2_hit_data_table": 0x8037d470,
		"MoveBG::rollvariant2_obj_hit_info": 0x8037d480,
		"rollvariant2_obj_hit_info": 0x8037d480,
		"MoveBG::@3078": 0x8037d490,
		"MoveBG::rollvariant3_hit_data_table": 0x8037d4a0,
		"rollvariant3_hit_data_table": 0x8037d4a0,
		"MoveBG::rollvariant3_obj_hit_info": 0x8037d4b0,
		"rollvariant3_obj_hit_info": 0x8037d4b0,
		"MoveBG::@3079": 0x8037d4c0,
		"MoveBG::rollvariant4_hit_data_table": 0x8037d4d0,
		"rollvariant4_hit_data_table": 0x8037d4d0,
		"MoveBG::rollvariant4_obj_hit_info": 0x8037d4e0,
		"rollvariant4_obj_hit_info": 0x8037d4e0,
		"MoveBG::lamptrapspike_anim_data": 0x8037d514,
		"lamptrapspike_anim_data": 0x8037d514,
		"MoveBG::lamptrapiron_anim_data": 0x8037d53c,
		"lamptrapiron_anim_data": 0x8037d53c,
		"MoveBG::lamptrap_hit_data_table": 0x8037d550,
		"lamptrap_hit_data_table": 0x8037d550,
		"MoveBG::lamptrap_obj_hit_info": 0x8037d560,
		"lamptrap_obj_hit_info": 0x8037d560,
		"MoveBG::@3088": 0x8037d5b4,
		"MoveBG::WoodBox_anim_data": 0x8037d5d8,
		"WoodBox_anim_data": 0x8037d5d8,
		"MoveBG::WoodBox_sound_data": 0x8037d614,
		"WoodBox_sound_data": 0x8037d614,
		"MoveBG::AirportPole_hit_data_table": 0x8037d63c,
		"AirportPole_hit_data_table": 0x8037d63c,
		"MoveBG::AirportPole_obj_hit_info": 0x8037d64c,
		"AirportPole_obj_hit_info": 0x8037d64c,
		"MoveBG::@3093": 0x8037d668,
		"MoveBG::@3094": 0x8037d674,
		"MoveBG::ice_car_anim_data": 0x8037d680,
		"ice_car_anim_data": 0x8037d680,
		"MoveBG::ice_car_hit_data_table": 0x8037d70c,
		"ice_car_hit_data_table": 0x8037d70c,
		"MoveBG::ice_car_obj_hit_info": 0x8037d71c,
		"ice_car_obj_hit_info": 0x8037d71c,
		"MoveBG::AirportBuoy_hit_data_table": 0x8037d73c,
		"AirportBuoy_hit_data_table": 0x8037d73c,
		"MoveBG::AirportBuoy_obj_hit_info": 0x8037d74c,
		"AirportBuoy_obj_hit_info": 0x8037d74c,
		"MoveBG::dptKing_map_collision_data": 0x8037d768,
		"dptKing_map_collision_data": 0x8037d768,
		"MoveBG::monumentshine_anim_data": 0x8037d7a0,
		"monumentshine_anim_data": 0x8037d7a0,
		"MoveBG::monumentshine_hit_data_table": 0x8037d7b4,
		"monumentshine_hit_data_table": 0x8037d7b4,
		"MoveBG::monumentshine_obj_hit_info": 0x8037d7c4,
		"monumentshine_obj_hit_info": 0x8037d7c4,
		"MoveBG::belldolpic_anim_data": 0x8037d7f4,
		"belldolpic_anim_data": 0x8037d7f4,
		"MoveBG::belldolpic_hit_data_table": 0x8037d808,
		"belldolpic_hit_data_table": 0x8037d808,
		"MoveBG::belldolpic_obj_hit_info": 0x8037d818,
		"belldolpic_obj_hit_info": 0x8037d818,
		"MoveBG::DptWeathercock_anim_data": 0x8037d858,
		"DptWeathercock_anim_data": 0x8037d858,
		"MoveBG::DptWeathercock_hit_data_table": 0x8037d86c,
		"DptWeathercock_hit_data_table": 0x8037d86c,
		"MoveBG::DptWeathercock_obj_hit_info": 0x8037d87c,
		"DptWeathercock_obj_hit_info": 0x8037d87c,
		"MoveBG::DptMonteFence_hit_data_table": 0x8037d89c,
		"DptMonteFence_hit_data_table": 0x8037d89c,
		"MoveBG::DptMonteFence_obj_hit_info": 0x8037d8ac,
		"DptMonteFence_obj_hit_info": 0x8037d8ac,
		"MoveBG::MapSmoke_hit_data_table": 0x8037d8dc,
		"MapSmoke_hit_data_table": 0x8037d8dc,
		"MoveBG::MapSmoke_obj_hit_info": 0x8037d8ec,
		"MapSmoke_obj_hit_info": 0x8037d8ec,
		"MoveBG::@3112": 0x8037d908,
		"MoveBG::MareGate_anim_data": 0x8037d924,
		"MareGate_anim_data": 0x8037d924,
		"MoveBG::NozzleDoor_anim_data": 0x8037d960,
		"NozzleDoor_anim_data": 0x8037d960,
		"MoveBG::NozzleDoor_hit_data_table": 0x8037d988,
		"NozzleDoor_hit_data_table": 0x8037d988,
		"MoveBG::NozzleDoor_obj_hit_info": 0x8037d998,
		"NozzleDoor_obj_hit_info": 0x8037d998,
		"MoveBG::DokanGate_anim_data": 0x8037d9d0,
		"DokanGate_anim_data": 0x8037d9d0,
		"MoveBG::Crane_hit_data_table": 0x8037d9f0,
		"Crane_hit_data_table": 0x8037d9f0,
		"MoveBG::Crane_obj_hit_info": 0x8037da00,
		"Crane_obj_hit_info": 0x8037da00,
		"MoveBG::CraneUpDown_hit_data_table": 0x8037da30,
		"CraneUpDown_hit_data_table": 0x8037da30,
		"MoveBG::CraneUpDown_obj_hit_info": 0x8037da40,
		"CraneUpDown_obj_hit_info": 0x8037da40,
		"MoveBG::crane_cargo_hit_data_table": 0x8037da5c,
		"crane_cargo_hit_data_table": 0x8037da5c,
		"MoveBG::crane_cargo_obj_hit_info": 0x8037da6c,
		"crane_cargo_obj_hit_info": 0x8037da6c,
		"MoveBG::Submarine_hit_data_table": 0x8037da9c,
		"Submarine_hit_data_table": 0x8037da9c,
		"MoveBG::Submarine_obj_hit_info": 0x8037daac,
		"Submarine_obj_hit_info": 0x8037daac,
		"MoveBG::submarine_map_collision_data": 0x8037dac8,
		"submarine_map_collision_data": 0x8037dac8,
		"MoveBG::ricco_ship_hit_data_table": 0x8037dad8,
		"ricco_ship_hit_data_table": 0x8037dad8,
		"MoveBG::ricco_ship_obj_hit_info": 0x8037dae8,
		"ricco_ship_obj_hit_info": 0x8037dae8,
		"MoveBG::ricco_pole_hit_data_table": 0x8037db04,
		"ricco_pole_hit_data_table": 0x8037db04,
		"MoveBG::ricco_pole_obj_hit_info": 0x8037db14,
		"ricco_pole_obj_hit_info": 0x8037db14,
		"MoveBG::riccoLog_hit_data_table": 0x8037db30,
		"riccoLog_hit_data_table": 0x8037db30,
		"MoveBG::riccoLog_obj_hit_info": 0x8037db40,
		"riccoLog_obj_hit_info": 0x8037db40,
		"MoveBG::gesoSurfboard_anim_data": 0x8037db6c,
		"gesoSurfboard_anim_data": 0x8037db6c,
		"MoveBG::gesoSurfboard_hit_data_table": 0x8037db80,
		"gesoSurfboard_hit_data_table": 0x8037db80,
		"MoveBG::gesoSurfboard_obj_hit_info": 0x8037db90,
		"gesoSurfboard_obj_hit_info": 0x8037db90,
		"MoveBG::riccoWatermill_hit_data_table": 0x8037dbc4,
		"riccoWatermill_hit_data_table": 0x8037dbc4,
		"MoveBG::riccoWatermill_obj_hit_info": 0x8037dbd4,
		"riccoWatermill_obj_hit_info": 0x8037dbd4,
		"MoveBG::riccoShipLog_hit_data_table": 0x8037dbf4,
		"riccoShipLog_hit_data_table": 0x8037dbf4,
		"MoveBG::riccoShipLog_obj_hit_info": 0x8037dc04,
		"riccoShipLog_obj_hit_info": 0x8037dc04,
		"MoveBG::riccoShipDol_hit_data_table": 0x8037dc24,
		"riccoShipDol_hit_data_table": 0x8037dc24,
		"MoveBG::riccoShipDol_obj_hit_info": 0x8037dc34,
		"riccoShipDol_obj_hit_info": 0x8037dc34,
		"MoveBG::riccoYachtL_hit_data_table": 0x8037dc54,
		"riccoYachtL_hit_data_table": 0x8037dc54,
		"MoveBG::riccoYachtL_obj_hit_info": 0x8037dc64,
		"riccoYachtL_obj_hit_info": 0x8037dc64,
		"MoveBG::riccoYachtS_hit_data_table": 0x8037dc80,
		"riccoYachtS_hit_data_table": 0x8037dc80,
		"MoveBG::riccoYachtS_obj_hit_info": 0x8037dc90,
		"riccoYachtS_obj_hit_info": 0x8037dc90,
		"MoveBG::riccoBoatL_hit_data_table": 0x8037dcac,
		"riccoBoatL_hit_data_table": 0x8037dcac,
		"MoveBG::riccoBoatL_obj_hit_info": 0x8037dcbc,
		"riccoBoatL_obj_hit_info": 0x8037dcbc,
		"MoveBG::riccoBoatS_hit_data_table": 0x8037dcd8,
		"riccoBoatS_hit_data_table": 0x8037dcd8,
		"MoveBG::riccoBoatS_obj_hit_info": 0x8037dce8,
		"riccoBoatS_obj_hit_info": 0x8037dce8,
		"MoveBG::surfgeso_hit_data_table": 0x8037ddb8,
		"surfgeso_hit_data_table": 0x8037ddb8,
		"MoveBG::surfgeso_obj_hit_info": 0x8037ddc8,
		"surfgeso_obj_hit_info": 0x8037ddc8,
		"MoveBG::surfgeso_anim_data": 0x8037dde8,
		"surfgeso_anim_data": 0x8037dde8,
		"MoveBG::@3157": 0x8037de18,
		"MoveBG::windmill_anim_data": 0x8037de38,
		"windmill_anim_data": 0x8037de38,
		"MoveBG::Windmill_hit_data_table": 0x8037de4c,
		"Windmill_hit_data_table": 0x8037de4c,
		"MoveBG::Windmill_obj_hit_info": 0x8037de5c,
		"Windmill_obj_hit_info": 0x8037de5c,
		"MoveBG::MiniWindmill_hit_data_table": 0x8037de88,
		"MiniWindmill_hit_data_table": 0x8037de88,
		"MoveBG::MiniWindmill_obj_hit_info": 0x8037de98,
		"MiniWindmill_obj_hit_info": 0x8037de98,
		"MoveBG::@3162": 0x8037deb8,
		"MoveBG::@3163": 0x8037dec8,
		"MoveBG::@3164": 0x8037ded8,
		"MoveBG::lamp_bianco_anim_data": 0x8037dee8,
		"lamp_bianco_anim_data": 0x8037dee8,
		"MoveBG::lamp_bianco_hit_data_table": 0x8037df74,
		"lamp_bianco_hit_data_table": 0x8037df74,
		"MoveBG::lamp_bianco_obj_hit_info": 0x8037dfa4,
		"lamp_bianco_obj_hit_info": 0x8037dfa4,
		"MoveBG::@3165": 0x8037dfb4,
		"MoveBG::lamp_bianco_map_collision_data": 0x8037dfc0,
		"lamp_bianco_map_collision_data": 0x8037dfc0,
		"MoveBG::WindmillBlock_hit_data_table": 0x8037dfdc,
		"WindmillBlock_hit_data_table": 0x8037dfdc,
		"MoveBG::WindmillBlock_obj_hit_info": 0x8037dfec,
		"WindmillBlock_obj_hit_info": 0x8037dfec,
		"MoveBG::PolluterPakkun_hit_data_table": 0x8037e010,
		"PolluterPakkun_hit_data_table": 0x8037e010,
		"MoveBG::PolluterPakkun_obj_hit_info": 0x8037e020,
		"PolluterPakkun_obj_hit_info": 0x8037e020,
		"MoveBG::@3168": 0x8037e030,
		"MoveBG::@3169": 0x8037e040,
		"MoveBG::BiaBell_anim_data": 0x8037e07c,
		"BiaBell_anim_data": 0x8037e07c,
		"MoveBG::BiaBell_hit_data_table": 0x8037e0e0,
		"BiaBell_hit_data_table": 0x8037e0e0,
		"MoveBG::BiaBell_obj_hit_info": 0x8037e0f0,
		"BiaBell_obj_hit_info": 0x8037e0f0,
		"MoveBG::watermill00_anim_data": 0x8037e13c,
		"watermill00_anim_data": 0x8037e13c,
		"MoveBG::BiaWatermill00_hit_data_table": 0x8037e150,
		"BiaWatermill00_hit_data_table": 0x8037e150,
		"MoveBG::BiaWatermill00_obj_hit_info": 0x8037e160,
		"BiaWatermill00_obj_hit_info": 0x8037e160,
		"MoveBG::@3177": 0x8037e170,
		"MoveBG::BiaWatermill01_hit_data_table": 0x8037e180,
		"BiaWatermill01_hit_data_table": 0x8037e180,
		"MoveBG::BiaWatermill01_obj_hit_info": 0x8037e190,
		"BiaWatermill01_obj_hit_info": 0x8037e190,
		"MoveBG::@3178": 0x8037e1a0,
		"MoveBG::BiaWatermillVertical_hit_data_table": 0x8037e1b0,
		"BiaWatermillVertical_hit_data_table": 0x8037e1b0,
		"MoveBG::BiaWatermillVertical_obj_hit_info": 0x8037e1c0,
		"BiaWatermillVertical_obj_hit_info": 0x8037e1c0,
		"MoveBG::@3179": 0x8037e1d0,
		"MoveBG::BiaTurnBridge_hit_data_table": 0x8037e1e8,
		"BiaTurnBridge_hit_data_table": 0x8037e1e8,
		"MoveBG::BiaTurnBridge_obj_hit_info": 0x8037e1f8,
		"BiaTurnBridge_obj_hit_info": 0x8037e1f8,
		"MoveBG::@3180": 0x8037e208,
		"MoveBG::LeafBoat_hit_data_table": 0x8037e218,
		"LeafBoat_hit_data_table": 0x8037e218,
		"MoveBG::LeafBoat_obj_hit_info": 0x8037e228,
		"LeafBoat_obj_hit_info": 0x8037e228,
		"MoveBG::LampSeesaw_anim_data": 0x8037e254,
		"LampSeesaw_anim_data": 0x8037e254,
		"MoveBG::LampSeesaw_hit_data_table": 0x8037e268,
		"LampSeesaw_hit_data_table": 0x8037e268,
		"MoveBG::LampSeesaw_obj_hit_info": 0x8037e298,
		"LampSeesaw_obj_hit_info": 0x8037e298,
		"MoveBG::SandBird_anim_data": 0x8037e2dc,
		"SandBird_anim_data": 0x8037e2dc,
		"MoveBG::SandBirdBlock_hit_data_table": 0x8037e2fc,
		"SandBirdBlock_hit_data_table": 0x8037e2fc,
		"MoveBG::SandBirdBlock_obj_hit_info": 0x8037e30c,
		"SandBirdBlock_obj_hit_info": 0x8037e30c,
		"MoveBG::SandBirdBlock_map_collision_data": 0x8037e32c,
		"SandBirdBlock_map_collision_data": 0x8037e32c,
		"MoveBG::@3191": 0x8037e34c,
		"MoveBG::SkyIsland_anim_data": 0x8037e358,
		"SkyIsland_anim_data": 0x8037e358,
		"MoveBG::@3192": 0x8037e36c,
		"MoveBG::SandLeaf_anim_data": 0x8037e3c8,
		"SandLeaf_anim_data": 0x8037e3c8,
		"MoveBG::sand_leaf_hit_data_table": 0x8037e42c,
		"sand_leaf_hit_data_table": 0x8037e42c,
		"MoveBG::sand_leaf_obj_hit_info": 0x8037e43c,
		"sand_leaf_obj_hit_info": 0x8037e43c,
		"MoveBG::SandLeafBase00_anim_data": 0x8037e46c,
		"SandLeafBase00_anim_data": 0x8037e46c,
		"MoveBG::SandLeafBase00_map_collision_data": 0x8037e490,
		"SandLeafBase00_map_collision_data": 0x8037e490,
		"MoveBG::SandLeafBase01_anim_data": 0x8037e4b4,
		"SandLeafBase01_anim_data": 0x8037e4b4,
		"MoveBG::SandLeafBase01_map_collision_data": 0x8037e4d8,
		"SandLeafBase01_map_collision_data": 0x8037e4d8,
		"MoveBG::SandLeafBase02_anim_data": 0x8037e4fc,
		"SandLeafBase02_anim_data": 0x8037e4fc,
		"MoveBG::SandLeafBase02_map_collision_data": 0x8037e520,
		"SandLeafBase02_map_collision_data": 0x8037e520,
		"MoveBG::SandLeafBase03_anim_data": 0x8037e544,
		"SandLeafBase03_anim_data": 0x8037e544,
		"MoveBG::SandLeafBase03_map_collision_data": 0x8037e568,
		"SandLeafBase03_map_collision_data": 0x8037e568,
		"MoveBG::SandBomb_anim_data": 0x8037e5c8,
		"SandBomb_anim_data": 0x8037e5c8,
		"MoveBG::sand_bomb_hit_data_table": 0x8037e654,
		"sand_bomb_hit_data_table": 0x8037e654,
		"MoveBG::sand_bomb_obj_hit_info": 0x8037e664,
		"sand_bomb_obj_hit_info": 0x8037e664,
		"MoveBG::@3212": 0x8037e674,
		"MoveBG::mirror_L_hit_data_table": 0x8037e680,
		"mirror_L_hit_data_table": 0x8037e680,
		"MoveBG::mirror_L_obj_hit_info": 0x8037e690,
		"mirror_L_obj_hit_info": 0x8037e690,
		"MoveBG::mirror_L_map_collision_data": 0x8037e6a0,
		"mirror_L_map_collision_data": 0x8037e6a0,
		"MoveBG::mirror_M_hit_data_table": 0x8037e6b0,
		"mirror_M_hit_data_table": 0x8037e6b0,
		"MoveBG::mirror_M_obj_hit_info": 0x8037e6c0,
		"mirror_M_obj_hit_info": 0x8037e6c0,
		"MoveBG::mirror_M_map_collision_data": 0x8037e6d0,
		"mirror_M_map_collision_data": 0x8037e6d0,
		"MoveBG::mirrorS_hit_data_table": 0x8037e6e0,
		"mirrorS_hit_data_table": 0x8037e6e0,
		"MoveBG::mirrorS_obj_hit_info": 0x8037e6f0,
		"mirrorS_obj_hit_info": 0x8037e6f0,
		"MoveBG::mirrorS_map_collision_data": 0x8037e700,
		"mirrorS_map_collision_data": 0x8037e700,
		"MoveBG::@3218": 0x8037e730,
		"MoveBG::SandCastle_anim_data": 0x8037e740,
		"SandCastle_anim_data": 0x8037e740,
		"MoveBG::@3219": 0x8037e790,
		"MoveBG::SandCastle_map_collision_data": 0x8037e79c,
		"SandCastle_map_collision_data": 0x8037e79c,
		"MoveBG::MammaBlockRotate_map_collision_data": 0x8037e7c0,
		"MammaBlockRotate_map_collision_data": 0x8037e7c0,
		"MoveBG::MammaSurfboard_hit_data_table": 0x8037e800,
		"MammaSurfboard_hit_data_table": 0x8037e800,
		"MoveBG::MammaSurfboard_obj_hit_info": 0x8037e810,
		"MammaSurfboard_obj_hit_info": 0x8037e810,
		"MoveBG::@3225": 0x8037e834,
		"MoveBG::@3226": 0x8037e848,
		"MoveBG::@3227": 0x8037e85c,
		"MoveBG::@3228": 0x8037e870,
		"MoveBG::MammaYacht00_hit_data_table": 0x8037e884,
		"MammaYacht00_hit_data_table": 0x8037e884,
		"MoveBG::MammaYacht00_obj_hit_info": 0x8037e894,
		"MammaYacht00_obj_hit_info": 0x8037e894,
		"MoveBG::@3229": 0x8037e8a4,
		"MoveBG::SandBombBase00_anim_data": 0x8037e8f8,
		"SandBombBase00_anim_data": 0x8037e8f8,
		"MoveBG::SandBombBase00_map_collision_data": 0x8037e930,
		"SandBombBase00_map_collision_data": 0x8037e930,
		"MoveBG::SandBombBaseMushroom_anim_data": 0x8037e95c,
		"SandBombBaseMushroom_anim_data": 0x8037e95c,
		"MoveBG::SandBombBaseMushroom_map_collision_data": 0x8037e99c,
		"SandBombBaseMushroom_map_collision_data": 0x8037e99c,
		"MoveBG::SandBombBasePyramid_anim_data": 0x8037e9c4,
		"SandBombBasePyramid_anim_data": 0x8037e9c4,
		"MoveBG::SandBombBasePyramid_map_collision_data": 0x8037ea00,
		"SandBombBasePyramid_map_collision_data": 0x8037ea00,
		"MoveBG::SandBombBaseShit_anim_data": 0x8037ea28,
		"SandBombBaseShit_anim_data": 0x8037ea28,
		"MoveBG::SandBombBaseShit_map_collision_data": 0x8037ea64,
		"SandBombBaseShit_map_collision_data": 0x8037ea64,
		"MoveBG::SandBombBaseStar_anim_data": 0x8037ea8c,
		"SandBombBaseStar_anim_data": 0x8037ea8c,
		"MoveBG::SandBombBaseStar_map_collision_data": 0x8037eac8,
		"SandBombBaseStar_map_collision_data": 0x8037eac8,
		"MoveBG::SandBombBaseTurtle_anim_data": 0x8037eaf0,
		"SandBombBaseTurtle_anim_data": 0x8037eaf0,
		"MoveBG::SandBombBaseTurtle_map_collision_data": 0x8037eb2c,
		"SandBombBaseTurtle_map_collision_data": 0x8037eb2c,
		"MoveBG::SandBombBaseFoot_anim_data": 0x8037eb54,
		"SandBombBaseFoot_anim_data": 0x8037eb54,
		"MoveBG::SandBombBaseFoot_map_collision_data": 0x8037eb90,
		"SandBombBaseFoot_map_collision_data": 0x8037eb90,
		"MoveBG::SandBombBaseHand_anim_data": 0x8037ebb8,
		"SandBombBaseHand_anim_data": 0x8037ebb8,
		"MoveBG::SandBombBaseHand_map_collision_data": 0x8037ebf4,
		"SandBombBaseHand_map_collision_data": 0x8037ebf4,
		"MoveBG::SandBombBaseStairs_anim_data": 0x8037ec1c,
		"SandBombBaseStairs_anim_data": 0x8037ec1c,
		"MoveBG::SandBombBaseStairs_map_collision_data": 0x8037ec58,
		"SandBombBaseStairs_map_collision_data": 0x8037ec58,
		"MoveBG::GoalWatermelon_hit_data_table": 0x8037ec68,
		"GoalWatermelon_hit_data_table": 0x8037ec68,
		"MoveBG::GoalWatermelon_obj_hit_info": 0x8037ec78,
		"GoalWatermelon_obj_hit_info": 0x8037ec78,
		"MoveBG::TeethOfJuicer_anim_data": 0x8037ecbc,
		"TeethOfJuicer_anim_data": 0x8037ecbc,
		"MoveBG::TeethOfJuicer_hit_data_table": 0x8037ecd0,
		"TeethOfJuicer_hit_data_table": 0x8037ecd0,
		"MoveBG::TeethOfJuicer_obj_hit_info": 0x8037ece0,
		"TeethOfJuicer_obj_hit_info": 0x8037ece0,
		"MoveBG::merrygoround_anim_data": 0x8037ed1c,
		"merrygoround_anim_data": 0x8037ed1c,
		"MoveBG::merry_hit_data_table": 0x8037ed30,
		"merry_hit_data_table": 0x8037ed30,
		"MoveBG::merrygoround_obj_hit_info": 0x8037ed40,
		"merrygoround_obj_hit_info": 0x8037ed40,
		"MoveBG::merry_egg_hit_data_table": 0x8037ed50,
		"merry_egg_hit_data_table": 0x8037ed50,
		"MoveBG::merry_egg_obj_hit_info": 0x8037ed60,
		"merry_egg_obj_hit_info": 0x8037ed60,
		"MoveBG::merry_pole_hit_data_table": 0x8037ed7c,
		"merry_pole_hit_data_table": 0x8037ed7c,
		"MoveBG::merry_pole_obj_hit_info": 0x8037ed8c,
		"merry_pole_obj_hit_info": 0x8037ed8c,
		"MoveBG::FerrisWheel_anim_data": 0x8037edc4,
		"FerrisWheel_anim_data": 0x8037edc4,
		"MoveBG::FerrisWheel_hit_data_table": 0x8037edd8,
		"FerrisWheel_hit_data_table": 0x8037edd8,
		"MoveBG::FerrisWheel_obj_hit_info": 0x8037ede8,
		"FerrisWheel_obj_hit_info": 0x8037ede8,
		"MoveBG::FerrisWheelGondola_hit_data_table": 0x8037ee14,
		"FerrisWheelGondola_hit_data_table": 0x8037ee14,
		"MoveBG::FerrisWheelGondola_obj_hit_info": 0x8037ee24,
		"FerrisWheelGondola_obj_hit_info": 0x8037ee24,
		"MoveBG::FerrisLOD_anim_data": 0x8037ee50,
		"FerrisLOD_anim_data": 0x8037ee50,
		"MoveBG::Viking_hit_data_table": 0x8037ee70,
		"Viking_hit_data_table": 0x8037ee70,
		"MoveBG::Viking_obj_hit_info": 0x8037ee80,
		"Viking_obj_hit_info": 0x8037ee80,
		"MoveBG::balloon_koopajr_anim_data": 0x8037eee0,
		"balloon_koopajr_anim_data": 0x8037eee0,
		"MoveBG::balloon_koopajr_hit_data_table": 0x8037ef1c,
		"balloon_koopajr_hit_data_table": 0x8037ef1c,
		"MoveBG::balloon_koopajr_obj_hit_info": 0x8037ef2c,
		"balloon_koopajr_obj_hit_info": 0x8037ef2c,
		"MoveBG::@3276": 0x8037ef4c,
		"MoveBG::@3277": 0x8037ef5c,
		"MoveBG::ShellCup_anim_data": 0x8037ef68,
		"ShellCup_anim_data": 0x8037ef68,
		"MoveBG::@3278": 0x8037ef7c,
		"MoveBG::ShellCup_hit_data_table": 0x8037ef8c,
		"ShellCup_hit_data_table": 0x8037ef8c,
		"MoveBG::ShellCup_obj_hit_info": 0x8037ef9c,
		"ShellCup_obj_hit_info": 0x8037ef9c,
		"MoveBG::Gateshell_anim_data": 0x8037efd4,
		"Gateshell_anim_data": 0x8037efd4,
		"MoveBG::PinnaHangingBridgeBoard_anim_data": 0x8037f004,
		"PinnaHangingBridgeBoard_anim_data": 0x8037f004,
		"MoveBG::PinnaHangingBridgeBoard_hit_data_table": 0x8037f018,
		"PinnaHangingBridgeBoard_hit_data_table": 0x8037f018,
		"MoveBG::PinnaHangingBridgeBoard_obj_hit_info": 0x8037f028,
		"PinnaHangingBridgeBoard_obj_hit_info": 0x8037f028,
		"MoveBG::GateManta_anim_data": 0x8037f078,
		"GateManta_anim_data": 0x8037f078,
		"MoveBG::@3289": 0x8037f098,
		"MoveBG::@3290": 0x8037f0a8,
		"MoveBG::AmiKing_anim_data": 0x8037f0bc,
		"AmiKing_anim_data": 0x8037f0bc,
		"MoveBG::AmiKing_hit_data_table": 0x8037f0d0,
		"AmiKing_hit_data_table": 0x8037f0d0,
		"MoveBG::AmiKing_obj_hit_info": 0x8037f0e0,
		"AmiKing_obj_hit_info": 0x8037f0e0,
		"MoveBG::PinnaCoaster_hit_data_table": 0x8037f0f0,
		"PinnaCoaster_hit_data_table": 0x8037f0f0,
		"MoveBG::PinnaCoaster_obj_hit_info": 0x8037f100,
		"PinnaCoaster_obj_hit_info": 0x8037f100,
		"MoveBG::roulette_anim_data": 0x8037f128,
		"roulette_anim_data": 0x8037f128,
		"MoveBG::slotdrum_hit_data_table": 0x8037f13c,
		"slotdrum_hit_data_table": 0x8037f13c,
		"MoveBG::slotdrum_obj_hit_info": 0x8037f14c,
		"slotdrum_obj_hit_info": 0x8037f14c,
		"MoveBG::telesaslot_hit_data_table": 0x8037f174,
		"telesaslot_hit_data_table": 0x8037f174,
		"MoveBG::telesaslot_obj_hit_info": 0x8037f184,
		"telesaslot_obj_hit_info": 0x8037f184,
		"MoveBG::@3300": 0x8037f194,
		"MoveBG::donchou_anim_data": 0x8037f1a0,
		"donchou_anim_data": 0x8037f1a0,
		"MoveBG::donchou_hit_data_table": 0x8037f1b4,
		"donchou_hit_data_table": 0x8037f1b4,
		"MoveBG::donchou_obj_hit_info": 0x8037f1c4,
		"donchou_obj_hit_info": 0x8037f1c4,
		"MoveBG::casino_panel_gate_hit_data_table": 0x8037f1d4,
		"casino_panel_gate_hit_data_table": 0x8037f1d4,
		"MoveBG::casino_panel_gate_obj_hit_info": 0x8037f1e4,
		"casino_panel_gate_obj_hit_info": 0x8037f1e4,
		"MoveBG::bosswall_anim_data": 0x8037f210,
		"bosswall_anim_data": 0x8037f210,
		"MoveBG::casinoroof_anim_data": 0x8037f258,
		"casinoroof_anim_data": 0x8037f258,
		"MoveBG::GlassBreak_anim_data": 0x8037f29c,
		"GlassBreak_anim_data": 0x8037f29c,
		"MoveBG::GlassBreak_sound_data": 0x8037f328,
		"GlassBreak_sound_data": 0x8037f328,
		"MoveBG::closet_anim_data": 0x8037f368,
		"closet_anim_data": 0x8037f368,
		"MoveBG::closet_hit_data_table": 0x8037f37c,
		"closet_hit_data_table": 0x8037f37c,
		"MoveBG::closet_obj_hit_info": 0x8037f38c,
		"closet_obj_hit_info": 0x8037f38c,
		"MoveBG::ChestRevolve_anim_data": 0x8037f3e0,
		"ChestRevolve_anim_data": 0x8037f3e0,
		"MoveBG::ChestRevolve_map_collision_data": 0x8037f418,
		"ChestRevolve_map_collision_data": 0x8037f418,
		"MoveBG::PosterTeresa_anim_data": 0x8037f44c,
		"PosterTeresa_anim_data": 0x8037f44c,
		"MoveBG::PictureTeresa_anim_data": 0x8037f494,
		"PictureTeresa_anim_data": 0x8037f494,
		"MoveBG::PictureTeresa_hit_data_table": 0x8037f4a8,
		"PictureTeresa_hit_data_table": 0x8037f4a8,
		"MoveBG::PictureTeresa_obj_hit_info": 0x8037f4b8,
		"PictureTeresa_obj_hit_info": 0x8037f4b8,
		"MoveBG::PanelBreak_anim_data": 0x8037f4f4,
		"PanelBreak_anim_data": 0x8037f4f4,
		"MoveBG::PanelBreak_sound_data": 0x8037f580,
		"PanelBreak_sound_data": 0x8037f580,
		"MoveBG::PanelRevolve_anim_data": 0x8037f5cc,
		"PanelRevolve_anim_data": 0x8037f5cc,
		"MoveBG::cogwheel_anim_data": 0x8037f644,
		"cogwheel_anim_data": 0x8037f644,
		"MoveBG::Cogwheel_hit_data_table": 0x8037f658,
		"Cogwheel_hit_data_table": 0x8037f658,
		"MoveBG::Cogwheel_obj_hit_info": 0x8037f668,
		"Cogwheel_obj_hit_info": 0x8037f668,
		"MoveBG::CogwheelPlate_hit_data_table": 0x8037f694,
		"CogwheelPlate_hit_data_table": 0x8037f694,
		"MoveBG::CogwheelPlate_obj_hit_info": 0x8037f6a4,
		"CogwheelPlate_obj_hit_info": 0x8037f6a4,
		"MoveBG::@3336": 0x8037f6b4,
		"MoveBG::CogwheelPot_hit_data_table": 0x8037f6c4,
		"CogwheelPot_hit_data_table": 0x8037f6c4,
		"MoveBG::CogwheelPot_obj_hit_info": 0x8037f6d4,
		"CogwheelPot_obj_hit_info": 0x8037f6d4,
		"MoveBG::@3337": 0x8037f6e4,
		"MoveBG::mare_float_house_hit_data_table": 0x8037f6f4,
		"mare_float_house_hit_data_table": 0x8037f6f4,
		"MoveBG::mare_float_house_obj_hit_info": 0x8037f704,
		"mare_float_house_obj_hit_info": 0x8037f704,
		"MoveBG::StopRock_hit_data_table": 0x8037f714,
		"StopRock_hit_data_table": 0x8037f714,
		"MoveBG::StopRock_obj_hit_info": 0x8037f724,
		"StopRock_obj_hit_info": 0x8037f724,
		"MoveBG::@3339": 0x8037f734,
		"MoveBG::ElasticCode_hit_data_table": 0x8037f740,
		"ElasticCode_hit_data_table": 0x8037f740,
		"MoveBG::ElasticCode_obj_hit_info": 0x8037f750,
		"ElasticCode_obj_hit_info": 0x8037f750,
		"MoveBG::@3340": 0x8037f760,
		"MoveBG::@3343": 0x8037f784,
		"MoveBG::GrowthTree_anim_data": 0x8037f794,
		"GrowthTree_anim_data": 0x8037f794,
		"MoveBG::GrowthTree_hit_data_table": 0x8037f7bc,
		"GrowthTree_hit_data_table": 0x8037f7bc,
		"MoveBG::GrowthTree_obj_hit_info": 0x8037f7cc,
		"GrowthTree_obj_hit_info": 0x8037f7cc,
		"MoveBG::MuddyBoat_anim_data": 0x8037f824,
		"MuddyBoat_anim_data": 0x8037f824,
		"MoveBG::MuddyBoat_hit_data_table": 0x8037f860,
		"MuddyBoat_hit_data_table": 0x8037f860,
		"MoveBG::MuddyBoat_obj_hit_info": 0x8037f870,
		"MuddyBoat_obj_hit_info": 0x8037f870,
		"MoveBG::Puncher_anim_data": 0x8037f8d4,
		"Puncher_anim_data": 0x8037f8d4,
		"MoveBG::Puncher_hit_data_table": 0x8037f8fc,
		"Puncher_hit_data_table": 0x8037f8fc,
		"MoveBG::Puncher_obj_hit_info": 0x8037f90c,
		"Puncher_obj_hit_info": 0x8037f90c,
		"MoveBG::@3354": 0x8037f91c,
		"MoveBG::@3356": 0x8037f940,
		"MoveBG::HatoPop_anim_data": 0x8037f964,
		"HatoPop_anim_data": 0x8037f964,
		"MoveBG::HatoPop_hit_data_table": 0x8037f98c,
		"HatoPop_hit_data_table": 0x8037f98c,
		"MoveBG::HatoPop_obj_hit_info": 0x8037f99c,
		"HatoPop_obj_hit_info": 0x8037f99c,
		"MoveBG::MareWaterJump_hit_data_table": 0x8037f9ac,
		"MareWaterJump_hit_data_table": 0x8037f9ac,
		"MoveBG::MareWaterJump_obj_hit_info": 0x8037f9bc,
		"MareWaterJump_obj_hit_info": 0x8037f9bc,
		"MoveBG::@3358": 0x8037f9cc,
		"MoveBG::@3359": 0x8037f9e0,
		"MoveBG::BumpyWall_hit_data_table": 0x8037f9f0,
		"BumpyWall_hit_data_table": 0x8037f9f0,
		"MoveBG::BumpyWall_obj_hit_info": 0x8037fa00,
		"BumpyWall_obj_hit_info": 0x8037fa00,
		"MoveBG::@3360": 0x8037fa10,
		"MoveBG::ExBottle_hit_data_table": 0x8037fa24,
		"ExBottle_hit_data_table": 0x8037fa24,
		"MoveBG::ExBottle_obj_hit_info": 0x8037fa34,
		"ExBottle_obj_hit_info": 0x8037fa34,
		"MoveBG::@3362": 0x8037fa50,
		"MoveBG::@3363": 0x8037fa60,
		"MoveBG::CoinFish_anim_data": 0x8037fa6c,
		"CoinFish_anim_data": 0x8037fa6c,
		"MoveBG::@3365": 0x8037fa8c,
		"MoveBG::@3366": 0x8037fa9c,
		"MoveBG::MareFall_anim_data": 0x8037faa8,
		"MareFall_anim_data": 0x8037faa8,
		"MoveBG::@3367": 0x8037fabc,
		"MoveBG::MonteRoot_anim_data": 0x8037fae0,
		"MonteRoot_anim_data": 0x8037fae0,
		"MoveBG::MonteRoot_hit_data_table": 0x8037faf4,
		"MonteRoot_hit_data_table": 0x8037faf4,
		"MoveBG::MonteRoot_obj_hit_info": 0x8037fb04,
		"MonteRoot_obj_hit_info": 0x8037fb04,
		"MoveBG::@3370": 0x8037fb14,
		"MoveBG::@3371": 0x8037fb20,
		"MoveBG::@3372": 0x8037fb30,
		"MoveBG::JumpMushroom_anim_data": 0x8037fb44,
		"JumpMushroom_anim_data": 0x8037fb44,
		"MoveBG::@3373": 0x8037fb6c,
		"MoveBG::@3374": 0x8037fb78,
		"MoveBG::MonteGoalFlag_anim_data": 0x8037fba8,
		"MonteGoalFlag_anim_data": 0x8037fba8,
		"MoveBG::MonteGoalFlag_hit_data_table": 0x8037fbbc,
		"MonteGoalFlag_hit_data_table": 0x8037fbbc,
		"MoveBG::MonteGoalFlag_obj_hit_info": 0x8037fbcc,
		"MonteGoalFlag_obj_hit_info": 0x8037fbcc,
		"MoveBG::HangingBridgeBoard_anim_data": 0x8037fbf8,
		"HangingBridgeBoard_anim_data": 0x8037fbf8,
		"MoveBG::HangingBridgeBoard_hit_data_table": 0x8037fc0c,
		"HangingBridgeBoard_hit_data_table": 0x8037fc0c,
		"MoveBG::HangingBridgeBoard_obj_hit_info": 0x8037fc1c,
		"HangingBridgeBoard_obj_hit_info": 0x8037fc1c,
		"MoveBG::SwingBoard_hit_data_table": 0x8037fc50,
		"SwingBoard_hit_data_table": 0x8037fc50,
		"MoveBG::SwingBoard_obj_hit_info": 0x8037fc60,
		"SwingBoard_obj_hit_info": 0x8037fc60,
		"MoveBG::Fluff_anim_data": 0x8037fc88,
		"Fluff_anim_data": 0x8037fc88,
		"MoveBG::Fluff_hit_data_table": 0x8037fc9c,
		"Fluff_hit_data_table": 0x8037fc9c,
		"MoveBG::Fluff_obj_hit_info": 0x8037fcac,
		"Fluff_obj_hit_info": 0x8037fcac,
		"MoveBG::Bathtub_anim_data": 0x8037fce8,
		"Bathtub_anim_data": 0x8037fce8,
		"MoveBG::BathtubStandBreaking_anim_data": 0x8037fd90,
		"BathtubStandBreaking_anim_data": 0x8037fd90,
		"MoveBG::ex1_turn_lift_anim_data": 0x8037fe10,
		"ex1_turn_lift_anim_data": 0x8037fe10,
		"MoveBG::y_turn_lift_anim_data": 0x8037fe94,
		"y_turn_lift_anim_data": 0x8037fe94,
		"MoveBG::Nail_anim_data": 0x8037ff00,
		"Nail_anim_data": 0x8037ff00,
		"MoveBG::Nail_hit_data_table": 0x8037ff14,
		"Nail_hit_data_table": 0x8037ff14,
		"MoveBG::Nail_obj_hit_info": 0x8037ff24,
		"Nail_obj_hit_info": 0x8037ff24,
		"MoveBG::PachinkoNail_anim_data": 0x8037ff54,
		"PachinkoNail_anim_data": 0x8037ff54,
		"MoveBG::FileLoadBlockA_anim_data": 0x8037ffe0,
		"FileLoadBlockA_anim_data": 0x8037ffe0,
		"MoveBG::FileLoadBlock_hit_data_table": 0x8038001c,
		"FileLoadBlock_hit_data_table": 0x8038001c,
		"MoveBG::FileLoadBlock_obj_hit_info": 0x8038002c,
		"FileLoadBlock_obj_hit_info": 0x8038002c,
		"MoveBG::FileLoadBlockB_anim_data": 0x80380078,
		"FileLoadBlockB_anim_data": 0x80380078,
		"MoveBG::FileLoadBlockC_anim_data": 0x803800f0,
		"FileLoadBlockC_anim_data": 0x803800f0,
		"MoveBG::@3728": 0x8038013c,
		"MoveBG::@2183": 0x803801b8,
		"MoveBG::@2184": 0x803801f0,
		"MoveBG::@2185": 0x80380224,
		"MoveBG::@3779": 0x80380418,
		"MoveBG::@3786": 0x80380480,
		"MoveBG::@3806": 0x8038058c,
		"MoveBG::@3807": 0x803805a8,
		"MoveBG::@3808": 0x803805b4,
		"MoveBG::@3809": 0x803805c0,
		"MoveBG::@3810": 0x803805dc,
		"MoveBG::@4173": 0x803808b0,
		"MoveBG::@4174": 0x803808cc,
		"MoveBG::@4175": 0x803808e8,
		"MoveBG::@4176": 0x80380904,
		"MoveBG::@4177": 0x80380924,
		"MoveBG::@4178": 0x80380940,
		"MoveBG::@4179": 0x80380960,
		"MoveBG::@2409": 0x80380f08,
		"MoveBG::@2410": 0x80380f38,
		"MoveBG::@2411": 0x80380f70,
		"MoveBG::@2412": 0x80380fa4,
		"MoveBG::@4241": 0x80381284,
		"MoveBG::@3440": 0x80381694,
		"MoveBG::@2724": 0x80381780,
		"MoveBG::@4109": 0x80381988,
		"MoveBG::@4496": 0x80381a7c,
		"@4496": 0x80381a7c,
		"MoveBG::@4971": 0x80381b48,
		"MoveBG::@4976": 0x80381b84,
		"MoveBG::@2211": 0x80381f70,
		"MoveBG::@2212": 0x80381fa0,
		"MoveBG::@2213": 0x80381fd8,
		"MoveBG::@2214": 0x8038200c,
		"MoveBG::@2692": 0x8038203c,
		"MoveBG::@2498": 0x80382234,
		"MoveBG::@2499": 0x80382240,
		"MoveBG::@2500": 0x80382250,
		"MoveBG::@2501": 0x80382260,
		"MoveBG::@2464": 0x80382378,
		"MoveBG::@2467": 0x80382384,
		"MoveBG::@2468": 0x80382390,
		"@2468": 0x80382390,
		"MoveBG::@2469": 0x8038239c,
		"@2469": 0x8038239c,
		"MoveBG::@2470": 0x803823a8,
		"MoveBG::@2471": 0x803823b4,
		"MoveBG::@2473": 0x803823d0,
		"MoveBG::param_table": 0x803823f0,
		"param_table": 0x803823f0,
		"MoveBG::@2539": 0x80382600,
		"MoveBG::@2540": 0x80382624,
		"MoveBG::@2634": 0x80382648,
		"MoveBG::@2639": 0x803826a8,
		"MoveBG::@2371": 0x803826e8,
		"MoveBG::@2372": 0x80382718,
		"MoveBG::@2373": 0x80382750,
		"MoveBG::@2374": 0x80382784,
		"MoveBG::@2600": 0x80382cd0,
		"MoveBG::@2188": 0x80382d40,
		"MoveBG::@2520": 0x80382e00,
		"MoveBG::@2522": 0x80382e0c,
		"MoveBG::@2397": 0x80382ea0,
		"MoveBG::@2398": 0x80382ed0,
		"MoveBG::@2399": 0x80382f08,
		"MoveBG::@2400": 0x80382f3c,
		"MoveBG::@2575": 0x80382fac,
		"MoveBG::@2576": 0x80382fb8,
		"MoveBG::@2577": 0x80382fc4,
		"MoveBG::@2578": 0x80382fd0,
		"MoveBG::cDirtyFileName": 0x803833e8,
		"MoveBG::cDirtyTexName": 0x8038340c,
		"MoveBG::@3679": 0x803834a0,
		"MoveBG::@3680": 0x803834c0,
		"MoveBG::@3715": 0x80383560,
		"MoveBG::@3755": 0x80383588,
		"MoveBG::@3758": 0x803835c0,
		"MoveBG::@2753": 0x803836e0,
		"MoveBG::@2605": 0x80383b68,
		"MoveBG::@2659": 0x80383bac,
		"MoveBG::@2660": 0x80383bbc,
		"MoveBG::@2661": 0x80383bdc,
		"MoveBG::@5842": 0x80383fd4,
		"MoveBG::@5966": 0x80384044,
		"@5966": 0x80384044,
		"MoveBG::@5967": 0x80384054,
		"@5967": 0x80384054,
		"MoveBG::@5968": 0x80384064,
		"@5968": 0x80384064,
		"MoveBG::@5969": 0x80384074,
		"@5969": 0x80384074,
		"MoveBG::@5970": 0x80384080,
		"@5970": 0x80384080,
		"MoveBG::@5971": 0x8038408c,
		"@5971": 0x8038408c,
		"MoveBG::@5972": 0x80384098,
		"@5972": 0x80384098,
		"MoveBG::@5973": 0x803840a4,
		"@5973": 0x803840a4,
		"MoveBG::@5976": 0x803840c0,
		"@5976": 0x803840c0,
		"MoveBG::@5977": 0x803840cc,
		"@5977": 0x803840cc,
		"MoveBG::@5978": 0x803840d8,
		"@5978": 0x803840d8,
		"MoveBG::@5991": 0x80384124,
		"MoveBG::@2546": 0x80384188,
		"MoveBG::@2547": 0x803841b8,
		"MoveBG::@2548": 0x803841f0,
		"MoveBG::@2549": 0x80384224,
		"MoveBG::@2327": 0x80384448,
		"MoveBG::@2328": 0x80384478,
		"MoveBG::@2329": 0x803844b0,
		"MoveBG::@2330": 0x803844e4,
		"Map::@2324": 0x80378908,
		"Map::@2514": 0x803789f8,
		"Map::@2516": 0x80378a04,
		"Map::@2972": 0x80378a10,
		"Map::@3338": 0x80378a20,
		"Map::@3339": 0x80378a3c,
		"Map::@3340": 0x80378a4c,
		"Map::@3506": 0x80378a5c,
		"Map::@3507": 0x80378a74,
		"Map::@3509": 0x80378a80,
		"Map::@3510": 0x80378a94,
		"Map::@3511": 0x80378aa0,
		"Map::@3512": 0x80378ab4,
		"Map::@3566": 0x80378ad0,
		"Map::@3567": 0x80378ae8,
		"Map::@3701": 0x80378af4,
		"Map::@3702": 0x80378b08,
		"Map::@3703": 0x80378b14,
		"Map::@3704": 0x80378b38,
		"Map::@3705": 0x80378b5c,
		"Map::@3799": 0x80378b78,
		"Map::@3800": 0x80378b8c,
		"Map::@3801": 0x80378bb4,
		"Map::@3802": 0x80378bdc,
		"Map::@1526": 0x80378c0c,
		"Map::@1766": 0x80378c20,
		"@1766": 0x80378c20,
		"Map::@1768": 0x80378c2c,
		"Map::@2018": 0x80378c38,
		"Map::@2019": 0x80378c48,
		"Map::@2020": 0x80378c58,
		"Map::@2272": 0x80378ca0,
		"Map::@2273": 0x80378cd0,
		"Map::@2274": 0x80378d08,
		"Map::@2275": 0x80378d3c,
		"Map::@2604": 0x80378d60,
		"Map::@3076": 0x80378d78,
		"Map::@3151": 0x80378dc0,
		"Map::@3154": 0x80378dcc,
		"Map::@2513": 0x80378f28,
		"Map::@2515": 0x80378f34,
		"Map::@2517": 0x80378f40,
		"Map::@2667": 0x80378f90,
		"Map::@2502": 0x80378fa0,
		"Map::@2503": 0x80378fb0,
		"Map::@2197": 0x80379088,
		"Map::@2198": 0x803790b8,
		"Map::@2199": 0x803790f0,
		"Map::@2200": 0x80379124,
		"Map::@2882": 0x80379224,
		"Map::@2883": 0x80379230,
		"Map::@2884": 0x80379248,
		"Map::@2885": 0x8037926c,
		"Map::@2886": 0x80379280,
		"Map::@2887": 0x8037928c,
		"Map::@2888": 0x803792a0,
		"Map::@2889": 0x803792b4,
		"Map::@2890": 0x803792c8,
		"Map::@2891": 0x803792dc,
		"Map::@2892": 0x803792f0,
		"Map::@2893": 0x803792fc,
		"Map::@2894": 0x80379310,
		"Map::@2895": 0x80379324,
		"Map::@2896": 0x8037933c,
		"Map::@2897": 0x80379348,
		"Map::@2898": 0x80379354,
		"Map::@2899": 0x80379360,
		"Map::actor_data_table": 0x8037936c,
		"actor_data_table": 0x8037936c,
		"Map::sound_info": 0x80379b2c,
		"sound_info": 0x80379b2c,
		"Map::@1937": 0x80379bfc,
		"Map::@2174": 0x80379c10,
		"Map::@2176": 0x80379c1c,
		"Map::@2579": 0x80379c28,
		"Map::@2178": 0x80379ca8,
		"Map::@2179": 0x80379cd8,
		"Map::@2180": 0x80379d10,
		"Map::@2181": 0x80379d44,
		"Map::@2829": 0x80379e7c,
		"Map::@2986": 0x80379e88,
		"Map::@2987": 0x80379e9c,
		"Map::@2988": 0x80379eb0,
		"Map::@2771": 0x8037a038,
		"Map::@2772": 0x8037a05c,
		"Map::@2784": 0x8037a080,
		"Map::@1974": 0x8037a130,
		"Map::@2925": 0x8037a258,
		"Map::@3396": 0x8037a340,
		"Map::@3403": 0x8037a360,
		"Map::@3688": 0x8037a384,
		"Map::@3699": 0x8037a394,
		"Map::@3735": 0x8037a3a4,
		"Map::@1900": 0x8037a3c0,
		"Map::@1907": 0x8037a3d4,
		"Map::@1996": 0x8037a3e0,
		"Map::@1997": 0x8037a410,
		"Map::@1998": 0x8037a448,
		"Map::@1999": 0x8037a47c,
		"Map::@4358": 0x8037a5ac,
		"Map::@4748": 0x8037a650,
		"Map::@4749": 0x8037a65c,
		"Map::@4752": 0x8037a668,
		"Map::@4755": 0x8037a678,
		"Map::@4758": 0x8037a6a4,
		"Map::@4762": 0x8037a6bc,
		"Map::@4832": 0x8037a718,
		"Map::@4834": 0x8037a724,
		"Map::@4835": 0x8037a730,
		"Map::@4837": 0x8037a73c,
		"Map::@4838": 0x8037a748,
		"Map::@4844": 0x8037a760,
		"GC2D::@1772": 0x803774d8,
		"GC2D::@1953": 0x803774f4,
		"GC2D::@2082": 0x80377508,
		"GC2D::@2084": 0x80377528,
		"GC2D::@2086": 0x80377548,
		"GC2D::scNozzleSoundList": 0x80377588,
		"scNozzleSoundList": 0x80377588,
		"GC2D::@1937": 0x8037777c,
		"GC2D::scTalkSoundList": 0x80377850,
		"scTalkSoundList": 0x80377850,
		"GC2D::@2719": 0x80377a6c,
		"GC2D::@2722": 0x80377a7c,
		"GC2D::@2723": 0x80377aa4,
		"GC2D::@1991": 0x80377cd0,
		"GC2D::@2112": 0x80377d9c,
		"GC2D::@1705": 0x80377f84,
		"GC2D::@2421": 0x8037804c,
		"GC2D::@2422": 0x80378078,
		"GC2D::@3040": 0x803781b4,
		"GC2D::@3041": 0x803781c4,
		"GC2D::@3042": 0x803781d0,
		"GC2D::@3043": 0x803781e0,
		"GC2D::@3044": 0x803781f4,
		"GC2D::@3045": 0x80378204,
		"GC2D::@3046": 0x80378210,
		"GC2D::@3047": 0x8037821c,
		"GC2D::@3048": 0x80378228,
		"GC2D::@3049": 0x8037823c,
		"GC2D::@3050": 0x80378264,
		"GC2D::@3051": 0x8037828c,
		"GC2D::@3052": 0x803782b4,
		"GC2D::@3053": 0x803782e0,
		"GC2D::@3054": 0x80378308,
		"GC2D::@3055": 0x80378330,
		"GC2D::@3056": 0x80378358,
		"GC2D::@3057": 0x80378380,
		"GC2D::@3058": 0x803783a8,
		"GC2D::@3059": 0x803783bc,
		"GC2D::@3060": 0x803783cc,
		"GC2D::@3066": 0x803783dc,
		"GC2D::@3128": 0x80378410,
		"GC2D::@1752": 0x8037842c,
		"GC2D::@2482": 0x80378440,
		"GC2D::@2483": 0x80378458,
		"GC2D::@1942": 0x803784bc,
		"GC2D::@4089": 0x8037851c,
		"GC2D::@4090": 0x80378538,
		"GC2D::@4091": 0x8037855c,
		"GC2D::@4092": 0x80378580,
		"GC2D::@4093": 0x803785a8,
		"GC2D::@4094": 0x803785d0,
		"GC2D::@4095": 0x803785f4,
		"GC2D::@1938": 0x803786a4,
		"@unnamed@::cRumbleAnm": 0x803786b8,
		"cRumbleAnm": 0x803786b8,
		"@unnamed@::cSurMonteAnm": 0x80378708,
		"cSurMonteAnm": 0x80378708,
		"@unnamed@::cSurLTSpeakerAnm": 0x80378748,
		"cSurLTSpeakerAnm": 0x80378748,
		"@unnamed@::cSurRTSpeakerAnm": 0x80378770,
		"cSurRTSpeakerAnm": 0x80378770,
		"@unnamed@::cSurLBSpeakerAnm": 0x80378798,
		"cSurLBSpeakerAnm": 0x80378798,
		"@unnamed@::cSurRBSpeakerAnm": 0x803787c0,
		"cSurRBSpeakerAnm": 0x803787c0,
		"@unnamed@::cSteMonteAnm": 0x803787e8,
		"cSteMonteAnm": 0x803787e8,
		"@unnamed@::cSteLSpeakerAnm": 0x80378828,
		"cSteLSpeakerAnm": 0x80378828,
		"@unnamed@::cSteRSpeakerAnm": 0x80378850,
		"cSteRSpeakerAnm": 0x80378850,
		"@unnamed@::cMonoMonteAnm": 0x80378878,
		"cMonoMonteAnm": 0x80378878,
		"@unnamed@::cMonoSpeakerAnm": 0x80378888,
		"cMonoSpeakerAnm": 0x80378888,
		"@unnamed@::cSoundToggleItems": 0x80378898,
		"cSoundToggleItems": 0x80378898,
		"GC2D::@1557": 0x803788d0,
		"GC2D::@1578": 0x803788e4,
		"GC2D::@1579": 0x803788f0,
		"Enemy::@4571": 0x80367460,
		"@4571": 0x80367460,
		"Enemy::@2141": 0x803674e4,
		"Enemy::@2673": 0x803675b8,
		"Enemy::@2685": 0x803675d0,
		"Enemy::@1973": 0x803678d8,
		"Enemy::@1974": 0x80367908,
		"Enemy::@1975": 0x80367940,
		"Enemy::@1976": 0x80367974,
		"Enemy::@2270": 0x80367ad8,
		"Enemy::@2272": 0x80367b44,
		"Enemy::@2281": 0x80367c48,
		"Enemy::@2283": 0x80367cb4,
		"Enemy::replayLinkMonteMan": 0x8036831c,
		"replayLinkMonteMan": 0x8036831c,
		"Enemy::@6434": 0x80368520,
		"@6434": 0x80368520,
		"Enemy::@6435": 0x8036852c,
		"@6435": 0x8036852c,
		"Enemy::@6437": 0x8036853c,
		"@6437": 0x8036853c,
		"Enemy::@6438": 0x80368548,
		"@6438": 0x80368548,
		"Enemy::@6439": 0x80368554,
		"@6439": 0x80368554,
		"Enemy::@6440": 0x80368560,
		"@6440": 0x80368560,
		"Enemy::@6441": 0x8036856c,
		"@6441": 0x8036856c,
		"Enemy::@6442": 0x80368578,
		"@6442": 0x80368578,
		"Enemy::@6444": 0x80368594,
		"@6444": 0x80368594,
		"Enemy::@6445": 0x803685a0,
		"@6445": 0x803685a0,
		"Enemy::@6446": 0x803685b0,
		"@6446": 0x803685b0,
		"Enemy::@6448": 0x803685c0,
		"@6448": 0x803685c0,
		"Enemy::@6449": 0x803685dc,
		"@6449": 0x803685dc,
		"Enemy::@6450": 0x803685f8,
		"@6450": 0x803685f8,
		"Enemy::@6451": 0x80368618,
		"@6451": 0x80368618,
		"Enemy::@6455": 0x8036864c,
		"@6455": 0x8036864c,
		"Enemy::@6456": 0x80368670,
		"@6456": 0x80368670,
		"Enemy::@6457": 0x80368694,
		"@6457": 0x80368694,
		"Enemy::@6458": 0x803686b8,
		"@6458": 0x803686b8,
		"Enemy::@5330": 0x80368c10,
		"Enemy::@5331": 0x80368c24,
		"Enemy::@5332": 0x80368c3c,
		"Enemy::@5333": 0x80368c54,
		"Enemy::@5334": 0x80368c68,
		"Enemy::@5336": 0x80368c94,
		"Enemy::@5338": 0x80368ca4,
		"Enemy::@5340": 0x80368cb4,
		"Enemy::@1961": 0x80368d20,
		"Enemy::@1962": 0x80368d50,
		"Enemy::@1963": 0x80368d88,
		"Enemy::@1964": 0x80368dbc,
		"Enemy::@7735": 0x803692b4,
		"@7735": 0x803692b4,
		"Enemy::@7736": 0x803692c0,
		"@7736": 0x803692c0,
		"Enemy::@7737": 0x803692cc,
		"@7737": 0x803692cc,
		"Enemy::@7755": 0x803692fc,
		"@7755": 0x803692fc,
		"Enemy::@7788": 0x80369340,
		"@7788": 0x80369340,
		"Enemy::@7904": 0x803693b8,
		"@7904": 0x803693b8,
		"Enemy::@7905": 0x803693c8,
		"Enemy::@7906": 0x803693d8,
		"@7906": 0x803693d8,
		"Enemy::@7907": 0x803693ec,
		"@7907": 0x803693ec,
		"Enemy::@7908": 0x80369400,
		"@7908": 0x80369400,
		"Enemy::@8294": 0x80369480,
		"@8294": 0x80369480,
		"Enemy::@8297": 0x803694a8,
		"Enemy::@8298": 0x803694b8,
		"@8298": 0x803694b8,
		"Enemy::@8299": 0x803694c4,
		"@8299": 0x803694c4,
		"Enemy::@8300": 0x803694d8,
		"@8300": 0x803694d8,
		"Enemy::@8301": 0x803694ec,
		"@8301": 0x803694ec,
		"Enemy::@8302": 0x80369500,
		"@8302": 0x80369500,
		"Enemy::@8303": 0x80369518,
		"Enemy::@8304": 0x80369524,
		"@8304": 0x80369524,
		"Enemy::@8305": 0x80369538,
		"@8305": 0x80369538,
		"Enemy::@8306": 0x8036954c,
		"@8306": 0x8036954c,
		"Enemy::@8307": 0x80369560,
		"@8307": 0x80369560,
		"Enemy::@2430": 0x80369650,
		"Enemy::@2478": 0x80369750,
		"@2478": 0x80369750,
		"Enemy::@2479": 0x8036975c,
		"Enemy::@2480": 0x80369768,
		"Enemy::@2481": 0x80369774,
		"Enemy::@2482": 0x80369780,
		"Enemy::@2483": 0x8036978c,
		"Enemy::@2484": 0x80369798,
		"Enemy::@2121": 0x80369924,
		"Enemy::nameKuriTevColorData": 0x80369a24,
		"nameKuriTevColorData": 0x80369a24,
		"Enemy::@4531": 0x80369c14,
		"Enemy::@2325": 0x80369c5c,
		"Enemy::@2565": 0x80369ca0,
		"Enemy::@5123": 0x80369f44,
		"Enemy::@5125": 0x80369f50,
		"Enemy::@5127": 0x80369f78,
		"Enemy::@2396": 0x80369ff8,
		"Enemy::@2398": 0x8036a004,
		"Enemy::@4947": 0x8036a134,
		"Enemy::@4961": 0x8036a1c4,
		"Enemy::@4964": 0x8036a1f4,
		"Enemy::@4966": 0x8036a208,
		"Enemy::@4968": 0x8036a218,
		"Enemy::@1604": 0x8036a2f0,
		"Enemy::@1605": 0x8036a320,
		"Enemy::@1606": 0x8036a358,
		"Enemy::@2252": 0x8036a3b0,
		"Enemy::@2253": 0x8036a3c4,
		"Enemy::@2370": 0x8036a3f8,
		"Enemy::@2373": 0x8036a494,
		"Enemy::@2112": 0x8036a50c,
		"Enemy::@3712": 0x8036a7b0,
		"Enemy::@9188": 0x8036ada4,
		"@9188": 0x8036ada4,
		"Enemy::@9189": 0x8036adb4,
		"@9189": 0x8036adb4,
		"Enemy::@9191": 0x8036add4,
		"@9191": 0x8036add4,
		"Enemy::@9192": 0x8036ade4,
		"@9192": 0x8036ade4,
		"Enemy::@9193": 0x8036adf4,
		"@9193": 0x8036adf4,
		"Enemy::@9194": 0x8036ae04,
		"@9194": 0x8036ae04,
		"Enemy::@9196": 0x8036ae1c,
		"@9196": 0x8036ae1c,
		"Enemy::@2346": 0x8036afe4,
		"Enemy::@5269": 0x8036b300,
		"Enemy::@5271": 0x8036b330,
		"Enemy::cTelesaColor": 0x8036b4cc,
		"cTelesaColor": 0x8036b4cc,
		"Enemy::@5411": 0x8036b7bc,
		"Enemy::@5414": 0x8036b7f8,
		"Enemy::@5415": 0x8036b810,
		"@5415": 0x8036b810,
		"Enemy::@5417": 0x8036b828,
		"Enemy::@2255": 0x8036b8b8,
		"Enemy::@2256": 0x8036b8f0,
		"Enemy::@2257": 0x8036b924,
		"Enemy::@7290": 0x8036ba1c,
		"@7290": 0x8036ba1c,
		"Enemy::@7429": 0x8036ba98,
		"@7429": 0x8036ba98,
		"Enemy::@8401": 0x8036bad0,
		"@8401": 0x8036bad0,
		"Enemy::@9114": 0x8036bb44,
		"@9114": 0x8036bb44,
		"Enemy::@9116": 0x8036bb58,
		"@9116": 0x8036bb58,
		"Enemy::@9117": 0x8036bb68,
		"@9117": 0x8036bb68,
		"Enemy::@9118": 0x8036bb7c,
		"@9118": 0x8036bb7c,
		"Enemy::@9120": 0x8036bb9c,
		"@9120": 0x8036bb9c,
		"Enemy::@9122": 0x8036bbac,
		"@9122": 0x8036bbac,
		"Enemy::@9124": 0x8036bbb8,
		"@9124": 0x8036bbb8,
		"Enemy::@9125": 0x8036bbc4,
		"@9125": 0x8036bbc4,
		"Enemy::@9126": 0x8036bbd0,
		"@9126": 0x8036bbd0,
		"Enemy::@9127": 0x8036bbe4,
		"@9127": 0x8036bbe4,
		"Enemy::@9129": 0x8036bc0c,
		"@9129": 0x8036bc0c,
		"Enemy::@9131": 0x8036bc1c,
		"@9131": 0x8036bc1c,
		"Enemy::@9133": 0x8036bc2c,
		"@9133": 0x8036bc2c,
		"Enemy::@9134": 0x8036bc40,
		"@9134": 0x8036bc40,
		"Enemy::@9135": 0x8036bc58,
		"@9135": 0x8036bc58,
		"Enemy::@9136": 0x8036bc6c,
		"@9136": 0x8036bc6c,
		"Enemy::@9137": 0x8036bc7c,
		"@9137": 0x8036bc7c,
		"Enemy::@9139": 0x8036bca4,
		"@9139": 0x8036bca4,
		"Enemy::@9141": 0x8036bcb4,
		"@9141": 0x8036bcb4,
		"Enemy::@9142": 0x8036bcc8,
		"@9142": 0x8036bcc8,
		"Enemy::@9144": 0x8036bcf0,
		"@9144": 0x8036bcf0,
		"Enemy::@9146": 0x8036bd04,
		"@9146": 0x8036bd04,
		"Enemy::@9148": 0x8036bd2c,
		"@9148": 0x8036bd2c,
		"Enemy::@9150": 0x8036bd3c,
		"@9150": 0x8036bd3c,
		"Enemy::@2233": 0x8036bd60,
		"Enemy::@2154": 0x8036bd7c,
		"Enemy::@2210": 0x8036bd90,
		"Enemy::@2211": 0x8036bdc0,
		"Enemy::@2212": 0x8036bdf8,
		"Enemy::@2213": 0x8036be2c,
		"Enemy::@3113": 0x8036c164,
		"Enemy::@5869": 0x8036c508,
		"Enemy::@5870": 0x8036c530,
		"Enemy::@5871": 0x8036c558,
		"Enemy::@5872": 0x8036c584,
		"Enemy::@5873": 0x8036c5b0,
		"Enemy::@7218": 0x8036c614,
		"@7218": 0x8036c614,
		"Enemy::@7220": 0x8036c628,
		"@7220": 0x8036c628,
		"Enemy::@7222": 0x8036c63c,
		"@7222": 0x8036c63c,
		"Enemy::@7223": 0x8036c650,
		"@7223": 0x8036c650,
		"Enemy::@7224": 0x8036c660,
		"@7224": 0x8036c660,
		"Enemy::@8315": 0x8036c6ec,
		"@8315": 0x8036c6ec,
		"Enemy::@8316": 0x8036c700,
		"@8316": 0x8036c700,
		"Enemy::@8317": 0x8036c714,
		"@8317": 0x8036c714,
		"Enemy::@8318": 0x8036c724,
		"@8318": 0x8036c724,
		"Enemy::@8320": 0x8036c74c,
		"@8320": 0x8036c74c,
		"Enemy::@8322": 0x8036c76c,
		"Enemy::@8325": 0x8036c790,
		"Enemy::@8327": 0x8036c7a0,
		"Enemy::@8329": 0x8036c7b4,
		"@8329": 0x8036c7b4,
		"Enemy::@8331": 0x8036c7d4,
		"Enemy::@8334": 0x8036c7f8,
		"Enemy::@8335": 0x8036c80c,
		"Enemy::@8336": 0x8036c820,
		"Enemy::@8338": 0x8036c834,
		"Enemy::@6087": 0x8036d718,
		"@6087": 0x8036d718,
		"Enemy::@6088": 0x8036d730,
		"@6088": 0x8036d730,
		"Enemy::@6089": 0x8036d740,
		"Enemy::@6091": 0x8036d754,
		"Enemy::@6093": 0x8036d77c,
		"Enemy::entry$2906": 0x8036d900,
		"entry$2906": 0x8036d900,
		"Enemy::@2110": 0x8036d98c,
		"Enemy::@7585": 0x8036de3c,
		"Enemy::@7586": 0x8036de4c,
		"@7586": 0x8036de4c,
		"Enemy::@7587": 0x8036de5c,
		"@7587": 0x8036de5c,
		"Enemy::@7589": 0x8036de7c,
		"@7589": 0x8036de7c,
		"Enemy::@7590": 0x8036de8c,
		"@7590": 0x8036de8c,
		"Enemy::@7593": 0x8036deac,
		"@7593": 0x8036deac,
		"Enemy::@7595": 0x8036dec0,
		"@7595": 0x8036dec0,
		"Enemy::@2150": 0x8036e2cc,
		"Enemy::@4484": 0x8036e98c,
		"Enemy::@4485": 0x8036e9a0,
		"Enemy::@5050": 0x8036eddc,
		"Enemy::@5053": 0x8036edfc,
		"Enemy::@2315": 0x8036ee1c,
		"Enemy::@2554": 0x8036ee30,
		"Enemy::@2555": 0x8036ee60,
		"Enemy::@3934": 0x8036f0d8,
		"Enemy::@3936": 0x8036f10c,
		"Enemy::@7630": 0x8036f1c8,
		"@7630": 0x8036f1c8,
		"Enemy::@7633": 0x8036f1ec,
		"@7633": 0x8036f1ec,
		"Enemy::@7634": 0x8036f1f8,
		"@7634": 0x8036f1f8,
		"Enemy::@7635": 0x8036f204,
		"@7635": 0x8036f204,
		"Enemy::@7636": 0x8036f210,
		"Enemy::@7637": 0x8036f21c,
		"Enemy::@7638": 0x8036f228,
		"Enemy::@7639": 0x8036f234,
		"Enemy::@7640": 0x8036f240,
		"Enemy::@7641": 0x8036f24c,
		"Enemy::@7642": 0x8036f258,
		"Enemy::@7643": 0x8036f264,
		"Enemy::@7644": 0x8036f270,
		"Enemy::@7645": 0x8036f27c,
		"Enemy::@7646": 0x8036f288,
		"Enemy::@7647": 0x8036f294,
		"Enemy::@7648": 0x8036f2a0,
		"Enemy::@7649": 0x8036f2ac,
		"Enemy::@7650": 0x8036f2b8,
		"Enemy::@7651": 0x8036f2c4,
		"Enemy::@7652": 0x8036f2d4,
		"@7652": 0x8036f2d4,
		"Enemy::@7677": 0x8036f674,
		"@7677": 0x8036f674,
		"Enemy::@8598": 0x8036f744,
		"@8598": 0x8036f744,
		"Enemy::@8599": 0x8036f754,
		"@8599": 0x8036f754,
		"Enemy::@8600": 0x8036f764,
		"@8600": 0x8036f764,
		"Enemy::@8601": 0x8036f774,
		"@8601": 0x8036f774,
		"Enemy::@8602": 0x8036f788,
		"@8602": 0x8036f788,
		"Enemy::@8603": 0x8036f79c,
		"@8603": 0x8036f79c,
		"Enemy::@8604": 0x8036f7a8,
		"@8604": 0x8036f7a8,
		"Enemy::@8605": 0x8036f7b8,
		"@8605": 0x8036f7b8,
		"Enemy::@8606": 0x8036f7c8,
		"@8606": 0x8036f7c8,
		"Enemy::@8607": 0x8036f7dc,
		"@8607": 0x8036f7dc,
		"Enemy::@8608": 0x8036f7ec,
		"@8608": 0x8036f7ec,
		"Enemy::@8609": 0x8036f7fc,
		"@8609": 0x8036f7fc,
		"Enemy::@8610": 0x8036f818,
		"@8610": 0x8036f818,
		"Enemy::@8611": 0x8036f830,
		"@8611": 0x8036f830,
		"Enemy::@8612": 0x8036f840,
		"@8612": 0x8036f840,
		"Enemy::@8613": 0x8036f854,
		"@8613": 0x8036f854,
		"Enemy::@8614": 0x8036f868,
		"@8614": 0x8036f868,
		"Enemy::@8615": 0x8036f87c,
		"@8615": 0x8036f87c,
		"Enemy::@9058": 0x8036f8b8,
		"@9058": 0x8036f8b8,
		"Enemy::@9060": 0x8036f8d4,
		"@9060": 0x8036f8d4,
		"Enemy::@9061": 0x8036f8e0,
		"@9061": 0x8036f8e0,
		"Enemy::@9062": 0x8036f8f0,
		"@9062": 0x8036f8f0,
		"Enemy::@5159": 0x8036ff64,
		"Enemy::@5780": 0x8036ffa4,
		"@5780": 0x8036ffa4,
		"Enemy::@5782": 0x8036ffd0,
		"@5782": 0x8036ffd0,
		"Enemy::@5784": 0x8036ffdc,
		"@5784": 0x8036ffdc,
		"Enemy::@6156": 0x80370160,
		"Enemy::@6158": 0x8037016c,
		"@6158": 0x8037016c,
		"Enemy::@6161": 0x8037018c,
		"@6161": 0x8037018c,
		"Enemy::@6169": 0x8037022c,
		"Enemy::@7954": 0x803707e8,
		"@7954": 0x803707e8,
		"Enemy::@7955": 0x80370810,
		"@7955": 0x80370810,
		"Enemy::@8097": 0x80370a44,
		"@8097": 0x80370a44,
		"Enemy::@8102": 0x80370a88,
		"@8102": 0x80370a88,
		"Enemy::@8104": 0x80370aac,
		"@8104": 0x80370aac,
		"Enemy::@8105": 0x80370ac4,
		"@8105": 0x80370ac4,
		"Enemy::@8106": 0x80370adc,
		"@8106": 0x80370adc,
		"Enemy::@8107": 0x80370af4,
		"@8107": 0x80370af4,
		"Enemy::@8109": 0x80370b20,
		"@8109": 0x80370b20,
		"Enemy::@8110": 0x80370b34,
		"@8110": 0x80370b34,
		"Enemy::@8111": 0x80370b44,
		"@8111": 0x80370b44,
		"Enemy::@8112": 0x80370b58,
		"@8112": 0x80370b58,
		"Enemy::@9004": 0x80370be0,
		"@9004": 0x80370be0,
		"Enemy::@2118": 0x803710ac,
		"Enemy::@2359": 0x80371128,
		"Enemy::@2701": 0x80371320,
		"Enemy::@4297": 0x803714f8,
		"@4297": 0x803714f8,
		"Enemy::@5348": 0x803719a4,
		"Enemy::@5349": 0x803719b0,
		"Enemy::@5350": 0x803719c0,
		"Enemy::@5351": 0x803719d0,
		"Enemy::@5353": 0x803719f4,
		"Enemy::@5354": 0x80371a04,
		"Enemy::@2261": 0x80371bb4,
		"Enemy::entry$2260": 0x80371bcc,
		"entry$2260": 0x80371bcc,
		"Enemy::@1597": 0x80371c48,
		"Enemy::@2029": 0x80371d08,
		"Enemy::@2031": 0x80371d18,
		"Enemy::@2004": 0x80371fe0,
		"Enemy::@2005": 0x80372010,
		"Enemy::@2006": 0x80372048,
		"Enemy::@2007": 0x8037207c,
		"Enemy::@2353": 0x803720ac,
		"Enemy::@2715": 0x80372120,
		"Enemy::@4364": 0x80372164,
		"Enemy::@4365": 0x80372178,
		"Enemy::@4833": 0x8037218c,
		"Enemy::@4834": 0x803721a0,
		"Enemy::@2220": 0x80372200,
		"Enemy::@2221": 0x80372230,
		"Enemy::@2222": 0x80372268,
		"Enemy::@2223": 0x8037229c,
		"Enemy::sBodyBckIndex$2891": 0x80372328,
		"sBodyBckIndex$2891": 0x80372328,
		"Enemy::sHeadBckIndex$2906": 0x80372370,
		"sHeadBckIndex$2906": 0x80372370,
		"Enemy::sHeadBtpIndex$2907": 0x803723b8,
		"sHeadBtpIndex$2907": 0x803723b8,
		"Enemy::sHeadBtkIndex$2908": 0x80372400,
		"sHeadBtkIndex$2908": 0x80372400,
		"Enemy::@1637": 0x80372498,
		"Enemy::@1639": 0x803724b0,
		"Enemy::@1641": 0x803724c4,
		"Enemy::@1643": 0x803724dc,
		"Enemy::@1645": 0x803724f0,
		"@1645": 0x803724f0,
		"Enemy::@1646": 0x80372504,
		"@1646": 0x80372504,
		"Enemy::@1648": 0x80372514,
		"@1648": 0x80372514,
		"Enemy::@1650": 0x80372528,
		"Enemy::@1652": 0x8037253c,
		"Enemy::@1654": 0x80372554,
		"@1654": 0x80372554,
		"Enemy::@1656": 0x8037256c,
		"@1656": 0x8037256c,
		"Enemy::@1657": 0x80372584,
		"Enemy::@1658": 0x80372598,
		"Enemy::@1660": 0x803725b0,
		"Enemy::@1661": 0x803725c4,
		"Enemy::@1662": 0x803725e0,
		"Enemy::@1666": 0x80372608,
		"Enemy::@1667": 0x8037261c,
		"Enemy::@1669": 0x8037262c,
		"Enemy::@1671": 0x8037263c,
		"Enemy::@1673": 0x8037265c,
		"Enemy::@1674": 0x80372674,
		"Enemy::@1675": 0x8037268c,
		"Enemy::@1676": 0x803726a0,
		"Enemy::@1677": 0x803726b4,
		"@1677": 0x803726b4,
		"Enemy::@1678": 0x803726c8,
		"@1678": 0x803726c8,
		"Enemy::@1679": 0x803726dc,
		"@1679": 0x803726dc,
		"Enemy::@1681": 0x803726f4,
		"Enemy::@1682": 0x80372708,
		"Enemy::@1684": 0x8037271c,
		"Enemy::@1686": 0x80372730,
		"Enemy::@1687": 0x80372748,
		"Enemy::@1778": 0x80372758,
		"Enemy::@1780": 0x80372768,
		"Enemy::@1786": 0x803727a4,
		"Enemy::@1788": 0x803727b8,
		"@1788": 0x803727b8,
		"Enemy::@1792": 0x803727e0,
		"@1792": 0x803727e0,
		"Enemy::@1793": 0x803727f4,
		"@1793": 0x803727f4,
		"Enemy::@1802": 0x8037286c,
		"Enemy::@1803": 0x80372880,
		"Enemy::@1805": 0x80372894,
		"@1805": 0x80372894,
		"Enemy::@1806": 0x803728a8,
		"Enemy::@1808": 0x803728b8,
		"Enemy::@1810": 0x803728c8,
		"Enemy::@1812": 0x803728dc,
		"@1812": 0x803728dc,
		"Enemy::@1814": 0x803728f0,
		"@1814": 0x803728f0,
		"Enemy::@1816": 0x80372908,
		"Enemy::@1818": 0x80372920,
		"Enemy::@1820": 0x80372938,
		"Enemy::@1821": 0x80372950,
		"@1821": 0x80372950,
		"Enemy::@1822": 0x80372968,
		"@1822": 0x80372968,
		"Enemy::@1824": 0x8037297c,
		"@1824": 0x8037297c,
		"Enemy::@1825": 0x80372990,
		"Enemy::@2560": 0x80372a64,
		"Enemy::@2434": 0x80373130,
		"@2434": 0x80373130,
		"Enemy::@2435": 0x80373160,
		"@2435": 0x80373160,
		"Enemy::@2436": 0x80373198,
		"@2436": 0x80373198,
		"Enemy::@2437": 0x803731cc,
		"Enemy::sSnortStepFrames": 0x803731f0,
		"sSnortStepFrames": 0x803731f0,
		"Enemy::entry$2836": 0x80373590,
		"entry$2836": 0x80373590,
		"Enemy::@3211": 0x803735c0,
		"Enemy::@2444": 0x803735f8,
		"Enemy::zangle$3575": 0x80373778,
		"zangle$3575": 0x80373778,
		"Enemy::@2122": 0x80373974,
		"Enemy::@2363": 0x803739b8,
		"Enemy::@2365": 0x80373a24,
		"Enemy::@1755": 0x80373ce0,
		"Enemy::@1756": 0x80373d10,
		"Enemy::@1757": 0x80373d48,
		"Enemy::@1758": 0x80373d7c,
		"Enemy::@1941": 0x80373dcc,
		"Enemy::@1942": 0x80373dfc,
		"Enemy::@1943": 0x80373e2c,
		"Enemy::@1948": 0x80373f24,
		"Enemy::@1949": 0x80373f54,
		"Enemy::@1950": 0x80373f80,
		"Enemy::@1951": 0x80373fac,
		"Enemy::@1952": 0x80373fd8,
		"Enemy::@1953": 0x80374004,
		"Enemy::@1954": 0x8037403c,
		"Enemy::@1956": 0x80374098,
		"Enemy::@2588": 0x80374300,
		"Enemy::@2589": 0x80374328,
		"Enemy::@3742": 0x80374464,
		"Enemy::entry$3295": 0x80374a20,
		"entry$3295": 0x80374a20,
		"Enemy::@3477": 0x80374b80,
		"Enemy::@2766": 0x80374d74,
		"Enemy::@3287": 0x80374f30,
		"Enemy::@1529": 0x803755c4,
		"@1529": 0x803755c4,
		"Enemy::@1608": 0x80375608,
		"Enemy::@1609": 0x80375640,
		"Enemy::@1610": 0x80375674,
		"Enemy::@2183": 0x803756e8,
		"Enemy::@2184": 0x80375710,
		"Enemy::@2185": 0x80375734,
		"Enemy::@2186": 0x8037575c,
		"Enemy::@2187": 0x80375784,
		"Enemy::@2188": 0x803757ac,
		"Enemy::@2189": 0x803757d4,
		"Enemy::@2190": 0x803757fc,
		"Enemy::@2191": 0x80375824,
		"Enemy::@2192": 0x80375848,
		"Enemy::@2193": 0x8037586c,
		"Enemy::@3773": 0x80375b34,
		"Enemy::@3555": 0x80375fd0,
		"Enemy::@3573": 0x80376090,
		"@unnamed@::cDropCoinNumTable": 0x803762f4,
		"cDropCoinNumTable": 0x803762f4,
		"Enemy::@3632": 0x803763d0,
		"Enemy::@4779": 0x8037647c,
		"Enemy::@1586": 0x80376510,
		"Enemy::@1587": 0x80376548,
		"Enemy::@1588": 0x8037657c,
		"Enemy::@2369": 0x803765a0,
		"Enemy::@2389": 0x803765e0,
		"@unnamed@::cJointNames": 0x80376634,
		"cJointNames": 0x80376634,
		"Enemy::@5696": 0x80376bc0,
		"@5696": 0x80376bc0,
		"Enemy::@5697": 0x80376bd0,
		"@5697": 0x80376bd0,
		"Enemy::@5699": 0x80376c04,
		"@5699": 0x80376c04,
		"Enemy::@5703": 0x80376c4c,
		"@5703": 0x80376c4c,
		"Enemy::@5706": 0x80376c94,
		"Enemy::@2015": 0x80377018,
		"Enemy::@2016": 0x80377048,
		"Enemy::@2017": 0x80377080,
		"Enemy::@1525": 0x803773e4,
		"Enemy::@1582": 0x803773f8,
		"Enemy::@1583": 0x80377428,
		"Enemy::@1584": 0x80377460,
		"Enemy::@2160": 0x803774b8,
		"Enemy::@2161": 0x803774c4,
		"Camera::@1873": 0x8039b3c0,
		"@1873": 0x8039b3c0,
		"Camera::@1874": 0x8039b3f0,
		"@1874": 0x8039b3f0,
		"Camera::@1875": 0x8039b428,
		"Camera::@1876": 0x8039b45c,
		"@1876": 0x8039b45c,
		"Camera::cDirtyFileName": 0x8039b480,
		"Camera::cDirtyTexName": 0x8039b4a4,
		"Camera::@1901": 0x8039b798,
		"@1901": 0x8039b798,
		"Camera::@1903": 0x8039b7a4,
		"@1903": 0x8039b7a4,
		"Camera::@1905": 0x8039b7b4,
		"@1905": 0x8039b7b4,
		"Camera::@1912": 0x8039b818,
		"Camera::@1915": 0x8039b844,
		"@1915": 0x8039b844,
		"Camera::@1917": 0x8039b85c,
		"Camera::@1919": 0x8039b874,
		"@1919": 0x8039b874,
		"Camera::@1921": 0x8039b88c,
		"@1921": 0x8039b88c,
		"Camera::@1941": 0x8039ba10,
		"Camera::@1943": 0x8039ba28,
		"Camera::@1944": 0x8039ba40,
		"Camera::@1946": 0x8039ba58,
		"Camera::@1948": 0x8039ba70,
		"Camera::@1957": 0x8039bae4,
		"Camera::@1959": 0x8039baf8,
		"Camera::@1961": 0x8039bb0c,
		"Camera::@1962": 0x8039bb20,
		"Camera::@1964": 0x8039bb34,
		"Camera::@1966": 0x8039bb44,
		"Camera::@1967": 0x8039bb54,
		"Camera::@1968": 0x8039bb68,
		"Camera::@1969": 0x8039bb7c,
		"Camera::@1970": 0x8039bb90,
		"Camera::@1971": 0x8039bba4,
		"Camera::@1972": 0x8039bbb8,
		"Camera::@1973": 0x8039bbc8,
		"Camera::@1974": 0x8039bbd8,
		"Camera::@1975": 0x8039bbf0,
		"Camera::@1976": 0x8039bc04,
		"Camera::@1977": 0x8039bc14,
		"Camera::@1988": 0x8039bcdc,
		"@1988": 0x8039bcdc,
		"Camera::@1989": 0x8039bcec,
		"Camera::@1994": 0x8039bd3c,
		"Camera::@1995": 0x8039bd4c,
		"Camera::@2003": 0x8039bde8,
		"Camera::@2004": 0x8039bdfc,
		"Camera::@2005": 0x8039be0c,
		"Camera::@2006": 0x8039be1c,
		"Camera::@2007": 0x8039be2c,
		"Camera::@2008": 0x8039be3c,
		"Camera::@2009": 0x8039be4c,
		"Camera::@2012": 0x8039be7c,
		"Camera::@2013": 0x8039be90,
		"Camera::@2014": 0x8039bea4,
		"Camera::@2015": 0x8039beb4,
		"Camera::@2016": 0x8039bec8,
		"Camera::@2017": 0x8039bedc,
		"Camera::@2021": 0x8039bf24,
		"Camera::@2022": 0x8039bf34,
		"Camera::@2023": 0x8039bf4c,
		"Camera::@2029": 0x8039bfbc,
		"Camera::@2030": 0x8039bfcc,
		"Camera::@2031": 0x8039bfdc,
		"Camera::@2032": 0x8039bfec,
		"Camera::@2033": 0x8039c000,
		"Camera::@2034": 0x8039c010,
		"Camera::@2035": 0x8039c028,
		"Camera::@2036": 0x8039c038,
		"Camera::@2037": 0x8039c048,
		"Camera::@2038": 0x8039c05c,
		"Camera::@2119": 0x8039c070,
		"Camera::@2120": 0x8039c08c,
		"Camera::@2122": 0x8039c098,
		"Camera::@2123": 0x8039c0a8,
		"Camera::@2127": 0x8039c0dc,
		"Camera::@2129": 0x8039c0f0,
		"Camera::@2130": 0x8039c108,
		"Camera::@2131": 0x8039c118,
		"Camera::@2135": 0x8039c148,
		"Camera::@2136": 0x8039c158,
		"Camera::@2138": 0x8039c168,
		"Camera::@2139": 0x8039c17c,
		"Camera::@2141": 0x8039c1a4,
		"Camera::@2142": 0x8039c1b8,
		"Camera::@2143": 0x8039c1d4,
		"Camera::@2144": 0x8039c1e8,
		"Camera::@2146": 0x8039c1fc,
		"Camera::@2147": 0x8039c214,
		"Camera::@2148": 0x8039c22c,
		"Camera::@2150": 0x8039c254,
		"Camera::@2151": 0x8039c268,
		"Camera::@2152": 0x8039c27c,
		"Camera::@2174": 0x8039c2b4,
		"Camera::@2175": 0x8039c2cc,
		"Camera::@2203": 0x8039c34c,
		"Camera::@2204": 0x8039c358,
		"Camera::@2206": 0x8039c364,
		"Camera::@2207": 0x8039c370,
		"Camera::@2208": 0x8039c37c,
		"Camera::@1632": 0x8039c478,
		"Camera::@2078": 0x8039c4d8,
		"Camera::@2079": 0x8039c4e4,
		"Camera::@2223": 0x8039c508,
		"Camera::@2224": 0x8039c514,
		"CPolarSubCamera::sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x8039c5e0,
		"sFixCameraPos$localstatic0$drawJetCoasterBalloonMessage_": 0x8039c5e0,
		"Camera::@1681": 0x8039c6d0,
		"Camera::@1682": 0x8039c6fc,
		"Camera::@1683": 0x8039c72c,
		"Camera::@1684": 0x8039c750,
		"Camera::@1685": 0x8039c760,
		"Camera::@1686": 0x8039c770,
		"Camera::@1687": 0x8039c784,
		"Camera::@1688": 0x8039c7b4,
		"Camera::@1689": 0x8039c7e8,
		"Camera::@1650": 0x8039c850,
		"Camera::@1535": 0x8039c898,
		"Camera::@1578": 0x8039ccf8,
		"Camera::@1579": 0x8039cd10,
		"Camera::@1580": 0x8039cd28,
		"Camera::@1581": 0x8039cd40,
		"Camera::@1582": 0x8039cd5c,
		"Camera::@1583": 0x8039cd78,
		"Camera::@1584": 0x8039cd90,
		"Camera::@1585": 0x8039cdac,
		"Camera::@1586": 0x8039cdc8,
		"Camera::@1587": 0x8039cde4,
		"Camera::@1588": 0x8039ce00,
		"Camera::@1589": 0x8039ce18,
		"Camera::@1590": 0x8039ce30,
		"Camera::@1591": 0x8039ce48,
		"Camera::@1592": 0x8039ce68,
		"Camera::@1597": 0x8039ceec,
		"Camera::@1598": 0x8039cf08,
		"Camera::@1599": 0x8039cf20,
		"Camera::@1600": 0x8039cf38,
		"Camera::@1601": 0x8039cf50,
		"Camera::@1602": 0x8039cf6c,
		"Camera::@1603": 0x8039cf84,
		"Camera::@1604": 0x8039cfa4,
		"Camera::@1605": 0x8039cfbc,
		"Camera::@1606": 0x8039cfd4,
		"Camera::@1607": 0x8039cff0,
		"Animal::@2233": 0x803662a0,
		"@unnamed@::cFishoidMdlNames": 0x803662d0,
		"cFishoidMdlNames": 0x803662d0,
		"Animal::@3202": 0x80366338,
		"Animal::@2337": 0x80366368,
		"Animal::@2338": 0x80366398,
		"Animal::@2340": 0x80366404,
		"Animal::@2543": 0x80366428,
		"Animal::entry$2542": 0x80366438,
		"entry$2542": 0x80366438,
		"Animal::@2573": 0x80366450,
		"Animal::@1562": 0x80366480,
		"Animal::@1563": 0x80366490,
		"Animal::@1565": 0x803664a0,
		"Animal::@1567": 0x803664b0,
		"Animal::@1569": 0x803664c4,
		"Animal::@1571": 0x803664d8,
		"Animal::@1573": 0x803664e8,
		"Animal::@1575": 0x803664fc,
		"Animal::@1577": 0x80366510,
		"Animal::@1940": 0x80366534,
		"Animal::@2018": 0x80366548,
		"Animal::@2019": 0x80366578,
		"Animal::@2020": 0x803665b0,
		"Animal::@2021": 0x803665e4,
		"Animal::@2904": 0x80366608,
		"Animal::@2905": 0x80366628,
		"Animal::@2906": 0x80366648,
		"Animal::@2907": 0x80366668,
		"@unnamed@::cRandomAnims": 0x80366688,
		"cRandomAnims": 0x80366688,
		"Animal::@2909": 0x8036669c,
		"@unnamed@::cColorTable": 0x803666a8,
		"Animal::entry$3023": 0x803666d8,
		"entry$3023": 0x803666d8,
		"Animal::@3452": 0x803666f0,
		"Animal::@3871": 0x80366704,
		"Animal::@3928": 0x80366718,
		"Animal::@3929": 0x80366724,
		"Animal::@3931": 0x80366730,
		"Animal::@3932": 0x80366740,
		"Animal::@3934": 0x80366750,
		"Animal::@3936": 0x80366760,
		"Animal::@3938": 0x80366770,
		"Animal::@3940": 0x80366780,
		"Animal::@3941": 0x80366790,
		"Animal::@3942": 0x803667a4,
		"Animal::@3943": 0x803667b8,
		"Animal::@3945": 0x803667cc,
		"Animal::@3947": 0x803667dc,
		"Animal::@3948": 0x803667ec,
		"Animal::@3949": 0x803667fc,
		"Animal::@3950": 0x80366808,
		"Animal::@3952": 0x80366818,
		"Animal::@3953": 0x80366828,
		"Animal::@1996": 0x80366858,
		"Animal::@1997": 0x80366888,
		"Animal::@1998": 0x803668c0,
		"Animal::@1999": 0x803668f4,
		"Animal::@2986": 0x80366918,
		"Animal::@2987": 0x80366928,
		"Animal::@2988": 0x80366938,
		"Animal::entry$2985": 0x8036694c,
		"Animal::@3447": 0x8036697c,
		"Animal::@3661": 0x8036698c,
		"Animal::@3662": 0x803669a0,
		"Animal::@3663": 0x803669b0,
		"Animal::@3665": 0x803669c0,
		"Animal::@3666": 0x803669d0,
		"Animal::@3670": 0x803669dc,
		"Animal::@3672": 0x803669ec,
		"Animal::@3674": 0x803669f8,
		"Animal::@3675": 0x80366a08,
		"Animal::@5081": 0x80366a18,
		"Animal::@2393": 0x80366b08,
		"Animal::@2394": 0x80366b18,
		"Animal::@2395": 0x80366b28,
		"@unnamed@::cButterflyMdlNames": 0x80366b38,
		"cButterflyMdlNames": 0x80366b38,
		"Animal::entry$2459": 0x80366b44,
		"entry$2459": 0x80366b44,
		"Animal::@2493": 0x80366b74,
		"Animal::@2594": 0x80366b84,
		"Animal::@2711": 0x80366b94,
		"MAnmSoundMario::__vt": 0x8039e2f0,
		"GC2D::@6908": 0x803b06f4,
		"GC2D::@7473": 0x803b0720,
		"GC2D::@3853": 0x803b07b4,
		"GC2D::@4210": 0x803b0b8c,
		"GC2D::@4593": 0x803b0db4,
		"GC2D::@7289": 0x803b0e8c,
		"GC2D::@7731": 0x803b0eac,
		"@7731": 0x803b0eac,
		"GC2D::@7728": 0x803b0ed4,
		"@7728": 0x803b0ed4,
		"GC2D::@2171": 0x803b1a20,
		"GC2D::@2173": 0x803b1a2c,
		"GC2D::@2175": 0x803b1a38,
		"GC2D::@2177": 0x803b1a44,
		"GC2D::@2180": 0x803b1a50,
		"GC2D::@2186": 0x803b1a74,
		"GC2D::@2189": 0x803b1a80,
		"GC2D::@2191": 0x803b1a8c,
		"GC2D::@2193": 0x803b1a98,
		"MoveBG::@5074": 0x803bf4b4,
		"System::title": 0x803cfe98,
		"title": 0x803cfe98,
		"System::comment": 0x803cfeb4,
		"comment": 0x803cfeb4,
		"Camera::@3715": 0x803d9bd0,
		"Camera::@3891": 0x803d9c9c,
		"Enemy::names$3265": 0x803a004c,
		"names$3265": 0x803a004c,
		"Enemy::bmdFileNames$3278": 0x803a0060,
		"bmdFileNames$3278": 0x803a0060,
		"Enemy::entry$2959": 0x803a040c,
		"entry$2959": 0x803a040c,
		"Enemy::entry$3041": 0x803a0d2c,
		"entry$3041": 0x803a0d2c,
		"Enemy::entry$3108": 0x803a0d44,
		"entry$3108": 0x803a0d44,
		"Enemy::entry$3118": 0x803a0d5c,
		"entry$3118": 0x803a0d5c,
		"Enemy::entry$3161": 0x803a0d8c,
		"entry$3161": 0x803a0d8c,
		"Enemy::entry$2940": 0x803a2370,
		"entry$2940": 0x803a2370,
		"Enemy::@6300": 0x803a35e0,
		"@6300": 0x803a35e0,
		"Enemy::entry$2985": 0x803a3ec4,
		"Enemy::entry$3395": 0x803a3edc,
		"entry$3395": 0x803a3edc,
		"Enemy::entry$3029": 0x803a4aa8,
		"entry$3029": 0x803a4aa8,
		"Enemy::table$3022": 0x803a6260,
		"table$3022": 0x803a6260,
		"Enemy::table$3034": 0x803a6290,
		"table$3034": 0x803a6290,
		"Enemy::table$3035": 0x803a62a8,
		"table$3035": 0x803a62a8,
		"Enemy::table$3037": 0x803a62d4,
		"table$3037": 0x803a62d4,
		"Enemy::table$3038": 0x803a62e8,
		"table$3038": 0x803a62e8,
		"Enemy::table$3039": 0x803a62fc,
		"table$3039": 0x803a62fc,
		"Enemy::table$3040": 0x803a6310,
		"table$3040": 0x803a6310,
		"Enemy::onetimeFilenames$3486": 0x803a6374,
		"onetimeFilenames$3486": 0x803a6374,
		"Enemy::loopFilenames$3500": 0x803a6390,
		"loopFilenames$3500": 0x803a6390,
		"Enemy::graphlist$2864": 0x803a712c,
		"graphlist$2864": 0x803a712c,
		"Enemy::entry$3103": 0x803a7448,
		"entry$3103": 0x803a7448,
		"Enemy::entry$3330": 0x803a7460,
		"entry$3330": 0x803a7460,
		"Enemy::entry$3142": 0x803a826c,
		"entry$3142": 0x803a826c,
		"Enemy::entry$3269": 0x803a8594,
		"entry$3269": 0x803a8594,
		"Enemy::manNameTable$3929": 0x803a85ac,
		"manNameTable$3929": 0x803a85ac,
		"Enemy::sCannonDomPartsJointTable$3045": 0x803a9490,
		"sCannonDomPartsJointTable$3045": 0x803a9490,
		"Enemy::entry$3117": 0x803a988c,
		"entry$3117": 0x803a988c,
		"Enemy::sEyePartsJointTable$3526": 0x803a98b0,
		"sEyePartsJointTable$3526": 0x803a98b0,
		"Enemy::sToothPartsJointTable$3537": 0x803a98c0,
		"sToothPartsJointTable$3537": 0x803a98c0,
		"Enemy::sCollisionJointTable$3569": 0x803a98e0,
		"sCollisionJointTable$3569": 0x803a98e0,
		"Enemy::sCollisionFileTable$3573": 0x803a98f0,
		"sCollisionFileTable$3573": 0x803a98f0,
		"Enemy::entry$3038": 0x803aa444,
		"entry$3038": 0x803aa444,
		"Enemy::entry$2762": 0x803aa940,
		"entry$2762": 0x803aa940,
		"Enemy::entry$2896": 0x803aa958,
		"entry$2896": 0x803aa958,
		"Enemy::jIndexTable$3048": 0x803aa97c,
		"jIndexTable$3048": 0x803aa97c,
		"Enemy::entry$3090": 0x803aa98c,
		"entry$3090": 0x803aa98c,
		"Enemy::entry$2822": 0x803abe70,
		"entry$2822": 0x803abe70,
		"Enemy::jntidx$3419": 0x803aca84,
		"jntidx$3419": 0x803aca84,
		"Enemy::@4439": 0x803acae4,
		"Enemy::@4829": 0x803acb10,
		"Enemy::entry$2800": 0x803ad084,
		"entry$2800": 0x803ad084,
		"Enemy::entry$2814": 0x803ad750,
		"entry$2814": 0x803ad750,
		"Enemy::entry$3228": 0x803af6ac,
		"entry$3228": 0x803af6ac,
		"Enemy::entry$2932": 0x803af944,
		"entry$2932": 0x803af944,
		"GC2D::scDolpicNewsDolpic8_Aa1": 0x803b03a8,
		"scDolpicNewsDolpic8_Aa1": 0x803b03a8,
		"GC2D::scDolpicNewsDolpic8_Aa2": 0x803b03b8,
		"scDolpicNewsDolpic8_Aa2": 0x803b03b8,
		"GC2D::scDolpicNewsDolpic8_Aa3": 0x803b03cc,
		"scDolpicNewsDolpic8_Aa3": 0x803b03cc,
		"GC2D::scDolpicNewsDolpic8_Aa4": 0x803b03dc,
		"scDolpicNewsDolpic8_Aa4": 0x803b03dc,
		"GC2D::scDolpicNewsDolpic8_Ab1": 0x803b03e8,
		"scDolpicNewsDolpic8_Ab1": 0x803b03e8,
		"GC2D::scDolpicNewsDolpic8_Ab2": 0x803b03f8,
		"scDolpicNewsDolpic8_Ab2": 0x803b03f8,
		"GC2D::scDolpicNewsDolpic8_Ab3": 0x803b040c,
		"scDolpicNewsDolpic8_Ab3": 0x803b040c,
		"GC2D::scDolpicNewsDolpic8_Ab4": 0x803b041c,
		"scDolpicNewsDolpic8_Ab4": 0x803b041c,
		"GC2D::scDolpicNewsDolpic8_Ac1": 0x803b0428,
		"scDolpicNewsDolpic8_Ac1": 0x803b0428,
		"GC2D::scDolpicNewsDolpic8_Ac2": 0x803b0434,
		"scDolpicNewsDolpic8_Ac2": 0x803b0434,
		"GC2D::scDolpicNewsDolpic8_Ac3": 0x803b0444,
		"scDolpicNewsDolpic8_Ac3": 0x803b0444,
		"GC2D::scDolpicNewsDolpic8_Ba1": 0x803b0450,
		"scDolpicNewsDolpic8_Ba1": 0x803b0450,
		"GC2D::scDolpicNewsDolpic8_Ba2": 0x803b0464,
		"scDolpicNewsDolpic8_Ba2": 0x803b0464,
		"GC2D::scDolpicNewsDolpic8_Ba3": 0x803b047c,
		"scDolpicNewsDolpic8_Ba3": 0x803b047c,
		"GC2D::scDolpicNewsDolpic8_Ba4": 0x803b0490,
		"scDolpicNewsDolpic8_Ba4": 0x803b0490,
		"GC2D::scDolpicNewsDolpic8_Bb1": 0x803b04a0,
		"scDolpicNewsDolpic8_Bb1": 0x803b04a0,
		"GC2D::scDolpicNewsDolpic8_Bb2": 0x803b04b4,
		"scDolpicNewsDolpic8_Bb2": 0x803b04b4,
		"GC2D::scDolpicNewsDolpic8_Bb3": 0x803b04cc,
		"scDolpicNewsDolpic8_Bb3": 0x803b04cc,
		"GC2D::scDolpicNewsDolpic8_Bb4": 0x803b04e0,
		"scDolpicNewsDolpic8_Bb4": 0x803b04e0,
		"GC2D::scDolpicNewsDolpic8_Bc1": 0x803b04f0,
		"scDolpicNewsDolpic8_Bc1": 0x803b04f0,
		"GC2D::scDolpicNewsDolpic8_Bc2": 0x803b0500,
		"scDolpicNewsDolpic8_Bc2": 0x803b0500,
		"GC2D::scDolpicNewsDolpic8_Bc3": 0x803b0514,
		"scDolpicNewsDolpic8_Bc3": 0x803b0514,
		"GC2D::scDolpicNewsDolpic8_Bc4": 0x803b0524,
		"scDolpicNewsDolpic8_Bc4": 0x803b0524,
		"GC2D::scDolpicNewsDolpic8_Ca1": 0x803b0530,
		"scDolpicNewsDolpic8_Ca1": 0x803b0530,
		"GC2D::scDolpicNewsDolpic8_Ca2": 0x803b0540,
		"scDolpicNewsDolpic8_Ca2": 0x803b0540,
		"GC2D::scDolpicNewsDolpic8_Ca3": 0x803b0554,
		"scDolpicNewsDolpic8_Ca3": 0x803b0554,
		"GC2D::scDolpicNewsDolpic8_Ca4": 0x803b0564,
		"scDolpicNewsDolpic8_Ca4": 0x803b0564,
		"GC2D::scDolpicNewsDolpic8_Cb1": 0x803b0570,
		"scDolpicNewsDolpic8_Cb1": 0x803b0570,
		"GC2D::scDolpicNewsDolpic8_Cb2": 0x803b0580,
		"scDolpicNewsDolpic8_Cb2": 0x803b0580,
		"GC2D::scDolpicNewsDolpic8_Cb3": 0x803b0594,
		"scDolpicNewsDolpic8_Cb3": 0x803b0594,
		"GC2D::scDolpicNewsDolpic8_Cb4": 0x803b05a4,
		"scDolpicNewsDolpic8_Cb4": 0x803b05a4,
		"GC2D::scDolpicNewsDolpic8_Cc1": 0x803b05b0,
		"scDolpicNewsDolpic8_Cc1": 0x803b05b0,
		"GC2D::scDolpicNewsDolpic8_Cc2": 0x803b05bc,
		"scDolpicNewsDolpic8_Cc2": 0x803b05bc,
		"GC2D::scDolpicNewsDolpic8_Cc3": 0x803b05cc,
		"scDolpicNewsDolpic8_Cc3": 0x803b05cc,
		"GC2D::scDolpicNewsDolpic8_Da1": 0x803b05d8,
		"scDolpicNewsDolpic8_Da1": 0x803b05d8,
		"GC2D::scDolpicNewsDolpic8_Da2": 0x803b05e4,
		"scDolpicNewsDolpic8_Da2": 0x803b05e4,
		"GC2D::scDolpicNewsDolpic8_Da3": 0x803b05f4,
		"scDolpicNewsDolpic8_Da3": 0x803b05f4,
		"GC2D::scDolpicNewsDolpic8_Db1": 0x803b0600,
		"scDolpicNewsDolpic8_Db1": 0x803b0600,
		"GC2D::scDolpicNewsDolpic8_Db2": 0x803b060c,
		"scDolpicNewsDolpic8_Db2": 0x803b060c,
		"GC2D::scDolpicNewsDolpic8_Db3": 0x803b061c,
		"scDolpicNewsDolpic8_Db3": 0x803b061c,
		"GC2D::scDolpicNewsDolpic8_Dc2": 0x803b0628,
		"scDolpicNewsDolpic8_Dc2": 0x803b0628,
		"GC2D::@2647": 0x803b1434,
		"GC2D::strDispProg": 0x803b1510,
		"strDispProg": 0x803b1510,
		"GC2D::strSetProg": 0x803b1538,
		"strSetProg": 0x803b1538,
		"GC2D::strSetInter": 0x803b15ac,
		"strSetInter": 0x803b15ac,
		"GC2D::@2195": 0x803b1aa4,
		"GC2D::boundtable$268": 0x803b16b8,
		"boundtable$268": 0x803b16b8,
		"GC2D::drawpath_table_NTSC": 0x803b16f0,
		"drawpath_table_NTSC": 0x803b16f0,
		"GC2D::drawpath_table_PAL": 0x803b1834,
		"drawpath_table_PAL": 0x803b1834,
		"GC2D::@1004": 0x803b1978,
		"@1004": 0x803b1978,
		"Map::@3484": 0x803b206c,
		"MoveBG::item_names$2995": 0x803b9240,
		"item_names$2995": 0x803b9240,
		"MoveBG::@4305": 0x803b98f0,
		"TWatermelonStatic::__vt": 0x803bf660,
		"NPC::sCameraNames$2617": 0x803c9978,
		"sCameraNames$2617": 0x803c9978,
		"Strategic::@3446": 0x803ca2c8,
		"Player::@5864": 0x803cd5a0,
		"Player::@5723": 0x803cd668,
		"Player::@6690": 0x803cd690,
		"@6690": 0x803cd690,
		"Player::@6689": 0x803cd6b4,
		"@6689": 0x803cd6b4,
		"Player::param$3386": 0x803cd718,
		"param$3386": 0x803cd718,
		"Player::param$3389": 0x803cd72c,
		"param$3389": 0x803cd72c,
		"Player::param$3392": 0x803cd740,
		"param$3392": 0x803cd740,
		"Player::param$3395": 0x803cd754,
		"param$3395": 0x803cd754,
		"Player::param$3400": 0x803cd768,
		"param$3400": 0x803cd768,
		"Player::param$3403": 0x803cd77c,
		"param$3403": 0x803cd77c,
		"System::@3617": 0x803cf4d8,
		"System::@4380": 0x803cf52c,
		"System::@2823": 0x803cf590,
		"MSStageCubeFadeDouble::__vt": 0x803d01bc,
		"JKRFile::__vt": 0x803d0248,
		"JKRAramArchive::__vt": 0x803d0268,
		"JKRAramHeap::__vt": 0x803d02b0,
		"JKRAram::sMessageBuffer": 0x803d02c0,
		"JKRAram::sMessageQueue": 0x803d02d0,
		"JKRAram::__vt": 0x803d02f0,
		"JKRArchive::__vt": 0x803d0300,
		"JKRCompArchive::__vt": 0x803d0348,
		"JKRDisposer::__vt": 0x803d0390,
		"JKRDvdArchive::__vt": 0x803d03a0,
		"JKRDvdFile::__vt": 0x803d03e8,
		"JKRExpHeap::__vt": 0x803d0410,
		"JKRArcFinder::__vt": 0x803d0460,
		"JKRFileLoader::__vt": 0x803d0470,
		"JKRHeap::__vt": 0x803d04b0,
		"JKRMemArchive::__vt": 0x803d0500,
		"JKRSolidHeap::__vt": 0x803d0548,
		"JKRStdHeap::__vt": 0x803d0598,
		"JKRThread::__vt": 0x803d05e8,
		"JSURandomOutputStream::__vt": 0x803d05f8,
		"JSUOutputStream::__vt": 0x803d0620,
		"JSURandomInputStream::__vt": 0x803d0638,
		"JSUInputStream::__vt": 0x803d065c,
		"JSUMemoryOutputStream::__vt": 0x803d0678,
		"JSUMemoryInputStream::__vt": 0x803d06a0,
		"JSUFileInputStream::__vt": 0x803d06c8,
		"JUTException::sMessageQueue": 0x803d06f0,
		"JUTException::sCpuExpName": 0x803d0710,
		"sCpuExpName": 0x803d0710,
		"JUTException::__vt": 0x803d0750,
		"JUTDirectPrint::sAsciiTable": 0x803d0760,
		"sAsciiTable": 0x803d0760,
		"JUTDirectPrint::sFontData": 0x803d07e0,
		"sFontData": 0x803d07e0,
		"JUTDirectPrint::sFontData2": 0x803d08e0,
		"sFontData2": 0x803d08e0,
		"JUTFont::__vt": 0x803d0a18,
		"JSystem::channel_mask": 0x803d0a50,
		"channel_mask": 0x803d0a50,
		"JUTGamePad::__vt": 0x803d0a60,
		"J2DPane::__vt": 0x803d0a70,
		"J2DPicture::__vt": 0x803d0aa0,
		"J2DPrint::__vt": 0x803d0b30,
		"J2DSetScreen::__vt": 0x803d0b90,
		"J2DScreen::__vt": 0x803d0bc4,
		"J2DTextBox::__vt": 0x803d0bf8,
		"J2DWindow::__vt": 0x803d0c28,
		"J2DWindow::Texture::__vt": 0x803d0c54,
		"JSystem::j3dDefaultTransformInfo": 0x803d0c60,
		"j3dDefaultTransformInfo": 0x803d0c60,
		"JSystem::j3dDefaultMtx": 0x803d0c80,
		"j3dDefaultMtx": 0x803d0c80,
		"JSystem::PSMulUnit01": 0x803d0cb0,
		"PSMulUnit01": 0x803d0cb0,
		"J3DSkinDeform::__vt": 0x803d0cb8,
		"J3DJoint::__vt": 0x803d0cc8,
		"J3DMtxCalcMayaAnm::__vt": 0x803d0cf0,
		"J3DMtxCalcMaya::__vt": 0x803d0d44,
		"J3DMtxCalcSoftimage::__vt": 0x803d0d88,
		"J3DMtxCalcBasic::__vt": 0x803d0dcc,
		"J3DMtxCalcAnm::__vt": 0x803d0e10,
		"J3DPEBlockFull::__vt": 0x803d0e40,
		"J3DIndBlockFull::__vt": 0x803d0ea4,
		"J3DTevBlock16::__vt": 0x803d0eec,
		"J3DTevBlock4::__vt": 0x803d0f88,
		"J3DTevBlock2::__vt": 0x803d1024,
		"J3DTevBlock1::__vt": 0x803d10c0,
		"J3DTexGenBlockBasic::__vt": 0x803d115c,
		"J3DColorBlockLightOn::__vt": 0x803d11ac,
		"J3DColorBlockLightOff::__vt": 0x803d1210,
		"J3DPEBlockXlu::__vt": 0x803d1274,
		"J3DPEBlockTexEdge::__vt": 0x803d12d8,
		"J3DPEBlockOpa::__vt": 0x803d133c,
		"J3DPEBlock::__vt": 0x803d13a0,
		"J3DIndBlockNull::__vt": 0x803d1404,
		"J3DIndBlock::__vt": 0x803d144c,
		"J3DTevBlock::__vt": 0x803d1494,
		"J3DTexGenBlock::__vt": 0x803d1530,
		"J3DColorBlock::__vt": 0x803d1580,
		"J3DModel::__vt": 0x803d1634,
		"J3DModelData::__vt": 0x803d1650,
		"J3DNode::__vt": 0x803d1660,
		"JSystem::@952": 0x803d1688,
		"@952": 0x803d1688,
		"JSystem::@953": 0x803d1694,
		"@953": 0x803d1694,
		"JSystem::@954": 0x803d16a0,
		"@954": 0x803d16a0,
		"J3DShapeMtx::mtxLoadPipeline": 0x803d16b8,
		"mtxLoadPipeline": 0x803d16b8,
		"J3DShapeDraw::__vt": 0x803d16e8,
		"J3DShapeMtxMulti::__vt": 0x803d16f4,
		"J3DShapeMtxDL::__vt": 0x803d1714,
		"J3DShapeMtx::__vt": 0x803d1734,
		"J3DAnmColorKey::__vt": 0x803d1770,
		"J3DAnmColor::__vt": 0x803d1780,
		"J3DAnmColorFull::__vt": 0x803d1790,
		"J3DAnmVtxColorKey::__vt": 0x803d17a0,
		"J3DAnmVtxColor::__vt": 0x803d17b0,
		"J3DAnmVtxColorFull::__vt": 0x803d17c0,
		"J3DAnmClusterKey::__vt": 0x803d17d0,
		"J3DAnmCluster::__vt": 0x803d17e0,
		"J3DAnmClusterFull::__vt": 0x803d17f0,
		"J3DAnmTransformKey::__vt": 0x803d1800,
		"J3DAnmTransform::__vt": 0x803d1814,
		"J3DAnmTransformFull::__vt": 0x803d1824,
		"J3DAnmBase::__vt": 0x803d1834,
		"J3DModelLoader_v21::__vt": 0x803d1840,
		"J3DModelLoader_v26::__vt": 0x803d1868,
		"J3DTexture::__vt": 0x803d1890,
		"J3DModelLoader::__vt": 0x803d189c,
		"J3DAnmKeyLoader_v15::__vt": 0x803d18c8,
		"J3DAnmFullLoader_v15::__vt": 0x803d18d8,
		"J3DAnmLoader::__vt": 0x803d18e8,
		"J3DAnmVisibilityFull::__vt": 0x803d18f8,
		"J3DAnmTexPattern::__vt": 0x803d1904,
		"J3DAnmTevRegKey::__vt": 0x803d1910,
		"J3DAnmTextureSRTKey::__vt": 0x803d191c,
		"J2DGrafContext::__vt": 0x803d1928,
		"JKRDecomp::sMessageBuffer": 0x803d1950,
		"JKRDecomp::sMessageQueue": 0x803d1960,
		"JKRDecomp::__vt": 0x803d1980,
		"J2DOrthoGraph::__vt": 0x803d1990,
		"J3DVertexBuffer::__vt": 0x803d19b8,
		"J3DShapePacket::__vt": 0x803d19c8,
		"J3DMatPacket::__vt": 0x803d19e0,
		"J3DDrawPacket::__vt": 0x803d19f8,
		"J3DCallBackPacket::__vt": 0x803d1a10,
		"J3DPacket::__vt": 0x803d1a28,
		"JSystem::j3dDefaultLightInfo": 0x803d1a84,
		"j3dDefaultLightInfo": 0x803d1a84,
		"JSystem::j3dDefaultTexCoordInfo": 0x803d1ab8,
		"j3dDefaultTexCoordInfo": 0x803d1ab8,
		"JSystem::j3dDefaultTexMtxInfo": 0x803d1ad8,
		"j3dDefaultTexMtxInfo": 0x803d1ad8,
		"JSystem::j3dDefaultIndTexMtxInfo": 0x803d1b3c,
		"j3dDefaultIndTexMtxInfo": 0x803d1b3c,
		"JSystem::j3dDefaultTevStageInfo": 0x803d1b58,
		"j3dDefaultTevStageInfo": 0x803d1b58,
		"JSystem::j3dDefaultIndTevStageInfo": 0x803d1b6c,
		"j3dDefaultIndTevStageInfo": 0x803d1b6c,
		"JSystem::j3dDefaultFogInfo": 0x803d1b78,
		"j3dDefaultFogInfo": 0x803d1b78,
		"JSystem::j3dDefaultNBTScaleInfo": 0x803d1ba4,
		"j3dDefaultNBTScaleInfo": 0x803d1ba4,
		"JSystem::@815": 0x803d1bc4,
		"@815": 0x803d1bc4,
		"JSystem::@816": 0x803d1bd0,
		"@816": 0x803d1bd0,
		"JSystem::@817": 0x803d1bdc,
		"@817": 0x803d1bdc,
		"JSystem::@818": 0x803d1be8,
		"@818": 0x803d1be8,
		"JSystem::@819": 0x803d1bf4,
		"@819": 0x803d1bf4,
		"J3DDrawBuffer::sortFuncTable": 0x803d1c00,
		"sortFuncTable": 0x803d1c00,
		"JSystem::@820": 0x803d1c48,
		"@820": 0x803d1c48,
		"JSystem::@821": 0x803d1c54,
		"@821": 0x803d1c54,
		"J3DDrawBuffer::drawFuncTable": 0x803d1c60,
		"drawFuncTable": 0x803d1c60,
		"J3DMaterialAnm::__vt": 0x803d1c78,
		"J3DTexNoAnm::__vt": 0x803d1c88,
		"JKRAramBlock::__vt": 0x803d1c98,
		"JKRAramStream::sMessageBuffer": 0x803d1ca8,
		"JKRAramStream::sMessageQueue": 0x803d1cb8,
		"JKRAramStream::__vt": 0x803d1cd8,
		"JUTResFont::saoAboutEncoding_": 0x803d1ce8,
		"JUTResFont::__vt": 0x803d1cf4,
		"JUTRomFont::saoAboutEncoding_": 0x803d1d30,
		"JUTRomFont::__vt": 0x803d1d48,
		"JSystem::@320": 0x803d1d88,
		"JSystem::c2r$795": 0x803d1ddc,
		"c2r$795": 0x803d1ddc,
		"JUTConsole::__vt": 0x803d1df0,
		"JDrama::TActor::__vt": 0x803d1e00,
		"JDrama::TOrthoProj::__vt": 0x803d1ea0,
		"JDrama::TLookAtCamera::__vt": 0x803d1f74,
		"JDrama::TPolarCamera::__vt": 0x803d2068,
		"JDrama::TCamera::__vt": 0x803d2144,
		"JDrama::TSmplChara::__vt": 0x803d2208,
		"JDrama::TDirector::__vt": 0x803d2230,
		"JDrama::TDisplay::__vt": 0x803d22a0,
		"JDrama::TDrawBufObj::__vt": 0x803d22b0,
		"JDrama::TDStageDisp::__vt": 0x803d22d8,
		"JDrama::TDStageGroup::__vt": 0x803d2300,
		"JDrama::TEfbCtrlTex::__vt": 0x803d2330,
		"JDrama::TEfbCtrlDisp::__vt": 0x803d2354,
		"JDrama::TEfbCtrl::__vt": 0x803d2378,
		"JDrama::TFrmGXSet::__vt": 0x803d23a0,
		"JDrama::TLightMap::__vt": 0x803d23c8,
		"JDrama::TAmbAry::__vt": 0x803d23ec,
		"JDrama::TAmbColor::__vt": 0x803d2410,
		"JDrama::TIdxLight::__vt": 0x803d2474,
		"JDrama::TLightAry::__vt": 0x803d2510,
		"JDrama::TLight::__vt": 0x803d2534,
		"JDrama::TNameRef::__vt": 0x803d25d0,
		"JDrama::TNameRefPtrListT<JDrama::TNameRef,JDrama::TNameRef>::__vt": 0x803d25f0,
		"JDrama::TNameRefGen::__vt": 0x803d2610,
		"JDrama::TPlacement::__vt": 0x803d2620,
		"JDrama::TScreen::__vt": 0x803d2648,
		"TCamConnecter::__vt": 0x803d266c,
		"JDrama::TSmJ3DAct::__vt": 0x803d2690,
		"JDrama::TSmJ3DScn::__vt": 0x803d2730,
		"JDrama::TViewConnecter::__vt": 0x803d2760,
		"JDrama::TViewport::__vt": 0x803d2788,
		"JALSeModData<JALSeModVolFunk>::__vt": 0x803d27b0,
		"JALSeModData<JALSeModPitFunk>::__vt": 0x803d27c0,
		"JALSeModData<JALSeModEffFunk>::__vt": 0x803d27d0,
		"JALSeModData<JALSeModVolDist>::__vt": 0x803d27e0,
		"JALSeModData<JALSeModEffDist>::__vt": 0x803d27f0,
		"JALSeModData<JALSeModPitDist>::__vt": 0x803d2800,
		"JALSeModData<JALSeModVolFGrp>::__vt": 0x803d2810,
		"JALSeModData<JALSeModPitFGrp>::__vt": 0x803d2820,
		"JALSeModData<JALSeModEffFGrp>::__vt": 0x803d2830,
		"JALSeModData<JALSeModVolDGrp>::__vt": 0x803d2840,
		"JALSeModData<JALSeModEffDGrp>::__vt": 0x803d2850,
		"JALSeModData<JALSeModPitDGrp>::__vt": 0x803d2860,
		"JALSeModPitDGrp::__vt": 0x803d2870,
		"JALSeModDataGrp<JALSeModPitDGrp>::__vt": 0x803d2880,
		"JALSeModEffDGrp::__vt": 0x803d2890,
		"JALSeModDataGrp<JALSeModEffDGrp>::__vt": 0x803d28a0,
		"JALSeModVolDGrp::__vt": 0x803d28b0,
		"JALSeModDataGrp<JALSeModVolDGrp>::__vt": 0x803d28c0,
		"JALSeModEffFGrp::__vt": 0x803d28d0,
		"JALSeModDataGrp<JALSeModEffFGrp>::__vt": 0x803d28e0,
		"JALSeModPitFGrp::__vt": 0x803d28f0,
		"JALSeModDataGrp<JALSeModPitFGrp>::__vt": 0x803d2900,
		"JALSeModVolFGrp::__vt": 0x803d2910,
		"JALSeModDataGrp<JALSeModVolFGrp>::__vt": 0x803d2920,
		"JALSeModPitDist::__vt": 0x803d2930,
		"JALSeModEffDist::__vt": 0x803d2940,
		"JALSeModVolDist::__vt": 0x803d2950,
		"JALSeModEffFunk::__vt": 0x803d2960,
		"JALSeModPitFunk::__vt": 0x803d2970,
		"JALSeModVolFunk::__vt": 0x803d2980,
		"JAIAnimeSound::__vt": 0x803d2990,
		"JSystem::@547": 0x803d29a0,
		"@547": 0x803d29a0,
		"JAIBasic::__vt": 0x803d29c4,
		"JAIConst::dummyZeroVec": 0x803d2a00,
		"dummyZeroVec": 0x803d2a00,
		"JAIConst::nullInfoData2": 0x803d2a0c,
		"nullInfoData2": 0x803d2a0c,
		"JAIConst::sCInfos_0": 0x803d2a2c,
		"sCInfos_0": 0x803d2a2c,
		"JAInter::StreamLib::filter_table": 0x803d2a50,
		"filter_table": 0x803d2a50,
		"JAInter::StreamLib::table4": 0x803d2a90,
		"table4": 0x803d2a90,
		"JAISound::__vt": 0x803d2ab0,
		"JASystem::BankMgr::OSC_RELEASE_TABLE": 0x803d2ae8,
		"OSC_RELEASE_TABLE": 0x803d2ae8,
		"JASystem::BankMgr::OSC_ENV": 0x803d2af4,
		"OSC_ENV": 0x803d2af4,
		"JASystem::TBasicBank::__vt": 0x803d2b10,
		"JASystem::TBank::__vt": 0x803d2b24,
		"JASystem::TBasicInst::__vt": 0x803d2b38,
		"JASystem::TInst::__vt": 0x803d2b50,
		"JASystem::TWaveHandle::__vt": 0x803d2b68,
		"JASystem::TBasicWaveBank::TWaveHandle::__vt": 0x803d2b7c,
		"JASystem::TBasicWaveBank::TWaveGroup::__vt": 0x803d2b90,
		"JASystem::WaveArcLoader::TObject::__vt": 0x803d2ba4,
		"JASystem::TBasicWaveBank::__vt": 0x803d2bb8,
		"JASystem::TWaveBank::__vt": 0x803d2bcc,
		"JASystem::TInstEffect::__vt": 0x803d2be0,
		"JASystem::TDrumSet::__vt": 0x803d2bf0,
		"JASystem::TInstRand::__vt": 0x803d2c08,
		"JASystem::TInstSense::__vt": 0x803d2c18,
		"JASystem::TSimpleWaveBank::TWaveHandle::__vt": 0x803d2c28,
		"JASystem::TSimpleWaveBank::__vt": 0x803d2c3c,
		"JASystem::WaveArcLoader::sCurrentDir": 0x803d2c70,
		"sCurrentDir": 0x803d2c70,
		"JASystem::Driver::calc_sw_table": 0x803d2cb0,
		"calc_sw_table": 0x803d2cb0,
		"JSystem::@325": 0x803d2d24,
		"@325": 0x803d2d24,
		"JASystem::Driver::C5BASE_PITCHTABLE": 0x803d2d60,
		"C5BASE_PITCHTABLE": 0x803d2d60,
		"JASystem::history": 0x803d34a0,
		"history": 0x803d34a0,
		"JASystem::DSPInterface::SEND_TABLE": 0x803d34c8,
		"SEND_TABLE": 0x803d34c8,
		"JSystem::connect_table$341": 0x803d34e0,
		"connect_table$341": 0x803d34e0,
		"JASystem::Driver::FORCE_STOP_TABLE": 0x803d34f8,
		"FORCE_STOP_TABLE": 0x803d34f8,
		"JASystem::Dvd::audioRootPath": 0x803d3508,
		"audioRootPath": 0x803d3508,
		"JASystem::HardStream::rootDir": 0x803d3528,
		"rootDir": 0x803d3528,
		"JSystem::@550": 0x803d3548,
		"@550": 0x803d3548,
		"JASystem::Player::CUTOFF_TO_IIR_TABLE": 0x803d3568,
		"CUTOFF_TO_IIR_TABLE": 0x803d3568,
		"JASystem::Player::s_key_table": 0x803d3968,
		"s_key_table": 0x803d3968,
		"JASystem::Player::sAdsrDef": 0x803d3a68,
		"sAdsrDef": 0x803d3a68,
		"JASystem::Player::sEnvelopeDef": 0x803d3a80,
		"sEnvelopeDef": 0x803d3a80,
		"JASystem::Player::sVibratoDef": 0x803d3a98,
		"sVibratoDef": 0x803d3a98,
		"JASystem::Player::sTremoroDef": 0x803d3ab0,
		"sTremoroDef": 0x803d3ab0,
		"JASystem::Player::sAdsTable": 0x803d3ac8,
		"sAdsTable": 0x803d3ac8,
		"JASystem::Player::sRelTable": 0x803d3ae0,
		"sRelTable": 0x803d3ae0,
		"JASystem::Player::sVibTable": 0x803d3aec,
		"sVibTable": 0x803d3aec,
		"JASystem::Player::sTreTable": 0x803d3b10,
		"sTreTable": 0x803d3b10,
		"JASystem::TTrack::sOscTable": 0x803d3b38,
		"sOscTable": 0x803d3b38,
		"JSystem::@982": 0x803d3b40,
		"@982": 0x803d3b40,
		"JSystem::@1324": 0x803d3bb8,
		"@1324": 0x803d3bb8,
		"JSystem::@139": 0x803d3c18,
		"@139": 0x803d3c18,
		"JSystem::@140": 0x803d3c24,
		"@140": 0x803d3c24,
		"JSystem::@141": 0x803d3c30,
		"@141": 0x803d3c30,
		"JSystem::@142": 0x803d3c3c,
		"@142": 0x803d3c3c,
		"JSystem::@143": 0x803d3c48,
		"@143": 0x803d3c48,
		"JSystem::@146": 0x803d3c6c,
		"@146": 0x803d3c6c,
		"JSystem::@147": 0x803d3c78,
		"@147": 0x803d3c78,
		"JSystem::@152": 0x803d3cb4,
		"JSystem::@153": 0x803d3cc0,
		"JSystem::@154": 0x803d3ccc,
		"@154": 0x803d3ccc,
		"JSystem::@155": 0x803d3cd8,
		"@155": 0x803d3cd8,
		"JSystem::@156": 0x803d3ce4,
		"JSystem::@157": 0x803d3cf0,
		"JSystem::@158": 0x803d3cfc,
		"JSystem::@159": 0x803d3d08,
		"JSystem::@161": 0x803d3d20,
		"@161": 0x803d3d20,
		"JSystem::@162": 0x803d3d2c,
		"@162": 0x803d3d2c,
		"JSystem::@163": 0x803d3d38,
		"@163": 0x803d3d38,
		"JSystem::@168": 0x803d3d74,
		"JSystem::@169": 0x803d3d80,
		"JSystem::@170": 0x803d3d8c,
		"JSystem::@171": 0x803d3d98,
		"@171": 0x803d3d98,
		"JSystem::@172": 0x803d3da4,
		"@172": 0x803d3da4,
		"JSystem::@173": 0x803d3db0,
		"@173": 0x803d3db0,
		"JSystem::@174": 0x803d3dbc,
		"JSystem::@175": 0x803d3dc8,
		"JSystem::@176": 0x803d3dd4,
		"@176": 0x803d3dd4,
		"JSystem::@180": 0x803d3e04,
		"@180": 0x803d3e04,
		"JSystem::@181": 0x803d3e10,
		"@181": 0x803d3e10,
		"JSystem::@182": 0x803d3e1c,
		"JSystem::@183": 0x803d3e28,
		"JSystem::@184": 0x803d3e34,
		"@184": 0x803d3e34,
		"JSystem::@185": 0x803d3e40,
		"@185": 0x803d3e40,
		"JASystem::TSeqParser::sCmdPList": 0x803d3e7c,
		"sCmdPList": 0x803d3e7c,
		"J3DMaterialTable::__vt": 0x803d4180,
		"JSystem::@2833": 0x803d4190,
		"JSystem::@3104": 0x803d41ac,
		"JSystem::@2535": 0x803d41d8,
		"JPADragField::__vt": 0x803d41f8,
		"JPARandomField::__vt": 0x803d4210,
		"JPAConvectionField::__vt": 0x803d4228,
		"JPAVortexField::__vt": 0x803d4240,
		"JPANewtonField::__vt": 0x803d4258,
		"JPAMagnetField::__vt": 0x803d4270,
		"JPAAirField::__vt": 0x803d4288,
		"JPAGravityField::__vt": 0x803d42a0,
		"JPABaseField::__vt": 0x803d42b8,
		"JPAParticle::__vt": 0x803d42d0,
		"JPABaseParticle::__vt": 0x803d4328,
		"JSystem::@2383": 0x803d4380,
		"JSystem::@2382": 0x803d43ac,
		"JPADrawCalcEmitterVisitor::__vt": 0x803d43d8,
		"JPADrawCalcParticleVisitor::__vt": 0x803d43e8,
		"JPADrawExecParticleVisitor::__vt": 0x803d43f8,
		"JPADrawExecEmitterVisitor::__vt": 0x803d4408,
		"JPADrawCalcChildScaleOut::__vt": 0x803d4418,
		"JPADrawCalcChildAlphaOut::__vt": 0x803d4428,
		"JPADrawCalcAlphaFlickMultSin::__vt": 0x803d4438,
		"JPADrawCalcAlphaFlickAddSin::__vt": 0x803d4448,
		"JPADrawCalcAlphaFlickNrmSin::__vt": 0x803d4458,
		"JPADrawCalcAlpha::__vt": 0x803d4468,
		"JPADrawCalcColorCopyFromEmitter::__vt": 0x803d4478,
		"JPADrawCalcScaleAnmTimingReverseY::__vt": 0x803d4488,
		"JPADrawCalcScaleAnmTimingReverseX::__vt": 0x803d4498,
		"JPADrawCalcScaleAnmTimingRepeatY::__vt": 0x803d44a8,
		"JPADrawCalcScaleAnmTimingRepeatX::__vt": 0x803d44b8,
		"JPADrawCalcScaleAnmTimingNormal::__vt": 0x803d44c8,
		"JPADrawCalcScaleCopyX2Y::__vt": 0x803d44d8,
		"JPADrawCalcScaleYBySpeed::__vt": 0x803d44e8,
		"JPADrawCalcScaleXBySpeed::__vt": 0x803d44f8,
		"JPADrawCalcScaleY::__vt": 0x803d4508,
		"JPADrawCalcScaleX::__vt": 0x803d4518,
		"JPADrawExecCallBack::__vt": 0x803d4528,
		"JPADrawCalcTextureAnmIndexRandom::__vt": 0x803d454c,
		"JPADrawCalcTextureAnmIndexMerge::__vt": 0x803d4570,
		"JPADrawCalcTextureAnmIndexReverse::__vt": 0x803d4594,
		"JPADrawCalcTextureAnmIndexRepeat::__vt": 0x803d45b8,
		"JPADrawCalcTextureAnmIndexNormal::__vt": 0x803d45dc,
		"JPADrawCalcColorAnmFrameRandom::__vt": 0x803d4600,
		"JPADrawCalcColorAnmFrameMerge::__vt": 0x803d4624,
		"JPADrawCalcColorAnmFrameReverse::__vt": 0x803d4648,
		"JPADrawCalcColorAnmFrameRepeat::__vt": 0x803d466c,
		"JPADrawCalcColorAnmFrameNormal::__vt": 0x803d4690,
		"JPADrawCalcColorEnv::__vt": 0x803d46b4,
		"JPADrawCalcColorPrm::__vt": 0x803d46d8,
		"JPADrawExecRegisterColorChildPE::__vt": 0x803d46fc,
		"JPADrawExecRegisterColorEmitterE::__vt": 0x803d470c,
		"JPADrawExecRegisterColorEmitterP::__vt": 0x803d471c,
		"JPADrawExecRegisterColorEmitterPE::__vt": 0x803d472c,
		"JPADrawExecStripeCross::__vt": 0x803d473c,
		"JPADrawExecStripe::__vt": 0x803d474c,
		"JPADrawExecLine::__vt": 0x803d475c,
		"JPADrawExecPoint::__vt": 0x803d476c,
		"JPADrawExecRotationCross::__vt": 0x803d477c,
		"JPADrawExecRotation::__vt": 0x803d478c,
		"JPADrawExecDirBillBoard::__vt": 0x803d479c,
		"JPADrawExecRotDirectionalCross::__vt": 0x803d47ac,
		"JPADrawExecDirectionalCross::__vt": 0x803d47bc,
		"JPADrawExecRotDirectional::__vt": 0x803d47cc,
		"JPADrawExecDirectional::__vt": 0x803d47dc,
		"JPADrawExecRotYBillBoard::__vt": 0x803d47ec,
		"JPADrawExecYBillBoard::__vt": 0x803d47fc,
		"JPADrawExecRotBillBoard::__vt": 0x803d480c,
		"JPADrawExecBillBoard::__vt": 0x803d481c,
		"JPADrawExecRegisterPrmAEnv::__vt": 0x803d482c,
		"JPADrawExecRegisterPrmCEnv::__vt": 0x803d483c,
		"JPADrawExecRegisterEnvColorAnm::__vt": 0x803d484c,
		"JPADrawExecRegisterPrmAlphaAnm::__vt": 0x803d485c,
		"JPADrawExecRegisterPrmColorAnm::__vt": 0x803d486c,
		"JPADrawExecSetLineWidth::__vt": 0x803d487c,
		"JPADrawExecSetPointSize::__vt": 0x803d488c,
		"JPADrawExecLoadTexture::__vt": 0x803d489c,
		"JPADrawExecLoadDefaultTexture::__vt": 0x803d48c0,
		"JPADrawExecSetTexMtx::__vt": 0x803d48d0,
		"JPADrawExecGenIdtMtx::__vt": 0x803d48f4,
		"JPADrawExecGenTexMtx0::__vt": 0x803d4904,
		"JPADrawExecGenPrjTexMtx::__vt": 0x803d4914,
		"JPADrawExecGenPrjMtx::__vt": 0x803d4924,
		"JPADrawExecLoadExTex::__vt": 0x803d4934,
		"JPAExTexShape::__vt": 0x803d4948,
		"JPADataBlock::__vt": 0x803d4954,
		"JPAKeyFrameAnime::__vt": 0x803d4960,
		"JPAEmitterLoader::__vt": 0x803d496c,
		"JPAEmitterLoader_v10::__vt": 0x803d4978,
		"JPABaseShape::stBlendMode": 0x803d4988,
		"stBlendMode": 0x803d4988,
		"JPABaseShape::stBlendFactor": 0x803d4998,
		"stBlendFactor": 0x803d4998,
		"JPABaseShape::stLogicOp": 0x803d49c0,
		"stLogicOp": 0x803d49c0,
		"JPABaseShape::stCompare": 0x803d4a00,
		"stCompare": 0x803d4a00,
		"JPABaseShape::stAlphaOp": 0x803d4a20,
		"stAlphaOp": 0x803d4a20,
		"JPABaseShape::__vt": 0x803d4a30,
		"JPAExtraShape::__vt": 0x803d4a40,
		"JPASweepShape::__vt": 0x803d4a50,
		"JPATexture::__vt": 0x803d4a60,
		"JStage::TAmbientLight::__vt": 0x803d4a70,
		"JStage::TCamera::__vt": 0x803d4aa8,
		"JStage::TActor::__vt": 0x803d4b30,
		"JStage::TLight::__vt": 0x803d4b98,
		"JStage::TObject::__vt": 0x803d4bf8,
		"JStage::TSystem::__vt": 0x803d4c28,
		"MSL_C.PPCEABI.bare.H::__files": 0x803d6960,
		"__files": 0x803d6960,
		"MSL_C.PPCEABI.bare.H::@1009": 0x803d6a38,
		"@1009": 0x803d6a38,
		"MSL_C.PPCEABI.bare.H::@1066": 0x803d6abc,
		"@1066": 0x803d6abc,
		"MSL_C.PPCEABI.bare.H::@1186": 0x803d6b40,
		"@1186": 0x803d6b40,
		"MSL_C.PPCEABI.bare.H::@1185": 0x803d6c10,
		"@1185": 0x803d6c10,
		"MSL_C.PPCEABI.bare.H::@410": 0x803d6c58,
		"@410": 0x803d6c58,
		"MSL_C.PPCEABI.bare.H::__float_nan": 0x803d6ca0,
		"__float_nan": 0x803d6ca0,
		"MSL_C.PPCEABI.bare.H::__float_huge": 0x803d6ca4,
		"__float_huge": 0x803d6ca4,
		"MSL_C.PPCEABI.bare.H::__four_over_pi_m1": 0x803d6ca8,
		"__four_over_pi_m1": 0x803d6ca8,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTable": 0x803d6cb8,
		"gTRKDispatchTable": 0x803d6cb8,
		"TRK_MINNOW_DOLPHIN::@175": 0x803d6d40,
		"TRK_MINNOW_DOLPHIN::@214": 0x803d6d5c,
		"TRK_MINNOW_DOLPHIN::gTRKRestoreFlags": 0x803d6d78,
		"gTRKRestoreFlags": 0x803d6d78,
		"TRK_MINNOW_DOLPHIN::gTRKExceptionStatus": 0x803d6d84,
		"gTRKExceptionStatus": 0x803d6d84,
		"TRK_MINNOW_DOLPHIN::gTRKStepStatus": 0x803d6d94,
		"gTRKStepStatus": 0x803d6d94,
		"TRK_MINNOW_DOLPHIN::TRK_ISR_OFFSETS": 0x803d6da8,
		"TRK_ISR_OFFSETS": 0x803d6da8,
		"TRK_MINNOW_DOLPHIN::gDBCommTable": 0x803d6de8,
		"gDBCommTable": 0x803d6de8,
		"db::@7": 0x803d6e08,
		"@7": 0x803d6e08,
		"os::@84": 0x803d6e20,
		"os::@85": 0x803d6e40,
		"@85": 0x803d6e40,
		"os::@86": 0x803d6e58,
		"@86": 0x803d6e58,
		"os::@87": 0x803d6e64,
		"@87": 0x803d6e64,
		"os::@88": 0x803d6e70,
		"@88": 0x803d6e70,
		"os::@89": 0x803d6e80,
		"@89": 0x803d6e80,
		"os::__OSExceptionLocations": 0x803d6f08,
		"__OSExceptionLocations": 0x803d6f08,
		"os::@130": 0x803d6f44,
		"os::@131": 0x803d6f60,
		"@131": 0x803d6f60,
		"os::@132": 0x803d6f90,
		"@132": 0x803d6f90,
		"os::@133": 0x803d6fc0,
		"os::@352": 0x803d6fe0,
		"@352": 0x803d6fe0,
		"os::@353": 0x803d7004,
		"@353": 0x803d7004,
		"os::@354": 0x803d703c,
		"os::@355": 0x803d7064,
		"os::@356": 0x803d70b4,
		"@356": 0x803d70b4,
		"os::@357": 0x803d70f4,
		"os::@358": 0x803d712c,
		"os::@359": 0x803d7178,
		"@359": 0x803d7178,
		"os::@360": 0x803d71ac,
		"os::@361": 0x803d71ec,
		"@361": 0x803d71ec,
		"os::@362": 0x803d7228,
		"@362": 0x803d7228,
		"os::@363": 0x803d7270,
		"os::@364": 0x803d72d0,
		"os::@383": 0x803d72fc,
		"@383": 0x803d72fc,
		"os::@384": 0x803d7310,
		"@384": 0x803d7310,
		"os::@385": 0x803d7324,
		"os::@386": 0x803d7340,
		"os::@387": 0x803d7354,
		"@387": 0x803d7354,
		"os::@388": 0x803d7364,
		"os::DSPInitCode": 0x803d7378,
		"DSPInitCode": 0x803d7378,
		"os::@97": 0x803d7568,
		"os::@98": 0x803d7588,
		"os::@110": 0x803d75a4,
		"os::@111": 0x803d75c0,
		"os::@112": 0x803d75dc,
		"@112": 0x803d75dc,
		"os::@113": 0x803d75f4,
		"@113": 0x803d75f4,
		"os::@59": 0x803d7628,
		"@59": 0x803d7628,
		"os::@60": 0x803d766c,
		"os::@61": 0x803d769c,
		"os::@62": 0x803d76cc,
		"@62": 0x803d76cc,
		"os::@63": 0x803d76fc,
		"os::@64": 0x803d7710,
		"os::@65": 0x803d7734,
		"@65": 0x803d7734,
		"os::@66": 0x803d7748,
		"os::@67": 0x803d7764,
		"@67": 0x803d7764,
		"os::@68": 0x803d7778,
		"@68": 0x803d7778,
		"os::@70": 0x803d77c0,
		"@70": 0x803d77c0,
		"os::@74": 0x803d77dc,
		"@74": 0x803d77dc,
		"os::@10": 0x803d7800,
		"@10": 0x803d7800,
		"os::@11": 0x803d7818,
		"@11": 0x803d7818,
		"os::@12": 0x803d7840,
		"@12": 0x803d7840,
		"os::@30": 0x803d785c,
		"os::@31": 0x803d787c,
		"os::@33": 0x803d7894,
		"os::@34": 0x803d78c8,
		"os::@35": 0x803d78d8,
		"os::@36": 0x803d7938,
		"os::@37": 0x803d7984,
		"os::@38": 0x803d79e8,
		"os::@39": 0x803d7a48,
		"os::@40": 0x803d7a68,
		"os::@41": 0x803d7a88,
		"os::@42": 0x803d7aa4,
		"os::@43": 0x803d7adc,
		"@43": 0x803d7adc,
		"os::HankakuToCode": 0x803d7b20,
		"HankakuToCode": 0x803d7b20,
		"os::Zenkaku2Code": 0x803d7ca0,
		"Zenkaku2Code": 0x803d7ca0,
		"os::InterruptPrioTable": 0x803d8630,
		"InterruptPrioTable": 0x803d8630,
		"os::ResetFunctionInfo": 0x803d8660,
		"os::YearDays": 0x803d8670,
		"YearDays": 0x803d8670,
		"os::LeapYearDays": 0x803d86a0,
		"LeapYearDays": 0x803d86a0,
		"dvd::@117": 0x803d86d0,
		"dvd::@138": 0x803d8798,
		"dvd::@237": 0x803d87d0,
		"dvd::@263": 0x803d8804,
		"@263": 0x803d8804,
		"dvd::@269": 0x803d8834,
		"dvd::@309": 0x803d885c,
		"dvd::@340": 0x803d8898,
		"dvd::@341": 0x803d8900,
		"dvd::@342": 0x803d8958,
		"@342": 0x803d8958,
		"dvd::@373": 0x803d89b4,
		"@373": 0x803d89b4,
		"dvd::@374": 0x803d8a18,
		"@374": 0x803d8a18,
		"dvd::@375": 0x803d8a68,
		"@375": 0x803d8a68,
		"dvd::@13": 0x803d8ac0,
		"@13": 0x803d8ac0,
		"dvd::@14": 0x803d8ad8,
		"dvd::@15": 0x803d8ae4,
		"dvd::@16": 0x803d8b00,
		"dvd::@293": 0x803d8b0c,
		"dvd::@331": 0x803d8b2c,
		"@331": 0x803d8b2c,
		"dvd::@835": 0x803d8b6c,
		"@835": 0x803d8b6c,
		"dvd::@936": 0x803d8ba0,
		"@936": 0x803d8ba0,
		"dvd::ErrorTable": 0x803d8bd8,
		"ErrorTable": 0x803d8bd8,
		"dvd::@36": 0x803d8c20,
		"dvd::@37": 0x803d8c3c,
		"dvd::@38": 0x803d8c54,
		"dvd::@39": 0x803d8c68,
		"dvd::@42": 0x803d8c7c,
		"vi::timing": 0x803d8c90,
		"timing": 0x803d8c90,
		"vi::taps": 0x803d8dc0,
		"taps": 0x803d8dc0,
		"vi::@92": 0x803d8df4,
		"vi::@336": 0x803d8e4c,
		"@336": 0x803d8e4c,
		"vi::@337": 0x803d8e78,
		"@337": 0x803d8e78,
		"vi::@338": 0x803d8ea4,
		"@338": 0x803d8ea4,
		"vi::@339": 0x803d8ed0,
		"vi::@340": 0x803d8efc,
		"vi::@341": 0x803d8f28,
		"pad::ResetFunctionInfo": 0x803d8f58,
		"dsp::@16": 0x803d8f68,
		"dsp::@17": 0x803d8f88,
		"dsp::@18": 0x803d8f94,
		"dsp::@264": 0x803d8fa0,
		"@264": 0x803d8fa0,
		"dsp::@265": 0x803d8fc0,
		"@265": 0x803d8fc0,
		"dsp::@266": 0x803d8ff0,
		"@266": 0x803d8ff0,
		"dsp::@267": 0x803d9020,
		"@267": 0x803d9020,
		"dsp::@268": 0x803d9050,
		"@268": 0x803d9050,
		"dsp::@269": 0x803d9080,
		"dsp::@292": 0x803d90b0,
		"card::ResetFunctionInfo": 0x803d90e0,
		"card::SectorSizeTable": 0x803d9260,
		"SectorSizeTable": 0x803d9260,
		"card::LatencyTable": 0x803d9280,
		"LatencyTable": 0x803d9280,
		"gx::@189": 0x803d9308,
		"gx::@256": 0x803d9370,
		"gx::@302": 0x803d93d8,
		"gx::@329": 0x803d941c,
		"gx::@393": 0x803d9460,
		"@393": 0x803d9460,
		"gx::@499": 0x803d94a4,
		"@499": 0x803d94a4,
		"gx::@498": 0x803d94c0,
		"@498": 0x803d94c0,
		"gx::GXNtsc480IntDf": 0x803d9518,
		"GXNtsc480IntDf": 0x803d9518,
		"gx::GXNtsc480Int": 0x803d9554,
		"GXNtsc480Int": 0x803d9554,
		"gx::GXMpal480IntDf": 0x803d9590,
		"GXMpal480IntDf": 0x803d9590,
		"gx::GXPal528IntDf": 0x803d95cc,
		"GXPal528IntDf": 0x803d95cc,
		"gx::GXEurgb60Hz480IntDf": 0x803d9608,
		"GXEurgb60Hz480IntDf": 0x803d9608,
		"gx::@92": 0x803d9648,
		"gx::@168": 0x803d9830,
		"gx::c2r$71": 0x803d9870,
		"c2r$71": 0x803d9870,
		"gx::p2f$194": 0x803d9898,
		"p2f$194": 0x803d9898,
		"gx::@242": 0x803d98b8,
		"@242": 0x803d98b8,
		"gx::@241": 0x803d9914,
		"gd::@121": 0x803d99a8,
		"gd::@207": 0x803d9a10,
		"@207": 0x803d9a10,
		"gd::c2r$382": 0x803d9a58,
		"c2r$382": 0x803d9a58,
		"si::Si": 0x803d9a68,
		"Si": 0x803d9a68,
		"si::Type": 0x803d9a7c,
		"si::@456": 0x803d9a8c,
		"@456": 0x803d9a8c,
		"si::@458": 0x803d9a98,
		"@458": 0x803d9a98,
		"si::@459": 0x803d9aa8,
		"@459": 0x803d9aa8,
		"si::@460": 0x803d9ab8,
		"@460": 0x803d9ab8,
		"si::@461": 0x803d9ac8,
		"si::@462": 0x803d9ad4,
		"@462": 0x803d9ad4,
		"si::@463": 0x803d9ae4,
		"si::@464": 0x803d9af8,
		"@464": 0x803d9af8,
		"si::@465": 0x803d9b0c,
		"@465": 0x803d9b0c,
		"si::@466": 0x803d9b20,
		"@466": 0x803d9b20,
		"si::@467": 0x803d9b2c,
		"@467": 0x803d9b2c,
		"si::XYNTSC": 0x803d9b38,
		"XYNTSC": 0x803d9b38,
		"si::XYPAL": 0x803d9b68,
		"XYPAL": 0x803d9b68,
		"si::@16": 0x803d9b98,
		"THPPlayer::VolumeTable": 0x8039e998,
		"VolumeTable": 0x8039e998,
		"TDLColorTexQuad::__vt": 0x803cab08,
		"TDLTexQuad::__vt": 0x803cab28,
		"TSilhouette::__vt": 0x803cab48,
		"TLightWithDBSetManager::__vt": 0x803cab70,
		"TIndirectLightWithDBSet::__vt": 0x803cab94,
		"TMapObjectLightWithDBSet::__vt": 0x803cabbc,
		"TObjectLightWithDBSet::__vt": 0x803cabe4,
		"TPlayerLightWithDBSet::__vt": 0x803cac0c,
		"TLightWithDBSet::__vt": 0x803cac34,
		"TLightDrawBuffer::__vt": 0x803cac5c,
		"TLightMario::__vt": 0x803cac84,
		"TLightShadow::__vt": 0x803cacb8,
		"TLightCommon::__vt": 0x803cacec,
		"MarioUtil::@1431": 0x803cad20,
		"MarioUtil::@1210": 0x803cad38,
		"MarioUtil::atntable": 0x803cad48,
		"atntable": 0x803cad48,
		"TParamT<JGeometry::TVec3<float><float>>::__vt": 0x803cb550,
		"TMtxSwingRZReverseXZ::__vt": 0x803cb55c,
		"TParamVec::__vt": 0x803cb568,
		"TMtxSwingRZ::__vt": 0x803cb574,
		"TMtxTimeLag::__vt": 0x803cb580,
		"TMtxEffectBase::__vt": 0x803cb58c,
		"TScreenTexture::__vt": 0x803cb598,
		"TAfterEffect::__vt": 0x803cb5bc,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::vl$localstatic0$makeDL": 0x803cb5ec,
		"vl$localstatic0$makeDL": 0x803cb5ec,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::fl$localstatic1$makeDL": 0x803cb5fc,
		"fl$localstatic1$makeDL": 0x803cb5fc,
		"TMBindShadowManager::__vt": 0x803cb61c,
		"TMBindShadowManager::TSetup5$2216ShadowUtil_cpp::__vt": 0x803cb694,
		"TMBindShadowManager::TSetup4$2207ShadowUtil_cpp::__vt": 0x803cb6a4,
		"TMBindShadowManager::TSetup3$2195ShadowUtil_cpp::__vt": 0x803cb6b4,
		"TMBindShadowManager::TSetup2$2190ShadowUtil_cpp::__vt": 0x803cb6c4,
		"TMBindShadowManager::TCylinder$2171ShadowUtil_cpp::__vt": 0x803cb6d4,
		"TMBindShadowManager::TSetup1$2172ShadowUtil_cpp::__vt": 0x803cb6e4,
		"MarioUtil::IdentityMtx": 0x803cb710,
		"IdentityMtx": 0x803cb710,
		"MarioUtil::rumbleFrame_00": 0x803cb740,
		"rumbleFrame_00": 0x803cb740,
		"MarioUtil::rumblePower_00": 0x803cb76c,
		"rumblePower_00": 0x803cb76c,
		"MarioUtil::rumbleFrame_01": 0x803cb798,
		"rumbleFrame_01": 0x803cb798,
		"MarioUtil::rumblePower_01": 0x803cb7f8,
		"rumblePower_01": 0x803cb7f8,
		"MarioUtil::rumbleFrame_04": 0x803cb858,
		"rumbleFrame_04": 0x803cb858,
		"MarioUtil::rumblePower_04": 0x803cb874,
		"rumblePower_04": 0x803cb874,
		"MarioUtil::rumbleFrame_05": 0x803cb890,
		"rumbleFrame_05": 0x803cb890,
		"MarioUtil::rumblePower_05": 0x803cb8e4,
		"rumblePower_05": 0x803cb8e4,
		"MarioUtil::rumbleFrame_06": 0x803cb938,
		"rumbleFrame_06": 0x803cb938,
		"MarioUtil::rumblePower_06": 0x803cb960,
		"rumblePower_06": 0x803cb960,
		"MarioUtil::rumbleFrame_07": 0x803cb988,
		"rumbleFrame_07": 0x803cb988,
		"MarioUtil::rumblePower_07": 0x803cb9d8,
		"rumblePower_07": 0x803cb9d8,
		"MarioUtil::rumbleFrame_08": 0x803cba28,
		"rumbleFrame_08": 0x803cba28,
		"MarioUtil::rumblePower_08": 0x803cba3c,
		"rumblePower_08": 0x803cba3c,
		"MarioUtil::rumbleFrame_09": 0x803cba50,
		"rumbleFrame_09": 0x803cba50,
		"MarioUtil::rumblePower_09": 0x803cba60,
		"rumblePower_09": 0x803cba60,
		"MarioUtil::rumbleFrame_19": 0x803cba70,
		"rumbleFrame_19": 0x803cba70,
		"MarioUtil::rumblePower_19": 0x803cba84,
		"rumblePower_19": 0x803cba84,
		"MarioUtil::rumbleFrame_23": 0x803cba98,
		"rumbleFrame_23": 0x803cba98,
		"MarioUtil::rumblePower_23": 0x803cbbcc,
		"rumblePower_23": 0x803cbbcc,
		"MarioUtil::rumbleFrame_24": 0x803cbd00,
		"rumbleFrame_24": 0x803cbd00,
		"MarioUtil::rumblePower_24": 0x803cbd94,
		"rumblePower_24": 0x803cbd94,
		"MarioUtil::channelDataTbl": 0x803cbe28,
		"channelDataTbl": 0x803cbe28,
		"MarioUtil::_info": 0x803cbf58,
		"_info": 0x803cbf58,
		"TGDLStatic::__vt": 0x803cc040,
		"TGDLStatic::TGDLSentinel::__vt": 0x803cc050,
		"Koga::ToolData::__vt": 0x803cc060,
		"M3DUtil::@1411": 0x803cc070,
		"M3UMtxCalcSIAnmBlendQuat::__vt": 0x803cc07c,
		"M3UModel::__vt": 0x803cc0c0,
		"M3UModelCommon::__vt": 0x803cc0e4,
		"MActorAnmEach<J3DAnmClusterKey>::__vt": 0x803cc0f0,
		"MActorAnmMatEach<J3DAnmTevRegKey>::__vt": 0x803cc118,
		"MActorAnmEach<J3DAnmTevRegKey>::__vt": 0x803cc140,
		"MActorAnmMatEach<J3DAnmTextureSRTKey>::__vt": 0x803cc168,
		"MActorAnmEach<J3DAnmTextureSRTKey>::__vt": 0x803cc190,
		"MActorAnmMatEach<J3DAnmTexPattern>::__vt": 0x803cc1b8,
		"MActorAnmEach<J3DAnmTexPattern>::__vt": 0x803cc1e0,
		"MActorAnmMatEach<J3DAnmColorKey>::__vt": 0x803cc208,
		"MActorAnmEach<J3DAnmColorKey>::__vt": 0x803cc230,
		"MActorAnmEach<J3DAnmTransformKey>::__vt": 0x803cc258,
		"MActorAnmBlk::__vt": 0x803cc280,
		"MActorAnmBrk::__vt": 0x803cc2a8,
		"MActorAnmBpk::__vt": 0x803cc2d0,
		"MActorAnmBtk::__vt": 0x803cc2f8,
		"MActorAnmBtp::__vt": 0x803cc320,
		"MActorAnmBck::__vt": 0x803cc348,
		"MActorAnmBase::__vt": 0x803cc370,
		"SDLModel::__vt": 0x803cc3a8,
		"SDLMatPacket::__vt": 0x803cc3c8,
		"SampleCtrlJoint::__vt": 0x803cc3e0,
		"SampleCtrlMaterial::__vt": 0x803cc3ec,
		"SampleCtrlShape::__vt": 0x803cc3f8,
		"SampleCtrlModelData::__vt": 0x803cc408,
		"TBaseParam::__vt": 0x803cf150,
		"TMarioParticleManager::__vt": 0x803cf188,
		"TMarioEmitterCallBackBindToSRTMtxPtr::__vt": 0x803cf1d0,
		"TMarioEmitterCallBackBindToMtxPtr::__vt": 0x803cf1e4,
		"TMarioEmitterCallBackBindToPosPtr::__vt": 0x803cf1f8,
		"TEmitterIndirectViewObj::__vt": 0x803cf20c,
		"TEmitterViewObj::__vt": 0x803cf230,
		"JPACallBackBase<JPABaseEmitter*>::__vt": 0x803cf254,
		"TEventWatcher::__vt": 0x803cf268,
		"TSpcTypedInterp<TEventWatcher>::__vt": 0x803cf290,
		"TSpcTypedBinary<TEventWatcher>::__vt": 0x803cf2a4,
		"System::@2031": 0x803cf2b8,
		"System::@2087": 0x803cf310,
		"System::@2135": 0x803cf338,
		"System::@2168": 0x803cf364,
		"TGCLogoDir::__vt": 0x803cf390,
		"TNintendo2D::__vt": 0x803cf3fc,
		"TGXAlphaUpdate::__vt": 0x803cf420,
		"TReInitGX::__vt": 0x803cf444,
		"TSMSDrawInit::__vt": 0x803cf468,
		"TJ3DSysSetViewMtx::__vt": 0x803cf48c,
		"TJ3DSysFlag::__vt": 0x803cf4b0,
		"TMarDirector::__vt": 0x803cf5c8,
		"TMarNameRefGen::__vt": 0x803cf638,
		"TNameRefAryT<TStagePositionInfo,JDrama::TNameRef>::__vt": 0x803cf648,
		"TNameRefPtrAryT<TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>,JDrama::TNameRef>::__vt": 0x803cf668,
		"TNameRefAryT<TScenarioArchiveName,JDrama::TNameRef>::__vt": 0x803cf688,
		"TNameRefAryT<TCameraMapTool,JDrama::TNameRef>::__vt": 0x803cf6c8,
		"TNameRefAryT<TStageEventInfo,JDrama::TNameRef>::__vt": 0x803cf6e8,
		"TCubeManagerFast::__vt": 0x803cf708,
		"TCubeManagerArea::__vt": 0x803cf72c,
		"TCubeManagerMarioIn::__vt": 0x803cf750,
		"TMenuDirector::__vt": 0x803cf778,
		"TPerformList::__vt": 0x803cf7e8,
		"System::SMSAASamplePattern_non": 0x803cf838,
		"SMSAASamplePattern_non": 0x803cf838,
		"System::SMSAASamplePattern_aa": 0x803cf850,
		"SMSAASamplePattern_aa": 0x803cf850,
		"System::SMSVFilter_non": 0x803cf868,
		"SMSVFilter_non": 0x803cf868,
		"System::SMSVFilter_flicker": 0x803cf870,
		"SMSVFilter_flicker": 0x803cf870,
		"TSnapTimeObj::__vt": 0x803cf878,
		"TTalkCursor::__vt": 0x803cf8a0,
		"TAlphaCatch::__vt": 0x803cf8c8,
		"TZBufferCatch::__vt": 0x803cf8ec,
		"System::@2633": 0x803cf910,
		"System::@2929": 0x803cf944,
		"TMarioGamePad::__vt": 0x803cf96c,
		"TScenarioArchiveName::__vt": 0x803cf978,
		"TStageEventInfo::__vt": 0x803cf998,
		"System::shineStageTable": 0x803cf9b8,
		"shineStageTable": 0x803cf9b8,
		"System::exShineTable": 0x803cf9f8,
		"exShineTable": 0x803cf9f8,
		"TStagePositionInfo::__vt": 0x803cfa18,
		"TTimeRec::__vt": 0x803cfa38,
		"TTHPRender::__vt": 0x803cfa48,
		"TNameKuriLauncherManager::__vt": 0x803cfa70,
		"THamuKuriLauncherManager::__vt": 0x803cfac4,
		"TCasinoRoulette::__vt": 0x803cfb18,
		"TSirenaGate::__vt": 0x803cfc80,
		"TMareWManager::__vt": 0x803cfde8,
		"TMareMManager::__vt": 0x803cfe40,
		"System::movies$2032": 0x803cfef8,
		"movies$2032": 0x803cfef8,
		"TMovieDirector::__vt": 0x803cff48,
		"System::@3810": 0x803cffb8,
		"System::@3898": 0x803cffe0,
		"System::@3897": 0x803d0008,
		"MSSTageSimpleEnvironment::__vt": 0x803d0180,
		"MSStageCubeSwitch::__vt": 0x803d0194,
		"MSStageCubeFadeMonte::__vt": 0x803d01a8,
		"MSStageCubeFade::__vt": 0x803d01d0,
		"MSStageDistFadeMonte::__vt": 0x803d01e4,
		"MSStageDistFade::__vt": 0x803d01f8,
		"MSStage::__vt": 0x803d020c,
		"TTargetArrow::__vt": 0x803d0220,
		"TLiveActor::__vt": 0x803ca1c8,
		"TLiveManager::__vt": 0x803ca478,
		"TObjManager::__vt": 0x803ca4b8,
		"TObjChara::__vt": 0x803ca50c,
		"Strategic::@285": 0x803ca530,
		"@285": 0x803ca530,
		"Strategic::@286": 0x803ca53c,
		"@286": 0x803ca53c,
		"Strategic::@287": 0x803ca548,
		"@287": 0x803ca548,
		"Strategic::@288": 0x803ca554,
		"Strategic::@289": 0x803ca560,
		"Strategic::@290": 0x803ca56c,
		"@290": 0x803ca56c,
		"Strategic::@291": 0x803ca578,
		"@291": 0x803ca578,
		"Strategic::@292": 0x803ca584,
		"Strategic::@293": 0x803ca590,
		"Strategic::@294": 0x803ca59c,
		"Strategic::@295": 0x803ca5a8,
		"Strategic::@296": 0x803ca5b4,
		"@296": 0x803ca5b4,
		"Strategic::@297": 0x803ca5c0,
		"Strategic::@298": 0x803ca5cc,
		"@298": 0x803ca5cc,
		"Strategic::@299": 0x803ca5d8,
		"@299": 0x803ca5d8,
		"Strategic::@300": 0x803ca5e4,
		"@300": 0x803ca5e4,
		"Strategic::@301": 0x803ca5f0,
		"Strategic::@302": 0x803ca5fc,
		"Strategic::@303": 0x803ca608,
		"Strategic::@304": 0x803ca614,
		"Strategic::@305": 0x803ca620,
		"Strategic::@306": 0x803ca62c,
		"@306": 0x803ca62c,
		"Strategic::@307": 0x803ca638,
		"@307": 0x803ca638,
		"Strategic::@308": 0x803ca644,
		"@308": 0x803ca644,
		"Strategic::@309": 0x803ca650,
		"Strategic::@310": 0x803ca65c,
		"@310": 0x803ca65c,
		"Strategic::@311": 0x803ca668,
		"@311": 0x803ca668,
		"Strategic::@312": 0x803ca674,
		"@312": 0x803ca674,
		"Strategic::@313": 0x803ca680,
		"@313": 0x803ca680,
		"Strategic::@314": 0x803ca68c,
		"@314": 0x803ca68c,
		"Strategic::@315": 0x803ca698,
		"@315": 0x803ca698,
		"Strategic::@316": 0x803ca6a4,
		"@316": 0x803ca6a4,
		"Strategic::@317": 0x803ca6b0,
		"@317": 0x803ca6b0,
		"Strategic::@318": 0x803ca6bc,
		"@318": 0x803ca6bc,
		"Strategic::@319": 0x803ca6c8,
		"@319": 0x803ca6c8,
		"Strategic::@320": 0x803ca6d4,
		"Strategic::@321": 0x803ca6e0,
		"Strategic::@322": 0x803ca6ec,
		"Strategic::@323": 0x803ca6f8,
		"Strategic::@324": 0x803ca704,
		"Strategic::table$284": 0x803ca710,
		"table$284": 0x803ca710,
		"TSpcInterp::__vt": 0x803ca8f0,
		"TSpcStack<TSpcSlice>::__vt": 0x803ca904,
		"TSpcStack<unsigned_long><unsigned_long>::__vt": 0x803ca910,
		"TSpcBinary::__vt": 0x803ca91c,
		"TStrategy::__vt": 0x803ca930,
		"TIdxGroupObj::__vt": 0x803ca954,
		"TQuestionManager::__vt": 0x803ca9b0,
		"TSMSSmplChara::__vt": 0x803ca9d8,
		"THitActor::__vt": 0x803caa00,
		"TBinder::__vt": 0x803caaa8,
		"TSharedParts::__vt": 0x803caab8,
		"TMirrorActor::__vt": 0x803caae0,
		"M3UModelMario::__vt": 0x803cc418,
		"TMarioCap::__vt": 0x803cc440,
		"Player::marioAnimeFiles": 0x803cc488,
		"Player::gMarioAnimeData": 0x803ccac0,
		"gMarioAnimeData": 0x803ccac0,
		"Player::marioAnimeTexPatternFilenames": 0x803cd540,
		"marioAnimeTexPatternFilenames": 0x803cd540,
		"Player::cParticleFileNames": 0x803cd790,
		"cParticleFileNames": 0x803cd790,
		"TWarpInCallBack::__vt": 0x803cd79c,
		"TBubbleCallBack::__vt": 0x803cd7d4,
		"TSplashManager::__vt": 0x803cd7e8,
		"TYoshiTongue::__vt": 0x803cd810,
		"Player::nozzleBmdData": 0x803cd8f8,
		"nozzleBmdData": 0x803cd8f8,
		"TWaterGun::__vt": 0x803cd9a0,
		"TNozzleDeform::__vt": 0x803cd9d0,
		"TNozzleTrigger::__vt": 0x803cd9f8,
		"TNozzleBase::__vt": 0x803cda20,
		"TMarioEffect::__vt": 0x803cda90,
		"TMario::__vt": 0x803cdb60,
		"Player::gModelWaterManagerWaterColor": 0x803cdd98,
		"gModelWaterManagerWaterColor": 0x803cdd98,
		"Player::prmNames": 0x803cdda8,
		"prmNames": 0x803cdda8,
		"Player::gWaterManagerPlaneInfo": 0x803cddec,
		"gWaterManagerPlaneInfo": 0x803cddec,
		"TModelWaterManager::__vt": 0x803ceeec,
		"TMarioPositionObj::__vt": 0x803cf038,
		"NPC::@3884": 0x803c8800,
		"NPC::@3883": 0x803c8854,
		"NPC::@3880": 0x803c88a4,
		"NPC::@4719": 0x803c8900,
		"TBaseNPC::__vt": 0x803c8958,
		"NPC::@3445": 0x803c8a6c,
		"NPC::@3991": 0x803c8ac4,
		"NPC::@3990": 0x803c8aec,
		"NPC::@4128": 0x803c8b48,
		"NPC::@4190": 0x803c8ba4,
		"TSunflowerSManager::__vt": 0x803c8c00,
		"NPC::@2899": 0x803c8c58,
		"TMareWBaseManager::__vt": 0x803c8c90,
		"TMareMBaseManager::__vt": 0x803c8ce8,
		"TMonteWBManager::__vt": 0x803c8d40,
		"TMonteWAManager::__vt": 0x803c8d98,
		"TMonteWManager::__vt": 0x803c8df0,
		"TMonteMEManager::__vt": 0x803c8e48,
		"TMonteMDManager::__vt": 0x803c8ea0,
		"TMonteMCManager::__vt": 0x803c8ef8,
		"TMonteMBManager::__vt": 0x803c8f50,
		"TMonteMAManager::__vt": 0x803c8fa8,
		"TMonteMManager::__vt": 0x803c9000,
		"TSunflowerLManager::__vt": 0x803c9058,
		"TRaccoonDogManager::__vt": 0x803c90b0,
		"TPeachManager::__vt": 0x803c9108,
		"TKinojiiManager::__vt": 0x803c9160,
		"TKinopioManager::__vt": 0x803c91b8,
		"TMareWBManager::__vt": 0x803c9210,
		"TMareWAManager::__vt": 0x803c9268,
		"TMareMDManager::__vt": 0x803c92c0,
		"TMareMCManager::__vt": 0x803c9318,
		"TMareMBManager::__vt": 0x803c9370,
		"TMareMAManager::__vt": 0x803c93c8,
		"TMonteWCManager::__vt": 0x803c9420,
		"TMonteMHManager::__vt": 0x803c9478,
		"TMonteMGManager::__vt": 0x803c94d0,
		"TMonteMFManager::__vt": 0x803c9528,
		"TMonteWSpecialManager::__vt": 0x803c9580,
		"TMonteMSpecialManager::__vt": 0x803c95d8,
		"TMonteWBaseManager::__vt": 0x803c9630,
		"TMonteMBaseManager::__vt": 0x803c9688,
		"TMareBaseManager::__vt": 0x803c96e0,
		"TNPCManager::__vt": 0x803c9738,
		"TMareJellyFishManager::__vt": 0x803c9790,
		"TBoardNpcManager::__vt": 0x803c97c0,
		"TNerveNPCMareStand::__vt": 0x803c9800,
		"TNerveNPCBlown::__vt": 0x803c9810,
		"TNerveNPCMad::__vt": 0x803c9820,
		"TNerveNPCThrow::__vt": 0x803c9830,
		"TNerveNPCTalk::__vt": 0x803c9840,
		"TNerveNPCSetPosAfterSinkBottom::__vt": 0x803c9850,
		"TNerveNPCRecoverAfter::__vt": 0x803c9860,
		"TNerveNPCRecoverFromSink::__vt": 0x803c9870,
		"TNerveNPCSink::__vt": 0x803c9880,
		"TNerveNPCWet::__vt": 0x803c9890,
		"TNerveNPCTurnToMario::__vt": 0x803c98a0,
		"TNerveNPCWaitMarioApproach::__vt": 0x803c98b0,
		"TNerveNPCWaitContinue::__vt": 0x803c98c0,
		"TNerveNPCGraphWait::__vt": 0x803c98d0,
		"TNerveNPCUTurn::__vt": 0x803c98e0,
		"TNerveNPCGraphWander::__vt": 0x803c98f0,
		"NPC::sSaveFileName$1960": 0x803c9900,
		"sSaveFileName$1960": 0x803c9900,
		"NPC::sMareMB_FishingRodData": 0x803c99b8,
		"sMareMB_FishingRodData": 0x803c99b8,
		"NPC::sMareWB_BabyData": 0x803c99e4,
		"sMareWB_BabyData": 0x803c99e4,
		"NPC::sAllNpcInitData$1622": 0x803c9a10,
		"sAllNpcInitData$1622": 0x803c9a10,
		"NPC::MtxCalcTypeName": 0x803c9ab0,
		"NPC::monteMCommon_bastable": 0x803c9ac0,
		"monteMCommon_bastable": 0x803c9ac0,
		"NPC::monteMCommon_bas_c_table": 0x803c9b1c,
		"monteMCommon_bas_c_table": 0x803c9b1c,
		"NPC::monteME_bastable": 0x803c9b78,
		"monteME_bastable": 0x803c9b78,
		"NPC::monteME_bas_c_table": 0x803c9b94,
		"monteME_bas_c_table": 0x803c9b94,
		"NPC::monteMF_bastable": 0x803c9bb0,
		"monteMF_bastable": 0x803c9bb0,
		"NPC::monteMF_bas_c_table": 0x803c9bbc,
		"monteMF_bas_c_table": 0x803c9bbc,
		"NPC::monteMH_bastable": 0x803c9bc8,
		"monteMH_bastable": 0x803c9bc8,
		"NPC::monteMH_bas_c_table": 0x803c9bd8,
		"monteMH_bas_c_table": 0x803c9bd8,
		"NPC::monteWCommon_bastable": 0x803c9be8,
		"monteWCommon_bastable": 0x803c9be8,
		"NPC::monteWCommon_bas_c_table": 0x803c9c48,
		"monteWCommon_bas_c_table": 0x803c9c48,
		"NPC::monteWC_bastable": 0x803c9ca8,
		"monteWC_bastable": 0x803c9ca8,
		"NPC::monteWC_bas_c_table": 0x803c9cbc,
		"monteWC_bas_c_table": 0x803c9cbc,
		"NPC::mareM_bastable": 0x803c9cd0,
		"mareM_bastable": 0x803c9cd0,
		"NPC::mareM_bas_c_table": 0x803c9d24,
		"mareM_bas_c_table": 0x803c9d24,
		"NPC::mareMA_bastable": 0x803c9d78,
		"mareMA_bastable": 0x803c9d78,
		"NPC::mareMA_bas_c_table": 0x803c9d8c,
		"mareMA_bas_c_table": 0x803c9d8c,
		"NPC::mareMB_bastable": 0x803c9da0,
		"mareMB_bastable": 0x803c9da0,
		"NPC::mareMB_bas_c_table": 0x803c9db8,
		"mareMB_bas_c_table": 0x803c9db8,
		"NPC::mareMC_bastable": 0x803c9dd0,
		"mareMC_bastable": 0x803c9dd0,
		"NPC::mareMC_bas_c_table": 0x803c9de4,
		"mareMC_bas_c_table": 0x803c9de4,
		"NPC::mareW_bastable": 0x803c9df8,
		"mareW_bastable": 0x803c9df8,
		"NPC::mareW_bas_c_table": 0x803c9e48,
		"mareW_bas_c_table": 0x803c9e48,
		"NPC::mareWA_bastable": 0x803c9e98,
		"mareWA_bastable": 0x803c9e98,
		"NPC::mareWA_bas_c_table": 0x803c9ea8,
		"mareWA_bas_c_table": 0x803c9ea8,
		"NPC::mareWB_bastable": 0x803c9eb8,
		"mareWB_bastable": 0x803c9eb8,
		"NPC::mareWB_bas_c_table": 0x803c9ed0,
		"mareWB_bas_c_table": 0x803c9ed0,
		"NPC::kinopio_bastable": 0x803c9ee8,
		"kinopio_bastable": 0x803c9ee8,
		"NPC::kinopio_bas_c_table": 0x803c9f4c,
		"kinopio_bas_c_table": 0x803c9f4c,
		"NPC::kinojii_bastable": 0x803c9fb0,
		"kinojii_bastable": 0x803c9fb0,
		"NPC::kinojii_bas_c_table": 0x803c9ff8,
		"kinojii_bas_c_table": 0x803c9ff8,
		"NPC::peach_bastable": 0x803ca040,
		"peach_bastable": 0x803ca040,
		"NPC::peach_bas_c_table": 0x803ca09c,
		"peach_bas_c_table": 0x803ca09c,
		"NPC::raccoonDog_bastable": 0x803ca0f8,
		"raccoonDog_bastable": 0x803ca0f8,
		"NPC::raccoonDog_bas_c_table": 0x803ca108,
		"raccoonDog_bas_c_table": 0x803ca108,
		"NPC::sunflowerL_bastable": 0x803ca118,
		"sunflowerL_bastable": 0x803ca118,
		"NPC::sunflowerL_bas_c_table": 0x803ca12c,
		"sunflowerL_bas_c_table": 0x803ca12c,
		"NPC::sunflowerS_bastable": 0x803ca140,
		"sunflowerS_bastable": 0x803ca140,
		"NPC::sunflowerS_bas_c_table": 0x803ca154,
		"sunflowerS_bas_c_table": 0x803ca154,
		"MAnmSoundNPC::__vt": 0x8039e2e0,
		"MAnmSound::__vt": 0x8039e300,
		"MSSeCallBack::smTrackCategory": 0x8039e310,
		"smTrackCategory": 0x8039e310,
		"MSSeCallBack::smPolifonic": 0x8039e350,
		"smPolifonic": 0x8039e350,
		"MSound::__vt": 0x8039e360,
		"MSound::@2331": 0x8039e3f0,
		"MSoundSESystem::MSRandPlay::__vt": 0x8039e4b0,
		"MSound::@2334": 0x8039e4bc,
		"MSSetSoundTL<MSSetSoundGrp>::__vt": 0x8039e548,
		"MSSetSoundGrp::__vt": 0x8039e560,
		"MSoundSESystem::MSRandVol::__vt": 0x8039e578,
		"JALListFrameLoop<MSSetSoundGrp>::__vt": 0x8039e584,
		"MSSetSoundTL<MSSetSound>::__vt": 0x8039e590,
		"MSSetSound::__vt": 0x8039e5a8,
		"JALListFrameLoop<MSSetSound>::__vt": 0x8039e5c0,
		"MSHandle::smACosPrm": 0x8039e5f8,
		"smACosPrm": 0x8039e5f8,
		"MSHandle::smSeCategory": 0x8039e78c,
		"smSeCategory": 0x8039e78c,
		"MSHandle::__vt": 0x8039e88c,
		"MSBgmXFade::scTiming": 0x8039e908,
		"scTiming": 0x8039e908,
		"MSBgmXFade::scExp": 0x8039e950,
		"scExp": 0x8039e950,
		"TWoodBarrel::__vt": 0x803b2de8,
		"TMapObjBase::__vt": 0x803b2fc8,
		"TMapObjGeneral::mDefaultSound": 0x803b3168,
		"mDefaultSound": 0x803b3168,
		"MoveBG::normal_sound_data": 0x803b3190,
		"normal_sound_data": 0x803b3190,
		"MoveBG::end_data": 0x803b31b8,
		"end_data": 0x803b31b8,
		"MoveBG::no_data": 0x803b31f4,
		"no_data": 0x803b31f4,
		"MoveBG::billboard_dolphin_data": 0x803b3230,
		"billboard_dolphin_data": 0x803b3230,
		"MoveBG::billboard_sun_data": 0x803b326c,
		"billboard_sun_data": 0x803b326c,
		"MoveBG::billboard_restaurant_data": 0x803b32a8,
		"billboard_restaurant_data": 0x803b32a8,
		"MoveBG::billboard_fish_data": 0x803b32e4,
		"billboard_fish_data": 0x803b32e4,
		"MoveBG::HideObj_data": 0x803b3320,
		"HideObj_data": 0x803b3320,
		"MoveBG::WaterHitHideObj_data": 0x803b335c,
		"WaterHitHideObj_data": 0x803b335c,
		"MoveBG::FruitHitHideObj_data": 0x803b3398,
		"FruitHitHideObj_data": 0x803b3398,
		"MoveBG::HipDropHideObj_data": 0x803b33d4,
		"HipDropHideObj_data": 0x803b33d4,
		"MoveBG::MonteChair_data": 0x803b3410,
		"MonteChair_data": 0x803b3410,
		"MoveBG::door_data": 0x803b344c,
		"door_data": 0x803b344c,
		"MoveBG::doorHotel_data": 0x803b3488,
		"doorHotel_data": 0x803b3488,
		"MoveBG::manhole_data": 0x803b34c4,
		"manhole_data": 0x803b34c4,
		"MoveBG::FruitBasket_data": 0x803b3500,
		"FruitBasket_data": 0x803b3500,
		"MoveBG::BasketReverse_data": 0x803b353c,
		"BasketReverse_data": 0x803b353c,
		"MoveBG::CoconutJuice_data": 0x803b3578,
		"CoconutJuice_data": 0x803b3578,
		"MoveBG::Pile_data": 0x803b35b4,
		"Pile_data": 0x803b35b4,
		"MoveBG::ChangeStage_data": 0x803b35f0,
		"ChangeStage_data": 0x803b35f0,
		"MoveBG::ChangeStageMerrygoround_data": 0x803b362c,
		"ChangeStageMerrygoround_data": 0x803b362c,
		"MoveBG::StartDemo_data": 0x803b3668,
		"StartDemo_data": 0x803b3668,
		"MoveBG::ChipShine_data": 0x803b36a4,
		"ChipShine_data": 0x803b36a4,
		"MoveBG::KoopaJrSignM_data": 0x803b36e0,
		"KoopaJrSignM_data": 0x803b36e0,
		"MoveBG::StarSign_data": 0x803b371c,
		"StarSign_data": 0x803b371c,
		"MoveBG::SignCircle_data": 0x803b3758,
		"SignCircle_data": 0x803b3758,
		"MoveBG::SignCross_data": 0x803b3794,
		"SignCross_data": 0x803b3794,
		"MoveBG::SignTriangle_data": 0x803b37d0,
		"SignTriangle_data": 0x803b37d0,
		"MoveBG::ArrowBoardLR_data": 0x803b380c,
		"ArrowBoardLR_data": 0x803b380c,
		"MoveBG::ArrowBoardUp_data": 0x803b3848,
		"ArrowBoardUp_data": 0x803b3848,
		"MoveBG::ArrowBoardDown_data": 0x803b3884,
		"ArrowBoardDown_data": 0x803b3884,
		"MoveBG::WaterSprayCylinder_data": 0x803b38c0,
		"WaterSprayCylinder_data": 0x803b38c0,
		"MoveBG::WaterSprayBox_data": 0x803b38fc,
		"WaterSprayBox_data": 0x803b38fc,
		"MoveBG::ObjSwitch_data": 0x803b3938,
		"ObjSwitch_data": 0x803b3938,
		"MoveBG::RedCoinSwitch_data": 0x803b3974,
		"RedCoinSwitch_data": 0x803b3974,
		"MoveBG::bucket_data": 0x803b39b0,
		"bucket_data": 0x803b39b0,
		"MoveBG::GeneralHitObj_data": 0x803b39ec,
		"GeneralHitObj_data": 0x803b39ec,
		"MoveBG::bottle_large_data": 0x803b3a28,
		"bottle_large_data": 0x803b3a28,
		"MoveBG::bottle_short_data": 0x803b3a64,
		"bottle_short_data": 0x803b3a64,
		"MoveBG::WaterRecoverObj_data": 0x803b3aa0,
		"WaterRecoverObj_data": 0x803b3aa0,
		"MoveBG::watergun_item_data": 0x803b3adc,
		"watergun_item_data": 0x803b3adc,
		"MoveBG::nozzle_normal_physical_data": 0x803b3b18,
		"nozzle_normal_physical_data": 0x803b3b18,
		"MoveBG::nozzle_normal_physical_info": 0x803b3b4c,
		"nozzle_normal_physical_info": 0x803b3b4c,
		"MoveBG::nozzle_normal_item_data": 0x803b3b58,
		"nozzle_normal_item_data": 0x803b3b58,
		"MoveBG::yoshi_whistle_item_data": 0x803b3b94,
		"yoshi_whistle_item_data": 0x803b3b94,
		"MoveBG::nozzle_rocket_item_data": 0x803b3bd0,
		"nozzle_rocket_item_data": 0x803b3bd0,
		"MoveBG::nozzle_back_item_data": 0x803b3c0c,
		"nozzle_back_item_data": 0x803b3c0c,
		"MoveBG::coin_physical_data": 0x803b3c48,
		"coin_physical_data": 0x803b3c48,
		"MoveBG::coin_physical_info": 0x803b3c7c,
		"coin_physical_info": 0x803b3c7c,
		"MoveBG::coin_data": 0x803b3c88,
		"coin_data": 0x803b3c88,
		"MoveBG::invisible_coin_data": 0x803b3cc4,
		"invisible_coin_data": 0x803b3cc4,
		"MoveBG::coin_red_data": 0x803b3d00,
		"coin_red_data": 0x803b3d00,
		"MoveBG::coin_blue_data": 0x803b3d3c,
		"coin_blue_data": 0x803b3d3c,
		"MoveBG::shine_data": 0x803b3d78,
		"shine_data": 0x803b3d78,
		"MoveBG::mario_cap_data": 0x803b3db4,
		"mario_cap_data": 0x803b3db4,
		"MoveBG::joint_coin_data": 0x803b3df0,
		"joint_coin_data": 0x803b3df0,
		"MoveBG::eggYoshi_data": 0x803b3e2c,
		"eggYoshi_data": 0x803b3e2c,
		"MoveBG::EggYoshi_physical_data": 0x803b3e68,
		"EggYoshi_physical_data": 0x803b3e68,
		"MoveBG::EggYoshi_physical_info": 0x803b3e9c,
		"EggYoshi_physical_info": 0x803b3e9c,
		"MoveBG::eggYoshiEvent_data": 0x803b3ea8,
		"eggYoshiEvent_data": 0x803b3ea8,
		"MoveBG::NozzleBox_data": 0x803b3ee4,
		"NozzleBox_data": 0x803b3ee4,
		"MoveBG::mushroom1up_data": 0x803b3f20,
		"mushroom1up_data": 0x803b3f20,
		"MoveBG::mushroom1upR_data": 0x803b3f5c,
		"mushroom1upR_data": 0x803b3f5c,
		"MoveBG::mushroom1upX_data": 0x803b3f98,
		"mushroom1upX_data": 0x803b3f98,
		"MoveBG::jumpbase_data": 0x803b3fd4,
		"jumpbase_data": 0x803b3fd4,
		"MoveBG::coconut_physical_data": 0x803b4010,
		"coconut_physical_data": 0x803b4010,
		"MoveBG::coconut_physical_info": 0x803b4044,
		"coconut_physical_info": 0x803b4044,
		"MoveBG::coconut_data": 0x803b4050,
		"coconut_data": 0x803b4050,
		"MoveBG::papaya_physical_data": 0x803b408c,
		"papaya_physical_data": 0x803b408c,
		"MoveBG::papaya_physical_info": 0x803b40c0,
		"papaya_physical_info": 0x803b40c0,
		"MoveBG::papaya_data": 0x803b40cc,
		"papaya_data": 0x803b40cc,
		"MoveBG::pine_physical_data": 0x803b4108,
		"pine_physical_data": 0x803b4108,
		"MoveBG::pine_physical_info": 0x803b413c,
		"pine_physical_info": 0x803b413c,
		"MoveBG::pine_data": 0x803b4148,
		"pine_data": 0x803b4148,
		"MoveBG::CoverPine_data": 0x803b4184,
		"CoverPine_data": 0x803b4184,
		"MoveBG::durian_physical_data": 0x803b41c0,
		"durian_physical_data": 0x803b41c0,
		"MoveBG::durian_physical_info": 0x803b41f4,
		"durian_physical_info": 0x803b41f4,
		"MoveBG::durian_data": 0x803b4200,
		"durian_data": 0x803b4200,
		"MoveBG::banana_physical_data": 0x803b423c,
		"banana_physical_data": 0x803b423c,
		"MoveBG::banana_physical_info": 0x803b4270,
		"banana_physical_info": 0x803b4270,
		"MoveBG::banana_data": 0x803b427c,
		"banana_data": 0x803b427c,
		"MoveBG::red_pepper_physical_data": 0x803b42b8,
		"red_pepper_physical_data": 0x803b42b8,
		"MoveBG::red_pepper_physical_info": 0x803b42ec,
		"red_pepper_physical_info": 0x803b42ec,
		"MoveBG::RedPepper_data": 0x803b42f8,
		"RedPepper_data": 0x803b42f8,
		"MoveBG::fence_normal_data": 0x803b4334,
		"fence_normal_data": 0x803b4334,
		"MoveBG::fence3x3_data": 0x803b4370,
		"fence3x3_data": 0x803b4370,
		"MoveBG::fence_revolve_data": 0x803b43ac,
		"fence_revolve_data": 0x803b43ac,
		"MoveBG::fence_revolve_inner_data": 0x803b43e8,
		"fence_revolve_inner_data": 0x803b43e8,
		"MoveBG::fenceInnerGreen_data": 0x803b4424,
		"fenceInnerGreen_data": 0x803b4424,
		"MoveBG::FenceWaterV_data": 0x803b4460,
		"FenceWaterV_data": 0x803b4460,
		"MoveBG::FenceWaterH_data": 0x803b449c,
		"FenceWaterH_data": 0x803b449c,
		"MoveBG::RailFence_data": 0x803b44d8,
		"RailFence_data": 0x803b44d8,
		"MoveBG::bambooFenceRevolveInner_data": 0x803b4514,
		"bambooFenceRevolveInner_data": 0x803b4514,
		"MoveBG::bambooFenceRevolveOuter_data": 0x803b4550,
		"bambooFenceRevolveOuter_data": 0x803b4550,
		"MoveBG::bambooRailFence_data": 0x803b458c,
		"bambooRailFence_data": 0x803b458c,
		"MoveBG::wood_barrel_physical_data": 0x803b45c8,
		"wood_barrel_physical_data": 0x803b45c8,
		"MoveBG::wood_barrel_physical_info": 0x803b45fc,
		"wood_barrel_physical_info": 0x803b45fc,
		"MoveBG::wood_barrel_hold_data": 0x803b4608,
		"wood_barrel_hold_data": 0x803b4608,
		"MoveBG::wood_barrel_data": 0x803b461c,
		"wood_barrel_data": 0x803b461c,
		"MoveBG::wood_barrel_once_data": 0x803b4658,
		"wood_barrel_once_data": 0x803b4658,
		"MoveBG::barrel_float_data": 0x803b4694,
		"barrel_float_data": 0x803b4694,
		"MoveBG::drum_can_data": 0x803b46d0,
		"drum_can_data": 0x803b46d0,
		"MoveBG::barrel_oil_data": 0x803b470c,
		"barrel_oil_data": 0x803b470c,
		"MoveBG::breakable_block_data": 0x803b4748,
		"breakable_block_data": 0x803b4748,
		"MoveBG::supermario_block_data": 0x803b4784,
		"supermario_block_data": 0x803b4784,
		"MoveBG::move_block_data": 0x803b47c0,
		"move_block_data": 0x803b47c0,
		"MoveBG::fall_slow_block_data": 0x803b47fc,
		"fall_slow_block_data": 0x803b47fc,
		"MoveBG::expand_block_data": 0x803b4838,
		"expand_block_data": 0x803b4838,
		"MoveBG::spread_block_data": 0x803b4874,
		"spread_block_data": 0x803b4874,
		"MoveBG::water_roll_block_data": 0x803b48b0,
		"water_roll_block_data": 0x803b48b0,
		"MoveBG::sand_block_data": 0x803b48ec,
		"sand_block_data": 0x803b48ec,
		"MoveBG::water_power_lift_data": 0x803b4928,
		"water_power_lift_data": 0x803b4928,
		"MoveBG::water_power_inertial_lift_data": 0x803b4964,
		"water_power_inertial_lift_data": 0x803b4964,
		"MoveBG::water_power_ship_data": 0x803b49a0,
		"water_power_ship_data": 0x803b49a0,
		"MoveBG::lean_direct_block_data": 0x803b49dc,
		"lean_direct_block_data": 0x803b49dc,
		"MoveBG::lean_indirect_block_data": 0x803b4a18,
		"lean_indirect_block_data": 0x803b4a18,
		"MoveBG::lean_block_data": 0x803b4a54,
		"lean_block_data": 0x803b4a54,
		"MoveBG::skate_block_data": 0x803b4a90,
		"skate_block_data": 0x803b4a90,
		"MoveBG::MoveCoin_data": 0x803b4acc,
		"MoveCoin_data": 0x803b4acc,
		"MoveBG::cluster_block_data": 0x803b4b08,
		"cluster_block_data": 0x803b4b08,
		"MoveBG::NormalBlock_data": 0x803b4b44,
		"NormalBlock_data": 0x803b4b44,
		"MoveBG::IceBlock_data": 0x803b4b80,
		"IceBlock_data": 0x803b4b80,
		"MoveBG::BrickBlock_data": 0x803b4bbc,
		"BrickBlock_data": 0x803b4bbc,
		"MoveBG::WaterMelonBlock_data": 0x803b4bf8,
		"WaterMelonBlock_data": 0x803b4bf8,
		"MoveBG::TelesaBlock_data": 0x803b4c34,
		"TelesaBlock_data": 0x803b4c34,
		"MoveBG::WoodBlockPole_data": 0x803b4c70,
		"WoodBlockPole_data": 0x803b4c70,
		"MoveBG::JuiceBlock_data": 0x803b4cac,
		"JuiceBlock_data": 0x803b4cac,
		"MoveBG::SuperHipDropBlock_data": 0x803b4ce8,
		"SuperHipDropBlock_data": 0x803b4ce8,
		"MoveBG::palmNormal_data": 0x803b4d24,
		"palmNormal_data": 0x803b4d24,
		"MoveBG::palmOugi_data": 0x803b4d60,
		"palmOugi_data": 0x803b4d60,
		"MoveBG::palmSago_data": 0x803b4d9c,
		"palmSago_data": 0x803b4d9c,
		"MoveBG::palmNatume_data": 0x803b4dd8,
		"palmNatume_data": 0x803b4dd8,
		"MoveBG::palmLeaf_data": 0x803b4e14,
		"palmLeaf_data": 0x803b4e14,
		"MoveBG::BananaTree_data": 0x803b4e50,
		"BananaTree_data": 0x803b4e50,
		"MoveBG::FruitTree_data": 0x803b4e8c,
		"FruitTree_data": 0x803b4e8c,
		"MoveBG::flower_data": 0x803b4ec8,
		"flower_data": 0x803b4ec8,
		"MoveBG::flowerOrange_data": 0x803b4f04,
		"flowerOrange_data": 0x803b4f04,
		"MoveBG::flowerPink_data": 0x803b4f40,
		"flowerPink_data": 0x803b4f40,
		"MoveBG::flowerPurple_data": 0x803b4f7c,
		"flowerPurple_data": 0x803b4f7c,
		"MoveBG::flowerRed_data": 0x803b4fb8,
		"flowerRed_data": 0x803b4fb8,
		"MoveBG::flowerYellow_data": 0x803b4ff4,
		"flowerYellow_data": 0x803b4ff4,
		"MoveBG::flowerSunflower_data": 0x803b5030,
		"flowerSunflower_data": 0x803b5030,
		"MoveBG::telegraph_pole_l_data": 0x803b506c,
		"telegraph_pole_l_data": 0x803b506c,
		"MoveBG::telegraph_pole_s_data": 0x803b50a8,
		"telegraph_pole_s_data": 0x803b50a8,
		"MoveBG::streetlamp_data": 0x803b50e4,
		"streetlamp_data": 0x803b50e4,
		"MoveBG::PoleNormal_data": 0x803b5120,
		"PoleNormal_data": 0x803b5120,
		"MoveBG::football_physical_data": 0x803b515c,
		"football_physical_data": 0x803b515c,
		"MoveBG::football_physical_info": 0x803b5190,
		"football_physical_info": 0x803b5190,
		"MoveBG::football_data": 0x803b519c,
		"football_data": 0x803b519c,
		"MoveBG::football_goal_data": 0x803b51d8,
		"football_goal_data": 0x803b51d8,
		"MoveBG::baloonball_physical_data": 0x803b5214,
		"baloonball_physical_data": 0x803b5214,
		"MoveBG::baloonball_physical_info": 0x803b5248,
		"baloonball_physical_info": 0x803b5248,
		"MoveBG::baloonball_data": 0x803b5254,
		"baloonball_data": 0x803b5254,
		"MoveBG::coconutball_data": 0x803b5290,
		"coconutball_data": 0x803b5290,
		"MoveBG::watermelon_physical_data": 0x803b52cc,
		"watermelon_physical_data": 0x803b52cc,
		"MoveBG::watermelon_physical_info": 0x803b5300,
		"watermelon_physical_info": 0x803b5300,
		"MoveBG::watermelon_data": 0x803b530c,
		"watermelon_data": 0x803b530c,
		"MoveBG::WatermelonStatic_data": 0x803b5348,
		"WatermelonStatic_data": 0x803b5348,
		"MoveBG::cloud_data": 0x803b5384,
		"cloud_data": 0x803b5384,
		"MoveBG::normallift_data": 0x803b53c0,
		"normallift_data": 0x803b53c0,
		"MoveBG::exrollcube_data": 0x803b53fc,
		"exrollcube_data": 0x803b53fc,
		"MoveBG::exkickboard_data": 0x803b5438,
		"exkickboard_data": 0x803b5438,
		"MoveBG::railblockr_data": 0x803b5474,
		"railblockr_data": 0x803b5474,
		"MoveBG::railblocky_data": 0x803b54b0,
		"railblocky_data": 0x803b54b0,
		"MoveBG::railblockb_data": 0x803b54ec,
		"railblockb_data": 0x803b54ec,
		"MoveBG::rollblockr_data": 0x803b5528,
		"rollblockr_data": 0x803b5528,
		"MoveBG::rollblocky_data": 0x803b5564,
		"rollblocky_data": 0x803b5564,
		"MoveBG::rollblockb_data": 0x803b55a0,
		"rollblockb_data": 0x803b55a0,
		"MoveBG::umaibou_data": 0x803b55dc,
		"umaibou_data": 0x803b55dc,
		"MoveBG::kamaboko_data": 0x803b5618,
		"kamaboko_data": 0x803b5618,
		"MoveBG::getag_data": 0x803b5654,
		"getag_data": 0x803b5654,
		"MoveBG::getao_data": 0x803b5690,
		"getao_data": 0x803b5690,
		"MoveBG::uirou_data": 0x803b56cc,
		"uirou_data": 0x803b56cc,
		"MoveBG::hikidashi_data": 0x803b5708,
		"hikidashi_data": 0x803b5708,
		"MoveBG::castella_data": 0x803b5744,
		"castella_data": 0x803b5744,
		"MoveBG::yoshiblock_data": 0x803b5780,
		"yoshiblock_data": 0x803b5780,
		"MoveBG::WoodBlockTriangle_data": 0x803b57bc,
		"WoodBlockTriangle_data": 0x803b57bc,
		"MoveBG::WoodBlockPyramid_data": 0x803b57f8,
		"WoodBlockPyramid_data": 0x803b57f8,
		"MoveBG::WoodBlockLong_data": 0x803b5834,
		"WoodBlockLong_data": 0x803b5834,
		"MoveBG::WoodBlockLarge_data": 0x803b5870,
		"WoodBlockLarge_data": 0x803b5870,
		"MoveBG::WoodBlockCone_data": 0x803b58ac,
		"WoodBlockCone_data": 0x803b58ac,
		"MoveBG::WoodBlockL_data": 0x803b58e8,
		"WoodBlockL_data": 0x803b58e8,
		"MoveBG::WoodBlockBridge_data": 0x803b5924,
		"WoodBlockBridge_data": 0x803b5924,
		"MoveBG::WoodBlockCube_data": 0x803b5960,
		"WoodBlockCube_data": 0x803b5960,
		"MoveBG::normalvariant0_data": 0x803b599c,
		"normalvariant0_data": 0x803b599c,
		"MoveBG::normalvariant1_data": 0x803b59d8,
		"normalvariant1_data": 0x803b59d8,
		"MoveBG::normalvariant2_data": 0x803b5a14,
		"normalvariant2_data": 0x803b5a14,
		"MoveBG::normalvariant3_data": 0x803b5a50,
		"normalvariant3_data": 0x803b5a50,
		"MoveBG::normalvariant4_data": 0x803b5a8c,
		"normalvariant4_data": 0x803b5a8c,
		"MoveBG::railvariant0_data": 0x803b5ac8,
		"railvariant0_data": 0x803b5ac8,
		"MoveBG::railvariant1_data": 0x803b5b04,
		"railvariant1_data": 0x803b5b04,
		"MoveBG::railvariant2_data": 0x803b5b40,
		"railvariant2_data": 0x803b5b40,
		"MoveBG::railvariant3_data": 0x803b5b7c,
		"railvariant3_data": 0x803b5b7c,
		"MoveBG::railvariant4_data": 0x803b5bb8,
		"railvariant4_data": 0x803b5bb8,
		"MoveBG::rollvariant0_data": 0x803b5bf4,
		"rollvariant0_data": 0x803b5bf4,
		"MoveBG::rollvariant1_data": 0x803b5c30,
		"rollvariant1_data": 0x803b5c30,
		"MoveBG::rollvariant2_data": 0x803b5c6c,
		"rollvariant2_data": 0x803b5c6c,
		"MoveBG::rollvariant3_data": 0x803b5ca8,
		"rollvariant3_data": 0x803b5ca8,
		"MoveBG::rollvariant4_data": 0x803b5ce4,
		"rollvariant4_data": 0x803b5ce4,
		"MoveBG::lamptrapspike_data": 0x803b5d20,
		"lamptrapspike_data": 0x803b5d20,
		"MoveBG::lamptrapiron_data": 0x803b5d5c,
		"lamptrapiron_data": 0x803b5d5c,
		"MoveBG::airplane_data": 0x803b5d98,
		"airplane_data": 0x803b5d98,
		"MoveBG::WoodBox_data": 0x803b5dd4,
		"WoodBox_data": 0x803b5dd4,
		"MoveBG::AirportPole_data": 0x803b5e10,
		"AirportPole_data": 0x803b5e10,
		"MoveBG::ice_car_data": 0x803b5e4c,
		"ice_car_data": 0x803b5e4c,
		"MoveBG::move_ice_car_data": 0x803b5e88,
		"move_ice_car_data": 0x803b5e88,
		"MoveBG::AirportBuoy_data": 0x803b5ec4,
		"AirportBuoy_data": 0x803b5ec4,
		"MoveBG::dptCannon_data": 0x803b5f00,
		"dptCannon_data": 0x803b5f00,
		"MoveBG::dptKing_data": 0x803b5f3c,
		"dptKing_data": 0x803b5f3c,
		"MoveBG::KoopaJrSubmarine_data": 0x803b5f78,
		"KoopaJrSubmarine_data": 0x803b5f78,
		"MoveBG::monumentshine_data": 0x803b5fb4,
		"monumentshine_data": 0x803b5fb4,
		"MoveBG::belldolpic_data": 0x803b5ff0,
		"belldolpic_data": 0x803b5ff0,
		"MoveBG::dptWeathercock_data": 0x803b602c,
		"dptWeathercock_data": 0x803b602c,
		"MoveBG::dptMonteFence_data": 0x803b6068,
		"dptMonteFence_data": 0x803b6068,
		"MoveBG::dptCoronaFence_data": 0x803b60a4,
		"dptCoronaFence_data": 0x803b60a4,
		"MoveBG::MapSmoke_data": 0x803b60e0,
		"MapSmoke_data": 0x803b60e0,
		"MoveBG::MareGate_data": 0x803b611c,
		"MareGate_data": 0x803b611c,
		"MoveBG::DemoCannon_data": 0x803b6158,
		"DemoCannon_data": 0x803b6158,
		"MoveBG::NozzleDoor_data": 0x803b6194,
		"NozzleDoor_data": 0x803b6194,
		"MoveBG::DokanGate_data": 0x803b61d0,
		"DokanGate_data": 0x803b61d0,
		"MoveBG::crane_data": 0x803b620c,
		"crane_data": 0x803b620c,
		"MoveBG::crane90Scene2_data": 0x803b6248,
		"crane90Scene2_data": 0x803b6248,
		"MoveBG::crane180Scene1_data": 0x803b6284,
		"crane180Scene1_data": 0x803b6284,
		"MoveBG::craneUpDown_data": 0x803b62c0,
		"craneUpDown_data": 0x803b62c0,
		"MoveBG::craneCargoUpDown_data": 0x803b62fc,
		"craneCargoUpDown_data": 0x803b62fc,
		"MoveBG::tank_data": 0x803b6338,
		"tank_data": 0x803b6338,
		"MoveBG::container_data": 0x803b6374,
		"container_data": 0x803b6374,
		"MoveBG::submarine_data": 0x803b63b0,
		"submarine_data": 0x803b63b0,
		"MoveBG::riccoShip_data": 0x803b63ec,
		"riccoShip_data": 0x803b63ec,
		"MoveBG::riccoPole_data": 0x803b6428,
		"riccoPole_data": 0x803b6428,
		"MoveBG::riccoLog_data": 0x803b6464,
		"riccoLog_data": 0x803b6464,
		"MoveBG::gesoSurfboard_data": 0x803b64a0,
		"gesoSurfboard_data": 0x803b64a0,
		"MoveBG::gesoSurfboardStatic_data": 0x803b64dc,
		"gesoSurfboardStatic_data": 0x803b64dc,
		"MoveBG::riccoWatermill_data": 0x803b6518,
		"riccoWatermill_data": 0x803b6518,
		"MoveBG::riccoShipLog_data": 0x803b6554,
		"riccoShipLog_data": 0x803b6554,
		"MoveBG::riccoShipDol_data": 0x803b6590,
		"riccoShipDol_data": 0x803b6590,
		"MoveBG::riccoYachtL_data": 0x803b65cc,
		"riccoYachtL_data": 0x803b65cc,
		"MoveBG::riccoYachtS_data": 0x803b6608,
		"riccoYachtS_data": 0x803b6608,
		"MoveBG::riccoBoatL_data": 0x803b6644,
		"riccoBoatL_data": 0x803b6644,
		"MoveBG::riccoBoatS_data": 0x803b6680,
		"riccoBoatS_data": 0x803b6680,
		"MoveBG::riccoBasket_data": 0x803b66bc,
		"riccoBasket_data": 0x803b66bc,
		"MoveBG::riccoGangway_data": 0x803b66f8,
		"riccoGangway_data": 0x803b66f8,
		"MoveBG::riccoShipFish_data": 0x803b6734,
		"riccoShipFish_data": 0x803b6734,
		"MoveBG::riccoShipGeso_data": 0x803b6770,
		"riccoShipGeso_data": 0x803b6770,
		"MoveBG::riccoSwitch_data": 0x803b67ac,
		"riccoSwitch_data": 0x803b67ac,
		"MoveBG::riccoSwitchShine_data": 0x803b67e8,
		"riccoSwitchShine_data": 0x803b67e8,
		"MoveBG::riccoFenceMaze_data": 0x803b6824,
		"riccoFenceMaze_data": 0x803b6824,
		"MoveBG::riccoStand_data": 0x803b6860,
		"riccoStand_data": 0x803b6860,
		"MoveBG::riccoGrille_data": 0x803b689c,
		"riccoGrille_data": 0x803b689c,
		"MoveBG::riccoArrow_data": 0x803b68d8,
		"riccoArrow_data": 0x803b68d8,
		"MoveBG::riccoStreetStall_data": 0x803b6914,
		"riccoStreetStall_data": 0x803b6914,
		"MoveBG::riccoHericopter_data": 0x803b6950,
		"riccoHericopter_data": 0x803b6950,
		"MoveBG::surfgeso_red_data": 0x803b698c,
		"surfgeso_red_data": 0x803b698c,
		"MoveBG::surfgeso_yellow_data": 0x803b69c8,
		"surfgeso_yellow_data": 0x803b69c8,
		"MoveBG::surfgeso_green_data": 0x803b6a04,
		"surfgeso_green_data": 0x803b6a04,
		"MoveBG::big_windmill_data": 0x803b6a40,
		"big_windmill_data": 0x803b6a40,
		"MoveBG::windmill_far_data": 0x803b6a7c,
		"windmill_far_data": 0x803b6a7c,
		"MoveBG::MiniWindmillL_data": 0x803b6ab8,
		"MiniWindmillL_data": 0x803b6ab8,
		"MoveBG::MiniWindmillS_data": 0x803b6af4,
		"MiniWindmillS_data": 0x803b6af4,
		"MoveBG::WindmillRoof_data": 0x803b6b30,
		"WindmillRoof_data": 0x803b6b30,
		"MoveBG::lamp_bianco_data": 0x803b6b6c,
		"lamp_bianco_data": 0x803b6b6c,
		"MoveBG::root_pakkun_data": 0x803b6ba8,
		"root_pakkun_data": 0x803b6ba8,
		"MoveBG::windmill_block_data": 0x803b6be4,
		"windmill_block_data": 0x803b6be4,
		"MoveBG::PolluterPakkun_data": 0x803b6c20,
		"PolluterPakkun_data": 0x803b6c20,
		"MoveBG::BiaBell_data": 0x803b6c5c,
		"BiaBell_data": 0x803b6c5c,
		"MoveBG::BiaWatermill00_data": 0x803b6c98,
		"BiaWatermill00_data": 0x803b6c98,
		"MoveBG::BiaWatermill01_data": 0x803b6cd4,
		"BiaWatermill01_data": 0x803b6cd4,
		"MoveBG::BiaWatermillVertical_data": 0x803b6d10,
		"BiaWatermillVertical_data": 0x803b6d10,
		"MoveBG::BiaTurnBridge_data": 0x803b6d4c,
		"BiaTurnBridge_data": 0x803b6d4c,
		"MoveBG::LeafBoat_data": 0x803b6d88,
		"LeafBoat_data": 0x803b6d88,
		"MoveBG::LeafBoatRotten_data": 0x803b6dc4,
		"LeafBoatRotten_data": 0x803b6dc4,
		"MoveBG::LampSeesaw_data": 0x803b6e00,
		"LampSeesaw_data": 0x803b6e00,
		"MoveBG::BiancoDoor_data": 0x803b6e3c,
		"BiancoDoor_data": 0x803b6e3c,
		"MoveBG::BiaBridge_data": 0x803b6e78,
		"BiaBridge_data": 0x803b6e78,
		"MoveBG::SandBird_data": 0x803b6eb4,
		"SandBird_data": 0x803b6eb4,
		"MoveBG::SandBirdBlock_data": 0x803b6ef0,
		"SandBirdBlock_data": 0x803b6ef0,
		"MoveBG::SkyIsland_data": 0x803b6f2c,
		"SkyIsland_data": 0x803b6f2c,
		"MoveBG::SandLeaf_data": 0x803b6f68,
		"SandLeaf_data": 0x803b6f68,
		"MoveBG::SandLeafBase00_data": 0x803b6fa4,
		"SandLeafBase00_data": 0x803b6fa4,
		"MoveBG::SandLeafBase01_data": 0x803b6fe0,
		"SandLeafBase01_data": 0x803b6fe0,
		"MoveBG::SandLeafBase02_data": 0x803b701c,
		"SandLeafBase02_data": 0x803b701c,
		"MoveBG::SandLeafBase03_data": 0x803b7058,
		"SandLeafBase03_data": 0x803b7058,
		"MoveBG::SandBomb_data": 0x803b7094,
		"SandBomb_data": 0x803b7094,
		"MoveBG::MirrorL_data": 0x803b70d0,
		"MirrorL_data": 0x803b70d0,
		"MoveBG::MirrorM_data": 0x803b710c,
		"MirrorM_data": 0x803b710c,
		"MoveBG::MirrorS_data": 0x803b7148,
		"MirrorS_data": 0x803b7148,
		"MoveBG::SandCastle_data": 0x803b7184,
		"SandCastle_data": 0x803b7184,
		"MoveBG::MammaBlockRotate_data": 0x803b71c0,
		"MammaBlockRotate_data": 0x803b71c0,
		"MoveBG::SandEgg_data": 0x803b71fc,
		"SandEgg_data": 0x803b71fc,
		"MoveBG::SandEggBroken_data": 0x803b7238,
		"SandEggBroken_data": 0x803b7238,
		"MoveBG::ShiningStone_data": 0x803b7274,
		"ShiningStone_data": 0x803b7274,
		"MoveBG::MammaSurfboard00_data": 0x803b72b0,
		"MammaSurfboard00_data": 0x803b72b0,
		"MoveBG::MammaSurfboard01_data": 0x803b72ec,
		"MammaSurfboard01_data": 0x803b72ec,
		"MoveBG::MammaSurfboard02_data": 0x803b7328,
		"MammaSurfboard02_data": 0x803b7328,
		"MoveBG::MammaSurfboard03_data": 0x803b7364,
		"MammaSurfboard03_data": 0x803b7364,
		"MoveBG::MammaSurfboardStand_data": 0x803b73a0,
		"MammaSurfboardStand_data": 0x803b73a0,
		"MoveBG::MammaYacht00_data": 0x803b73dc,
		"MammaYacht00_data": 0x803b73dc,
		"MoveBG::MammaYacht01_data": 0x803b7418,
		"MammaYacht01_data": 0x803b7418,
		"MoveBG::MammaYacht02_data": 0x803b7454,
		"MammaYacht02_data": 0x803b7454,
		"MoveBG::SandBombBase00_data": 0x803b7490,
		"SandBombBase00_data": 0x803b7490,
		"MoveBG::SandBombBaseMushroom_data": 0x803b74cc,
		"SandBombBaseMushroom_data": 0x803b74cc,
		"MoveBG::SandBombBasePyramid_data": 0x803b7508,
		"SandBombBasePyramid_data": 0x803b7508,
		"MoveBG::SandBombBaseShit_data": 0x803b7544,
		"SandBombBaseShit_data": 0x803b7544,
		"MoveBG::SandBombBaseStar_data": 0x803b7580,
		"SandBombBaseStar_data": 0x803b7580,
		"MoveBG::SandBombBaseTurtle_data": 0x803b75bc,
		"SandBombBaseTurtle_data": 0x803b75bc,
		"MoveBG::SandBombBaseFoot_data": 0x803b75f8,
		"SandBombBaseFoot_data": 0x803b75f8,
		"MoveBG::SandBombBaseHand_data": 0x803b7634,
		"SandBombBaseHand_data": 0x803b7634,
		"MoveBG::SandBombBaseStairs_data": 0x803b7670,
		"SandBombBaseStairs_data": 0x803b7670,
		"MoveBG::coral00_data": 0x803b76ac,
		"coral00_data": 0x803b76ac,
		"MoveBG::coral01_data": 0x803b76e8,
		"coral01_data": 0x803b76e8,
		"MoveBG::GoalWatermelon_data": 0x803b7724,
		"GoalWatermelon_data": 0x803b7724,
		"MoveBG::TeethOfJuicer_data": 0x803b7760,
		"TeethOfJuicer_data": 0x803b7760,
		"MoveBG::SandEggRepair_data": 0x803b779c,
		"SandEggRepair_data": 0x803b779c,
		"MoveBG::merrygoround_data": 0x803b77d8,
		"merrygoround_data": 0x803b77d8,
		"MoveBG::merry_egg_data": 0x803b7814,
		"merry_egg_data": 0x803b7814,
		"MoveBG::merry_pole_data": 0x803b7850,
		"merry_pole_data": 0x803b7850,
		"MoveBG::FerrisWheel_data": 0x803b788c,
		"FerrisWheel_data": 0x803b788c,
		"MoveBG::gondola_data": 0x803b78c8,
		"gondola_data": 0x803b78c8,
		"MoveBG::FerrisLOD_data": 0x803b7904,
		"FerrisLOD_data": 0x803b7904,
		"MoveBG::viking_data": 0x803b7940,
		"viking_data": 0x803b7940,
		"MoveBG::PinnaEntrance_data": 0x803b797c,
		"PinnaEntrance_data": 0x803b797c,
		"MoveBG::PinnaEntranceOpen_data": 0x803b79b8,
		"PinnaEntranceOpen_data": 0x803b79b8,
		"MoveBG::SirenaGate_data": 0x803b79f4,
		"SirenaGate_data": 0x803b79f4,
		"MoveBG::BalloonKoopaJr_data": 0x803b7a30,
		"BalloonKoopaJr_data": 0x803b7a30,
		"MoveBG::ShellCup_data": 0x803b7a6c,
		"ShellCup_data": 0x803b7a6c,
		"MoveBG::Gateshell_data": 0x803b7aa8,
		"Gateshell_data": 0x803b7aa8,
		"MoveBG::PinnaHangingBridgeBoard_data": 0x803b7ae4,
		"PinnaHangingBridgeBoard_data": 0x803b7ae4,
		"MoveBG::GateManta_data": 0x803b7b20,
		"GateManta_data": 0x803b7b20,
		"MoveBG::PinnaSunFlower_data": 0x803b7b5c,
		"PinnaSunFlower_data": 0x803b7b5c,
		"MoveBG::AmiKing_data": 0x803b7b98,
		"AmiKing_data": 0x803b7b98,
		"MoveBG::PinnaCoaster_data": 0x803b7bd4,
		"PinnaCoaster_data": 0x803b7bd4,
		"MoveBG::casinoroulette_data": 0x803b7c10,
		"casinoroulette_data": 0x803b7c10,
		"MoveBG::roulette00_data": 0x803b7c4c,
		"roulette00_data": 0x803b7c4c,
		"MoveBG::roulette01_data": 0x803b7c88,
		"roulette01_data": 0x803b7c88,
		"MoveBG::roulette02_data": 0x803b7cc4,
		"roulette02_data": 0x803b7cc4,
		"MoveBG::slotdrum_data": 0x803b7d00,
		"slotdrum_data": 0x803b7d00,
		"MoveBG::telesaslot_data": 0x803b7d3c,
		"telesaslot_data": 0x803b7d3c,
		"MoveBG::donchou_data": 0x803b7d78,
		"donchou_data": 0x803b7d78,
		"MoveBG::casino_panel_gate_data": 0x803b7db4,
		"casino_panel_gate_data": 0x803b7db4,
		"MoveBG::SakuCasino_data": 0x803b7df0,
		"SakuCasino_data": 0x803b7df0,
		"MoveBG::SirenabossWall_data": 0x803b7e2c,
		"SirenabossWall_data": 0x803b7e2c,
		"MoveBG::SirenaCasinoRoof_data": 0x803b7e68,
		"SirenaCasinoRoof_data": 0x803b7e68,
		"MoveBG::GlassBreak_data": 0x803b7ea4,
		"GlassBreak_data": 0x803b7ea4,
		"MoveBG::Closet_data": 0x803b7ee0,
		"Closet_data": 0x803b7ee0,
		"MoveBG::ChestRevolve_data": 0x803b7f1c,
		"ChestRevolve_data": 0x803b7f1c,
		"MoveBG::PosterTeresa_data": 0x803b7f58,
		"PosterTeresa_data": 0x803b7f58,
		"MoveBG::PictureTeresa_data": 0x803b7f94,
		"PictureTeresa_data": 0x803b7f94,
		"MoveBG::PanelBreak_data": 0x803b7fd0,
		"PanelBreak_data": 0x803b7fd0,
		"MoveBG::PanelRevolve_data": 0x803b800c,
		"PanelRevolve_data": 0x803b800c,
		"MoveBG::SirenaBlockBreak_data": 0x803b8048,
		"SirenaBlockBreak_data": 0x803b8048,
		"MoveBG::SirenaShop_data": 0x803b8084,
		"SirenaShop_data": 0x803b8084,
		"MoveBG::StainHotel_data": 0x803b80c0,
		"StainHotel_data": 0x803b80c0,
		"MoveBG::cogwheel_data": 0x803b80fc,
		"cogwheel_data": 0x803b80fc,
		"MoveBG::CogwheelPlate_data": 0x803b8138,
		"CogwheelPlate_data": 0x803b8138,
		"MoveBG::CogwheelPot_data": 0x803b8174,
		"CogwheelPot_data": 0x803b8174,
		"MoveBG::mare_float_house_data": 0x803b81b0,
		"mare_float_house_data": 0x803b81b0,
		"MoveBG::StopRock_physical_data": 0x803b81ec,
		"StopRock_physical_data": 0x803b81ec,
		"MoveBG::StopRock_physical_info": 0x803b8220,
		"StopRock_physical_info": 0x803b8220,
		"MoveBG::StopRock_data": 0x803b822c,
		"StopRock_data": 0x803b822c,
		"MoveBG::ElasticCode_data": 0x803b8268,
		"ElasticCode_data": 0x803b8268,
		"MoveBG::GrowthTree_data": 0x803b82a4,
		"GrowthTree_data": 0x803b82a4,
		"MoveBG::WireBellPurple_data": 0x803b82e0,
		"WireBellPurple_data": 0x803b82e0,
		"MoveBG::MuddyBoat_data": 0x803b831c,
		"MuddyBoat_data": 0x803b831c,
		"MoveBG::Puncher_data": 0x803b8358,
		"Puncher_data": 0x803b8358,
		"MoveBG::HatoPop_data": 0x803b8394,
		"HatoPop_data": 0x803b8394,
		"MoveBG::MareWaterJump_data": 0x803b83d0,
		"MareWaterJump_data": 0x803b83d0,
		"MoveBG::BumpyWall_data": 0x803b840c,
		"BumpyWall_data": 0x803b840c,
		"MoveBG::ExBottle_data": 0x803b8448,
		"ExBottle_data": 0x803b8448,
		"MoveBG::CoinFish_data": 0x803b8484,
		"CoinFish_data": 0x803b8484,
		"MoveBG::MareFall_data": 0x803b84c0,
		"MareFall_data": 0x803b84c0,
		"MoveBG::MareCork_data": 0x803b84fc,
		"MareCork_data": 0x803b84fc,
		"MoveBG::MonteRoot_data": 0x803b8538,
		"MonteRoot_data": 0x803b8538,
		"MoveBG::JumpMushroom_data": 0x803b8574,
		"JumpMushroom_data": 0x803b8574,
		"MoveBG::MonteGoalFlag_data": 0x803b85b0,
		"MonteGoalFlag_data": 0x803b85b0,
		"MoveBG::HangingBridgeBoard_data": 0x803b85ec,
		"HangingBridgeBoard_data": 0x803b85ec,
		"MoveBG::HangingBridge_data": 0x803b8628,
		"HangingBridge_data": 0x803b8628,
		"MoveBG::SwingBoard_data": 0x803b8664,
		"SwingBoard_data": 0x803b8664,
		"MoveBG::Fluff_data": 0x803b86a0,
		"Fluff_data": 0x803b86a0,
		"MoveBG::FluffManager_data": 0x803b86dc,
		"FluffManager_data": 0x803b86dc,
		"MoveBG::Bathtub_data": 0x803b8718,
		"Bathtub_data": 0x803b8718,
		"MoveBG::BathtubStand_data": 0x803b8754,
		"BathtubStand_data": 0x803b8754,
		"MoveBG::BathtubStandBreaking_animation": 0x803b8790,
		"BathtubStandBreaking_animation": 0x803b8790,
		"MoveBG::BathtubStandBreaking_data": 0x803b879c,
		"BathtubStandBreaking_data": 0x803b879c,
		"MoveBG::ex1_turn_lift_move_data": 0x803b87d8,
		"ex1_turn_lift_move_data": 0x803b87d8,
		"MoveBG::ex1_turn_lift_data": 0x803b87e4,
		"ex1_turn_lift_data": 0x803b87e4,
		"MoveBG::z_turn_disk_move_data": 0x803b8820,
		"z_turn_disk_move_data": 0x803b8820,
		"MoveBG::z_turn_disk_data": 0x803b882c,
		"z_turn_disk_data": 0x803b882c,
		"MoveBG::y_turn_lift_move_data": 0x803b8868,
		"y_turn_lift_move_data": 0x803b8868,
		"MoveBG::y_turn_lift_data": 0x803b8874,
		"y_turn_lift_data": 0x803b8874,
		"MoveBG::EXskyTumiki_data": 0x803b88b0,
		"EXskyTumiki_data": 0x803b88b0,
		"MoveBG::EXskyWindow_data": 0x803b88ec,
		"EXskyWindow_data": 0x803b88ec,
		"MoveBG::EXskySenro_data": 0x803b8928,
		"EXskySenro_data": 0x803b8928,
		"MoveBG::Nail_data": 0x803b8964,
		"Nail_data": 0x803b8964,
		"MoveBG::PachinkoNail_data": 0x803b89a0,
		"PachinkoNail_data": 0x803b89a0,
		"MoveBG::FileLoadBlockA_data": 0x803b89dc,
		"FileLoadBlockA_data": 0x803b89dc,
		"MoveBG::FileLoadBlockB_data": 0x803b8a18,
		"FileLoadBlockB_data": 0x803b8a18,
		"MoveBG::FileLoadBlockC_data": 0x803b8a54,
		"FileLoadBlockC_data": 0x803b8a54,
		"MoveBG::sObjDataTable": 0x803b8a90,
		"sObjDataTable": 0x803b8a90,
		"TMapObjGeneral::__vt": 0x803b9030,
		"TMapObjBaseManager::__vt": 0x803b9258,
		"TMerryPole::__vt": 0x803b9298,
		"TMapObjManager::__vt": 0x803b93fc,
		"TMapObjTurn::__vt": 0x803b9440,
		"TMapObjMessenger::__vt": 0x803b95b4,
		"TShine::mPromiLife": 0x803b9690,
		"mPromiLife": 0x803b9690,
		"TShine::mSenkoRate": 0x803b96a0,
		"mSenkoRate": 0x803b96a0,
		"TShine::mKiraRate": 0x803b96b0,
		"mKiraRate": 0x803b96b0,
		"TShine::mBowRate": 0x803b96c0,
		"mBowRate": 0x803b96c0,
		"TNozzleBox::__vt": 0x803b96d0,
		"TItemNozzle::__vt": 0x803b993c,
		"TEggYoshi::__vt": 0x803b9b20,
		"TShine::__vt": 0x803b9cfc,
		"TCoinBlue::__vt": 0x803b9ee0,
		"TCoinRed::__vt": 0x803ba0c4,
		"TCoinEmpty::__vt": 0x803ba2a8,
		"TFlowerCoin::__vt": 0x803ba48c,
		"TCoin::__vt": 0x803ba670,
		"TItem::__vt": 0x803ba854,
		"TItemManager::__vt": 0x803baa38,
		"TBasketReverse::__vt": 0x803baa78,
		"TRedCoinSwitch::__vt": 0x803babdc,
		"TMapObjSwitch::__vt": 0x803bad40,
		"THideObjInfo::__vt": 0x803baea4,
		"TMapObjWaterSpray::__vt": 0x803baf48,
		"TDamageObj::__vt": 0x803bb0ac,
		"TMapObjStartDemo::__vt": 0x803bb150,
		"TMapObjChangeStageHipDrop::__vt": 0x803bb2b4,
		"TMapObjChangeStage::__vt": 0x803bb418,
		"TMapObjBillboard::__vt": 0x803bb57c,
		"TManhole::__vt": 0x803bb6ec,
		"TDoor::__vt": 0x803bb8c8,
		"TSuperHipDropBlock::__vt": 0x803bba30,
		"TTelesaBlock::__vt": 0x803bbba0,
		"TJuiceBlock::__vt": 0x803bbd04,
		"TBrickBlock::__vt": 0x803bbe68,
		"TIceBlock::__vt": 0x803bbfd8,
		"TLeanBlock::__vt": 0x803bc13c,
		"TSandBlock::__vt": 0x803bc2a4,
		"TBreakableBlock::__vt": 0x803bc408,
		"TWoodLog::__vt": 0x803bc5e8,
		"TBellWatermill::__vt": 0x803bc750,
		"TBiancoBell::__vt": 0x803bc8c4,
		"TLampSeesawMain::__vt": 0x803bca28,
		"TLampSeesaw::__vt": 0x803bcb90,
		"TLeafBoatRotten::__vt": 0x803bccf8,
		"TLeafBoat::__vt": 0x803bce5c,
		"TBiancoMiniWindmill::__vt": 0x803bcfc0,
		"TBiancoWatermillVertical::__vt": 0x803bd130,
		"TBiancoWatermill::__vt": 0x803bd294,
		"TMapObjRootPakkun::__vt": 0x803bd3f8,
		"TBigWindmill::__vt": 0x803bd55c,
		"TPictureTelesa::__vt": 0x803bd6c0,
		"TPanelRevolve::__vt": 0x803bd83c,
		"TChestRevolve::__vt": 0x803bd9a0,
		"TWarpAreaActor::__vt": 0x803bdb04,
		"TSirenaCasinoRoof::__vt": 0x803bdba8,
		"TSirenabossWall::__vt": 0x803bdd0c,
		"TSakuCasino::__vt": 0x803bde70,
		"TCloset::__vt": 0x803bdfd4,
		"TDonchou::__vt": 0x803be144,
		"TCasinoPanelGate::__vt": 0x803be2a8,
		"TItemSlotDrum::__vt": 0x803be418,
		"TSlotDrum::__vt": 0x803be58c,
		"TRoulette::__vt": 0x803be700,
		"TRouletteSw::__vt": 0x803be868,
		"TFruitLauncher::__vt": 0x803be910,
		"TFruitSwitch::__vt": 0x803bea74,
		"TSurfGesoObj::__vt": 0x803bebd8,
		"TRiccoWatermill::__vt": 0x803bedbc,
		"TCraneCargo::__vt": 0x803bef20,
		"TCraneUpDown::__vt": 0x803bf088,
		"TCraneRotY::__vt": 0x803bf1ec,
		"TSandEgg::__vt": 0x803bf350,
		"TMammaMirrorMapOperator::__vt": 0x803bf4d8,
		"TGoalWatermelon::__vt": 0x803bf4fc,
		"TSandBird::__vt": 0x803bf7c4,
		"TMammaYacht::__vt": 0x803bf934,
		"TMammaBlockRotate::__vt": 0x803bfa98,
		"TShiningStone::__vt": 0x803bfbfc,
		"TLeanMirror::__vt": 0x803bfca0,
		"TSandCastle::__vt": 0x803bfe04,
		"TSandBombBase::__vt": 0x803bff88,
		"TSandBomb::__vt": 0x803c010c,
		"TSandLeafBase::__vt": 0x803c0270,
		"TSandBase::__vt": 0x803c03dc,
		"TSandLeaf::__vt": 0x803c0548,
		"TPinnaCoaster::__vt": 0x803c06b0,
		"TAmiKing::__vt": 0x803c0814,
		"TWaterRecoverObj::__vt": 0x803c0978,
		"TPinnaEntrance::__vt": 0x803c0adc,
		"TBalloonKoopaJr::__vt": 0x803c0c40,
		"TChangeStageMerrygoround::__vt": 0x803c0e1c,
		"TMerrygoround::__vt": 0x803c0f80,
		"TShellCup::__vt": 0x803c10e4,
		"TPinnaShell::__vt": 0x803c1248,
		"TViking::__vt": 0x803c12ec,
		"THorizontalViking::__vt": 0x803c1454,
		"TFerrisWheel::__vt": 0x803c15bc,
		"TGateShadow::__vt": 0x803c1720,
		"TMareEventPoint::__vt": 0x803c1748,
		"TMareCork::__vt": 0x803c17ec,
		"TMareFall::__vt": 0x803c1950,
		"TMuddyBoat::__vt": 0x803c1ab4,
		"TMapObjPuncher::__vt": 0x803c1c18,
		"TWireBell::__vt": 0x803c1d7c,
		"TMapObjGrowTree::__vt": 0x803c1ee0,
		"TMapObjElasticCode::__vt": 0x803c2044,
		"TCogwheel::__vt": 0x803c21a8,
		"TCogwheelScale::__vt": 0x803c230c,
		"TMapObjFlagManager::__vt": 0x803c2470,
		"TMapObjFlag::__vt": 0x803c2494,
		"TMapObjWave::__vt": 0x803c2540,
		"TMapObjFloatOnSea::__vt": 0x803c2568,
		"TSandPlane::__vt": 0x803c26d0,
		"TRockPlane::__vt": 0x803c27cc,
		"TMapObjPlane::__vt": 0x803c28c8,
		"TRideCloud::__vt": 0x803c29c8,
		"TBigWatermelon::__vt": 0x803c2b38,
		"TCoverFruit::__vt": 0x803c2d60,
		"TRandomFruit::__vt": 0x803c2ec4,
		"TResetFruit::__vt": 0x803c30b4,
		"TMapObjBall::__vt": 0x803c32a4,
		"TAirportEventSink::__vt": 0x803c3498,
		"TAirportSwitch::__vt": 0x803c34ec,
		"TTurboNozzleDoor::__vt": 0x803c36c8,
		"TDemoCannon::__vt": 0x803c382c,
		"TMareGate::__vt": 0x803c3990,
		"TMapObjSmoke::__vt": 0x803c3af4,
		"TDptMonteFence::__vt": 0x803c3c64,
		"TBellDolpic::__vt": 0x803c3dc8,
		"TMonumentShine::__vt": 0x803c3f2c,
		"TMapObjRevivalPollution::__vt": 0x803c4090,
		"TPolluterBase::__vt": 0x803c40b4,
		"TMapObjGrassManager::__vt": 0x803c4218,
		"TMapObjGrassGroup::__vt": 0x803c423c,
		"TMapObjPoleManager::__vt": 0x803c42e0,
		"TMapObjWaterFilter::__vt": 0x803c4308,
		"TMapObjSeaIndirect::__vt": 0x803c43a8,
		"MoveBG::gateMActorNames": 0x803c4480,
		"gateMActorNames": 0x803c4480,
		"MoveBG::gateNames$2573": 0x803c4494,
		"gateNames$2573": 0x803c4494,
		"TModelGate::__vt": 0x803c44ac,
		"TRailFence::__vt": 0x803c4638,
		"TFenceWaterH::__vt": 0x803c479c,
		"TFenceWater::__vt": 0x803c4908,
		"TRevolvingFenceInner::__vt": 0x803c4a74,
		"TRevolvingFenceOuter::__vt": 0x803c4bd8,
		"TFence::__vt": 0x803c4d3c,
		"TFileLoadBlock::__vt": 0x803c4ea0,
		"TMapObjOptionWall::__vt": 0x803c5004,
		"TWoodBlock::__vt": 0x803c50a8,
		"TRollBlock::__vt": 0x803c5218,
		"TRailBlock::__vt": 0x803c537c,
		"TNormalLift::__vt": 0x803c54ec,
		"TRailMapObj::__vt": 0x803c565c,
		"TFluffManager::__vt": 0x803c57d0,
		"TFluff::__vt": 0x803c5934,
		"TGoalFlag::__vt": 0x803c5a98,
		"TSwingBoard::__vt": 0x803c5bfc,
		"THangingBridge::__vt": 0x803c5d60,
		"THangingBridgeBoard::__vt": 0x803c5d84,
		"TJumpMushroom::__vt": 0x803c5eec,
		"TMapObjMonteRoot::__vt": 0x803c6050,
		"TMapObjTreeScale::__vt": 0x803c61b8,
		"TMapObjTree::__vt": 0x803c6394,
		"TMapObjSteam::__vt": 0x803c6570,
		"TJointCoin::__vt": 0x803c66e0,
		"TMapObjNail::__vt": 0x803c6850,
		"TPool::__vt": 0x803c69c0,
		"TPoolManager::__vt": 0x803c6b24,
		"TBathtub::__vt": 0x803c6b68,
		"TBathtubGrip::__vt": 0x803c6ccc,
		"TBathtubGripPartsHard::__vt": 0x803c6e30,
		"TBathtubGripPartsFragile::__vt": 0x803c6f2c,
		"TBathtubGripParts::__vt": 0x803c7028,
		"TJumpBase::__vt": 0x803c7128,
		"TMushroom1up::__vt": 0x803c728c,
		"TWoodBox::__vt": 0x803c73f0,
		"TBreakHideObj::__vt": 0x803c7560,
		"THideObjPictureTwin::__vt": 0x803c76d0,
		"TWaterHitPictureHideObj::__vt": 0x803c784c,
		"THipDropHideObj::__vt": 0x803c79c8,
		"TFruitBasketEvent::__vt": 0x803c7b38,
		"TFruitBasket::__vt": 0x803c7cb0,
		"TFruitHitHideObj::__vt": 0x803c7e28,
		"TWaterHitHideObj::__vt": 0x803c7f9c,
		"THideObj::__vt": 0x803c810c,
		"THideObjBase::__vt": 0x803c827c,
		"TLampTrapIron::__vt": 0x803c83f0,
		"TLampTrapIronHit::__vt": 0x803c8554,
		"TLampTrapSpike::__vt": 0x803c85f8,
		"TLampTrapSpikeHit::__vt": 0x803c875c,
		"TJointModel::__vt": 0x803b1ae8,
		"TJointModelManager::__vt": 0x803b1b20,
		"TJointObj::__vt": 0x803b1b48,
		"TMap::__vt": 0x803b1b70,
		"Map::@3341": 0x803b1b94,
		"TBGCheckListWarp::__vt": 0x803b1bd8,
		"TBGCheckList::__vt": 0x803b1be4,
		"TMapCollisionWarp::__vt": 0x803b1bf0,
		"TMapCollisionMove::__vt": 0x803b1c14,
		"TMapCollisionStatic::__vt": 0x803b1c38,
		"TMapCollisionBase::__vt": 0x803b1c5c,
		"TMapDrawWall::__vt": 0x803b1c80,
		"TMapEvent::__vt": 0x803b1ca8,
		"TMapEventSinkShadowMario::__vt": 0x803b1ce8,
		"TMapEventSinkBianco::__vt": 0x803b1d3c,
		"TMapEventSinkInPollutionReset::__vt": 0x803b1d90,
		"TMapEventSinkInPollution::__vt": 0x803b1de4,
		"TMapEventSink::__vt": 0x803b1e38,
		"TMirrorMapDrawBuf::__vt": 0x803b1e90,
		"TMirrorModelManager::__vt": 0x803b1eb4,
		"TMirrorModelObj::__vt": 0x803b1ed8,
		"TMirrorModel::__vt": 0x803b1ef4,
		"TMirrorCamera::__vt": 0x803b1f10,
		"Map::name_table$2428": 0x803b1fd8,
		"name_table$2428": 0x803b1fd8,
		"TMapModel::__vt": 0x803b1fec,
		"TMapModelManager::__vt": 0x803b2020,
		"TMapObjSoundGroup::__vt": 0x803b2048,
		"TMapModelActor::__vt": 0x803b2088,
		"TMapStaticObj::__vt": 0x803b212c,
		"TMapWireManager::__vt": 0x803b21d0,
		"TMapWireActor::__vt": 0x803b21f4,
		"TPollutionCounterBase::__vt": 0x803b22a8,
		"TPollutionCounterObj::__vt": 0x803b22bc,
		"TPollutionCounterLayer::__vt": 0x803b22d0,
		"Map::mare_name_table$2805": 0x803b22f0,
		"mare_name_table$2805": 0x803b22f0,
		"Map::name_table$2816": 0x803b2318,
		"name_table$2816": 0x803b2318,
		"TPollutionManager::__vt": 0x803b236c,
		"Map::@3043": 0x803b2394,
		"TPollutionLayerWallMinusX::__vt": 0x803b23b0,
		"TPollutionLayerWallMinusZ::__vt": 0x803b240c,
		"TPollutionObj::__vt": 0x803b2468,
		"TShimmer::__vt": 0x803b2490,
		"TSky::__vt": 0x803b2530,
		"TMapEventSirenaSink::__vt": 0x803b25d0,
		"Map::x_offset_table$2432": 0x803b2630,
		"x_offset_table$2432": 0x803b2630,
		"Map::z_offset_table$2433": 0x803b2658,
		"z_offset_table$2433": 0x803b2658,
		"TPollutionLayer::__vt": 0x803b2680,
		"TPollutionLayerWallBase::__vt": 0x803b26dc,
		"TPollutionLayerWallPlusX::__vt": 0x803b2738,
		"TPollutionLayerWallPlusZ::__vt": 0x803b2794,
		"TPollutionLayerWave::__vt": 0x803b27f0,
		"TPollutionTest::__vt": 0x803b2850,
		"TMarineSnow::__vt": 0x803b2878,
		"TDolpicEventRiccoMammaGate::__vt": 0x803b2918,
		"TDolpicEventBiancoGate::__vt": 0x803b2958,
		"TMareEventBumpyWall::__vt": 0x803b2998,
		"Map::@3790": 0x803b2afc,
		"TMareEventDepressWall::__vt": 0x803b2b1c,
		"TMareEventWallRock::__vt": 0x803b2b40,
		"TMareWallRock::__vt": 0x803b2b64,
		"TBathWaterManager::fileNames": 0x803b2ca0,
		"fileNames": 0x803b2ca0,
		"TBathWaterManager::__vt": 0x803b2ca8,
		"TBathWater::__vt": 0x803b2ccc,
		"TBathWaterMeshRenderer::__vt": 0x803b2d70,
		"TBathWaterRenderer::__vt": 0x803b2d84,
		"TBathWaterPreprocessor::__vt": 0x803b2d98,
		"TStickyStainManager::__vt": 0x803b2dc0,
		"TFlashPane::__vt": 0x803b02b0,
		"TMenuPlane::__vt": 0x803b02d4,
		"TMenuBase::__vt": 0x803b02f8,
		"TSMSFader::__vt": 0x803b0320,
		"GC2D::scDolpicNewsDolpic5_1": 0x803b0378,
		"scDolpicNewsDolpic5_1": 0x803b0378,
		"GC2D::scDolpicNewsDolpic5_4": 0x803b0384,
		"scDolpicNewsDolpic5_4": 0x803b0384,
		"GC2D::scDolpicNewsDolpic6": 0x803b0390,
		"scDolpicNewsDolpic6": 0x803b0390,
		"GC2D::scDolpicNewsDolpic7": 0x803b039c,
		"scDolpicNewsDolpic7": 0x803b039c,
		"GC2D::scDolpicNewsDolpic9": 0x803b0634,
		"scDolpicNewsDolpic9": 0x803b0634,
		"GC2D::scDolpicNewsDolpic10": 0x803b0640,
		"scDolpicNewsDolpic10": 0x803b0640,
		"TGCConsole2::__vt": 0x803b065c,
		"TTalk2D2::cColorTable": 0x803b0778,
		"TTalk2D2::__vt": 0x803b0790,
		"TPauseMenu2::__vt": 0x803b0918,
		"TSwitchHelpActor::__vt": 0x803b0940,
		"THelpActor::__vt": 0x803b09e8,
		"TCardSave::cMessageID": 0x803b0a90,
		"TCardSave::__vt": 0x803b0b68,
		"TCardLoad::cMessageID": 0x803b0cb8,
		"TCardLoad::__vt": 0x803b0d90,
		"TConsoleStr::__vt": 0x803b1040,
		"TSelectMenu::__vt": 0x803b1220,
		"TSelectGrad::__vt": 0x803b1290,
		"TSelectDir::__vt": 0x803b12b8,
		"TSelectShine::__vt": 0x803b1350,
		"TSelectShineManager::__vt": 0x803b1360,
		"TBlendPane::__vt": 0x803b1388,
		"TGuide::__vt": 0x803b1410,
		"TSunShine::__vt": 0x803b1468,
		"TSunGlass::__vt": 0x803b1490,
		"TShineFader::__vt": 0x803b14b8,
		"TProgSelect::__vt": 0x803b1620,
		"GC2D::camLoc$96": 0x803b1648,
		"camLoc$96": 0x803b1648,
		"GC2D::objPt$97": 0x803b1654,
		"objPt$97": 0x803b1654,
		"GC2D::up$98": 0x803b1660,
		"up$98": 0x803b1660,
		"GC2D::handle_table": 0x803b166c,
		"handle_table": 0x803b166c,
		"GC2D::handle_type": 0x803b16a8,
		"handle_type": 0x803b16a8,
		"TMovieSubTitle::__vt": 0x803b19a0,
		"TOptionSoundUnit::cSoundSettings": 0x803b19f0,
		"cSoundSettings": 0x803b19f0,
		"TOptionSoundUnit::cFlagInfos": 0x803b1a08,
		"cFlagInfos": 0x803b1a08,
		"TMovieRumble::__vt": 0x803b1ac0,
		"TConductor::__vt": 0x8039ea98,
		"Enemy::entry$2672": 0x8039eac0,
		"entry$2672": 0x8039eac0,
		"Enemy::entry$2684": 0x8039ead8,
		"entry$2684": 0x8039ead8,
		"Enemy::entry$2697": 0x8039eaf0,
		"entry$2697": 0x8039eaf0,
		"Enemy::entry$2706": 0x8039eb08,
		"entry$2706": 0x8039eb08,
		"TEffectExplosion::__vt": 0x8039eb20,
		"TEffectModelManager::__vt": 0x8039ec34,
		"TEffectExplosionManager::__vt": 0x8039ec88,
		"TEffectColumSand::__vt": 0x8039ecdc,
		"TEffectColumSandManager::__vt": 0x8039edf0,
		"TEffectBombColumWater::__vt": 0x8039ee44,
		"TEffectBombColumWaterManager::__vt": 0x8039ef58,
		"TEffectColumWater::__vt": 0x8039efac,
		"TEffectColumWaterManager::__vt": 0x8039f0c0,
		"TEffectModel::__vt": 0x8039f114,
		"TEffectObjManager::__vt": 0x8039f228,
		"TEffectObjBase::__vt": 0x8039f24c,
		"TEffectBiancoFunsui::__vt": 0x8039f300,
		"TEffectPinnaFunsui::__vt": 0x8039f3a4,
		"TSimpleEffect::__vt": 0x8039f448,
		"TEMarioManager::__vt": 0x8039f4f0,
		"TEMario::__vt": 0x8039f544,
		"TSpineEnemy::__vt": 0x8039f658,
		"TSolidStack<TNerveBase<TLiveActor>_const*>::__vt": 0x8039f76c,
		"TSpineBase<TLiveActor>::__vt": 0x8039f778,
		"TSolidStack<TPathNode>::__vt": 0x8039f788,
		"TEnemyPolluteModel::__vt": 0x8039f798,
		"TEnemyPolluteModelManager::__vt": 0x8039f7c0,
		"TEnemyAttachment::__vt": 0x8039f7e8,
		"TEnemyManager::__vt": 0x8039f940,
		"Enemy::marioAnimeFiles": 0x8039f9e8,
		"Enemy::recordFileNamesDolpic1": 0x803a0020,
		"recordFileNamesDolpic1": 0x803a0020,
		"Enemy::recordFileNamesMonteMan": 0x803a0040,
		"recordFileNamesMonteMan": 0x803a0040,
		"TEnemyMario::__vt": 0x803a007c,
		"Enemy::rikuGesso_bastable": 0x803a03b0,
		"rikuGesso_bastable": 0x803a03b0,
		"TNerveGessoTurn::__vt": 0x803a0424,
		"TNerveGessoLand::__vt": 0x803a0434,
		"TNerveGessoFindMario::__vt": 0x803a0444,
		"TNerveGessoRolling::__vt": 0x803a0454,
		"TNerveGessoFall::__vt": 0x803a0464,
		"TNerveGessoPollute::__vt": 0x803a0474,
		"TNerveGessoPunch::__vt": 0x803a0484,
		"TNerveGessoFreeze::__vt": 0x803a0494,
		"TNerveGessoStay::__vt": 0x803a04a4,
		"TGessoPolluteObj::__vt": 0x803a04b4,
		"TLandGesso::__vt": 0x803a05fc,
		"TSurfGesso::__vt": 0x803a07b4,
		"TGesso::__vt": 0x803a096c,
		"TGessoManager::__vt": 0x803a0b24,
		"TGessoPolluteModel::__vt": 0x803a0b7c,
		"TGessoPolluteModelManager::__vt": 0x803a0ba4,
		"Enemy::grDummyRail": 0x803a0c08,
		"grDummyRail": 0x803a0c08,
		"TGraphWeb::__vt": 0x803a0cd4,
		"Enemy::hanekuri_bastable": 0x803a0ce0,
		"hanekuri_bastable": 0x803a0ce0,
		"Enemy::hamukurianm_bastable": 0x803a0cf0,
		"hamukurianm_bastable": 0x803a0cf0,
		"TNerveDoroHanePrepareAttack::__vt": 0x803a0da4,
		"TNerveDoroHaneHitWater::__vt": 0x803a0db4,
		"TNerveDoroHaneRise::__vt": 0x803a0dc4,
		"TNerveFireHamuKuriRecover::__vt": 0x803a0dd4,
		"TNerveDoroHamuKuriRobCap::__vt": 0x803a0de4,
		"TNerveHaneHamuKuriMoveOnGraph::__vt": 0x803a0df4,
		"TNerveHaneHamuKuriUpWait::__vt": 0x803a0e04,
		"TNerveDangoHamuKuriWait::__vt": 0x803a0e14,
		"TNerveHamuKuriJitabata::__vt": 0x803a0e24,
		"TNerveHamuKuriLand::__vt": 0x803a0e34,
		"TNerveHamuKuriWallDie::__vt": 0x803a0e44,
		"TNerveHamuKuriBoundFreeze::__vt": 0x803a0e54,
		"TNerveHamuKuriGoForSearchActor::__vt": 0x803a0e64,
		"TDoroHamuKuri::__vt": 0x803a0e74,
		"TFireHamuKuri::__vt": 0x803a103c,
		"TBossDangoHamuKuri::__vt": 0x803a1204,
		"TDangoHamuKuri::__vt": 0x803a13cc,
		"THaneHamuKuri2::__vt": 0x803a1594,
		"TDoroHaneKuri::__vt": 0x803a175c,
		"THaneHamuKuri::__vt": 0x803a1924,
		"THamuKuri::__vt": 0x803a1aec,
		"TDoroHamuKuriManager::__vt": 0x803a1cb4,
		"TDoroHige::__vt": 0x803a1d0c,
		"TFireHamuKuriManager::__vt": 0x803a1d30,
		"TBossDangoHamuKuriManager::__vt": 0x803a1d88,
		"TDangoHamuKuriManager::__vt": 0x803a1de0,
		"TDoroHaneKuriManager::__vt": 0x803a1e38,
		"THaneHamuKuriManager::__vt": 0x803a1e90,
		"THamuKuriManager::__vt": 0x803a1ee8,
		"THamuKuriLauncher::__vt": 0x803a1f40,
		"Enemy::mameGesso_bastable": 0x803a2070,
		"mameGesso_bastable": 0x803a2070,
		"TNerveMameGessoWait::__vt": 0x803a20bc,
		"TNerveMameGessoObject::__vt": 0x803a20cc,
		"TNerveMameGessoThrown::__vt": 0x803a20dc,
		"TNerveMameGessoPickUp::__vt": 0x803a20ec,
		"TNerveMameGessoTrample::__vt": 0x803a20fc,
		"TNerveMameGessoJitabata::__vt": 0x803a210c,
		"TNerveMameGessoDamage::__vt": 0x803a211c,
		"TNerveMameGessoGraphJumpWander::__vt": 0x803a212c,
		"TMameGesso::__vt": 0x803a213c,
		"TMameGessoManager::__vt": 0x803a22f4,
		"Enemy::namekuri2_bastable": 0x803a2350,
		"namekuri2_bastable": 0x803a2350,
		"TNerveNKFollowMario::__vt": 0x803a2388,
		"TDiffusionNameKuri::__vt": 0x803a23a8,
		"TNerveNameKuriDrawPollute::__vt": 0x803a2560,
		"TNerveNameKuriDiffuse::__vt": 0x803a2570,
		"TNerveNameKuriExplosion::__vt": 0x803a2580,
		"TNerveNameKuriJumpAttackPrepare::__vt": 0x803a2590,
		"TNerveNameKuriJumpAttack::__vt": 0x803a25a0,
		"TNerveNameKuriLand::__vt": 0x803a25b0,
		"TDiffusionNameKuriManager::__vt": 0x803a25c0,
		"TNameKuri::__vt": 0x803a2618,
		"TNameIndParCallback::__vt": 0x803a27d0,
		"TNameKuriManager::__vt": 0x803a27e0,
		"TNameKuriLauncher::__vt": 0x803a2838,
		"Enemy::pakkun_bastable": 0x803a2968,
		"pakkun_bastable": 0x803a2968,
		"TNerveStayPakkunAppear::__vt": 0x803a29a8,
		"TNerveStayPakkunHide::__vt": 0x803a29b8,
		"TNervePakkunFreeze::__vt": 0x803a29c8,
		"TNervePakkunShoot::__vt": 0x803a29d8,
		"TNervePakkunHide::__vt": 0x803a29e8,
		"TNervePakkunAppear::__vt": 0x803a29f8,
		"TNervePakkunStay::__vt": 0x803a2a08,
		"TNervePakkunGenerate::__vt": 0x803a2a18,
		"TStayPakkun::__vt": 0x803a2a28,
		"TPakkunSeed::__vt": 0x803a2bd8,
		"TPakkun::__vt": 0x803a2d20,
		"TPakkunManager::__vt": 0x803a2ed0,
		"TNerveSmallEnemyChange::__vt": 0x803a2f40,
		"TNerveSmallEnemyWait::__vt": 0x803a2f50,
		"TNerveSmallEnemyHitWaterJump::__vt": 0x803a2f60,
		"TNerveSmallEnemyJump::__vt": 0x803a2f70,
		"TNerveSmallEnemyFreeze::__vt": 0x803a2f80,
		"TNerveSmallEnemyDie::__vt": 0x803a2f90,
		"TSmallEnemy::__vt": 0x803a2fa0,
		"TSmallEnemyManager::__vt": 0x803a3148,
		"TSpider::__vt": 0x803a31a0,
		"TNerveTypicalGraphWander::__vt": 0x803a31b0,
		"TTypicalManager::__vt": 0x803a31c0,
		"TTypicalEnemy::__vt": 0x803a3214,
		"TWalker::__vt": 0x803a3328,
		"TSolidStack<TBGCheckData_const*>::__vt": 0x803a3338,
		"TNerveWalkerTraceMario::__vt": 0x803a3348,
		"TNerveWalkerEscape::__vt": 0x803a3358,
		"TNerveWalkerPostAttack::__vt": 0x803a3368,
		"TNerveWalkerAttack::__vt": 0x803a3378,
		"TNerveWalkerGraphWander::__vt": 0x803a3388,
		"TNerveWalkerGenerate::__vt": 0x803a3398,
		"TWalkerEnemy::__vt": 0x803a33a8,
		"Enemy::bgeso_bastable": 0x803a3560,
		"bgeso_bastable": 0x803a3560,
		"TNerveBGRoll::__vt": 0x803a35d0,
		"TNerveBGPolDrop::__vt": 0x803a3620,
		"TNerveBGPollute::__vt": 0x803a3630,
		"TNerveBGDie::__vt": 0x803a3640,
		"TNerveBGTug::__vt": 0x803a3650,
		"TNerveBGTentacleDamage::__vt": 0x803a3660,
		"TNerveBGBeakDamage::__vt": 0x803a3670,
		"TNerveBGEyeDamage::__vt": 0x803a3680,
		"TNerveBGWait::__vt": 0x803a3690,
		"TBossGessoManager::__vt": 0x803a36a0,
		"TBossGesso::__vt": 0x803a36f4,
		"TBGBinder::__vt": 0x803a3808,
		"TBossGessoMtxCalc::__vt": 0x803a3818,
		"TBGBodyHit::__vt": 0x803a385c,
		"TBGEyeHit::__vt": 0x803a3900,
		"TBGBeakHit::__vt": 0x803a39a4,
		"Enemy::dennoko_bastable": 0x803a3a58,
		"dennoko_bastable": 0x803a3a58,
		"TNerveElecCarapaceReturn::__vt": 0x803a3ab8,
		"TNerveElecCarapaceWait::__vt": 0x803a3ac8,
		"TNerveElecCarapaceMove::__vt": 0x803a3ad8,
		"TNerveElecNokonokoAttack::__vt": 0x803a3ae8,
		"TNerveElecNokonokoRebirth::__vt": 0x803a3af8,
		"TNerveElecNokonokoFreeze::__vt": 0x803a3b08,
		"TNerveElecNokonokoTurn::__vt": 0x803a3b18,
		"TNerveElecNokonokoCollect::__vt": 0x803a3b28,
		"TNerveElecNokonokoShoot::__vt": 0x803a3b38,
		"TElecCarapace::__vt": 0x803a3b48,
		"TElecNokonoko::__vt": 0x803a3c90,
		"TElecNokonokoManager::__vt": 0x803a3e4c,
		"Enemy::telesa_bastable": 0x803a3ea8,
		"telesa_bastable": 0x803a3ea8,
		"TNerveKageMarioModokiWait::__vt": 0x803a3ef4,
		"TKageMarioModoki::__vt": 0x803a3f38,
		"TKageMarioModokiManager::__vt": 0x803a40f0,
		"TNerveTelesaTrample::__vt": 0x803a4148,
		"TNerveTelesaAttackMario::__vt": 0x803a4158,
		"TNerveTelesaFreeze::__vt": 0x803a4168,
		"TNerveTelesaDie::__vt": 0x803a4178,
		"TNerveTelesaImitate::__vt": 0x803a4188,
		"TMarioModokiTelesa::__vt": 0x803a4198,
		"TBoxTelesa::__vt": 0x803a4350,
		"TLoopTelesa::__vt": 0x803a4508,
		"TSeeTelesa::__vt": 0x803a46c0,
		"TTelesa::__vt": 0x803a4878,
		"TTelesaManager::__vt": 0x803a4a30,
		"Enemy::fireWanwan_bastable": 0x803a4a88,
		"fireWanwan_bastable": 0x803a4a88,
		"TNerveFireWanwanEscape::__vt": 0x803a4ac0,
		"TNerveFireWanwanFreeze::__vt": 0x803a4ad0,
		"TNerveFireWanwanFly::__vt": 0x803a4ae0,
		"TNerveFireWanwanHungTail::__vt": 0x803a4af0,
		"TNerveFireWanwanDie::__vt": 0x803a4b00,
		"TNerveFireWanwanRecover::__vt": 0x803a4b10,
		"TNerveFireWanwanRecoverGraph::__vt": 0x803a4b20,
		"TNerveFireWanwanTired::__vt": 0x803a4b30,
		"TNerveFireWanwanAttack::__vt": 0x803a4b40,
		"TNerveFireWanwanFindMario::__vt": 0x803a4b50,
		"TNerveFireWanwanTurn::__vt": 0x803a4b60,
		"TNerveFireWanwanGraphWander::__vt": 0x803a4b70,
		"TFireWanwan::__vt": 0x803a4b80,
		"TFireWanwanTailHit::__vt": 0x803a4d28,
		"TFireWanwanManager::__vt": 0x803a4ddc,
		"TStageEnemyInfo::__vt": 0x803a4e38,
		"TStageEnemyInfoTable::__vt": 0x803a4e58,
		"TNameRefPtrAryT<TStageEnemyInfo,JDrama::TNameRef>::__vt": 0x803a4e78,
		"TOneShotGenerator::__vt": 0x803a4e98,
		"TGenerator::__vt": 0x803a4f3c,
		"Enemy::bosspakkun_bastable": 0x803a4f60,
		"bosspakkun_bastable": 0x803a4f60,
		"TNerveBPCannonL::__vt": 0x803a4fd8,
		"TNerveBPWaitL::__vt": 0x803a4fe8,
		"TNerveBPBreakSleep::__vt": 0x803a4ff8,
		"TNerveBPSleep::__vt": 0x803a5008,
		"TNerveBPFall::__vt": 0x803a5018,
		"TNerveBPHover::__vt": 0x803a5028,
		"TNerveBPFlyPivot::__vt": 0x803a5038,
		"TNerveBPFlyCannon::__vt": 0x803a5048,
		"TNerveBPTouchDown::__vt": 0x803a5058,
		"TNerveBPFly::__vt": 0x803a5068,
		"TNerveBPTakeOff::__vt": 0x803a5078,
		"TNerveBPDie::__vt": 0x803a5088,
		"TNerveBPPreDie::__vt": 0x803a5098,
		"TNerveBPJumpReact::__vt": 0x803a50a8,
		"TNerveBPStompReact::__vt": 0x803a50b8,
		"TNerveBPSwing::__vt": 0x803a50c8,
		"TNerveBPGetUp::__vt": 0x803a50d8,
		"TNerveBPTumbleOut::__vt": 0x803a50e8,
		"TNerveBPTumble::__vt": 0x803a50f8,
		"TNerveBPTumbleIn::__vt": 0x803a5108,
		"TNerveBPSwallow::__vt": 0x803a5118,
		"TNerveBPPivot::__vt": 0x803a5128,
		"TNerveBPTornado::__vt": 0x803a5138,
		"TNerveBPVomit::__vt": 0x803a5148,
		"TNerveBPCannon::__vt": 0x803a5158,
		"TNerveBPWait::__vt": 0x803a5168,
		"TBossPakkunManager::__vt": 0x803a5178,
		"TBossPakkun::__vt": 0x803a51cc,
		"TBossPakkunMtxCalc::__vt": 0x803a52e0,
		"TBPNavel::__vt": 0x803a5324,
		"TBPHeadHit::__vt": 0x803a53c8,
		"TBPTornado::__vt": 0x803a546c,
		"TBPVomit::__vt": 0x803a5510,
		"TBPPolDrop::__vt": 0x803a5534,
		"Enemy::pukupuku_bastable": 0x803a55d8,
		"pukupuku_bastable": 0x803a55d8,
		"Enemy::moepuku_bastable": 0x803a5604,
		"moepuku_bastable": 0x803a5604,
		"TNerveTobiPukuSwimWander::__vt": 0x803a5630,
		"TNerveTobiPukuReturnLaunch::__vt": 0x803a5640,
		"TNerveTobiPukuPrepareFly::__vt": 0x803a5650,
		"TNerveTobiPukuBound::__vt": 0x803a5660,
		"TNerveTobiPukuLand::__vt": 0x803a5670,
		"TNerveTobiPukuDie::__vt": 0x803a5680,
		"TNerveTobiPukuPitiPiti::__vt": 0x803a5690,
		"TNerveTobiPukuFall::__vt": 0x803a56a0,
		"TNerveTobiPukuHitWater::__vt": 0x803a56b0,
		"TNerveTobiPukuAttack::__vt": 0x803a56c0,
		"TNerveTobiPukuFly::__vt": 0x803a56d0,
		"TNerveTobiPukuGenerate::__vt": 0x803a56e0,
		"TMoePuku::__vt": 0x803a56f0,
		"TPukuPuku::__vt": 0x803a58f0,
		"TTobiPuku::__vt": 0x803a5af0,
		"TMoePukuLaunchPad::__vt": 0x803a5cf0,
		"TTobiPukuLaunchPad::__vt": 0x803a5e9c,
		"TMoePukuManager::__vt": 0x803a6048,
		"TTobiPukuManager::__vt": 0x803a60a0,
		"TMoePukuLaunchPadManager::__vt": 0x803a60f8,
		"TTobiPukuLaunchPadManager::__vt": 0x803a6150,
		"Enemy::tinkoopa_bastable": 0x803a61e0,
		"tinkoopa_bastable": 0x803a61e0,
		"Enemy::TTinKoopa_jointNameTable": 0x803a6224,
		"TTinKoopa_jointNameTable": 0x803a6224,
		"Enemy::table$3029": 0x803a6278,
		"table$3029": 0x803a6278,
		"Enemy::table$3036": 0x803a62c0,
		"table$3036": 0x803a62c0,
		"Enemy::breastTrackJointNameTable": 0x803a6324,
		"breastTrackJointNameTable": 0x803a6324,
		"Enemy::bellyTrackJointNameTable": 0x803a633c,
		"bellyTrackJointNameTable": 0x803a633c,
		"Enemy::rightArmTrackJointNameTable": 0x803a6354,
		"rightArmTrackJointNameTable": 0x803a6354,
		"Enemy::leftArmTrackJointNameTable": 0x803a6364,
		"leftArmTrackJointNameTable": 0x803a6364,
		"TNerveTinKoopaBreak::__vt": 0x803a63d4,
		"TNerveTinKoopaDamage::__vt": 0x803a6444,
		"TNerveTinKoopaWait::__vt": 0x803a6454,
		"TTinKoopaManager::__vt": 0x803a6464,
		"TTinKoopaMtxCalc::__vt": 0x803a64b8,
		"TTinKoopaPartsBase::__vt": 0x803a64fc,
		"TTinKoopaFlame::__vt": 0x803a65fc,
		"TTinKoopa::__vt": 0x803a66a0,
		"Enemy::clauncher_bastable": 0x803a67b8,
		"clauncher_bastable": 0x803a67b8,
		"TCommonLauncherManager::__vt": 0x803a67c8,
		"TCommonLauncher::__vt": 0x803a681c,
		"TLauncherManager::__vt": 0x803a6948,
		"TLauncher::__vt": 0x803a699c,
		"Enemy::bwanwan_bastable": 0x803a6b00,
		"bwanwan_bastable": 0x803a6b00,
		"TNerveBWFall::__vt": 0x803a6b1c,
		"TNerveBWShake::__vt": 0x803a6c7c,
		"TNerveBWJumpAway::__vt": 0x803a6c8c,
		"TNerveBWDie::__vt": 0x803a6c9c,
		"TNerveBWJumpToBath::__vt": 0x803a6cac,
		"TNerveBWWakeup::__vt": 0x803a6cbc,
		"TNerveBWStun::__vt": 0x803a6ccc,
		"TNerveBWJump::__vt": 0x803a6cdc,
		"TNerveBWBark::__vt": 0x803a6cec,
		"TNerveBWRoll::__vt": 0x803a6cfc,
		"TNerveBWGraphWander::__vt": 0x803a6d0c,
		"TBossWanwanManager::__vt": 0x803a6d1c,
		"TBossWanwan::__vt": 0x803a6d70,
		"TBossWanwanMtxCalc::__vt": 0x803a6e84,
		"TBWBinder::__vt": 0x803a6ec8,
		"TBWHit::__vt": 0x803a6ed8,
		"TBWPicket::__vt": 0x803a6f7c,
		"TBWLeash::__vt": 0x803a7030,
		"TBWLeashNode::__vt": 0x803a7054,
		"Enemy::tyuhana_bastable": 0x803a70f8,
		"tyuhana_bastable": 0x803a70f8,
		"TNerveChuuHanaWait::__vt": 0x803a7144,
		"TNerveChuuHanaJumpPrepare::__vt": 0x803a7154,
		"TNerveChuuHanaAttack::__vt": 0x803a7164,
		"TNerveChuuHanaObject::__vt": 0x803a7174,
		"TNerveChuuHanaFall2::__vt": 0x803a7184,
		"TNerveChuuHanaFall::__vt": 0x803a7194,
		"TNerveChuuHanaRoll::__vt": 0x803a71a4,
		"TNerveChuuHanaStick::__vt": 0x803a71b4,
		"TNerveChuuHanaKeepBalance::__vt": 0x803a71c4,
		"TNerveChuuHanaForceJumped::__vt": 0x803a71d4,
		"TNerveChuuHanaWalkOnPanel::__vt": 0x803a71e4,
		"TChuuHana::__vt": 0x803a71f4,
		"TChuuHanaAseParCallback::__vt": 0x803a73ac,
		"TChuuHanaManager::__vt": 0x803a73bc,
		"Enemy::igaiga_bastable": 0x803a7418,
		"igaiga_bastable": 0x803a7418,
		"Enemy::gorogoro_bastable": 0x803a7438,
		"gorogoro_bastable": 0x803a7438,
		"TNerveGorogoroDie::__vt": 0x803a7478,
		"TNerveGorogoroRollOnGraph::__vt": 0x803a7488,
		"TGorogoro::__vt": 0x803a7498,
		"TGorogoroManager::__vt": 0x803a7668,
		"TGorogoroPolluteModel::__vt": 0x803a76c0,
		"TGorogoroPolluteModelManager::__vt": 0x803a76e8,
		"TNerveIgaigaShootFromCannon::__vt": 0x803a7710,
		"TNerveIgaigaWaterHit::__vt": 0x803a7720,
		"TNerveIgaigaRollOnGraph::__vt": 0x803a7730,
		"TIgaiga::__vt": 0x803a7740,
		"TIgaigaManager::__vt": 0x803a7910,
		"TIgaigaPolluteModel::__vt": 0x803a7968,
		"TIgaigaPolluteModelManager::__vt": 0x803a7990,
		"TRollEnemy::__vt": 0x803a79b8,
		"Enemy::poihana_bastable": 0x803a7b88,
		"poihana_bastable": 0x803a7b88,
		"TNervePoihanaTrapped::__vt": 0x803a7bc0,
		"TNervePoihanaThrow::__vt": 0x803a7bd0,
		"TNervePoihanaFreeze::__vt": 0x803a7be0,
		"TNervePoihanaSleep::__vt": 0x803a7bf0,
		"TSleepPoiHana::__vt": 0x803a7c00,
		"TPoiHanaRed::__vt": 0x803a7db8,
		"TPoiHana::__vt": 0x803a7f70,
		"TPoiHanaCollision::__vt": 0x803a8128,
		"TPoiHanaManager::__vt": 0x803a81cc,
		"Enemy::tamaNoko_bastable": 0x803a8228,
		"tamaNoko_bastable": 0x803a8228,
		"TNerveTamaNokoWait::__vt": 0x803a8284,
		"TNerveTamaNokoHitWater::__vt": 0x803a8294,
		"TNerveTamaNokoSink::__vt": 0x803a82a4,
		"TNerveTamaNokoThrown::__vt": 0x803a82b4,
		"TNerveTamaNokoPickUp::__vt": 0x803a82c4,
		"TNerveTamaNokoDown::__vt": 0x803a82d4,
		"TNerveTamaNokoAttack::__vt": 0x803a82e4,
		"TNerveTamaNokoSleep::__vt": 0x803a82f4,
		"TTamaNoko::__vt": 0x803a8304,
		"TTamaNokoManager::__vt": 0x803a84bc,
		"TTamaNokoFlower::__vt": 0x803a8514,
		"Enemy::btelesa_bastable": 0x803a8538,
		"btelesa_bastable": 0x803a8538,
		"TNerveBossTelesaFallDemo::__vt": 0x803a85d0,
		"TBossTelesaKillSmallEnemy::__vt": 0x803a85e0,
		"TNerveBossTelesaFreeze::__vt": 0x803a8684,
		"TNerveBossTelesaPrepareSlot::__vt": 0x803a8694,
		"TNerveBossTelesaSpitSlotItem::__vt": 0x803a86a4,
		"TNerveBossTelesaSlotStart::__vt": 0x803a86b4,
		"TNerveBossTelesaAppear::__vt": 0x803a86c4,
		"TNerveBossTelesaHideWait::__vt": 0x803a86d4,
		"TNerveBossTelesaHide::__vt": 0x803a86e4,
		"TNerveBossTelesaSpit::__vt": 0x803a86f4,
		"TNerveBossTelesaDie::__vt": 0x803a8704,
		"TBossTelesa::__vt": 0x803a8714,
		"TTelesaSlot::__vt": 0x803a8828,
		"TBossTelesaTongue::__vt": 0x803a8b0c,
		"TBossTelesaBody::__vt": 0x803a8bb0,
		"TBossTelesaManager::__vt": 0x803a8c54,
		"TNerveBubbleSplit::__vt": 0x803a8ca8,
		"TNerveBubbleLive::__vt": 0x803a8cb8,
		"TBubble::__vt": 0x803a8cc8,
		"TBubbleManager::__vt": 0x803a8e80,
		"TNerveRHGraphWander::__vt": 0x803a8ed8,
		"TRiccoHookManager::__vt": 0x803a8ee8,
		"TRiccoHook::__vt": 0x803a8f3c,
		"THookTake::__vt": 0x803a9050,
		"Enemy::bombhei_bastable": 0x803a9140,
		"bombhei_bastable": 0x803a9140,
		"TNerveBombHeiExplosion::__vt": 0x803a9180,
		"TNerveBombHeiThrown::__vt": 0x803a91d0,
		"TNerveBombHeiPickUp::__vt": 0x803a91e0,
		"TNerveBombHeiWaitExplosion::__vt": 0x803a91f0,
		"TNerveBombHeiWalkExplosion::__vt": 0x803a9200,
		"TNerveBombHeiAttack::__vt": 0x803a9210,
		"TNerveBombHeiGenerate::__vt": 0x803a9220,
		"TBombHei::__vt": 0x803a9230,
		"TBombHeiManager::__vt": 0x803a93e8,
		"Enemy::cannon_bastable": 0x803a9440,
		"cannon_bastable": 0x803a9440,
		"TNerveCannonObject::__vt": 0x803a949c,
		"TNerveCannonDamageDemo::__vt": 0x803a94ac,
		"TNerveCannonDamage::__vt": 0x803a94bc,
		"TNerveCannonClose::__vt": 0x803a94cc,
		"TNerveCannonForceBombShoot::__vt": 0x803a94dc,
		"TNerveCannonShoot::__vt": 0x803a94ec,
		"TNerveCannonSearch::__vt": 0x803a94fc,
		"TNerveCannonOpen::__vt": 0x803a950c,
		"TCannon::__vt": 0x803a951c,
		"TCannonDom::__vt": 0x803a96c8,
		"TChorobei::__vt": 0x803a96ec,
		"TCannonManager::__vt": 0x803a9790,
		"Enemy::bosseel_bastable": 0x803a9820,
		"bosseel_bastable": 0x803a9820,
		"Enemy::bossEelTears_bastable": 0x803a987c,
		"bossEelTears_bastable": 0x803a987c,
		"TNerveBossEelSleepOnBottom::__vt": 0x803a9900,
		"TNerveBossEelMouthOpenWait::__vt": 0x803a9974,
		"TNerveBossEelDie::__vt": 0x803a9984,
		"TNerveBossEelEat::__vt": 0x803a9994,
		"TNerveBossEelQuickBack::__vt": 0x803a99a4,
		"TNerveBossEelSlowBack::__vt": 0x803a99b4,
		"TNerveBossEelOutWait::__vt": 0x803a99c4,
		"TNerveBossEelAppear::__vt": 0x803a99d4,
		"TNerveBossEelSecondSpin::__vt": 0x803a99e4,
		"TNerveBossEelFirstSpin::__vt": 0x803a99f4,
		"TNerveBossEelWaitAppear::__vt": 0x803a9a04,
		"TBossEel::__vt": 0x803a9a14,
		"TBossEelTearsRecoverCollision::__vt": 0x803a9b28,
		"TBossEelBarrierCollision::__vt": 0x803a9bd4,
		"TBossEelAwaCollision::__vt": 0x803a9c80,
		"TBossEelBodyCollision::__vt": 0x803a9d2c,
		"TBossEelCollision::__vt": 0x803a9dd8,
		"TBossEelHeartCoin::__vt": 0x803a9e84,
		"TBossEelEye::__vt": 0x803a9ea8,
		"TBossEelVortex::__vt": 0x803a9ecc,
		"TBossEelTooth::__vt": 0x803a9f74,
		"TBossEelManager::__vt": 0x803aa018,
		"TNerveOilBallStay::__vt": 0x803aa06c,
		"TOilBall::__vt": 0x803aa07c,
		"TNerveBEelTearsSplit::__vt": 0x803aa194,
		"TNerveBEelTearsMarioRecover::__vt": 0x803aa1a4,
		"TNerveBEelTearsWaterHit::__vt": 0x803aa1b4,
		"TNerveBEelTearsMoveUp::__vt": 0x803aa1c4,
		"TNerveBEelTearsGenerate::__vt": 0x803aa1d4,
		"TBEelTears::__vt": 0x803aa1e4,
		"TBEelTearsManager::__vt": 0x803aa2fc,
		"TBEelTearsDrop::__vt": 0x803aa350,
		"TNerveKillerExplosion::__vt": 0x803aa468,
		"TKiller::__vt": 0x803aa4b8,
		"TKillerManager::__vt": 0x803aa67c,
		"TNerveFlyEnemyChaseFly::__vt": 0x803aa6d4,
		"TNerveFlyEnemyNormalFly::__vt": 0x803aa6e4,
		"TFlyEnemy::__vt": 0x803aa6f4,
		"TBeamManager::__vt": 0x803aa8b8,
		"Enemy::sambo_bastable": 0x803aa8e0,
		"sambo_bastable": 0x803aa8e0,
		"TNerveSamboHeadHitWall::__vt": 0x803aa9a4,
		"TNerveSamboHeadRecoverWater::__vt": 0x803aa9b4,
		"TNerveSamboHeadHitWater::__vt": 0x803aa9c4,
		"TNerveSamboHeadHide::__vt": 0x803aa9d4,
		"TNerveSamboHeadAttack::__vt": 0x803aa9e4,
		"TNerveSamboHeadAppear::__vt": 0x803aa9f4,
		"TSamboHead::__vt": 0x803aaa04,
		"TSamboHeadManager::__vt": 0x803aabbc,
		"TNerveHanaSamboFreeze::__vt": 0x803aac14,
		"TNerveHanaSamboDie::__vt": 0x803aac24,
		"TNerveHanaSamboHide::__vt": 0x803aac34,
		"TNerveHanaSamboAttack::__vt": 0x803aac44,
		"TNerveHanaSamboWait::__vt": 0x803aac54,
		"TNerveHanaSamboAppear::__vt": 0x803aac64,
		"THanaSambo::__vt": 0x803aac74,
		"THanaSamboHead::__vt": 0x803aae1c,
		"THanaSamboManager::__vt": 0x803aaec0,
		"TSamboFlower::__vt": 0x803aaf18,
		"TSamboFlowerManager::__vt": 0x803ab030,
		"TSamboLeaf::__vt": 0x803ab088,
		"Enemy::popo_bastable": 0x803ab0b0,
		"popo_bastable": 0x803ab0b0,
		"TNervePopoThrown::__vt": 0x803ab0f0,
		"TNervePopoWait::__vt": 0x803ab100,
		"TNervePopoExplosion::__vt": 0x803ab110,
		"TNervePopoFly::__vt": 0x803ab120,
		"TNervePopoAttack::__vt": 0x803ab130,
		"TNervePopoPossessedNozzle::__vt": 0x803ab140,
		"TPopo::__vt": 0x803ab150,
		"TPopoCollision::__vt": 0x803ab308,
		"TPopoManager::__vt": 0x803ab3ac,
		"TNerveSBH_Fall::__vt": 0x803ab408,
		"TNerveSBH_SleepContinue::__vt": 0x803ab418,
		"TSleepBossHanachan::__vt": 0x803ab428,
		"TSleepBossHanachanManager::__vt": 0x803ab53c,
		"TDemoBossHanachan::__vt": 0x803ab590,
		"TDemoBossHanachanManager::__vt": 0x803ab6a4,
		"TNerveFruitsBoatBckTrace::__vt": 0x803ab6f8,
		"TNerveFruitsBoatGraphWander::__vt": 0x803ab708,
		"TFruitsBoatManager::__vt": 0x803ab718,
		"TFruitsBoat::__vt": 0x803ab76c,
		"TWaterHitActor::__vt": 0x803ab880,
		"Enemy::sChangeSaveFileName$2712": 0x803ab928,
		"sChangeSaveFileName$2712": 0x803ab928,
		"Enemy::entry$2725": 0x803ab934,
		"entry$2725": 0x803ab934,
		"TBossHanachan::__vt": 0x803ab964,
		"TBossHanachanManager::__vt": 0x803aba78,
		"TNerveBossHanachanDead::__vt": 0x803abad0,
		"TNerveBossHanachanSnort::__vt": 0x803abae0,
		"TNerveBossHanachanDamage::__vt": 0x803abaf0,
		"TNerveBossHanachanGetUp::__vt": 0x803abb00,
		"TNerveBossHanachanDown::__vt": 0x803abb10,
		"TNerveBossHanachanTumble::__vt": 0x803abb20,
		"TNerveBossHanachanGraphWander::__vt": 0x803abb30,
		"TBossHanachanPartsHead::__vt": 0x803abb40,
		"TFootHitActor::__vt": 0x803abc88,
		"TBossHanachanPartsBody::__vt": 0x803abd2c,
		"Enemy::amiNoko_bastable": 0x803abe30,
		"amiNoko_bastable": 0x803abe30,
		"TNerveAmiNokoFreeze::__vt": 0x803abe88,
		"TNerveAmiNokoDie::__vt": 0x803abe98,
		"TNerveAmiNokoTurn::__vt": 0x803abea8,
		"TNerveAmiNokoWalkOnFence::__vt": 0x803abeb8,
		"TAmiNoko::__vt": 0x803abec8,
		"TAmiHit::__vt": 0x803ac080,
		"TAmiNokoManager::__vt": 0x803ac124,
		"Enemy::gatekeeper_bastable": 0x803ac180,
		"gatekeeper_bastable": 0x803ac180,
		"TNerveBGKLaunchName::__vt": 0x803ac1d0,
		"TBGKObstacle::__vt": 0x803ac1e0,
		"TNerveBGKLaunchGoro::__vt": 0x803ac284,
		"TNerveBGKDive::__vt": 0x803ac294,
		"TNerveBGKDie::__vt": 0x803ac2a4,
		"TNerveBGKAwakeDamage::__vt": 0x803ac2b4,
		"TNerveBGKSleepDamage::__vt": 0x803ac2c4,
		"TNerveBGKWait2::__vt": 0x803ac2d4,
		"TNerveBGKWait::__vt": 0x803ac2e4,
		"TNerveBGKAppear::__vt": 0x803ac2f4,
		"TNerveBGKSleep::__vt": 0x803ac304,
		"TBiancoGateKeeper::__vt": 0x803ac314,
		"TBGKMtxCalc::__vt": 0x803ac428,
		"TBiancoGateKeeperManager::__vt": 0x803ac46c,
		"TGateKeeperBase::__vt": 0x803ac4c4,
		"TGKHitObj::__vt": 0x803ac5d8,
		"TEggGenManager::__vt": 0x803ac680,
		"TEggGenerator::__vt": 0x803ac6d4,
		"TNerveSealDie::__vt": 0x803ac7e8,
		"TNerveSealWait::__vt": 0x803ac7f8,
		"TNerveSealSleep::__vt": 0x803ac808,
		"TSealManager::__vt": 0x803ac818,
		"TSeal::__vt": 0x803ac86c,
		"TBGPolDrop::__vt": 0x803ac980,
		"Enemy::tstatestr": 0x803aca58,
		"tstatestr": 0x803aca58,
		"TBGTentacle::__vt": 0x803aca94,
		"TBGAttackHit::__vt": 0x803accb8,
		"TBGTakeHit::__vt": 0x803acd5c,
		"TBGTentacleMtxCalc::__vt": 0x803ace10,
		"TEffectEnemy::__vt": 0x803ace68,
		"TEffectEnemyManager::__vt": 0x803ad020,
		"Enemy::hauntleg_bastable": 0x803ad078,
		"hauntleg_bastable": 0x803ad078,
		"TNerveHauntLegHaunt::__vt": 0x803ad090,
		"THauntLeg::__vt": 0x803ad0a0,
		"THauntedObject::__vt": 0x803ad258,
		"THauntLegManager::__vt": 0x803ad2fc,
		"TAreaCylinderManager::__vt": 0x803ad358,
		"TAreaCylinder::__vt": 0x803ad37c,
		"TNerveWireTrapGoWait::__vt": 0x803ad3a0,
		"TNerveWireTrapWait::__vt": 0x803ad3e0,
		"TNerveWireTrapSearch::__vt": 0x803ad3f0,
		"TNerveWireTrapOnewayMoveEnd::__vt": 0x803ad400,
		"TNerveWireTrapOnewayMove::__vt": 0x803ad410,
		"TNerveWireTrapOnewayMoveStart::__vt": 0x803ad420,
		"TNerveWireTrapReturnMove::__vt": 0x803ad430,
		"TWireTrapManager::__vt": 0x803ad440,
		"TWireTrap::__vt": 0x803ad494,
		"Enemy::bosshanachan_bastable": 0x803ad5a8,
		"bosshanachan_bastable": 0x803ad5a8,
		"TBossHanachanPartsBase::__vt": 0x803ad640,
		"Enemy::rocket_bastable": 0x803ad740,
		"rocket_bastable": 0x803ad740,
		"TNerveRocketWait::__vt": 0x803ad768,
		"TNerveRocketFly::__vt": 0x803ad778,
		"TNerveRocketPossessedNozzle::__vt": 0x803ad788,
		"TRocket::__vt": 0x803ad798,
		"TRocketManager::__vt": 0x803ad940,
		"Enemy::Kazekun_bastable": 0x803ad998,
		"Kazekun_bastable": 0x803ad998,
		"TNerveKazekunHitWater::__vt": 0x803ad9ac,
		"TNerveKazekunWait::__vt": 0x803ad9bc,
		"TNerveKazekunDisappear::__vt": 0x803ad9cc,
		"TNerveKazekunAttack::__vt": 0x803ad9dc,
		"TNerveKazekunPreAttack::__vt": 0x803ad9ec,
		"TNerveKazekunTurn::__vt": 0x803ad9fc,
		"TNerveKazekunAppear::__vt": 0x803ada0c,
		"TNerveKazekunSearch::__vt": 0x803ada1c,
		"TKazekunManager::__vt": 0x803ada2c,
		"TKazekun::__vt": 0x803ada84,
		"TBossManta::sFrameRate": 0x803adc30,
		"sFrameRate": 0x803adc30,
		"TBossManta::sScale": 0x803adc48,
		"sScale": 0x803adc48,
		"Enemy::onetimeFilenames$3261": 0x803adc60,
		"onetimeFilenames$3261": 0x803adc60,
		"Enemy::loopFilenames$3273": 0x803adc74,
		"loopFilenames$3273": 0x803adc74,
		"TBossMantaManager::__vt": 0x803adc9c,
		"TBossMantaAdditionalCollision::__vt": 0x803adcf0,
		"TBossManta::__vt": 0x803add94,
		"TNerveMantaAppearDemo::__vt": 0x803adea8,
		"TNerveMantaDeath::__vt": 0x803adeb8,
		"TNerveMantaSpawn::__vt": 0x803adec8,
		"TNerveMantaHitWater::__vt": 0x803aded8,
		"TNerveMantaMove::__vt": 0x803adee8,
		"TWireBinder::__vt": 0x803adef8,
		"TNerveYumboFreeze::__vt": 0x803adf3c,
		"TNerveYumboAttack::__vt": 0x803adf4c,
		"TNerveYumboAppearing::__vt": 0x803adf5c,
		"TNerveYumboHiding::__vt": 0x803adf6c,
		"TNerveYumboDancing::__vt": 0x803adf7c,
		"TYumbo::__vt": 0x803adf8c,
		"TYumboManager::__vt": 0x803ae134,
		"TYumboSeed::__vt": 0x803ae18c,
		"Enemy::TKoopaJr_jointNameTable": 0x803ae248,
		"TKoopaJr_jointNameTable": 0x803ae248,
		"TKoopaJrSubmarineManager::__vt": 0x803ae25c,
		"TNerveKoopaJrSubmarineLaunchKiller::__vt": 0x803ae2b0,
		"TNerveKoopaJrSubmarineCannonOpenClose::__vt": 0x803ae2c0,
		"TNerveKoopaJrSubmarineWait::__vt": 0x803ae2d0,
		"TKoopaJrSubmarine::__vt": 0x803ae2e0,
		"TKoopaJrManager::__vt": 0x803ae3f4,
		"TNerveKoopaJrYahoo::__vt": 0x803ae448,
		"TNerveKoopaJrLaunch::__vt": 0x803ae458,
		"TNerveKoopaJrDemo::__vt": 0x803ae468,
		"TNerveKoopaJrDamage::__vt": 0x803ae478,
		"TNerveKoopaJrWait::__vt": 0x803ae488,
		"TKoopaJr::__vt": 0x803ae498,
		"TCallbackHitActor::__vt": 0x803ae5ac,
		"Enemy::kumokun_bastable": 0x803ae650,
		"kumokun_bastable": 0x803ae650,
		"Enemy::kumokun_bas_c_table": 0x803ae684,
		"kumokun_bas_c_table": 0x803ae684,
		"TNerveKumokunPreFly::__vt": 0x803ae6b8,
		"TSolidStack<char_const*>::__vt": 0x803ae6c8,
		"TNerveKumokunFly::__vt": 0x803ae6d4,
		"TNerveKumokunPostFreeze::__vt": 0x803ae6e4,
		"TNerveKumokunFreeze::__vt": 0x803ae6f4,
		"TNerveKumokunWait::__vt": 0x803ae704,
		"TNerveKumokunSearch::__vt": 0x803ae714,
		"TNerveKumokunPostWalk::__vt": 0x803ae724,
		"TNerveKumokunWalk::__vt": 0x803ae734,
		"TNerveKumokunPreWalk::__vt": 0x803ae744,
		"TKumokunManager::__vt": 0x803ae754,
		"TKumokun::__vt": 0x803ae7ac,
		"Enemy::koopa_bastable": 0x803ae958,
		"koopa_bastable": 0x803ae958,
		"TKoopaManager::__vt": 0x803ae994,
		"TNerveKoopaTurnR::__vt": 0x803aea24,
		"TNerveKoopaTurnL::__vt": 0x803aea34,
		"TNerveKoopaTurn::__vt": 0x803aea44,
		"TKoopa::__vt": 0x803aea54,
		"TKoopaBody::__vt": 0x803aeb68,
		"TKoopaHead::__vt": 0x803aec14,
		"TKoopaHand::__vt": 0x803aecc0,
		"TKoopaFlame::__vt": 0x803aed6c,
		"TKoopaParts::__vt": 0x803aee18,
		"TNerveKoopaGetDown::__vt": 0x803aeec4,
		"TNerveKoopaGetShowered::__vt": 0x803aeed4,
		"TNerveKoopaStagger::__vt": 0x803aeee4,
		"TNerveKoopaProvoke::__vt": 0x803aeef4,
		"TNerveKoopaFlame::__vt": 0x803aef04,
		"TNerveKoopaFall::__vt": 0x803aef14,
		"TNerveKoopaTumble::__vt": 0x803aef24,
		"TNerveKoopaWait::__vt": 0x803aef34,
		"Enemy::tori_bastable": 0x803aef48,
		"tori_bastable": 0x803aef48,
		"TNerveKukkuRecoverGraph::__vt": 0x803aef60,
		"TNerveKukkuPostFall::__vt": 0x803aef70,
		"TNerveKukkuFall::__vt": 0x803aef80,
		"TNerveKukkuGraphWander::__vt": 0x803aef90,
		"TKukku::__vt": 0x803aefa0,
		"TKukkuManager::__vt": 0x803af148,
		"TKukkuBall::__vt": 0x803af1a0,
		"Enemy::amenbo_bastable": 0x803af248,
		"amenbo_bastable": 0x803af248,
		"TNerveAmenboHitWater::__vt": 0x803af264,
		"TNerveAmenboWalk::__vt": 0x803af274,
		"TNerveAmenboPreAttack::__vt": 0x803af284,
		"TNerveAmenboTurn::__vt": 0x803af294,
		"TNerveAmenboSearch::__vt": 0x803af2a4,
		"TAmenbo::__vt": 0x803af2b4,
		"TAmenboManager::__vt": 0x803af45c,
		"Enemy::bathtubpeach_bastable": 0x803af4b8,
		"bathtubpeach_bastable": 0x803af4b8,
		"TBathtubPeachManager::__vt": 0x803af514,
		"TNervePeachEscape::__vt": 0x803af568,
		"TNervePeachStagger::__vt": 0x803af578,
		"TBathtubPeach::__vt": 0x803af588,
		"Enemy::bathtubkiller_bastable": 0x803af6a0,
		"bathtubkiller_bastable": 0x803af6a0,
		"TBathtubKillerManager::__vt": 0x803af6d0,
		"TNerveBathtubKillerExplosion::__vt": 0x803af728,
		"TNerveBathtubKillerBreak::__vt": 0x803af738,
		"TNerveBathtubKillerStraight::__vt": 0x803af748,
		"TNerveBathtubKillerChaseStraight::__vt": 0x803af758,
		"TNerveBathtubKillerChase::__vt": 0x803af768,
		"TNerveBathtubKillerWander::__vt": 0x803af778,
		"TBathtubKiller::__vt": 0x803af788,
		"TCoasterKillerManager::__vt": 0x803af968,
		"TNerveCoasterKillerExplosion::__vt": 0x803af9c0,
		"TCoasterKiller::__vt": 0x803af9d0,
		"TNerveCoasterEnemyWander::__vt": 0x803afb94,
		"TCoasterEnemy::__vt": 0x803afba4,
		"TNerveDebuTelesaWait::__vt": 0x803afd68,
		"TDebuTelesaManager::__vt": 0x803afd78,
		"TDebuTelesa::__vt": 0x803afdd0,
		"Enemy::tabepuku_bastable": 0x803aff78,
		"tabepuku_bastable": 0x803aff78,
		"TNerveTabePukuDrag::__vt": 0x803aff84,
		"TNerveTabePukuDive::__vt": 0x803aff94,
		"TNerveTabePukuBite::__vt": 0x803affa4,
		"TNerveTabePukuAttack::__vt": 0x803affb4,
		"TNerveTabePukuRecoverGraph::__vt": 0x803affc4,
		"TNerveTabePukuFound::__vt": 0x803affd4,
		"TNerveTabePukuGraphWander::__vt": 0x803affe4,
		"TTabePukuManager::__vt": 0x803afff4,
		"TTabePuku::__vt": 0x803b004c,
		"TTPHitActor::__vt": 0x803b01f4,
		"TBathtubBinder::__vt": 0x803b02a0,
		"CPolarSubCamera::__vt": 0x803d9dc0,
		"Camera::@1790": 0x803d9fa0,
		"Camera::sNoticeActorManagerName": 0x803da088,
		"sNoticeActorManagerName": 0x803da088,
		"CPolarSubCamera::sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803da098,
		"sPositionNameTable$localstatic0$calcTowerCenterPos_": 0x803da098,
		"TLensFlare::__vt": 0x803da0b0,
		"TLensGlow::__vt": 0x803da0d8,
		"TSunMgr::__vt": 0x803da100,
		"TSunModel::__vt": 0x803da138,
		"TCubeManagerBase::__vt": 0x803da1d8,
		"TCameraMapTool::__vt": 0x803da200,
		"TCubeStreamInfo::__vt": 0x803da220,
		"TCubeCameraInfo::__vt": 0x803da240,
		"TCubeGeneralInfo::__vt": 0x803da260,
		"Camera::sAddBckFileNameTable": 0x803da280,
		"sAddBckFileNameTable": 0x803da280,
		"CPolarSubCamera::mCamKindNameSaveFile": 0x803da290,
		"mCamKindNameSaveFile": 0x803da290,
		"Camera::@1781": 0x803da3b4,
		"TCameraShake::mCamShakeNameSave": 0x803da828,
		"mCamShakeNameSave": 0x803da828,
		"TBoidLeader::__vt": 0x8039d500,
		"TFishoidManager::__vt": 0x8039d548,
		"TFishoid::__vt": 0x8039d670,
		"TFish::__vt": 0x8039d788,
		"TRealoid::__vt": 0x8039d840,
		"TRealoidActor::__vt": 0x8039d958,
		"TAnimalBase::__vt": 0x8039da10,
		"TMewManager::__vt": 0x8039db28,
		"TAnimalManagerBase::__vt": 0x8039db7c,
		"TNerveAnimalGraphWander::__vt": 0x8039dc00,
		"Animal::bird_bastable": 0x8039dc10,
		"bird_bastable": 0x8039dc10,
		"TNerveAnimalBirdLanding::__vt": 0x8039dc34,
		"TNerveAnimalBirdPreLanding::__vt": 0x8039dc44,
		"TNerveAnimalBirdComeback::__vt": 0x8039dc54,
		"TNerveAnimalBirdChangeToCoin::__vt": 0x8039dc64,
		"TNerveAnimalBirdGraphWander::__vt": 0x8039dc74,
		"TNerveAnimalBirdTakeoff::__vt": 0x8039dc84,
		"TNerveAnimalBirdWalkOnGround::__vt": 0x8039dc94,
		"TNerveAnimalBirdActionOnGround::__vt": 0x8039dca4,
		"TNerveAnimalBirdWaitOnGround::__vt": 0x8039dcb4,
		"TAnimalBirdManager::__vt": 0x8039dcc4,
		"TAnimalBird::__vt": 0x8039dd18,
		"TNerveBeeHiveReset::__vt": 0x8039de30,
		"TNerveBeeHiveMarioWaterIn::__vt": 0x8039de40,
		"TNerveBeeHiveAttack::__vt": 0x8039de50,
		"TNerveBeeHiveBreak::__vt": 0x8039de60,
		"TNerveBeeHiveFall::__vt": 0x8039de70,
		"TNerveBeeHiveWait::__vt": 0x8039de80,
		"TBeeHiveManager::__vt": 0x8039de90,
		"TBeeHive::__vt": 0x8039dee4,
		"TBee::__vt": 0x8039dffc,
		"TButterfloidManager::__vt": 0x8039e0b8,
		"TButterfloid::__vt": 0x8039e10c,
		"TButterfly::__vt": 0x8039e224,
		"main::gpApplication": 0x803da8e0,
		"gpApplication": 0x803da8e0,
		"Animal::@2305": 0x803da930,
		"MSound::@2063": 0x803dad98,
		"MSound::@3781": 0x803dada8,
		"MSound::@3782": 0x803dadb4,
		"MSound::@3783": 0x803dadc0,
		"MSound::@3784": 0x803dadcc,
		"MSound::@3785": 0x803dadd8,
		"MSound::@3786": 0x803dade4,
		"MSound::@3787": 0x803dadf0,
		"MSound::@3788": 0x803dadfc,
		"MSound::@3789": 0x803dae08,
		"MSound::@3790": 0x803dae14,
		"MSound::@3791": 0x803dae20,
		"MSound::@3792": 0x803dae2c,
		"MSound::@3793": 0x803dae38,
		"MSound::@3794": 0x803dae44,
		"MSound::@3795": 0x803dae50,
		"MSound::@3200": 0x803dbd44,
		"MSound::@3201": 0x803dbd50,
		"MSound::@3202": 0x803dbd5c,
		"MSound::@3203": 0x803dbd68,
		"GC2D::@12016": 0x803e4b78,
		"@12016": 0x803e4b78,
		"GC2D::@12017": 0x803e4b84,
		"@12017": 0x803e4b84,
		"GC2D::@12018": 0x803e4b90,
		"@12018": 0x803e4b90,
		"GC2D::@12019": 0x803e4b9c,
		"@12019": 0x803e4b9c,
		"GC2D::@12020": 0x803e4ba8,
		"@12020": 0x803e4ba8,
		"GC2D::@12021": 0x803e4bb4,
		"@12021": 0x803e4bb4,
		"GC2D::@12022": 0x803e4bc0,
		"@12022": 0x803e4bc0,
		"GC2D::@12023": 0x803e4bcc,
		"@12023": 0x803e4bcc,
		"GC2D::@12024": 0x803e4bd8,
		"@12024": 0x803e4bd8,
		"GC2D::@12025": 0x803e4be4,
		"@12025": 0x803e4be4,
		"GC2D::@12026": 0x803e4bf0,
		"@12026": 0x803e4bf0,
		"GC2D::@12027": 0x803e4bfc,
		"@12027": 0x803e4bfc,
		"GC2D::@12028": 0x803e4c08,
		"@12028": 0x803e4c08,
		"GC2D::@12029": 0x803e4c14,
		"@12029": 0x803e4c14,
		"GC2D::@12030": 0x803e4c20,
		"@12030": 0x803e4c20,
		"GC2D::@4961": 0x803e4c30,
		"GC2D::@4962": 0x803e4c3c,
		"GC2D::@4963": 0x803e4c48,
		"GC2D::@4964": 0x803e4c54,
		"GC2D::@4965": 0x803e4c60,
		"GC2D::@4966": 0x803e4c6c,
		"GC2D::@4967": 0x803e4c78,
		"GC2D::@4968": 0x803e4c84,
		"GC2D::@4969": 0x803e4c90,
		"GC2D::@4970": 0x803e4c9c,
		"GC2D::@4971": 0x803e4ca8,
		"GC2D::@4972": 0x803e4cb4,
		"GC2D::@4973": 0x803e4cc0,
		"GC2D::@4974": 0x803e4ccc,
		"GC2D::@4975": 0x803e4cd8,
		"GC2D::@7040": 0x803e4da0,
		"@7040": 0x803e4da0,
		"GC2D::@7041": 0x803e4dac,
		"@7041": 0x803e4dac,
		"GC2D::@7042": 0x803e4db8,
		"@7042": 0x803e4db8,
		"GC2D::@7043": 0x803e4dc4,
		"@7043": 0x803e4dc4,
		"GC2D::@7044": 0x803e4dd0,
		"@7044": 0x803e4dd0,
		"GC2D::@7045": 0x803e4ddc,
		"@7045": 0x803e4ddc,
		"GC2D::@7046": 0x803e4de8,
		"@7046": 0x803e4de8,
		"GC2D::@7047": 0x803e4df4,
		"@7047": 0x803e4df4,
		"GC2D::@7048": 0x803e4e00,
		"@7048": 0x803e4e00,
		"GC2D::@7049": 0x803e4e0c,
		"@7049": 0x803e4e0c,
		"GC2D::@7050": 0x803e4e18,
		"@7050": 0x803e4e18,
		"GC2D::@7051": 0x803e4e24,
		"@7051": 0x803e4e24,
		"GC2D::@7052": 0x803e4e30,
		"@7052": 0x803e4e30,
		"GC2D::@7053": 0x803e4e3c,
		"@7053": 0x803e4e3c,
		"GC2D::@7054": 0x803e4e48,
		"@7054": 0x803e4e48,
		"GC2D::@8433": 0x803e4e94,
		"GC2D::@8434": 0x803e4ea0,
		"GC2D::@8435": 0x803e4eac,
		"GC2D::@8436": 0x803e4eb8,
		"GC2D::@8437": 0x803e4ec4,
		"GC2D::@8438": 0x803e4ed0,
		"GC2D::@8439": 0x803e4edc,
		"GC2D::@8440": 0x803e4ee8,
		"GC2D::@8441": 0x803e4ef4,
		"GC2D::@8442": 0x803e4f00,
		"GC2D::@2259": 0x803e84e0,
		"GC2D::@2260": 0x803e84ec,
		"GC2D::@2264": 0x803e851c,
		"GC2D::@2266": 0x803e8534,
		"GC2D::@2268": 0x803e854c,
		"GC2D::@2270": 0x803e8564,
		"GC2D::@2272": 0x803e857c,
		"GC2D::@2273": 0x803e8588,
		"MoveBG::@5432": 0x803ea76c,
		"MoveBG::@5433": 0x803ea778,
		"System::@2660": 0x803ed4bc,
		"System::@2661": 0x803ed4c8,
		"System::@2662": 0x803ed4d4,
		"System::@2663": 0x803ed4e0,
		"System::@2665": 0x803ed4f8,
		"System::@2666": 0x803ed504,
		"System::@2667": 0x803ed510,
		"Camera::@3184": 0x803f5030,
		"Camera::@3185": 0x803f503c,
		"Camera::@2275": 0x803f51b0,
		"Camera::@2276": 0x803f51bc,
		"Camera::@2277": 0x803f51c8,
		"Camera::@2278": 0x803f51d4,
		"Camera::@2279": 0x803f51e0,
		"Camera::@2280": 0x803f51ec,
		"Camera::@2281": 0x803f51f8,
		"Camera::@2282": 0x803f5204,
		"Camera::@2283": 0x803f5210,
		"Enemy::@3173": 0x803e0f9c,
		"Enemy::@6774": 0x803e1170,
		"@6774": 0x803e1170,
		"Enemy::@3231": 0x803e1234,
		"Enemy::@3868": 0x803e13b4,
		"@3868": 0x803e13b4,
		"Enemy::@8476": 0x803e13f0,
		"@8476": 0x803e13f0,
		"Enemy::@2575": 0x803e1610,
		"Enemy::@2676": 0x803e1634,
		"Enemy::@2728": 0x803e1658,
		"Enemy::@2755": 0x803e1664,
		"Enemy::@4067": 0x803e16e8,
		"Enemy::@4068": 0x803e16f4,
		"Enemy::@4756": 0x803e1760,
		"Enemy::@4757": 0x803e176c,
		"Enemy::@3256": 0x803e192c,
		"Enemy::@2617": 0x803e1a30,
		"Enemy::@2628": 0x803e1a3c,
		"Enemy::@9293": 0x803e1b9c,
		"@9293": 0x803e1b9c,
		"Enemy::@9294": 0x803e1ba8,
		"@9294": 0x803e1ba8,
		"Enemy::@9295": 0x803e1bb4,
		"@9295": 0x803e1bb4,
		"Enemy::@9296": 0x803e1bc0,
		"@9296": 0x803e1bc0,
		"Enemy::@9297": 0x803e1bcc,
		"@9297": 0x803e1bcc,
		"Enemy::@9298": 0x803e1bd8,
		"@9298": 0x803e1bd8,
		"Enemy::@9299": 0x803e1be4,
		"@9299": 0x803e1be4,
		"Enemy::@9300": 0x803e1bf0,
		"@9300": 0x803e1bf0,
		"Enemy::@9301": 0x803e1bfc,
		"@9301": 0x803e1bfc,
		"Enemy::@9302": 0x803e1c08,
		"@9302": 0x803e1c08,
		"Enemy::@9303": 0x803e1c14,
		"@9303": 0x803e1c14,
		"Enemy::@9304": 0x803e1c20,
		"@9304": 0x803e1c20,
		"Enemy::@9305": 0x803e1c2c,
		"@9305": 0x803e1c2c,
		"Enemy::@9306": 0x803e1c38,
		"@9306": 0x803e1c38,
		"Enemy::@9307": 0x803e1c44,
		"@9307": 0x803e1c44,
		"Enemy::@5542": 0x803e1de8,
		"@5542": 0x803e1de8,
		"Enemy::@9741": 0x803e1f9c,
		"@9741": 0x803e1f9c,
		"Enemy::@9742": 0x803e1fa8,
		"@9742": 0x803e1fa8,
		"Enemy::up$3221": 0x803e1fb8,
		"up$3221": 0x803e1fb8,
		"Enemy::up$3267": 0x803e1fc4,
		"up$3267": 0x803e1fc4,
		"Enemy::goal$3320": 0x803e1fd0,
		"goal$3320": 0x803e1fd0,
		"Enemy::start$3323": 0x803e1fdc,
		"start$3323": 0x803e1fdc,
		"Enemy::goal$3327": 0x803e1fe8,
		"goal$3327": 0x803e1fe8,
		"Enemy::start$3330": 0x803e1ff4,
		"start$3330": 0x803e1ff4,
		"Enemy::s$3577": 0x803e2000,
		"s$3577": 0x803e2000,
		"Enemy::@3720": 0x803e203c,
		"Enemy::@8446": 0x803e21bc,
		"@8446": 0x803e21bc,
		"Enemy::@8447": 0x803e21c8,
		"@8447": 0x803e21c8,
		"Enemy::@8448": 0x803e21d4,
		"@8448": 0x803e21d4,
		"Enemy::@8449": 0x803e21e0,
		"@8449": 0x803e21e0,
		"Enemy::@8450": 0x803e21ec,
		"@8450": 0x803e21ec,
		"Enemy::@3201": 0x803e26a8,
		"Enemy::@3222": 0x803e26c0,
		"Enemy::@5936": 0x803e26fc,
		"Enemy::@5937": 0x803e2708,
		"Enemy::@5938": 0x803e2714,
		"Enemy::@5939": 0x803e2720,
		"Enemy::@5940": 0x803e272c,
		"Enemy::@5941": 0x803e2738,
		"@5941": 0x803e2738,
		"Enemy::@5942": 0x803e2744,
		"@5942": 0x803e2744,
		"Enemy::@5943": 0x803e2750,
		"@5943": 0x803e2750,
		"Enemy::@5944": 0x803e275c,
		"@5944": 0x803e275c,
		"Enemy::@5945": 0x803e2768,
		"@5945": 0x803e2768,
		"Enemy::@5946": 0x803e2774,
		"@5946": 0x803e2774,
		"Enemy::@5947": 0x803e2780,
		"@5947": 0x803e2780,
		"Enemy::@5948": 0x803e278c,
		"@5948": 0x803e278c,
		"Enemy::@5949": 0x803e2798,
		"@5949": 0x803e2798,
		"Enemy::@5950": 0x803e27a4,
		"@5950": 0x803e27a4,
		"Enemy::@3164": 0x803e28b8,
		"Enemy::@4636": 0x803e2960,
		"Enemy::@5302": 0x803e29e8,
		"Enemy::@5304": 0x803e2a00,
		"Enemy::@5305": 0x803e2a0c,
		"Enemy::@5306": 0x803e2a18,
		"Enemy::@4084": 0x803e2ad0,
		"Enemy::@4129": 0x803e2af4,
		"Enemy::@4196": 0x803e2b18,
		"Enemy::@9251": 0x803e2bd8,
		"@9251": 0x803e2bd8,
		"Enemy::@3080": 0x803e2cd8,
		"Enemy::@3090": 0x803e2ce4,
		"Enemy::@6278": 0x803e2e94,
		"@6278": 0x803e2e94,
		"Enemy::@6279": 0x803e2ea0,
		"@6279": 0x803e2ea0,
		"Enemy::@3227": 0x803e2ed4,
		"Enemy::@3801": 0x803e2f1c,
		"Enemy::@3814": 0x803e2f28,
		"Enemy::@9455": 0x803e2f94,
		"@9455": 0x803e2f94,
		"Enemy::@9456": 0x803e2fa0,
		"@9456": 0x803e2fa0,
		"Enemy::@9457": 0x803e2fac,
		"@9457": 0x803e2fac,
		"Enemy::@9458": 0x803e2fb8,
		"@9458": 0x803e2fb8,
		"Enemy::@9459": 0x803e2fc4,
		"@9459": 0x803e2fc4,
		"Enemy::@9460": 0x803e2fd0,
		"@9460": 0x803e2fd0,
		"Enemy::@9461": 0x803e2fdc,
		"@9461": 0x803e2fdc,
		"Enemy::@9462": 0x803e2fe8,
		"@9462": 0x803e2fe8,
		"Enemy::@2775": 0x803e3398,
		"Enemy::@3707": 0x803e3458,
		"Enemy::@3079": 0x803e3710,
		"Enemy::@4585": 0x803e374c,
		"@4585": 0x803e374c,
		"Enemy::@4587": 0x803e3764,
		"@4587": 0x803e3764,
		"Enemy::@4591": 0x803e3794,
		"Enemy::@4592": 0x803e37a0,
		"Enemy::@4593": 0x803e37ac,
		"Enemy::@4594": 0x803e37b8,
		"Enemy::@3418": 0x803e380c,
		"Enemy::@5811": 0x803e3848,
		"Enemy::@5812": 0x803e3854,
		"@5812": 0x803e3854,
		"Enemy::@5813": 0x803e3860,
		"@5813": 0x803e3860,
		"Enemy::@5814": 0x803e386c,
		"@5814": 0x803e386c,
		"Enemy::@5815": 0x803e3878,
		"@5815": 0x803e3878,
		"Enemy::@5816": 0x803e3884,
		"@5816": 0x803e3884,
		"Enemy::@5817": 0x803e3890,
		"@5817": 0x803e3890,
		"Enemy::@5818": 0x803e389c,
		"@5818": 0x803e389c,
		"Enemy::@6694": 0x803e3b48,
		"@6694": 0x803e3b48,
		"Enemy::@6695": 0x803e3b54,
		"@6695": 0x803e3b54,
		"Enemy::@6696": 0x803e3b60,
		"@6696": 0x803e3b60,
		"Enemy::@6697": 0x803e3b6c,
		"@6697": 0x803e3b6c,
		"Enemy::@2686": 0x803e3d90,
		"Enemy::@2723": 0x803e3dc0,
		"Enemy::@4174": 0x803e41c4,
		"Enemy::@4175": 0x803e41d0,
		"Enemy::@4176": 0x803e41dc,
		"Enemy::@4182": 0x803e4224,
		"Enemy::@4183": 0x803e4230,
		"Enemy::@4184": 0x803e423c,
		"Enemy::@4185": 0x803e4248,
		"Enemy::@3322": 0x803e42bc,
		"Enemy::@6243": 0x803e42e0,
		"@6243": 0x803e42e0,
		"Enemy::@6244": 0x803e42ec,
		"@6244": 0x803e42ec,
		"Enemy::@6245": 0x803e42f8,
		"@6245": 0x803e42f8,
		"Enemy::@6250": 0x803e4334,
		"@6250": 0x803e4334,
		"Enemy::@2665": 0x803e4388,
		"Enemy::@2677": 0x803e4394,
		"Enemy::@2716": 0x803e43b8,
		"Enemy::@2756": 0x803e43dc,
		"Enemy::@4852": 0x803e45e8,
		"Enemy::@4853": 0x803e45f4,
		"Enemy::@2532": 0x803e4618,
		"Enemy::@2544": 0x803e4624,
		"Enemy::@2578": 0x803e4648,
		"Enemy::@3906": 0x803e48d0,
		"@3906": 0x803e48d0,
		"Enemy::@3907": 0x803e48dc,
		"GC2D::@3390": 0x803e4d00,
		"GC2D::@3391": 0x803e4d0c,
		"GC2D::@3392": 0x803e4d18,
		"GC2D::@3400": 0x803e4d78,
		"GC2D::@3401": 0x803e4d84,
		"GC2D::@3402": 0x803e4d90,
		"GC2D::@8428": 0x803e4e58,
		"@8428": 0x803e4e58,
		"GC2D::@8429": 0x803e4e64,
		"@8429": 0x803e4e64,
		"GC2D::@8430": 0x803e4e70,
		"@8430": 0x803e4e70,
		"GC2D::@8431": 0x803e4e7c,
		"GC2D::@8432": 0x803e4e88,
		"GC2D::@4130": 0x803e5090,
		"Map::@3827": 0x803e8c20,
		"Map::@3828": 0x803e8c2c,
		"Map::@3829": 0x803e8c38,
		"Map::@3830": 0x803e8c44,
		"Map::@3831": 0x803e8c50,
		"Map::@2683": 0x803e8ee8,
		"Map::@3658": 0x803e8f40,
		"Map::@3659": 0x803e8f4c,
		"Map::@3660": 0x803e8f58,
		"Map::@3661": 0x803e8f64,
		"Map::@3662": 0x803e8f70,
		"Map::@3663": 0x803e8f7c,
		"Map::@3664": 0x803e8f88,
		"Map::@3665": 0x803e8f94,
		"Map::@3666": 0x803e8fa0,
		"Map::@3667": 0x803e8fac,
		"Map::@3672": 0x803e8fe8,
		"Map::@2937": 0x803e9110,
		"Map::@2800": 0x803e95b8,
		"Map::@2801": 0x803e95c4,
		"Map::@2802": 0x803e95d0,
		"Map::@2804": 0x803e95e8,
		"Map::@2805": 0x803e95f4,
		"Map::@3117": 0x803e9ba4,
		"Map::@3118": 0x803e9bb0,
		"Map::@3119": 0x803e9bbc,
		"Map::@3120": 0x803e9bc8,
		"Map::@3121": 0x803e9bd4,
		"Map::@3122": 0x803e9be0,
		"Map::@5861": 0x803e9ca8,
		"Map::@5862": 0x803e9cb4,
		"Map::@5863": 0x803e9cc0,
		"Map::@5864": 0x803e9ccc,
		"Map::@5865": 0x803e9cd8,
		"Map::@5866": 0x803e9ce4,
		"Map::@5867": 0x803e9cf0,
		"Map::@5868": 0x803e9cfc,
		"Map::@5869": 0x803e9d08,
		"Map::@5870": 0x803e9d14,
		"Map::@5871": 0x803e9d20,
		"Map::@5872": 0x803e9d2c,
		"Map::@5873": 0x803e9d38,
		"Map::@5874": 0x803e9d44,
		"Map::@5875": 0x803e9d50,
		"MoveBG::@4334": 0x803ea040,
		"MoveBG::@4339": 0x803ea07c,
		"MoveBG::@4340": 0x803ea088,
		"MoveBG::@4341": 0x803ea094,
		"MoveBG::@4342": 0x803ea0a0,
		"MoveBG::@4926": 0x803ea1b0,
		"MoveBG::@4927": 0x803ea1bc,
		"MoveBG::@4928": 0x803ea1c8,
		"MoveBG::@4929": 0x803ea1d4,
		"MoveBG::@4930": 0x803ea1e0,
		"MoveBG::@4931": 0x803ea1ec,
		"MoveBG::@4932": 0x803ea1f8,
		"MoveBG::@4933": 0x803ea204,
		"MoveBG::@4934": 0x803ea210,
		"MoveBG::@4935": 0x803ea21c,
		"MoveBG::@4936": 0x803ea228,
		"MoveBG::@4937": 0x803ea234,
		"MoveBG::@4938": 0x803ea240,
		"MoveBG::@4939": 0x803ea24c,
		"MoveBG::@4940": 0x803ea258,
		"MoveBG::@2756": 0x803ea268,
		"MoveBG::@2757": 0x803ea274,
		"MoveBG::@2758": 0x803ea280,
		"MoveBG::@2759": 0x803ea28c,
		"MoveBG::@2761": 0x803ea2a4,
		"MoveBG::@2763": 0x803ea2bc,
		"MoveBG::@2764": 0x803ea2c8,
		"MoveBG::@2765": 0x803ea2d4,
		"MoveBG::@2766": 0x803ea2e0,
		"MoveBG::@5315": 0x803ea548,
		"MoveBG::@5316": 0x803ea554,
		"MoveBG::@5317": 0x803ea560,
		"MoveBG::@5318": 0x803ea56c,
		"MoveBG::@5319": 0x803ea578,
		"MoveBG::@5320": 0x803ea584,
		"MoveBG::@5321": 0x803ea590,
		"MoveBG::@5322": 0x803ea59c,
		"MoveBG::@5323": 0x803ea5a8,
		"MoveBG::@5324": 0x803ea5b4,
		"MoveBG::@5325": 0x803ea5c0,
		"MoveBG::@5326": 0x803ea5cc,
		"MoveBG::@5327": 0x803ea5d8,
		"MoveBG::@5328": 0x803ea5e4,
		"MoveBG::@5329": 0x803ea5f0,
		"MoveBG::@4428": 0x803ea818,
		"MoveBG::@4429": 0x803ea824,
		"MoveBG::@4430": 0x803ea830,
		"MoveBG::@5466": 0x803ead50,
		"MoveBG::@5467": 0x803ead5c,
		"MoveBG::@5468": 0x803ead68,
		"MoveBG::@5469": 0x803ead74,
		"MoveBG::@5470": 0x803ead80,
		"MoveBG::@5471": 0x803ead8c,
		"MoveBG::@5472": 0x803ead98,
		"MoveBG::@5473": 0x803eada4,
		"MoveBG::@5474": 0x803eadb0,
		"MoveBG::@5475": 0x803eadbc,
		"MoveBG::@5476": 0x803eadc8,
		"MoveBG::@5477": 0x803eadd4,
		"MoveBG::@4518": 0x803eb4a0,
		"MoveBG::@4519": 0x803eb4ac,
		"MoveBG::@4520": 0x803eb4b8,
		"MoveBG::@4521": 0x803eb4c4,
		"MoveBG::@4522": 0x803eb4d0,
		"MoveBG::@4527": 0x803eb50c,
		"MoveBG::@4528": 0x803eb518,
		"MoveBG::@4529": 0x803eb524,
		"MoveBG::yDown$3084": 0x803eb780,
		"yDown$3084": 0x803eb780,
		"MoveBG::y$3281": 0x803eb78c,
		"y$3281": 0x803eb78c,
		"MoveBG::@6024": 0x803eb798,
		"MoveBG::@6025": 0x803eb7a4,
		"MoveBG::@6026": 0x803eb7b0,
		"MoveBG::@6027": 0x803eb7bc,
		"MoveBG::@6028": 0x803eb7c8,
		"NPC::@2634": 0x803ebccc,
		"NPC::@2635": 0x803ebcd8,
		"NPC::@2636": 0x803ebce4,
		"NPC::@2637": 0x803ebcf0,
		"NPC::@2638": 0x803ebcfc,
		"NPC::@2639": 0x803ebd08,
		"Strategic::@3371": 0x803ebed0,
		"Strategic::@3372": 0x803ebedc,
		"Strategic::@3373": 0x803ebee8,
		"Strategic::@3374": 0x803ebef4,
		"Strategic::@3375": 0x803ebf00,
		"Strategic::@3376": 0x803ebf0c,
		"Strategic::@3377": 0x803ebf18,
		"Strategic::@3378": 0x803ebf24,
		"Strategic::@3379": 0x803ebf30,
		"Strategic::@3380": 0x803ebf3c,
		"Strategic::@3381": 0x803ebf48,
		"Strategic::@3382": 0x803ebf54,
		"Strategic::@3383": 0x803ebf60,
		"Strategic::@3384": 0x803ebf6c,
		"Strategic::@3385": 0x803ebf78,
		"Strategic::@2743": 0x803ec000,
		"Strategic::@2744": 0x803ec00c,
		"Strategic::@2745": 0x803ec018,
		"Strategic::@2746": 0x803ec024,
		"Strategic::@2747": 0x803ec030,
		"Player::@2099": 0x803ec1c0,
		"Player::@2100": 0x803ec1cc,
		"Player::@2101": 0x803ec1d8,
		"Player::@2102": 0x803ec1e4,
		"Player::@2103": 0x803ec1f0,
		"Player::@2104": 0x803ec1fc,
		"Player::@2105": 0x803ec208,
		"Player::@2106": 0x803ec214,
		"Player::@2107": 0x803ec220,
		"Player::@2515": 0x803ec330,
		"Player::@2516": 0x803ec33c,
		"Player::@2517": 0x803ec348,
		"Player::@3712": 0x803ec3e8,
		"Player::@3713": 0x803ec3f4,
		"Player::@3714": 0x803ec400,
		"Player::@3715": 0x803ec40c,
		"Player::@3716": 0x803ec418,
		"Player::@3114": 0x803ec4a0,
		"Player::@3117": 0x803ec4c4,
		"Player::@3118": 0x803ec4d0,
		"Player::@3119": 0x803ec4dc,
		"Player::@2769": 0x803ec5ac,
		"Player::@2770": 0x803ec5b8,
		"Player::@2771": 0x803ec5c4,
		"Player::@4086": 0x803ec618,
		"Player::@4087": 0x803ec624,
		"Player::@4088": 0x803ec630,
		"Player::@4089": 0x803ec63c,
		"Player::@4090": 0x803ec648,
		"Player::@4091": 0x803ec654,
		"Player::@4092": 0x803ec660,
		"Player::@2787": 0x803ec718,
		"Player::@2788": 0x803ec724,
		"Player::@2789": 0x803ec730,
		"Player::@3447": 0x803ec794,
		"Player::@3448": 0x803ec7a0,
		"Player::@3449": 0x803ec7ac,
		"Player::@3205": 0x803ec840,
		"Player::@3207": 0x803ec858,
		"Player::@2150": 0x803ec94c,
		"Player::@2151": 0x803ec958,
		"Player::scale$2683": 0x803ec9b0,
		"scale$2683": 0x803ec9b0,
		"Player::scale$2734": 0x803ec9bc,
		"scale$2734": 0x803ec9bc,
		"Player::@3602": 0x803ec9ec,
		"Player::@3603": 0x803ec9f8,
		"Player::@3605": 0x803eca10,
		"Player::@3606": 0x803eca1c,
		"Player::@3607": 0x803eca28,
		"Player::@6203": 0x803ecca8,
		"@6203": 0x803ecca8,
		"Player::@6204": 0x803eccb4,
		"@6204": 0x803eccb4,
		"Player::@6205": 0x803eccc0,
		"@6205": 0x803eccc0,
		"Player::@6206": 0x803ecccc,
		"@6206": 0x803ecccc,
		"Player::@6207": 0x803eccd8,
		"Player::@6208": 0x803ecce4,
		"@6208": 0x803ecce4,
		"Player::@6209": 0x803eccf0,
		"@6209": 0x803eccf0,
		"Player::@6210": 0x803eccfc,
		"@6210": 0x803eccfc,
		"Player::@6211": 0x803ecd08,
		"@6211": 0x803ecd08,
		"Player::@6212": 0x803ecd14,
		"@6212": 0x803ecd14,
		"Player::@6213": 0x803ecd20,
		"@6213": 0x803ecd20,
		"Player::@6214": 0x803ecd2c,
		"@6214": 0x803ecd2c,
		"Player::@6215": 0x803ecd38,
		"@6215": 0x803ecd38,
		"Player::@6216": 0x803ecd44,
		"@6216": 0x803ecd44,
		"Player::@6217": 0x803ecd50,
		"@6217": 0x803ecd50,
		"Player::@6583": 0x803ecf94,
		"@6583": 0x803ecf94,
		"Player::@6584": 0x803ecfa0,
		"@6584": 0x803ecfa0,
		"Player::@6585": 0x803ecfac,
		"@6585": 0x803ecfac,
		"Player::@3254": 0x803ed2a0,
		"Player::@3255": 0x803ed2ac,
		"Player::@3256": 0x803ed2b8,
		"System::@7659": 0x803ed3c8,
		"System::@7660": 0x803ed3d4,
		"System::@7661": 0x803ed3e0,
		"System::@7662": 0x803ed3ec,
		"System::@7663": 0x803ed3f8,
		"System::@7664": 0x803ed404,
		"System::@7665": 0x803ed410,
		"System::@7666": 0x803ed41c,
		"System::@7667": 0x803ed428,
		"System::@7668": 0x803ed434,
		"System::@7669": 0x803ed440,
		"System::@7670": 0x803ed44c,
		"System::@7671": 0x803ed458,
		"System::@7672": 0x803ed464,
		"System::@7673": 0x803ed470,
		"System::@2757": 0x803ed6a8,
		"System::@2758": 0x803ed6b4,
		"System::@2759": 0x803ed6c0,
		"System::@2760": 0x803ed6cc,
		"System::@2761": 0x803ed6d8,
		"System::@2762": 0x803ed6e4,
		"System::@2763": 0x803ed6f0,
		"System::@3425": 0x803ed7a8,
		"System::@3426": 0x803ed7b4,
		"System::@3427": 0x803ed7c0,
		"System::@6129": 0x803ed818,
		"System::@6130": 0x803ed824,
		"System::@6131": 0x803ed830,
		"System::@6132": 0x803ed83c,
		"System::@6133": 0x803ed848,
		"System::@6134": 0x803ed854,
		"System::@6135": 0x803ed860,
		"System::@6136": 0x803ed86c,
		"System::@6137": 0x803ed878,
		"System::@3016": 0x803edd50,
		"System::@3017": 0x803edd5c,
		"System::@3018": 0x803edd68,
		"System::@3019": 0x803edd74,
		"System::@3021": 0x803edd8c,
		"System::@3022": 0x803edd98,
		"System::@3023": 0x803edda4,
		"System::@3024": 0x803eddb0,
		"System::@3025": 0x803eddbc,
		"System::@3026": 0x803eddc8,
		"System::@3027": 0x803eddd4,
		"System::@3028": 0x803edde0,
		"System::@3029": 0x803eddec,
		"System::@3030": 0x803eddf8,
		"System::@2649": 0x803ee078,
		"System::@2650": 0x803ee084,
		"System::@2651": 0x803ee090,
		"System::@2652": 0x803ee09c,
		"System::@4190": 0x803ee29c,
		"System::@4191": 0x803ee2a8,
		"System::@4192": 0x803ee2b4,
		"@4192": 0x803ee2b4,
		"System::@4193": 0x803ee2c0,
		"@4193": 0x803ee2c0,
		"System::@4194": 0x803ee2cc,
		"@4194": 0x803ee2cc,
		"System::@4195": 0x803ee2d8,
		"@4195": 0x803ee2d8,
		"JSystem::@25": 0x803ee328,
		"JSystem::exCallbackObject": 0x803ee338,
		"exCallbackObject": 0x803ee338,
		"JSystem::@301": 0x803ee358,
		"JUTAssertion::@unnamed@::sMessageFileLine": 0x803ee398,
		"sMessageFileLine": 0x803ee398,
		"JUTAssertion::@unnamed@::sMessageString": 0x803ee3d8,
		"sMessageString": 0x803ee3d8,
		"JSystem::@1661": 0x803ee438,
		"JSystem::@1662": 0x803ee444,
		"JSystem::@1663": 0x803ee450,
		"JSystem::@1664": 0x803ee45c,
		"JSystem::@1665": 0x803ee468,
		"JSystem::@1666": 0x803ee474,
		"JSystem::@1667": 0x803ee480,
		"JSystem::@1668": 0x803ee48c,
		"JAInter::StreamLib::finfo": 0x803ee4c8,
		"finfo": 0x803ee4c8,
		"JAInter::StreamLib::header": 0x803ee504,
		"header": 0x803ee504,
		"JAInter::StreamLib::Filename": 0x803ee524,
		"Filename": 0x803ee524,
		"JSystem::@557": 0x803ee598,
		"@557": 0x803ee598,
		"JSystem::osc$294": 0x803ee5a8,
		"osc$294": 0x803ee5a8,
		"JSystem::@257": 0x803ee5c0,
		"@257": 0x803ee5c0,
		"JASystem::WaveArcLoader::sAramHeap": 0x803ee5cc,
		"sAramHeap": 0x803ee5cc,
		"JASystem::AudioThread::audioproc_mq": 0x803ee5f8,
		"audioproc_mq": 0x803ee5f8,
		"JASystem::AudioThread::msgbuf": 0x803ee618,
		"msgbuf": 0x803ee618,
		"JASystem::DSPBuf::dsp_buf": 0x803ee658,
		"dsp_buf": 0x803ee658,
		"JASystem::Kernel::dac": 0x803ee668,
		"dac": 0x803ee668,
		"JASystem::Dvd::mq": 0x803ee678,
		"mq": 0x803ee678,
		"JSystem::finfo$314": 0x803ee698,
		"finfo$314": 0x803ee698,
		"JSystem::req$315": 0x803ee6d4,
		"req$315": 0x803ee6d4,
		"JSystem::finfo$361": 0x803ee754,
		"finfo$361": 0x803ee754,
		"JSystem::req$362": 0x803ee790,
		"req$362": 0x803ee790,
		"JSystem::finfo$369": 0x803ee7b0,
		"finfo$369": 0x803ee7b0,
		"JSystem::req$370": 0x803ee7ec,
		"req$370": 0x803ee7ec,
		"JSystem::finfo$393": 0x803ee80c,
		"finfo$393": 0x803ee80c,
		"JSystem::finfo$422": 0x803ee848,
		"finfo$422": 0x803ee848,
		"JSystem::finfo$426": 0x803ee884,
		"finfo$426": 0x803ee884,
		"JASystem::HardStream::strCtrl": 0x803ee8cc,
		"strCtrl": 0x803ee8cc,
		"JSystem::finfo$425": 0x803ee91c,
		"finfo$425": 0x803ee91c,
		"JSystem::get_addr_cmd$429": 0x803ee9d0,
		"get_addr_cmd$429": 0x803ee9d0,
		"JSystem::stop_cmd$430": 0x803eecd0,
		"stop_cmd$430": 0x803eecd0,
		"JSystem::finish_cmd$431": 0x803eed00,
		"finish_cmd$431": 0x803eed00,
		"JSystem::@241": 0x803eed30,
		"JASystem::Kernel::audioAramHeap": 0x803eed3c,
		"audioAramHeap": 0x803eed3c,
		"JASystem::Player::oRandom": 0x803eed50,
		"oRandom": 0x803eed50,
		"JASystem::TrackMgr::sTrackList": 0x803eedd8,
		"sTrackList": 0x803eedd8,
		"JSystem::JPAEmitterInfoObj": 0x803eeed8,
		"JPAEmitterInfoObj": 0x803eeed8,
		"JSystem::@1657": 0x803ef058,
		"JSystem::@1658": 0x803ef064,
		"JSystem::taskwork": 0x803f10e0,
		"taskwork": 0x803f10e0,
		"JSystem::sync_stack": 0x803f1160,
		"sync_stack": 0x803f1160,
		"Runtime.PPCEABI.H::fragmentinfo": 0x803f1170,
		"fragmentinfo": 0x803f1170,
		"MSL_C.PPCEABI.bare.H::atexit_funcs": 0x803f1180,
		"atexit_funcs": 0x803f1180,
		"MSL_C.PPCEABI.bare.H::__atexit_funcs": 0x803f1280,
		"__atexit_funcs": 0x803f1280,
		"TRK_MINNOW_DOLPHIN::gTRKEventQueue": 0x803f1380,
		"gTRKEventQueue": 0x803f1380,
		"TRK_MINNOW_DOLPHIN::gTRKBigEndian": 0x803f13a8,
		"gTRKBigEndian": 0x803f13a8,
		"TRK_MINNOW_DOLPHIN::gTRKMsgBufs": 0x803f13b0,
		"gTRKMsgBufs": 0x803f13b0,
		"TRK_MINNOW_DOLPHIN::gTRKFramingState": 0x803f2d60,
		"gTRKFramingState": 0x803f2d60,
		"TRK_MINNOW_DOLPHIN::gTRKInputPendingPtr": 0x803f2d74,
		"gTRKInputPendingPtr": 0x803f2d74,
		"TRK_MINNOW_DOLPHIN::gTRKDispatchTableSize": 0x803f2d78,
		"gTRKDispatchTableSize": 0x803f2d78,
		"TRK_MINNOW_DOLPHIN::gTRKSaveState": 0x803f2d84,
		"gTRKSaveState": 0x803f2d84,
		"TRK_MINNOW_DOLPHIN::TRKvalue128_temp": 0x803f2e18,
		"TRKvalue128_temp": 0x803f2e18,
		"TRK_MINNOW_DOLPHIN::gTRKState": 0x803f2e28,
		"gTRKState": 0x803f2e28,
		"TRK_MINNOW_DOLPHIN::lc_base": 0x803f3300,
		"lc_base": 0x803f3300,
		"TRK_MINNOW_DOLPHIN::TRK_mainError": 0x803f3308,
		"TRK_mainError": 0x803f3308,
		"os::DriveBlock": 0x803f3340,
		"DriveBlock": 0x803f3340,
		"os::__OSErrorTable": 0x803f3370,
		"__OSErrorTable": 0x803f3370,
		"os::RunQueue": 0x803f3438,
		"RunQueue": 0x803f3438,
		"dvd::CommandList": 0x803f3e20,
		"CommandList": 0x803f3e20,
		"dvd::Prev": 0x803f3ed8,
		"Prev": 0x803f3ed8,
		"dvd::Curr": 0x803f3ee4,
		"Curr": 0x803f3ee4,
		"dvd::DummyCommandBlock": 0x803f3f80,
		"DummyCommandBlock": 0x803f3f80,
		"dvd::WaitingQueue": 0x803f3fd8,
		"WaitingQueue": 0x803f3fd8,
		"dvd::bb2Buf": 0x803f3ff8,
		"bb2Buf": 0x803f3ff8,
		"dvd::block$16": 0x803f4038,
		"block$16": 0x803f4038,
		"vi::regs": 0x803f4068,
		"regs": 0x803f4068,
		"vi::shdwRegs": 0x803f40e0,
		"shdwRegs": 0x803f40e0,
		"vi::HorVer": 0x803f4158,
		"HorVer": 0x803f4158,
		"pad::Type": 0x803f41b0,
		"pad::Origin": 0x803f41c0,
		"Origin": 0x803f41c0,
		"pad::CmdProbeDevice": 0x803f41f0,
		"CmdProbeDevice": 0x803f41f0,
		"card::__CARDDiskNone": 0x803f4420,
		"__CARDDiskNone": 0x803f4420,
		"gx::gxData": 0x803f4440,
		"gxData": 0x803f4440,
		"gx::FifoObj": 0x803f4938,
		"FifoObj": 0x803f4938,
		"gx::vcd": 0x803f49b8,
		"vcd": 0x803f49b8,
		"gx::vat": 0x803f4a90,
		"vat": 0x803f4a90,
		"si::TypeCallback": 0x803f4da0,
		"TypeCallback": 0x803f4da0,
		"si::RDSTHandler": 0x803f4de0,
		"RDSTHandler": 0x803f4de0,
		"si::InputBufferValid": 0x803f4df0,
		"InputBufferValid": 0x803f4df0,
		"si::InputBuffer": 0x803f4e00,
		"InputBuffer": 0x803f4e00,
		"si::InputBufferVcount": 0x803f4e20,
		"InputBufferVcount": 0x803f4e20,
		"si::cmdFixDevice$326": 0x803f4e30,
		"cmdFixDevice$326": 0x803f4e30,
		"exi::Ecb": 0x803f4e40,
		"Ecb": 0x803f4e40,
		"thp::__THPLCWork512": 0x803f5000,
		"__THPLCWork512": 0x803f5000,
		"thp::__THPLCWork640": 0x803f500c,
		"__THPLCWork640": 0x803f500c,
		"thp::__THPMCUBuffer": 0x803f5018,
		"__THPMCUBuffer": 0x803f5018,
		"THPPlayer::AudioDecodeThreadStack": 0x803dc2d0,
		"AudioDecodeThreadStack": 0x803dc2d0,
		"THPPlayer::FreeAudioBufferQueue": 0x803dd2d0,
		"FreeAudioBufferQueue": 0x803dd2d0,
		"THPPlayer::DecodedAudioBufferQueue": 0x803dd2f0,
		"DecodedAudioBufferQueue": 0x803dd2f0,
		"THPPlayer::FreeAudioBufferMessage": 0x803dd310,
		"FreeAudioBufferMessage": 0x803dd310,
		"THPPlayer::DecodedAudioBufferMessage": 0x803dd31c,
		"DecodedAudioBufferMessage": 0x803dd31c,
		"THPPlayer::PrepareReadyQueue": 0x803dd560,
		"PrepareReadyQueue": 0x803dd560,
		"THPPlayer::UsedTextureSetQueue": 0x803dd580,
		"UsedTextureSetQueue": 0x803dd580,
		"THPPlayer::UsedTextureSetMessage": 0x803dd5a0,
		"UsedTextureSetMessage": 0x803dd5a0,
		"THPPlayer::FreeReadBufferQueue": 0x803de740,
		"FreeReadBufferQueue": 0x803de740,
		"THPPlayer::ReadedBufferQueue": 0x803de760,
		"ReadedBufferQueue": 0x803de760,
		"THPPlayer::ReadedBufferQueue2": 0x803de780,
		"ReadedBufferQueue2": 0x803de780,
		"THPPlayer::FreeReadBufferMessage": 0x803de7a0,
		"FreeReadBufferMessage": 0x803de7a0,
		"THPPlayer::ReadedBufferMessage": 0x803de7c8,
		"ReadedBufferMessage": 0x803de7c8,
		"THPPlayer::ReadedBufferMessage2": 0x803de7f0,
		"ReadedBufferMessage2": 0x803de7f0,
		"THPPlayer::ReadThreadStack": 0x803deb28,
		"ReadThreadStack": 0x803deb28,
		"THPPlayer::VideoDecodeThreadStack": 0x803dfe38,
		"VideoDecodeThreadStack": 0x803dfe38,
		"THPPlayer::FreeTextureSetQueue": 0x803e0e38,
		"FreeTextureSetQueue": 0x803e0e38,
		"THPPlayer::DecodedTextureSetQueue": 0x803e0e58,
		"DecodedTextureSetQueue": 0x803e0e58,
		"THPPlayer::FreeTextureSetMessage": 0x803e0e78,
		"FreeTextureSetMessage": 0x803e0e78,
		"THPPlayer::DecodedTextureSetMessage": 0x803e0e84,
		"DecodedTextureSetMessage": 0x803e0e84,
		"MarioUtil::sViewPlane": 0x803ec040,
		"sViewPlane": 0x803ec040,
		"MarioUtil::@2174": 0x803ec0a0,
		"MarioUtil::setup1$2173": 0x803ec0ac,
		"setup1$2173": 0x803ec0ac,
		"MarioUtil::@2178": 0x803ec0d0,
		"MarioUtil::cylinder$2177": 0x803ec0dc,
		"cylinder$2177": 0x803ec0dc,
		"MarioUtil::@2192": 0x803ec100,
		"MarioUtil::setup2$2191": 0x803ec10c,
		"setup2$2191": 0x803ec10c,
		"MarioUtil::@2197": 0x803ec130,
		"MarioUtil::setup3$2196": 0x803ec13c,
		"setup3$2196": 0x803ec13c,
		"MarioUtil::@2209": 0x803ec160,
		"MarioUtil::setup4$2208": 0x803ec16c,
		"setup4$2208": 0x803ec16c,
		"MarioUtil::@2218": 0x803ec190,
		"MarioUtil::setup5$2217": 0x803ec19c,
		"setup5$2217": 0x803ec19c,
		"System::@2272": 0x803ed55c,
		"System::@2273": 0x803ed568,
		"System::@2274": 0x803ed574,
		"System::@2275": 0x803ed580,
		"System::@2276": 0x803ed58c,
		"System::@2277": 0x803ed598,
		"System::@2278": 0x803ed5a4,
		"System::@2279": 0x803ed5b0,
		"System::@2280": 0x803ed5bc,
		"System::@2281": 0x803ed5c8,
		"System::@2282": 0x803ed5d4,
		"System::@2283": 0x803ed5e0,
		"System::@2764": 0x803ed6fc,
		"System::@2765": 0x803ed708,
		"System::@2766": 0x803ed714,
		"System::@2767": 0x803ed720,
		"System::@2768": 0x803ed72c,
		"System::@2769": 0x803ed738,
		"System::@2770": 0x803ed744,
		"System::@2771": 0x803ed750,
		"System::@3428": 0x803ed7cc,
		"System::@3431": 0x803ed7f0,
		"System::@6138": 0x803ed884,
		"System::@6139": 0x803ed890,
		"System::@6140": 0x803ed89c,
		"System::@6141": 0x803ed8a8,
		"@6141": 0x803ed8a8,
		"System::@6142": 0x803ed8b4,
		"@6142": 0x803ed8b4,
		"System::@6143": 0x803ed8c0,
		"@6143": 0x803ed8c0,
		"System::gParticleFlagLoaded": 0x803ede08,
		"gParticleFlagLoaded": 0x803ede08,
		"System::@2640": 0x803ee00c,
		"System::@2643": 0x803ee030,
		"System::@2644": 0x803ee03c,
		"System::@2645": 0x803ee048,
		"System::@2646": 0x803ee054,
		"System::@2647": 0x803ee060,
		"System::@2648": 0x803ee06c,
		"System::@2913": 0x803ee0c0,
		"System::@2914": 0x803ee0cc,
		"System::@2915": 0x803ee0d8,
		"System::@2916": 0x803ee0e4,
		"System::@2917": 0x803ee0f0,
		"System::@2918": 0x803ee0fc,
		"System::@2919": 0x803ee108,
		"System::@2920": 0x803ee114,
		"System::@2921": 0x803ee120,
		"System::@2922": 0x803ee12c,
		"System::@2923": 0x803ee138,
		"System::@2924": 0x803ee144,
		"System::@2925": 0x803ee150,
		"System::@2926": 0x803ee15c,
		"System::@2927": 0x803ee168,
		"Strategic::@2737": 0x803ebfb8,
		"Strategic::@2738": 0x803ebfc4,
		"Strategic::@2739": 0x803ebfd0,
		"Strategic::@2740": 0x803ebfdc,
		"Strategic::@2741": 0x803ebfe8,
		"Strategic::@2742": 0x803ebff4,
		"Player::@2108": 0x803ec22c,
		"Player::@2109": 0x803ec238,
		"Player::@2112": 0x803ec25c,
		"Player::@2113": 0x803ec268,
		"Player::@2524": 0x803ec39c,
		"Player::@2525": 0x803ec3a8,
		"Player::@2526": 0x803ec3b4,
		"Player::@2527": 0x803ec3c0,
		"Player::@2528": 0x803ec3cc,
		"Player::@3120": 0x803ec4e8,
		"Player::@3121": 0x803ec4f4,
		"Player::@3122": 0x803ec500,
		"Player::@3123": 0x803ec50c,
		"Player::@3126": 0x803ec530,
		"Player::@3127": 0x803ec53c,
		"Player::@3128": 0x803ec548,
		"Player::@2772": 0x803ec5d0,
		"Player::@2773": 0x803ec5dc,
		"Player::@2774": 0x803ec5e8,
		"Player::@2775": 0x803ec5f4,
		"Player::@2776": 0x803ec600,
		"Player::@2777": 0x803ec60c,
		"Player::@2790": 0x803ec73c,
		"Player::@2791": 0x803ec748,
		"Player::@2792": 0x803ec754,
		"Player::@2793": 0x803ec760,
		"Player::@3455": 0x803ec7f4,
		"Player::@3608": 0x803eca34,
		"Player::@6586": 0x803ecfb8,
		"@6586": 0x803ecfb8,
		"Player::@6587": 0x803ecfc4,
		"@6587": 0x803ecfc4,
		"Player::@6588": 0x803ecfd0,
		"@6588": 0x803ecfd0,
		"Player::@6589": 0x803ecfdc,
		"Player::@6590": 0x803ecfe8,
		"@6590": 0x803ecfe8,
		"Player::@6591": 0x803ecff4,
		"@6591": 0x803ecff4,
		"Player::@6592": 0x803ed000,
		"@6592": 0x803ed000,
		"Player::@6593": 0x803ed00c,
		"@6593": 0x803ed00c,
		"Player::@6594": 0x803ed018,
		"@6594": 0x803ed018,
		"Player::@6595": 0x803ed024,
		"@6595": 0x803ed024,
		"Player::@6596": 0x803ed030,
		"@6596": 0x803ed030,
		"Player::@6597": 0x803ed03c,
		"@6597": 0x803ed03c,
		"Player::@2664": 0x803ed048,
		"TModelWaterManager::mStaticHitActor": 0x803ed054,
		"mStaticHitActor": 0x803ed054,
		"Player::wcheck$2854": 0x803ed0c0,
		"wcheck$2854": 0x803ed0c0,
		"Player::@4749": 0x803ed0ec,
		"Player::@4750": 0x803ed0f8,
		"Player::@4751": 0x803ed104,
		"Player::@4752": 0x803ed110,
		"Player::@4753": 0x803ed11c,
		"Player::@4754": 0x803ed128,
		"Player::@4755": 0x803ed134,
		"Player::@4756": 0x803ed140,
		"Player::@4757": 0x803ed14c,
		"Player::@4758": 0x803ed158,
		"Player::@4759": 0x803ed164,
		"Player::@4760": 0x803ed170,
		"Player::@4761": 0x803ed17c,
		"Player::@4762": 0x803ed188,
		"Player::@4763": 0x803ed194,
		"NPC::@2936": 0x803eba78,
		"NPC::@2937": 0x803eba84,
		"NPC::@2938": 0x803eba90,
		"NPC::@2939": 0x803eba9c,
		"NPC::@2940": 0x803ebaa8,
		"NPC::@2941": 0x803ebab4,
		"NPC::@2942": 0x803ebac0,
		"NPC::@2943": 0x803ebacc,
		"NPC::@2944": 0x803ebad8,
		"NPC::@2945": 0x803ebae4,
		"NPC::@2946": 0x803ebaf0,
		"NPC::@2947": 0x803ebafc,
		"NPC::@2948": 0x803ebb08,
		"NPC::@2949": 0x803ebb14,
		"NPC::@2950": 0x803ebb20,
		"NPC::@4339": 0x803ebb30,
		"NPC::@4340": 0x803ebb3c,
		"NPC::@4341": 0x803ebb48,
		"NPC::@4342": 0x803ebb54,
		"NPC::@4343": 0x803ebb60,
		"NPC::@4344": 0x803ebb6c,
		"NPC::@4345": 0x803ebb78,
		"NPC::@4346": 0x803ebb84,
		"NPC::@4347": 0x803ebb90,
		"NPC::@4348": 0x803ebb9c,
		"NPC::@4349": 0x803ebba8,
		"NPC::@4350": 0x803ebbb4,
		"NPC::@4351": 0x803ebbc0,
		"NPC::@4352": 0x803ebbcc,
		"NPC::@4353": 0x803ebbd8,
		"NPC::@2244": 0x803ebbf4,
		"NPC::@2252": 0x803ebc00,
		"NPC::@2265": 0x803ebc0c,
		"NPC::@2304": 0x803ebc24,
		"NPC::@2405": 0x803ebc78,
		"NPC::@2415": 0x803ebc84,
		"NPC::@2437": 0x803ebc9c,
		"NPC::@2640": 0x803ebd14,
		"NPC::@2641": 0x803ebd20,
		"NPC::@2642": 0x803ebd2c,
		"NPC::@2643": 0x803ebd38,
		"NPC::@2644": 0x803ebd44,
		"NPC::@2645": 0x803ebd50,
		"NPC::@3044": 0x803ebd60,
		"NPC::@3045": 0x803ebd6c,
		"NPC::@3046": 0x803ebd78,
		"NPC::@3047": 0x803ebd84,
		"NPC::@3048": 0x803ebd90,
		"NPC::@3049": 0x803ebd9c,
		"NPC::@3050": 0x803ebda8,
		"NPC::@3051": 0x803ebdb4,
		"NPC::@3052": 0x803ebdc0,
		"NPC::@3053": 0x803ebdcc,
		"NPC::@3054": 0x803ebdd8,
		"NPC::@3055": 0x803ebde4,
		"NPC::@3056": 0x803ebdf0,
		"NPC::@3057": 0x803ebdfc,
		"NPC::@3058": 0x803ebe08,
		"NPC::@2377": 0x803ebe18,
		"NPC::@2378": 0x803ebe24,
		"NPC::@2379": 0x803ebe30,
		"NPC::@2380": 0x803ebe3c,
		"NPC::@2381": 0x803ebe48,
		"NPC::@2382": 0x803ebe54,
		"NPC::@2383": 0x803ebe60,
		"NPC::@2384": 0x803ebe6c,
		"NPC::@2386": 0x803ebe84,
		"NPC::@2387": 0x803ebe90,
		"NPC::@2388": 0x803ebe9c,
		"NPC::@2389": 0x803ebea8,
		"NPC::@2390": 0x803ebeb4,
		"MSBgm::smBgmInTrack": 0x803dae60,
		"smBgmInTrack": 0x803dae60,
		"MSound::@1961": 0x803daf98,
		"MSound::@1962": 0x803dafa4,
		"MSound::@1963": 0x803dafb0,
		"MSound::@1964": 0x803dafbc,
		"MSound::@1965": 0x803dafc8,
		"MSound::_posByCamera": 0x803dafd8,
		"_posByCamera": 0x803dafd8,
		"MSound::@1969": 0x803dbc90,
		"MSoundSESystem::MSRandVol::smList": 0x803dbc9c,
		"MSoundSESystem::MSRandPlay::smList": 0x803dbcb4,
		"MSound::@3189": 0x803dbcc0,
		"MSound::@3190": 0x803dbccc,
		"MSound::@3191": 0x803dbcd8,
		"MSound::@3192": 0x803dbce4,
		"MSound::@3193": 0x803dbcf0,
		"MSound::@3194": 0x803dbcfc,
		"MSound::@3195": 0x803dbd08,
		"MSound::@3196": 0x803dbd14,
		"MSound::@3197": 0x803dbd20,
		"MSound::@3198": 0x803dbd2c,
		"MSound::@3199": 0x803dbd38,
		"MSSetSound::smSetSound": 0x803dbd78,
		"smSetSound": 0x803dbd78,
		"MSound::@1932": 0x803dbd9c,
		"MSound::@1933": 0x803dbda8,
		"MSound::@1934": 0x803dbdb4,
		"MSound::@1935": 0x803dbdc0,
		"MSound::@1936": 0x803dbdcc,
		"MSound::@1937": 0x803dbdd8,
		"MSound::@1938": 0x803dbde4,
		"MSound::@1939": 0x803dbdf0,
		"MSound::@1940": 0x803dbdfc,
		"MSound::@1941": 0x803dbe08,
		"MSound::@1942": 0x803dbe14,
		"MSound::@1943": 0x803dbe20,
		"MSound::@1944": 0x803dbe2c,
		"MSound::@2082": 0x803dbe50,
		"MSound::@2083": 0x803dbe5c,
		"MSound::@2084": 0x803dbe68,
		"MSound::@2085": 0x803dbe74,
		"MSound::@2086": 0x803dbe80,
		"MSound::@2087": 0x803dbe8c,
		"MSound::@2088": 0x803dbe98,
		"MSound::@2089": 0x803dbea4,
		"MSound::@2090": 0x803dbeb0,
		"MSound::@2091": 0x803dbebc,
		"MSound::@2092": 0x803dbec8,
		"MSound::@2093": 0x803dbed4,
		"MSound::@2094": 0x803dbee0,
		"MSound::@2095": 0x803dbeec,
		"MSound::@2096": 0x803dbef8,
		"MSound::@1947": 0x803dbf20,
		"MSound::@1948": 0x803dbf2c,
		"MSound::@1949": 0x803dbf38,
		"MSound::@1950": 0x803dbf44,
		"MoveBG::@4343": 0x803ea0ac,
		"MoveBG::@4344": 0x803ea0b8,
		"MoveBG::@4345": 0x803ea0c4,
		"MoveBG::@4346": 0x803ea0d0,
		"MoveBG::@4347": 0x803ea0dc,
		"MoveBG::@4348": 0x803ea0e8,
		"MoveBG::@4274": 0x803ea0f8,
		"MoveBG::@4278": 0x803ea128,
		"MoveBG::@4279": 0x803ea134,
		"MoveBG::@4280": 0x803ea140,
		"MoveBG::@4281": 0x803ea14c,
		"MoveBG::@4282": 0x803ea158,
		"MoveBG::@4286": 0x803ea188,
		"MoveBG::submarineCranePos_forSound": 0x803ea600,
		"submarineCranePos_forSound": 0x803ea600,
		"MoveBG::submarineSetWtPos_forSound": 0x803ea60c,
		"submarineSetWtPos_forSound": 0x803ea60c,
		"MoveBG::@3531": 0x803ea630,
		"MoveBG::@3532": 0x803ea63c,
		"MoveBG::@3533": 0x803ea648,
		"MoveBG::@3534": 0x803ea654,
		"MoveBG::@3535": 0x803ea660,
		"MoveBG::@3540": 0x803ea69c,
		"MoveBG::@3541": 0x803ea6a8,
		"MoveBG::@3542": 0x803ea6b4,
		"MoveBG::@5419": 0x803ea6d0,
		"MoveBG::@5420": 0x803ea6dc,
		"MoveBG::@5421": 0x803ea6e8,
		"MoveBG::@5422": 0x803ea6f4,
		"MoveBG::@5423": 0x803ea700,
		"MoveBG::@5424": 0x803ea70c,
		"MoveBG::@5425": 0x803ea718,
		"MoveBG::@5426": 0x803ea724,
		"MoveBG::@5427": 0x803ea730,
		"MoveBG::@5428": 0x803ea73c,
		"MoveBG::@5429": 0x803ea748,
		"MoveBG::@5430": 0x803ea754,
		"MoveBG::@5431": 0x803ea760,
		"MoveBG::@2483": 0x803ea840,
		"MoveBG::@2484": 0x803ea84c,
		"MoveBG::@2485": 0x803ea858,
		"MoveBG::fall_upper_pos": 0x803ea8f8,
		"fall_upper_pos": 0x803ea8f8,
		"MoveBG::@4408": 0x803ea9ac,
		"MoveBG::@2557": 0x803eab28,
		"MoveBG::@2558": 0x803eab34,
		"MoveBG::@2562": 0x803eab64,
		"MoveBG::@2563": 0x803eab70,
		"MoveBG::@2564": 0x803eab7c,
		"MoveBG::@2565": 0x803eab88,
		"MoveBG::@2566": 0x803eab94,
		"MoveBG::@2567": 0x803eaba0,
		"MoveBG::@5478": 0x803eade0,
		"MoveBG::@5479": 0x803eadec,
		"MoveBG::@5480": 0x803eadf8,
		"MoveBG::up$2645": 0x803eaec0,
		"up$2645": 0x803eaec0,
		"MoveBG::up$2710": 0x803eaecc,
		"up$2710": 0x803eaecc,
		"MoveBG::@2741": 0x803eafc0,
		"MoveBG::@2743": 0x803eafd8,
		"MoveBG::@2745": 0x803eaff0,
		"MoveBG::@2746": 0x803eaffc,
		"MoveBG::@2747": 0x803eb008,
		"MoveBG::@2751": 0x803eb038,
		"TMapObjGrassManager::mDrawVec": 0x803eb048,
		"mDrawVec": 0x803eb048,
		"MoveBG::@2728": 0x803eb06c,
		"MoveBG::@2729": 0x803eb078,
		"MoveBG::@2731": 0x803eb090,
		"MoveBG::@2732": 0x803eb09c,
		"MoveBG::@2736": 0x803eb0cc,
		"MoveBG::@2311": 0x803eb108,
		"MoveBG::@2312": 0x803eb114,
		"MoveBG::@2313": 0x803eb120,
		"MoveBG::@2314": 0x803eb12c,
		"MoveBG::@2315": 0x803eb138,
		"MoveBG::@2316": 0x803eb144,
		"MoveBG::@2317": 0x803eb150,
		"MoveBG::@2318": 0x803eb15c,
		"@2318": 0x803eb15c,
		"MoveBG::@2319": 0x803eb168,
		"MoveBG::@2320": 0x803eb174,
		"MoveBG::@2321": 0x803eb180,
		"MoveBG::@2322": 0x803eb18c,
		"MoveBG::@2323": 0x803eb198,
		"MoveBG::@2324": 0x803eb1a4,
		"MoveBG::@2325": 0x803eb1b0,
		"MoveBG::@3437": 0x803eb320,
		"MoveBG::@6029": 0x803eb7d4,
		"MoveBG::@6030": 0x803eb7e0,
		"MoveBG::@6031": 0x803eb7ec,
		"MoveBG::@6032": 0x803eb7f8,
		"MoveBG::@6033": 0x803eb804,
		"MoveBG::@6034": 0x803eb810,
		"MoveBG::@6035": 0x803eb81c,
		"MoveBG::@6036": 0x803eb828,
		"MoveBG::@6037": 0x803eb834,
		"MoveBG::@6038": 0x803eb840,
		"Map::@2345": 0x803e8640,
		"Map::@2417": 0x803e86e0,
		"Map::@2418": 0x803e86ec,
		"Map::@2419": 0x803e86f8,
		"Map::@2519": 0x803e8708,
		"Map::@2520": 0x803e8714,
		"Map::@2522": 0x803e872c,
		"Map::@2524": 0x803e8744,
		"Map::@2525": 0x803e8750,
		"Map::@2526": 0x803e875c,
		"Map::@2527": 0x803e8768,
		"Map::pos$2895": 0x803e87c0,
		"pos$2895": 0x803e87c0,
		"Map::@2534": 0x803e88b0,
		"Map::@2535": 0x803e88bc,
		"Map::@2536": 0x803e88c8,
		"Map::@2540": 0x803e88f8,
		"Map::@2541": 0x803e8904,
		"Map::@2542": 0x803e8910,
		"Map::@2543": 0x803e891c,
		"Map::@2544": 0x803e8928,
		"TMapCollisionData::mIllegalCheckData": 0x803e8938,
		"mIllegalCheckData": 0x803e8938,
		"Map::@2159": 0x803e8980,
		"Map::@2160": 0x803e898c,
		"Map::@2161": 0x803e8998,
		"Map::@2162": 0x803e89a4,
		"Map::@2163": 0x803e89b0,
		"Map::@2164": 0x803e89bc,
		"Map::@2165": 0x803e89c8,
		"Map::@2166": 0x803e89d4,
		"Map::@2171": 0x803e8a10,
		"Map::@2172": 0x803e8a1c,
		"Map::@2173": 0x803e8a28,
		"Map::@2402": 0x803e8a38,
		"Map::@2403": 0x803e8a44,
		"Map::@2404": 0x803e8a50,
		"Map::@2701": 0x803e8afc,
		"Map::@2702": 0x803e8b08,
		"Map::@2708": 0x803e8b50,
		"Map::@2709": 0x803e8b5c,
		"Map::@2710": 0x803e8b68,
		"Map::@2712": 0x803e8b80,
		"Map::@2713": 0x803e8b8c,
		"Map::@2749": 0x803e8c9c,
		"Map::@2750": 0x803e8ca8,
		"Map::@2751": 0x803e8cb4,
		"Map::@2752": 0x803e8cc0,
		"Map::@2753": 0x803e8ccc,
		"Map::@2754": 0x803e8cd8,
		"Map::@2755": 0x803e8ce4,
		"Map::@2756": 0x803e8cf0,
		"Map::@2757": 0x803e8cfc,
		"Map::@2758": 0x803e8d08,
		"Map::@3295": 0x803e8d30,
		"Map::@3296": 0x803e8d3c,
		"Map::@3297": 0x803e8d48,
		"Map::@3298": 0x803e8d54,
		"Map::@3299": 0x803e8d60,
		"Map::@3300": 0x803e8d6c,
		"Map::@3301": 0x803e8d78,
		"Map::@3302": 0x803e8d84,
		"Map::@3303": 0x803e8d90,
		"Map::@3304": 0x803e8d9c,
		"Map::@3305": 0x803e8da8,
		"Map::@2668": 0x803e8dd0,
		"Map::@2669": 0x803e8ddc,
		"Map::@2671": 0x803e8df4,
		"Map::@2672": 0x803e8e00,
		"Map::@2673": 0x803e8e0c,
		"Map::@2684": 0x803e8ef4,
		"Map::@2688": 0x803e8f24,
		"Map::@2689": 0x803e8f30,
		"Map::@2358": 0x803e8ff8,
		"Map::@2359": 0x803e9004,
		"Map::@2360": 0x803e9010,
		"Map::@2361": 0x803e901c,
		"Map::@2362": 0x803e9028,
		"Map::@2363": 0x803e9034,
		"Map::@2365": 0x803e904c,
		"Map::@2366": 0x803e9058,
		"Map::@2367": 0x803e9064,
		"Map::@2369": 0x803e907c,
		"Map::@2370": 0x803e9088,
		"Map::@2371": 0x803e9094,
		"Map::@2372": 0x803e90a0,
		"Map::@2938": 0x803e911c,
		"Map::@2939": 0x803e9128,
		"Map::@2940": 0x803e9134,
		"Map::@2941": 0x803e9140,
		"Map::@2942": 0x803e914c,
		"Map::@2943": 0x803e9158,
		"Map::@2584": 0x803e918c,
		"Map::@2586": 0x803e91a4,
		"Map::@2588": 0x803e91bc,
		"Map::@2589": 0x803e91c8,
		"Map::@2590": 0x803e91d4,
		"Map::@2591": 0x803e91e0,
		"Map::@2592": 0x803e91ec,
		"Map::@2593": 0x803e91f8,
		"Map::@2594": 0x803e9204,
		"Map::@2615": 0x803e9220,
		"Map::@2616": 0x803e922c,
		"Map::@2617": 0x803e9238,
		"Map::@2621": 0x803e9268,
		"Map::@2622": 0x803e9274,
		"Map::@2623": 0x803e9280,
		"Map::@2624": 0x803e928c,
		"Map::@2625": 0x803e9298,
		"Map::@2626": 0x803e92a4,
		"Map::@2627": 0x803e92b0,
		"Map::@2628": 0x803e92bc,
		"Map::@2629": 0x803e92c8,
		"Map::@3519": 0x803e92d8,
		"Map::@3520": 0x803e92e4,
		"Map::@3521": 0x803e92f0,
		"Map::@3522": 0x803e92fc,
		"Map::@3523": 0x803e9308,
		"Map::@3524": 0x803e9314,
		"Map::@3525": 0x803e9320,
		"Map::@3526": 0x803e932c,
		"Map::@3527": 0x803e9338,
		"Map::@3528": 0x803e9344,
		"Map::@3529": 0x803e9350,
		"Map::@3530": 0x803e935c,
		"Map::@3531": 0x803e9368,
		"Map::@3532": 0x803e9374,
		"Map::@3533": 0x803e9380,
		"Map::@3240": 0x803e939c,
		"Map::@3241": 0x803e93a8,
		"Map::@3242": 0x803e93b4,
		"Map::@3243": 0x803e93c0,
		"Map::@3244": 0x803e93cc,
		"Map::@3245": 0x803e93d8,
		"Map::@3246": 0x803e93e4,
		"Map::@3247": 0x803e93f0,
		"Map::@3248": 0x803e93fc,
		"Map::@3249": 0x803e9408,
		"Map::@3250": 0x803e9414,
		"Map::@3251": 0x803e9420,
		"Map::@3252": 0x803e942c,
		"Map::@3253": 0x803e9438,
		"Map::@2743": 0x803e94b4,
		"Map::@2374": 0x803e9500,
		"Map::@2379": 0x803e953c,
		"Map::@2380": 0x803e9548,
		"Map::@2381": 0x803e9554,
		"Map::@2382": 0x803e9560,
		"Map::@2383": 0x803e956c,
		"Map::@2386": 0x803e9590,
		"Map::@2387": 0x803e959c,
		"Map::@2388": 0x803e95a8,
		"Map::@2867": 0x803e9670,
		"Map::pos$2426": 0x803e97e0,
		"pos$2426": 0x803e97e0,
		"Map::@3094": 0x803e9858,
		"Map::@3095": 0x803e9864,
		"Map::@3096": 0x803e9870,
		"Map::@3098": 0x803e9888,
		"Map::@3099": 0x803e9894,
		"Map::@3100": 0x803e98a0,
		"Map::@3101": 0x803e98ac,
		"Map::@2727": 0x803e9910,
		"Map::@2728": 0x803e991c,
		"Map::@2729": 0x803e9928,
		"Map::@2730": 0x803e9934,
		"Map::@2731": 0x803e9940,
		"Map::@2732": 0x803e994c,
		"Map::@2733": 0x803e9958,
		"Map::@2330": 0x803e99c8,
		"Map::@2658": 0x803e9ae0,
		"Map::@2659": 0x803e9aec,
		"Map::@2660": 0x803e9af8,
		"Map::@2661": 0x803e9b04,
		"Map::@2662": 0x803e9b10,
		"Map::@2663": 0x803e9b1c,
		"Map::@2664": 0x803e9b28,
		"Map::@3109": 0x803e9b44,
		"Map::@3110": 0x803e9b50,
		"Map::@3111": 0x803e9b5c,
		"Map::@3112": 0x803e9b68,
		"Map::@3113": 0x803e9b74,
		"Map::@3114": 0x803e9b80,
		"Map::@3115": 0x803e9b8c,
		"Map::@3116": 0x803e9b98,
		"Map::@3971": 0x803e9bf0,
		"Map::@3972": 0x803e9bfc,
		"Map::@3973": 0x803e9c08,
		"Map::@3974": 0x803e9c14,
		"Map::@3975": 0x803e9c20,
		"Map::@3976": 0x803e9c2c,
		"Map::@3977": 0x803e9c38,
		"Map::@3978": 0x803e9c44,
		"Map::@3979": 0x803e9c50,
		"Map::@3980": 0x803e9c5c,
		"Map::@3981": 0x803e9c68,
		"Map::@3982": 0x803e9c74,
		"Map::@3983": 0x803e9c80,
		"Map::@3984": 0x803e9c8c,
		"Map::@3985": 0x803e9c98,
		"GC2D::@2410": 0x803e4afc,
		"GC2D::@2411": 0x803e4b08,
		"GC2D::@2412": 0x803e4b14,
		"GC2D::@2413": 0x803e4b20,
		"GC2D::@2414": 0x803e4b2c,
		"GC2D::@3388": 0x803e4ce8,
		"GC2D::@3389": 0x803e4cf4,
		"GC2D::@3131": 0x803e4fc8,
		"GC2D::@3132": 0x803e4fd4,
		"GC2D::@3133": 0x803e4fe0,
		"GC2D::@3135": 0x803e4ff8,
		"GC2D::@3136": 0x803e5004,
		"GC2D::@3137": 0x803e5010,
		"GC2D::@3138": 0x803e501c,
		"GC2D::@3139": 0x803e5028,
		"GC2D::@3140": 0x803e5034,
		"GC2D::@3141": 0x803e5040,
		"GC2D::@3142": 0x803e504c,
		"GC2D::@3143": 0x803e5058,
		"GC2D::@3144": 0x803e5064,
		"GC2D::@3145": 0x803e5070,
		"TSelectShineManager::cCenter": 0x803e5080,
		"cCenter": 0x803e5080,
		"GC2D::hx": 0x803e5160,
		"hx": 0x803e5160,
		"Enemy::@3176": 0x803e0fc0,
		"Enemy::@3178": 0x803e0fd8,
		"Enemy::@4335": 0x803e1084,
		"Enemy::@4336": 0x803e1090,
		"Enemy::@3909": 0x803e10c4,
		"Enemy::@3918": 0x803e1130,
		"Enemy::@8477": 0x803e13fc,
		"@8477": 0x803e13fc,
		"Enemy::@8478": 0x803e1408,
		"@8478": 0x803e1408,
		"Enemy::@8479": 0x803e1414,
		"@8479": 0x803e1414,
		"Enemy::@8480": 0x803e1420,
		"@8480": 0x803e1420,
		"Enemy::@8481": 0x803e142c,
		"@8481": 0x803e142c,
		"Enemy::@8482": 0x803e1438,
		"@8482": 0x803e1438,
		"Enemy::@8483": 0x803e1444,
		"@8483": 0x803e1444,
		"Enemy::@8484": 0x803e1450,
		"@8484": 0x803e1450,
		"Enemy::@8485": 0x803e145c,
		"@8485": 0x803e145c,
		"Enemy::@8486": 0x803e1468,
		"@8486": 0x803e1468,
		"Enemy::@8487": 0x803e1474,
		"@8487": 0x803e1474,
		"Enemy::@8488": 0x803e1480,
		"@8488": 0x803e1480,
		"Enemy::@8489": 0x803e148c,
		"@8489": 0x803e148c,
		"Enemy::@8490": 0x803e1498,
		"@8490": 0x803e1498,
		"Enemy::@6476": 0x803e155c,
		"@6476": 0x803e155c,
		"Enemy::@6477": 0x803e1568,
		"@6477": 0x803e1568,
		"Enemy::@6480": 0x803e158c,
		"@6480": 0x803e158c,
		"Enemy::@6481": 0x803e1598,
		"@6481": 0x803e1598,
		"Enemy::@6482": 0x803e15a4,
		"@6482": 0x803e15a4,
		"Enemy::@6485": 0x803e15c8,
		"@6485": 0x803e15c8,
		"Enemy::@6486": 0x803e15d4,
		"@6486": 0x803e15d4,
		"Enemy::@6487": 0x803e15e0,
		"@6487": 0x803e15e0,
		"Enemy::@6488": 0x803e15ec,
		"@6488": 0x803e15ec,
		"Enemy::@6489": 0x803e15f8,
		"@6489": 0x803e15f8,
		"Enemy::@6490": 0x803e1604,
		"@6490": 0x803e1604,
		"Enemy::@4766": 0x803e17d8,
		"Enemy::@4767": 0x803e17e4,
		"Enemy::@4769": 0x803e17fc,
		"Enemy::@2167": 0x803e1a20,
		"Enemy::@5543": 0x803e1df4,
		"@5543": 0x803e1df4,
		"Enemy::@5544": 0x803e1e00,
		"@5544": 0x803e1e00,
		"Enemy::@5545": 0x803e1e0c,
		"@5545": 0x803e1e0c,
		"Enemy::@5546": 0x803e1e18,
		"@5546": 0x803e1e18,
		"Enemy::@5552": 0x803e1e60,
		"@5552": 0x803e1e60,
		"Enemy::@9728": 0x803e1f00,
		"@9728": 0x803e1f00,
		"Enemy::@9729": 0x803e1f0c,
		"@9729": 0x803e1f0c,
		"Enemy::@9730": 0x803e1f18,
		"@9730": 0x803e1f18,
		"Enemy::@9731": 0x803e1f24,
		"@9731": 0x803e1f24,
		"Enemy::@9732": 0x803e1f30,
		"@9732": 0x803e1f30,
		"Enemy::@9733": 0x803e1f3c,
		"@9733": 0x803e1f3c,
		"Enemy::@9734": 0x803e1f48,
		"@9734": 0x803e1f48,
		"Enemy::@9735": 0x803e1f54,
		"@9735": 0x803e1f54,
		"Enemy::@9736": 0x803e1f60,
		"@9736": 0x803e1f60,
		"Enemy::@9737": 0x803e1f6c,
		"@9737": 0x803e1f6c,
		"Enemy::@9738": 0x803e1f78,
		"@9738": 0x803e1f78,
		"Enemy::@9739": 0x803e1f84,
		"@9739": 0x803e1f84,
		"Enemy::@9740": 0x803e1f90,
		"@9740": 0x803e1f90,
		"Enemy::@8436": 0x803e2144,
		"Enemy::@8437": 0x803e2150,
		"Enemy::@8438": 0x803e215c,
		"Enemy::@8439": 0x803e2168,
		"Enemy::@8440": 0x803e2174,
		"Enemy::@8441": 0x803e2180,
		"Enemy::@8442": 0x803e218c,
		"Enemy::@8443": 0x803e2198,
		"@8443": 0x803e2198,
		"Enemy::@8444": 0x803e21a4,
		"@8444": 0x803e21a4,
		"Enemy::@8445": 0x803e21b0,
		"@8445": 0x803e21b0,
		"Enemy::@5229": 0x803e22a0,
		"Enemy::@5235": 0x803e22e8,
		"Enemy::@5236": 0x803e22f4,
		"Enemy::@5237": 0x803e2300,
		"Enemy::TTinKoopa_jointIndexTable": 0x803e2340,
		"TTinKoopa_jointIndexTable": 0x803e2340,
		"Enemy::BW_BATH_POS": 0x803e2518,
		"BW_BATH_POS": 0x803e2518,
		"Enemy::BW_PICKET_START": 0x803e2524,
		"BW_PICKET_START": 0x803e2524,
		"Enemy::BW_HEAD_START": 0x803e2530,
		"BW_HEAD_START": 0x803e2530,
		"Enemy::@3239": 0x803e26d8,
		"Enemy::@4624": 0x803e28d0,
		"Enemy::@4625": 0x803e28dc,
		"Enemy::@4626": 0x803e28e8,
		"Enemy::@4627": 0x803e28f4,
		"Enemy::@4628": 0x803e2900,
		"Enemy::@4629": 0x803e290c,
		"Enemy::@4630": 0x803e2918,
		"Enemy::@4631": 0x803e2924,
		"Enemy::@4632": 0x803e2930,
		"Enemy::@4633": 0x803e293c,
		"Enemy::@4634": 0x803e2948,
		"Enemy::@5309": 0x803e2a3c,
		"Enemy::@5310": 0x803e2a48,
		"Enemy::@5311": 0x803e2a54,
		"Enemy::@5312": 0x803e2a60,
		"Enemy::@5313": 0x803e2a6c,
		"Enemy::@5314": 0x803e2a78,
		"Enemy::@9237": 0x803e2b30,
		"@9237": 0x803e2b30,
		"Enemy::@9238": 0x803e2b3c,
		"@9238": 0x803e2b3c,
		"Enemy::@9239": 0x803e2b48,
		"@9239": 0x803e2b48,
		"Enemy::@9240": 0x803e2b54,
		"@9240": 0x803e2b54,
		"Enemy::@9241": 0x803e2b60,
		"@9241": 0x803e2b60,
		"Enemy::@9242": 0x803e2b6c,
		"@9242": 0x803e2b6c,
		"Enemy::@9243": 0x803e2b78,
		"@9243": 0x803e2b78,
		"Enemy::@9244": 0x803e2b84,
		"@9244": 0x803e2b84,
		"Enemy::@9245": 0x803e2b90,
		"@9245": 0x803e2b90,
		"Enemy::@9246": 0x803e2b9c,
		"@9246": 0x803e2b9c,
		"Enemy::@9247": 0x803e2ba8,
		"@9247": 0x803e2ba8,
		"Enemy::@9248": 0x803e2bb4,
		"@9248": 0x803e2bb4,
		"Enemy::@9249": 0x803e2bc0,
		"@9249": 0x803e2bc0,
		"Enemy::@9250": 0x803e2bcc,
		"@9250": 0x803e2bcc,
		"Enemy::@4274": 0x803e2cfc,
		"Enemy::@4275": 0x803e2d08,
		"Enemy::@4280": 0x803e2d44,
		"Enemy::@6269": 0x803e2e28,
		"@6269": 0x803e2e28,
		"Enemy::@6270": 0x803e2e34,
		"@6270": 0x803e2e34,
		"Enemy::@6271": 0x803e2e40,
		"@6271": 0x803e2e40,
		"Enemy::@6272": 0x803e2e4c,
		"@6272": 0x803e2e4c,
		"Enemy::@6273": 0x803e2e58,
		"@6273": 0x803e2e58,
		"Enemy::@6274": 0x803e2e64,
		"@6274": 0x803e2e64,
		"Enemy::@6275": 0x803e2e70,
		"@6275": 0x803e2e70,
		"Enemy::@6276": 0x803e2e7c,
		"@6276": 0x803e2e7c,
		"Enemy::@6277": 0x803e2e88,
		"@6277": 0x803e2e88,
		"Enemy::@9463": 0x803e2ff4,
		"@9463": 0x803e2ff4,
		"Enemy::@9464": 0x803e3000,
		"@9464": 0x803e3000,
		"Enemy::@9465": 0x803e300c,
		"@9465": 0x803e300c,
		"Enemy::@9466": 0x803e3018,
		"@9466": 0x803e3018,
		"Enemy::@9467": 0x803e3024,
		"@9467": 0x803e3024,
		"Enemy::@9468": 0x803e3030,
		"@9468": 0x803e3030,
		"Enemy::@9469": 0x803e303c,
		"@9469": 0x803e303c,
		"Enemy::@4652": 0x803e30b4,
		"Enemy::@4654": 0x803e30cc,
		"Enemy::@5453": 0x803e32ec,
		"Enemy::@5454": 0x803e32f8,
		"Enemy::@5455": 0x803e3304,
		"Enemy::@2265": 0x803e3368,
		"Enemy::up$2718": 0x803e3380,
		"up$2718": 0x803e3380,
		"Enemy::up$2732": 0x803e338c,
		"up$2732": 0x803e338c,
		"Enemy::@4906": 0x803e3468,
		"Enemy::@2400": 0x803e3550,
		"Enemy::@2409": 0x803e355c,
		"Enemy::@2647": 0x803e3574,
		"Enemy::@2648": 0x803e3580,
		"Enemy::@2649": 0x803e358c,
		"Enemy::@2650": 0x803e3598,
		"Enemy::@2651": 0x803e35a4,
		"Enemy::@2652": 0x803e35b0,
		"Enemy::@2653": 0x803e35bc,
		"Enemy::@3818": 0x803e3640,
		"Enemy::@3819": 0x803e364c,
		"Enemy::@3820": 0x803e3658,
		"Enemy::@2732": 0x803e390c,
		"Enemy::@2733": 0x803e3918,
		"Enemy::@2734": 0x803e3924,
		"Enemy::@2735": 0x803e3930,
		"Enemy::@2736": 0x803e393c,
		"Enemy::@2737": 0x803e3948,
		"Enemy::@2738": 0x803e3954,
		"Enemy::@2739": 0x803e3960,
		"Enemy::@2742": 0x803e3984,
		"Enemy::@3272": 0x803e3a0c,
		"Enemy::@3273": 0x803e3a18,
		"Enemy::@6698": 0x803e3b78,
		"@6698": 0x803e3b78,
		"Enemy::@6699": 0x803e3b84,
		"@6699": 0x803e3b84,
		"Enemy::@6700": 0x803e3b90,
		"@6700": 0x803e3b90,
		"Enemy::@6701": 0x803e3b9c,
		"@6701": 0x803e3b9c,
		"Enemy::@6702": 0x803e3ba8,
		"@6702": 0x803e3ba8,
		"Enemy::@6703": 0x803e3bb4,
		"@6703": 0x803e3bb4,
		"Enemy::@6704": 0x803e3bc0,
		"@6704": 0x803e3bc0,
		"Enemy::@6705": 0x803e3bcc,
		"Enemy::@6706": 0x803e3bd8,
		"Enemy::@6707": 0x803e3be4,
		"@6707": 0x803e3be4,
		"Enemy::@6708": 0x803e3bf0,
		"@6708": 0x803e3bf0,
		"Enemy::@4140": 0x803e3dd8,
		"Enemy::@5909": 0x803e40bc,
		"Enemy::@5910": 0x803e40c8,
		"Enemy::@5911": 0x803e40d4,
		"Enemy::@5912": 0x803e40e0,
		"Enemy::@5913": 0x803e40ec,
		"Enemy::@5914": 0x803e40f8,
		"Enemy::@5916": 0x803e4110,
		"Enemy::@5917": 0x803e411c,
		"Enemy::TKoopaJr_jointIndexTable": 0x803e4260,
		"TKoopaJr_jointIndexTable": 0x803e4260,
		"Enemy::@4842": 0x803e4570,
		"Enemy::@4845": 0x803e4594,
		"Enemy::@4846": 0x803e45a0,
		"Enemy::@4847": 0x803e45ac,
		"Enemy::@4850": 0x803e45d0,
		"Enemy::@4851": 0x803e45dc,
		"Enemy::@4981": 0x803e4a54,
		"Camera::@3186": 0x803f5048,
		"Camera::@3187": 0x803f5054,
		"Camera::@3188": 0x803f5060,
		"Camera::@3189": 0x803f506c,
		"Camera::@3190": 0x803f5078,
		"Camera::@3191": 0x803f5084,
		"Camera::@3192": 0x803f5090,
		"Camera::@3193": 0x803f509c,
		"Camera::@3194": 0x803f50a8,
		"Camera::@3195": 0x803f50b4,
		"Camera::@3196": 0x803f50c0,
		"Camera::@3197": 0x803f50cc,
		"Camera::@3198": 0x803f50d8,
		"Camera::CLBConstUpVec": 0x803f50e8,
		"CLBConstUpVec": 0x803f50e8,
		"Camera::@2254": 0x803f51a0,
		"Camera::@2284": 0x803f521c,
		"Camera::@2285": 0x803f5228,
		"Camera::@2286": 0x803f5234,
		"@2286": 0x803f5234,
		"Camera::@2287": 0x803f5240,
		"Camera::@2288": 0x803f524c,
		"@2288": 0x803f524c,
		"Camera::@2289": 0x803f5258,
		"Animal::@3346": 0x803da940,
		"Animal::@3348": 0x803da958,
		"Animal::@3349": 0x803da964,
		"Animal::@3350": 0x803da970,
		"Animal::@3351": 0x803da97c,
		"Animal::@3352": 0x803da988,
		"Animal::@3353": 0x803da994,
		"Animal::@3354": 0x803da9a0,
		"Animal::@3355": 0x803da9ac,
		"Animal::@3356": 0x803da9b8,
		"Animal::@3357": 0x803da9c4,
		"Animal::@3358": 0x803da9d0,
		"Animal::@3359": 0x803da9dc,
		"Animal::@3360": 0x803da9e8,
		"Animal::@2617": 0x803daa04,
		"Animal::@2618": 0x803daa10,
		"Animal::@2619": 0x803daa1c,
		"Animal::@2620": 0x803daa28,
		"Animal::@2621": 0x803daa34,
		"Animal::@2622": 0x803daa40,
		"Animal::@2623": 0x803daa4c,
		"Animal::@2624": 0x803daa58,
		"Animal::@2625": 0x803daa64,
		"Animal::@2626": 0x803daa70,
		"Animal::@2629": 0x803daa94,
		"Animal::@2630": 0x803daaa0,
		"Animal::@2001": 0x803daab0,
		"Animal::@3026": 0x803daac0,
		"Animal::@3041": 0x803daacc,
		"Animal::@3056": 0x803daad8,
		"Animal::@3068": 0x803daae4,
		"Animal::@3078": 0x803daaf0,
		"Animal::@3097": 0x803daafc,
		"Animal::@3105": 0x803dab08,
		"Animal::@3117": 0x803dab14,
		"Animal::@3129": 0x803dab20,
		"Animal::@4981": 0x803dab2c,
		"Animal::@4982": 0x803dab38,
		"Animal::@4983": 0x803dab44,
		"Animal::@4984": 0x803dab50,
		"Animal::@4985": 0x803dab5c,
		"Animal::@4986": 0x803dab68,
		"Animal::@4987": 0x803dab74,
		"Animal::@4988": 0x803dab80,
		"Animal::@4989": 0x803dab8c,
		"Animal::@4990": 0x803dab98,
		"Animal::@4991": 0x803daba4,
		"Animal::@4992": 0x803dabb0,
		"Animal::@4994": 0x803dabc8,
		"Animal::@4995": 0x803dabd4,
		"Animal::@2990": 0x803dabe0,
		"Animal::@3004": 0x803dabec,
		"Animal::@3014": 0x803dabf8,
		"Animal::@3036": 0x803dac10,
		"Animal::@3048": 0x803dac1c,
		"Animal::@5213": 0x803dac28,
		"Animal::@5214": 0x803dac34,
		"Animal::@5215": 0x803dac40,
		"Animal::@5216": 0x803dac4c,
		"Animal::@5217": 0x803dac58,
		"Animal::@5218": 0x803dac64,
		"Animal::@5219": 0x803dac70,
		"Animal::@5220": 0x803dac7c,
		"Animal::@5221": 0x803dac88,
		"Animal::@5222": 0x803dac94,
		"Animal::@5223": 0x803daca0,
		"Animal::@5224": 0x803dacac,
		"Animal::@5225": 0x803dacb8,
		"Animal::@5226": 0x803dacc4,
		"Animal::@5227": 0x803dacd0,
		"Animal::@2422": 0x803dace0,
		"JKRAramHeap::sAramList": 0x803f5264,
		"sAramList": 0x803f5264,
		"JKRAram::sAramCommandList": 0x803f5270,
		"sAramCommandList": 0x803f5270,
		"JKRDvdFile::sDvdList": 0x803f527c,
		"sDvdList": 0x803f527c,
		"JKRFileLoader::sVolumeList": 0x803f5288,
		"sVolumeList": 0x803f5288,
		"JKRThread::sThreadList": 0x803f5294,
		"sThreadList": 0x803f5294,
		"JUTException::sMapFileList": 0x803f52a0,
		"sMapFileList": 0x803f52a0,
		"JUTGamePad::mPadList": 0x803f52ac,
		"mPadList": 0x803f52ac,
		"JUTGamePad::mPadStatus": 0x803f5428,
		"mPadStatus": 0x803f5428,
		"JUTGamePad::mPadButton": 0x803f5458,
		"mPadButton": 0x803f5458,
		"JUTGamePad::mPadMStick": 0x803f5518,
		"mPadMStick": 0x803f5518,
		"JUTGamePad::mPadSStick": 0x803f5558,
		"mPadSStick": 0x803f5558,
		"J2DPrint::mMutex": 0x803f5598,
		"JSystem::j3dSys": 0x803f55b0,
		"j3dSys": 0x803f55b0,
		"J3DSys::mCurrentMtx": 0x803f575c,
		"mCurrentMtx": 0x803f575c,
		"J3DSys::mCurrentS": 0x803f578c,
		"mCurrentS": 0x803f578c,
		"J3DSys::mParentS": 0x803f5798,
		"mParentS": 0x803f5798,
		"J3DSys::sTexCoordScaleTable": 0x803f57a4,
		"sTexCoordScaleTable": 0x803f57a4,
		"JKRDvdRipper::sDvdAsyncList": 0x803f57e4,
		"sDvdAsyncList": 0x803f57e4,
		"JKRDvdAramRipper::sDvdAramAsyncList": 0x803f57f0,
		"sDvdAramAsyncList": 0x803f57f0,
		"JSystem::j3dTexCoordTable": 0x803f57fc,
		"j3dTexCoordTable": 0x803f57fc,
		"JSystem::j3dTevSwapTableTable": 0x803f7d24,
		"j3dTevSwapTableTable": 0x803f7d24,
		"JSystem::j3dAlphaCmpTable": 0x803f8124,
		"j3dAlphaCmpTable": 0x803f8124,
		"JSystem::j3dZModeTable": 0x803f8424,
		"j3dZModeTable": 0x803f8424,
		"JKRAramPiece::sAramPieceCommandList": 0x803f8484,
		"sAramPieceCommandList": 0x803f8484,
		"JKRAramPiece::mMutex": 0x803f84a8,
		"JSystem::JAInullCamera": 0x803f84c0,
		"JAInullCamera": 0x803f84c0,
		"JAIConst::nullActor": 0x803f84cc,
		"nullActor": 0x803f84cc,
		"JAIConst::camMtx": 0x803f8524,
		"camMtx": 0x803f8524,
		"JAIConst::camTrans": 0x803f8554,
		"camTrans": 0x803f8554,
		"JAIConst::camPreTrans": 0x803f8560,
		"camPreTrans": 0x803f8560,
		"JAInter::StreamLib::streamHeap": 0x803f856c,
		"streamHeap": 0x803f856c,
		"JAISystemInterface::systemPortCmd": 0x803f8580,
		"systemPortCmd": 0x803f8580,
		"JASystem::TTrack::sParser": 0x803fcf00,
		"sParser": 0x803fcf00,
		"JPADraw::vc": 0x803fcf04,
		"vc": 0x803fcf04,
		"JPADraw::cb": 0x803fd0f0,
		"Enemy::idx$3338": 0x803fd248,
		"idx$3338": 0x803fd248,
		"Enemy::loopIndirectFilenames$3524": 0x803fd2b4,
		"loopIndirectFilenames$3524": 0x803fd2b4,
		"Enemy::anmlist$3310": 0x803fd2e0,
		"anmlist$3310": 0x803fd2e0,
		"Enemy::graphlist$3316": 0x803fd2e8,
		"graphlist$3316": 0x803fd2e8,
		"Enemy::onetimeFilenames$3164": 0x803fd484,
		"onetimeFilenames$3164": 0x803fd484,
		"Enemy::@2526": 0x803fd4bc,
		"Enemy::@2527": 0x803fd4c0,
		"Enemy::loopFilenames$3194": 0x803fd558,
		"loopFilenames$3194": 0x803fd558,
		"GC2D::scDolpicNewsDolpic8_Ac4": 0x803fd5a0,
		"scDolpicNewsDolpic8_Ac4": 0x803fd5a0,
		"GC2D::scDolpicNewsDolpic8_Cc4": 0x803fd5a8,
		"scDolpicNewsDolpic8_Cc4": 0x803fd5a8,
		"GC2D::scDolpicNewsDolpic8_Da4": 0x803fd5b0,
		"scDolpicNewsDolpic8_Da4": 0x803fd5b0,
		"GC2D::scDolpicNewsDolpic8_Db4": 0x803fd5b8,
		"scDolpicNewsDolpic8_Db4": 0x803fd5b8,
		"GC2D::scDolpicNewsDolpic8_Dc1": 0x803fd5c0,
		"scDolpicNewsDolpic8_Dc1": 0x803fd5c0,
		"GC2D::scDolpicNewsDolpic8_Dc3": 0x803fd5c8,
		"scDolpicNewsDolpic8_Dc3": 0x803fd5c8,
		"GC2D::strYes": 0x803fd5d0,
		"strYes": 0x803fd5d0,
		"GC2D::strNo": 0x803fd5d8,
		"strNo": 0x803fd5d8,
		"GC2D::mag$265": 0x803fd5fc,
		"mag$265": 0x803fd5fc,
		"MoveBG::rotate_frame_rate": 0x803fd7f0,
		"rotate_frame_rate": 0x803fd7f0,
		"System::sShineViewObjName$3422": 0x803fdb28,
		"sShineViewObjName$3422": 0x803fdb28,
		"System::stages$3013": 0x803fdb30,
		"stages$3013": 0x803fdb30,
		"JSystem::rootPath$1763": 0x803fdb58,
		"rootPath$1763": 0x803fdb58,
		"JUTException::sMessageBuffer": 0x803fdb60,
		"JUTGamePad::mStickMode": 0x803fdb68,
		"mStickMode": 0x803fdb68,
		"JUTGamePad::C3ButtonReset::sResetPattern": 0x803fdb6c,
		"sResetPattern": 0x803fdb6c,
		"JSystem::Unit01": 0x803fdb70,
		"JSystem::J3DUnit01": 0x803fdb78,
		"J3DUnit01": 0x803fdb78,
		"JKRDvdRipper::szpBufferSize": 0x803fdb84,
		"JKRDvdAramRipper::szpBufferSize": 0x803fdb8c,
		"JSystem::GXTexMode0Ids": 0x803fdb90,
		"GXTexMode0Ids": 0x803fdb90,
		"JSystem::GXTexMode1Ids": 0x803fdb98,
		"GXTexMode1Ids": 0x803fdb98,
		"JSystem::GXTexImage0Ids": 0x803fdba0,
		"GXTexImage0Ids": 0x803fdba0,
		"JSystem::GXTexImage1Ids": 0x803fdba8,
		"GXTexImage1Ids": 0x803fdba8,
		"JSystem::GXTexImage2Ids": 0x803fdbb0,
		"GXTexImage2Ids": 0x803fdbb0,
		"JSystem::GXTexImage3Ids": 0x803fdbb8,
		"GXTexImage3Ids": 0x803fdbb8,
		"JSystem::GXTexTlutIds": 0x803fdbc0,
		"GXTexTlutIds": 0x803fdbc0,
		"JSystem::GX2HWFiltConv": 0x803fdbc8,
		"JSystem::j3dDefaultColInfo": 0x803fdbd0,
		"j3dDefaultColInfo": 0x803fdbd0,
		"JSystem::j3dDefaultAmbInfo": 0x803fdbd4,
		"j3dDefaultAmbInfo": 0x803fdbd4,
		"JSystem::j3dDefaultTevOrderInfoNull": 0x803fdbdc,
		"j3dDefaultTevOrderInfoNull": 0x803fdbdc,
		"JSystem::j3dDefaultIndTexOrderNull": 0x803fdbe0,
		"j3dDefaultIndTexOrderNull": 0x803fdbe0,
		"JSystem::j3dDefaultTevColor": 0x803fdbe4,
		"j3dDefaultTevColor": 0x803fdbe4,
		"JSystem::j3dDefaultIndTexCoordScaleInfo": 0x803fdbec,
		"j3dDefaultIndTexCoordScaleInfo": 0x803fdbec,
		"JSystem::j3dDefaultTevKColor": 0x803fdbf0,
		"j3dDefaultTevKColor": 0x803fdbf0,
		"JSystem::j3dDefaultTevSwapMode": 0x803fdbf4,
		"j3dDefaultTevSwapMode": 0x803fdbf4,
		"JSystem::j3dDefaultTevSwapModeTable": 0x803fdbf8,
		"j3dDefaultTevSwapModeTable": 0x803fdbf8,
		"JSystem::j3dDefaultBlendInfo": 0x803fdbfc,
		"j3dDefaultBlendInfo": 0x803fdbfc,
		"JSystem::j3dDefaultColorChanInfo": 0x803fdc00,
		"j3dDefaultColorChanInfo": 0x803fdc00,
		"JSystem::JRNTexImage1Ids": 0x803fdc18,
		"JRNTexImage1Ids": 0x803fdc18,
		"JSystem::JRNTexImage2Ids": 0x803fdc20,
		"JRNTexImage2Ids": 0x803fdc20,
		"JALCalc::cEqualCSlope": 0x803fdc28,
		"cEqualCSlope": 0x803fdc28,
		"JALCalc::cPlusPSlope": 0x803fdc2c,
		"cPlusPSlope": 0x803fdc2c,
		"JAInter::TAsnData::asnFileName": 0x803fdc30,
		"asnFileName": 0x803fdc30,
		"JAInter::StreamLib::LOOP_BLOCKS": 0x803fdc38,
		"LOOP_BLOCKS": 0x803fdc38,
		"JAInter::StreamLib::LOOP_SAMPLESIZE": 0x803fdc3c,
		"LOOP_SAMPLESIZE": 0x803fdc3c,
		"JAInter::StreamLib::outputmode": 0x803fdc40,
		"outputmode": 0x803fdc40,
		"JAIGlobalParameter::soundSceneMax": 0x803fdc50,
		"soundSceneMax": 0x803fdc50,
		"JAIGlobalParameter::seRegistMax": 0x803fdc54,
		"seRegistMax": 0x803fdc54,
		"JAIGlobalParameter::seTrackMax": 0x803fdc58,
		"seTrackMax": 0x803fdc58,
		"JAIGlobalParameter::seqTrackMax": 0x803fdc5c,
		"seqTrackMax": 0x803fdc5c,
		"JAIGlobalParameter::seqPlayTrackMax": 0x803fdc60,
		"seqPlayTrackMax": 0x803fdc60,
		"JAIGlobalParameter::seqControlBufferMax": 0x803fdc64,
		"seqControlBufferMax": 0x803fdc64,
		"JAIGlobalParameter::streamControlBufferMax": 0x803fdc68,
		"streamControlBufferMax": 0x803fdc68,
		"JAIGlobalParameter::streamParameterBufferMax": 0x803fdc6c,
		"streamParameterBufferMax": 0x803fdc6c,
		"JAIGlobalParameter::autoHeapMax": 0x803fdc70,
		"autoHeapMax": 0x803fdc70,
		"JAIGlobalParameter::stayHeapMax": 0x803fdc74,
		"stayHeapMax": 0x803fdc74,
		"JAIGlobalParameter::autoHeapRoomSize": 0x803fdc78,
		"autoHeapRoomSize": 0x803fdc78,
		"JAIGlobalParameter::stayHeapSize": 0x803fdc7c,
		"stayHeapSize": 0x803fdc7c,
		"JAIGlobalParameter::seInfoFileName": 0x803fdc80,
		"seInfoFileName": 0x803fdc80,
		"JAIGlobalParameter::seqInfoFileName": 0x803fdc84,
		"seqInfoFileName": 0x803fdc84,
		"JAIGlobalParameter::streamInfoFileName": 0x803fdc88,
		"streamInfoFileName": 0x803fdc88,
		"JAIGlobalParameter::initDataFileName": 0x803fdc8c,
		"initDataFileName": 0x803fdc8c,
		"JAIGlobalParameter::wavePath": 0x803fdc90,
		"wavePath": 0x803fdc90,
		"JAIGlobalParameter::sequenceArchivesPath": 0x803fdc94,
		"sequenceArchivesPath": 0x803fdc94,
		"JAIGlobalParameter::streamPath": 0x803fdc98,
		"streamPath": 0x803fdc98,
		"JAIGlobalParameter::sequenceArchivesFileName": 0x803fdc9c,
		"sequenceArchivesFileName": 0x803fdc9c,
		"JAIGlobalParameter::inputGainDown": 0x803fdca0,
		"inputGainDown": 0x803fdca0,
		"JAIGlobalParameter::outputGainUp": 0x803fdca4,
		"outputGainUp": 0x803fdca4,
		"JAIGlobalParameter::distanceMax": 0x803fdca8,
		"distanceMax": 0x803fdca8,
		"JAIGlobalParameter::maxVolumeDistance": 0x803fdcac,
		"maxVolumeDistance": 0x803fdcac,
		"JAIGlobalParameter::seDolbyCenterValue": 0x803fdcb0,
		"seDolbyCenterValue": 0x803fdcb0,
		"JAIGlobalParameter::seDolbyFrontDistanceMax": 0x803fdcb4,
		"seDolbyFrontDistanceMax": 0x803fdcb4,
		"JAIGlobalParameter::seDolbyBehindDistanceMax": 0x803fdcb8,
		"seDolbyBehindDistanceMax": 0x803fdcb8,
		"JAIGlobalParameter::dopplarMoveTime": 0x803fdcbc,
		"dopplarMoveTime": 0x803fdcbc,
		"JAIGlobalParameter::dummyPositionMax": 0x803fdcc0,
		"dummyPositionMax": 0x803fdcc0,
		"JAIGlobalParameter::seqMuteMoveSpeedSePlay": 0x803fdcc4,
		"seqMuteMoveSpeedSePlay": 0x803fdcc4,
		"JAIGlobalParameter::audioCameraMax": 0x803fdcc8,
		"audioCameraMax": 0x803fdcc8,
		"JAIGlobalParameter::systemTrackMax": 0x803fdccc,
		"systemTrackMax": 0x803fdccc,
		"JAIGlobalParameter::systemRootTrackMax": 0x803fdcd0,
		"systemRootTrackMax": 0x803fdcd0,
		"JAIGlobalParameter::panDistanceMax": 0x803fdcd4,
		"panDistanceMax": 0x803fdcd4,
		"JAIGlobalParameter::panDistance2Max": 0x803fdcd8,
		"panDistance2Max": 0x803fdcd8,
		"JAIGlobalParameter::panAngleParameter": 0x803fdcdc,
		"panAngleParameter": 0x803fdcdc,
		"JAIGlobalParameter::panAngleParameter2": 0x803fdce0,
		"panAngleParameter2": 0x803fdce0,
		"JAIGlobalParameter::dopplarParameter": 0x803fdce4,
		"dopplarParameter": 0x803fdce4,
		"JAIGlobalParameter::seDistancepitchMax": 0x803fdcec,
		"seDistancepitchMax": 0x803fdcec,
		"JASystem::Driver::DSPQueue::waitMax": 0x803fdcf0,
		"waitMax": 0x803fdcf0,
		"JASystem::Driver::JAS_SYSTEM_OUTPUT_MODE": 0x803fdcfc,
		"JAS_SYSTEM_OUTPUT_MODE": 0x803fdcfc,
		"JASystem::Driver::DSP_VOICE_WAITS_MAX": 0x803fdd04,
		"DSP_VOICE_WAITS_MAX": 0x803fdd04,
		"JASystem::TDSPChannel::smnFree": 0x803fdd08,
		"smnFree": 0x803fdd08,
		"JASystem::DSP_LIMIT_RATIO": 0x803fdd0c,
		"DSP_LIMIT_RATIO": 0x803fdd0c,
		"JSystem::COMP_BLOCKSAMPLES$234": 0x803fdd14,
		"COMP_BLOCKSAMPLES$234": 0x803fdd14,
		"JSystem::COMP_BLOCKBYTES$235": 0x803fdd1c,
		"COMP_BLOCKBYTES$235": 0x803fdd1c,
		"JASystem::Kernel::maxCallbacksUser": 0x803fdd28,
		"maxCallbacksUser": 0x803fdd28,
		"JASystem::Dvd::dvdMsgsSize": 0x803fdd30,
		"dvdMsgsSize": 0x803fdd30,
		"JASystem::Dvd::dvdBufSize": 0x803fdd34,
		"dvdBufSize": 0x803fdd34,
		"JASystem::Dvd::maxDics": 0x803fdd38,
		"maxDics": 0x803fdd38,
		"JASystem::HardStream::playListMax": 0x803fdd40,
		"playListMax": 0x803fdd40,
		"JASystem::Kernel::gDacRate": 0x803fdd48,
		"gDacRate": 0x803fdd48,
		"JASystem::Kernel::gSubFrames": 0x803fdd4c,
		"gSubFrames": 0x803fdd4c,
		"JASystem::Kernel::gFrameSamples": 0x803fdd50,
		"gFrameSamples": 0x803fdd50,
		"JASystem::Kernel::gDacSize": 0x803fdd54,
		"gDacSize": 0x803fdd54,
		"JASystem::Kernel::audioDramSize": 0x803fdd58,
		"audioDramSize": 0x803fdd58,
		"JASystem::Kernel::audioAramSize": 0x803fdd5c,
		"audioAramSize": 0x803fdd5c,
		"JASystem::Vload::vlMaxArcs": 0x803fdd60,
		"vlMaxArcs": 0x803fdd60,
		"JASystem::Player::sV0": 0x803fdd68,
		"sV0": 0x803fdd68,
		"JASystem::Player::sV1": 0x803fdd6c,
		"sV1": 0x803fdd6c,
		"Runtime.PPCEABI.H::fragmentID": 0x803fdd78,
		"fragmentID": 0x803fdd78,
		"MSL_C.PPCEABI.bare.H::@wstringBase0": 0x803fdd80,
		"@wstringBase0": 0x803fdd80,
		"MSL_C.PPCEABI.bare.H::next": 0x803fdd88,
		"MSL_C.PPCEABI.bare.H::K1": 0x803fdd90,
		"K1": 0x803fdd90,
		"MSL_C.PPCEABI.bare.H::K2": 0x803fdd94,
		"K2": 0x803fdd94,
		"os::__OSCurrHeap": 0x803fdd98,
		"__OSCurrHeap": 0x803fdd98,
		"os::__OSArenaLo": 0x803fdda0,
		"__OSArenaLo": 0x803fdda0,
		"os::@32": 0x803fdda8,
		"mtx::Unit01": 0x803fddb8,
		"dvd::FirstRead": 0x803fddc0,
		"FirstRead": 0x803fddc0,
		"dvd::@116": 0x803fddc8,
		"dvd::autoInvalidation": 0x803fddd0,
		"autoInvalidation": 0x803fddd0,
		"dvd::@35": 0x803fddd8,
		"dvd::@40": 0x803fdddc,
		"dvd::@41": 0x803fdde0,
		"pad::ClampRegion": 0x803fdde8,
		"ClampRegion": 0x803fdde8,
		"pad::ResettingChan": 0x803fddf0,
		"ResettingChan": 0x803fddf0,
		"pad::XPatchBits": 0x803fddf4,
		"XPatchBits": 0x803fddf4,
		"pad::AnalogMode": 0x803fddf8,
		"AnalogMode": 0x803fddf8,
		"pad::Spec": 0x803fddfc,
		"Spec": 0x803fddfc,
		"pad::MakeStatus": 0x803fde00,
		"MakeStatus": 0x803fde00,
		"pad::CmdReadOrigin": 0x803fde04,
		"CmdReadOrigin": 0x803fde04,
		"pad::CmdCalibrate": 0x803fde08,
		"CmdCalibrate": 0x803fde08,
		"card::next": 0x803fde10,
		"gx::gx": 0x803fde20,
		"gx::tbl1$215": 0x803fde28,
		"tbl1$215": 0x803fde28,
		"gx::tbl2$216": 0x803fde2c,
		"tbl2$216": 0x803fde2c,
		"gx::tbl3$217": 0x803fde30,
		"tbl3$217": 0x803fde30,
		"gx::GX2HWFiltConv": 0x803fde38,
		"gd::cm2hw$400": 0x803fde48,
		"cm2hw$400": 0x803fde48,
		"gd::cm2hw$515": 0x803fde4c,
		"cm2hw$515": 0x803fde4c,
		"MarioUtil::className$1930": 0x803fd9e8,
		"className$1930": 0x803fd9e8,
		"MarioUtil::className$1944": 0x803fd9f0,
		"className$1944": 0x803fd9f0,
		"TMBindShadowManager::mSquareShadowHeight": 0x803fd9f8,
		"mSquareShadowHeight": 0x803fd9f8,
		"TMBindShadowManager::mTreeScale": 0x803fd9fc,
		"mTreeScale": 0x803fd9fc,
		"TMBindShadowManager::mYScalePlus": 0x803fda00,
		"mYScalePlus": 0x803fda00,
		"MarioUtil::ColorBlack": 0x803fda08,
		"ColorBlack": 0x803fda08,
		"MarioUtil::ColorWhite": 0x803fda0c,
		"ColorWhite": 0x803fda0c,
		"RumbleMgr::mMotorCountLimit": 0x803fda10,
		"mMotorCountLimit": 0x803fda10,
		"RumbleMgr::mPowerThreshold": 0x803fda18,
		"mPowerThreshold": 0x803fda18,
		"MarioUtil::rumblePoint_00": 0x803fda20,
		"rumblePoint_00": 0x803fda20,
		"MarioUtil::rumblePoint_01": 0x803fda24,
		"rumblePoint_01": 0x803fda24,
		"MarioUtil::rumblePoint_02": 0x803fda28,
		"rumblePoint_02": 0x803fda28,
		"MarioUtil::rumbleFrame_02": 0x803fda2c,
		"rumbleFrame_02": 0x803fda2c,
		"MarioUtil::rumblePower_02": 0x803fda34,
		"rumblePower_02": 0x803fda34,
		"MarioUtil::rumblePoint_03": 0x803fda3c,
		"rumblePoint_03": 0x803fda3c,
		"MarioUtil::rumbleFrame_03": 0x803fda40,
		"rumbleFrame_03": 0x803fda40,
		"MarioUtil::rumblePower_03": 0x803fda48,
		"rumblePower_03": 0x803fda48,
		"MarioUtil::rumblePoint_04": 0x803fda50,
		"rumblePoint_04": 0x803fda50,
		"MarioUtil::rumblePoint_05": 0x803fda54,
		"rumblePoint_05": 0x803fda54,
		"MarioUtil::rumblePoint_06": 0x803fda58,
		"rumblePoint_06": 0x803fda58,
		"MarioUtil::rumblePoint_07": 0x803fda5c,
		"rumblePoint_07": 0x803fda5c,
		"MarioUtil::rumblePoint_08": 0x803fda60,
		"rumblePoint_08": 0x803fda60,
		"MarioUtil::rumblePoint_09": 0x803fda64,
		"rumblePoint_09": 0x803fda64,
		"MarioUtil::rumblePoint_10": 0x803fda68,
		"rumblePoint_10": 0x803fda68,
		"MarioUtil::rumbleFrame_10": 0x803fda6c,
		"rumbleFrame_10": 0x803fda6c,
		"MarioUtil::rumblePower_10": 0x803fda70,
		"rumblePower_10": 0x803fda70,
		"MarioUtil::rumblePoint_11": 0x803fda74,
		"rumblePoint_11": 0x803fda74,
		"MarioUtil::rumbleFrame_11": 0x803fda78,
		"rumbleFrame_11": 0x803fda78,
		"MarioUtil::rumblePower_11": 0x803fda7c,
		"rumblePower_11": 0x803fda7c,
		"MarioUtil::rumblePoint_12": 0x803fda80,
		"rumblePoint_12": 0x803fda80,
		"MarioUtil::rumbleFrame_12": 0x803fda84,
		"rumbleFrame_12": 0x803fda84,
		"MarioUtil::rumblePower_12": 0x803fda88,
		"rumblePower_12": 0x803fda88,
		"MarioUtil::rumblePoint_13": 0x803fda8c,
		"rumblePoint_13": 0x803fda8c,
		"MarioUtil::rumbleFrame_13": 0x803fda90,
		"rumbleFrame_13": 0x803fda90,
		"MarioUtil::rumblePower_13": 0x803fda94,
		"rumblePower_13": 0x803fda94,
		"MarioUtil::rumblePoint_14": 0x803fda98,
		"rumblePoint_14": 0x803fda98,
		"MarioUtil::rumbleFrame_14": 0x803fda9c,
		"rumbleFrame_14": 0x803fda9c,
		"MarioUtil::rumblePower_14": 0x803fdaa0,
		"rumblePower_14": 0x803fdaa0,
		"MarioUtil::rumblePoint_15": 0x803fdaa4,
		"rumblePoint_15": 0x803fdaa4,
		"MarioUtil::rumbleFrame_15": 0x803fdaa8,
		"rumbleFrame_15": 0x803fdaa8,
		"MarioUtil::rumblePower_15": 0x803fdaac,
		"rumblePower_15": 0x803fdaac,
		"MarioUtil::rumblePoint_16": 0x803fdab0,
		"rumblePoint_16": 0x803fdab0,
		"MarioUtil::rumbleFrame_16": 0x803fdab4,
		"rumbleFrame_16": 0x803fdab4,
		"MarioUtil::rumblePower_16": 0x803fdab8,
		"rumblePower_16": 0x803fdab8,
		"MarioUtil::rumblePoint_17": 0x803fdabc,
		"rumblePoint_17": 0x803fdabc,
		"MarioUtil::rumbleFrame_17": 0x803fdac0,
		"rumbleFrame_17": 0x803fdac0,
		"MarioUtil::rumblePower_17": 0x803fdac4,
		"rumblePower_17": 0x803fdac4,
		"MarioUtil::rumblePoint_18": 0x803fdac8,
		"rumblePoint_18": 0x803fdac8,
		"MarioUtil::rumbleFrame_18": 0x803fdacc,
		"rumbleFrame_18": 0x803fdacc,
		"MarioUtil::rumblePower_18": 0x803fdad0,
		"rumblePower_18": 0x803fdad0,
		"MarioUtil::rumblePoint_19": 0x803fdad4,
		"rumblePoint_19": 0x803fdad4,
		"MarioUtil::rumblePoint_20": 0x803fdad8,
		"rumblePoint_20": 0x803fdad8,
		"MarioUtil::rumbleFrame_20": 0x803fdadc,
		"rumbleFrame_20": 0x803fdadc,
		"MarioUtil::rumblePower_20": 0x803fdae4,
		"rumblePower_20": 0x803fdae4,
		"MarioUtil::rumblePoint_21": 0x803fdaec,
		"rumblePoint_21": 0x803fdaec,
		"MarioUtil::rumbleFrame_21": 0x803fdaf0,
		"rumbleFrame_21": 0x803fdaf0,
		"MarioUtil::rumblePower_21": 0x803fdaf8,
		"rumblePower_21": 0x803fdaf8,
		"MarioUtil::rumblePoint_22": 0x803fdb00,
		"rumblePoint_22": 0x803fdb00,
		"MarioUtil::rumbleFrame_22": 0x803fdb04,
		"rumbleFrame_22": 0x803fdb04,
		"MarioUtil::rumblePower_22": 0x803fdb0c,
		"rumblePower_22": 0x803fdb0c,
		"MarioUtil::rumblePoint_23": 0x803fdb14,
		"rumblePoint_23": 0x803fdb14,
		"MarioUtil::rumblePoint_24": 0x803fdb18,
		"rumblePoint_24": 0x803fdb18,
		"MarioUtil::channelNum": 0x803fdb1c,
		"channelNum": 0x803fdb1c,
		"M3DUtil::@1211": 0x803fdb20,
		"@1211": 0x803fdb20,
		"System::cCameraBckNameShineGetInside": 0x803fdb38,
		"System::cCameraBckNameShineGetOutside": 0x803fdb3c,
		"System::cCameraBckNameGate": 0x803fdb40,
		"System::cSunVolumeName": 0x803fdb48,
		"System::cSunsetVolumeName": 0x803fdb4c,
		"System::cTargetArrowBmdFileName": 0x803fdb50,
		"cTargetArrowBmdFileName": 0x803fdb50,
		"TLiveActor::mVelocityMinY": 0x803fd9c8,
		"mVelocityMinY": 0x803fd9c8,
		"NPC::cNpcPartsNameRootJoint": 0x803fd948,
		"cNpcPartsNameRootJoint": 0x803fd948,
		"NPC::cDummyPollutionTexName": 0x803fd950,
		"cDummyPollutionTexName": 0x803fd950,
		"NPC::cRealPollutionTexName": 0x803fd954,
		"cRealPollutionTexName": 0x803fd954,
		"NPC::cMonteMDummyStrawTexName": 0x803fd958,
		"cMonteMDummyStrawTexName": 0x803fd958,
		"NPC::cMonteWDummyStrawTexName": 0x803fd95c,
		"cMonteWDummyStrawTexName": 0x803fd95c,
		"NPC::cMonteMRealStrawTexName": 0x803fd960,
		"cMonteMRealStrawTexName": 0x803fd960,
		"NPC::cMonteWRealStrawTexName": 0x803fd964,
		"cMonteWRealStrawTexName": 0x803fd964,
		"NPC::cScreenTexViewObjName": 0x803fd968,
		"cScreenTexViewObjName": 0x803fd968,
		"NPC::cJellyFishDummyScreenTexName": 0x803fd96c,
		"cJellyFishDummyScreenTexName": 0x803fd96c,
		"NPC::cJellyFishDummyTexName": 0x803fd970,
		"cJellyFishDummyTexName": 0x803fd970,
		"NPC::cJellyFishRealTexName": 0x803fd974,
		"cJellyFishRealTexName": 0x803fd974,
		"NPC::cMonteMCommonVolumeName": 0x803fd978,
		"cMonteMCommonVolumeName": 0x803fd978,
		"NPC::cMonteWCommonVolumeName": 0x803fd97c,
		"cMonteWCommonVolumeName": 0x803fd97c,
		"NPC::cMareMCommonVolumeName": 0x803fd980,
		"cMareMCommonVolumeName": 0x803fd980,
		"NPC::cMareWCommonVolumeName": 0x803fd984,
		"cMareWCommonVolumeName": 0x803fd984,
		"NPC::cMareCommonNormalBmtName": 0x803fd988,
		"cMareCommonNormalBmtName": 0x803fd988,
		"NPC::cMareCommonPollutionBmtName": 0x803fd98c,
		"cMareCommonPollutionBmtName": 0x803fd98c,
		"NPC::cManiyaParentViewObjName": 0x803fd990,
		"cManiyaParentViewObjName": 0x803fd990,
		"NPC::cManiyaChildViewObjName": 0x803fd994,
		"cManiyaChildViewObjName": 0x803fd994,
		"NPC::cNotUseFastCubeViewObjName0": 0x803fd998,
		"cNotUseFastCubeViewObjName0": 0x803fd998,
		"NPC::cNotUseFastCubeViewObjName1": 0x803fd99c,
		"cNotUseFastCubeViewObjName1": 0x803fd99c,
		"NPC::cEyeMaterialName": 0x803fd9a0,
		"cEyeMaterialName": 0x803fd9a0,
		"NPC::cNeckJointName": 0x803fd9a4,
		"cNeckJointName": 0x803fd9a4,
		"TBaseNPC::sWaistJointName$localstatic0$setMtxEffect_": 0x803fd9a8,
		"sWaistJointName$localstatic0$setMtxEffect_": 0x803fd9a8,
		"NPC::cPeachPartsTextureName": 0x803fd9b0,
		"cPeachPartsTextureName": 0x803fd9b0,
		"NPC::cPeachHostTextureName": 0x803fd9b4,
		"cPeachHostTextureName": 0x803fd9b4,
		"NPC::monteMG_bastable": 0x803fd9b8,
		"monteMG_bastable": 0x803fd9b8,
		"NPC::mareMD_bastable": 0x803fd9c0,
		"mareMD_bastable": 0x803fd9c0,
		"MSBgm::smMainVolume": 0x803fd1a0,
		"smMainVolume": 0x803fd1a0,
		"MSHandle::cPan_MaxAmp": 0x803fd1a8,
		"cPan_MaxAmp": 0x803fd1a8,
		"MSHandle::cPan_CAdjust": 0x803fd1ac,
		"cPan_CAdjust": 0x803fd1ac,
		"MSHandle::cPan_CShift": 0x803fd1b0,
		"cPan_CShift": 0x803fd1b0,
		"MSHandle::cPan_HiSence_Dist": 0x803fd1b4,
		"cPan_HiSence_Dist": 0x803fd1b4,
		"MSHandle::cMS_DistanceMax_Sence": 0x803fd1b8,
		"cMS_DistanceMax_Sence": 0x803fd1b8,
		"MSHandle::cDol_0Rad": 0x803fd1bc,
		"cDol_0Rad": 0x803fd1bc,
		"MSHandle::cDol_HalfRad": 0x803fd1c0,
		"cDol_HalfRad": 0x803fd1c0,
		"MSHandle::cDol_FullRad": 0x803fd1c4,
		"cDol_FullRad": 0x803fd1c4,
		"TWoodBarrel::mWaitAppearTime": 0x803fd698,
		"mWaitAppearTime": 0x803fd698,
		"TWoodBarrel::mBreakTime": 0x803fd69c,
		"mBreakTime": 0x803fd69c,
		"TWoodBarrel::mOilBarrelFlushTime": 0x803fd6a0,
		"mOilBarrelFlushTime": 0x803fd6a0,
		"MoveBG::streetlamp_sink_data": 0x803fd6a8,
		"streetlamp_sink_data": 0x803fd6a8,
		"MoveBG::lamp_bianco_sink_data": 0x803fd6b0,
		"lamp_bianco_sink_data": 0x803fd6b0,
		"TMapObjGeneral::mNormalLivingTime": 0x803fd6b8,
		"mNormalLivingTime": 0x803fd6b8,
		"TMapObjGeneral::mNormalFlushTime": 0x803fd6bc,
		"mNormalFlushTime": 0x803fd6bc,
		"TMapObjGeneral::mNormalFlushInterval": 0x803fd6c0,
		"mNormalFlushInterval": 0x803fd6c0,
		"TMapObjGeneral::mNormalWaitToAppearTime": 0x803fd6c4,
		"mNormalWaitToAppearTime": 0x803fd6c4,
		"TMapObjGeneral::mNormalAppearingScaleUp": 0x803fd6c8,
		"mNormalAppearingScaleUp": 0x803fd6c8,
		"TMapObjGeneral::mNormalThrowSpeedRate": 0x803fd6cc,
		"mNormalThrowSpeedRate": 0x803fd6cc,
		"TMapObjLibWave::mWaveSpeed": 0x803fd6d0,
		"mWaveSpeed": 0x803fd6d0,
		"TItem::mAppearedScaleSpeed": 0x803fd6d8,
		"mAppearedScaleSpeed": 0x803fd6d8,
		"TShine::mCircleRateY": 0x803fd6dc,
		"mCircleRateY": 0x803fd6dc,
		"TShine::mUpSpeed": 0x803fd6e0,
		"mUpSpeed": 0x803fd6e0,
		"TShine::mSpeedDownRate": 0x803fd6e4,
		"TManhole::mDownHeight": 0x803fd6e8,
		"TManhole::mDownSpeed": 0x803fd6ec,
		"mDownSpeed": 0x803fd6ec,
		"TManhole::mVibrationSpeed": 0x803fd6f0,
		"mVibrationSpeed": 0x803fd6f0,
		"TManhole::mVibrationEndHeight": 0x803fd6f4,
		"mVibrationEndHeight": 0x803fd6f4,
		"TManhole::mVibrationDecreaseRate": 0x803fd6f8,
		"mVibrationDecreaseRate": 0x803fd6f8,
		"TSandBlock::mSandScaleUp": 0x803fd700,
		"mSandScaleUp": 0x803fd700,
		"TSandBlock::mSandScaleDown": 0x803fd704,
		"mSandScaleDown": 0x803fd704,
		"TSandBlock::mSandScaleMin": 0x803fd708,
		"mSandScaleMin": 0x803fd708,
		"TSandBlock::mWaitTimeToFall": 0x803fd70c,
		"mWaitTimeToFall": 0x803fd70c,
		"TSandBlock::mSandWaitTime": 0x803fd710,
		"mSandWaitTime": 0x803fd710,
		"TIceBlock::mMeltSpeedWater": 0x803fd714,
		"mMeltSpeedWater": 0x803fd714,
		"TIceBlock::mMeltSpeedAuto": 0x803fd718,
		"mMeltSpeedAuto": 0x803fd718,
		"TIceBlock::mAutoMeltScale": 0x803fd71c,
		"mAutoMeltScale": 0x803fd71c,
		"MoveBG::sSubZ": 0x803fd724,
		"sSubZ": 0x803fd724,
		"MoveBG::sSpeed": 0x803fd728,
		"sSpeed": 0x803fd728,
		"TMapObjRootPakkun::mTremblePower": 0x803fd72c,
		"mTremblePower": 0x803fd72c,
		"TMapObjRootPakkun::mTrembleAccel": 0x803fd730,
		"mTrembleAccel": 0x803fd730,
		"TMapObjRootPakkun::mTrembleBrake": 0x803fd734,
		"mTrembleBrake": 0x803fd734,
		"TMapObjRootPakkun::mTrembleTime": 0x803fd738,
		"mTrembleTime": 0x803fd738,
		"TBiancoWatermillVertical::mRotAccel": 0x803fd73c,
		"TBiancoWatermillVertical::mRotSpeedDownRate": 0x803fd740,
		"mRotSpeedDownRate": 0x803fd740,
		"TBiancoWatermillVertical::mRotSpeedMax": 0x803fd744,
		"TBiancoWatermillVertical::mBridgeRotRate": 0x803fd748,
		"mBridgeRotRate": 0x803fd748,
		"TBiancoMiniWindmill::mRotWaterAccel": 0x803fd74c,
		"mRotWaterAccel": 0x803fd74c,
		"TBiancoMiniWindmill::mFriction": 0x803fd750,
		"mFriction": 0x803fd750,
		"TBiancoMiniWindmill::mRotSpeedMax": 0x803fd754,
		"MoveBG::sMessengerPosZ": 0x803fd758,
		"sMessengerPosZ": 0x803fd758,
		"MoveBG::sMessengerPosY": 0x803fd75c,
		"sMessengerPosY": 0x803fd75c,
		"TLeafBoatRotten::mAlphaDownSpeed": 0x803fd760,
		"mAlphaDownSpeed": 0x803fd760,
		"TLeafBoatRotten::mCollisionRemoveAlpha": 0x803fd764,
		"mCollisionRemoveAlpha": 0x803fd764,
		"TLeafBoatRotten::mRottenColor": 0x803fd768,
		"mRottenColor": 0x803fd768,
		"TCraneRotY::mWaitTime": 0x803fd770,
		"TCraneUpDown::mRotSpeed": 0x803fd774,
		"TCraneUpDown::mWaitTime": 0x803fd778,
		"TRiccoWatermill::mRotAccel": 0x803fd77c,
		"TRiccoWatermill::mRotSpeedMaxUp": 0x803fd780,
		"mRotSpeedMaxUp": 0x803fd780,
		"TRiccoWatermill::mRotSpeedMaxDown": 0x803fd784,
		"mRotSpeedMaxDown": 0x803fd784,
		"TRiccoWatermill::mRotDown": 0x803fd788,
		"mRotDown": 0x803fd788,
		"TRiccoWatermill::mSubmarineMoveRate": 0x803fd78c,
		"mSubmarineMoveRate": 0x803fd78c,
		"TRiccoWatermill::mSubmarineMaxTransY": 0x803fd790,
		"mSubmarineMaxTransY": 0x803fd790,
		"TRiccoWatermill::mSubmarineBottomTransY": 0x803fd794,
		"mSubmarineBottomTransY": 0x803fd794,
		"TRiccoWatermill::mWaitTime": 0x803fd798,
		"TFruitLauncher::mObjSpeedXZ": 0x803fd79c,
		"mObjSpeedXZ": 0x803fd79c,
		"TFruitLauncher::mObjSpeedY": 0x803fd7a0,
		"mObjSpeedY": 0x803fd7a0,
		"TFruitLauncher::mFruitLiveTime": 0x803fd7a4,
		"mFruitLiveTime": 0x803fd7a4,
		"TSandBase::mWitherTime": 0x803fd7a8,
		"mWitherTime": 0x803fd7a8,
		"TSandBase::mScaleMin": 0x803fd7ac,
		"TSandBombBase::mFiringFrameSpeed": 0x803fd7b0,
		"mFiringFrameSpeed": 0x803fd7b0,
		"TSandBombBase::mFiringFrameDownSpeed": 0x803fd7b4,
		"mFiringFrameDownSpeed": 0x803fd7b4,
		"TSandBombBase::mExplodeFrameSpeed": 0x803fd7b8,
		"mExplodeFrameSpeed": 0x803fd7b8,
		"TSandBombBase::mMarioJumpRate": 0x803fd7bc,
		"mMarioJumpRate": 0x803fd7bc,
		"TSandBombBase::mExlodingRumbleTime": 0x803fd7c0,
		"mExlodingRumbleTime": 0x803fd7c0,
		"TSandCastle::mCollisionRate": 0x803fd7c4,
		"mCollisionRate": 0x803fd7c4,
		"TLeanMirror::mGoTargetTime": 0x803fd7c8,
		"mGoTargetTime": 0x803fd7c8,
		"TLeanMirror::mDemoWaitTime": 0x803fd7cc,
		"mDemoWaitTime": 0x803fd7cc,
		"TLeanMirror::mDemoLightTime": 0x803fd7d0,
		"mDemoLightTime": 0x803fd7d0,
		"TMammaBlockRotate::mRotSpeed": 0x803fd7d4,
		"TMammaBlockRotate::mRotReturnSpeed": 0x803fd7d8,
		"mRotReturnSpeed": 0x803fd7d8,
		"TMammaBlockRotate::mRotEnd": 0x803fd7dc,
		"mRotEnd": 0x803fd7dc,
		"TMammaBlockRotate::mMapGoSpeed": 0x803fd7e0,
		"mMapGoSpeed": 0x803fd7e0,
		"TMammaBlockRotate::mMapBackSpeed": 0x803fd7e4,
		"mMapBackSpeed": 0x803fd7e4,
		"TMammaBlockRotate::mWaitTime": 0x803fd7e8,
		"TShellCup::mOpenRotMax": 0x803fd7f4,
		"mOpenRotMax": 0x803fd7f4,
		"TShellCup::mShellDamageRot": 0x803fd7f8,
		"mShellDamageRot": 0x803fd7f8,
		"TShellCup::mWaterOpenAccel": 0x803fd7fc,
		"mWaterOpenAccel": 0x803fd7fc,
		"TShellCup::mCloseAccel": 0x803fd800,
		"mCloseAccel": 0x803fd800,
		"TMerrygoround::mRotSpeed": 0x803fd804,
		"TCogwheelScale::mWaterLeakSpeed": 0x803fd808,
		"mWaterLeakSpeed": 0x803fd808,
		"TCogwheel::mRopeWidthX": 0x803fd810,
		"TCogwheel::mRopeWidthZ": 0x803fd814,
		"TCogwheel::mTexPosRate": 0x803fd818,
		"TCogwheel::mMinSpeed": 0x803fd81c,
		"mMinSpeed": 0x803fd81c,
		"MoveBG::mGrowStartFrame": 0x803fd820,
		"mGrowStartFrame": 0x803fd820,
		"MoveBG::mGrowEndFrame": 0x803fd824,
		"mGrowEndFrame": 0x803fd824,
		"TMapObjFlag::mFlutterSpeed": 0x803fd828,
		"mFlutterSpeed": 0x803fd828,
		"TMapObjPlane::mHipDropDownRate": 0x803fd838,
		"mHipDropDownRate": 0x803fd838,
		"TMapObjPlane::mWaterDownRate": 0x803fd83c,
		"mWaterDownRate": 0x803fd83c,
		"TMapObjPlane::mTexScale": 0x803fd840,
		"mTexScale": 0x803fd840,
		"TRideCloud::mMoveSpeedDefault": 0x803fd848,
		"mMoveSpeedDefault": 0x803fd848,
		"TRideCloud::mCushionLen": 0x803fd84c,
		"mCushionLen": 0x803fd84c,
		"TRideCloud::mCushionSpeed": 0x803fd850,
		"mCushionSpeed": 0x803fd850,
		"TRideCloud::mScaleSpeed": 0x803fd854,
		"mScaleSpeed": 0x803fd854,
		"TResetFruit::mFruitLivingTime": 0x803fd858,
		"mFruitLivingTime": 0x803fd858,
		"TResetFruit::mScaleUpSpeed": 0x803fd85c,
		"TResetFruit::mBreakingScaleSpeed": 0x803fd860,
		"mBreakingScaleSpeed": 0x803fd860,
		"TResetFruit::mFruitWaitTimeToAppear": 0x803fd864,
		"mFruitWaitTimeToAppear": 0x803fd864,
		"TMapObjGrassManager::mWidth": 0x803fd880,
		"mWidth": 0x803fd880,
		"TMapObjGrassManager::mSwingWidth": 0x803fd884,
		"mSwingWidth": 0x803fd884,
		"TMapObjGrassManager::mSwingSpeed": 0x803fd888,
		"mSwingSpeed": 0x803fd888,
		"TMapObjGrassManager::mDistNear": 0x803fd88c,
		"mDistNear": 0x803fd88c,
		"TMapObjGrassManager::mDistFar": 0x803fd890,
		"mDistFar": 0x803fd890,
		"MoveBG::sGrassAddTime": 0x803fd894,
		"sGrassAddTime": 0x803fd894,
		"TRevolvingFenceInner::mSpeed": 0x803fd8a8,
		"mSpeed": 0x803fd8a8,
		"TFenceWater::mWaterAccel": 0x803fd8ac,
		"mWaterAccel": 0x803fd8ac,
		"TFenceWater::mBackSpeed": 0x803fd8b0,
		"mBackSpeed": 0x803fd8b0,
		"TFenceWater::mTurnedWaitTime": 0x803fd8b4,
		"mTurnedWaitTime": 0x803fd8b4,
		"TRailFence::mFallHeight": 0x803fd8b8,
		"mFallHeight": 0x803fd8b8,
		"TRailFence::mWaitTime": 0x803fd8bc,
		"MoveBG::sRumbleTime": 0x803fd8c0,
		"sRumbleTime": 0x803fd8c0,
		"THangingBridgeBoard::mMarioAccelY": 0x803fd8c8,
		"mMarioAccelY": 0x803fd8c8,
		"THangingBridgeBoard::mMarioHipDropAccelY": 0x803fd8cc,
		"mMarioHipDropAccelY": 0x803fd8cc,
		"THangingBridgeBoard::mReturnAccelRate": 0x803fd8d0,
		"THangingBridgeBoard::mSpeedDownRate": 0x803fd8d4,
		"THangingBridgeBoard::mRopeWidthX": 0x803fd8d8,
		"THangingBridgeBoard::mRopeWidthZ": 0x803fd8dc,
		"THangingBridgeBoard::mTexPosRate": 0x803fd8e0,
		"THangingBridge::mRopeWidthBetweenBoards": 0x803fd8e4,
		"mRopeWidthBetweenBoards": 0x803fd8e4,
		"THangingBridge::mRopeWidthBetweenBoardsY": 0x803fd8e8,
		"mRopeWidthBetweenBoardsY": 0x803fd8e8,
		"THangingBridge::mPointNumBetweenBoards": 0x803fd8ec,
		"mPointNumBetweenBoards": 0x803fd8ec,
		"THangingBridge::mBetweenBoardsTexPosRate": 0x803fd8f0,
		"mBetweenBoardsTexPosRate": 0x803fd8f0,
		"TSwingBoard::mBoardWidth": 0x803fd8f4,
		"mBoardWidth": 0x803fd8f4,
		"TSwingBoard::mRopeWidthX": 0x803fd8f8,
		"TSwingBoard::mRopeWidthZ": 0x803fd8fc,
		"TSwingBoard::mTexPosRate": 0x803fd900,
		"TSwingBoard::mReturnAccelRate": 0x803fd904,
		"TSwingBoard::mSpeedDownRate": 0x803fd908,
		"TFluff::mScaleUpSpeed": 0x803fd90c,
		"TFluff::mScaleDownSpeed": 0x803fd910,
		"mScaleDownSpeed": 0x803fd910,
		"TFluffManager::mWindMin": 0x803fd914,
		"mWindMin": 0x803fd914,
		"TMapObjTree::mBananaTreeJumpPower": 0x803fd918,
		"mBananaTreeJumpPower": 0x803fd918,
		"TMapObjTreeScale::mScaleSpeedY": 0x803fd91c,
		"mScaleSpeedY": 0x803fd91c,
		"TMapObjTreeScale::mStatusChangeScaleY": 0x803fd920,
		"mStatusChangeScaleY": 0x803fd920,
		"TMapObjTreeScale::mScaleSpeedXZ": 0x803fd924,
		"mScaleSpeedXZ": 0x803fd924,
		"TMapObjTreeScale::mScaleMin": 0x803fd928,
		"MoveBG::sWaitTime": 0x803fd92c,
		"sWaitTime": 0x803fd92c,
		"TMapObjNail::mDownHeight": 0x803fd930,
		"TLampTrapIron::mHitPointMax": 0x803fd940,
		"mHitPointMax": 0x803fd940,
		"TLampTrapIron::mFireTimerMax": 0x803fd944,
		"mFireTimerMax": 0x803fd944,
		"TMapEventSink::mCleanedDegree": 0x803fd600,
		"Map::table$2575": 0x803fd608,
		"table$2575": 0x803fd608,
		"TMapWire::mMoveTimerSpeed": 0x803fd610,
		"mMoveTimerSpeed": 0x803fd610,
		"TMapWire::mDownRateMax": 0x803fd614,
		"mDownRateMax": 0x803fd614,
		"TMapWire::mEndRate": 0x803fd618,
		"mEndRate": 0x803fd618,
		"TMapWire::mStretchRate": 0x803fd61c,
		"mStretchRate": 0x803fd61c,
		"TMapWire::mHeightRate": 0x803fd620,
		"mHeightRate": 0x803fd620,
		"TMapWire::mReleaseHeight": 0x803fd624,
		"mReleaseHeight": 0x803fd624,
		"TMapWire::mFootLength": 0x803fd628,
		"mFootLength": 0x803fd628,
		"TMapWire::mDrawWidth": 0x803fd62c,
		"mDrawWidth": 0x803fd62c,
		"TMapWire::mDrawHeight": 0x803fd630,
		"mDrawHeight": 0x803fd630,
		"TMapWireActor::mCommonAttackRadius": 0x803fd638,
		"mCommonAttackRadius": 0x803fd638,
		"TMapWireActor::mCommonAttackHeight": 0x803fd63c,
		"mCommonAttackHeight": 0x803fd63c,
		"TPollutionLayer::mAreaMinRate": 0x803fd640,
		"mAreaMinRate": 0x803fd640,
		"TPollutionLayer::mSpreadArea": 0x803fd644,
		"mSpreadArea": 0x803fd644,
		"TPollutionLayer::mSpreadFrequency": 0x803fd648,
		"mSpreadFrequency": 0x803fd648,
		"TPollutionLayer::mFireArea": 0x803fd64c,
		"mFireArea": 0x803fd64c,
		"TPollutionLayer::mFireEffectWaitTime": 0x803fd650,
		"mFireEffectWaitTime": 0x803fd650,
		"TPollutionLayer::mThunderArea": 0x803fd654,
		"mThunderArea": 0x803fd654,
		"TPollutionLayer::mGlassWallArea": 0x803fd658,
		"mGlassWallArea": 0x803fd658,
		"TPollutionLayer::mGlassWallEffectTime": 0x803fd65c,
		"mGlassWallEffectTime": 0x803fd65c,
		"TPollutionManager::mFlushTime": 0x803fd660,
		"mFlushTime": 0x803fd660,
		"TPollutionLayerWave::mInterval": 0x803fd668,
		"mInterval": 0x803fd668,
		"TPollutionLayer::mEffectTime": 0x803fd670,
		"mEffectTime": 0x803fd670,
		"TMareWallRock::mAppearSpeed": 0x803fd678,
		"mAppearSpeed": 0x803fd678,
		"TMareWallRock::mDepressSpeed": 0x803fd67c,
		"TMareWallRock::mCleanedDegree": 0x803fd680,
		"TMareWallRock::mWaitTimeToAppear": 0x803fd684,
		"mWaitTimeToAppear": 0x803fd684,
		"TMareWallRock::mWaitTimeToDepress": 0x803fd688,
		"mWaitTimeToDepress": 0x803fd688,
		"TMareEventDepressWall::mDepressSpeed": 0x803fd68c,
		"TMareEventDepressWall::mRiseSpeed": 0x803fd690,
		"mRiseSpeed": 0x803fd690,
		"TMareEventDepressWall::mWaitTimeToWatch": 0x803fd694,
		"mWaitTimeToWatch": 0x803fd694,
		"GC2D::scDolpicNewsDolpic0": 0x803fd580,
		"scDolpicNewsDolpic0": 0x803fd580,
		"GC2D::scDolpicNewsDolpic1": 0x803fd588,
		"scDolpicNewsDolpic1": 0x803fd588,
		"GC2D::scDolpicNewsDolpic5_2": 0x803fd590,
		"scDolpicNewsDolpic5_2": 0x803fd590,
		"GC2D::scDolpicNewsDolpic5_3": 0x803fd598,
		"scDolpicNewsDolpic5_3": 0x803fd598,
		"GC2D::fbuf": 0x803fd5e0,
		"fbuf": 0x803fd5e0,
		"GC2D::vtable_org": 0x803fd5e4,
		"vtable_org": 0x803fd5e4,
		"GC2D::dec_step": 0x803fd5ec,
		"dec_step": 0x803fd5ec,
		"GC2D::inc_step": 0x803fd5f0,
		"inc_step": 0x803fd5f0,
		"GC2D::fbuf2": 0x803fd5f4,
		"fbuf2": 0x803fd5f4,
		"GC2D::gmover_tex_buffer": 0x803fd5f8,
		"gmover_tex_buffer": 0x803fd5f8,
		"TGesso::mBodyRotSpeed": 0x803fd1d4,
		"mBodyRotSpeed": 0x803fd1d4,
		"TGesso::mPollRange": 0x803fd1d8,
		"mPollRange": 0x803fd1d8,
		"TGesso::mThroughHoseiDistY": 0x803fd1dc,
		"mThroughHoseiDistY": 0x803fd1dc,
		"THamuKuri::mCapGravityY": 0x803fd1e0,
		"mCapGravityY": 0x803fd1e0,
		"THamuKuri::mCapSpeed": 0x803fd1e4,
		"mCapSpeed": 0x803fd1e4,
		"THamuKuri::mVGenerateGravityY": 0x803fd1e8,
		"mVGenerateGravityY": 0x803fd1e8,
		"THamuKuri::mLandAnmFrameNum": 0x803fd1ec,
		"mLandAnmFrameNum": 0x803fd1ec,
		"Enemy::mFireHamNoseColorDiff": 0x803fd1f4,
		"mFireHamNoseColorDiff": 0x803fd1f4,
		"Enemy::mFireHamOtherColorDiff": 0x803fd1fc,
		"mFireHamOtherColorDiff": 0x803fd1fc,
		"TMameGesso::mBaseHoseiTransY": 0x803fd208,
		"mBaseHoseiTransY": 0x803fd208,
		"TNameKuriManager::mExplosionSpeed": 0x803fd210,
		"mExplosionSpeed": 0x803fd210,
		"TNameKuriManager::mStopMinScaleFrame": 0x803fd214,
		"mStopMinScaleFrame": 0x803fd214,
		"TPakkunManager::mRootExplosionScaleRate": 0x803fd218,
		"mRootExplosionScaleRate": 0x803fd218,
		"TPakkunManager::mTestFlyAngX": 0x803fd21c,
		"mTestFlyAngX": 0x803fd21c,
		"TPakkunManager::mIgnoreHitWaterY": 0x803fd220,
		"mIgnoreHitWaterY": 0x803fd220,
		"TSmallEnemyManager::mBlockWaitTime": 0x803fd228,
		"mBlockWaitTime": 0x803fd228,
		"TSmallEnemyManager::mBlockMoveSpeed": 0x803fd22c,
		"mBlockMoveSpeed": 0x803fd22c,
		"TSmallEnemyManager::mBlockWaitMoveY": 0x803fd230,
		"mBlockWaitMoveY": 0x803fd230,
		"TSmallEnemyManager::mChangeBlockTime": 0x803fd234,
		"mChangeBlockTime": 0x803fd234,
		"TSmallEnemyManager::mBlockXZScale": 0x803fd238,
		"mBlockXZScale": 0x803fd238,
		"TSmallEnemyManager::mBlockYScale": 0x803fd23c,
		"mBlockYScale": 0x803fd23c,
		"TTelesa::mFlyAngMax": 0x803fd258,
		"mFlyAngMax": 0x803fd258,
		"TTobiPuku::mLandAngle": 0x803fd270,
		"mLandAngle": 0x803fd270,
		"TTobiPuku::mBoundVelocityY": 0x803fd278,
		"mBoundVelocityY": 0x803fd278,
		"TChuuHana::mCheckOnPanelTimeRoll": 0x803fd2b8,
		"mCheckOnPanelTimeRoll": 0x803fd2b8,
		"TChuuHana::mCheckOnPanelTime": 0x803fd2bc,
		"mCheckOnPanelTime": 0x803fd2bc,
		"TChuuHana::mSmallMirrorR": 0x803fd2c8,
		"mSmallMirrorR": 0x803fd2c8,
		"TChuuHana::mMediumMirrorR": 0x803fd2cc,
		"mMediumMirrorR": 0x803fd2cc,
		"TChuuHana::mLargeMirrorR": 0x803fd2d0,
		"mLargeMirrorR": 0x803fd2d0,
		"TRollEnemy::mBoundVal": 0x803fd2d8,
		"mBoundVal": 0x803fd2d8,
		"TIgaiga::mReachNodeDist": 0x803fd2dc,
		"mReachNodeDist": 0x803fd2dc,
		"TTamaNoko::mStopOnAirTimeMax": 0x803fd2f8,
		"mStopOnAirTimeMax": 0x803fd2f8,
		"TTamaNoko::mRollOnAirTimeMax": 0x803fd2fc,
		"mRollOnAirTimeMax": 0x803fd2fc,
		"TTamaNoko::mRollOnAirAngle": 0x803fd300,
		"mRollOnAirAngle": 0x803fd300,
		"TTamaNoko::mDropVelocityY": 0x803fd304,
		"mDropVelocityY": 0x803fd304,
		"TBossTelesa::mEnemyGenRate": 0x803fd308,
		"mEnemyGenRate": 0x803fd308,
		"TBossTelesa::mItemGenRate": 0x803fd30c,
		"mItemGenRate": 0x803fd30c,
		"TBossTelesa::mBaseHoseiPosY": 0x803fd314,
		"mBaseHoseiPosY": 0x803fd314,
		"TBossTelesa::mRouletteUpRate": 0x803fd318,
		"mRouletteUpRate": 0x803fd318,
		"TBossTelesa::mTelesaGenerateInterval": 0x803fd31c,
		"mTelesaGenerateInterval": 0x803fd31c,
		"TBossTelesa::mCameraMoveLimit": 0x803fd320,
		"mCameraMoveLimit": 0x803fd320,
		"TBossTelesa::mCameraMoveSp": 0x803fd324,
		"mCameraMoveSp": 0x803fd324,
		"TCannon::mVelocityRate": 0x803fd334,
		"mVelocityRate": 0x803fd334,
		"TCannon::mSearchRate": 0x803fd338,
		"mSearchRate": 0x803fd338,
		"TBossEel::mOpenRollSpeed": 0x803fd340,
		"mOpenRollSpeed": 0x803fd340,
		"TBossEel::mForcePow": 0x803fd348,
		"mForcePow": 0x803fd348,
		"TFlyEnemy::mTestSp": 0x803fd354,
		"mTestSp": 0x803fd354,
		"TFlyEnemy::mInvalidTime": 0x803fd358,
		"mInvalidTime": 0x803fd358,
		"TFlyEnemy::mTestMarioSpMax": 0x803fd35c,
		"mTestMarioSpMax": 0x803fd35c,
		"TPopo::mTestAng_x": 0x803fd36c,
		"TPopo::mTestAng_y": 0x803fd370,
		"TPopo::mNozzleOffsetZ": 0x803fd374,
		"TPopo::mTestBodyScale": 0x803fd380,
		"mTestBodyScale": 0x803fd380,
		"TPopo::mColOffsetY": 0x803fd388,
		"TPopo::mColMinVal": 0x803fd38c,
		"mColMinVal": 0x803fd38c,
		"Enemy::sleepBossHanachan_bastable": 0x803fd398,
		"sleepBossHanachan_bastable": 0x803fd398,
		"Enemy::cSandPillarModelName": 0x803fd3a8,
		"cSandPillarModelName": 0x803fd3a8,
		"Enemy::cHitPoint1_RailName": 0x803fd3ac,
		"cHitPoint1_RailName": 0x803fd3ac,
		"Enemy::cHitPoint2_RailName": 0x803fd3b0,
		"cHitPoint2_RailName": 0x803fd3b0,
		"Enemy::cSandTextureName": 0x803fd3b4,
		"cSandTextureName": 0x803fd3b4,
		"Enemy::cDummyTextureName": 0x803fd3b8,
		"cDummyTextureName": 0x803fd3b8,
		"Enemy::cMapCollisionJointName": 0x803fd3c0,
		"cMapCollisionJointName": 0x803fd3c0,
		"Enemy::cBodyMapCollisionFileName": 0x803fd3c4,
		"cBodyMapCollisionFileName": 0x803fd3c4,
		"Enemy::cHeadMapCollisionFileName": 0x803fd3c8,
		"cHeadMapCollisionFileName": 0x803fd3c8,
		"Enemy::cLegJointName_L3": 0x803fd3cc,
		"cLegJointName_L3": 0x803fd3cc,
		"Enemy::cLegJointName_R3": 0x803fd3d0,
		"cLegJointName_R3": 0x803fd3d0,
		"Enemy::cNoseHallJointName_L": 0x803fd3d4,
		"cNoseHallJointName_L": 0x803fd3d4,
		"Enemy::cNoseHallJointName_R": 0x803fd3d8,
		"cNoseHallJointName_R": 0x803fd3d8,
		"Enemy::sFootJointName$2739": 0x803fd3dc,
		"sFootJointName$2739": 0x803fd3dc,
		"TRocket::mTestAng_y": 0x803fd3f0,
		"TRocket::mNozzleOffsetZ": 0x803fd3f4,
		"TRocket::mColOffsetY": 0x803fd3f8,
		"Enemy::koopajrsubmarine_bastable": 0x803fd420,
		"koopajrsubmarine_bastable": 0x803fd420,
		"Enemy::@2523": 0x803fd4b0,
		"Enemy::@2524": 0x803fd4b4,
		"Enemy::@2525": 0x803fd4b8,
		"Enemy::DebuTelesa_bastable": 0x803fd568,
		"DebuTelesa_bastable": 0x803fd568,
		"Camera::cStartCamName": 0x803fde50,
		"cStartCamName": 0x803fde50,
		"Camera::cStartAfterCamName": 0x803fde54,
		"cStartAfterCamName": 0x803fde54,
		"Camera::cJetCoasterCam0BckName": 0x803fde58,
		"cJetCoasterCam0BckName": 0x803fde58,
		"Camera::cJetCoasterCam1BckName": 0x803fde5c,
		"cJetCoasterCam1BckName": 0x803fde5c,
		"Camera::cJetCoasterDemoBckName": 0x803fde60,
		"cJetCoasterDemoBckName": 0x803fde60,
		"Camera::cStartCamBckFileName": 0x803fde64,
		"cStartCamBckFileName": 0x803fde64,
		"Camera::bossGesoViewObjName": 0x803fde68,
		"bossGesoViewObjName": 0x803fde68,
		"Camera::cSunWarpPointName": 0x803fde70,
		"cSunWarpPointName": 0x803fde70,
		"Camera::cPositionJointName": 0x803fde78,
		"cPositionJointName": 0x803fde78,
		"Camera::cLookatJointName": 0x803fde7c,
		"cLookatJointName": 0x803fde7c,
		"Camera::cCameraBckVolumeName": 0x803fde80,
		"cCameraBckVolumeName": 0x803fde80,
		"Camera::cLoadCamName": 0x803fde88,
		"cLoadCamName": 0x803fde88,
		"TNerveWaitForever<TLiveActor>::instance$localstatic0$theNerve": 0x803fdea4,
		"Enemy::instance$3230": 0x803fe068,
		"instance$3230": 0x803fe068,
		"Enemy::instance$3275": 0x803fe078,
		"instance$3275": 0x803fe078,
		"Enemy::instance$3358": 0x803fe088,
		"instance$3358": 0x803fe088,
		"Enemy::instance$3372": 0x803fe090,
		"instance$3372": 0x803fe090,
		"Enemy::instance$3382": 0x803fe098,
		"instance$3382": 0x803fe098,
		"Enemy::instance$3392": 0x803fe0a0,
		"instance$3392": 0x803fe0a0,
		"Enemy::instance$3749": 0x803fe0ac,
		"instance$3749": 0x803fe0ac,
		"Enemy::instance$3763": 0x803fe0b4,
		"instance$3763": 0x803fe0b4,
		"Enemy::instance$3792": 0x803fe0c4,
		"instance$3792": 0x803fe0c4,
		"Enemy::instance$3836": 0x803fe0dc,
		"instance$3836": 0x803fe0dc,
		"Enemy::instance$3847": 0x803fe0e4,
		"instance$3847": 0x803fe0e4,
		"Enemy::instance$3867": 0x803fe0ec,
		"instance$3867": 0x803fe0ec,
		"Enemy::instance$3881": 0x803fe0f4,
		"instance$3881": 0x803fe0f4,
		"Enemy::instance$3892": 0x803fe0fc,
		"instance$3892": 0x803fe0fc,
		"Enemy::instance$3915": 0x803fe10c,
		"instance$3915": 0x803fe10c,
		"Enemy::instance$2574": 0x803fe114,
		"instance$2574": 0x803fe114,
		"Enemy::instance$2632": 0x803fe11c,
		"instance$2632": 0x803fe11c,
		"Enemy::instance$2655": 0x803fe124,
		"instance$2655": 0x803fe124,
		"Enemy::instance$2675": 0x803fe12c,
		"instance$2675": 0x803fe12c,
		"Enemy::instance$2695": 0x803fe134,
		"instance$2695": 0x803fe134,
		"Enemy::instance$2709": 0x803fe13c,
		"instance$2709": 0x803fe13c,
		"Enemy::instance$2727": 0x803fe144,
		"instance$2727": 0x803fe144,
		"Enemy::instance$2754": 0x803fe14c,
		"instance$2754": 0x803fe14c,
		"Enemy::instance$3061": 0x803fe158,
		"instance$3061": 0x803fe158,
		"Enemy::instance$3074": 0x803fe160,
		"instance$3074": 0x803fe160,
		"Enemy::instance$3150": 0x803fe178,
		"instance$3150": 0x803fe178,
		"Enemy::instance$3164": 0x803fe188,
		"instance$3164": 0x803fe188,
		"Enemy::instance$3245": 0x803fe1a4,
		"instance$3245": 0x803fe1a4,
		"Enemy::instance$3288": 0x803fe1ac,
		"instance$3288": 0x803fe1ac,
		"Enemy::instance$3301": 0x803fe1b4,
		"instance$3301": 0x803fe1b4,
		"Enemy::instance$3349": 0x803fe1cc,
		"instance$3349": 0x803fe1cc,
		"Enemy::instance$3227": 0x803fe1dc,
		"instance$3227": 0x803fe1dc,
		"Enemy::instance$3255": 0x803fe1e4,
		"instance$3255": 0x803fe1e4,
		"Enemy::instance$3297": 0x803fe1fc,
		"instance$3297": 0x803fe1fc,
		"Enemy::instance$3309": 0x803fe204,
		"instance$3309": 0x803fe204,
		"Enemy::instance$2616": 0x803fe214,
		"instance$2616": 0x803fe214,
		"Enemy::instance$2627": 0x803fe21c,
		"instance$2627": 0x803fe21c,
		"Enemy::instance$2639": 0x803fe224,
		"instance$2639": 0x803fe224,
		"Enemy::instance$2658": 0x803fe22c,
		"instance$2658": 0x803fe22c,
		"Enemy::instance$2669": 0x803fe234,
		"instance$2669": 0x803fe234,
		"Enemy::instance$3721": 0x803fe244,
		"instance$3721": 0x803fe244,
		"Enemy::instance$3739": 0x803fe24c,
		"instance$3739": 0x803fe24c,
		"Enemy::instance$3754": 0x803fe254,
		"instance$3754": 0x803fe254,
		"Enemy::instance$3794": 0x803fe25c,
		"instance$3794": 0x803fe25c,
		"Enemy::instance$3814": 0x803fe264,
		"instance$3814": 0x803fe264,
		"Enemy::instance$3833": 0x803fe26c,
		"instance$3833": 0x803fe26c,
		"Enemy::instance$3896": 0x803fe27c,
		"instance$3896": 0x803fe27c,
		"Enemy::instance$3913": 0x803fe284,
		"instance$3913": 0x803fe284,
		"Enemy::instance$3160": 0x803fe28c,
		"instance$3160": 0x803fe28c,
		"Enemy::instance$3264": 0x803fe2ac,
		"instance$3264": 0x803fe2ac,
		"Enemy::instance$3314": 0x803fe2cc,
		"instance$3314": 0x803fe2cc,
		"Enemy::instance$3299": 0x803fe2d4,
		"instance$3299": 0x803fe2d4,
		"Enemy::instance$3325": 0x803fe2dc,
		"instance$3325": 0x803fe2dc,
		"Enemy::instance$3346": 0x803fe2e4,
		"instance$3346": 0x803fe2e4,
		"Enemy::instance$3485": 0x803fe304,
		"instance$3485": 0x803fe304,
		"Enemy::instance$3499": 0x803fe30c,
		"instance$3499": 0x803fe30c,
		"Enemy::instance$3511": 0x803fe314,
		"instance$3511": 0x803fe314,
		"Enemy::instance$3521": 0x803fe31c,
		"instance$3521": 0x803fe31c,
		"Enemy::instance$3534": 0x803fe324,
		"instance$3534": 0x803fe324,
		"Enemy::instance$3549": 0x803fe32c,
		"instance$3549": 0x803fe32c,
		"Enemy::instance$3565": 0x803fe334,
		"instance$3565": 0x803fe334,
		"Enemy::instance$3575": 0x803fe33c,
		"instance$3575": 0x803fe33c,
		"Enemy::instance$3584": 0x803fe344,
		"instance$3584": 0x803fe344,
		"Enemy::instance$3594": 0x803fe34c,
		"instance$3594": 0x803fe34c,
		"Enemy::instance$3609": 0x803fe354,
		"instance$3609": 0x803fe354,
		"Enemy::instance$3620": 0x803fe35c,
		"instance$3620": 0x803fe35c,
		"Enemy::instance$3625": 0x803fe368,
		"instance$3625": 0x803fe368,
		"Enemy::instance$3665": 0x803fe370,
		"instance$3665": 0x803fe370,
		"Enemy::instance$3678": 0x803fe378,
		"instance$3678": 0x803fe378,
		"Enemy::instance$3707": 0x803fe380,
		"instance$3707": 0x803fe380,
		"Enemy::instance$3719": 0x803fe388,
		"instance$3719": 0x803fe388,
		"Enemy::instance$3732": 0x803fe390,
		"instance$3732": 0x803fe390,
		"Enemy::instance$3745": 0x803fe398,
		"instance$3745": 0x803fe398,
		"Enemy::instance$3759": 0x803fe3a0,
		"instance$3759": 0x803fe3a0,
		"Enemy::instance$3795": 0x803fe3b0,
		"instance$3795": 0x803fe3b0,
		"Enemy::instance$3808": 0x803fe3b8,
		"instance$3808": 0x803fe3b8,
		"Enemy::instance$3834": 0x803fe3c8,
		"instance$3834": 0x803fe3c8,
		"Enemy::instance$3871": 0x803fe3e0,
		"instance$3871": 0x803fe3e0,
		"Enemy::instance$3918": 0x803fe3f8,
		"instance$3918": 0x803fe3f8,
		"Enemy::instance$3930": 0x803fe400,
		"instance$3930": 0x803fe400,
		"Enemy::instance$3940": 0x803fe408,
		"instance$3940": 0x803fe408,
		"Enemy::instance$3954": 0x803fe410,
		"instance$3954": 0x803fe410,
		"Enemy::instance$3991": 0x803fe418,
		"instance$3991": 0x803fe418,
		"Enemy::instance$4009": 0x803fe428,
		"instance$4009": 0x803fe428,
		"Enemy::instance$4025": 0x803fe430,
		"instance$4025": 0x803fe430,
		"Enemy::instance$3115": 0x803fe450,
		"instance$3115": 0x803fe450,
		"Enemy::instance$3130": 0x803fe458,
		"instance$3130": 0x803fe458,
		"Enemy::instance$3155": 0x803fe460,
		"instance$3155": 0x803fe460,
		"Enemy::instance$3180": 0x803fe470,
		"instance$3180": 0x803fe470,
		"Enemy::instance$3197": 0x803fe478,
		"instance$3197": 0x803fe478,
		"Enemy::instance$3248": 0x803fe488,
		"instance$3248": 0x803fe488,
		"Enemy::instance$3270": 0x803fe490,
		"instance$3270": 0x803fe490,
		"Enemy::instance$3282": 0x803fe498,
		"instance$3282": 0x803fe498,
		"Enemy::instance$3531": 0x803fe4a4,
		"instance$3531": 0x803fe4a4,
		"Enemy::instance$3543": 0x803fe4ac,
		"instance$3543": 0x803fe4ac,
		"Enemy::instance$3556": 0x803fe4b4,
		"instance$3556": 0x803fe4b4,
		"Enemy::instance$3479": 0x803fe4bc,
		"instance$3479": 0x803fe4bc,
		"Enemy::instance$3526": 0x803fe4c4,
		"instance$3526": 0x803fe4c4,
		"Enemy::instance$3539": 0x803fe4cc,
		"instance$3539": 0x803fe4cc,
		"Enemy::instance$3553": 0x803fe4d4,
		"instance$3553": 0x803fe4d4,
		"Enemy::instance$3564": 0x803fe4dc,
		"instance$3564": 0x803fe4dc,
		"Enemy::instance$3581": 0x803fe4e4,
		"instance$3581": 0x803fe4e4,
		"Enemy::instance$3591": 0x803fe4ec,
		"instance$3591": 0x803fe4ec,
		"Enemy::instance$3610": 0x803fe4f4,
		"instance$3610": 0x803fe4f4,
		"Enemy::instance$3629": 0x803fe4fc,
		"instance$3629": 0x803fe4fc,
		"Enemy::instance$3643": 0x803fe504,
		"instance$3643": 0x803fe504,
		"Enemy::instance$3653": 0x803fe50c,
		"instance$3653": 0x803fe50c,
		"Enemy::instance$3110": 0x803fe518,
		"instance$3110": 0x803fe518,
		"Enemy::instance$3148": 0x803fe528,
		"instance$3148": 0x803fe528,
		"Enemy::instance$3176": 0x803fe530,
		"instance$3176": 0x803fe530,
		"Enemy::instance$3200": 0x803fe538,
		"instance$3200": 0x803fe538,
		"Enemy::instance$3221": 0x803fe548,
		"instance$3221": 0x803fe548,
		"Enemy::instance$3254": 0x803fe560,
		"instance$3254": 0x803fe560,
		"Enemy::instance$3267": 0x803fe568,
		"instance$3267": 0x803fe568,
		"Enemy::instance$3457": 0x803fe594,
		"instance$3457": 0x803fe594,
		"Enemy::instance$3470": 0x803fe59c,
		"instance$3470": 0x803fe59c,
		"Enemy::instance$3137": 0x803fe5ac,
		"instance$3137": 0x803fe5ac,
		"Enemy::instance$3163": 0x803fe5b4,
		"instance$3163": 0x803fe5b4,
		"Enemy::instance$3344": 0x803fe5cc,
		"instance$3344": 0x803fe5cc,
		"Enemy::instance$3407": 0x803fe5d4,
		"instance$3407": 0x803fe5d4,
		"Enemy::instance$3425": 0x803fe5dc,
		"instance$3425": 0x803fe5dc,
		"Enemy::instance$3439": 0x803fe5e4,
		"instance$3439": 0x803fe5e4,
		"Enemy::instance$3449": 0x803fe5ec,
		"instance$3449": 0x803fe5ec,
		"Enemy::instance$3473": 0x803fe5f4,
		"instance$3473": 0x803fe5f4,
		"Enemy::instance$3500": 0x803fe5fc,
		"instance$3500": 0x803fe5fc,
		"Enemy::instance$3199": 0x803fe604,
		"instance$3199": 0x803fe604,
		"Enemy::instance$4027": 0x803fe614,
		"instance$4027": 0x803fe614,
		"Enemy::instance$4069": 0x803fe61c,
		"instance$4069": 0x803fe61c,
		"Enemy::instance$4083": 0x803fe624,
		"instance$4083": 0x803fe624,
		"Enemy::instance$4093": 0x803fe62c,
		"instance$4093": 0x803fe62c,
		"Enemy::instance$4106": 0x803fe634,
		"instance$4106": 0x803fe634,
		"Enemy::instance$4128": 0x803fe63c,
		"instance$4128": 0x803fe63c,
		"Enemy::instance$4144": 0x803fe644,
		"instance$4144": 0x803fe644,
		"Enemy::instance$4160": 0x803fe64c,
		"instance$4160": 0x803fe64c,
		"Enemy::instance$4195": 0x803fe654,
		"instance$4195": 0x803fe654,
		"Enemy::instance$4206": 0x803fe65c,
		"instance$4206": 0x803fe65c,
		"Enemy::instance$2589": 0x803fe664,
		"instance$2589": 0x803fe664,
		"Enemy::instance$3010": 0x803fe66c,
		"instance$3010": 0x803fe66c,
		"Enemy::instance$3033": 0x803fe674,
		"instance$3033": 0x803fe674,
		"Enemy::instance$3042": 0x803fe67c,
		"instance$3042": 0x803fe67c,
		"Enemy::instance$3055": 0x803fe684,
		"Enemy::instance$3079": 0x803fe68c,
		"instance$3079": 0x803fe68c,
		"Enemy::instance$3089": 0x803fe694,
		"instance$3089": 0x803fe694,
		"Enemy::instance$3101": 0x803fe69c,
		"instance$3101": 0x803fe69c,
		"Enemy::instance$3283": 0x803fe6a4,
		"instance$3283": 0x803fe6a4,
		"Enemy::instance$3296": 0x803fe6ac,
		"instance$3296": 0x803fe6ac,
		"Enemy::instance$3333": 0x803fe6b4,
		"instance$3333": 0x803fe6b4,
		"Enemy::instance$3366": 0x803fe6bc,
		"instance$3366": 0x803fe6bc,
		"Enemy::instance$3410": 0x803fe6cc,
		"instance$3410": 0x803fe6cc,
		"Enemy::instance$3462": 0x803fe6dc,
		"instance$3462": 0x803fe6dc,
		"Enemy::instance$3226": 0x803fe6ec,
		"instance$3226": 0x803fe6ec,
		"Enemy::instance$3800": 0x803fe71c,
		"instance$3800": 0x803fe71c,
		"Enemy::instance$3813": 0x803fe724,
		"instance$3813": 0x803fe724,
		"Enemy::instance$3826": 0x803fe72c,
		"instance$3826": 0x803fe72c,
		"Enemy::instance$3886": 0x803fe748,
		"instance$3886": 0x803fe748,
		"Enemy::instance$3894": 0x803fe750,
		"instance$3894": 0x803fe750,
		"Enemy::instance$3925": 0x803fe758,
		"instance$3925": 0x803fe758,
		"Enemy::instance$3944": 0x803fe760,
		"instance$3944": 0x803fe760,
		"Enemy::instance$3971": 0x803fe768,
		"instance$3971": 0x803fe768,
		"Enemy::instance$2972": 0x803fe778,
		"instance$2972": 0x803fe778,
		"Enemy::instance$2969": 0x803fe7a4,
		"instance$2969": 0x803fe7a4,
		"Enemy::instance$2983": 0x803fe7ac,
		"instance$2983": 0x803fe7ac,
		"Enemy::instance$3022": 0x803fe7bc,
		"instance$3022": 0x803fe7bc,
		"Enemy::instance$3036": 0x803fe7c4,
		"instance$3036": 0x803fe7c4,
		"Enemy::instance$3058": 0x803fe7cc,
		"instance$3058": 0x803fe7cc,
		"Enemy::instance$3212": 0x803fe7e4,
		"instance$3212": 0x803fe7e4,
		"Enemy::instance$3179": 0x803fe80c,
		"instance$3179": 0x803fe80c,
		"Enemy::instance$3196": 0x803fe814,
		"instance$3196": 0x803fe814,
		"Enemy::instance$3250": 0x803fe82c,
		"instance$3250": 0x803fe82c,
		"Enemy::instance$2774": 0x803fe84c,
		"instance$2774": 0x803fe84c,
		"Enemy::instance$2796": 0x803fe854,
		"instance$2796": 0x803fe854,
		"Enemy::instance$2974": 0x803fe89c,
		"instance$2974": 0x803fe89c,
		"Enemy::instance$3004": 0x803fe8a4,
		"instance$3004": 0x803fe8a4,
		"Enemy::instance$3078": 0x803fe8b4,
		"instance$3078": 0x803fe8b4,
		"Enemy::instance$3403": 0x803fe8dc,
		"instance$3403": 0x803fe8dc,
		"Enemy::instance$3417": 0x803fe8e4,
		"instance$3417": 0x803fe8e4,
		"Enemy::instance$3430": 0x803fe8ec,
		"instance$3430": 0x803fe8ec,
		"Enemy::instance$3458": 0x803fe8f4,
		"instance$3458": 0x803fe8f4,
		"Enemy::instance$3472": 0x803fe8fc,
		"instance$3472": 0x803fe8fc,
		"Enemy::instance$3486": 0x803fe904,
		"instance$3486": 0x803fe904,
		"Enemy::instance$2859": 0x803fe928,
		"instance$2859": 0x803fe928,
		"Enemy::instance$2685": 0x803fe93c,
		"instance$2685": 0x803fe93c,
		"Enemy::instance$2704": 0x803fe94c,
		"instance$2704": 0x803fe94c,
		"Enemy::instance$2712": 0x803fe954,
		"instance$2712": 0x803fe954,
		"Enemy::instance$2722": 0x803fe95c,
		"instance$2722": 0x803fe95c,
		"Enemy::instance$2730": 0x803fe964,
		"instance$2730": 0x803fe964,
		"Enemy::instance$2890": 0x803fe974,
		"instance$2890": 0x803fe974,
		"Enemy::instance$2842": 0x803fe98c,
		"instance$2842": 0x803fe98c,
		"Enemy::instance$2854": 0x803fe994,
		"instance$2854": 0x803fe994,
		"Enemy::instance$2864": 0x803fe99c,
		"instance$2864": 0x803fe99c,
		"Enemy::instance$2876": 0x803fe9a4,
		"instance$2876": 0x803fe9a4,
		"Enemy::instance$2889": 0x803fe9ac,
		"instance$2889": 0x803fe9ac,
		"Enemy::instance$2911": 0x803fe9bc,
		"instance$2911": 0x803fe9bc,
		"Enemy::instance$2879": 0x803fea0c,
		"instance$2879": 0x803fea0c,
		"Enemy::instance$2891": 0x803fea14,
		"instance$2891": 0x803fea14,
		"Enemy::instance$3111": 0x803fea34,
		"instance$3111": 0x803fea34,
		"Enemy::instance$3131": 0x803fea44,
		"instance$3131": 0x803fea44,
		"Enemy::instance$3149": 0x803fea54,
		"instance$3149": 0x803fea54,
		"Enemy::instance$3321": 0x803fea64,
		"instance$3321": 0x803fea64,
		"Enemy::instance$2664": 0x803fea74,
		"instance$2664": 0x803fea74,
		"Enemy::instance$2676": 0x803fea7c,
		"instance$2676": 0x803fea7c,
		"Enemy::instance$2688": 0x803fea84,
		"instance$2688": 0x803fea84,
		"Enemy::instance$2698": 0x803fea8c,
		"instance$2698": 0x803fea8c,
		"Enemy::instance$2715": 0x803fea94,
		"instance$2715": 0x803fea94,
		"Enemy::instance$2745": 0x803feaa4,
		"instance$2745": 0x803feaa4,
		"Enemy::instance$2755": 0x803feaac,
		"instance$2755": 0x803feaac,
		"Enemy::instance$2766": 0x803feab4,
		"instance$2766": 0x803feab4,
		"Enemy::instance$3102": 0x803feb0c,
		"instance$3102": 0x803feb0c,
		"Enemy::instance$3144": 0x803feb1c,
		"instance$3144": 0x803feb1c,
		"Enemy::instance$2531": 0x803feb2c,
		"instance$2531": 0x803feb2c,
		"Enemy::instance$2543": 0x803feb34,
		"instance$2543": 0x803feb34,
		"Enemy::instance$2557": 0x803feb3c,
		"instance$2557": 0x803feb3c,
		"Enemy::instance$2567": 0x803feb44,
		"instance$2567": 0x803feb44,
		"Enemy::instance$2577": 0x803feb4c,
		"instance$2577": 0x803feb4c,
		"Enemy::instance$3132": 0x803feb6c,
		"instance$3132": 0x803feb6c,
		"Enemy::instance$2851": 0x803feba4,
		"instance$2851": 0x803feba4,
		"Enemy::instance$2897": 0x803febc0,
		"instance$2897": 0x803febc0,
		"Enemy::instance$2923": 0x803febd0,
		"instance$2923": 0x803febd0,
		"Enemy::instance$2929": 0x803febd8,
		"instance$2929": 0x803febd8,
		"Enemy::instance$2939": 0x803febe0,
		"instance$2939": 0x803febe0,
		"GC2D::HX_CIRCLE_STATE1_TIME": 0x803fec84,
		"HX_CIRCLE_STATE1_TIME": 0x803fec84,
		"GC2D::HX_CIRCLE_STATE1_TIME2": 0x803fec88,
		"HX_CIRCLE_STATE1_TIME2": 0x803fec88,
		"GC2D::r$184": 0x803fec8c,
		"r$184": 0x803fec8c,
		"GC2D::p1$185": 0x803fec90,
		"p1$185": 0x803fec90,
		"GC2D::p2$186": 0x803fec94,
		"p2$186": 0x803fec94,
		"GC2D::p3$187": 0x803fec98,
		"p3$187": 0x803fec98,
		"GC2D::boke$191": 0x803feca4,
		"boke$191": 0x803feca4,
		"GC2D::STATE1_TIME": 0x803feca8,
		"STATE1_TIME": 0x803feca8,
		"GC2D::STATE1_TIME1": 0x803fecac,
		"STATE1_TIME1": 0x803fecac,
		"GC2D::STATE1_TIME2": 0x803fecb0,
		"STATE1_TIME2": 0x803fecb0,
		"GC2D::STATE1_TIME3": 0x803fecb4,
		"STATE1_TIME3": 0x803fecb4,
		"GC2D::STATE2_TIME": 0x803fecb8,
		"STATE2_TIME": 0x803fecb8,
		"GC2D::STATE3_TIME": 0x803fecbc,
		"STATE3_TIME": 0x803fecbc,
		"GC2D::rot$266": 0x803fecc0,
		"rot$266": 0x803fecc0,
		"GC2D::fade$267": 0x803fecc4,
		"fade$267": 0x803fecc4,
		"GC2D::boundstate$269": 0x803fecc8,
		"boundstate$269": 0x803fecc8,
		"GC2D::boundtimer$270": 0x803feccc,
		"boundtimer$270": 0x803feccc,
		"GC2D::bounddelta$271": 0x803fecd0,
		"bounddelta$271": 0x803fecd0,
		"GC2D::HX_LOGO_TIMER1": 0x803fecd8,
		"HX_LOGO_TIMER1": 0x803fecd8,
		"GC2D::HX_LOGO_TIMER2": 0x803fecdc,
		"HX_LOGO_TIMER2": 0x803fecdc,
		"GC2D::dp$329": 0x803fecec,
		"dp$329": 0x803fecec,
		"GC2D::bx$330": 0x803fecf0,
		"bx$330": 0x803fecf0,
		"GC2D::by$331": 0x803fecf4,
		"by$331": 0x803fecf4,
		"GC2D::count$332": 0x803fecf8,
		"count$332": 0x803fecf8,
		"GC2D::HX_TEST1_TIMER": 0x803fecfc,
		"HX_TEST1_TIMER": 0x803fecfc,
		"GC2D::HX_TEST1_TIMER2": 0x803fed00,
		"HX_TEST1_TIMER2": 0x803fed00,
		"GC2D::r$410": 0x803fed04,
		"r$410": 0x803fed04,
		"GC2D::HX_Test2_STATE1_TIME": 0x803fed08,
		"HX_Test2_STATE1_TIME": 0x803fed08,
		"GC2D::HX_Test2_STATE2_TIME": 0x803fed0c,
		"HX_Test2_STATE2_TIME": 0x803fed0c,
		"GC2D::HX_Test2_STATE3_TIME": 0x803fed10,
		"HX_Test2_STATE3_TIME": 0x803fed10,
		"GC2D::HX_Test2_STATE4_TIME": 0x803fed14,
		"HX_Test2_STATE4_TIME": 0x803fed14,
		"GC2D::r$436": 0x803fed18,
		"r$436": 0x803fed18,
		"GC2D::r$455": 0x803fed1c,
		"r$455": 0x803fed1c,
		"GC2D::HX_TEST4_TIME": 0x803fed20,
		"HX_TEST4_TIME": 0x803fed20,
		"GC2D::thin$495": 0x803fed24,
		"thin$495": 0x803fed24,
		"GC2D::rstep$496": 0x803fed28,
		"rstep$496": 0x803fed28,
		"GC2D::thin_d$497": 0x803fed2c,
		"thin_d$497": 0x803fed2c,
		"GC2D::rstep_d$498": 0x803fed30,
		"rstep_d$498": 0x803fed30,
		"GC2D::HX_TEST5_FADETIME": 0x803fed34,
		"HX_TEST5_FADETIME": 0x803fed34,
		"MoveBG::total_use_size$2279": 0x803fede4,
		"total_use_size$2279": 0x803fede4,
		"NPC::sViewObjName$2623": 0x803feef4,
		"sViewObjName$2623": 0x803feef4,
		"MSStageCubeFade::smInstance": 0x803ff0b8,
		"MSStageCubeFadeDouble::smInstance": 0x803ff0bc,
		"JKRArchive::sCurrentDirID": 0x803ff0c8,
		"sCurrentDirID": 0x803ff0c8,
		"JKRAram::sAramObject": 0x803ff0d0,
		"sAramObject": 0x803ff0d0,
		"JSystem::srcAddress": 0x803ff0f4,
		"srcAddress": 0x803ff0f4,
		"JSystem::whatdo": 0x803ff108,
		"whatdo": 0x803ff108,
		"JSystem::whatdo2": 0x803ff10c,
		"whatdo2": 0x803ff10c,
		"JSystem::DBfoundSize": 0x803ff110,
		"DBfoundSize": 0x803ff110,
		"JSystem::DBfoundOffset": 0x803ff114,
		"DBfoundOffset": 0x803ff114,
		"JSystem::DBfoundBlock": 0x803ff118,
		"DBfoundBlock": 0x803ff118,
		"JSystem::DBnewFreeBlock": 0x803ff11c,
		"DBnewFreeBlock": 0x803ff11c,
		"JSystem::DBnewUsedBlock": 0x803ff120,
		"DBnewUsedBlock": 0x803ff120,
		"JKRFileLoader::sCurrentVolume": 0x803ff128,
		"sCurrentVolume": 0x803ff128,
		"JKRHeap::sSystemHeap": 0x803ff130,
		"sSystemHeap": 0x803ff130,
		"JKRHeap::sCurrentHeap": 0x803ff134,
		"JKRHeap::sRootHeap": 0x803ff138,
		"sRootHeap": 0x803ff138,
		"JKRHeap::mErrorHandler": 0x803ff13c,
		"mErrorHandler": 0x803ff13c,
		"JKRHeap::mCodeStart": 0x803ff140,
		"mCodeStart": 0x803ff140,
		"JKRHeap::mCodeEnd": 0x803ff144,
		"mCodeEnd": 0x803ff144,
		"JKRHeap::mUserRamStart": 0x803ff148,
		"mUserRamStart": 0x803ff148,
		"JKRHeap::mUserRamEnd": 0x803ff14c,
		"mUserRamEnd": 0x803ff14c,
		"JKRHeap::mMemorySize": 0x803ff150,
		"mMemorySize": 0x803ff150,
		"JUTException::sErrorManager": 0x803ff158,
		"sErrorManager": 0x803ff158,
		"JUTException::sPreUserCallback": 0x803ff15c,
		"sPreUserCallback": 0x803ff15c,
		"JUTException::sPostUserCallback": 0x803ff160,
		"sPostUserCallback": 0x803ff160,
		"JUTException::sConsoleBuffer": 0x803ff164,
		"sConsoleBuffer": 0x803ff164,
		"JUTException::sConsoleBufferSize": 0x803ff168,
		"sConsoleBufferSize": 0x803ff168,
		"JUTException::sConsole": 0x803ff16c,
		"sConsole": 0x803ff16c,
		"JUTException::msr": 0x803ff170,
		"msr": 0x803ff170,
		"JUTException::fpscr": 0x803ff174,
		"fpscr": 0x803ff174,
		"JUTDirectPrint::sDirectPrint": 0x803ff178,
		"sDirectPrint": 0x803ff178,
		"JUTGamePad::mPadAssign": 0x803ff184,
		"mPadAssign": 0x803ff184,
		"JUTGamePad::mSuppressPadReset": 0x803ff188,
		"mSuppressPadReset": 0x803ff188,
		"JUTGamePad::sAnalogMode": 0x803ff18c,
		"sAnalogMode": 0x803ff18c,
		"JUTGamePad::CRumble::mStatus": 0x803ff190,
		"mStatus": 0x803ff190,
		"JUTGamePad::CRumble::mEnable": 0x803ff194,
		"mEnable": 0x803ff194,
		"JUTGamePad::C3ButtonReset::sCallback": 0x803ff198,
		"sCallback": 0x803ff198,
		"JUTGamePad::C3ButtonReset::sCallbackArg": 0x803ff19c,
		"sCallbackArg": 0x803ff19c,
		"JUTGamePad::C3ButtonReset::sResetOccurredPort": 0x803ff1ac,
		"sResetOccurredPort": 0x803ff1ac,
		"JSystem::jmaSinShift": 0x803ff1b4,
		"jmaSinShift": 0x803ff1b4,
		"JSystem::jmaSinTable": 0x803ff1b8,
		"jmaSinTable": 0x803ff1b8,
		"JSystem::jmaCosTable": 0x803ff1bc,
		"jmaCosTable": 0x803ff1bc,
		"J2DPrint::mStrBuff": 0x803ff1c0,
		"mStrBuff": 0x803ff1c0,
		"J2DPrint::mStrBuffSize": 0x803ff1c8,
		"mStrBuffSize": 0x803ff1c8,
		"J3DShapeMtx::currentPipeline": 0x803ff1d0,
		"currentPipeline": 0x803ff1d0,
		"JSystem::j3dDefaultViewNo": 0x803ff1d8,
		"j3dDefaultViewNo": 0x803ff1d8,
		"JSystem::dmaBuf": 0x803ff224,
		"dmaBuf": 0x803ff224,
		"JSystem::dmaEnd": 0x803ff228,
		"dmaEnd": 0x803ff228,
		"JSystem::dmaCurrent": 0x803ff22c,
		"dmaCurrent": 0x803ff22c,
		"JKRDecomp::sDecompObject": 0x803ff250,
		"sDecompObject": 0x803ff250,
		"J3DDrawPacket::sInterruptFlag": 0x803ff258,
		"sInterruptFlag": 0x803ff258,
		"J3DDrawBuffer::entryNum": 0x803ff260,
		"entryNum": 0x803ff260,
		"JKRAramStream::sAramStreamObject": 0x803ff268,
		"sAramStreamObject": 0x803ff268,
		"JKRAramStream::transBuffer": 0x803ff26c,
		"transBuffer": 0x803ff26c,
		"JKRAramStream::transSize": 0x803ff270,
		"transSize": 0x803ff270,
		"JKRAramStream::transHeap": 0x803ff274,
		"transHeap": 0x803ff274,
		"JUTAssertion::@unnamed@::sMessageLife": 0x803ff278,
		"sMessageLife": 0x803ff278,
		"JUTVideo::sManager": 0x803ff280,
		"JUTRomFont::spAboutEncoding_": 0x803ff288,
		"spAboutEncoding_": 0x803ff288,
		"JUTRomFont::spFontHeader_": 0x803ff28c,
		"spFontHeader_": 0x803ff28c,
		"JUTRomFont::suFontHeaderRefered_": 0x803ff290,
		"suFontHeaderRefered_": 0x803ff290,
		"JUTConsoleManager::sManager": 0x803ff298,
		"JSystem::sReportConsole": 0x803ff29c,
		"sReportConsole": 0x803ff29c,
		"JSystem::sWarningConsole": 0x803ff2a0,
		"sWarningConsole": 0x803ff2a0,
		"JDrama::TNameRefGen::instance": 0x803ff2a8,
		"instance": 0x803ff2a8,
		"JADHioNode::smCurrentHeap": 0x803ff2b0,
		"smCurrentHeap": 0x803ff2b0,
		"JSystem::oRandom$356": 0x803ff2bc,
		"oRandom$356": 0x803ff2bc,
		"JALSystem::spFManager": 0x803ff2c0,
		"spFManager": 0x803ff2c0,
		"JAInter::TAsnData::asnData": 0x803ff2c8,
		"asnData": 0x803ff2c8,
		"JAIBasic::basic": 0x803ff2d0,
		"basic": 0x803ff2d0,
		"JSystem::_dinfo$1264": 0x803ff2d4,
		"_dinfo$1264": 0x803ff2d4,
		"JSystem::_info$1317": 0x803ff2d8,
		"_info$1317": 0x803ff2d8,
		"JAIConst::random": 0x803ff2e0,
		"random": 0x803ff2e0,
		"JAInter::TDebugHeap::currentHeap": 0x803ff2e8,
		"currentHeap": 0x803ff2e8,
		"JAInter::StreamLib::adpcm_remain": 0x803ff2f0,
		"adpcm_remain": 0x803ff2f0,
		"JAInter::StreamLib::adpcm_loadpoint": 0x803ff2f4,
		"adpcm_loadpoint": 0x803ff2f4,
		"JAInter::StreamLib::loadsize": 0x803ff2f8,
		"loadsize": 0x803ff2f8,
		"JAInter::StreamLib::adpcm_buffer": 0x803ff2fc,
		"adpcm_buffer": 0x803ff2fc,
		"JAInter::StreamLib::loop_buffer": 0x803ff300,
		"loop_buffer": 0x803ff300,
		"JAInter::StreamLib::store_buffer": 0x803ff304,
		"store_buffer": 0x803ff304,
		"JAInter::StreamLib::assign_ch": 0x803ff308,
		"assign_ch": 0x803ff308,
		"JAInter::StreamLib::playside": 0x803ff310,
		"playside": 0x803ff310,
		"JAInter::StreamLib::playback_samples": 0x803ff314,
		"playback_samples": 0x803ff314,
		"JAInter::StreamLib::loadup_samples": 0x803ff318,
		"loadup_samples": 0x803ff318,
		"JAInter::StreamLib::adpcmbuf_state": 0x803ff31c,
		"adpcmbuf_state": 0x803ff31c,
		"JAInter::StreamLib::movieframe": 0x803ff320,
		"movieframe": 0x803ff320,
		"JAInter::StreamLib::outvolume": 0x803ff32c,
		"outvolume": 0x803ff32c,
		"JAInter::StreamLib::outpitch": 0x803ff330,
		"outpitch": 0x803ff330,
		"JAInter::StreamLib::outpan": 0x803ff334,
		"outpan": 0x803ff334,
		"JAInter::StreamLib::stackvolume": 0x803ff338,
		"stackvolume": 0x803ff338,
		"JAInter::StreamLib::stackpitch": 0x803ff33c,
		"stackpitch": 0x803ff33c,
		"JAInter::StreamLib::stackpan": 0x803ff340,
		"stackpan": 0x803ff340,
		"JAInter::StreamLib::loop_start_flag": 0x803ff348,
		"loop_start_flag": 0x803ff348,
		"JAInter::StreamLib::outpause": 0x803ff34c,
		"outpause": 0x803ff34c,
		"JAInter::StreamLib::playmode": 0x803ff350,
		"playmode": 0x803ff350,
		"JAInter::StreamLib::shift_sample": 0x803ff354,
		"shift_sample": 0x803ff354,
		"JAInter::StreamLib::extra_sample": 0x803ff358,
		"extra_sample": 0x803ff358,
		"JAInter::StreamLib::DvdLoadFlag": 0x803ff35c,
		"DvdLoadFlag": 0x803ff35c,
		"JAInter::StreamLib::startInitFlag": 0x803ff360,
		"startInitFlag": 0x803ff360,
		"JAInter::StreamLib::Mode": 0x803ff364,
		"Mode": 0x803ff364,
		"JAInter::StreamLib::Head": 0x803ff368,
		"Head": 0x803ff368,
		"JSystem::before$612": 0x803ff370,
		"before$612": 0x803ff370,
		"JSystem::oldstat$823": 0x803ff380,
		"oldstat$823": 0x803ff380,
		"JSystem::old_dspside$839": 0x803ff388,
		"old_dspside$839": 0x803ff388,
		"JAIGlobalParameter::interfaceHeapSize": 0x803ff394,
		"interfaceHeapSize": 0x803ff394,
		"JAIGlobalParameter::audioResPath": 0x803ff398,
		"audioResPath": 0x803ff398,
		"JAIGlobalParameter::minDistanceVolume": 0x803ff39c,
		"minDistanceVolume": 0x803ff39c,
		"JAISound::interPointer": 0x803ff3a0,
		"interPointer": 0x803ff3a0,
		"JASystem::TBank::sCurrentHeap": 0x803ff3a8,
		"JASystem::BankMgr::sTableSize": 0x803ff3b0,
		"JASystem::BankMgr::sBankArray": 0x803ff3b4,
		"sBankArray": 0x803ff3b4,
		"JASystem::BankMgr::sVir2PhyTable": 0x803ff3b8,
		"sVir2PhyTable": 0x803ff3b8,
		"JASystem::BNKParser::sUsedHeapSize": 0x803ff3c0,
		"JSystem::oscp$295": 0x803ff3c8,
		"oscp$295": 0x803ff3c8,
		"JSystem::oRandom$331": 0x803ff3d4,
		"oRandom$331": 0x803ff3d4,
		"JASystem::TWaveBank::sCurrentHeap": 0x803ff3d8,
		"JASystem::WaveBankMgr::sTableSize": 0x803ff3e0,
		"JASystem::WaveBankMgr::sWaveBank": 0x803ff3e4,
		"sWaveBank": 0x803ff3e4,
		"JASystem::WSParser::sUsedHeapSize": 0x803ff3e8,
		"JASystem::AudioThread::isDSPBoot": 0x803ff3f0,
		"isDSPBoot": 0x803ff3f0,
		"JASystem::AudioThread::audioproc_mq_init": 0x803ff3f4,
		"audioproc_mq_init": 0x803ff3f4,
		"JASystem::AudioThread::intcount": 0x803ff3f8,
		"intcount": 0x803ff3f8,
		"JASystem::AudioThread::priority_set": 0x803ff3fc,
		"priority_set": 0x803ff3fc,
		"JASystem::AudioThread::jac_pri": 0x803ff400,
		"jac_pri": 0x803ff400,
		"JASystem::AudioThread::dvd_pri": 0x803ff404,
		"dvd_pri": 0x803ff404,
		"JSystem::first$120": 0x803ff408,
		"first$120": 0x803ff408,
		"JASystem::Driver::DSPQueue::waitp": 0x803ff410,
		"waitp": 0x803ff410,
		"JASystem::Driver::DSPQueue::waittime": 0x803ff414,
		"waittime": 0x803ff414,
		"JASystem::Driver::DSPQueue::cur_waits": 0x803ff418,
		"cur_waits": 0x803ff418,
		"JASystem::Driver::DSPQueue::cur_top": 0x803ff41c,
		"cur_top": 0x803ff41c,
		"JASystem::Driver::DSPQueue::cur_tail": 0x803ff420,
		"cur_tail": 0x803ff420,
		"JASystem::ChGlobal::GLOBAL_CHANNEL": 0x803ff428,
		"GLOBAL_CHANNEL": 0x803ff428,
		"JASystem::ChGlobal::CHANNEL": 0x803ff42c,
		"CHANNEL": 0x803ff42c,
		"JASystem::ChGlobal::OSCILLATOR": 0x803ff430,
		"OSCILLATOR": 0x803ff430,
		"JASystem::DSPBuf::dac_sync_counter": 0x803ff43c,
		"dac_sync_counter": 0x803ff43c,
		"JASystem::TDSPChannel::DSPCH": 0x803ff440,
		"DSPCH": 0x803ff440,
		"JASystem::TDSPChannel::smnUse": 0x803ff444,
		"smnUse": 0x803ff444,
		"JSystem::first$144": 0x803ff448,
		"first$144": 0x803ff448,
		"JASystem::old_time": 0x803ff450,
		"old_time": 0x803ff450,
		"JASystem::DSPInterface::CH_BUF": 0x803ff458,
		"CH_BUF": 0x803ff458,
		"JASystem::DSPInterface::FX_BUF": 0x803ff45c,
		"FX_BUF": 0x803ff45c,
		"JASystem::Kernel::JASUniversalDacCounter": 0x803ff460,
		"JASUniversalDacCounter": 0x803ff460,
		"JASystem::Kernel::lastRspMadep": 0x803ff464,
		"lastRspMadep": 0x803ff464,
		"JASystem::Kernel::useRspMadep": 0x803ff468,
		"useRspMadep": 0x803ff468,
		"JASystem::Kernel::vframeWorkRunning": 0x803ff46c,
		"vframeWorkRunning": 0x803ff46c,
		"JASystem::Kernel::dacCallbackFunc": 0x803ff470,
		"dacCallbackFunc": 0x803ff470,
		"JASystem::Kernel::JASVframeCounter": 0x803ff474,
		"JASVframeCounter": 0x803ff474,
		"JASystem::Kernel::extMixCallback": 0x803ff478,
		"extMixCallback": 0x803ff478,
		"JSystem::dacp$140": 0x803ff480,
		"dacp$140": 0x803ff480,
		"JASystem::Calc::JASC_SINTABLE": 0x803ff488,
		"JASC_SINTABLE": 0x803ff488,
		"JASystem::Calc::JASC_DOL2TABLE": 0x803ff48c,
		"JASC_DOL2TABLE": 0x803ff48c,
		"JASystem::Kernel::callList": 0x803ff490,
		"callList": 0x803ff490,
		"JSystem::cmd_once": 0x803ff498,
		"cmd_once": 0x803ff498,
		"JSystem::cmd_stay": 0x803ff4a0,
		"cmd_stay": 0x803ff4a0,
		"JASystem::Dvd::mqInit": 0x803ff4a8,
		"mqInit": 0x803ff4a8,
		"JASystem::Dvd::buffersize": 0x803ff4ac,
		"buffersize": 0x803ff4ac,
		"JASystem::Dvd::buffers": 0x803ff4b0,
		"buffers": 0x803ff4b0,
		"JASystem::Dvd::nextBufferSize": 0x803ff4b4,
		"nextBufferSize": 0x803ff4b4,
		"JASystem::Dvd::nextBufferTop": 0x803ff4b8,
		"nextBufferTop": 0x803ff4b8,
		"JASystem::Dvd::nextBuffers": 0x803ff4bc,
		"nextBuffers": 0x803ff4bc,
		"JASystem::Dvd::audioDvdBuffer": 0x803ff4c0,
		"audioDvdBuffer": 0x803ff4c0,
		"JASystem::Dvd::bufferLoad": 0x803ff4c8,
		"bufferLoad": 0x803ff4c8,
		"JASystem::Dvd::bufferFull": 0x803ff4cc,
		"bufferFull": 0x803ff4cc,
		"JASystem::Dvd::callStackArray": 0x803ff4d0,
		"callStackArray": 0x803ff4d0,
		"JASystem::Dvd::msgBuf": 0x803ff4d4,
		"msgBuf": 0x803ff4d4,
		"JASystem::Dvd::curQ": 0x803ff4d8,
		"curQ": 0x803ff4d8,
		"JASystem::Dvd::dvdtSleep": 0x803ff4dc,
		"dvdtSleep": 0x803ff4dc,
		"JASystem::Dvd::dvdThreadPauseFlag": 0x803ff4e4,
		"dvdThreadPauseFlag": 0x803ff4e4,
		"JASystem::Dvd::errorCallback": 0x803ff4e8,
		"errorCallback": 0x803ff4e8,
		"JASystem::Dvd::dvdFileDics": 0x803ff4ec,
		"dvdFileDics": 0x803ff4ec,
		"JASystem::Dvd::dvdFile": 0x803ff4f0,
		"dvdFile": 0x803ff4f0,
		"JASystem::Dvd::dvdEntryNum": 0x803ff4f4,
		"dvdEntryNum": 0x803ff4f4,
		"JSystem::arq_index$316": 0x803ff4f8,
		"arq_index$316": 0x803ff4f8,
		"JASystem::HardStream::streamFiles": 0x803ff504,
		"streamFiles": 0x803ff504,
		"JASystem::HardStream::playList": 0x803ff508,
		"playList": 0x803ff508,
		"JSystem::cur_finfo$426": 0x803ff50c,
		"cur_finfo$426": 0x803ff50c,
		"JSystem::last_frame$577": 0x803ff514,
		"last_frame$577": 0x803ff514,
		"JASystem::Kernel::global_id": 0x803ff520,
		"global_id": 0x803ff520,
		"JASystem::Kernel::gOutputRate": 0x803ff528,
		"gOutputRate": 0x803ff528,
		"JASystem::Kernel::gAiSetting": 0x803ff52c,
		"gAiSetting": 0x803ff52c,
		"JSystem::JASDram": 0x803ff530,
		"JASDram": 0x803ff530,
		"JASystem::Kernel::JASAramDmaBufferTop": 0x803ff534,
		"JASAramDmaBufferTop": 0x803ff534,
		"JASystem::Kernel::audioAramTop": 0x803ff538,
		"audioAramTop": 0x803ff538,
		"JASystem::Kernel::CARD_SECURITY_BUFFER": 0x803ff53c,
		"CARD_SECURITY_BUFFER": 0x803ff53c,
		"JASystem::Vload::vlDirName": 0x803ff540,
		"vlDirName": 0x803ff540,
		"JASystem::Vload::vlArcName": 0x803ff544,
		"vlArcName": 0x803ff544,
		"JASystem::Vload::vlArc": 0x803ff548,
		"vlArc": 0x803ff548,
		"JASystem::Vload::vlCurrentArcs": 0x803ff54c,
		"vlCurrentArcs": 0x803ff54c,
		"JASystem::TTrack::sCallBackFunc": 0x803ff554,
		"sCallBackFunc": 0x803ff554,
		"JASystem::TrackMgr::sTrackPool": 0x803ff558,
		"sTrackPool": 0x803ff558,
		"JASystem::TrackMgr::sSeqOuter": 0x803ff55c,
		"sSeqOuter": 0x803ff55c,
		"JASystem::TrackMgr::sRootTrack": 0x803ff560,
		"sRootTrack": 0x803ff560,
		"JASystem::TrackMgr::sFreeSeqpQueue": 0x803ff564,
		"sFreeSeqpQueue": 0x803ff564,
		"JASystem::TrackMgr::sRootSeqCount": 0x803ff568,
		"sRootSeqCount": 0x803ff568,
		"JASystem::TrackMgr::sTrackCount": 0x803ff56c,
		"sTrackCount": 0x803ff56c,
		"JASystem::TrackMgr::sTLists": 0x803ff570,
		"sTLists": 0x803ff570,
		"JASystem::TrackMgr::seqRemain": 0x803ff574,
		"seqRemain": 0x803ff574,
		"JASystem::TrackMgr::getP": 0x803ff578,
		"getP": 0x803ff578,
		"JASystem::TrackMgr::backP": 0x803ff57c,
		"backP": 0x803ff57c,
		"JSystem::FieldRand": 0x803ff580,
		"FieldRand": 0x803ff580,
		"JPADrawContext::pcb": 0x803ff588,
		"pcb": 0x803ff588,
		"JSystem::flag": 0x803ff590,
		"flag": 0x803ff590,
		"JSystem::taskreadp": 0x803ff598,
		"taskreadp": 0x803ff598,
		"JSystem::taskwritep": 0x803ff59c,
		"taskwritep": 0x803ff59c,
		"JSystem::__DSP_tmp_task": 0x803ff5a0,
		"__DSP_tmp_task": 0x803ff5a0,
		"JSystem::AUDIO_UPDATE_REQUEST": 0x803ff5ac,
		"AUDIO_UPDATE_REQUEST": 0x803ff5ac,
		"JSystem::DSP_prior_task": 0x803ff5b0,
		"DSP_prior_task": 0x803ff5b0,
		"Runtime.PPCEABI.H::__global_destructor_chain": 0x803ff5b8,
		"__global_destructor_chain": 0x803ff5b8,
		"MSL_C.PPCEABI.bare.H::__aborting": 0x803ff5c0,
		"__aborting": 0x803ff5c0,
		"MSL_C.PPCEABI.bare.H::atexit_curr_func": 0x803ff5c4,
		"atexit_curr_func": 0x803ff5c4,
		"MSL_C.PPCEABI.bare.H::__atexit_curr_func": 0x803ff5c8,
		"__atexit_curr_func": 0x803ff5c8,
		"MSL_C.PPCEABI.bare.H::__stdio_exit": 0x803ff5cc,
		"__stdio_exit": 0x803ff5cc,
		"MSL_C.PPCEABI.bare.H::__console_exit": 0x803ff5d0,
		"__console_exit": 0x803ff5d0,
		"MSL_C.PPCEABI.bare.H::errno": 0x803ff5d8,
		"errno": 0x803ff5d8,
		"MSL_C.PPCEABI.bare.H::initialized$16": 0x803ff5e0,
		"initialized$16": 0x803ff5e0,
		"db::__DBInterface": 0x803ff5e8,
		"__DBInterface": 0x803ff5e8,
		"db::DBVerbose": 0x803ff5ec,
		"DBVerbose": 0x803ff5ec,
		"os::BootInfo": 0x803ff5f0,
		"os::BI2DebugFlag": 0x803ff5f4,
		"BI2DebugFlag": 0x803ff5f4,
		"os::BI2DebugFlagHolder": 0x803ff5f8,
		"BI2DebugFlagHolder": 0x803ff5f8,
		"os::__OSIsGcam": 0x803ff5fc,
		"__OSIsGcam": 0x803ff5fc,
		"os::AreWeInitialized": 0x803ff600,
		"AreWeInitialized": 0x803ff600,
		"os::OSExceptionTable": 0x803ff604,
		"OSExceptionTable": 0x803ff604,
		"os::__OSSavedRegionEnd": 0x803ff608,
		"__OSSavedRegionEnd": 0x803ff608,
		"os::__OSSavedRegionStart": 0x803ff60c,
		"__OSSavedRegionStart": 0x803ff60c,
		"os::__OSInIPL": 0x803ff610,
		"__OSInIPL": 0x803ff610,
		"os::AlarmQueue": 0x803ff620,
		"AlarmQueue": 0x803ff620,
		"os::HeapArray": 0x803ff628,
		"HeapArray": 0x803ff628,
		"os::NumHeaps": 0x803ff62c,
		"NumHeaps": 0x803ff62c,
		"os::ArenaStart": 0x803ff630,
		"ArenaStart": 0x803ff630,
		"os::ArenaEnd": 0x803ff634,
		"ArenaEnd": 0x803ff634,
		"os::__OSArenaHi": 0x803ff638,
		"__OSArenaHi": 0x803ff638,
		"os::FontData": 0x803ff640,
		"FontData": 0x803ff640,
		"os::SheetImage": 0x803ff644,
		"SheetImage": 0x803ff644,
		"os::WidthTable": 0x803ff648,
		"WidthTable": 0x803ff648,
		"os::CharsInSheet": 0x803ff64c,
		"CharsInSheet": 0x803ff64c,
		"os::InterruptHandlerTable": 0x803ff650,
		"InterruptHandlerTable": 0x803ff650,
		"os::__OSLastInterruptSrr0": 0x803ff654,
		"__OSLastInterruptSrr0": 0x803ff654,
		"os::SaveStart": 0x803ff668,
		"SaveStart": 0x803ff668,
		"os::SaveEnd": 0x803ff66c,
		"SaveEnd": 0x803ff66c,
		"os::Prepared": 0x803ff670,
		"Prepared": 0x803ff670,
		"os::ResetFunctionQueue": 0x803ff678,
		"ResetFunctionQueue": 0x803ff678,
		"os::ResetCallback": 0x803ff680,
		"ResetCallback": 0x803ff680,
		"os::Down": 0x803ff684,
		"Down": 0x803ff684,
		"os::LastState": 0x803ff688,
		"os::RunQueueBits": 0x803ff6a0,
		"RunQueueBits": 0x803ff6a0,
		"os::RunQueueHint": 0x803ff6a4,
		"RunQueueHint": 0x803ff6a4,
		"os::Reschedule": 0x803ff6a8,
		"Reschedule": 0x803ff6a8,
		"dvd::StopAtNextInt": 0x803ff6b0,
		"StopAtNextInt": 0x803ff6b0,
		"dvd::LastLength": 0x803ff6b4,
		"LastLength": 0x803ff6b4,
		"dvd::Callback": 0x803ff6b8,
		"dvd::ResetCoverCallback": 0x803ff6bc,
		"ResetCoverCallback": 0x803ff6bc,
		"dvd::ResetOccurred": 0x803ff6c8,
		"ResetOccurred": 0x803ff6c8,
		"dvd::WaitingCoverClose": 0x803ff6cc,
		"WaitingCoverClose": 0x803ff6cc,
		"dvd::Breaking": 0x803ff6d0,
		"Breaking": 0x803ff6d0,
		"dvd::WorkAroundType": 0x803ff6d4,
		"WorkAroundType": 0x803ff6d4,
		"dvd::WorkAroundSeekLocation": 0x803ff6d8,
		"WorkAroundSeekLocation": 0x803ff6d8,
		"dvd::LastCommandWasRead": 0x803ff6f0,
		"LastCommandWasRead": 0x803ff6f0,
		"dvd::NextCommandNumber": 0x803ff6f4,
		"NextCommandNumber": 0x803ff6f4,
		"dvd::BootInfo": 0x803ff6f8,
		"dvd::FstStart": 0x803ff6fc,
		"FstStart": 0x803ff6fc,
		"dvd::FstStringStart": 0x803ff700,
		"FstStringStart": 0x803ff700,
		"dvd::MaxEntryNum": 0x803ff704,
		"MaxEntryNum": 0x803ff704,
		"dvd::currentDirectory": 0x803ff708,
		"currentDirectory": 0x803ff708,
		"dvd::__DVDLongFileNameFlag": 0x803ff70c,
		"__DVDLongFileNameFlag": 0x803ff70c,
		"dvd::__DVDThreadQueue": 0x803ff710,
		"__DVDThreadQueue": 0x803ff710,
		"dvd::executing": 0x803ff718,
		"executing": 0x803ff718,
		"dvd::currID": 0x803ff71c,
		"currID": 0x803ff71c,
		"dvd::bootInfo": 0x803ff720,
		"bootInfo": 0x803ff720,
		"dvd::PauseFlag": 0x803ff724,
		"PauseFlag": 0x803ff724,
		"dvd::PausingFlag": 0x803ff728,
		"PausingFlag": 0x803ff728,
		"dvd::AutoFinishing": 0x803ff72c,
		"AutoFinishing": 0x803ff72c,
		"dvd::FatalErrorFlag": 0x803ff730,
		"FatalErrorFlag": 0x803ff730,
		"dvd::CurrCommand": 0x803ff734,
		"CurrCommand": 0x803ff734,
		"dvd::Canceling": 0x803ff738,
		"Canceling": 0x803ff738,
		"dvd::CancelCallback": 0x803ff73c,
		"CancelCallback": 0x803ff73c,
		"dvd::ResumeFromHere": 0x803ff740,
		"ResumeFromHere": 0x803ff740,
		"dvd::CancelLastError": 0x803ff744,
		"CancelLastError": 0x803ff744,
		"dvd::LastError": 0x803ff748,
		"LastError": 0x803ff748,
		"dvd::NumInternalRetry": 0x803ff74c,
		"NumInternalRetry": 0x803ff74c,
		"dvd::ResetRequired": 0x803ff750,
		"ResetRequired": 0x803ff750,
		"dvd::FirstTimeInBootrom": 0x803ff754,
		"FirstTimeInBootrom": 0x803ff754,
		"dvd::DVDInitialized": 0x803ff758,
		"DVDInitialized": 0x803ff758,
		"dvd::LastState": 0x803ff75c,
		"dvd::status": 0x803ff760,
		"status": 0x803ff760,
		"dvd::bb2": 0x803ff764,
		"bb2": 0x803ff764,
		"dvd::idTmp": 0x803ff768,
		"idTmp": 0x803ff768,
		"vi::retraceCount": 0x803ff770,
		"retraceCount": 0x803ff770,
		"vi::flushFlag": 0x803ff774,
		"flushFlag": 0x803ff774,
		"vi::retraceQueue": 0x803ff778,
		"retraceQueue": 0x803ff778,
		"vi::PreCB": 0x803ff780,
		"PreCB": 0x803ff780,
		"vi::PostCB": 0x803ff784,
		"PostCB": 0x803ff784,
		"vi::encoderType": 0x803ff788,
		"encoderType": 0x803ff788,
		"vi::changeMode": 0x803ff790,
		"vi::shdwChangeMode": 0x803ff7a0,
		"shdwChangeMode": 0x803ff7a0,
		"vi::CurrTiming": 0x803ff7b0,
		"CurrTiming": 0x803ff7b0,
		"vi::CurrTvMode": 0x803ff7b4,
		"CurrTvMode": 0x803ff7b4,
		"vi::FBSet": 0x803ff7b8,
		"FBSet": 0x803ff7b8,
		"vi::message$332": 0x803ff7bc,
		"message$332": 0x803ff7bc,
		"pad::Initialized": 0x803ff7c0,
		"pad::EnabledBits": 0x803ff7c4,
		"EnabledBits": 0x803ff7c4,
		"pad::ResettingBits": 0x803ff7c8,
		"ResettingBits": 0x803ff7c8,
		"pad::RecalibrateBits": 0x803ff7cc,
		"RecalibrateBits": 0x803ff7cc,
		"pad::WaitingBits": 0x803ff7d0,
		"WaitingBits": 0x803ff7d0,
		"pad::CheckingBits": 0x803ff7d4,
		"CheckingBits": 0x803ff7d4,
		"pad::PendingBits": 0x803ff7d8,
		"PendingBits": 0x803ff7d8,
		"pad::SamplingCallback": 0x803ff7dc,
		"SamplingCallback": 0x803ff7dc,
		"pad::recalibrated$396": 0x803ff7e0,
		"recalibrated$396": 0x803ff7e0,
		"pad::__PADSpec": 0x803ff7e4,
		"__PADSpec": 0x803ff7e4,
		"ai::__AIS_Callback": 0x803ff7e8,
		"__AIS_Callback": 0x803ff7e8,
		"ai::__AID_Callback": 0x803ff7ec,
		"__AID_Callback": 0x803ff7ec,
		"ai::__CallbackStack": 0x803ff7f0,
		"__CallbackStack": 0x803ff7f0,
		"ai::__OldStack": 0x803ff7f4,
		"__OldStack": 0x803ff7f4,
		"ai::__AI_init_flag": 0x803ff7f8,
		"__AI_init_flag": 0x803ff7f8,
		"ar::__AR_Callback": 0x803ff828,
		"__AR_Callback": 0x803ff828,
		"ar::__AR_Size": 0x803ff82c,
		"__AR_Size": 0x803ff82c,
		"ar::__AR_InternalSize": 0x803ff830,
		"__AR_InternalSize": 0x803ff830,
		"ar::__AR_ExpansionSize": 0x803ff834,
		"__AR_ExpansionSize": 0x803ff834,
		"ar::__AR_StackPointer": 0x803ff838,
		"__AR_StackPointer": 0x803ff838,
		"ar::__AR_FreeBlocks": 0x803ff83c,
		"__AR_FreeBlocks": 0x803ff83c,
		"ar::__AR_BlockLength": 0x803ff840,
		"__AR_BlockLength": 0x803ff840,
		"ar::__AR_init_flag": 0x803ff844,
		"__AR_init_flag": 0x803ff844,
		"ar::__ARQRequestQueueHi": 0x803ff848,
		"__ARQRequestQueueHi": 0x803ff848,
		"ar::__ARQRequestTailHi": 0x803ff84c,
		"__ARQRequestTailHi": 0x803ff84c,
		"ar::__ARQRequestQueueLo": 0x803ff850,
		"__ARQRequestQueueLo": 0x803ff850,
		"ar::__ARQRequestTailLo": 0x803ff854,
		"__ARQRequestTailLo": 0x803ff854,
		"ar::__ARQRequestPendingHi": 0x803ff858,
		"__ARQRequestPendingHi": 0x803ff858,
		"ar::__ARQRequestPendingLo": 0x803ff85c,
		"__ARQRequestPendingLo": 0x803ff85c,
		"ar::__ARQCallbackHi": 0x803ff860,
		"__ARQCallbackHi": 0x803ff860,
		"ar::__ARQCallbackLo": 0x803ff864,
		"__ARQCallbackLo": 0x803ff864,
		"ar::__ARQChunkSize": 0x803ff868,
		"__ARQChunkSize": 0x803ff868,
		"ar::__ARQ_init_flag": 0x803ff86c,
		"__ARQ_init_flag": 0x803ff86c,
		"dsp::__DSP_init_flag": 0x803ff870,
		"__DSP_init_flag": 0x803ff870,
		"dsp::__DSP_last_task": 0x803ff878,
		"__DSP_last_task": 0x803ff878,
		"dsp::__DSP_first_task": 0x803ff87c,
		"__DSP_first_task": 0x803ff87c,
		"dsp::__DSP_curr_task": 0x803ff880,
		"__DSP_curr_task": 0x803ff880,
		"gx::__piReg": 0x803ff888,
		"__piReg": 0x803ff888,
		"gx::__cpReg": 0x803ff88c,
		"__cpReg": 0x803ff88c,
		"gx::__peReg": 0x803ff890,
		"__peReg": 0x803ff890,
		"gx::__memReg": 0x803ff894,
		"__memReg": 0x803ff894,
		"gx::CPUFifo": 0x803ff898,
		"CPUFifo": 0x803ff898,
		"gx::GPFifo": 0x803ff89c,
		"GPFifo": 0x803ff89c,
		"gx::__GXCurrentThread": 0x803ff8a0,
		"__GXCurrentThread": 0x803ff8a0,
		"gx::GXOverflowSuspendInProgress": 0x803ff8a8,
		"GXOverflowSuspendInProgress": 0x803ff8a8,
		"gx::BreakPointCB": 0x803ff8ac,
		"BreakPointCB": 0x803ff8ac,
		"gx::__GXOverflowCount": 0x803ff8b0,
		"__GXOverflowCount": 0x803ff8b0,
		"gx::__GXCurrentBP": 0x803ff8b4,
		"__GXCurrentBP": 0x803ff8b4,
		"gx::TokenCB": 0x803ff8b8,
		"TokenCB": 0x803ff8b8,
		"gx::DrawDoneCB": 0x803ff8bc,
		"DrawDoneCB": 0x803ff8bc,
		"gx::FinishQueue": 0x803ff8c4,
		"FinishQueue": 0x803ff8c4,
		"OdemuExi2::MTRCallback": 0x803ff8d0,
		"MTRCallback": 0x803ff8d0,
		"OdemuExi2::DBGCallback": 0x803ff8d4,
		"DBGCallback": 0x803ff8d4,
		"OdemuExi2::SendMailData": 0x803ff8d8,
		"SendMailData": 0x803ff8d8,
		"OdemuExi2::RecvDataLeng": 0x803ff8dc,
		"RecvDataLeng": 0x803ff8dc,
		"OdemuExi2::pEXIInputFlag": 0x803ff8e0,
		"pEXIInputFlag": 0x803ff8e0,
		"gd::__GDCurrentDL": 0x803ff8e8,
		"__GDCurrentDL": 0x803ff8e8,
		"gd::overflowcb": 0x803ff8ec,
		"overflowcb": 0x803ff8ec,
		"si::cmdTypeAndStatus$77": 0x803ff8f0,
		"cmdTypeAndStatus$77": 0x803ff8f0,
		"si::cmdTypeAndStatus$371": 0x803ff8f4,
		"cmdTypeAndStatus$371": 0x803ff8f4,
		"si::__PADFixBits": 0x803ff8f8,
		"__PADFixBits": 0x803ff8f8,
		"si::SamplingRate": 0x803ff900,
		"SamplingRate": 0x803ff900,
		"exi::Chan": 0x803ff908,
		"Chan": 0x803ff908,
		"exi::Dev": 0x803ff90c,
		"Dev": 0x803ff90c,
		"exi::Enabled": 0x803ff910,
		"Enabled": 0x803ff910,
		"exi::BarnacleEnabled": 0x803ff914,
		"BarnacleEnabled": 0x803ff914,
		"thp::__THPHuffmanBits": 0x803ff9c4,
		"__THPHuffmanBits": 0x803ff9c4,
		"thp::__THPHuffmanSizeTab": 0x803ff9c8,
		"__THPHuffmanSizeTab": 0x803ff9c8,
		"thp::__THPHuffmanCodeTab": 0x803ff9cc,
		"__THPHuffmanCodeTab": 0x803ff9cc,
		"thp::__THPOldGQR5": 0x803ffa24,
		"__THPOldGQR5": 0x803ffa24,
		"thp::__THPOldGQR6": 0x803ffa28,
		"__THPOldGQR6": 0x803ffa28,
		"thp::__THPWorkArea": 0x803ffa2c,
		"__THPWorkArea": 0x803ffa2c,
		"thp::__THPInfo": 0x803ffa30,
		"__THPInfo": 0x803ffa30,
		"thp::__THPInitFlag": 0x803ffa34,
		"__THPInitFlag": 0x803ffa34,
		"THPPlayer::AudioDecodeThreadCreated": 0x803fe018,
		"AudioDecodeThreadCreated": 0x803fe018,
		"THPPlayer::Initialized": 0x803fe020,
		"THPPlayer::PrepareReadyMessage": 0x803fe024,
		"PrepareReadyMessage": 0x803fe024,
		"THPPlayer::OldVIPostCallback": 0x803fe028,
		"OldVIPostCallback": 0x803fe028,
		"THPPlayer::SoundBufferIndex": 0x803fe02c,
		"SoundBufferIndex": 0x803fe02c,
		"THPPlayer::LastAudioBuffer": 0x803fe030,
		"LastAudioBuffer": 0x803fe030,
		"THPPlayer::CurAudioBuffer": 0x803fe034,
		"CurAudioBuffer": 0x803fe034,
		"THPPlayer::ReadThreadCreated": 0x803fe038,
		"ReadThreadCreated": 0x803fe038,
		"THPPlayer::VideoDecodeThreadCreated": 0x803fe040,
		"VideoDecodeThreadCreated": 0x803fe040,
		"THPPlayer::First": 0x803fe044,
		"First": 0x803fe044,
		"MarioUtil::gpSilhouetteManager": 0x803fef30,
		"gpSilhouetteManager": 0x803fef30,
		"MarioUtil::sKeepViewClipFovy": 0x803fef34,
		"sKeepViewClipFovy": 0x803fef34,
		"MarioUtil::sKeepViewClipAspect": 0x803fef38,
		"sKeepViewClipAspect": 0x803fef38,
		"MarioUtil::sKeepViewClipNear": 0x803fef3c,
		"sKeepViewClipNear": 0x803fef3c,
		"MarioUtil::sKeepViewClipFar": 0x803fef40,
		"sKeepViewClipFar": 0x803fef40,
		"TLightCommon::mAmbAry": 0x803fef48,
		"mAmbAry": 0x803fef48,
		"TLightCommon::mLightAry": 0x803fef4c,
		"mLightAry": 0x803fef4c,
		"TLightCommon::mLightPos": 0x803fef50,
		"mLightPos": 0x803fef50,
		"MarioUtil::gpLightManager": 0x803fef54,
		"gpLightManager": 0x803fef54,
		"MarioUtil::gpAfterEffect": 0x803fef58,
		"gpAfterEffect": 0x803fef58,
		"MarioUtil::gpScreenTexture": 0x803fef5c,
		"gpScreenTexture": 0x803fef5c,
		"MarioUtil::gpBindShadowManager": 0x803fef60,
		"gpBindShadowManager": 0x803fef60,
		"TMBindShadowManager::mJoinDist": 0x803fef64,
		"mJoinDist": 0x803fef64,
		"MarioUtil::SMSRumbleMgr": 0x803fef70,
		"SMSRumbleMgr": 0x803fef70,
		"MarioUtil::currentTGDLStatic": 0x803fef78,
		"currentTGDLStatic": 0x803fef78,
		"System::gpMarioParticleManager": 0x803feff0,
		"gpMarioParticleManager": 0x803feff0,
		"System::emitterCallBackBindToPosPtr": 0x803feff4,
		"emitterCallBackBindToPosPtr": 0x803feff4,
		"System::emitterCallBackBindToMtxPtr": 0x803feff8,
		"emitterCallBackBindToMtxPtr": 0x803feff8,
		"System::emitterCallBackBindToSRTMtxPtr": 0x803feffc,
		"emitterCallBackBindToSRTMtxPtr": 0x803feffc,
		"TFlagManager::smInstance": 0x803ff000,
		"System::gpSceneCmnDat": 0x803ff008,
		"gpSceneCmnDat": 0x803ff008,
		"System::gpSceneCmnDatSize": 0x803ff00c,
		"gpSceneCmnDatSize": 0x803ff00c,
		"TParams::mArc": 0x803ff010,
		"mArc": 0x803ff010,
		"TParams::mSceneArc": 0x803ff014,
		"mSceneArc": 0x803ff014,
		"System::gpMarDirector": 0x803ff018,
		"gpMarDirector": 0x803ff018,
		"System::gpMSound": 0x803ff01c,
		"gpMSound": 0x803ff01c,
		"System::gpSetupThreadStack": 0x803ff020,
		"gpSetupThreadStack": 0x803ff020,
		"System::gpCardManager": 0x803ff024,
		"gpCardManager": 0x803ff024,
		"System::gpSystemFont": 0x803ff028,
		"gpSystemFont": 0x803ff028,
		"System::gpRomFont": 0x803ff02c,
		"gpRomFont": 0x803ff02c,
		"System::sGameInit": 0x803ff030,
		"sGameInit": 0x803ff030,
		"System::arcBufNLogo": 0x803ff034,
		"arcBufNLogo": 0x803ff034,
		"System::arcBufMario": 0x803ff038,
		"arcBufMario": 0x803ff038,
		"System::arcBufCmn": 0x803ff03c,
		"arcBufCmn": 0x803ff03c,
		"System::bufStageArcBin": 0x803ff040,
		"bufStageArcBin": 0x803ff040,
		"System::spGameHeapBlock": 0x803ff044,
		"spGameHeapBlock": 0x803ff044,
		"System::gArBkConsole": 0x803ff048,
		"gArBkConsole": 0x803ff048,
		"System::gArBkGuide": 0x803ff050,
		"gArBkGuide": 0x803ff050,
		"TMarioGamePad::mResetFlag": 0x803ff058,
		"mResetFlag": 0x803ff058,
		"System::gpPositionHolder": 0x803ff060,
		"gpPositionHolder": 0x803ff060,
		"TTimeRec::_instance": 0x803ff068,
		"_instance": 0x803ff068,
		"TDrawSyncManager::smInstance": 0x803ff070,
		"System::sDetach": 0x803ff078,
		"sDetach": 0x803ff078,
		"System::gpResourceManager": 0x803ff080,
		"gpResourceManager": 0x803ff080,
		"System::gpEmitterManager4D2": 0x803ff084,
		"gpEmitterManager4D2": 0x803ff084,
		"MSMainProc::MSStageInfo::msStg": 0x803ff088,
		"msStg": 0x803ff088,
		"MSMainProc::MSStageInfo::demoBgm": 0x803ff08c,
		"demoBgm": 0x803ff08c,
		"MSMainProc::MSStageInfo::stageBgm": 0x803ff090,
		"stageBgm": 0x803ff090,
		"MSMainProc::MSStageInfo::stageBgmSilent": 0x803ff094,
		"stageBgmSilent": 0x803ff094,
		"MSMainProc::MSStageInfo::switchBgm": 0x803ff0a0,
		"switchBgm": 0x803ff0a0,
		"MSMainProc::MSStageInfo::switchBgm2": 0x803ff0a4,
		"switchBgm2": 0x803ff0a4,
		"MSMainProc::MSStageInfo::cubeFadeRatio": 0x803ff0a8,
		"cubeFadeRatio": 0x803ff0a8,
		"MSStage::smMSStage": 0x803ff0b4,
		"smMSStage": 0x803ff0b4,
		"System::gpTargetArrow": 0x803ff0c0,
		"gpTargetArrow": 0x803ff0c0,
		"Strategic::gpObjHitCheck": 0x803fef10,
		"gpObjHitCheck": 0x803fef10,
		"Strategic::gpStrategy": 0x803fef20,
		"gpStrategy": 0x803fef20,
		"Strategic::gpQuestionManager": 0x803fef28,
		"gpQuestionManager": 0x803fef28,
		"Player::gpMarioForCallBack": 0x803fef80,
		"gpMarioForCallBack": 0x803fef80,
		"Player::gpMarioOriginal": 0x803fef88,
		"gpMarioOriginal": 0x803fef88,
		"Player::bubbleCallBack": 0x803fef94,
		"bubbleCallBack": 0x803fef94,
		"Player::warpInCallBack": 0x803fef9c,
		"warpInCallBack": 0x803fef9c,
		"Player::gpSplashManager": 0x803fefa0,
		"gpSplashManager": 0x803fefa0,
		"Player::gpMarioAddress": 0x803fefa8,
		"gpMarioAddress": 0x803fefa8,
		"Player::gpMarioPos": 0x803fefac,
		"gpMarioPos": 0x803fefac,
		"Player::gpMarioAngleX": 0x803fefb0,
		"gpMarioAngleX": 0x803fefb0,
		"Player::gpMarioAngleY": 0x803fefb4,
		"gpMarioAngleY": 0x803fefb4,
		"Player::gpMarioAngleZ": 0x803fefb8,
		"gpMarioAngleZ": 0x803fefb8,
		"Player::gpMarioSpeedX": 0x803fefbc,
		"gpMarioSpeedX": 0x803fefbc,
		"Player::gpMarioSpeedY": 0x803fefc0,
		"gpMarioSpeedY": 0x803fefc0,
		"Player::gpMarioSpeedZ": 0x803fefc4,
		"gpMarioSpeedZ": 0x803fefc4,
		"Player::gpMarioLightID": 0x803fefc8,
		"gpMarioLightID": 0x803fefc8,
		"Player::gpMarioFlag": 0x803fefcc,
		"gpMarioFlag": 0x803fefcc,
		"Player::gpMarioThrowPower": 0x803fefd0,
		"gpMarioThrowPower": 0x803fefd0,
		"Player::gpMarioGroundPlane": 0x803fefd4,
		"gpMarioGroundPlane": 0x803fefd4,
		"Player::gpModelWaterManager": 0x803fefd8,
		"gpModelWaterManager": 0x803fefd8,
		"Player::sphere_glist_p": 0x803fefe0,
		"sphere_glist_p": 0x803fefe0,
		"Player::sphere_pos_t": 0x803fefe4,
		"sphere_pos_t": 0x803fefe4,
		"TBaseNPC::mPtrSaveNormal": 0x803fee40,
		"mPtrSaveNormal": 0x803fee40,
		"NPC::gpCurrentNpc": 0x803fee48,
		"gpCurrentNpc": 0x803fee48,
		"TMonteMBaseManager::mStaticCommonKeeper": 0x803fee50,
		"TMonteWBaseManager::mStaticCommonKeeper": 0x803fee54,
		"TMareMBaseManager::mStaticCommonKeeper": 0x803fee58,
		"TMareWBaseManager::mStaticCommonKeeper": 0x803fee5c,
		"TMareBaseManager::mStaticBmtNormal": 0x803fee60,
		"mStaticBmtNormal": 0x803fee60,
		"TMareBaseManager::mStaticBmtPollution": 0x803fee64,
		"mStaticBmtPollution": 0x803fee64,
		"NPC::gpMareJellyFishManager": 0x803fee68,
		"gpMareJellyFishManager": 0x803fee68,
		"NPC::instance$2212": 0x803fee74,
		"instance$2212": 0x803fee74,
		"NPC::instance$2243": 0x803fee7c,
		"instance$2243": 0x803fee7c,
		"NPC::instance$2251": 0x803fee84,
		"instance$2251": 0x803fee84,
		"NPC::instance$2264": 0x803fee8c,
		"NPC::instance$2275": 0x803fee94,
		"instance$2275": 0x803fee94,
		"NPC::instance$2303": 0x803fee9c,
		"instance$2303": 0x803fee9c,
		"NPC::instance$2349": 0x803feea4,
		"instance$2349": 0x803feea4,
		"NPC::instance$2359": 0x803feeac,
		"NPC::instance$2365": 0x803feeb4,
		"instance$2365": 0x803feeb4,
		"NPC::instance$2373": 0x803feebc,
		"instance$2373": 0x803feebc,
		"NPC::instance$2384": 0x803feec4,
		"instance$2384": 0x803feec4,
		"NPC::instance$2390": 0x803feecc,
		"instance$2390": 0x803feecc,
		"NPC::instance$2404": 0x803feed4,
		"instance$2404": 0x803feed4,
		"NPC::instance$2414": 0x803feedc,
		"instance$2414": 0x803feedc,
		"NPC::instance$2424": 0x803feee4,
		"instance$2424": 0x803feee4,
		"NPC::instance$2436": 0x803feeec,
		"instance$2436": 0x803feeec,
		"TNpcEvent::mDownSunflowerNum": 0x803feef0,
		"mDownSunflowerNum": 0x803feef0,
		"TBaseNPC::sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x803fef00,
		"sCheckPollutedStartCounter$localstatic0$initSinkNpc_": 0x803fef00,
		"TNpcTrample::msAmpDecrease": 0x803fef08,
		"msAmpDecrease": 0x803fef08,
		"MSound::MSGMSound": 0x803fdffc,
		"MSGMSound": 0x803fdffc,
		"MSound::MSGBasic": 0x803fe000,
		"MSGBasic": 0x803fe000,
		"MSoundSESystem::MSoundSE::mObj": 0x803fe008,
		"mObj": 0x803fe008,
		"MSoundSESystem::SeInfo::smSeSetting": 0x803fe00c,
		"smSeSetting": 0x803fe00c,
		"MoveBG::gpMapObjManager": 0x803feda8,
		"gpMapObjManager": 0x803feda8,
		"MoveBG::gpItemManager": 0x803fedb0,
		"gpItemManager": 0x803fedb0,
		"MoveBG::gpMapObjSwitch": 0x803fedb8,
		"gpMapObjSwitch": 0x803fedb8,
		"MoveBG::sAngleAdd": 0x803fedc0,
		"sAngleAdd": 0x803fedc0,
		"MoveBG::gpCurObject": 0x803fedc8,
		"gpCurObject": 0x803fedc8,
		"TRiccoWatermill::mSubmarineSurfaceTransY": 0x803fedd0,
		"mSubmarineSurfaceTransY": 0x803fedd0,
		"MoveBG::switchSnd": 0x803fedd8,
		"switchSnd": 0x803fedd8,
		"MoveBG::gpMapObjFlagManager": 0x803fede0,
		"gpMapObjFlagManager": 0x803fede0,
		"MoveBG::sColor": 0x803fedf0,
		"sColor": 0x803fedf0,
		"MoveBG::gpMapObjWave": 0x803fedf4,
		"gpMapObjWave": 0x803fedf4,
		"MoveBG::timer$2477": 0x803fedf8,
		"timer$2477": 0x803fedf8,
		"TMapObjGrassManager::mColorUpper": 0x803fee08,
		"TMapObjGrassManager::mColorLower": 0x803fee0c,
		"TMapObjGrassManager::mColorFar": 0x803fee10,
		"mColorFar": 0x803fee10,
		"TMapObjGrassManager::mDrawVecS16": 0x803fee14,
		"mDrawVecS16": 0x803fee14,
		"MoveBG::gpMapObjGrassManager": 0x803fee1c,
		"gpMapObjGrassManager": 0x803fee1c,
		"MoveBG::gpMapObjPoleManager": 0x803fee20,
		"gpMapObjPoleManager": 0x803fee20,
		"THangingBridge::mRopeHeight": 0x803fee28,
		"mRopeHeight": 0x803fee28,
		"MoveBG::gpPoolManager": 0x803fee30,
		"gpPoolManager": 0x803fee30,
		"Map::gpMap": 0x803fed38,
		"gpMap": 0x803fed38,
		"Map::gpMapCollisionData": 0x803fed40,
		"gpMapCollisionData": 0x803fed40,
		"Map::gpMirrorModelManager": 0x803fed48,
		"gpMirrorModelManager": 0x803fed48,
		"TMapStaticObj::mEffectCoronaScale": 0x803fed50,
		"mEffectCoronaScale": 0x803fed50,
		"Map::gpMapWireManager": 0x803fed58,
		"gpMapWireManager": 0x803fed58,
		"TMapWireManager::mUpperSurface": 0x803fed5c,
		"mUpperSurface": 0x803fed5c,
		"TMapWireManager::mLowerSurface": 0x803fed60,
		"mLowerSurface": 0x803fed60,
		"Map::counter$2576": 0x803fed68,
		"counter$2576": 0x803fed68,
		"Map::gpPollution": 0x803fed70,
		"gpPollution": 0x803fed70,
		"Map::effect_counter$2421": 0x803fed78,
		"effect_counter$2421": 0x803fed78,
		"Map::now_pos_no$2429": 0x803fed80,
		"now_pos_no$2429": 0x803fed80,
		"Map::counter_x$2434": 0x803fed88,
		"counter_x$2434": 0x803fed88,
		"Map::counter_z$2437": 0x803fed90,
		"counter_z$2437": 0x803fed90,
		"Map::effect_timer$2449": 0x803fed98,
		"effect_timer$2449": 0x803fed98,
		"Map::delta$2349": 0x803feda0,
		"delta$2349": 0x803feda0,
		"TGCConsole2::cDownTopPoint": 0x803febe8,
		"cDownTopPoint": 0x803febe8,
		"TGCConsole2::cDownMidPoint": 0x803febf0,
		"cDownMidPoint": 0x803febf0,
		"TGCConsole2::cDownBotPoint": 0x803febf8,
		"cDownBotPoint": 0x803febf8,
		"TGCConsole2::cUpTopPoint": 0x803fec00,
		"cUpTopPoint": 0x803fec00,
		"TGCConsole2::cUpMidPoint": 0x803fec08,
		"cUpMidPoint": 0x803fec08,
		"TGCConsole2::cUpBotPoint": 0x803fec10,
		"cUpBotPoint": 0x803fec10,
		"TGCConsole2::cCoinTopPoint": 0x803fec18,
		"cCoinTopPoint": 0x803fec18,
		"TGCConsole2::cCoinMidPoint": 0x803fec20,
		"cCoinMidPoint": 0x803fec20,
		"TGCConsole2::cCoinBotPoint": 0x803fec28,
		"cCoinBotPoint": 0x803fec28,
		"GC2D::gpTalk2D": 0x803fec30,
		"gpTalk2D": 0x803fec30,
		"GC2D::gpCardLoad": 0x803fec38,
		"gpCardLoad": 0x803fec38,
		"TConsoleStr::cShineGetRight1": 0x803fec40,
		"cShineGetRight1": 0x803fec40,
		"TConsoleStr::cShineGetLeft1": 0x803fec48,
		"cShineGetLeft1": 0x803fec48,
		"TConsoleStr::cShineGetRight2": 0x803fec50,
		"cShineGetRight2": 0x803fec50,
		"TConsoleStr::cShineGetLeft2": 0x803fec58,
		"cShineGetLeft2": 0x803fec58,
		"TConsoleStr::cShineGetRight3": 0x803fec60,
		"cShineGetRight3": 0x803fec60,
		"TConsoleStr::cShineGetLeft3": 0x803fec68,
		"cShineGetLeft3": 0x803fec68,
		"GC2D::vtable": 0x803fec7c,
		"vtable": 0x803fec7c,
		"GC2D::hxs_logo_resetflag": 0x803fece0,
		"hxs_logo_resetflag": 0x803fece0,
		"GC2D::hxs_logodraw_resetflag": 0x803fece4,
		"hxs_logodraw_resetflag": 0x803fece4,
		"Enemy::gpConductor": 0x803fe048,
		"gpConductor": 0x803fe048,
		"Enemy::gpEffectObjManager": 0x803fe050,
		"gpEffectObjManager": 0x803fe050,
		"Enemy::gpCurGesso": 0x803fe058,
		"gpCurGesso": 0x803fe058,
		"Enemy::gpCurNameKuri": 0x803fe150,
		"gpCurNameKuri": 0x803fe150,
		"Enemy::gpCurPakkun": 0x803fe190,
		"gpCurPakkun": 0x803fe190,
		"Enemy::gpCurPakkunSeed": 0x803fe194,
		"gpCurPakkunSeed": 0x803fe194,
		"Enemy::instance$2166": 0x803fe20c,
		"instance$2166": 0x803fe20c,
		"Enemy::instance$3999": 0x803fe420,
		"instance$3999": 0x803fe420,
		"Enemy::gpCurTobiPuku": 0x803fe438,
		"gpCurTobiPuku": 0x803fe438,
		"Enemy::gpCurChuuHana": 0x803fe510,
		"gpCurChuuHana": 0x803fe510,
		"Enemy::instance$3238": 0x803fe558,
		"instance$3238": 0x803fe558,
		"Enemy::gpCurRollEnemy": 0x803fe570,
		"gpCurRollEnemy": 0x803fe570,
		"TRollEnemy::mTransYOffset": 0x803fe574,
		"mTransYOffset": 0x803fe574,
		"Enemy::testHeight": 0x803fe730,
		"testHeight": 0x803fe730,
		"Enemy::gpCurKiller": 0x803fe770,
		"gpCurKiller": 0x803fe770,
		"Enemy::gpBeamManager": 0x803fe790,
		"gpBeamManager": 0x803fe790,
		"Enemy::gpCurSamboHead": 0x803fe79c,
		"gpCurSamboHead": 0x803fe79c,
		"Enemy::gpCurPopo": 0x803fe800,
		"gpCurPopo": 0x803fe800,
		"TPopo::mTestAng_z": 0x803fe804,
		"Enemy::instance$2264": 0x803fe83c,
		"Enemy::instance$2270": 0x803fe844,
		"instance$2270": 0x803fe844,
		"Enemy::sCommonSaveFileName$2709": 0x803fe858,
		"sCommonSaveFileName$2709": 0x803fe858,
		"Enemy::instance$2359": 0x803fe864,
		"Enemy::instance$2371": 0x803fe86c,
		"instance$2371": 0x803fe86c,
		"Enemy::instance$2383": 0x803fe874,
		"instance$2383": 0x803fe874,
		"Enemy::instance$2391": 0x803fe87c,
		"instance$2391": 0x803fe87c,
		"Enemy::instance$2399": 0x803fe884,
		"instance$2399": 0x803fe884,
		"Enemy::instance$2408": 0x803fe88c,
		"instance$2408": 0x803fe88c,
		"Enemy::instance$2423": 0x803fe894,
		"instance$2423": 0x803fe894,
		"Enemy::instance$2838": 0x803fe90c,
		"instance$2838": 0x803fe90c,
		"Enemy::instance$2856": 0x803fe914,
		"instance$2856": 0x803fe914,
		"Enemy::gpCurHauntLeg": 0x803fe920,
		"gpCurHauntLeg": 0x803fe920,
		"TRocket::mTestAng_x": 0x803fe968,
		"TRocket::mTestAng_z": 0x803fe96c,
		"Enemy::instance$2918": 0x803fe9cc,
		"instance$2918": 0x803fe9cc,
		"Enemy::instance$2924": 0x803fe9d4,
		"instance$2924": 0x803fe9d4,
		"Enemy::instance$2930": 0x803fe9dc,
		"instance$2930": 0x803fe9dc,
		"Enemy::instance$2936": 0x803fe9e4,
		"instance$2936": 0x803fe9e4,
		"Enemy::instance$2942": 0x803fe9ec,
		"instance$2942": 0x803fe9ec,
		"TBossManta::sCenterJointIndex": 0x803fe9f0,
		"sCenterJointIndex": 0x803fe9f0,
		"TBossManta::sBodyJointIndex": 0x803fe9f4,
		"sBodyJointIndex": 0x803fe9f4,
		"TBossManta::sRwingJointIndex": 0x803fe9f8,
		"sRwingJointIndex": 0x803fe9f8,
		"TBossManta::sLwingJointIndex": 0x803fe9fc,
		"sLwingJointIndex": 0x803fe9fc,
		"Enemy::sDefeatSE$3156": 0x803fea04,
		"sDefeatSE$3156": 0x803fea04,
		"TNerveKoopaTurnR::nerve$localstatic0$theNerve": 0x803feabc,
		"TNerveKoopaTurnL::nerve$localstatic0$theNerve": 0x803feac4,
		"TNerveKoopaTumble::nerve$localstatic0$theNerve": 0x803feacc,
		"TNerveKoopaProvoke::nerve$localstatic0$theNerve": 0x803fead4,
		"TNerveKoopaWait::nerve$localstatic0$theNerve": 0x803feadc,
		"TNerveKoopaFlame::nerve$localstatic0$theNerve": 0x803feae4,
		"TNerveKoopaGetDown::nerve$localstatic0$theNerve": 0x803feaec,
		"TNerveKoopaStagger::nerve$localstatic0$theNerve": 0x803feaf4,
		"TNerveKoopaFall::nerve$localstatic0$theNerve": 0x803feafc,
		"TNerveKoopaGetShowered::nerve$localstatic0$theNerve": 0x803feb04,
		"TNervePeachStagger::nerve$localstatic0$theNerve": 0x803feb54,
		"TNervePeachEscape::nerve$localstatic0$theNerve": 0x803feb5c,
		"@unnamed@::cAngleMax": 0x803feba8,
		"cAngleMax": 0x803feba8,
		"Camera::gpCamera": 0x803ffa38,
		"gpCamera": 0x803ffa38,
		"Camera::gpCameraMario": 0x803ffa40,
		"gpCameraMario": 0x803ffa40,
		"Camera::gpCameraShake": 0x803ffa48,
		"gpCameraShake": 0x803ffa48,
		"Camera::gpSunMgr": 0x803ffa50,
		"gpSunMgr": 0x803ffa50,
		"Camera::gpSunModel": 0x803ffa58,
		"gpSunModel": 0x803ffa58,
		"Camera::gpCubeCamera": 0x803ffa60,
		"gpCubeCamera": 0x803ffa60,
		"Camera::gpCubeMirror": 0x803ffa64,
		"gpCubeMirror": 0x803ffa64,
		"Camera::gpCubeWire": 0x803ffa68,
		"gpCubeWire": 0x803ffa68,
		"Camera::gpCubeStream": 0x803ffa6c,
		"gpCubeStream": 0x803ffa6c,
		"Camera::gpCubeShadow": 0x803ffa70,
		"gpCubeShadow": 0x803ffa70,
		"Camera::gpCubeArea": 0x803ffa74,
		"gpCubeArea": 0x803ffa74,
		"Camera::gpCubeFastA": 0x803ffa78,
		"gpCubeFastA": 0x803ffa78,
		"Camera::gpCubeFastB": 0x803ffa7c,
		"gpCubeFastB": 0x803ffa7c,
		"Camera::gpCubeFastC": 0x803ffa80,
		"gpCubeFastC": 0x803ffa80,
		"Camera::gpCubeSoundChange": 0x803ffa84,
		"gpCubeSoundChange": 0x803ffa84,
		"Camera::gpCubeSoundEffect": 0x803ffa88,
		"gpCubeSoundEffect": 0x803ffa88,
		"Camera::gpCamMapToolTable": 0x803ffa90,
		"gpCamMapToolTable": 0x803ffa90,
		"Camera::gpCameraOption": 0x803ffa98,
		"gpCameraOption": 0x803ffa98,
		"Animal::instance$2000": 0x803fdf74,
		"instance$2000": 0x803fdf74,
		"Animal::instance$3025": 0x803fdf7c,
		"Animal::instance$3040": 0x803fdf84,
		"instance$3040": 0x803fdf84,
		"Animal::instance$3055": 0x803fdf8c,
		"Animal::instance$3067": 0x803fdf94,
		"instance$3067": 0x803fdf94,
		"Animal::instance$3077": 0x803fdf9c,
		"instance$3077": 0x803fdf9c,
		"Animal::instance$3096": 0x803fdfa4,
		"instance$3096": 0x803fdfa4,
		"Animal::instance$3104": 0x803fdfac,
		"instance$3104": 0x803fdfac,
		"Animal::instance$3116": 0x803fdfb4,
		"instance$3116": 0x803fdfb4,
		"Animal::instance$3128": 0x803fdfbc,
		"@unnamed@::cAngleLimit": 0x803fdfc0,
		"cAngleLimit": 0x803fdfc0,
		"Animal::instance$2989": 0x803fdfc8,
		"instance$2989": 0x803fdfc8,
		"Animal::instance$3003": 0x803fdfd0,
		"instance$3003": 0x803fdfd0,
		"Animal::instance$3013": 0x803fdfd8,
		"Animal::instance$3023": 0x803fdfe0,
		"instance$3023": 0x803fdfe0,
		"Animal::instance$3035": 0x803fdfe8,
		"Animal::instance$3047": 0x803fdff0,
		"instance$3047": 0x803fdff0,
		"Animal::@2344": 0x803ffb08,
		"Animal::@2367": 0x803ffb10,
		"Animal::@2459": 0x803ffb24,
		"Animal::@2460": 0x803ffb28,
		"Animal::@2461": 0x803ffb2c,
		"Animal::@2462": 0x803ffb30,
		"Animal::@2632": 0x803ffb34,
		"Animal::@2633": 0x803ffb38,
		"Animal::@2694": 0x803ffb3c,
		"Animal::@2185": 0x803ffbe0,
		"Animal::@2186": 0x803ffbe4,
		"Animal::@2198": 0x803ffbe8,
		"Animal::@2204": 0x803ffbec,
		"MSound::@1986": 0x803ffd74,
		"MSound::@1987": 0x803ffd78,
		"MSound::@2470": 0x803ffd98,
		"MSound::@2528": 0x803ffd9c,
		"MSound::@2602": 0x803ffda0,
		"MSound::@2603": 0x803ffda4,
		"MSound::@2622": 0x803ffdb0,
		"MSound::@2623": 0x803ffdb4,
		"MSound::@2984": 0x803ffdd8,
		"MSound::@2985": 0x803ffddc,
		"MSound::@2986": 0x803ffde0,
		"MSound::@3109": 0x803ffde4,
		"MSound::@3450": 0x803ffde8,
		"MSound::@3451": 0x803ffdec,
		"MSound::@3456": 0x803ffdf0,
		"MSound::@2940": 0x803fff84,
		"MSound::@2941": 0x803fff88,
		"MSound::@2942": 0x803fff8c,
		"MSound::@2943": 0x803fff90,
		"MSound::@3170": 0x803fffa0,
		"GC2D::@3503": 0x804027c0,
		"GC2D::@3531": 0x804027c4,
		"GC2D::@6892": 0x804027e0,
		"@6892": 0x804027e0,
		"GC2D::@6893": 0x804027e4,
		"@6893": 0x804027e4,
		"GC2D::@6894": 0x804027e8,
		"@6894": 0x804027e8,
		"GC2D::@6895": 0x804027ec,
		"@6895": 0x804027ec,
		"GC2D::@6896": 0x804027f0,
		"GC2D::@6897": 0x804027f4,
		"GC2D::@6898": 0x804027f8,
		"@6898": 0x804027f8,
		"GC2D::@6899": 0x804027fc,
		"GC2D::@6900": 0x80402800,
		"GC2D::@6901": 0x80402804,
		"GC2D::@6902": 0x80402808,
		"GC2D::@6903": 0x8040280c,
		"GC2D::@6906": 0x80402810,
		"@6906": 0x80402810,
		"GC2D::@7057": 0x80402828,
		"@7057": 0x80402828,
		"GC2D::@7139": 0x8040282c,
		"GC2D::@7140": 0x80402830,
		"@7140": 0x80402830,
		"GC2D::@9048": 0x80402840,
		"GC2D::@9049": 0x80402844,
		"@9049": 0x80402844,
		"GC2D::@9534": 0x80402848,
		"@9534": 0x80402848,
		"GC2D::@9857": 0x8040284c,
		"@9857": 0x8040284c,
		"GC2D::@11722": 0x80402850,
		"@11722": 0x80402850,
		"GC2D::@11723": 0x80402854,
		"@11723": 0x80402854,
		"GC2D::@11724": 0x80402858,
		"@11724": 0x80402858,
		"GC2D::@11941": 0x8040285c,
		"@11941": 0x8040285c,
		"GC2D::@12009": 0x80402864,
		"@12009": 0x80402864,
		"GC2D::@3282": 0x80402874,
		"GC2D::@3348": 0x80402878,
		"GC2D::@3349": 0x8040287c,
		"GC2D::@3533": 0x80402888,
		"GC2D::@3535": 0x80402898,
		"GC2D::@3536": 0x8040289c,
		"GC2D::@3537": 0x804028a0,
		"GC2D::@3690": 0x804028a8,
		"GC2D::@3691": 0x804028ac,
		"GC2D::@3852": 0x804028b0,
		"GC2D::@4330": 0x804028b4,
		"GC2D::@4503": 0x804028b8,
		"GC2D::@4504": 0x804028bc,
		"GC2D::@4505": 0x804028c0,
		"GC2D::@4506": 0x804028c4,
		"GC2D::@4507": 0x804028c8,
		"GC2D::@4508": 0x804028cc,
		"@4508": 0x804028cc,
		"GC2D::@4892": 0x804028d8,
		"GC2D::@4893": 0x804028dc,
		"GC2D::@4924": 0x804028e0,
		"GC2D::@4958": 0x804028e8,
		"GC2D::@4207": 0x804029f0,
		"GC2D::@4208": 0x804029f4,
		"GC2D::@4209": 0x804029f8,
		"GC2D::@4249": 0x80402a10,
		"GC2D::@5935": 0x80402a14,
		"@5935": 0x80402a14,
		"GC2D::@5936": 0x80402a18,
		"GC2D::@5937": 0x80402a1c,
		"GC2D::@5938": 0x80402a20,
		"GC2D::@5939": 0x80402a24,
		"GC2D::@5940": 0x80402a28,
		"GC2D::@6985": 0x80402a2c,
		"@6985": 0x80402a2c,
		"GC2D::@6987": 0x80402a34,
		"@6987": 0x80402a34,
		"GC2D::@4590": 0x80402a9c,
		"GC2D::@4591": 0x80402aa0,
		"GC2D::@4592": 0x80402aa4,
		"GC2D::@5192": 0x80402ab0,
		"GC2D::@5193": 0x80402ab4,
		"GC2D::@5194": 0x80402ab8,
		"GC2D::@5195": 0x80402abc,
		"GC2D::@5196": 0x80402ac0,
		"GC2D::@5197": 0x80402ac4,
		"GC2D::@5525": 0x80402ac8,
		"@5525": 0x80402ac8,
		"GC2D::@7283": 0x80402ad8,
		"@7283": 0x80402ad8,
		"GC2D::@7284": 0x80402adc,
		"@7284": 0x80402adc,
		"GC2D::@7285": 0x80402ae0,
		"@7285": 0x80402ae0,
		"GC2D::@7286": 0x80402ae4,
		"@7286": 0x80402ae4,
		"GC2D::@7287": 0x80402ae8,
		"@7287": 0x80402ae8,
		"GC2D::@7288": 0x80402aec,
		"GC2D::@7722": 0x80402af0,
		"@7722": 0x80402af0,
		"GC2D::@7723": 0x80402af4,
		"@7723": 0x80402af4,
		"GC2D::@7724": 0x80402af8,
		"@7724": 0x80402af8,
		"GC2D::@7725": 0x80402afc,
		"@7725": 0x80402afc,
		"GC2D::@7726": 0x80402b00,
		"@7726": 0x80402b00,
		"GC2D::@7727": 0x80402b04,
		"@7727": 0x80402b04,
		"GC2D::@8331": 0x80402b08,
		"GC2D::@8337": 0x80402b10,
		"GC2D::@8377": 0x80402b14,
		"@8377": 0x80402b14,
		"GC2D::@2237": 0x80402b54,
		"GC2D::@2238": 0x80402b58,
		"@2238": 0x80402b58,
		"GC2D::@2548": 0x80402b70,
		"GC2D::@2890": 0x80402b74,
		"GC2D::@2891": 0x80402b78,
		"GC2D::@2892": 0x80402b7c,
		"GC2D::@3468": 0x80402b98,
		"GC2D::@3473": 0x80402ba0,
		"GC2D::@3474": 0x80402ba4,
		"GC2D::@3476": 0x80402ba8,
		"GC2D::@2455": 0x80402f60,
		"GC2D::@2456": 0x80402f64,
		"GC2D::@2457": 0x80402f68,
		"GC2D::@2458": 0x80402f6c,
		"GC2D::@2691": 0x80402f70,
		"GC2D::@2692": 0x80402f74,
		"GC2D::@2693": 0x80402f78,
		"GC2D::@2871": 0x80402f88,
		"GC2D::@2872": 0x80402f8c,
		"GC2D::@2873": 0x80402f90,
		"GC2D::@3516": 0x80402f9c,
		"GC2D::@3673": 0x80402fa0,
		"GC2D::@4021": 0x80402fa4,
		"MoveBG::@3465": 0x80404bc0,
		"MoveBG::@3650": 0x80404be8,
		"MoveBG::@3869": 0x80404c18,
		"MoveBG::@4236": 0x80404c48,
		"MoveBG::@4237": 0x80404c4c,
		"MoveBG::@4238": 0x80404c50,
		"MoveBG::@4269": 0x80404c54,
		"MoveBG::@4452": 0x80404c58,
		"MoveBG::@4497": 0x80404c70,
		"@4497": 0x80404c70,
		"MoveBG::@4752": 0x80404c80,
		"MoveBG::@4753": 0x80404c84,
		"MoveBG::@4754": 0x80404c88,
		"MoveBG::@4774": 0x80404c90,
		"MoveBG::@4833": 0x80404c94,
		"MoveBG::@4834": 0x80404c98,
		"MoveBG::@4835": 0x80404c9c,
		"MoveBG::@4941": 0x80404ca0,
		"MoveBG::@4966": 0x80404ca4,
		"MoveBG::@4967": 0x80404ca8,
		"MoveBG::@5157": 0x80404cbc,
		"MoveBG::@5158": 0x80404cc0,
		"MoveBG::@5229": 0x80404ccc,
		"MoveBG::@5338": 0x80404cd0,
		"System::@2169": 0x80406df0,
		"System::@2170": 0x80406df4,
		"System::@2266": 0x80406e08,
		"System::@2267": 0x80406e0c,
		"System::@2571": 0x80406e1c,
		"Camera::@3713": 0x804080b8,
		"Camera::@3714": 0x804080bc,
		"Camera::@2641": 0x804080c8,
		"Camera::@2642": 0x804080cc,
		"Camera::@2661": 0x804080d0,
		"Camera::@2662": 0x804080d4,
		"Camera::@2663": 0x804080d8,
		"Camera::@2750": 0x804080f0,
		"Camera::@2751": 0x804080f4,
		"Camera::@2752": 0x804080f8,
		"Camera::@3265": 0x80408108,
		"Camera::@3266": 0x8040810c,
		"Camera::@3267": 0x80408110,
		"Camera::@3268": 0x80408114,
		"Camera::@3269": 0x80408118,
		"Camera::@3270": 0x8040811c,
		"Camera::@3369": 0x80408128,
		"Camera::@3726": 0x8040812c,
		"Camera::@3727": 0x80408134,
		"Camera::@3825": 0x80408138,
		"Camera::@2182": 0x804081c8,
		"Camera::@2071": 0x804081e0,
		"Camera::@2072": 0x804081e4,
		"Camera::@2073": 0x804081e8,
		"Camera::@2200": 0x804081f8,
		"Camera::@2201": 0x804081fc,
		"Camera::@2319": 0x80408200,
		"Camera::@2320": 0x80408204,
		"Camera::@2321": 0x80408208,
		"Camera::@2322": 0x8040820c,
		"Camera::@2323": 0x80408210,
		"Camera::@2324": 0x80408214,
		"Camera::@2352": 0x80408468,
		"Camera::@2353": 0x8040846c,
		"Camera::@2354": 0x80408470,
		"Camera::@2355": 0x80408474,
		"Camera::@2702": 0x80408478,
		"Camera::@2703": 0x8040847c,
		"Camera::@2704": 0x80408480,
		"Camera::@2705": 0x80408484,
		"Camera::@2706": 0x80408488,
		"Camera::@2707": 0x8040848c,
		"Camera::@2708": 0x80408490,
		"Camera::@1830": 0x80408500,
		"@1830": 0x80408500,
		"Camera::@1831": 0x80408504,
		"Camera::@1832": 0x80408508,
		"Enemy::@2778": 0x80400200,
		"Enemy::@2779": 0x80400208,
		"Enemy::@2780": 0x80400210,
		"Enemy::@2785": 0x80400218,
		"Enemy::@2786": 0x80400220,
		"Enemy::@3203": 0x804004d4,
		"Enemy::@4103": 0x804004f8,
		"Enemy::@4104": 0x804004fc,
		"Enemy::@4106": 0x80400504,
		"Enemy::@4406": 0x80400550,
		"Enemy::@5108": 0x80400570,
		"Enemy::@5109": 0x80400574,
		"Enemy::@5192": 0x80400578,
		"Enemy::@5504": 0x80400580,
		"@5504": 0x80400580,
		"Enemy::@5908": 0x8040059c,
		"Enemy::@6426": 0x804005a8,
		"@6426": 0x804005a8,
		"Enemy::@3680": 0x80400608,
		"Enemy::@3681": 0x8040060c,
		"Enemy::@4082": 0x80400644,
		"Enemy::@4548": 0x80400668,
		"Enemy::@4549": 0x8040066c,
		"Enemy::@4808": 0x80400674,
		"@4808": 0x80400674,
		"Enemy::@5215": 0x8040067c,
		"Enemy::@5343": 0x8040068c,
		"Enemy::@4792": 0x80400754,
		"Enemy::@6518": 0x80400784,
		"Enemy::@6519": 0x80400788,
		"Enemy::@6520": 0x8040078c,
		"Enemy::@7348": 0x80400794,
		"@7348": 0x80400794,
		"Enemy::@3646": 0x80400820,
		"Enemy::@3648": 0x80400824,
		"Enemy::@4257": 0x80400850,
		"Enemy::@3443": 0x80400860,
		"Enemy::@3444": 0x80400864,
		"Enemy::@4054": 0x80400888,
		"Enemy::@4221": 0x804008ac,
		"Enemy::@4444": 0x804008c0,
		"@4444": 0x804008c0,
		"Enemy::@4499": 0x804008d0,
		"Enemy::@4033": 0x80400960,
		"Enemy::@4035": 0x80400968,
		"Enemy::@4558": 0x8040097c,
		"Enemy::idxarray$3431": 0x80400a50,
		"idxarray$3431": 0x80400a50,
		"Enemy::idxarray$3453": 0x80400a58,
		"idxarray$3453": 0x80400a58,
		"Enemy::idxarray$3500": 0x80400a60,
		"idxarray$3500": 0x80400a60,
		"Enemy::idxarray$3520": 0x80400a68,
		"idxarray$3520": 0x80400a68,
		"Enemy::@4704": 0x80400a90,
		"Enemy::@4706": 0x80400a94,
		"Enemy::@4707": 0x80400a98,
		"Enemy::@4708": 0x80400a9c,
		"Enemy::@6056": 0x80400ad4,
		"@6056": 0x80400ad4,
		"Enemy::@6299": 0x80400ad8,
		"@6299": 0x80400ad8,
		"Enemy::@6321": 0x80400adc,
		"@6321": 0x80400adc,
		"Enemy::@6322": 0x80400ae0,
		"@6322": 0x80400ae0,
		"Enemy::@6323": 0x80400ae4,
		"@6323": 0x80400ae4,
		"Enemy::@6589": 0x80400ae8,
		"Enemy::@7131": 0x80400aec,
		"@7131": 0x80400aec,
		"Enemy::@7132": 0x80400af0,
		"@7132": 0x80400af0,
		"Enemy::@7133": 0x80400af4,
		"@7133": 0x80400af4,
		"Enemy::@7192": 0x80400af8,
		"@7192": 0x80400af8,
		"Enemy::@7193": 0x80400afc,
		"@7193": 0x80400afc,
		"Enemy::@7822": 0x80400b04,
		"@7822": 0x80400b04,
		"Enemy::@7863": 0x80400b08,
		"@7863": 0x80400b08,
		"Enemy::@7864": 0x80400b0c,
		"@7864": 0x80400b0c,
		"Enemy::@7865": 0x80400b10,
		"@7865": 0x80400b10,
		"Enemy::@8145": 0x80400b14,
		"@8145": 0x80400b14,
		"Enemy::@8146": 0x80400b18,
		"@8146": 0x80400b18,
		"Enemy::@8147": 0x80400b20,
		"@8147": 0x80400b20,
		"Enemy::@8149": 0x80400b24,
		"@8149": 0x80400b24,
		"Enemy::@8360": 0x80400b28,
		"Enemy::@8735": 0x80400b2c,
		"@8735": 0x80400b2c,
		"Enemy::@9038": 0x80400b30,
		"@9038": 0x80400b30,
		"Enemy::@9197": 0x80400b34,
		"@9197": 0x80400b34,
		"Enemy::@9200": 0x80400b38,
		"@9200": 0x80400b38,
		"Enemy::@9202": 0x80400b3c,
		"@9202": 0x80400b3c,
		"Enemy::@9205": 0x80400b40,
		"@9205": 0x80400b40,
		"Enemy::@9207": 0x80400b44,
		"@9207": 0x80400b44,
		"Enemy::@9210": 0x80400b48,
		"@9210": 0x80400b48,
		"Enemy::@9212": 0x80400b4c,
		"@9212": 0x80400b4c,
		"Enemy::@9218": 0x80400b50,
		"@9218": 0x80400b50,
		"Enemy::@9222": 0x80400b54,
		"@9222": 0x80400b54,
		"Enemy::@9227": 0x80400b58,
		"@9227": 0x80400b58,
		"Enemy::@4122": 0x80400b9c,
		"Enemy::@4123": 0x80400ba0,
		"Enemy::@4435": 0x80400bc4,
		"Enemy::@4741": 0x80400bcc,
		"Enemy::@5172": 0x80400bd8,
		"Enemy::@4390": 0x80400c30,
		"Enemy::@4391": 0x80400c34,
		"Enemy::@4537": 0x80400c40,
		"Enemy::@4538": 0x80400c44,
		"@4538": 0x80400c44,
		"Enemy::@5296": 0x80400c7c,
		"Enemy::@5076": 0x80400cf0,
		"Enemy::@5183": 0x80400cf4,
		"Enemy::@5386": 0x80400d08,
		"@5386": 0x80400d08,
		"Enemy::@5387": 0x80400d0c,
		"@5387": 0x80400d0c,
		"Enemy::@6628": 0x80400d2c,
		"@6628": 0x80400d2c,
		"Enemy::@6948": 0x80400d30,
		"@6948": 0x80400d30,
		"Enemy::@7610": 0x80400d48,
		"@7610": 0x80400d48,
		"Enemy::@7611": 0x80400d4c,
		"@7611": 0x80400d4c,
		"Enemy::@7688": 0x80400d50,
		"@7688": 0x80400d50,
		"Enemy::@7689": 0x80400d54,
		"@7689": 0x80400d54,
		"Enemy::@7893": 0x80400d5c,
		"@7893": 0x80400d5c,
		"Enemy::@7894": 0x80400d60,
		"@7894": 0x80400d60,
		"Enemy::@8404": 0x80400d64,
		"@8404": 0x80400d64,
		"Enemy::@8768": 0x80400d68,
		"Enemy::@9151": 0x80400d8c,
		"@9151": 0x80400d8c,
		"Enemy::@9482": 0x80400d90,
		"@9482": 0x80400d90,
		"Enemy::@9483": 0x80400d94,
		"@9483": 0x80400d94,
		"Enemy::@4339": 0x80400dcc,
		"Enemy::@5038": 0x80400dec,
		"Enemy::@5039": 0x80400df0,
		"Enemy::@5390": 0x80400df4,
		"@5390": 0x80400df4,
		"Enemy::@5392": 0x80400dfc,
		"@5392": 0x80400dfc,
		"Enemy::@5393": 0x80400e00,
		"@5393": 0x80400e00,
		"Enemy::@5394": 0x80400e04,
		"@5394": 0x80400e04,
		"Enemy::@5788": 0x80400e14,
		"@5788": 0x80400e14,
		"Enemy::@5789": 0x80400e18,
		"@5789": 0x80400e18,
		"Enemy::@5790": 0x80400e1c,
		"@5790": 0x80400e1c,
		"Enemy::@6199": 0x80400e24,
		"@6199": 0x80400e24,
		"Enemy::@6929": 0x80400e38,
		"@6929": 0x80400e38,
		"Enemy::@6930": 0x80400e3c,
		"@6930": 0x80400e3c,
		"Enemy::@6931": 0x80400e40,
		"@6931": 0x80400e40,
		"Enemy::@6932": 0x80400e44,
		"@6932": 0x80400e44,
		"Enemy::@6933": 0x80400e48,
		"@6933": 0x80400e48,
		"Enemy::@7230": 0x80400e60,
		"@7230": 0x80400e60,
		"Enemy::@7408": 0x80400e64,
		"@7408": 0x80400e64,
		"Enemy::@7471": 0x80400e74,
		"@7471": 0x80400e74,
		"Enemy::@7472": 0x80400e78,
		"@7472": 0x80400e78,
		"Enemy::@7473": 0x80400e7c,
		"Enemy::@7474": 0x80400e80,
		"@7474": 0x80400e80,
		"Enemy::@7475": 0x80400e84,
		"@7475": 0x80400e84,
		"Enemy::@7997": 0x80400e90,
		"@7997": 0x80400e90,
		"Enemy::@7998": 0x80400e94,
		"@7998": 0x80400e94,
		"Enemy::@8342": 0x80400eac,
		"@8342": 0x80400eac,
		"Enemy::@3407": 0x80400ed0,
		"Enemy::@4901": 0x80400f38,
		"Enemy::@4992": 0x80400f40,
		"Enemy::@4830": 0x80400fc4,
		"Enemy::@5660": 0x80400fe0,
		"Enemy::@5661": 0x80400fe4,
		"Enemy::@6085": 0x80400ff8,
		"@6085": 0x80400ff8,
		"Enemy::@6602": 0x804010f4,
		"@6602": 0x804010f4,
		"Enemy::@6603": 0x804010f8,
		"@6603": 0x804010f8,
		"Enemy::@6604": 0x804010fc,
		"@6604": 0x804010fc,
		"Enemy::@6605": 0x80401100,
		"@6605": 0x80401100,
		"Enemy::@6606": 0x80401104,
		"@6606": 0x80401104,
		"Enemy::@6843": 0x80401108,
		"Enemy::@6844": 0x8040110c,
		"Enemy::@6845": 0x80401110,
		"Enemy::@7168": 0x80401114,
		"@7168": 0x80401114,
		"Enemy::@7169": 0x80401118,
		"@7169": 0x80401118,
		"Enemy::@7302": 0x8040111c,
		"@7302": 0x8040111c,
		"Enemy::@7303": 0x80401120,
		"@7303": 0x80401120,
		"Enemy::@7304": 0x80401124,
		"@7304": 0x80401124,
		"Enemy::@7305": 0x8040112c,
		"@7305": 0x8040112c,
		"Enemy::@7385": 0x80401130,
		"@7385": 0x80401130,
		"Enemy::@7505": 0x80401134,
		"@7505": 0x80401134,
		"Enemy::@7506": 0x80401138,
		"@7506": 0x80401138,
		"Enemy::@7507": 0x8040113c,
		"@7507": 0x8040113c,
		"Enemy::@7508": 0x80401140,
		"@7508": 0x80401140,
		"Enemy::@7509": 0x80401144,
		"@7509": 0x80401144,
		"Enemy::@7510": 0x80401148,
		"@7510": 0x80401148,
		"Enemy::@7780": 0x8040115c,
		"@7780": 0x8040115c,
		"Enemy::@7781": 0x80401160,
		"@7781": 0x80401160,
		"Enemy::@7782": 0x80401164,
		"@7782": 0x80401164,
		"Enemy::@7783": 0x80401168,
		"@7783": 0x80401168,
		"Enemy::@7784": 0x8040116c,
		"@7784": 0x8040116c,
		"Enemy::@7785": 0x80401170,
		"@7785": 0x80401170,
		"Enemy::@7786": 0x80401174,
		"@7786": 0x80401174,
		"Enemy::@4404": 0x804011e0,
		"Enemy::@4752": 0x804011e8,
		"Enemy::@5579": 0x8040120c,
		"@5579": 0x8040120c,
		"Enemy::@5580": 0x80401210,
		"@5580": 0x80401210,
		"Enemy::@5619": 0x80401214,
		"@5619": 0x80401214,
		"Enemy::@3684": 0x80401238,
		"Enemy::@3685": 0x8040123c,
		"@3685": 0x8040123c,
		"Enemy::@4858": 0x8040129c,
		"Enemy::@5177": 0x804012b0,
		"Enemy::@5179": 0x804012b8,
		"Enemy::@5201": 0x804012c0,
		"Enemy::@5202": 0x804012c4,
		"Enemy::@3871": 0x8040132c,
		"Enemy::@4486": 0x80401348,
		"Enemy::@4353": 0x804013dc,
		"Enemy::@6148": 0x80401448,
		"Enemy::@6149": 0x8040144c,
		"Enemy::@6150": 0x80401450,
		"Enemy::@6225": 0x80401454,
		"@6225": 0x80401454,
		"Enemy::@6297": 0x80401474,
		"@6297": 0x80401474,
		"Enemy::@6814": 0x80401478,
		"@6814": 0x80401478,
		"Enemy::@6815": 0x8040147c,
		"@6815": 0x8040147c,
		"Enemy::@7194": 0x80401484,
		"@7194": 0x80401484,
		"Enemy::@7195": 0x80401488,
		"@7195": 0x80401488,
		"Enemy::@8019": 0x80401498,
		"@8019": 0x80401498,
		"Enemy::@8020": 0x8040149c,
		"@8020": 0x8040149c,
		"Enemy::@8054": 0x804014b8,
		"@8054": 0x804014b8,
		"Enemy::@8181": 0x804014bc,
		"@8181": 0x804014bc,
		"Enemy::@8345": 0x804014c0,
		"@8345": 0x804014c0,
		"Enemy::@8749": 0x804014c4,
		"@8749": 0x804014c4,
		"Enemy::@8796": 0x804014cc,
		"@8796": 0x804014cc,
		"Enemy::@8849": 0x804014d8,
		"@8849": 0x804014d8,
		"Enemy::@9019": 0x804014dc,
		"@9019": 0x804014dc,
		"Enemy::@2747": 0x804014fc,
		"Enemy::@2749": 0x80401500,
		"Enemy::@3838": 0x804015a4,
		"Enemy::@5103": 0x80401610,
		"Enemy::@5104": 0x80401614,
		"Enemy::@5246": 0x804016f0,
		"Enemy::@5247": 0x804016f4,
		"Enemy::@5248": 0x804016f8,
		"Enemy::@5249": 0x804016fc,
		"Enemy::@6127": 0x80401730,
		"Enemy::@6840": 0x80401744,
		"Enemy::@6887": 0x80401748,
		"Enemy::@6888": 0x8040174c,
		"Enemy::@6889": 0x80401750,
		"Enemy::@6900": 0x80401754,
		"Enemy::@6902": 0x80401758,
		"Enemy::@6904": 0x8040175c,
		"Enemy::@6905": 0x80401760,
		"Enemy::@7021": 0x80401764,
		"@7021": 0x80401764,
		"Enemy::@7022": 0x80401768,
		"@7022": 0x80401768,
		"Enemy::@7125": 0x8040176c,
		"@7125": 0x8040176c,
		"Enemy::@7126": 0x80401770,
		"@7126": 0x80401770,
		"Enemy::@7322": 0x80401774,
		"@7322": 0x80401774,
		"Enemy::@7447": 0x8040177c,
		"@7447": 0x8040177c,
		"Enemy::@7448": 0x80401780,
		"@7448": 0x80401780,
		"Enemy::@7449": 0x80401784,
		"@7449": 0x80401784,
		"Enemy::@8977": 0x804017c8,
		"@8977": 0x804017c8,
		"Enemy::@8978": 0x804017cc,
		"@8978": 0x804017cc,
		"Enemy::@8979": 0x804017d0,
		"@8979": 0x804017d0,
		"Enemy::@8980": 0x804017d4,
		"@8980": 0x804017d4,
		"Enemy::@8997": 0x804017d8,
		"@8997": 0x804017d8,
		"Enemy::@3807": 0x80401850,
		"Enemy::@4210": 0x80401888,
		"Enemy::@3335": 0x804018c4,
		"Enemy::@4494": 0x8040192c,
		"Enemy::@5369": 0x80401944,
		"@5369": 0x80401944,
		"Enemy::@5533": 0x80401950,
		"@5533": 0x80401950,
		"Enemy::@5893": 0x8040196c,
		"Enemy::@3323": 0x80401970,
		"Enemy::@4009": 0x804019ac,
		"Enemy::@4241": 0x804019b8,
		"Enemy::@4242": 0x804019bc,
		"Enemy::@5091": 0x804019f8,
		"Enemy::@5092": 0x804019fc,
		"Enemy::@5154": 0x80401a00,
		"Enemy::@3319": 0x80401a8c,
		"Enemy::@3320": 0x80401a90,
		"Enemy::@3778": 0x80401cfc,
		"Enemy::@4163": 0x80401d08,
		"Enemy::@4362": 0x80401d10,
		"Enemy::@4431": 0x80401d18,
		"Enemy::@3640": 0x80401d20,
		"Enemy::@3641": 0x80401d24,
		"Enemy::@4563": 0x80401d40,
		"Enemy::@2300": 0x80401dec,
		"Enemy::@2301": 0x80401df0,
		"Enemy::@2302": 0x80401df4,
		"Enemy::@2303": 0x80401df8,
		"Enemy::@3802": 0x80401e40,
		"Enemy::@4089": 0x80401e84,
		"Enemy::@4223": 0x80401ea4,
		"Enemy::@4226": 0x80401eb0,
		"Enemy::@4437": 0x80401eb4,
		"Enemy::@4438": 0x80401eb8,
		"Enemy::@4719": 0x80401ebc,
		"Enemy::@4720": 0x80401ec0,
		"Enemy::@4723": 0x80401ecc,
		"Enemy::@4724": 0x80401ed0,
		"Enemy::@4727": 0x80401edc,
		"Enemy::@5439": 0x80401f04,
		"@5439": 0x80401f04,
		"Enemy::@5442": 0x80401f10,
		"@5442": 0x80401f10,
		"Enemy::@5979": 0x80401f14,
		"Enemy::@6548": 0x80401f18,
		"Enemy::@6549": 0x80401f1c,
		"Enemy::@6550": 0x80401f20,
		"Enemy::@6642": 0x80401f30,
		"@6642": 0x80401f30,
		"Enemy::@3217": 0x80401f78,
		"Enemy::@3218": 0x80401f7c,
		"Enemy::@3526": 0x80402044,
		"Enemy::@4457": 0x804020b4,
		"@4457": 0x804020b4,
		"Enemy::@4685": 0x804020bc,
		"Enemy::@3883": 0x80402234,
		"Enemy::@3884": 0x80402238,
		"Enemy::@3831": 0x8040227c,
		"Enemy::@4559": 0x80402298,
		"Enemy::@4560": 0x8040229c,
		"Enemy::@4561": 0x804022a0,
		"Enemy::@4562": 0x804022a4,
		"Enemy::@6036": 0x804022d0,
		"Enemy::@6041": 0x804022d4,
		"Enemy::@6042": 0x804022d8,
		"Enemy::@6043": 0x804022dc,
		"Enemy::@6044": 0x804022e0,
		"@6044": 0x804022e0,
		"Enemy::@6057": 0x80402348,
		"@6057": 0x80402348,
		"Enemy::@3669": 0x804023bc,
		"Enemy::@4248": 0x804023ec,
		"Enemy::@4249": 0x804023f4,
		"Enemy::@4417": 0x80402404,
		"Enemy::@3638": 0x804024a4,
		"Enemy::@4495": 0x804024cc,
		"Enemy::@4611": 0x804024dc,
		"Enemy::@3413": 0x80402550,
		"Enemy::@3957": 0x80402600,
		"Enemy::@4718": 0x80402608,
		"Enemy::@5691": 0x8040262c,
		"Enemy::@5693": 0x80402630,
		"Enemy::@5695": 0x80402634,
		"@5695": 0x80402634,
		"Enemy::@3956": 0x8040271c,
		"Enemy::@4797": 0x80402728,
		"GC2D::@3542": 0x804028a4,
		"GC2D::@3162": 0x804029ac,
		"GC2D::@3226": 0x804029c0,
		"GC2D::@3227": 0x804029c4,
		"GC2D::@3228": 0x804029c8,
		"GC2D::@3229": 0x804029cc,
		"GC2D::@3230": 0x804029d0,
		"GC2D::@3231": 0x804029d4,
		"GC2D::@3351": 0x804029d8,
		"GC2D::@3355": 0x804029e0,
		"GC2D::@3631": 0x80402c20,
		"GC2D::@3632": 0x80402c24,
		"GC2D::@3633": 0x80402c28,
		"GC2D::@3634": 0x80402c2c,
		"GC2D::@3635": 0x80402c30,
		"GC2D::@3636": 0x80402c34,
		"GC2D::@3637": 0x80402c38,
		"GC2D::@3957": 0x80402c50,
		"GC2D::@3961": 0x80402c54,
		"GC2D::@3962": 0x80402c58,
		"GC2D::@4077": 0x80402c5c,
		"GC2D::@4078": 0x80402c60,
		"GC2D::@4079": 0x80402c64,
		"GC2D::@4080": 0x80402c68,
		"GC2D::@2643": 0x80402d84,
		"GC2D::@2644": 0x80402d8c,
		"GC2D::@2645": 0x80402d90,
		"GC2D::@2646": 0x80402d94,
		"GC2D::@2746": 0x80402da0,
		"GC2D::@2747": 0x80402da4,
		"GC2D::@2748": 0x80402da8,
		"GC2D::@2848": 0x80402dac,
		"GC2D::@2849": 0x80402db0,
		"GC2D::@2946": 0x80402db8,
		"GC2D::@2947": 0x80402dbc,
		"GC2D::@3811": 0x80402dd4,
		"GC2D::@262": 0x80402e14,
		"GC2D::@301": 0x80402e18,
		"GC2D::@304": 0x80402e1c,
		"GC2D::@634": 0x80402e20,
		"GC2D::@635": 0x80402e24,
		"@635": 0x80402e24,
		"GC2D::@636": 0x80402e28,
		"@636": 0x80402e28,
		"GC2D::@637": 0x80402e2c,
		"@637": 0x80402e2c,
		"GC2D::@638": 0x80402e30,
		"@638": 0x80402e30,
		"GC2D::@639": 0x80402e34,
		"GC2D::@640": 0x80402e38,
		"GC2D::@641": 0x80402e3c,
		"@641": 0x80402e3c,
		"GC2D::@642": 0x80402e40,
		"GC2D::@643": 0x80402e44,
		"GC2D::@644": 0x80402e48,
		"@644": 0x80402e48,
		"GC2D::@688": 0x80402e58,
		"GC2D::@689": 0x80402e5c,
		"GC2D::@690": 0x80402e60,
		"@690": 0x80402e60,
		"GC2D::@691": 0x80402e64,
		"@691": 0x80402e64,
		"GC2D::@692": 0x80402e68,
		"@692": 0x80402e68,
		"GC2D::@693": 0x80402e6c,
		"@693": 0x80402e6c,
		"GC2D::@694": 0x80402e70,
		"GC2D::@695": 0x80402e74,
		"GC2D::@797": 0x80402e90,
		"GC2D::@798": 0x80402e94,
		"GC2D::@799": 0x80402e98,
		"GC2D::@800": 0x80402e9c,
		"GC2D::@801": 0x80402ea0,
		"GC2D::@802": 0x80402ea4,
		"GC2D::@803": 0x80402ea8,
		"GC2D::@804": 0x80402eac,
		"GC2D::@805": 0x80402eb0,
		"GC2D::@806": 0x80402eb4,
		"GC2D::@902": 0x80402eb8,
		"@902": 0x80402eb8,
		"GC2D::@903": 0x80402ebc,
		"GC2D::@1002": 0x80402ec0,
		"@1002": 0x80402ec0,
		"GC2D::@1003": 0x80402ec4,
		"@1003": 0x80402ec4,
		"GC2D::@1026": 0x80402ec8,
		"@1026": 0x80402ec8,
		"GC2D::@1058": 0x80402ecc,
		"@1058": 0x80402ecc,
		"GC2D::@1059": 0x80402ed0,
		"@1059": 0x80402ed0,
		"GC2D::@1060": 0x80402ed4,
		"@1060": 0x80402ed4,
		"GC2D::@1099": 0x80402ed8,
		"GC2D::@1135": 0x80402eec,
		"@1135": 0x80402eec,
		"GC2D::@1136": 0x80402ef0,
		"@1136": 0x80402ef0,
		"GC2D::@1137": 0x80402ef4,
		"@1137": 0x80402ef4,
		"GC2D::@1194": 0x80402ef8,
		"@1194": 0x80402ef8,
		"GC2D::@1195": 0x80402efc,
		"@1195": 0x80402efc,
		"GC2D::@1196": 0x80402f00,
		"@1196": 0x80402f00,
		"GC2D::@1197": 0x80402f04,
		"@1197": 0x80402f04,
		"GC2D::@1340": 0x80402f08,
		"@1340": 0x80402f08,
		"GC2D::@1687": 0x80402f0c,
		"GC2D::@1688": 0x80402f10,
		"GC2D::@1689": 0x80402f14,
		"GC2D::@1691": 0x80402f1c,
		"@1691": 0x80402f1c,
		"GC2D::@1692": 0x80402f20,
		"@1692": 0x80402f20,
		"GC2D::@1693": 0x80402f24,
		"@1693": 0x80402f24,
		"GC2D::@1694": 0x80402f28,
		"GC2D::@1695": 0x80402f2c,
		"@1695": 0x80402f2c,
		"GC2D::@1835": 0x80402f30,
		"@1835": 0x80402f30,
		"GC2D::@1936": 0x80402f34,
		"Map::@3225": 0x80403060,
		"Map::@3226": 0x80403064,
		"Map::@3227": 0x80403068,
		"Map::@3228": 0x8040306c,
		"Map::@3229": 0x80403070,
		"Map::@3623": 0x80403078,
		"Map::@2631": 0x80403110,
		"Map::@2635": 0x80403130,
		"Map::@2637": 0x80403140,
		"Map::@2638": 0x80403148,
		"Map::@2769": 0x804031a4,
		"Map::@2953": 0x804031b0,
		"Map::@2954": 0x804031b4,
		"Map::@2955": 0x804031b8,
		"Map::@2956": 0x804031bc,
		"Map::@3021": 0x804031d4,
		"Map::@3189": 0x804031dc,
		"Map::@3329": 0x804031e0,
		"Map::@3480": 0x804031e8,
		"Map::@3481": 0x804031ec,
		"Map::@2794": 0x804032e0,
		"Map::@2549": 0x80403324,
		"Map::@2717": 0x80403328,
		"Map::@3059": 0x804033b8,
		"Map::@3069": 0x804033bc,
		"Map::@3070": 0x804033c4,
		"Map::@3411": 0x804034c4,
		"Map::@3412": 0x804034c8,
		"Map::@3453": 0x80403500,
		"Map::@3841": 0x80403518,
		"@3841": 0x80403518,
		"Map::@3842": 0x8040351c,
		"Map::@4477": 0x80403528,
		"Map::@4624": 0x80403538,
		"Map::@4734": 0x8040353c,
		"Map::@4735": 0x80403544,
		"Map::@4736": 0x8040354c,
		"Map::@4737": 0x80403554,
		"Map::@4738": 0x8040355c,
		"Map::@5827": 0x804035ec,
		"MoveBG::@3476": 0x804047a4,
		"MoveBG::@3935": 0x804047d0,
		"MoveBG::@3448": 0x80404860,
		"MoveBG::@3638": 0x80404874,
		"MoveBG::@3881": 0x80404890,
		"MoveBG::@3882": 0x80404894,
		"MoveBG::@3892": 0x80404898,
		"MoveBG::@4100": 0x804048c4,
		"MoveBG::@4302": 0x804048c8,
		"MoveBG::@4303": 0x804048cc,
		"MoveBG::@4468": 0x804048d0,
		"MoveBG::@4469": 0x804048d4,
		"MoveBG::@4470": 0x804048d8,
		"MoveBG::@2627": 0x804048e0,
		"MoveBG::@2628": 0x804048e4,
		"MoveBG::@2629": 0x804048e8,
		"MoveBG::@2656": 0x804048ec,
		"MoveBG::@2657": 0x804048f4,
		"MoveBG::@3609": 0x80404958,
		"MoveBG::@3660": 0x80404a08,
		"MoveBG::@3661": 0x80404a0c,
		"MoveBG::@3662": 0x80404a10,
		"MoveBG::@3836": 0x80404a20,
		"MoveBG::@3837": 0x80404a24,
		"MoveBG::@3838": 0x80404a28,
		"MoveBG::@3839": 0x80404a2c,
		"@3839": 0x80404a2c,
		"MoveBG::@4030": 0x80404a38,
		"MoveBG::@4031": 0x80404a3c,
		"MoveBG::@4084": 0x80404a40,
		"MoveBG::@4240": 0x80404a4c,
		"MoveBG::@3671": 0x80404a7c,
		"MoveBG::@3672": 0x80404a80,
		"MoveBG::@3673": 0x80404a84,
		"MoveBG::@3741": 0x80404a88,
		"MoveBG::@3895": 0x80404aa4,
		"MoveBG::@3896": 0x80404aa8,
		"MoveBG::@4055": 0x80404ac0,
		"MoveBG::@4066": 0x80404ad0,
		"MoveBG::@4067": 0x80404ad4,
		"MoveBG::@4289": 0x80404ae4,
		"MoveBG::@4436": 0x80404af8,
		"MoveBG::@4437": 0x80404afc,
		"MoveBG::@4625": 0x80404b00,
		"MoveBG::@4626": 0x80404b04,
		"MoveBG::@4627": 0x80404b08,
		"MoveBG::@4628": 0x80404b0c,
		"MoveBG::@4630": 0x80404b14,
		"MoveBG::@4818": 0x80404b1c,
		"MoveBG::@4819": 0x80404b20,
		"MoveBG::@4820": 0x80404b24,
		"@4820": 0x80404b24,
		"MoveBG::@4831": 0x80404b28,
		"MoveBG::@4876": 0x80404b30,
		"MoveBG::@4877": 0x80404b34,
		"MoveBG::@5056": 0x80404b38,
		"MoveBG::@5057": 0x80404b3c,
		"MoveBG::@5219": 0x80404b40,
		"MoveBG::@5220": 0x80404b44,
		"MoveBG::@5224": 0x80404b50,
		"MoveBG::@3510": 0x80404cf0,
		"MoveBG::@3590": 0x80404d08,
		"MoveBG::@3706": 0x80404d14,
		"MoveBG::@3707": 0x80404d18,
		"MoveBG::@4039": 0x80404d68,
		"MoveBG::@4090": 0x80404d6c,
		"MoveBG::@4091": 0x80404d70,
		"MoveBG::@4092": 0x80404d74,
		"MoveBG::@4218": 0x80404d90,
		"MoveBG::@3725": 0x80404e34,
		"MoveBG::@3891": 0x80404e48,
		"MoveBG::@3998": 0x80404e4c,
		"MoveBG::@3999": 0x80404e50,
		"MoveBG::@4126": 0x80404e58,
		"MoveBG::@4129": 0x80404e5c,
		"MoveBG::@4130": 0x80404e64,
		"MoveBG::@4131": 0x80404e68,
		"MoveBG::@4132": 0x80404e6c,
		"MoveBG::@4270": 0x80404e90,
		"MoveBG::@2395": 0x80404eac,
		"MoveBG::@2593": 0x80404ec4,
		"MoveBG::@2594": 0x80404ec8,
		"MoveBG::@2595": 0x80404ecc,
		"MoveBG::@2597": 0x80404ed4,
		"MoveBG::@2598": 0x80404ed8,
		"MoveBG::@3593": 0x80405040,
		"MoveBG::@3613": 0x80405044,
		"MoveBG::@3965": 0x8040505c,
		"MoveBG::@4226": 0x80405060,
		"MoveBG::@4360": 0x80405064,
		"MoveBG::@4735": 0x80405088,
		"MoveBG::@4736": 0x8040508c,
		"MoveBG::@4737": 0x80405090,
		"MoveBG::@4738": 0x80405094,
		"MoveBG::@4739": 0x80405098,
		"MoveBG::@4740": 0x8040509c,
		"MoveBG::@4741": 0x804050a0,
		"MoveBG::@4742": 0x804050a4,
		"MoveBG::@4743": 0x804050a8,
		"MoveBG::@4744": 0x804050ac,
		"MoveBG::@5124": 0x804050b4,
		"MoveBG::@2696": 0x8040528c,
		"MoveBG::@2718": 0x80405290,
		"MoveBG::@3447": 0x80405338,
		"MoveBG::@3724": 0x80405354,
		"MoveBG::@3936": 0x80405358,
		"MoveBG::@3937": 0x8040535c,
		"MoveBG::@3938": 0x80405360,
		"MoveBG::@3939": 0x80405364,
		"MoveBG::@3940": 0x80405368,
		"MoveBG::@3556": 0x80405480,
		"MoveBG::@4465": 0x80405524,
		"@4465": 0x80405524,
		"MoveBG::@4651": 0x80405528,
		"MoveBG::@4652": 0x8040552c,
		"MoveBG::@4653": 0x80405530,
		"MoveBG::@4655": 0x80405538,
		"MoveBG::@4656": 0x8040553c,
		"MoveBG::@5240": 0x80405550,
		"MoveBG::@5241": 0x80405554,
		"MoveBG::@5343": 0x80405558,
		"MoveBG::@3739": 0x80405648,
		"NPC::@2672": 0x80405840,
		"NPC::@2673": 0x80405848,
		"NPC::@2676": 0x8040584c,
		"NPC::@2812": 0x80405850,
		"Strategic::@2842": 0x80405ad0,
		"Strategic::@2939": 0x80405adc,
		"Strategic::@3080": 0x80405ae8,
		"Strategic::@3179": 0x80405aec,
		"Strategic::@3298": 0x80405af0,
		"Strategic::@2878": 0x80405b4c,
		"Strategic::@3180": 0x80405b58,
		"M3DUtil::@3225": 0x80405ed8,
		"M3DUtil::@3566": 0x80405edc,
		"Player::@2179": 0x80405f88,
		"Player::@3234": 0x80405fb0,
		"Player::@2269": 0x80406008,
		"Player::@2270": 0x8040600c,
		"Player::@2271": 0x80406010,
		"Player::@2476": 0x80406014,
		"Player::@3638": 0x80406308,
		"Player::@3650": 0x80406310,
		"Player::@3960": 0x8040631c,
		"Player::@3961": 0x80406320,
		"Player::@4321": 0x80406324,
		"Player::@4322": 0x80406328,
		"Player::@4323": 0x8040632c,
		"Player::@4324": 0x80406330,
		"Player::@4938": 0x80406348,
		"Player::@4939": 0x8040634c,
		"Player::@4940": 0x80406350,
		"Player::@4941": 0x80406354,
		"Player::@4942": 0x80406358,
		"Player::@5652": 0x8040635c,
		"Player::@5734": 0x80406374,
		"Player::@5735": 0x80406378,
		"Player::@6339": 0x8040637c,
		"@6339": 0x8040637c,
		"Player::@6340": 0x80406380,
		"@6340": 0x80406380,
		"Player::@6341": 0x80406384,
		"@6341": 0x80406384,
		"Player::@6666": 0x80406388,
		"Player::@3367": 0x804063ac,
		"Player::@3592": 0x804063c8,
		"Player::@3593": 0x804063cc,
		"Player::@3594": 0x804063d0,
		"Player::@3595": 0x804063d4,
		"Player::@3905": 0x804063d8,
		"Player::@3941": 0x804063dc,
		"Player::@3942": 0x804063e0,
		"Player::@3943": 0x804063e4,
		"Player::@3944": 0x804063e8,
		"Player::@3945": 0x804063ec,
		"Player::@4059": 0x80406400,
		"Player::@4060": 0x80406404,
		"Player::@4180": 0x80406408,
		"Player::@4597": 0x80406418,
		"Player::@3063": 0x80406430,
		"Player::@4207": 0x80406438,
		"Player::@4208": 0x8040643c,
		"Player::@4209": 0x80406440,
		"Player::@4512": 0x8040647c,
		"Player::@5125": 0x80406494,
		"Player::@5126": 0x80406498,
		"Player::@5151": 0x8040649c,
		"Player::@5152": 0x804064a0,
		"Player::@5285": 0x804064a4,
		"Player::@5286": 0x804064a8,
		"Player::@5287": 0x804064ac,
		"Player::@5706": 0x804064b0,
		"Player::@5708": 0x804064b8,
		"Player::@5709": 0x804064bc,
		"Player::@5710": 0x804064c0,
		"Player::@5808": 0x804064c4,
		"@5808": 0x804064c4,
		"Player::@5809": 0x804064c8,
		"@5809": 0x804064c8,
		"Player::@5810": 0x804064cc,
		"@5810": 0x804064cc,
		"Player::@5811": 0x804064d0,
		"Player::@6169": 0x804064d4,
		"Player::@6170": 0x804064d8,
		"Player::@6171": 0x804064dc,
		"Player::@6172": 0x804064e0,
		"Player::@6173": 0x804064e4,
		"Player::@7138": 0x804064e8,
		"@7138": 0x804064e8,
		"Player::@7139": 0x804064ec,
		"Player::@7299": 0x804064f0,
		"@7299": 0x804064f0,
		"Player::@7578": 0x804064f4,
		"Player::@7579": 0x804064f8,
		"Player::@7580": 0x804064fc,
		"Player::@7581": 0x80406500,
		"Player::@7582": 0x80406504,
		"Player::@7583": 0x80406508,
		"Player::@7584": 0x8040650c,
		"Player::@7585": 0x80406510,
		"Player::@8023": 0x80406514,
		"Player::@8056": 0x80406518,
		"@8056": 0x80406518,
		"Player::@3030": 0x80406548,
		"Player::@3031": 0x8040654c,
		"Player::@3032": 0x80406550,
		"Player::@3033": 0x80406554,
		"Player::@3843": 0x804065c0,
		"Player::@3844": 0x804065c4,
		"Player::@3845": 0x804065c8,
		"Player::@3900": 0x804065cc,
		"Player::@3901": 0x804065d0,
		"Player::@3957": 0x804065e0,
		"Player::@4123": 0x80406600,
		"Player::@4124": 0x80406604,
		"Player::@4125": 0x80406608,
		"Player::@4164": 0x8040660c,
		"Player::@4242": 0x80406610,
		"Player::@4521": 0x80406618,
		"Player::@4522": 0x8040661c,
		"Player::@4544": 0x80406624,
		"Player::@4545": 0x80406628,
		"Player::@4686": 0x8040662c,
		"Player::@4778": 0x80406634,
		"Player::@4944": 0x80406638,
		"Player::@4945": 0x8040663c,
		"Player::@4946": 0x80406640,
		"Player::@3391": 0x80406648,
		"Player::@3392": 0x8040664c,
		"Player::@3393": 0x80406650,
		"Player::@3394": 0x80406654,
		"Player::@3395": 0x80406658,
		"Player::@3396": 0x8040665c,
		"Player::@3397": 0x80406660,
		"Player::@3398": 0x80406664,
		"Player::@3631": 0x8040667c,
		"Player::@3632": 0x80406680,
		"Player::@3633": 0x80406684,
		"Player::@3634": 0x80406688,
		"Player::@4049": 0x80406698,
		"Player::@4050": 0x8040669c,
		"Player::@4051": 0x804066a0,
		"Player::@4200": 0x804066a4,
		"Player::@4576": 0x804066a8,
		"Player::@4577": 0x804066ac,
		"Player::@4952": 0x804066b8,
		"Player::@5119": 0x804066d0,
		"Player::@5149": 0x804066d4,
		"Player::@5223": 0x804066d8,
		"Player::@5224": 0x804066dc,
		"Player::@5225": 0x804066e0,
		"Player::@5226": 0x804066e4,
		"Player::@5227": 0x804066e8,
		"Player::@5321": 0x804066ec,
		"Player::@5322": 0x804066f0,
		"Player::@5323": 0x804066f4,
		"Player::@5324": 0x804066f8,
		"Player::@2222": 0x80406700,
		"Player::@2223": 0x80406704,
		"Player::@3057": 0x80406734,
		"Player::@3058": 0x80406738,
		"Player::@3059": 0x8040673c,
		"Player::@3061": 0x80406744,
		"Player::@3062": 0x80406748,
		"Player::@3159": 0x80406750,
		"Player::@3353": 0x80406770,
		"Player::@3438": 0x80406798,
		"Player::@1969": 0x804067a0,
		"Player::@2005": 0x804067a4,
		"Player::@2087": 0x804067a8,
		"Player::@2630": 0x804067d8,
		"Player::@3274": 0x80406818,
		"Player::@3275": 0x8040681c,
		"Player::@3948": 0x8040684c,
		"Player::@4662": 0x80406870,
		"Player::@5099": 0x8040687c,
		"Player::@6090": 0x80406880,
		"Player::@6091": 0x80406888,
		"Player::@6093": 0x80406890,
		"Player::@6095": 0x80406894,
		"Player::@6098": 0x80406898,
		"Player::@6100": 0x804068a0,
		"Player::@6109": 0x804068a4,
		"@6109": 0x804068a4,
		"Player::@6111": 0x804068a8,
		"@6111": 0x804068a8,
		"Player::@6119": 0x804068ac,
		"@6119": 0x804068ac,
		"Player::@6125": 0x804068b4,
		"@6125": 0x804068b4,
		"Player::@6127": 0x804068b8,
		"Player::@6130": 0x804068bc,
		"Player::@6132": 0x804068c0,
		"Player::@6134": 0x804068c4,
		"Player::@6139": 0x804068cc,
		"Player::@3296": 0x804068d0,
		"Player::@3846": 0x804068e0,
		"Player::@3847": 0x804068e4,
		"Player::@3848": 0x804068e8,
		"Player::@3849": 0x804068ec,
		"Player::@3859": 0x80406900,
		"Player::@4110": 0x80406904,
		"Player::@4955": 0x80406908,
		"Player::@4966": 0x80406918,
		"Player::@4967": 0x8040691c,
		"Player::@4968": 0x80406920,
		"Player::@4969": 0x80406924,
		"Player::@4971": 0x8040692c,
		"Player::@4972": 0x80406930,
		"Player::@4973": 0x80406934,
		"Player::@4974": 0x80406938,
		"Player::@4977": 0x8040693c,
		"Player::@2010": 0x80406990,
		"Player::@2509": 0x80406998,
		"Player::@2510": 0x8040699c,
		"Player::@2511": 0x804069a0,
		"Player::@2512": 0x804069a8,
		"Player::@2513": 0x804069ac,
		"Player::@2514": 0x804069b4,
		"Player::@2551": 0x804069bc,
		"Player::@2553": 0x804069c0,
		"Player::@2580": 0x804069c8,
		"Player::@2583": 0x804069d0,
		"Player::@2585": 0x804069d8,
		"Player::@2586": 0x804069dc,
		"Player::@2587": 0x804069e4,
		"Player::@2606": 0x804069e8,
		"Player::@2608": 0x804069f0,
		"Player::@2610": 0x804069f4,
		"Player::@2612": 0x804069f8,
		"Player::@2614": 0x804069fc,
		"Player::@2627": 0x80406a00,
		"Player::@2702": 0x80406a18,
		"Player::@2703": 0x80406a1c,
		"Player::@2704": 0x80406a24,
		"Player::@2705": 0x80406a28,
		"Player::@2706": 0x80406a30,
		"Player::@2707": 0x80406a34,
		"Player::@2708": 0x80406a3c,
		"Player::@2709": 0x80406a40,
		"Player::@3237": 0x80406ae0,
		"Player::@3240": 0x80406ae4,
		"Player::@3360": 0x80406af8,
		"Player::@3552": 0x80406b20,
		"Player::@3557": 0x80406b28,
		"Player::@3778": 0x80406b5c,
		"Player::@3963": 0x80406b68,
		"Player::@3965": 0x80406b70,
		"Player::@4126": 0x80406b90,
		"Player::@6706": 0x80406bb8,
		"Player::@4212": 0x80406d40,
		"Player::@4213": 0x80406d44,
		"Player::@4217": 0x80406d54,
		"Player::@4218": 0x80406d58,
		"Player::@4219": 0x80406d5c,
		"Player::@4220": 0x80406d60,
		"Player::@4263": 0x80406d70,
		"@4263": 0x80406d70,
		"System::@3855": 0x80406db0,
		"System::@3856": 0x80406db4,
		"System::@3857": 0x80406db8,
		"System::@3858": 0x80406dbc,
		"System::@3909": 0x80406e40,
		"System::@3910": 0x80406e44,
		"System::@3912": 0x80406e48,
		"System::@4379": 0x80406e60,
		"System::@3070": 0x80406e78,
		"System::@1904": 0x80407098,
		"System::@4212": 0x804071e8,
		"System::@4213": 0x804071ec,
		"System::@2796": 0x80407438,
		"System::@3008": 0x80407450,
		"System::@3449": 0x80407460,
		"System::@3450": 0x80407464,
		"System::@3643": 0x80407468,
		"System::@3644": 0x8040746c,
		"System::@3645": 0x80407470,
		"System::@3646": 0x80407474,
		"JSystem::@722": 0x80407490,
		"@722": 0x80407490,
		"JSystem::@724": 0x80407498,
		"@724": 0x80407498,
		"JSystem::@728": 0x804074a8,
		"@728": 0x804074a8,
		"JSystem::@730": 0x804074b0,
		"@730": 0x804074b0,
		"JSystem::@1783": 0x804074c0,
		"JSystem::@370": 0x804074c8,
		"@370": 0x804074c8,
		"JSystem::@1565": 0x804074f8,
		"JSystem::@1629": 0x804074fc,
		"JSystem::@1630": 0x80407500,
		"JSystem::@1756": 0x80407504,
		"JSystem::@2094": 0x80407508,
		"JSystem::@2216": 0x80407510,
		"JSystem::@192": 0x80407518,
		"JSystem::@604": 0x80407520,
		"JSystem::@609": 0x80407530,
		"JSystem::@639": 0x80407548,
		"JSystem::@640": 0x8040754c,
		"JSystem::@669": 0x80407558,
		"JSystem::@670": 0x8040755c,
		"@670": 0x8040755c,
		"JSystem::@671": 0x80407560,
		"@671": 0x80407560,
		"JSystem::@672": 0x80407564,
		"@672": 0x80407564,
		"JSystem::@135": 0x80407568,
		"@135": 0x80407568,
		"JSystem::@543": 0x804075c0,
		"@543": 0x804075c0,
		"JSystem::@297": 0x804075d0,
		"JSystem::@920": 0x804075e8,
		"JSystem::@1014": 0x804075ec,
		"@1014": 0x804075ec,
		"JSystem::@52": 0x804075f0,
		"JSystem::@276": 0x80407600,
		"@276": 0x80407600,
		"JSystem::@403": 0x80407604,
		"@403": 0x80407604,
		"JSystem::@1321": 0x80407620,
		"@1321": 0x80407620,
		"JSystem::@1322": 0x80407624,
		"@1322": 0x80407624,
		"JSystem::@1329": 0x80407630,
		"@1329": 0x80407630,
		"JSystem::@871": 0x80407638,
		"@871": 0x80407638,
		"JSystem::@872": 0x8040763c,
		"@872": 0x8040763c,
		"JSystem::@912": 0x80407640,
		"@912": 0x80407640,
		"JSystem::@1084": 0x80407648,
		"@1084": 0x80407648,
		"JSystem::@1099": 0x8040764c,
		"JSystem::@1259": 0x80407654,
		"@1259": 0x80407654,
		"JSystem::@1260": 0x80407658,
		"@1260": 0x80407658,
		"JSystem::@1261": 0x8040765c,
		"@1261": 0x8040765c,
		"JSystem::@1262": 0x80407660,
		"@1262": 0x80407660,
		"JSystem::@1077": 0x80407680,
		"@1077": 0x80407680,
		"JSystem::@1258": 0x80407684,
		"@1258": 0x80407684,
		"JSystem::@330": 0x80407688,
		"@330": 0x80407688,
		"JSystem::@2218": 0x80407694,
		"JSystem::@2219": 0x80407698,
		"JSystem::@2221": 0x8040769c,
		"JSystem::@2222": 0x804076a4,
		"JSystem::@2223": 0x804076a8,
		"JSystem::@2225": 0x804076ac,
		"JSystem::@2226": 0x804076b4,
		"JSystem::@2227": 0x804076b8,
		"JSystem::@2456": 0x804076bc,
		"JSystem::@1460": 0x804076c0,
		"@1460": 0x804076c0,
		"JSystem::@2249": 0x804076c4,
		"JSystem::@994": 0x804076d8,
		"@994": 0x804076d8,
		"JSystem::@956": 0x804076e4,
		"@956": 0x804076e4,
		"JSystem::@1073": 0x804076e8,
		"JSystem::@1500": 0x80407700,
		"@1500": 0x80407700,
		"JSystem::@1288": 0x80407710,
		"@1288": 0x80407710,
		"JSystem::@1345": 0x80407714,
		"@1345": 0x80407714,
		"JSystem::@1425": 0x80407718,
		"@1425": 0x80407718,
		"JSystem::@1443": 0x80407720,
		"@1443": 0x80407720,
		"JSystem::@1126": 0x80407728,
		"@1126": 0x80407728,
		"JSystem::@123": 0x80407740,
		"JSystem::@124": 0x80407744,
		"@124": 0x80407744,
		"JSystem::@926": 0x80407760,
		"@926": 0x80407760,
		"JSystem::@927": 0x80407764,
		"@927": 0x80407764,
		"JSystem::@978": 0x80407768,
		"@978": 0x80407768,
		"JSystem::@979": 0x8040776c,
		"@979": 0x8040776c,
		"JSystem::@824": 0x80407778,
		"@824": 0x80407778,
		"JSystem::@825": 0x8040777c,
		"@825": 0x8040777c,
		"JSystem::@360": 0x80407788,
		"JSystem::@100": 0x80407798,
		"JSystem::@111": 0x804077a0,
		"JSystem::@335": 0x804077a8,
		"@335": 0x804077a8,
		"JSystem::@295": 0x804077c4,
		"JSystem::@385": 0x804077d0,
		"JSystem::@386": 0x804077d4,
		"JSystem::@388": 0x804077e0,
		"JSystem::@390": 0x804077f0,
		"@390": 0x804077f0,
		"JSystem::@697": 0x80407800,
		"@697": 0x80407800,
		"JSystem::@2338": 0x80407820,
		"JSystem::@878": 0x8040782c,
		"@878": 0x8040782c,
		"JSystem::@879": 0x80407830,
		"@879": 0x80407830,
		"JSystem::@633": 0x80407840,
		"@633": 0x80407840,
		"JSystem::@634": 0x80407844,
		"JSystem::@1466": 0x80407848,
		"@1466": 0x80407848,
		"JSystem::@1467": 0x8040784c,
		"@1467": 0x8040784c,
		"JSystem::@1469": 0x80407850,
		"@1469": 0x80407850,
		"JSystem::@1470": 0x80407854,
		"@1470": 0x80407854,
		"JSystem::@1471": 0x80407858,
		"@1471": 0x80407858,
		"JSystem::@1472": 0x8040785c,
		"@1472": 0x8040785c,
		"JSystem::@1477": 0x80407860,
		"@1477": 0x80407860,
		"JSystem::@1478": 0x80407868,
		"@1478": 0x80407868,
		"JSystem::@1479": 0x80407870,
		"@1479": 0x80407870,
		"JSystem::@48": 0x80407880,
		"@48": 0x80407880,
		"JSystem::@244": 0x804078a0,
		"@244": 0x804078a0,
		"JSystem::@354": 0x804078a8,
		"JSystem::@355": 0x804078ac,
		"JSystem::@544": 0x804078c0,
		"@544": 0x804078c0,
		"JSystem::@461": 0x804078c8,
		"JSystem::@622": 0x804078cc,
		"@622": 0x804078cc,
		"JSystem::@623": 0x804078d0,
		"@623": 0x804078d0,
		"JSystem::@624": 0x804078d4,
		"@624": 0x804078d4,
		"JSystem::@413": 0x804078f0,
		"@413": 0x804078f0,
		"JSystem::@694": 0x804078f8,
		"JSystem::@695": 0x804078fc,
		"JSystem::@696": 0x80407900,
		"@696": 0x80407900,
		"JSystem::@1287": 0x80407904,
		"@1287": 0x80407904,
		"JSystem::@494": 0x80407910,
		"@494": 0x80407910,
		"JSystem::@495": 0x80407914,
		"@495": 0x80407914,
		"JSystem::@496": 0x80407918,
		"@496": 0x80407918,
		"JSystem::@551": 0x80407924,
		"@551": 0x80407924,
		"JSystem::@587": 0x80407930,
		"@587": 0x80407930,
		"JSystem::@588": 0x80407934,
		"@588": 0x80407934,
		"JSystem::@589": 0x80407938,
		"@589": 0x80407938,
		"JSystem::@590": 0x8040793c,
		"@590": 0x8040793c,
		"JSystem::@762": 0x80407960,
		"JSystem::@763": 0x80407964,
		"JSystem::@934": 0x80407970,
		"@934": 0x80407970,
		"JSystem::@935": 0x80407974,
		"@935": 0x80407974,
		"JSystem::@826": 0x8040797c,
		"@826": 0x8040797c,
		"JSystem::@829": 0x80407990,
		"@829": 0x80407990,
		"JSystem::@830": 0x80407994,
		"@830": 0x80407994,
		"JSystem::@932": 0x804079a0,
		"@932": 0x804079a0,
		"JSystem::@504": 0x804079b0,
		"@504": 0x804079b0,
		"JSystem::@989": 0x804079b8,
		"@989": 0x804079b8,
		"JSystem::@534": 0x804079d0,
		"@534": 0x804079d0,
		"JSystem::@535": 0x804079d8,
		"@535": 0x804079d8,
		"JSystem::@536": 0x804079e0,
		"@536": 0x804079e0,
		"JSystem::@434": 0x804079f0,
		"@434": 0x804079f0,
		"JSystem::@602": 0x804079f4,
		"JSystem::@680": 0x80407a18,
		"@680": 0x80407a18,
		"JSystem::@681": 0x80407a1c,
		"@681": 0x80407a1c,
		"JSystem::@943": 0x80407a20,
		"JSystem::@944": 0x80407a24,
		"@944": 0x80407a24,
		"JSystem::@1207": 0x80407a2c,
		"@1207": 0x80407a2c,
		"JSystem::@1242": 0x80407a30,
		"@1242": 0x80407a30,
		"JSystem::@1373": 0x80407a34,
		"@1373": 0x80407a34,
		"JSystem::@509": 0x80407a38,
		"@509": 0x80407a38,
		"JSystem::@339": 0x80407a40,
		"JSystem::@340": 0x80407a44,
		"JSystem::@418": 0x80407a48,
		"@418": 0x80407a48,
		"JSystem::@419": 0x80407a4c,
		"@419": 0x80407a4c,
		"JSystem::@435": 0x80407a58,
		"JSystem::@568": 0x80407a80,
		"@568": 0x80407a80,
		"JSystem::@328": 0x80407a90,
		"@328": 0x80407a90,
		"JSystem::@345": 0x80407a98,
		"@345": 0x80407a98,
		"JSystem::@346": 0x80407a9c,
		"@346": 0x80407a9c,
		"JSystem::@252": 0x80407aa8,
		"@252": 0x80407aa8,
		"JSystem::@253": 0x80407aac,
		"@253": 0x80407aac,
		"JSystem::@274": 0x80407ad8,
		"@274": 0x80407ad8,
		"JSystem::@836": 0x80407ae4,
		"@836": 0x80407ae4,
		"JSystem::@120": 0x80407af8,
		"@120": 0x80407af8,
		"JSystem::@204": 0x80407b08,
		"@204": 0x80407b08,
		"JSystem::@231": 0x80407b0c,
		"@231": 0x80407b0c,
		"JSystem::@260": 0x80407b10,
		"JSystem::@261": 0x80407b14,
		"JSystem::@332": 0x80407b28,
		"@332": 0x80407b28,
		"JSystem::@334": 0x80407b38,
		"@334": 0x80407b38,
		"JSystem::@236": 0x80407b40,
		"@236": 0x80407b40,
		"JSystem::@525": 0x80407b50,
		"@525": 0x80407b50,
		"JSystem::@526": 0x80407b54,
		"@526": 0x80407b54,
		"JSystem::@527": 0x80407b58,
		"@527": 0x80407b58,
		"JSystem::@528": 0x80407b5c,
		"@528": 0x80407b5c,
		"JSystem::@621": 0x80407b74,
		"@621": 0x80407b74,
		"JSystem::@754": 0x80407b80,
		"JSystem::@129": 0x80407ba0,
		"@129": 0x80407ba0,
		"JSystem::@642": 0x80407bc8,
		"JSystem::@797": 0x80407bd0,
		"JSystem::@948": 0x80407bd8,
		"@948": 0x80407bd8,
		"JSystem::@949": 0x80407bdc,
		"@949": 0x80407bdc,
		"JSystem::@950": 0x80407be0,
		"@950": 0x80407be0,
		"JSystem::@981": 0x80407bf0,
		"@981": 0x80407bf0,
		"JSystem::@1217": 0x80407bf8,
		"@1217": 0x80407bf8,
		"JSystem::@1326": 0x80407bfc,
		"@1326": 0x80407bfc,
		"JSystem::@1344": 0x80407c04,
		"@1344": 0x80407c04,
		"JSystem::@363": 0x80407c08,
		"JSystem::@377": 0x80407c10,
		"@377": 0x80407c10,
		"JSystem::@411": 0x80407c30,
		"@411": 0x80407c30,
		"JSystem::@1706": 0x80407c48,
		"JSystem::@1707": 0x80407c4c,
		"JSystem::@2032": 0x80407c68,
		"JSystem::@2829": 0x80407c6c,
		"JSystem::@2830": 0x80407c70,
		"JSystem::@2840": 0x80407c80,
		"JSystem::@1786": 0x80407c88,
		"JSystem::@1787": 0x80407c8c,
		"JSystem::@1673": 0x80407c98,
		"JSystem::@1877": 0x80407c9c,
		"@1877": 0x80407c9c,
		"JSystem::@1955": 0x80407ca0,
		"JSystem::@1956": 0x80407ca4,
		"JSystem::@1957": 0x80407ca8,
		"JSystem::@2076": 0x80407cac,
		"JSystem::@1639": 0x80407cb4,
		"JSystem::@1681": 0x80407cc4,
		"JSystem::@1682": 0x80407cc8,
		"JSystem::@1683": 0x80407ccc,
		"JSystem::@1675": 0x80407ce8,
		"JSystem::@1689": 0x80407cec,
		"JSystem::@1820": 0x80407cf0,
		"JSystem::@1659": 0x80407cf8,
		"JSystem::@1860": 0x80407cfc,
		"JSystem::@2759": 0x80407d20,
		"JSystem::@2760": 0x80407d24,
		"JSystem::@2761": 0x80407d28,
		"JSystem::@2762": 0x80407d2c,
		"JSystem::@3307": 0x80407d30,
		"JSystem::@1743": 0x80407d40,
		"@1743": 0x80407d40,
		"JSystem::@1744": 0x80407d44,
		"@1744": 0x80407d44,
		"JSystem::@1745": 0x80407d48,
		"@1745": 0x80407d48,
		"JSystem::@2374": 0x80407d60,
		"JSystem::@2375": 0x80407d64,
		"JSystem::@2378": 0x80407d68,
		"JSystem::@2379": 0x80407d6c,
		"JSystem::@2380": 0x80407d70,
		"JSystem::@2538": 0x80407d74,
		"JSystem::@2542": 0x80407d78,
		"JSystem::@4485": 0x80407d7c,
		"JSystem::@4568": 0x80407d80,
		"@4568": 0x80407d80,
		"JSystem::@1505": 0x80407d88,
		"JSystem::@1506": 0x80407d8c,
		"@1506": 0x80407d8c,
		"JSystem::@1570": 0x80407da0,
		"JSystem::@1571": 0x80407da4,
		"JSystem::@1509": 0x80407da8,
		"@1509": 0x80407da8,
		"JSystem::@1510": 0x80407dac,
		"@1510": 0x80407dac,
		"JSystem::@1511": 0x80407db0,
		"@1511": 0x80407db0,
		"JSystem::@126": 0x80407dd0,
		"JSystem::@118": 0x80407dd8,
		"@118": 0x80407dd8,
		"JSystem::@71": 0x80407de0,
		"MSL_C.PPCEABI.bare.H::@156": 0x80407ea0,
		"MSL_C.PPCEABI.bare.H::@157": 0x80407ea4,
		"MSL_C.PPCEABI.bare.H::@158": 0x80407ea8,
		"MSL_C.PPCEABI.bare.H::@159": 0x80407eac,
		"MSL_C.PPCEABI.bare.H::@168": 0x80407eb0,
		"MSL_C.PPCEABI.bare.H::@169": 0x80407eb4,
		"MSL_C.PPCEABI.bare.H::@170": 0x80407eb8,
		"MSL_C.PPCEABI.bare.H::@188": 0x80407ebc,
		"MSL_C.PPCEABI.bare.H::@106": 0x80407ec0,
		"@106": 0x80407ec0,
		"MSL_C.PPCEABI.bare.H::@107": 0x80407ec4,
		"@107": 0x80407ec4,
		"MSL_C.PPCEABI.bare.H::@108": 0x80407ec8,
		"@108": 0x80407ec8,
		"MSL_C.PPCEABI.bare.H::__log2e_m1$localstatic0$__log2f__Ff": 0x80407ed8,
		"__log2e_m1$localstatic0$__log2f__Ff": 0x80407ed8,
		"MSL_C.PPCEABI.bare.H::@93": 0x80407ee0,
		"MSL_C.PPCEABI.bare.H::_inf": 0x80407ee8,
		"_inf": 0x80407ee8,
		"MSL_C.PPCEABI.bare.H::_nan": 0x80407eec,
		"_nan": 0x80407eec,
		"MSL_C.PPCEABI.bare.H::@246": 0x80407ef0,
		"@246": 0x80407ef0,
		"MSL_C.PPCEABI.bare.H::@247": 0x80407ef4,
		"@247": 0x80407ef4,
		"MSL_C.PPCEABI.bare.H::@248": 0x80407ef8,
		"@248": 0x80407ef8,
		"MSL_C.PPCEABI.bare.H::@249": 0x80407efc,
		"@249": 0x80407efc,
		"MSL_C.PPCEABI.bare.H::@250": 0x80407f00,
		"@250": 0x80407f00,
		"MSL_C.PPCEABI.bare.H::@251": 0x80407f04,
		"@251": 0x80407f04,
		"MSL_C.PPCEABI.bare.H::@259": 0x80407f10,
		"MSL_C.PPCEABI.bare.H::@260": 0x80407f14,
		"MSL_C.PPCEABI.bare.H::@261": 0x80407f18,
		"MSL_C.PPCEABI.bare.H::@262": 0x80407f1c,
		"os::@153": 0x80407f20,
		"mtx::@94": 0x80407f28,
		"mtx::@95": 0x80407f2c,
		"mtx::@193": 0x80407f30,
		"mtx::@214": 0x80407f34,
		"mtx::@217": 0x80407f38,
		"@217": 0x80407f38,
		"mtx::@218": 0x80407f3c,
		"@218": 0x80407f3c,
		"mtx::@97": 0x80407f40,
		"mtx::@98": 0x80407f44,
		"mtx::@99": 0x80407f48,
		"mtx::@100": 0x80407f4c,
		"mtx::@103": 0x80407f50,
		"@103": 0x80407f50,
		"mtx::@104": 0x80407f54,
		"@104": 0x80407f54,
		"mtx::@116": 0x80407f58,
		"mtx::@117": 0x80407f5c,
		"gx::@122": 0x80407f64,
		"@122": 0x80407f64,
		"gx::@123": 0x80407f68,
		"gx::@177": 0x80407f6c,
		"gx::@178": 0x80407f70,
		"gx::@179": 0x80407f74,
		"gx::@83": 0x80407f80,
		"gx::@127": 0x80407f94,
		"gx::@148": 0x80407f98,
		"gx::@167": 0x80407fb0,
		"gx::@164": 0x80407fb8,
		"gx::@192": 0x80407fc8,
		"gx::@193": 0x80407fcc,
		"gx::@194": 0x80407fd0,
		"@194": 0x80407fd0,
		"gx::@195": 0x80407fd4,
		"@195": 0x80407fd4,
		"gx::@196": 0x80407fd8,
		"@196": 0x80407fd8,
		"gx::@197": 0x80407fdc,
		"gx::@45": 0x80407fe0,
		"@45": 0x80407fe0,
		"gx::@125": 0x80407fe8,
		"@125": 0x80407fe8,
		"gx::@126": 0x80407fec,
		"gx::@130": 0x80408008,
		"gx::@357": 0x8040801c,
		"gx::@358": 0x80408020,
		"gx::@360": 0x80408024,
		"gx::@405": 0x80408038,
		"@405": 0x80408038,
		"gx::@493": 0x8040803c,
		"@493": 0x8040803c,
		"gx::@14": 0x80408040,
		"gx::@15": 0x80408044,
		"gx::@16": 0x80408048,
		"gx::@63": 0x80408058,
		"gx::@64": 0x8040805c,
		"thp::@665": 0x80408068,
		"@665": 0x80408068,
		"thp::@666": 0x8040806c,
		"@666": 0x8040806c,
		"thp::@667": 0x80408070,
		"@667": 0x80408070,
		"thp::@668": 0x80408074,
		"@668": 0x80408074,
		"thp::@669": 0x80408078,
		"THPPlayer::@22": 0x804000a8,
		"THPPlayer::@25": 0x804000b0,
		"THPPlayer::@28": 0x804000b4,
		"THPPlayer::@31": 0x804000b8,
		"THPPlayer::@55": 0x804000bc,
		"@55": 0x804000bc,
		"THPPlayer::@71": 0x804000c0,
		"THPPlayer::@72": 0x804000c4,
		"@72": 0x804000c4,
		"THPPlayer::@479": 0x804000d8,
		"@479": 0x804000d8,
		"THPPlayer::@791": 0x804000dc,
		"@791": 0x804000dc,
		"THPPlayer::@792": 0x804000e0,
		"@792": 0x804000e0,
		"MarioUtil::@1997": 0x80405c10,
		"MarioUtil::@1999": 0x80405c14,
		"MarioUtil::@2009": 0x80405c18,
		"MarioUtil::@2452": 0x80405c28,
		"MarioUtil::@2453": 0x80405c2c,
		"MarioUtil::@2472": 0x80405c30,
		"MarioUtil::@2473": 0x80405c34,
		"MarioUtil::@2948": 0x80405c38,
		"MarioUtil::@3041": 0x80405c3c,
		"MarioUtil::@3042": 0x80405c40,
		"MarioUtil::@3043": 0x80405c44,
		"MarioUtil::@3044": 0x80405c48,
		"MarioUtil::@3357": 0x80405c4c,
		"MarioUtil::@3505": 0x80405c50,
		"MarioUtil::@3506": 0x80405c54,
		"MarioUtil::@3507": 0x80405c58,
		"MarioUtil::@3555": 0x80405c5c,
		"MarioUtil::@3556": 0x80405c60,
		"MarioUtil::@3557": 0x80405c64,
		"MarioUtil::@3558": 0x80405c68,
		"MarioUtil::@3560": 0x80405c6c,
		"MarioUtil::@3561": 0x80405c70,
		"MarioUtil::@3565": 0x80405c74,
		"MarioUtil::@3566": 0x80405c78,
		"MarioUtil::@2043": 0x80405c88,
		"MarioUtil::@2044": 0x80405c8c,
		"MarioUtil::@2045": 0x80405c90,
		"MarioUtil::@2046": 0x80405c94,
		"MarioUtil::@2228": 0x80405c9c,
		"MarioUtil::@2229": 0x80405ca0,
		"MarioUtil::@2230": 0x80405ca4,
		"MarioUtil::@2231": 0x80405ca8,
		"MarioUtil::@2665": 0x80405cb0,
		"MarioUtil::@2666": 0x80405cb8,
		"MarioUtil::@2667": 0x80405cbc,
		"MarioUtil::@2844": 0x80405cc0,
		"MarioUtil::@1608": 0x80405cc8,
		"MarioUtil::@1627": 0x80405cd8,
		"MarioUtil::@1638": 0x80405cdc,
		"MarioUtil::@1639": 0x80405ce0,
		"MarioUtil::@1673": 0x80405ce4,
		"MarioUtil::@1674": 0x80405ce8,
		"MarioUtil::@1675": 0x80405cec,
		"MarioUtil::@1676": 0x80405cf0,
		"MarioUtil::@1797": 0x80405cf4,
		"MarioUtil::@1798": 0x80405cf8,
		"MarioUtil::@1884": 0x80405d10,
		"@1884": 0x80405d10,
		"MarioUtil::@2093": 0x80405d18,
		"MarioUtil::@2094": 0x80405d1c,
		"MarioUtil::@2123": 0x80405d20,
		"MarioUtil::@2124": 0x80405d24,
		"MarioUtil::@2156": 0x80405d28,
		"MarioUtil::@2194": 0x80405d30,
		"MarioUtil::@2550": 0x80405d48,
		"MarioUtil::@2551": 0x80405d50,
		"MarioUtil::@2552": 0x80405d54,
		"MarioUtil::@2553": 0x80405d58,
		"MarioUtil::@2554": 0x80405d5c,
		"MarioUtil::@2555": 0x80405d64,
		"MarioUtil::@1629": 0x80405d80,
		"MarioUtil::@1630": 0x80405d84,
		"MarioUtil::@1631": 0x80405d88,
		"MarioUtil::@1802": 0x80405d94,
		"MarioUtil::@1803": 0x80405d98,
		"MarioUtil::@1833": 0x80405da8,
		"MarioUtil::@1834": 0x80405dac,
		"@1834": 0x80405dac,
		"MarioUtil::@2235": 0x80405db0,
		"MarioUtil::@2297": 0x80405db4,
		"MarioUtil::@2312": 0x80405db8,
		"MarioUtil::@2315": 0x80405dbc,
		"MarioUtil::@2743": 0x80405dc4,
		"MarioUtil::@2744": 0x80405dc8,
		"MarioUtil::@2745": 0x80405dcc,
		"MarioUtil::@2746": 0x80405dd0,
		"MarioUtil::@2747": 0x80405dd4,
		"MarioUtil::@2748": 0x80405dd8,
		"MarioUtil::@2749": 0x80405ddc,
		"MarioUtil::@2750": 0x80405de0,
		"MarioUtil::@2751": 0x80405de4,
		"MarioUtil::@2752": 0x80405de8,
		"MarioUtil::@2753": 0x80405dec,
		"MarioUtil::@2754": 0x80405df0,
		"MarioUtil::@2857": 0x80405df4,
		"MarioUtil::@2858": 0x80405df8,
		"MarioUtil::@2859": 0x80405dfc,
		"MarioUtil::@2976": 0x80405e00,
		"MarioUtil::@2977": 0x80405e04,
		"MarioUtil::@2978": 0x80405e08,
		"MarioUtil::@4014": 0x80405e0c,
		"MarioUtil::@4158": 0x80405e10,
		"MarioUtil::@4159": 0x80405e14,
		"MarioUtil::@4634": 0x80405e18,
		"MarioUtil::@4756": 0x80405e1c,
		"MarioUtil::@4757": 0x80405e20,
		"MarioUtil::@4758": 0x80405e24,
		"MarioUtil::@4759": 0x80405e28,
		"MarioUtil::@4869": 0x80405e2c,
		"MarioUtil::@5163": 0x80405e38,
		"MarioUtil::@5164": 0x80405e3c,
		"MarioUtil::@51": 0x80405e40,
		"@51": 0x80405e40,
		"MarioUtil::@52": 0x80405e44,
		"MarioUtil::@53": 0x80405e48,
		"@53": 0x80405e48,
		"MarioUtil::@1799": 0x80405e50,
		"MarioUtil::@2233": 0x80405e64,
		"MarioUtil::@1767": 0x80405e70,
		"MarioUtil::@1790": 0x80405e74,
		"MarioUtil::@1841": 0x80405e78,
		"MarioUtil::@2244": 0x80405e7c,
		"MarioUtil::@2245": 0x80405e80,
		"MarioUtil::sFogOffColor$1583": 0x80405e88,
		"sFogOffColor$1583": 0x80405e88,
		"MarioUtil::@2280": 0x80405ea0,
		"MarioUtil::@2282": 0x80405eb0,
		"MarioUtil::@1941": 0x80405ec0,
		"MarioUtil::@1942": 0x80405ec4,
		"M3DUtil::@1572": 0x80405ec8,
		"M3DUtil::@1573": 0x80405ecc,
		"M3DUtil::@1716": 0x80405ed0,
		"@1716": 0x80405ed0,
		"M3DUtil::@1875": 0x80405ee8,
		"M3DUtil::@1908": 0x80405ef0,
		"M3DUtil::@1909": 0x80405ef4,
		"M3DUtil::@2660": 0x80405f00,
		"M3DUtil::@2663": 0x80405f08,
		"M3DUtil::@2666": 0x80405f10,
		"M3DUtil::@2669": 0x80405f18,
		"M3DUtil::@2672": 0x80405f20,
		"M3DUtil::@2019": 0x80405f28,
		"M3DUtil::@2020": 0x80405f30,
		"M3DUtil::@2021": 0x80405f34,
		"M3DUtil::@2022": 0x80405f3c,
		"M3DUtil::@2023": 0x80405f44,
		"M3DUtil::@2024": 0x80405f4c,
		"M3DUtil::@2025": 0x80405f54,
		"M3DUtil::@2161": 0x80405f5c,
		"M3DUtil::@2162": 0x80405f64,
		"M3DUtil::@2163": 0x80405f68,
		"M3DUtil::@1661": 0x80405f70,
		"M3DUtil::@1694": 0x80405f74,
		"System::@2802": 0x80406d90,
		"System::@2803": 0x80406d94,
		"System::@2171": 0x80406df8,
		"System::@1731": 0x80406e20,
		"@1731": 0x80406e20,
		"System::@2398": 0x80406e28,
		"System::@2389": 0x80406e80,
		"System::@2731": 0x80406e88,
		"System::@2738": 0x80406e90,
		"System::@2739": 0x80406e94,
		"System::@2740": 0x80406e98,
		"System::@2741": 0x80406e9c,
		"System::@2742": 0x80406ea0,
		"System::@2753": 0x80406ea8,
		"System::@2754": 0x80406eac,
		"System::@2975": 0x80406ec8,
		"System::@1626": 0x80406ed0,
		"System::@4673": 0x80406f28,
		"System::@2844": 0x80406f7c,
		"System::@2850": 0x80406fac,
		"System::@2851": 0x80406fb4,
		"System::@2852": 0x80406fbc,
		"System::@2853": 0x80406fc4,
		"System::@1607": 0x80406ff8,
		"System::@2481": 0x80407010,
		"System::@2485": 0x80407014,
		"System::@1806": 0x80407070,
		"System::@1807": 0x80407074,
		"System::@2115": 0x80407078,
		"System::@2116": 0x8040707c,
		"System::@2121": 0x80407088,
		"System::@2122": 0x8040708c,
		"System::@1665": 0x804070a0,
		"System::@3960": 0x8040710c,
		"System::@3962": 0x80407114,
		"System::@3964": 0x8040711c,
		"System::@4118": 0x80407168,
		"System::@2093": 0x80407200,
		"System::@2094": 0x80407204,
		"System::@5046": 0x8040724c,
		"System::@5060": 0x80407278,
		"System::@5102": 0x804072ac,
		"System::@5207": 0x80407300,
		"@5207": 0x80407300,
		"System::@5328": 0x80407380,
		"System::@5333": 0x80407390,
		"System::@2441": 0x804073d0,
		"System::@2442": 0x804073d4,
		"System::@2553": 0x804073dc,
		"System::@2829": 0x804073e4,
		"System::@2835": 0x804073ec,
		"System::@3804": 0x80407420,
		"Strategic::@2101": 0x80405b60,
		"Strategic::@2103": 0x80405b64,
		"Strategic::@2104": 0x80405b68,
		"Strategic::@2277": 0x80405b70,
		"Strategic::@1841": 0x80405b78,
		"Strategic::@1947": 0x80405b80,
		"Strategic::@1662": 0x80405b88,
		"Strategic::@2285": 0x80405b98,
		"Strategic::@2409": 0x80405b9c,
		"Strategic::@2532": 0x80405ba0,
		"Strategic::@2533": 0x80405ba8,
		"Strategic::@2534": 0x80405bb0,
		"Strategic::@2535": 0x80405bb8,
		"Strategic::@2536": 0x80405bc0,
		"Strategic::@2537": 0x80405bc8,
		"Strategic::@2538": 0x80405bd0,
		"Strategic::@2539": 0x80405bd4,
		"Strategic::@2540": 0x80405bdc,
		"Strategic::@2829": 0x80405be4,
		"Strategic::@2830": 0x80405be8,
		"Strategic::@2831": 0x80405bec,
		"Strategic::@1772": 0x80405bf0,
		"Strategic::@1825": 0x80405bf4,
		"Strategic::@1540": 0x80405bf8,
		"Strategic::@1618": 0x80405c00,
		"Strategic::@1619": 0x80405c04,
		"Strategic::@1660": 0x80405c08,
		"Player::@2856": 0x80406144,
		"Player::@2857": 0x8040614c,
		"Player::@2859": 0x8040615c,
		"Player::@2860": 0x80406164,
		"Player::@2861": 0x8040616c,
		"Player::@2865": 0x8040618c,
		"Player::@2866": 0x80406194,
		"Player::@2867": 0x8040619c,
		"Player::@2958": 0x80406288,
		"Player::@3647": 0x8040630c,
		"Player::@3070": 0x8040674c,
		"Player::@2710": 0x80406a48,
		"Player::@2712": 0x80406a4c,
		"Player::@2714": 0x80406a50,
		"Player::@2717": 0x80406a54,
		"Player::@2718": 0x80406a5c,
		"Player::@2719": 0x80406a60,
		"Player::@3571": 0x80406b34,
		"Player::@3749": 0x80406b48,
		"Player::@3998": 0x80406b7c,
		"Player::@6572": 0x80406ba4,
		"@6572": 0x80406ba4,
		"Player::@6573": 0x80406ba8,
		"@6573": 0x80406ba8,
		"Player::@2699": 0x80406bc0,
		"Player::@3018": 0x80406bc8,
		"Player::@3035": 0x80406bcc,
		"Player::@3049": 0x80406bd4,
		"Player::@3680": 0x80406c14,
		"Player::@3825": 0x80406c24,
		"Player::@3865": 0x80406c38,
		"@3865": 0x80406c38,
		"Player::@4343": 0x80406c3c,
		"Player::@4344": 0x80406c40,
		"Player::@4345": 0x80406c44,
		"Player::@4346": 0x80406c48,
		"Player::@4347": 0x80406c4c,
		"Player::@4502": 0x80406c50,
		"Player::@4503": 0x80406c54,
		"Player::@4561": 0x80406c5c,
		"Player::@4562": 0x80406c60,
		"Player::@4563": 0x80406c64,
		"Player::@4623": 0x80406c68,
		"Player::@4624": 0x80406c6c,
		"Player::@4625": 0x80406c70,
		"Player::@4637": 0x80406c7c,
		"Player::@4638": 0x80406c80,
		"Player::@4639": 0x80406c84,
		"Player::@4640": 0x80406c88,
		"Player::@4641": 0x80406c8c,
		"Player::@4642": 0x80406c90,
		"Player::@4643": 0x80406c94,
		"Player::@4644": 0x80406c98,
		"Player::@4648": 0x80406c9c,
		"Player::@4650": 0x80406ca0,
		"Player::@4651": 0x80406ca4,
		"Player::@4652": 0x80406cac,
		"Player::@4653": 0x80406cb0,
		"Player::@4654": 0x80406cb4,
		"Player::@4731": 0x80406cb8,
		"Player::@4732": 0x80406cc0,
		"Player::@4733": 0x80406cc8,
		"Player::@4734": 0x80406cd0,
		"Player::@4735": 0x80406cd8,
		"Player::@4737": 0x80406cdc,
		"Player::@4739": 0x80406ce4,
		"Player::@4740": 0x80406cec,
		"Player::@4744": 0x80406cf0,
		"Player::@4745": 0x80406cf8,
		"NPC::@3245": 0x80405680,
		"NPC::@3246": 0x80405684,
		"NPC::@3247": 0x80405688,
		"NPC::@3361": 0x80405698,
		"NPC::@3362": 0x8040569c,
		"NPC::@3363": 0x804056a0,
		"NPC::@3365": 0x804056a8,
		"NPC::@3366": 0x804056ac,
		"NPC::@3472": 0x804056b0,
		"NPC::@3878": 0x804056b4,
		"NPC::@3879": 0x804056b8,
		"NPC::@4245": 0x804056bc,
		"NPC::@4246": 0x804056c0,
		"NPC::@4247": 0x804056c4,
		"NPC::@4250": 0x804056d8,
		"NPC::@4778": 0x804056dc,
		"NPC::@3704": 0x804056e4,
		"NPC::@3705": 0x804056e8,
		"NPC::@3706": 0x804056ec,
		"NPC::@3707": 0x804056f0,
		"NPC::@3935": 0x80405708,
		"NPC::@3936": 0x8040570c,
		"NPC::@3989": 0x80405710,
		"NPC::@4213": 0x80405714,
		"NPC::@2536": 0x80405744,
		"NPC::@2804": 0x80405748,
		"NPC::@2805": 0x8040574c,
		"NPC::@2860": 0x80405750,
		"NPC::@2898": 0x80405758,
		"NPC::@2934": 0x8040575c,
		"NPC::@2857": 0x80405788,
		"NPC::@3036": 0x8040578c,
		"NPC::@3037": 0x80405790,
		"NPC::@2161": 0x80405798,
		"NPC::@2163": 0x8040579c,
		"NPC::@2165": 0x804057a0,
		"NPC::@2167": 0x804057a4,
		"NPC::@2169": 0x804057a8,
		"NPC::@2171": 0x804057ac,
		"NPC::@2173": 0x804057b0,
		"NPC::@2175": 0x804057b4,
		"NPC::@2177": 0x804057b8,
		"NPC::@2180": 0x804057bc,
		"NPC::@2182": 0x804057c0,
		"NPC::@2184": 0x804057c4,
		"NPC::@2187": 0x804057c8,
		"NPC::@2189": 0x804057cc,
		"NPC::@2194": 0x804057d0,
		"NPC::@2196": 0x804057d4,
		"NPC::@2204": 0x804057e4,
		"NPC::@2206": 0x804057e8,
		"NPC::@2208": 0x804057ec,
		"NPC::@2341": 0x80405818,
		"NPC::@2356": 0x80405820,
		"NPC::@2375": 0x80405834,
		"NPC::@2419": 0x80405838,
		"NPC::sPeach_TakenMiddle": 0x80405858,
		"sPeach_TakenMiddle": 0x80405858,
		"NPC::@1539": 0x80405860,
		"NPC::sMonteM_TieBColorBuf0": 0x80405868,
		"sMonteM_TieBColorBuf0": 0x80405868,
		"NPC::sMonteM_TieBColorBuf1": 0x80405870,
		"sMonteM_TieBColorBuf1": 0x80405870,
		"NPC::@1573": 0x80405878,
		"NPC::@1577": 0x80405880,
		"NPC::sMareMB_ElderMat1ColorBuf0": 0x80405888,
		"sMareMB_ElderMat1ColorBuf0": 0x80405888,
		"NPC::sMareMB_ElderMat1ColorBuf1": 0x80405890,
		"sMareMB_ElderMat1ColorBuf1": 0x80405890,
		"NPC::sMareMB_ElderMat2ColorBuf0": 0x80405898,
		"sMareMB_ElderMat2ColorBuf0": 0x80405898,
		"NPC::sMareMB_ElderMat2ColorBuf1": 0x804058a0,
		"sMareMB_ElderMat2ColorBuf1": 0x804058a0,
		"NPC::@1583": 0x804058a8,
		"NPC::sMareMB_ElderMat3ColorBuf0": 0x804058b0,
		"sMareMB_ElderMat3ColorBuf0": 0x804058b0,
		"NPC::sMareMB_ElderMat3ColorBuf1": 0x804058b8,
		"sMareMB_ElderMat3ColorBuf1": 0x804058b8,
		"NPC::@1584": 0x804058c0,
		"NPC::sMareMB_FishingRodMat1ColorBuf0": 0x804058c8,
		"sMareMB_FishingRodMat1ColorBuf0": 0x804058c8,
		"NPC::sMareMB_FishingRodMat1ColorBuf1": 0x804058d0,
		"sMareMB_FishingRodMat1ColorBuf1": 0x804058d0,
		"NPC::sMareMB_FishingRodMat2ColorBuf0": 0x804058d8,
		"sMareMB_FishingRodMat2ColorBuf0": 0x804058d8,
		"NPC::sMareMB_FishingRodMat2ColorBuf1": 0x804058e0,
		"sMareMB_FishingRodMat2ColorBuf1": 0x804058e0,
		"NPC::sMareMB_FishingRodMat3ColorBuf0": 0x804058e8,
		"sMareMB_FishingRodMat3ColorBuf0": 0x804058e8,
		"NPC::sMareMB_FishingRodMat3ColorBuf1": 0x804058f0,
		"sMareMB_FishingRodMat3ColorBuf1": 0x804058f0,
		"NPC::sMareMC_HatFColorBuf0": 0x804058f8,
		"sMareMC_HatFColorBuf0": 0x804058f8,
		"NPC::sMareMC_HatFColorBuf1": 0x80405900,
		"sMareMC_HatFColorBuf1": 0x80405900,
		"NPC::sMareMC_BeardColorBuf0": 0x80405908,
		"sMareMC_BeardColorBuf0": 0x80405908,
		"NPC::sMareMC_BeardColorBuf1": 0x80405910,
		"sMareMC_BeardColorBuf1": 0x80405910,
		"NPC::sMareMC_MustacheColorBuf0": 0x80405918,
		"sMareMC_MustacheColorBuf0": 0x80405918,
		"NPC::sMareMC_MustacheColorBuf1": 0x80405920,
		"sMareMC_MustacheColorBuf1": 0x80405920,
		"NPC::sMareMD_PipeColorBuf0": 0x80405928,
		"sMareMD_PipeColorBuf0": 0x80405928,
		"NPC::sMareMD_PipeColorBuf1": 0x80405930,
		"sMareMD_PipeColorBuf1": 0x80405930,
		"NPC::@1590": 0x80405938,
		"NPC::sMareWB_BabyBodyColorBuf0": 0x80405940,
		"sMareWB_BabyBodyColorBuf0": 0x80405940,
		"NPC::@1598": 0x80405948,
		"NPC::sMareWB_BabyHatColorBuf0": 0x80405950,
		"sMareWB_BabyHatColorBuf0": 0x80405950,
		"NPC::sMareWB_BabyHatColorBuf1": 0x80405958,
		"sMareWB_BabyHatColorBuf1": 0x80405958,
		"NPC::sMareWB_BabyBedColorBuf0": 0x80405960,
		"sMareWB_BabyBedColorBuf0": 0x80405960,
		"NPC::sMareWB_BabyBedColorBuf1": 0x80405968,
		"sMareWB_BabyBedColorBuf1": 0x80405968,
		"NPC::@1614": 0x80405970,
		"@1614": 0x80405970,
		"NPC::@1621": 0x80405978,
		"TBaseNPC::sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x80405988,
		"sIndividualMareWA0Bck$localstatic6$initIndividualAnm_": 0x80405988,
		"NPC::@2532": 0x80405990,
		"NPC::@2533": 0x80405994,
		"NPC::@2534": 0x80405998,
		"NPC::@2754": 0x804059b0,
		"NPC::@2755": 0x804059b4,
		"NPC::@2756": 0x804059b8,
		"NPC::@1832": 0x804059c0,
		"NPC::@1833": 0x804059c4,
		"NPC::@3189": 0x804059e0,
		"NPC::@3190": 0x804059e4,
		"NPC::@3191": 0x804059e8,
		"NPC::@3387": 0x804059f0,
		"NPC::@3388": 0x804059f4,
		"NPC::@3467": 0x80405a00,
		"NPC::@3468": 0x80405a04,
		"NPC::@3776": 0x80405a08,
		"NPC::@1682": 0x80405a10,
		"NPC::@1683": 0x80405a14,
		"NPC::@1684": 0x80405a18,
		"NPC::@1685": 0x80405a1c,
		"NPC::@1686": 0x80405a20,
		"NPC::@2611": 0x80405a38,
		"NPC::@2612": 0x80405a3c,
		"NPC::@2613": 0x80405a40,
		"NPC::@2614": 0x80405a44,
		"NPC::@2615": 0x80405a48,
		"NPC::@2695": 0x80405a4c,
		"NPC::@2499": 0x80405a68,
		"NPC::@2500": 0x80405a6c,
		"NPC::@2501": 0x80405a70,
		"NPC::@2319": 0x80405ab0,
		"NPC::@2320": 0x80405ab4,
		"NPC::@2321": 0x80405ab8,
		"NPC::@2322": 0x80405abc,
		"MSound::@1983": 0x803ffd68,
		"MSound::@1984": 0x803ffd6c,
		"MSound::@1985": 0x803ffd70,
		"MSound::@2263": 0x803ffe00,
		"MSound::@2264": 0x803ffe04,
		"MSound::@2265": 0x803ffe08,
		"MSound::@2486": 0x803ffe18,
		"MSound::@2543": 0x803ffe1c,
		"MSound::@2544": 0x803ffe20,
		"MSound::@2545": 0x803ffe24,
		"MSound::@2575": 0x803ffe28,
		"MSound::@2576": 0x803ffe2c,
		"MSound::@2577": 0x803ffe30,
		"MSound::@2818": 0x803ffe40,
		"MSound::@2819": 0x803ffe44,
		"MSound::@2820": 0x803ffe48,
		"MSound::@2821": 0x803ffe4c,
		"MSound::@2823": 0x803ffe50,
		"MSound::@2824": 0x803ffe54,
		"MSound::@2825": 0x803ffe58,
		"MSound::@2827": 0x803ffe5c,
		"MSound::@2828": 0x803ffe60,
		"MSound::@2829": 0x803ffe64,
		"MSound::@2830": 0x803ffe68,
		"MSound::@2831": 0x803ffe6c,
		"MSound::@2833": 0x803ffe70,
		"MSound::@2837": 0x803ffe74,
		"MSound::@2838": 0x803ffe78,
		"MSound::@2839": 0x803ffe7c,
		"MSound::@2840": 0x803ffe80,
		"MSound::@2842": 0x803ffe84,
		"MSound::@2843": 0x803ffe88,
		"MSound::@2845": 0x803ffe8c,
		"MSound::@2847": 0x803ffe90,
		"MSound::@2848": 0x803ffe94,
		"MSound::@2849": 0x803ffe98,
		"MSound::@2850": 0x803ffe9c,
		"MSound::@2859": 0x803ffebc,
		"MSound::@2860": 0x803ffec0,
		"MSound::@2874": 0x803ffee4,
		"MSound::@2878": 0x803ffee8,
		"MSound::@2884": 0x803ffef8,
		"MSound::@2890": 0x803fff00,
		"MSound::@2895": 0x803fff08,
		"MSound::@2902": 0x803fff18,
		"MSound::@2907": 0x803fff24,
		"MSound::@2909": 0x803fff2c,
		"MSound::@2910": 0x803fff30,
		"MSound::@2912": 0x803fff34,
		"MSound::@2915": 0x803fff3c,
		"MSound::@2919": 0x803fff44,
		"MSound::@2920": 0x803fff48,
		"MSound::@2923": 0x803fff50,
		"MSound::@2924": 0x803fff54,
		"MSound::@2925": 0x803fff58,
		"MSound::@2927": 0x803fff5c,
		"MSound::@2929": 0x803fff64,
		"MSound::@2931": 0x803fff6c,
		"MSound::@2933": 0x803fff70,
		"MSound::@2935": 0x803fff74,
		"MSound::@2937": 0x803fff78,
		"MSound::@2939": 0x803fff7c,
		"MSound::@1995": 0x803fffa8,
		"MSound::@1996": 0x803fffac,
		"MSound::@1997": 0x803fffb0,
		"MSound::@1998": 0x803fffb4,
		"MSound::@1999": 0x803fffb8,
		"MSound::@2000": 0x803fffbc,
		"MSound::@2001": 0x803fffc0,
		"MSound::@2020": 0x80400004,
		"MSound::@2021": 0x80400008,
		"MSound::@2022": 0x8040000c,
		"MSound::@2023": 0x80400014,
		"MSound::@2025": 0x8040001c,
		"MSound::@2027": 0x80400020,
		"MSound::@2029": 0x80400024,
		"MSound::@2030": 0x80400028,
		"MSound::@2031": 0x8040002c,
		"MSound::@2036": 0x80400060,
		"MSound::@2080": 0x80400080,
		"MSound::@2039": 0x80400098,
		"MSound::@2040": 0x8040009c,
		"MSound::@2041": 0x804000a0,
		"MoveBG::no_data_anim_info": 0x80403618,
		"no_data_anim_info": 0x80403618,
		"MoveBG::normal_sound_info": 0x80403620,
		"normal_sound_info": 0x80403620,
		"MoveBG::billboard_dolphin_anim_info": 0x80403630,
		"billboard_dolphin_anim_info": 0x80403630,
		"MoveBG::billboard_sun_anim_info": 0x80403638,
		"billboard_sun_anim_info": 0x80403638,
		"MoveBG::billboard_restaurant_anim_info": 0x80403640,
		"billboard_restaurant_anim_info": 0x80403640,
		"MoveBG::billboard_fish_anim_info": 0x80403648,
		"billboard_fish_anim_info": 0x80403648,
		"MoveBG::MonteChair_anim_info": 0x80403658,
		"MonteChair_anim_info": 0x80403658,
		"MoveBG::@2798": 0x80403660,
		"MoveBG::doorHotel_anim_info": 0x80403668,
		"doorHotel_anim_info": 0x80403668,
		"MoveBG::@2802": 0x80403670,
		"MoveBG::manhole_anim_info": 0x80403678,
		"manhole_anim_info": 0x80403678,
		"MoveBG::manhole_map_collision_info": 0x80403680,
		"manhole_map_collision_info": 0x80403680,
		"MoveBG::@2804": 0x80403688,
		"MoveBG::FruitBasket_anim_info": 0x80403690,
		"FruitBasket_anim_info": 0x80403690,
		"MoveBG::@2805": 0x80403698,
		"MoveBG::FruitBasket_map_collision_data": 0x804036a0,
		"FruitBasket_map_collision_data": 0x804036a0,
		"MoveBG::FruitBasket_map_collision_info": 0x804036a8,
		"FruitBasket_map_collision_info": 0x804036a8,
		"MoveBG::BasketReverse_anim_info": 0x804036b0,
		"BasketReverse_anim_info": 0x804036b0,
		"MoveBG::BasketReverse_map_collision_data": 0x804036b8,
		"BasketReverse_map_collision_data": 0x804036b8,
		"MoveBG::BasketReverse_map_collision_info": 0x804036c0,
		"BasketReverse_map_collision_info": 0x804036c0,
		"MoveBG::Pile_map_collision_data": 0x804036d0,
		"Pile_map_collision_data": 0x804036d0,
		"MoveBG::Pile_map_collision_info": 0x804036d8,
		"Pile_map_collision_info": 0x804036d8,
		"MoveBG::ChipShine_anim_info": 0x804036e0,
		"ChipShine_anim_info": 0x804036e0,
		"MoveBG::KoopaJrSignM_anim_info": 0x804036e8,
		"KoopaJrSignM_anim_info": 0x804036e8,
		"MoveBG::SignCircle_anim_info": 0x804036f0,
		"SignCircle_anim_info": 0x804036f0,
		"MoveBG::SignCross_anim_info": 0x804036f8,
		"SignCross_anim_info": 0x804036f8,
		"MoveBG::SignTriangle_anim_info": 0x80403700,
		"SignTriangle_anim_info": 0x80403700,
		"MoveBG::ObjSwitch_map_collision_data": 0x80403708,
		"ObjSwitch_map_collision_data": 0x80403708,
		"MoveBG::ObjSwitch_map_collision_info": 0x80403710,
		"ObjSwitch_map_collision_info": 0x80403710,
		"MoveBG::RedCoinSwitch_map_collision_data": 0x80403718,
		"RedCoinSwitch_map_collision_data": 0x80403718,
		"MoveBG::RedCoinSwitch_map_collision_info": 0x80403720,
		"RedCoinSwitch_map_collision_info": 0x80403720,
		"MoveBG::coin_sound_info": 0x80403730,
		"coin_sound_info": 0x80403730,
		"MoveBG::mario_cap_anim_info": 0x80403748,
		"mario_cap_anim_info": 0x80403748,
		"MoveBG::coin_anim_info": 0x80403750,
		"coin_anim_info": 0x80403750,
		"MoveBG::eggYoshi_anim_info": 0x80403758,
		"eggYoshi_anim_info": 0x80403758,
		"MoveBG::NozzleBox_anim_info": 0x80403760,
		"NozzleBox_anim_info": 0x80403760,
		"MoveBG::mushroom1up_anim_info": 0x80403768,
		"mushroom1up_anim_info": 0x80403768,
		"MoveBG::jumpbase_anim_info": 0x80403770,
		"jumpbase_anim_info": 0x80403770,
		"MoveBG::jumpbase_map_collision_data": 0x80403778,
		"jumpbase_map_collision_data": 0x80403778,
		"MoveBG::jumpbase_map_collision_info": 0x80403780,
		"jumpbase_map_collision_info": 0x80403780,
		"MoveBG::fruit_sound_info": 0x80403788,
		"fruit_sound_info": 0x80403788,
		"MoveBG::CoverPine_anim_info": 0x80403790,
		"CoverPine_anim_info": 0x80403790,
		"MoveBG::durian_sound_info": 0x80403798,
		"durian_sound_info": 0x80403798,
		"MoveBG::fence3x3_anim_info": 0x804037a0,
		"fence3x3_anim_info": 0x804037a0,
		"MoveBG::fence_revolve_outer_anim_info": 0x804037a8,
		"fence_revolve_outer_anim_info": 0x804037a8,
		"MoveBG::FenceWaterV_map_collision_data": 0x804037b0,
		"FenceWaterV_map_collision_data": 0x804037b0,
		"MoveBG::FenceWaterV_map_collision_info": 0x804037b8,
		"FenceWaterV_map_collision_info": 0x804037b8,
		"MoveBG::FenceWaterH_map_collision_info": 0x804037c0,
		"FenceWaterH_map_collision_info": 0x804037c0,
		"MoveBG::RailFence_anim_info": 0x804037c8,
		"RailFence_anim_info": 0x804037c8,
		"MoveBG::RailFence_map_collision_info": 0x804037d0,
		"RailFence_map_collision_info": 0x804037d0,
		"MoveBG::BambooRailFence_anim_info": 0x804037d8,
		"BambooRailFence_anim_info": 0x804037d8,
		"MoveBG::wood_barrel_anim_info": 0x804037e0,
		"wood_barrel_anim_info": 0x804037e0,
		"MoveBG::wood_barrel_map_collision_info": 0x804037f0,
		"wood_barrel_map_collision_info": 0x804037f0,
		"MoveBG::wood_barrel_sound_info": 0x804037f8,
		"wood_barrel_sound_info": 0x804037f8,
		"MoveBG::wood_barrel_sink_data": 0x80403800,
		"wood_barrel_sink_data": 0x80403800,
		"MoveBG::barrel_float_map_collision_data": 0x80403808,
		"barrel_float_map_collision_data": 0x80403808,
		"MoveBG::barrel_float_map_collision_info": 0x80403810,
		"barrel_float_map_collision_info": 0x80403810,
		"MoveBG::drum_can_anim_info": 0x80403818,
		"drum_can_anim_info": 0x80403818,
		"MoveBG::drum_can_map_collision_info": 0x80403820,
		"drum_can_map_collision_info": 0x80403820,
		"MoveBG::barrel_oil_anim_info": 0x80403828,
		"barrel_oil_anim_info": 0x80403828,
		"MoveBG::warp_block_map_collision_data": 0x80403830,
		"warp_block_map_collision_data": 0x80403830,
		"MoveBG::warp_block_map_collision_info": 0x80403838,
		"warp_block_map_collision_info": 0x80403838,
		"MoveBG::move_block_map_collision_data": 0x80403840,
		"move_block_map_collision_data": 0x80403840,
		"MoveBG::move_block_map_collision_info": 0x80403848,
		"move_block_map_collision_info": 0x80403848,
		"MoveBG::move_block_center_map_collision_data": 0x80403850,
		"move_block_center_map_collision_data": 0x80403850,
		"MoveBG::move_block_center_map_collision_info": 0x80403858,
		"move_block_center_map_collision_info": 0x80403858,
		"MoveBG::breakable_block_anim_info": 0x80403860,
		"breakable_block_anim_info": 0x80403860,
		"MoveBG::breakable_block_map_collision_data": 0x80403868,
		"breakable_block_map_collision_data": 0x80403868,
		"MoveBG::breakable_block_map_collision_info": 0x80403870,
		"breakable_block_map_collision_info": 0x80403870,
		"MoveBG::water_roll_block_anim_info": 0x80403878,
		"water_roll_block_anim_info": 0x80403878,
		"MoveBG::water_roll_block_map_collision_data": 0x80403880,
		"water_roll_block_map_collision_data": 0x80403880,
		"MoveBG::water_roll_block_map_collision_info": 0x80403888,
		"water_roll_block_map_collision_info": 0x80403888,
		"MoveBG::sand_block_anim_info": 0x80403890,
		"sand_block_anim_info": 0x80403890,
		"MoveBG::sand_block_map_collision_info": 0x80403898,
		"sand_block_map_collision_info": 0x80403898,
		"MoveBG::MoveCoin_anim_info": 0x804038a0,
		"MoveCoin_anim_info": 0x804038a0,
		"MoveBG::cluster_block_anim_info": 0x804038a8,
		"cluster_block_anim_info": 0x804038a8,
		"MoveBG::NormalBlock_map_collision_data": 0x804038b0,
		"NormalBlock_map_collision_data": 0x804038b0,
		"MoveBG::NormalBlock_map_collision_info": 0x804038b8,
		"NormalBlock_map_collision_info": 0x804038b8,
		"MoveBG::IceBlock_map_collision_data": 0x804038c0,
		"IceBlock_map_collision_data": 0x804038c0,
		"MoveBG::IceBlock_map_collision_info": 0x804038c8,
		"IceBlock_map_collision_info": 0x804038c8,
		"MoveBG::BrickBlock_anim_info": 0x804038d0,
		"BrickBlock_anim_info": 0x804038d0,
		"MoveBG::BrickBlock_map_collision_data": 0x804038d8,
		"BrickBlock_map_collision_data": 0x804038d8,
		"MoveBG::BrickBlock_map_collision_info": 0x804038e0,
		"BrickBlock_map_collision_info": 0x804038e0,
		"MoveBG::WaterMelonBlock_anim_info": 0x804038e8,
		"WaterMelonBlock_anim_info": 0x804038e8,
		"MoveBG::WaterMelonBlock_map_collision_data": 0x804038f0,
		"WaterMelonBlock_map_collision_data": 0x804038f0,
		"MoveBG::WaterMelonBlock_map_collision_info": 0x804038f8,
		"WaterMelonBlock_map_collision_info": 0x804038f8,
		"MoveBG::TelesaBlock_map_collision_data": 0x80403900,
		"TelesaBlock_map_collision_data": 0x80403900,
		"MoveBG::TelesaBlock_map_collision_info": 0x80403908,
		"TelesaBlock_map_collision_info": 0x80403908,
		"MoveBG::JuiceBlock_map_collision_data": 0x80403910,
		"JuiceBlock_map_collision_data": 0x80403910,
		"MoveBG::JuiceBlock_map_collision_info": 0x80403918,
		"JuiceBlock_map_collision_info": 0x80403918,
		"MoveBG::SuperHipDropBlock_anim_info": 0x80403920,
		"SuperHipDropBlock_anim_info": 0x80403920,
		"MoveBG::SuperHipDropBlock_map_collision_data": 0x80403928,
		"SuperHipDropBlock_map_collision_data": 0x80403928,
		"MoveBG::SuperHipDropBlock_map_collision_info": 0x80403930,
		"SuperHipDropBlock_map_collision_info": 0x80403930,
		"MoveBG::PalmNormal_anim_info": 0x80403938,
		"PalmNormal_anim_info": 0x80403938,
		"MoveBG::PalmNormalTree_map_collision_data": 0x80403940,
		"PalmNormalTree_map_collision_data": 0x80403940,
		"MoveBG::PalmNormalTree_map_collision_info": 0x80403948,
		"PalmNormalTree_map_collision_info": 0x80403948,
		"MoveBG::PalmOugiTree_map_collision_data": 0x80403950,
		"PalmOugiTree_map_collision_data": 0x80403950,
		"MoveBG::PalmOugiTree_map_collision_info": 0x80403958,
		"PalmOugiTree_map_collision_info": 0x80403958,
		"MoveBG::PalmSagoTree_map_collision_data": 0x80403960,
		"PalmSagoTree_map_collision_data": 0x80403960,
		"MoveBG::PalmSagoTree_map_collision_info": 0x80403968,
		"PalmSagoTree_map_collision_info": 0x80403968,
		"MoveBG::PalmNatumeTree_map_collision_data": 0x80403970,
		"PalmNatumeTree_map_collision_data": 0x80403970,
		"MoveBG::PalmNatumeTree_map_collision_info": 0x80403978,
		"PalmNatumeTree_map_collision_info": 0x80403978,
		"MoveBG::PalmLeaf_anim_info": 0x80403980,
		"PalmLeaf_anim_info": 0x80403980,
		"MoveBG::PalmLeafTree_map_collision_data": 0x80403988,
		"PalmLeafTree_map_collision_data": 0x80403988,
		"MoveBG::PalmLeafTree_map_collision_info": 0x80403990,
		"PalmLeafTree_map_collision_info": 0x80403990,
		"MoveBG::BananaTree_anim_info": 0x80403998,
		"BananaTree_anim_info": 0x80403998,
		"MoveBG::BananaTree_map_collision_data": 0x804039a0,
		"BananaTree_map_collision_data": 0x804039a0,
		"MoveBG::BananaTree_map_collision_info": 0x804039a8,
		"BananaTree_map_collision_info": 0x804039a8,
		"MoveBG::FruitTree_map_collision_data": 0x804039b0,
		"FruitTree_map_collision_data": 0x804039b0,
		"MoveBG::FruitTree_map_collision_info": 0x804039b8,
		"FruitTree_map_collision_info": 0x804039b8,
		"MoveBG::flowerOrange_anim_info": 0x804039c8,
		"flowerOrange_anim_info": 0x804039c8,
		"MoveBG::flowerPink_anim_info": 0x804039d0,
		"flowerPink_anim_info": 0x804039d0,
		"MoveBG::flowerPurple_anim_info": 0x804039d8,
		"flowerPurple_anim_info": 0x804039d8,
		"MoveBG::flowerRed_anim_info": 0x804039e0,
		"flowerRed_anim_info": 0x804039e0,
		"MoveBG::flowerYellow_anim_info": 0x804039e8,
		"flowerYellow_anim_info": 0x804039e8,
		"MoveBG::flowerSunflower_anim_info": 0x804039f0,
		"flowerSunflower_anim_info": 0x804039f0,
		"MoveBG::pole_sound_info": 0x804039f8,
		"pole_sound_info": 0x804039f8,
		"MoveBG::dptlight_anim_info": 0x80403a00,
		"dptlight_anim_info": 0x80403a00,
		"MoveBG::streetlamp_map_collision_info": 0x80403a08,
		"streetlamp_map_collision_info": 0x80403a08,
		"MoveBG::football_anim_info": 0x80403a10,
		"football_anim_info": 0x80403a10,
		"MoveBG::football_sound_info": 0x80403a18,
		"football_sound_info": 0x80403a18,
		"MoveBG::football_goal_anim_info": 0x80403a20,
		"football_goal_anim_info": 0x80403a20,
		"MoveBG::football_goal_map_collision_info": 0x80403a28,
		"football_goal_map_collision_info": 0x80403a28,
		"MoveBG::Watermelon_anim_info": 0x80403a30,
		"Watermelon_anim_info": 0x80403a30,
		"MoveBG::watermelon_sound_info": 0x80403a38,
		"watermelon_sound_info": 0x80403a38,
		"MoveBG::WatermelonStatic_anim_info": 0x80403a40,
		"WatermelonStatic_anim_info": 0x80403a40,
		"MoveBG::cloud_anim_info": 0x80403a48,
		"cloud_anim_info": 0x80403a48,
		"MoveBG::cloud_map_collision_data": 0x80403a58,
		"cloud_map_collision_data": 0x80403a58,
		"MoveBG::cloud_map_collision_info": 0x80403a60,
		"cloud_map_collision_info": 0x80403a60,
		"MoveBG::normallift_anim_info": 0x80403a68,
		"normallift_anim_info": 0x80403a68,
		"MoveBG::normallift_map_collision_data": 0x80403a70,
		"normallift_map_collision_data": 0x80403a70,
		"MoveBG::normallift_map_collision_info": 0x80403a78,
		"normallift_map_collision_info": 0x80403a78,
		"MoveBG::exrollcube_anim_info": 0x80403a80,
		"exrollcube_anim_info": 0x80403a80,
		"MoveBG::exrollcube_map_collision_data": 0x80403a88,
		"exrollcube_map_collision_data": 0x80403a88,
		"MoveBG::exrollcube_map_collision_info": 0x80403a90,
		"exrollcube_map_collision_info": 0x80403a90,
		"MoveBG::exkickboard_anim_info": 0x80403a98,
		"exkickboard_anim_info": 0x80403a98,
		"MoveBG::exkickboard_map_collision_data": 0x80403aa0,
		"exkickboard_map_collision_data": 0x80403aa0,
		"MoveBG::exkickboard_map_collision_info": 0x80403aa8,
		"exkickboard_map_collision_info": 0x80403aa8,
		"MoveBG::railblockr_anim_info": 0x80403ab0,
		"railblockr_anim_info": 0x80403ab0,
		"MoveBG::railblocky_anim_info": 0x80403ab8,
		"railblocky_anim_info": 0x80403ab8,
		"MoveBG::railblockb_anim_info": 0x80403ac0,
		"railblockb_anim_info": 0x80403ac0,
		"MoveBG::railblock_map_collision_data": 0x80403ac8,
		"railblock_map_collision_data": 0x80403ac8,
		"MoveBG::railblock_map_collision_info": 0x80403ad0,
		"railblock_map_collision_info": 0x80403ad0,
		"MoveBG::umaibou_anim_info": 0x80403ad8,
		"umaibou_anim_info": 0x80403ad8,
		"MoveBG::umaibou_map_collision_data": 0x80403ae8,
		"umaibou_map_collision_data": 0x80403ae8,
		"MoveBG::umaibou_map_collision_info": 0x80403af0,
		"umaibou_map_collision_info": 0x80403af0,
		"MoveBG::kamaboko_anim_info": 0x80403af8,
		"kamaboko_anim_info": 0x80403af8,
		"MoveBG::kamaboko_map_collision_data": 0x80403b00,
		"kamaboko_map_collision_data": 0x80403b00,
		"MoveBG::kamaboko_map_collision_info": 0x80403b08,
		"kamaboko_map_collision_info": 0x80403b08,
		"MoveBG::getag_anim_info": 0x80403b10,
		"getag_anim_info": 0x80403b10,
		"MoveBG::getao_anim_info": 0x80403b18,
		"getao_anim_info": 0x80403b18,
		"MoveBG::geta_map_collision_data": 0x80403b28,
		"geta_map_collision_data": 0x80403b28,
		"MoveBG::geta_map_collision_info": 0x80403b30,
		"geta_map_collision_info": 0x80403b30,
		"MoveBG::uirou_anim_info": 0x80403b48,
		"uirou_anim_info": 0x80403b48,
		"MoveBG::uirou_map_collision_data": 0x80403b58,
		"uirou_map_collision_data": 0x80403b58,
		"MoveBG::uirou_map_collision_info": 0x80403b60,
		"uirou_map_collision_info": 0x80403b60,
		"MoveBG::hikidashi_anim_info": 0x80403b68,
		"hikidashi_anim_info": 0x80403b68,
		"MoveBG::hikidashi_map_collision_data": 0x80403b70,
		"hikidashi_map_collision_data": 0x80403b70,
		"MoveBG::hikidashi_map_collision_info": 0x80403b78,
		"hikidashi_map_collision_info": 0x80403b78,
		"MoveBG::castella_anim_info": 0x80403b80,
		"castella_anim_info": 0x80403b80,
		"MoveBG::castella_map_collision_data": 0x80403b88,
		"castella_map_collision_data": 0x80403b88,
		"MoveBG::castella_map_collision_info": 0x80403b90,
		"castella_map_collision_info": 0x80403b90,
		"MoveBG::yoshiblock_anim_info": 0x80403b98,
		"yoshiblock_anim_info": 0x80403b98,
		"MoveBG::yoshiblock_map_collision_data": 0x80403ba0,
		"yoshiblock_map_collision_data": 0x80403ba0,
		"MoveBG::yoshiblock_map_collision_info": 0x80403ba8,
		"yoshiblock_map_collision_info": 0x80403ba8,
		"MoveBG::WoodBlockTriangle_map_collision_data": 0x80403bb0,
		"WoodBlockTriangle_map_collision_data": 0x80403bb0,
		"MoveBG::WoodBlockTriangle_map_collision_info": 0x80403bb8,
		"WoodBlockTriangle_map_collision_info": 0x80403bb8,
		"MoveBG::WoodBlockPyramid_map_collision_data": 0x80403bc0,
		"WoodBlockPyramid_map_collision_data": 0x80403bc0,
		"MoveBG::WoodBlockPyramid_map_collision_info": 0x80403bc8,
		"WoodBlockPyramid_map_collision_info": 0x80403bc8,
		"MoveBG::WoodBlockLong_map_collision_data": 0x80403bd0,
		"WoodBlockLong_map_collision_data": 0x80403bd0,
		"MoveBG::WoodBlockLong_map_collision_info": 0x80403bd8,
		"WoodBlockLong_map_collision_info": 0x80403bd8,
		"MoveBG::WoodBlockLarge_map_collision_data": 0x80403be0,
		"WoodBlockLarge_map_collision_data": 0x80403be0,
		"MoveBG::WoodBlockLarge_map_collision_info": 0x80403be8,
		"WoodBlockLarge_map_collision_info": 0x80403be8,
		"MoveBG::WoodBlockCone_map_collision_data": 0x80403bf0,
		"WoodBlockCone_map_collision_data": 0x80403bf0,
		"MoveBG::WoodBlockCone_map_collision_info": 0x80403bf8,
		"WoodBlockCone_map_collision_info": 0x80403bf8,
		"MoveBG::WoodBlockL_map_collision_data": 0x80403c00,
		"WoodBlockL_map_collision_data": 0x80403c00,
		"MoveBG::WoodBlockL_map_collision_info": 0x80403c08,
		"WoodBlockL_map_collision_info": 0x80403c08,
		"MoveBG::WoodBlockBridge_map_collision_data": 0x80403c10,
		"WoodBlockBridge_map_collision_data": 0x80403c10,
		"MoveBG::WoodBlockBridge_map_collision_info": 0x80403c18,
		"WoodBlockBridge_map_collision_info": 0x80403c18,
		"MoveBG::WoodBlockCube_map_collision_data": 0x80403c20,
		"WoodBlockCube_map_collision_data": 0x80403c20,
		"MoveBG::WoodBlockCube_map_collision_info": 0x80403c28,
		"WoodBlockCube_map_collision_info": 0x80403c28,
		"MoveBG::normalvariant0_map_collision_data": 0x80403c30,
		"normalvariant0_map_collision_data": 0x80403c30,
		"MoveBG::normalvariant0_map_collision_info": 0x80403c38,
		"normalvariant0_map_collision_info": 0x80403c38,
		"MoveBG::normalvariant1_map_collision_data": 0x80403c40,
		"normalvariant1_map_collision_data": 0x80403c40,
		"MoveBG::normalvariant1_map_collision_info": 0x80403c48,
		"normalvariant1_map_collision_info": 0x80403c48,
		"MoveBG::normalvariant2_map_collision_data": 0x80403c50,
		"normalvariant2_map_collision_data": 0x80403c50,
		"MoveBG::normalvariant2_map_collision_info": 0x80403c58,
		"normalvariant2_map_collision_info": 0x80403c58,
		"MoveBG::normalvariant3_map_collision_data": 0x80403c60,
		"normalvariant3_map_collision_data": 0x80403c60,
		"MoveBG::normalvariant3_map_collision_info": 0x80403c68,
		"normalvariant3_map_collision_info": 0x80403c68,
		"MoveBG::normalvariant4_map_collision_data": 0x80403c70,
		"normalvariant4_map_collision_data": 0x80403c70,
		"MoveBG::normalvariant4_map_collision_info": 0x80403c78,
		"normalvariant4_map_collision_info": 0x80403c78,
		"MoveBG::railvariant0_map_collision_data": 0x80403c80,
		"railvariant0_map_collision_data": 0x80403c80,
		"MoveBG::railvariant0_map_collision_info": 0x80403c88,
		"railvariant0_map_collision_info": 0x80403c88,
		"MoveBG::railvariant1_map_collision_data": 0x80403c90,
		"railvariant1_map_collision_data": 0x80403c90,
		"MoveBG::railvariant1_map_collision_info": 0x80403c98,
		"railvariant1_map_collision_info": 0x80403c98,
		"MoveBG::railvariant2_map_collision_data": 0x80403ca0,
		"railvariant2_map_collision_data": 0x80403ca0,
		"MoveBG::railvariant2_map_collision_info": 0x80403ca8,
		"railvariant2_map_collision_info": 0x80403ca8,
		"MoveBG::railvariant3_map_collision_data": 0x80403cb0,
		"railvariant3_map_collision_data": 0x80403cb0,
		"MoveBG::railvariant3_map_collision_info": 0x80403cb8,
		"railvariant3_map_collision_info": 0x80403cb8,
		"MoveBG::railvariant4_map_collision_data": 0x80403cc0,
		"railvariant4_map_collision_data": 0x80403cc0,
		"MoveBG::railvariant4_map_collision_info": 0x80403cc8,
		"railvariant4_map_collision_info": 0x80403cc8,
		"MoveBG::rollvariant0_map_collision_data": 0x80403cd0,
		"rollvariant0_map_collision_data": 0x80403cd0,
		"MoveBG::rollvariant0_map_collision_info": 0x80403cd8,
		"rollvariant0_map_collision_info": 0x80403cd8,
		"MoveBG::rollvariant1_map_collision_data": 0x80403ce0,
		"rollvariant1_map_collision_data": 0x80403ce0,
		"MoveBG::rollvariant1_map_collision_info": 0x80403ce8,
		"rollvariant1_map_collision_info": 0x80403ce8,
		"MoveBG::rollvariant2_map_collision_data": 0x80403cf0,
		"rollvariant2_map_collision_data": 0x80403cf0,
		"MoveBG::rollvariant2_map_collision_info": 0x80403cf8,
		"rollvariant2_map_collision_info": 0x80403cf8,
		"MoveBG::rollvariant3_map_collision_data": 0x80403d00,
		"rollvariant3_map_collision_data": 0x80403d00,
		"MoveBG::rollvariant3_map_collision_info": 0x80403d08,
		"rollvariant3_map_collision_info": 0x80403d08,
		"MoveBG::rollvariant4_map_collision_data": 0x80403d10,
		"rollvariant4_map_collision_data": 0x80403d10,
		"MoveBG::rollvariant4_map_collision_info": 0x80403d18,
		"rollvariant4_map_collision_info": 0x80403d18,
		"MoveBG::lamptrapspike_anim_info": 0x80403d20,
		"lamptrapspike_anim_info": 0x80403d20,
		"MoveBG::lamptrapiron_anim_info": 0x80403d28,
		"lamptrapiron_anim_info": 0x80403d28,
		"MoveBG::lamptrap_map_collision_data": 0x80403d30,
		"lamptrap_map_collision_data": 0x80403d30,
		"MoveBG::lamptrap_map_collision_info": 0x80403d38,
		"lamptrap_map_collision_info": 0x80403d38,
		"MoveBG::airplane_map_collision_data": 0x80403d40,
		"airplane_map_collision_data": 0x80403d40,
		"MoveBG::airplane_map_collision_info": 0x80403d48,
		"airplane_map_collision_info": 0x80403d48,
		"MoveBG::WoodBox_anim_info": 0x80403d50,
		"WoodBox_anim_info": 0x80403d50,
		"MoveBG::WoodBoxNozzle_map_collision_data": 0x80403d60,
		"WoodBoxNozzle_map_collision_data": 0x80403d60,
		"MoveBG::WoodBoxNozzle_map_collision_info": 0x80403d68,
		"WoodBoxNozzle_map_collision_info": 0x80403d68,
		"MoveBG::ice_car_anim_info": 0x80403d78,
		"ice_car_anim_info": 0x80403d78,
		"MoveBG::ice_car_map_collision_data": 0x80403d88,
		"ice_car_map_collision_data": 0x80403d88,
		"MoveBG::ice_car_map_collision_info": 0x80403d90,
		"ice_car_map_collision_info": 0x80403d90,
		"MoveBG::move_ice_car_map_collision_data": 0x80403da0,
		"move_ice_car_map_collision_data": 0x80403da0,
		"MoveBG::move_ice_car_map_collision_info": 0x80403da8,
		"move_ice_car_map_collision_info": 0x80403da8,
		"MoveBG::@3098": 0x80403db0,
		"MoveBG::AirportBuoy_map_collision_data": 0x80403db8,
		"AirportBuoy_map_collision_data": 0x80403db8,
		"MoveBG::AirportBuoy_map_collision_info": 0x80403dc0,
		"AirportBuoy_map_collision_info": 0x80403dc0,
		"MoveBG::dptKing_map_collision_info": 0x80403dd0,
		"dptKing_map_collision_info": 0x80403dd0,
		"MoveBG::KoopaJrSubmarine_map_collision_data": 0x80403dd8,
		"KoopaJrSubmarine_map_collision_data": 0x80403dd8,
		"MoveBG::KoopaJrSubmarine_map_collision_info": 0x80403de0,
		"KoopaJrSubmarine_map_collision_info": 0x80403de0,
		"MoveBG::monumentshine_anim_info": 0x80403de8,
		"monumentshine_anim_info": 0x80403de8,
		"MoveBG::belldolpic_anim_info": 0x80403df0,
		"belldolpic_anim_info": 0x80403df0,
		"MoveBG::DptWeathercock_anim_info": 0x80403df8,
		"DptWeathercock_anim_info": 0x80403df8,
		"MoveBG::DptMonteFence_map_collision_data": 0x80403e00,
		"DptMonteFence_map_collision_data": 0x80403e00,
		"MoveBG::DptMonteFence_map_collision_info": 0x80403e08,
		"DptMonteFence_map_collision_info": 0x80403e08,
		"MoveBG::DptCoronaFence_map_collision_data": 0x80403e10,
		"DptCoronaFence_map_collision_data": 0x80403e10,
		"MoveBG::DptCoronaFence_map_collision_info": 0x80403e18,
		"DptCoronaFence_map_collision_info": 0x80403e18,
		"MoveBG::MareGate_anim_info": 0x80403e20,
		"MareGate_anim_info": 0x80403e20,
		"MoveBG::NozzleDoor_anim_info": 0x80403e28,
		"NozzleDoor_anim_info": 0x80403e28,
		"MoveBG::NozzleDoor_map_collision_data": 0x80403e30,
		"NozzleDoor_map_collision_data": 0x80403e30,
		"MoveBG::NozzleDoor_map_collision_info": 0x80403e38,
		"NozzleDoor_map_collision_info": 0x80403e38,
		"MoveBG::DokanGate_anim_info": 0x80403e40,
		"DokanGate_anim_info": 0x80403e40,
		"MoveBG::@3121": 0x80403e48,
		"MoveBG::crane_map_collision_data": 0x80403e50,
		"crane_map_collision_data": 0x80403e50,
		"MoveBG::crane_map_collision_info": 0x80403e58,
		"crane_map_collision_info": 0x80403e58,
		"MoveBG::crane90Scene2_map_collision_data": 0x80403e60,
		"crane90Scene2_map_collision_data": 0x80403e60,
		"MoveBG::crane90Scene2_map_collision_info": 0x80403e68,
		"crane90Scene2_map_collision_info": 0x80403e68,
		"MoveBG::crane180Scene1_map_collision_data": 0x80403e70,
		"crane180Scene1_map_collision_data": 0x80403e70,
		"MoveBG::crane180Scene1_map_collision_info": 0x80403e78,
		"crane180Scene1_map_collision_info": 0x80403e78,
		"MoveBG::crane_updown_map_collision_data": 0x80403e80,
		"crane_updown_map_collision_data": 0x80403e80,
		"MoveBG::crane_updown_map_collision_info": 0x80403e88,
		"crane_updown_map_collision_info": 0x80403e88,
		"MoveBG::crane_cargo_map_collision_data": 0x80403e90,
		"crane_cargo_map_collision_data": 0x80403e90,
		"MoveBG::crane_cargo_map_collision_info": 0x80403e98,
		"crane_cargo_map_collision_info": 0x80403e98,
		"MoveBG::tank_map_collision_data": 0x80403ea8,
		"tank_map_collision_data": 0x80403ea8,
		"MoveBG::tank_map_collision_info": 0x80403eb0,
		"tank_map_collision_info": 0x80403eb0,
		"MoveBG::container_map_collision_data": 0x80403eb8,
		"container_map_collision_data": 0x80403eb8,
		"MoveBG::container_map_collision_info": 0x80403ec0,
		"container_map_collision_info": 0x80403ec0,
		"MoveBG::submarine_map_collision_info": 0x80403ec8,
		"submarine_map_collision_info": 0x80403ec8,
		"MoveBG::riccoShip_map_collision_data": 0x80403ed0,
		"riccoShip_map_collision_data": 0x80403ed0,
		"MoveBG::riccoShip_map_collision_info": 0x80403ed8,
		"riccoShip_map_collision_info": 0x80403ed8,
		"MoveBG::riccoLog_map_collision_data": 0x80403ee0,
		"riccoLog_map_collision_data": 0x80403ee0,
		"MoveBG::riccoLog_map_collision_info": 0x80403ee8,
		"riccoLog_map_collision_info": 0x80403ee8,
		"MoveBG::gesoSurfboard_anim_info": 0x80403ef0,
		"gesoSurfboard_anim_info": 0x80403ef0,
		"MoveBG::riccoShipLog_map_collision_data": 0x80403ef8,
		"riccoShipLog_map_collision_data": 0x80403ef8,
		"MoveBG::riccoShipLog_map_collision_info": 0x80403f00,
		"riccoShipLog_map_collision_info": 0x80403f00,
		"MoveBG::riccoShipDol_map_collision_data": 0x80403f08,
		"riccoShipDol_map_collision_data": 0x80403f08,
		"MoveBG::riccoShipDol_map_collision_info": 0x80403f10,
		"riccoShipDol_map_collision_info": 0x80403f10,
		"MoveBG::riccoYachtL_map_collision_data": 0x80403f18,
		"riccoYachtL_map_collision_data": 0x80403f18,
		"MoveBG::riccoYachtL_map_collision_info": 0x80403f20,
		"riccoYachtL_map_collision_info": 0x80403f20,
		"MoveBG::riccoYachtS_map_collision_data": 0x80403f28,
		"riccoYachtS_map_collision_data": 0x80403f28,
		"MoveBG::riccoYachtS_map_collision_info": 0x80403f30,
		"riccoYachtS_map_collision_info": 0x80403f30,
		"MoveBG::riccoBoatL_map_collision_data": 0x80403f38,
		"riccoBoatL_map_collision_data": 0x80403f38,
		"MoveBG::riccoBoatL_map_collision_info": 0x80403f40,
		"riccoBoatL_map_collision_info": 0x80403f40,
		"MoveBG::riccoBoatS_map_collision_data": 0x80403f48,
		"riccoBoatS_map_collision_data": 0x80403f48,
		"MoveBG::riccoBoatS_map_collision_info": 0x80403f50,
		"riccoBoatS_map_collision_info": 0x80403f50,
		"MoveBG::riccoBasket_map_collision_data": 0x80403f58,
		"riccoBasket_map_collision_data": 0x80403f58,
		"MoveBG::riccoBasket_map_collision_info": 0x80403f60,
		"riccoBasket_map_collision_info": 0x80403f60,
		"MoveBG::riccoGangway_map_collision_data": 0x80403f68,
		"riccoGangway_map_collision_data": 0x80403f68,
		"MoveBG::riccoGangway_map_collision_info": 0x80403f70,
		"riccoGangway_map_collision_info": 0x80403f70,
		"MoveBG::riccoShipFish_map_collision_data": 0x80403f78,
		"riccoShipFish_map_collision_data": 0x80403f78,
		"MoveBG::riccoShipFish_map_collision_info": 0x80403f80,
		"riccoShipFish_map_collision_info": 0x80403f80,
		"MoveBG::riccoShipGeso_map_collision_data": 0x80403f88,
		"riccoShipGeso_map_collision_data": 0x80403f88,
		"MoveBG::riccoShipGeso_map_collision_info": 0x80403f90,
		"riccoShipGeso_map_collision_info": 0x80403f90,
		"MoveBG::riccoSwitch_map_collision_data": 0x80403f98,
		"riccoSwitch_map_collision_data": 0x80403f98,
		"MoveBG::riccoSwitch_map_collision_info": 0x80403fa0,
		"riccoSwitch_map_collision_info": 0x80403fa0,
		"MoveBG::riccoFenceMaze_map_collision_data": 0x80403fa8,
		"riccoFenceMaze_map_collision_data": 0x80403fa8,
		"MoveBG::riccoFenceMaze_map_collision_info": 0x80403fb0,
		"riccoFenceMaze_map_collision_info": 0x80403fb0,
		"MoveBG::riccoStand_map_collision_data": 0x80403fb8,
		"riccoStand_map_collision_data": 0x80403fb8,
		"MoveBG::riccoStand_map_collision_info": 0x80403fc0,
		"riccoStand_map_collision_info": 0x80403fc0,
		"MoveBG::riccoGrille_map_collision_data": 0x80403fc8,
		"riccoGrille_map_collision_data": 0x80403fc8,
		"MoveBG::riccoGrille_map_collision_info": 0x80403fd0,
		"riccoGrille_map_collision_info": 0x80403fd0,
		"MoveBG::riccoArrow_map_collision_data": 0x80403fd8,
		"riccoArrow_map_collision_data": 0x80403fd8,
		"MoveBG::riccoArrow_map_collision_info": 0x80403fe0,
		"riccoArrow_map_collision_info": 0x80403fe0,
		"MoveBG::riccoStreetStall_map_collision_data": 0x80403fe8,
		"riccoStreetStall_map_collision_data": 0x80403fe8,
		"MoveBG::riccoStreetStall_map_collision_info": 0x80403ff0,
		"riccoStreetStall_map_collision_info": 0x80403ff0,
		"MoveBG::riccoHericopter_map_collision_data": 0x80403ff8,
		"riccoHericopter_map_collision_data": 0x80403ff8,
		"MoveBG::riccoHericopter_map_collision_info": 0x80404000,
		"riccoHericopter_map_collision_info": 0x80404000,
		"MoveBG::windmill_anim_info": 0x80404008,
		"windmill_anim_info": 0x80404008,
		"MoveBG::windmill_map_collision_data": 0x80404010,
		"windmill_map_collision_data": 0x80404010,
		"MoveBG::windmill_map_collision_info": 0x80404018,
		"windmill_map_collision_info": 0x80404018,
		"MoveBG::MiniWindmillL_map_collision_data": 0x80404020,
		"MiniWindmillL_map_collision_data": 0x80404020,
		"MoveBG::MiniWindmillL_map_collision_info": 0x80404028,
		"MiniWindmillL_map_collision_info": 0x80404028,
		"MoveBG::MiniWindmillS_map_collision_data": 0x80404030,
		"MiniWindmillS_map_collision_data": 0x80404030,
		"MoveBG::MiniWindmillS_map_collision_info": 0x80404038,
		"MiniWindmillS_map_collision_info": 0x80404038,
		"MoveBG::windmill_roof_map_collision_data": 0x80404040,
		"windmill_roof_map_collision_data": 0x80404040,
		"MoveBG::windmill_roof_map_collision_info": 0x80404048,
		"windmill_roof_map_collision_info": 0x80404048,
		"MoveBG::lamp_bianco_anim_info": 0x80404050,
		"lamp_bianco_anim_info": 0x80404050,
		"MoveBG::lamp_bianco_map_collision_info": 0x80404058,
		"lamp_bianco_map_collision_info": 0x80404058,
		"MoveBG::RootPakkun_map_collision_data": 0x80404060,
		"RootPakkun_map_collision_data": 0x80404060,
		"MoveBG::RootPakkun_map_collision_info": 0x80404068,
		"RootPakkun_map_collision_info": 0x80404068,
		"MoveBG::windmill_block_map_collision_data": 0x80404070,
		"windmill_block_map_collision_data": 0x80404070,
		"MoveBG::windmill_block_map_collision_info": 0x80404078,
		"windmill_block_map_collision_info": 0x80404078,
		"MoveBG::BiaBell_anim_info": 0x80404080,
		"BiaBell_anim_info": 0x80404080,
		"MoveBG::watermill00_anim_info": 0x80404090,
		"watermill00_anim_info": 0x80404090,
		"MoveBG::BiaWatermill01_map_collision_data": 0x80404098,
		"BiaWatermill01_map_collision_data": 0x80404098,
		"MoveBG::BiaWatermill01_map_collision_info": 0x804040a0,
		"BiaWatermill01_map_collision_info": 0x804040a0,
		"MoveBG::BiaWatermillVertical_map_collision_data": 0x804040a8,
		"BiaWatermillVertical_map_collision_data": 0x804040a8,
		"MoveBG::BiaWatermillVertical_map_collision_info": 0x804040b0,
		"BiaWatermillVertical_map_collision_info": 0x804040b0,
		"MoveBG::BiaTurnBridge_map_collision_data": 0x804040b8,
		"BiaTurnBridge_map_collision_data": 0x804040b8,
		"MoveBG::BiaTurnBridge_map_collision_info": 0x804040c0,
		"BiaTurnBridge_map_collision_info": 0x804040c0,
		"MoveBG::LeafBoat_map_collision_data": 0x804040c8,
		"LeafBoat_map_collision_data": 0x804040c8,
		"MoveBG::LeafBoat_map_collision_info": 0x804040d0,
		"LeafBoat_map_collision_info": 0x804040d0,
		"MoveBG::LampSeesaw_anim_info": 0x804040d8,
		"LampSeesaw_anim_info": 0x804040d8,
		"MoveBG::LampSeesaw_map_collision_data": 0x804040e0,
		"LampSeesaw_map_collision_data": 0x804040e0,
		"MoveBG::LampSeesaw_map_collision_info": 0x804040e8,
		"LampSeesaw_map_collision_info": 0x804040e8,
		"MoveBG::BiancoDoor_map_collision_data": 0x804040f8,
		"BiancoDoor_map_collision_data": 0x804040f8,
		"MoveBG::BiancoDoor_map_collision_info": 0x80404100,
		"BiancoDoor_map_collision_info": 0x80404100,
		"MoveBG::BiaBridge_map_collision_data": 0x80404108,
		"BiaBridge_map_collision_data": 0x80404108,
		"MoveBG::BiaBridge_map_collision_info": 0x80404110,
		"BiaBridge_map_collision_info": 0x80404110,
		"MoveBG::SandBird_anim_info": 0x80404118,
		"SandBird_anim_info": 0x80404118,
		"MoveBG::SandBirdBlock_map_collision_info": 0x80404120,
		"SandBirdBlock_map_collision_info": 0x80404120,
		"MoveBG::SkyIsland_anim_info": 0x80404128,
		"SkyIsland_anim_info": 0x80404128,
		"MoveBG::SkyIsland_map_collision_data": 0x80404130,
		"SkyIsland_map_collision_data": 0x80404130,
		"MoveBG::SkyIsland_map_collision_info": 0x80404138,
		"SkyIsland_map_collision_info": 0x80404138,
		"MoveBG::SandLeaf_anim_info": 0x80404140,
		"SandLeaf_anim_info": 0x80404140,
		"MoveBG::SandLeafBase00_anim_info": 0x80404148,
		"SandLeafBase00_anim_info": 0x80404148,
		"MoveBG::SandLeafBase00_map_collision_info": 0x80404150,
		"SandLeafBase00_map_collision_info": 0x80404150,
		"MoveBG::SandLeafBase01_anim_info": 0x80404158,
		"SandLeafBase01_anim_info": 0x80404158,
		"MoveBG::SandLeafBase01_map_collision_info": 0x80404160,
		"SandLeafBase01_map_collision_info": 0x80404160,
		"MoveBG::SandLeafBase02_anim_info": 0x80404168,
		"SandLeafBase02_anim_info": 0x80404168,
		"MoveBG::SandLeafBase02_map_collision_info": 0x80404170,
		"SandLeafBase02_map_collision_info": 0x80404170,
		"MoveBG::SandLeafBase03_anim_info": 0x80404178,
		"SandLeafBase03_anim_info": 0x80404178,
		"MoveBG::SandLeafBase03_map_collision_info": 0x80404180,
		"SandLeafBase03_map_collision_info": 0x80404180,
		"MoveBG::SandBomb_anim_info": 0x80404188,
		"SandBomb_anim_info": 0x80404188,
		"MoveBG::mirror_L_map_collision_info": 0x80404198,
		"mirror_L_map_collision_info": 0x80404198,
		"MoveBG::mirror_M_map_collision_info": 0x804041a8,
		"mirror_M_map_collision_info": 0x804041a8,
		"MoveBG::mirrorS_map_collision_info": 0x804041b8,
		"mirrorS_map_collision_info": 0x804041b8,
		"MoveBG::SandCastle_anim_info": 0x804041c0,
		"SandCastle_anim_info": 0x804041c0,
		"MoveBG::SandCastle_map_collision_info": 0x804041c8,
		"SandCastle_map_collision_info": 0x804041c8,
		"MoveBG::MammaBlockRotate_map_collision_info": 0x804041d0,
		"MammaBlockRotate_map_collision_info": 0x804041d0,
		"MoveBG::SandEgg_map_collision_data": 0x804041d8,
		"SandEgg_map_collision_data": 0x804041d8,
		"MoveBG::SandEgg_map_collision_info": 0x804041e0,
		"SandEgg_map_collision_info": 0x804041e0,
		"MoveBG::SandEggBroken_map_collision_data": 0x804041e8,
		"SandEggBroken_map_collision_data": 0x804041e8,
		"MoveBG::SandEggBroken_map_collision_info": 0x804041f0,
		"SandEggBroken_map_collision_info": 0x804041f0,
		"MoveBG::MammaSurfboardStand_map_collision_data": 0x804041f8,
		"MammaSurfboardStand_map_collision_data": 0x804041f8,
		"MoveBG::MammaSurfboardStand_map_collision_info": 0x80404200,
		"MammaSurfboardStand_map_collision_info": 0x80404200,
		"MoveBG::MammaYacht00_map_collision_data": 0x80404208,
		"MammaYacht00_map_collision_data": 0x80404208,
		"MoveBG::MammaYacht00_map_collision_info": 0x80404210,
		"MammaYacht00_map_collision_info": 0x80404210,
		"MoveBG::MammaYacht01_map_collision_data": 0x80404218,
		"MammaYacht01_map_collision_data": 0x80404218,
		"MoveBG::MammaYacht01_map_collision_info": 0x80404220,
		"MammaYacht01_map_collision_info": 0x80404220,
		"MoveBG::MammaYacht02_map_collision_data": 0x80404228,
		"MammaYacht02_map_collision_data": 0x80404228,
		"MoveBG::MammaYacht02_map_collision_info": 0x80404230,
		"MammaYacht02_map_collision_info": 0x80404230,
		"MoveBG::SandBombBase00_anim_info": 0x80404238,
		"SandBombBase00_anim_info": 0x80404238,
		"MoveBG::SandBombBase00_map_collision_info": 0x80404240,
		"SandBombBase00_map_collision_info": 0x80404240,
		"MoveBG::SandBombBaseMushroom_anim_info": 0x80404248,
		"SandBombBaseMushroom_anim_info": 0x80404248,
		"MoveBG::SandBombBaseMushroom_map_collision_info": 0x80404250,
		"SandBombBaseMushroom_map_collision_info": 0x80404250,
		"MoveBG::SandBombBasePyramid_anim_info": 0x80404258,
		"SandBombBasePyramid_anim_info": 0x80404258,
		"MoveBG::SandBombBasePyramid_map_collision_info": 0x80404260,
		"SandBombBasePyramid_map_collision_info": 0x80404260,
		"MoveBG::SandBombBaseShit_anim_info": 0x80404268,
		"SandBombBaseShit_anim_info": 0x80404268,
		"MoveBG::SandBombBaseShit_map_collision_info": 0x80404270,
		"SandBombBaseShit_map_collision_info": 0x80404270,
		"MoveBG::SandBombBaseStar_anim_info": 0x80404278,
		"SandBombBaseStar_anim_info": 0x80404278,
		"MoveBG::SandBombBaseStar_map_collision_info": 0x80404280,
		"SandBombBaseStar_map_collision_info": 0x80404280,
		"MoveBG::SandBombBaseTurtle_anim_info": 0x80404288,
		"SandBombBaseTurtle_anim_info": 0x80404288,
		"MoveBG::SandBombBaseTurtle_map_collision_info": 0x80404290,
		"SandBombBaseTurtle_map_collision_info": 0x80404290,
		"MoveBG::SandBombBaseFoot_anim_info": 0x80404298,
		"SandBombBaseFoot_anim_info": 0x80404298,
		"MoveBG::SandBombBaseFoot_map_collision_info": 0x804042a0,
		"SandBombBaseFoot_map_collision_info": 0x804042a0,
		"MoveBG::SandBombBaseHand_anim_info": 0x804042a8,
		"SandBombBaseHand_anim_info": 0x804042a8,
		"MoveBG::SandBombBaseHand_map_collision_info": 0x804042b0,
		"SandBombBaseHand_map_collision_info": 0x804042b0,
		"MoveBG::SandBombBaseStairs_anim_info": 0x804042b8,
		"SandBombBaseStairs_anim_info": 0x804042b8,
		"MoveBG::SandBombBaseStairs_map_collision_info": 0x804042c0,
		"SandBombBaseStairs_map_collision_info": 0x804042c0,
		"MoveBG::TeethOfJuicer_anim_info": 0x804042d8,
		"TeethOfJuicer_anim_info": 0x804042d8,
		"MoveBG::SandEggRepair_map_collision_data": 0x804042e0,
		"SandEggRepair_map_collision_data": 0x804042e0,
		"MoveBG::SandEggRepair_map_collision_info": 0x804042e8,
		"SandEggRepair_map_collision_info": 0x804042e8,
		"MoveBG::merrygoround_anim_info": 0x804042f8,
		"merrygoround_anim_info": 0x804042f8,
		"MoveBG::merrygoround_map_collision_data": 0x80404300,
		"merrygoround_map_collision_data": 0x80404300,
		"MoveBG::merrygoround_map_collision_info": 0x80404308,
		"merrygoround_map_collision_info": 0x80404308,
		"MoveBG::merry_egg_map_collision_data": 0x80404310,
		"merry_egg_map_collision_data": 0x80404310,
		"MoveBG::merry_egg_map_collision_info": 0x80404318,
		"merry_egg_map_collision_info": 0x80404318,
		"MoveBG::FerrisWheel_anim_info": 0x80404320,
		"FerrisWheel_anim_info": 0x80404320,
		"MoveBG::gondola_map_collision_data": 0x80404328,
		"gondola_map_collision_data": 0x80404328,
		"MoveBG::gondola_map_collision_info": 0x80404330,
		"gondola_map_collision_info": 0x80404330,
		"MoveBG::FerrisLOD_anim_info": 0x80404338,
		"FerrisLOD_anim_info": 0x80404338,
		"MoveBG::viking_map_collision_data": 0x80404348,
		"viking_map_collision_data": 0x80404348,
		"MoveBG::viking_map_collision_info": 0x80404350,
		"viking_map_collision_info": 0x80404350,
		"MoveBG::PinnaEntrance_map_collision_data": 0x80404358,
		"PinnaEntrance_map_collision_data": 0x80404358,
		"MoveBG::PinnaEntrance_map_collision_info": 0x80404360,
		"PinnaEntrance_map_collision_info": 0x80404360,
		"MoveBG::PinnaEntranceOpen_map_collision_data": 0x80404368,
		"PinnaEntranceOpen_map_collision_data": 0x80404368,
		"MoveBG::PinnaEntranceOpen_map_collision_info": 0x80404370,
		"PinnaEntranceOpen_map_collision_info": 0x80404370,
		"MoveBG::SirenaGate_map_collision_data": 0x80404378,
		"SirenaGate_map_collision_data": 0x80404378,
		"MoveBG::SirenaGate_map_collision_info": 0x80404380,
		"SirenaGate_map_collision_info": 0x80404380,
		"MoveBG::balloon_koopajr_anim_info": 0x80404388,
		"balloon_koopajr_anim_info": 0x80404388,
		"MoveBG::ShellCup_anim_info": 0x80404390,
		"ShellCup_anim_info": 0x80404390,
		"MoveBG::ShellCup_map_collision_data": 0x80404398,
		"ShellCup_map_collision_data": 0x80404398,
		"MoveBG::ShellCup_map_collision_info": 0x804043a0,
		"ShellCup_map_collision_info": 0x804043a0,
		"MoveBG::Gateshell_anim_info": 0x804043a8,
		"Gateshell_anim_info": 0x804043a8,
		"MoveBG::Gateshell_map_collision_data": 0x804043b0,
		"Gateshell_map_collision_data": 0x804043b0,
		"MoveBG::Gateshell_map_collision_info": 0x804043b8,
		"Gateshell_map_collision_info": 0x804043b8,
		"MoveBG::PinnaHangingBridgeBoard_anim_info": 0x804043c0,
		"PinnaHangingBridgeBoard_anim_info": 0x804043c0,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_data": 0x804043c8,
		"PinnaHangingBridgeBoard_map_collision_data": 0x804043c8,
		"MoveBG::PinnaHangingBridgeBoard_map_collision_info": 0x804043d0,
		"PinnaHangingBridgeBoard_map_collision_info": 0x804043d0,
		"MoveBG::GateManta_anim_info": 0x804043d8,
		"GateManta_anim_info": 0x804043d8,
		"MoveBG::AmiKing_anim_info": 0x804043e0,
		"AmiKing_anim_info": 0x804043e0,
		"MoveBG::@3291": 0x804043e8,
		"MoveBG::casinoroulette_map_collision_data": 0x804043f8,
		"casinoroulette_map_collision_data": 0x804043f8,
		"MoveBG::casinoroulette_map_collision_info": 0x80404400,
		"casinoroulette_map_collision_info": 0x80404400,
		"MoveBG::@3295": 0x80404408,
		"MoveBG::roulette_anim_info": 0x80404410,
		"roulette_anim_info": 0x80404410,
		"MoveBG::roulette00_map_collision_data": 0x80404418,
		"roulette00_map_collision_data": 0x80404418,
		"MoveBG::roulette00_map_collision_info": 0x80404420,
		"roulette00_map_collision_info": 0x80404420,
		"MoveBG::roulette01_map_collision_data": 0x80404430,
		"roulette01_map_collision_data": 0x80404430,
		"MoveBG::roulette01_map_collision_info": 0x80404438,
		"roulette01_map_collision_info": 0x80404438,
		"MoveBG::roulette02_map_collision_data": 0x80404448,
		"roulette02_map_collision_data": 0x80404448,
		"MoveBG::roulette02_map_collision_info": 0x80404450,
		"roulette02_map_collision_info": 0x80404450,
		"MoveBG::pazul_map_collision_data": 0x80404470,
		"pazul_map_collision_data": 0x80404470,
		"MoveBG::pazul_map_collision_info": 0x80404478,
		"pazul_map_collision_info": 0x80404478,
		"MoveBG::bosswall_anim_info": 0x80404480,
		"bosswall_anim_info": 0x80404480,
		"MoveBG::casinoroof_anim_info": 0x80404488,
		"casinoroof_anim_info": 0x80404488,
		"MoveBG::GlassBreak_anim_info": 0x80404490,
		"GlassBreak_anim_info": 0x80404490,
		"MoveBG::GlassBreak_map_collision_data": 0x80404498,
		"GlassBreak_map_collision_data": 0x80404498,
		"MoveBG::GlassBreak_map_collision_info": 0x804044a0,
		"GlassBreak_map_collision_info": 0x804044a0,
		"MoveBG::GlassBreak_sound_info": 0x804044a8,
		"GlassBreak_sound_info": 0x804044a8,
		"MoveBG::closet_anim_info": 0x804044b0,
		"closet_anim_info": 0x804044b0,
		"MoveBG::ChestRevolve_anim_info": 0x804044c0,
		"ChestRevolve_anim_info": 0x804044c0,
		"MoveBG::ChestRevolve_map_collision_info": 0x804044c8,
		"ChestRevolve_map_collision_info": 0x804044c8,
		"MoveBG::PosterTeresa_map_collision_data": 0x804044d0,
		"PosterTeresa_map_collision_data": 0x804044d0,
		"MoveBG::PosterTeresa_map_collision_info": 0x804044d8,
		"PosterTeresa_map_collision_info": 0x804044d8,
		"MoveBG::PictureTeresa_map_collision_data": 0x804044e0,
		"PictureTeresa_map_collision_data": 0x804044e0,
		"MoveBG::PictureTeresa_map_collision_info": 0x804044e8,
		"PictureTeresa_map_collision_info": 0x804044e8,
		"MoveBG::PanelBreak_anim_info": 0x804044f0,
		"PanelBreak_anim_info": 0x804044f0,
		"MoveBG::PanelBreak_map_collision_data": 0x804044f8,
		"PanelBreak_map_collision_data": 0x804044f8,
		"MoveBG::PanelBreak_map_collision_info": 0x80404500,
		"PanelBreak_map_collision_info": 0x80404500,
		"MoveBG::PanelBreak_sound_info": 0x80404508,
		"PanelBreak_sound_info": 0x80404508,
		"MoveBG::PanelRevolve_anim_info": 0x80404510,
		"PanelRevolve_anim_info": 0x80404510,
		"MoveBG::PanelRevolve_map_collision_data": 0x80404518,
		"PanelRevolve_map_collision_data": 0x80404518,
		"MoveBG::PanelRevolve_map_collision_info": 0x80404520,
		"PanelRevolve_map_collision_info": 0x80404520,
		"MoveBG::SirenaShop_map_collision_data": 0x80404528,
		"SirenaShop_map_collision_data": 0x80404528,
		"MoveBG::SirenaShop_map_collision_info": 0x80404530,
		"SirenaShop_map_collision_info": 0x80404530,
		"MoveBG::cogwheel_anim_info": 0x80404538,
		"cogwheel_anim_info": 0x80404538,
		"MoveBG::cogwheel_map_collision_data": 0x80404540,
		"cogwheel_map_collision_data": 0x80404540,
		"MoveBG::cogwheel_map_collision_info": 0x80404548,
		"cogwheel_map_collision_info": 0x80404548,
		"MoveBG::CogwheelPlate_map_collision_data": 0x80404550,
		"CogwheelPlate_map_collision_data": 0x80404550,
		"MoveBG::CogwheelPlate_map_collision_info": 0x80404558,
		"CogwheelPlate_map_collision_info": 0x80404558,
		"MoveBG::CogwheelPot_map_collision_data": 0x80404560,
		"CogwheelPot_map_collision_data": 0x80404560,
		"MoveBG::CogwheelPot_map_collision_info": 0x80404568,
		"CogwheelPot_map_collision_info": 0x80404568,
		"MoveBG::@3338": 0x80404570,
		"MoveBG::mare_float_house_map_collision_data": 0x80404578,
		"mare_float_house_map_collision_data": 0x80404578,
		"MoveBG::mare_float_house_map_collision_info": 0x80404580,
		"mare_float_house_map_collision_info": 0x80404580,
		"MoveBG::StopRock_map_collision_data": 0x80404588,
		"StopRock_map_collision_data": 0x80404588,
		"MoveBG::StopRock_map_collision_info": 0x80404590,
		"StopRock_map_collision_info": 0x80404590,
		"MoveBG::GrowthTree_anim_info": 0x80404598,
		"GrowthTree_anim_info": 0x80404598,
		"MoveBG::@3344": 0x804045a0,
		"MoveBG::GrowthTree_map_collision_data": 0x804045a8,
		"GrowthTree_map_collision_data": 0x804045a8,
		"MoveBG::GrowthTree_map_collision_info": 0x804045b0,
		"GrowthTree_map_collision_info": 0x804045b0,
		"MoveBG::MuddyBoat_anim_info": 0x804045b8,
		"MuddyBoat_anim_info": 0x804045b8,
		"MoveBG::MuddyBoat_map_collision_data": 0x804045c0,
		"MuddyBoat_map_collision_data": 0x804045c0,
		"MoveBG::MuddyBoat_map_collision_info": 0x804045c8,
		"MuddyBoat_map_collision_info": 0x804045c8,
		"MoveBG::Puncher_anim_info": 0x804045d0,
		"Puncher_anim_info": 0x804045d0,
		"MoveBG::HatoPop_anim_info": 0x804045e0,
		"HatoPop_anim_info": 0x804045e0,
		"MoveBG::@3357": 0x804045e8,
		"MoveBG::MareWaterJump_map_collision_data": 0x804045f0,
		"MareWaterJump_map_collision_data": 0x804045f0,
		"MoveBG::MareWaterJump_map_collision_info": 0x804045f8,
		"MareWaterJump_map_collision_info": 0x804045f8,
		"MoveBG::CoinFish_anim_info": 0x80404600,
		"CoinFish_anim_info": 0x80404600,
		"MoveBG::MareFall_anim_info": 0x80404608,
		"MareFall_anim_info": 0x80404608,
		"MoveBG::MareCork_map_collision_data": 0x80404610,
		"MareCork_map_collision_data": 0x80404610,
		"MoveBG::MareCork_map_collision_info": 0x80404618,
		"MareCork_map_collision_info": 0x80404618,
		"MoveBG::MonteRoot_anim_info": 0x80404620,
		"MonteRoot_anim_info": 0x80404620,
		"MoveBG::JumpMushroom_anim_info": 0x80404628,
		"JumpMushroom_anim_info": 0x80404628,
		"MoveBG::JumpMushroom_map_collision_data": 0x80404630,
		"JumpMushroom_map_collision_data": 0x80404630,
		"MoveBG::JumpMushroom_map_collision_info": 0x80404638,
		"JumpMushroom_map_collision_info": 0x80404638,
		"MoveBG::MonteGoalFlag_anim_info": 0x80404640,
		"MonteGoalFlag_anim_info": 0x80404640,
		"MoveBG::HangingBridgeBoard_anim_info": 0x80404648,
		"HangingBridgeBoard_anim_info": 0x80404648,
		"MoveBG::HangingBridgeBoard_map_collision_data": 0x80404658,
		"HangingBridgeBoard_map_collision_data": 0x80404658,
		"MoveBG::HangingBridgeBoard_map_collision_info": 0x80404660,
		"HangingBridgeBoard_map_collision_info": 0x80404660,
		"MoveBG::SwingBoard_map_collision_data": 0x80404668,
		"SwingBoard_map_collision_data": 0x80404668,
		"MoveBG::SwingBoard_map_collision_info": 0x80404670,
		"SwingBoard_map_collision_info": 0x80404670,
		"MoveBG::Fluff_anim_info": 0x80404678,
		"Fluff_anim_info": 0x80404678,
		"MoveBG::Bathtub_anim_info": 0x80404688,
		"Bathtub_anim_info": 0x80404688,
		"MoveBG::BathtubStandBreaking_anim_info": 0x804046a0,
		"BathtubStandBreaking_anim_info": 0x804046a0,
		"MoveBG::ex1_turn_lift_anim_info": 0x804046a8,
		"ex1_turn_lift_anim_info": 0x804046a8,
		"MoveBG::ex1_turn_lift_map_collision_data": 0x804046b0,
		"ex1_turn_lift_map_collision_data": 0x804046b0,
		"MoveBG::ex1_turn_lift_map_collision_info": 0x804046b8,
		"ex1_turn_lift_map_collision_info": 0x804046b8,
		"MoveBG::z_turn_disk_map_collision_data": 0x804046c0,
		"z_turn_disk_map_collision_data": 0x804046c0,
		"MoveBG::z_turn_disk_map_collision_info": 0x804046c8,
		"z_turn_disk_map_collision_info": 0x804046c8,
		"MoveBG::y_turn_lift_anim_info": 0x804046d0,
		"y_turn_lift_anim_info": 0x804046d0,
		"MoveBG::y_turn_lift_map_collision_data": 0x804046d8,
		"y_turn_lift_map_collision_data": 0x804046d8,
		"MoveBG::y_turn_lift_map_collision_info": 0x804046e0,
		"y_turn_lift_map_collision_info": 0x804046e0,
		"MoveBG::Nail_anim_info": 0x804046e8,
		"Nail_anim_info": 0x804046e8,
		"MoveBG::Nail_map_collision_data": 0x804046f8,
		"Nail_map_collision_data": 0x804046f8,
		"MoveBG::Nail_map_collision_info": 0x80404700,
		"Nail_map_collision_info": 0x80404700,
		"MoveBG::PachinkoNail_anim_info": 0x80404708,
		"PachinkoNail_anim_info": 0x80404708,
		"MoveBG::PachinkoNail_map_collision_data": 0x80404710,
		"PachinkoNail_map_collision_data": 0x80404710,
		"MoveBG::PachinkoNail_map_collision_info": 0x80404718,
		"PachinkoNail_map_collision_info": 0x80404718,
		"MoveBG::FileLoadBlock_map_collision_data": 0x80404720,
		"FileLoadBlock_map_collision_data": 0x80404720,
		"MoveBG::FileLoadBlock_map_collision_info": 0x80404728,
		"FileLoadBlock_map_collision_info": 0x80404728,
		"MoveBG::FileLoadBlockA_anim_info": 0x80404730,
		"FileLoadBlockA_anim_info": 0x80404730,
		"MoveBG::FileLoadBlockB_anim_info": 0x80404738,
		"FileLoadBlockB_anim_info": 0x80404738,
		"MoveBG::FileLoadBlockC_anim_info": 0x80404740,
		"FileLoadBlockC_anim_info": 0x80404740,
		"MoveBG::@3910": 0x8040474c,
		"MoveBG::@3969": 0x80404754,
		"MoveBG::@4008": 0x80404758,
		"MoveBG::@3676": 0x80404790,
		"MoveBG::@3727": 0x80404794,
		"MoveBG::@3738": 0x80404798,
		"MoveBG::@3651": 0x80404828,
		"MoveBG::@4224": 0x80404838,
		"MoveBG::@4629": 0x80404b10,
		"MoveBG::@3439": 0x80404bac,
		"MoveBG::@3654": 0x80404bb0,
		"MoveBG::@3655": 0x80404bb4,
		"MoveBG::@3656": 0x80404bb8,
		"MoveBG::@3657": 0x80404bbc,
		"MoveBG::@4230": 0x80404c30,
		"MoveBG::@4231": 0x80404c34,
		"MoveBG::@4233": 0x80404c3c,
		"MoveBG::@4755": 0x80404c8c,
		"MoveBG::@4969": 0x80404cac,
		"MoveBG::@4970": 0x80404cb0,
		"MoveBG::@4972": 0x80404cb4,
		"MoveBG::@4133": 0x80404e70,
		"MoveBG::@4136": 0x80404e7c,
		"MoveBG::@4137": 0x80404e80,
		"MoveBG::@4138": 0x80404e84,
		"MoveBG::@4139": 0x80404e88,
		"MoveBG::@2393": 0x80404ea4,
		"MoveBG::@2394": 0x80404ea8,
		"MoveBG::@2646": 0x80404ef8,
		"MoveBG::@2647": 0x80404efc,
		"MoveBG::@2648": 0x80404f00,
		"MoveBG::@2676": 0x80404f20,
		"MoveBG::@2677": 0x80404f24,
		"MoveBG::@2681": 0x80404f30,
		"MoveBG::@2682": 0x80404f34,
		"MoveBG::@2687": 0x80404f48,
		"MoveBG::@2689": 0x80404f50,
		"MoveBG::@2465": 0x80404f80,
		"MoveBG::@2466": 0x80404f88,
		"@2466": 0x80404f88,
		"MoveBG::@2512": 0x80404f90,
		"MoveBG::@2633": 0x80404fa4,
		"MoveBG::@2705": 0x80404fbc,
		"MoveBG::@3689": 0x80405048,
		"MoveBG::@4727": 0x80405068,
		"MoveBG::@4728": 0x8040506c,
		"MoveBG::@4729": 0x80405070,
		"MoveBG::@4730": 0x80405074,
		"MoveBG::@4731": 0x80405078,
		"MoveBG::@4732": 0x8040507c,
		"MoveBG::@4733": 0x80405080,
		"MoveBG::@4734": 0x80405084,
		"MoveBG::@2453": 0x80405140,
		"MoveBG::@2620": 0x8040514c,
		"MoveBG::@2621": 0x80405150,
		"MoveBG::@2622": 0x80405154,
		"MoveBG::@2623": 0x80405158,
		"MoveBG::@2186": 0x80405168,
		"MoveBG::@2263": 0x8040516c,
		"MoveBG::@2279": 0x80405170,
		"MoveBG::@2303": 0x80405174,
		"MoveBG::@2574": 0x80405180,
		"MoveBG::@3681": 0x8040525c,
		"MoveBG::@3682": 0x80405260,
		"@3682": 0x80405260,
		"MoveBG::@2671": 0x80405288,
		"MoveBG::@3442": 0x80405324,
		"MoveBG::@3443": 0x80405328,
		"MoveBG::@3444": 0x8040532c,
		"MoveBG::@3445": 0x80405330,
		"MoveBG::@3446": 0x80405334,
		"MoveBG::@2668": 0x80405428,
		"MoveBG::@2697": 0x80405434,
		"MoveBG::@2702": 0x80405444,
		"MoveBG::@2713": 0x8040545c,
		"MoveBG::@5980": 0x80405568,
		"@5980": 0x80405568,
		"MoveBG::@5988": 0x80405580,
		"MoveBG::@5994": 0x8040558c,
		"Map::@3002": 0x80402fb8,
		"Map::@3209": 0x80402fbc,
		"Map::@3210": 0x80402fc0,
		"Map::@3211": 0x80402fc4,
		"Map::@3508": 0x80402fc8,
		"Map::@2050": 0x80402fd0,
		"Map::@2904": 0x80402fd8,
		"Map::@2905": 0x80402fdc,
		"Map::@2906": 0x80402fe0,
		"Map::@3158": 0x80402ff0,
		"Map::@3159": 0x80402ff4,
		"Map::@3160": 0x80402ff8,
		"Map::@3161": 0x80402ffc,
		"Map::@3196": 0x80403000,
		"Map::@3255": 0x80403004,
		"Map::@3256": 0x80403008,
		"Map::@3279": 0x8040300c,
		"Map::@2183": 0x80403010,
		"Map::@2184": 0x80403014,
		"Map::@2185": 0x80403018,
		"Map::@2221": 0x8040301c,
		"Map::@1871": 0x80403028,
		"Map::@2017": 0x8040302c,
		"Map::@1838": 0x80403038,
		"@1838": 0x80403038,
		"Map::@1839": 0x8040303c,
		"Map::@1840": 0x80403040,
		"Map::@1841": 0x80403048,
		"Map::@3152": 0x80403058,
		"Map::@3153": 0x8040305c,
		"Map::@2976": 0x80403088,
		"Map::@2088": 0x80403090,
		"Map::@2089": 0x80403094,
		"Map::@2207": 0x804030a0,
		"Map::@2841": 0x804030c0,
		"Map::@3181": 0x804030d0,
		"Map::@3182": 0x804030d4,
		"Map::@3183": 0x804030d8,
		"Map::@2429": 0x804030e0,
		"Map::@2430": 0x804030e4,
		"Map::@2431": 0x804030ec,
		"Map::@2432": 0x804030f4,
		"Map::@2505": 0x804030fc,
		"Map::@2506": 0x80403100,
		"Map::@2640": 0x80403158,
		"Map::@2643": 0x80403170,
		"Map::@2644": 0x80403178,
		"Map::@2645": 0x80403180,
		"Map::@2646": 0x80403188,
		"Map::@2648": 0x80403198,
		"Map::@2569": 0x804031f4,
		"Map::@2570": 0x804031f8,
		"Map::@2572": 0x80403200,
		"Map::@2573": 0x80403204,
		"Map::@2574": 0x80403208,
		"Map::@2575": 0x8040320c,
		"Map::@2577": 0x80403214,
		"Map::@2578": 0x80403218,
		"Map::@2547": 0x8040326c,
		"Map::@2610": 0x8040327c,
		"Map::@2863": 0x80403290,
		"Map::@2958": 0x80403294,
		"Map::@3188": 0x804032a0,
		"Map::@2849": 0x804032a8,
		"Map::@2850": 0x804032ac,
		"Map::@2851": 0x804032b0,
		"Map::@2852": 0x804032b4,
		"Map::@2390": 0x804032c0,
		"Map::@2392": 0x804032c4,
		"Map::@2396": 0x804032c8,
		"Map::@2460": 0x804032cc,
		"Map::@2788": 0x804032f0,
		"Map::@2790": 0x804032f8,
		"Map::@2865": 0x80403304,
		"Map::@2866": 0x80403308,
		"Map::@2785": 0x80403314,
		"Map::@2352": 0x80403344,
		"Map::@2353": 0x80403348,
		"Map::@1992": 0x80403360,
		"Map::@1993": 0x80403364,
		"Map::@2926": 0x8040338c,
		"Map::@2927": 0x80403390,
		"Map::@2928": 0x80403394,
		"Map::@3135": 0x804033d4,
		"Map::@3136": 0x804033d8,
		"Map::@3169": 0x804033dc,
		"Map::@3258": 0x804033e0,
		"Map::@3272": 0x804033e8,
		"Map::@3290": 0x804033f0,
		"Map::@3291": 0x804033f8,
		"Map::@3292": 0x804033fc,
		"Map::@3397": 0x80403408,
		"Map::@3400": 0x80403420,
		"Map::@3401": 0x80403424,
		"Map::@3402": 0x80403428,
		"Map::@3700": 0x8040342c,
		"Map::@3760": 0x80403430,
		"Map::@3761": 0x80403434,
		"Map::@3762": 0x80403438,
		"Map::@3763": 0x8040343c,
		"Map::@3764": 0x80403440,
		"Map::@3765": 0x80403444,
		"Map::@3766": 0x80403448,
		"Map::@3767": 0x8040344c,
		"Map::@3768": 0x80403450,
		"Map::@3769": 0x80403454,
		"Map::@3770": 0x80403458,
		"Map::@3771": 0x8040345c,
		"Map::@3772": 0x80403460,
		"Map::@3773": 0x80403464,
		"Map::@3774": 0x80403468,
		"Map::@3775": 0x8040346c,
		"Map::@3776": 0x80403470,
		"Map::@3777": 0x80403474,
		"Map::@3778": 0x80403478,
		"Map::@3779": 0x8040347c,
		"Map::@3780": 0x80403480,
		"Map::@3781": 0x80403484,
		"Map::@3782": 0x80403488,
		"Map::@3783": 0x8040348c,
		"Map::@3784": 0x80403490,
		"Map::@3785": 0x80403494,
		"Map::@3786": 0x80403498,
		"Map::@3787": 0x8040349c,
		"Map::@3788": 0x804034a0,
		"Map::@3789": 0x804034a4,
		"Map::@2566": 0x804034b4,
		"Map::@2567": 0x804034b8,
		"Map::@3413": 0x804034cc,
		"Map::@3414": 0x804034d0,
		"Map::@3419": 0x804034e4,
		"Map::@3420": 0x804034e8,
		"Map::@3421": 0x804034ec,
		"Map::@3422": 0x804034f0,
		"Map::@3843": 0x80403520,
		"Map::@3844": 0x80403524,
		"Map::@4740": 0x8040356c,
		"Map::@4741": 0x80403574,
		"Map::@4759": 0x8040359c,
		"Map::@4842": 0x804035bc,
		"Map::@4846": 0x804035d0,
		"Map::@4847": 0x804035d4,
		"Map::@4848": 0x804035dc,
		"Map::@4851": 0x804035e8,
		"GC2D::@1680": 0x80402768,
		"GC2D::@1644": 0x80402778,
		"GC2D::@2120": 0x804027a8,
		"GC2D::@2375": 0x804027b0,
		"TGCConsole2::height$localstatic0$drawWater": 0x804027cc,
		"height$localstatic0$drawWater": 0x804027cc,
		"TGCConsole2::topDiff$localstatic1$drawWater": 0x804027d4,
		"topDiff$localstatic1$drawWater": 0x804027d4,
		"GC2D::@2720": 0x80402868,
		"GC2D::@2721": 0x80402870,
		"GC2D::@1549": 0x804028f0,
		"GC2D::@1550": 0x804028f4,
		"GC2D::@1551": 0x804028f8,
		"GC2D::@1552": 0x804028fc,
		"GC2D::@1553": 0x80402900,
		"GC2D::@2667": 0x8040294c,
		"GC2D::@2668": 0x80402950,
		"GC2D::@2669": 0x80402954,
		"GC2D::@2670": 0x80402958,
		"GC2D::@2671": 0x8040295c,
		"GC2D::@2672": 0x80402960,
		"GC2D::@2673": 0x80402964,
		"GC2D::@2674": 0x80402968,
		"GC2D::@3222": 0x804029b0,
		"GC2D::@3223": 0x804029b4,
		"GC2D::@3224": 0x804029b8,
		"GC2D::@3225": 0x804029bc,
		"GC2D::@1995": 0x804029e8,
		"GC2D::@1996": 0x804029ec,
		"GC2D::@2809": 0x80402c0c,
		"GC2D::@2878": 0x80402c10,
		"GC2D::@2879": 0x80402c14,
		"GC2D::@2392": 0x80402c70,
		"GC2D::@2393": 0x80402c74,
		"GC2D::@2394": 0x80402c78,
		"GC2D::@3119": 0x80402cb4,
		"GC2D::@1912": 0x80402cc0,
		"GC2D::@1913": 0x80402cc4,
		"GC2D::@2032": 0x80402ccc,
		"GC2D::@2033": 0x80402cd0,
		"GC2D::@2034": 0x80402cd4,
		"GC2D::@2035": 0x80402cd8,
		"GC2D::@2036": 0x80402cdc,
		"GC2D::@2037": 0x80402ce0,
		"GC2D::@2220": 0x80402cfc,
		"GC2D::@2488": 0x80402d0c,
		"GC2D::@2489": 0x80402d10,
		"GC2D::@2490": 0x80402d14,
		"GC2D::@2514": 0x80402d18,
		"GC2D::@2515": 0x80402d1c,
		"GC2D::@1505": 0x80402d20,
		"GC2D::@1507": 0x80402d24,
		"@1507": 0x80402d24,
		"GC2D::@1844": 0x80402de0,
		"@1844": 0x80402de0,
		"GC2D::@1684": 0x80402e00,
		"GC2D::@114": 0x80402e10,
		"GC2D::@1134": 0x80402ee8,
		"@1134": 0x80402ee8,
		"@unnamed@::cLongHeightMovieIdList": 0x80402f38,
		"cLongHeightMovieIdList": 0x80402f38,
		"@unnamed@::cStopRumbleAnm": 0x80402f50,
		"cStopRumbleAnm": 0x80402f50,
		"@unnamed@::cRumbleToggleItems": 0x80402f58,
		"cRumbleToggleItems": 0x80402f58,
		"GC2D::@1558": 0x80402fa8,
		"GC2D::@1580": 0x80402fb0,
		"Enemy::@4578": 0x80400110,
		"Enemy::@2718": 0x80400118,
		"Enemy::@2800": 0x80400288,
		"Enemy::@2802": 0x80400298,
		"Enemy::@2824": 0x8040031c,
		"Enemy::@2849": 0x804003d4,
		"Enemy::@2856": 0x8040040c,
		"Enemy::@3205": 0x804004dc,
		"Enemy::@3678": 0x80400600,
		"@3678": 0x80400600,
		"Enemy::@5337": 0x80400684,
		"Enemy::mFireHamNoseColorStart": 0x804006d0,
		"mFireHamNoseColorStart": 0x804006d0,
		"Enemy::mFireHamNoseColorEnd": 0x804006d8,
		"mFireHamNoseColorEnd": 0x804006d8,
		"Enemy::mFireHamOtherColorStart": 0x804006e0,
		"mFireHamOtherColorStart": 0x804006e0,
		"Enemy::mFireHamOtherColorEnd": 0x804006e8,
		"mFireHamOtherColorEnd": 0x804006e8,
		"Enemy::@6521": 0x80400790,
		"Enemy::@2402": 0x804009b0,
		"Enemy::@2403": 0x804009b4,
		"Enemy::@2404": 0x804009b8,
		"Enemy::@1602": 0x804009c4,
		"Enemy::@1603": 0x804009c8,
		"Enemy::@1630": 0x804009cc,
		"Enemy::@2245": 0x804009e4,
		"Enemy::@4121": 0x80400b98,
		"Enemy::@4317": 0x80400ba8,
		"@4317": 0x80400ba8,
		"Enemy::cTelesaColorStart": 0x80400be8,
		"cTelesaColorStart": 0x80400be8,
		"@unnamed@::cBodyColorOnFire": 0x80400c88,
		"cBodyColorOnFire": 0x80400c88,
		"@unnamed@::cBodyColorOnCool": 0x80400c90,
		"cBodyColorOnCool": 0x80400c90,
		"@unnamed@::cBodyColorOnSilver": 0x80400c98,
		"cBodyColorOnSilver": 0x80400c98,
		"Enemy::@5383": 0x80400cfc,
		"@5383": 0x80400cfc,
		"Enemy::@5385": 0x80400d04,
		"@5385": 0x80400d04,
		"Enemy::@7892": 0x80400d58,
		"@7892": 0x80400d58,
		"Enemy::@9121": 0x80400d70,
		"@9121": 0x80400d70,
		"Enemy::@9130": 0x80400d78,
		"@9130": 0x80400d78,
		"Enemy::@9149": 0x80400d88,
		"@9149": 0x80400d88,
		"Enemy::@1696": 0x80400d98,
		"@1696": 0x80400d98,
		"Enemy::@2231": 0x80400db0,
		"Enemy::@2232": 0x80400db4,
		"Enemy::@2299": 0x80400db8,
		"Enemy::@7468": 0x80400e68,
		"@7468": 0x80400e68,
		"Enemy::@7469": 0x80400e6c,
		"@7469": 0x80400e6c,
		"Enemy::@7470": 0x80400e70,
		"@7470": 0x80400e70,
		"Enemy::@8328": 0x80400ea0,
		"Enemy::@8337": 0x80400ea8,
		"Enemy::@3406": 0x80400ecc,
		"Enemy::@5924": 0x80401420,
		"@5924": 0x80401420,
		"Enemy::@5926": 0x80401428,
		"@5926": 0x80401428,
		"Enemy::@5928": 0x80401430,
		"@5928": 0x80401430,
		"Enemy::@5929": 0x80401434,
		"@5929": 0x80401434,
		"Enemy::@5930": 0x80401438,
		"@5930": 0x80401438,
		"Enemy::@6816": 0x80401480,
		"@6816": 0x80401480,
		"Enemy::@8021": 0x804014a0,
		"@8021": 0x804014a0,
		"Enemy::@8022": 0x804014a4,
		"@8022": 0x804014a4,
		"Enemy::@8023": 0x804014a8,
		"Enemy::@8024": 0x804014ac,
		"@8024": 0x804014ac,
		"Enemy::@8025": 0x804014b0,
		"@8025": 0x804014b0,
		"Enemy::@8026": 0x804014b4,
		"@8026": 0x804014b4,
		"Enemy::@8750": 0x804014c8,
		"@8750": 0x804014c8,
		"Enemy::@4926": 0x804015e8,
		"Enemy::@4927": 0x804015ec,
		"Enemy::@4930": 0x804015f8,
		"Enemy::@6157": 0x80401664,
		"Enemy::@6170": 0x80401670,
		"Enemy::@4678": 0x804016d8,
		"Enemy::@4204": 0x80401870,
		"Enemy::@4206": 0x80401878,
		"Enemy::@4208": 0x80401880,
		"Enemy::@4209": 0x80401884,
		"Enemy::@2022": 0x804018a8,
		"Enemy::@2023": 0x804018ac,
		"Enemy::@2024": 0x804018b0,
		"Enemy::@2025": 0x804018b4,
		"Enemy::@4239": 0x804019b0,
		"Enemy::@4240": 0x804019b4,
		"Enemy::@2030": 0x80401a34,
		"Enemy::@2032": 0x80401a38,
		"Enemy::@2082": 0x80401ab8,
		"Enemy::@2083": 0x80401abc,
		"Enemy::@2084": 0x80401ac0,
		"Enemy::@2085": 0x80401ac4,
		"Enemy::@2086": 0x80401ac8,
		"Enemy::@2087": 0x80401acc,
		"Enemy::@2088": 0x80401ad0,
		"Enemy::@4374": 0x80401b60,
		"@4374": 0x80401b60,
		"Enemy::@4377": 0x80401b6c,
		"Enemy::@4378": 0x80401b70,
		"Enemy::@4379": 0x80401b74,
		"Enemy::@4832": 0x80401b90,
		"Enemy::@4835": 0x80401b94,
		"Enemy::@4836": 0x80401b98,
		"Enemy::@2474": 0x80401bb8,
		"Enemy::@1638": 0x80401c30,
		"Enemy::@1640": 0x80401c34,
		"Enemy::@1642": 0x80401c38,
		"Enemy::@1644": 0x80401c3c,
		"Enemy::@1647": 0x80401c40,
		"@1647": 0x80401c40,
		"Enemy::@1649": 0x80401c44,
		"@1649": 0x80401c44,
		"Enemy::@1651": 0x80401c48,
		"@1651": 0x80401c48,
		"Enemy::@1653": 0x80401c4c,
		"Enemy::@1655": 0x80401c50,
		"Enemy::@1659": 0x80401c54,
		"Enemy::@1663": 0x80401c58,
		"Enemy::@1665": 0x80401c5c,
		"Enemy::@1668": 0x80401c60,
		"Enemy::@1670": 0x80401c64,
		"Enemy::@1680": 0x80401c68,
		"Enemy::@1683": 0x80401c6c,
		"Enemy::@1685": 0x80401c70,
		"Enemy::@1688": 0x80401c74,
		"Enemy::@1779": 0x80401c78,
		"Enemy::@1781": 0x80401c7c,
		"Enemy::@1787": 0x80401c88,
		"Enemy::@1789": 0x80401c8c,
		"@1789": 0x80401c8c,
		"Enemy::@1791": 0x80401c90,
		"@1791": 0x80401c90,
		"Enemy::@1794": 0x80401c94,
		"@1794": 0x80401c94,
		"Enemy::@1796": 0x80401c98,
		"@1796": 0x80401c98,
		"Enemy::@1804": 0x80401ca0,
		"@1804": 0x80401ca0,
		"Enemy::@1807": 0x80401ca4,
		"Enemy::@1809": 0x80401ca8,
		"Enemy::@1811": 0x80401cac,
		"Enemy::@1813": 0x80401cb0,
		"@1813": 0x80401cb0,
		"Enemy::@1815": 0x80401cb4,
		"@1815": 0x80401cb4,
		"Enemy::@1817": 0x80401cb8,
		"@1817": 0x80401cb8,
		"Enemy::@1819": 0x80401cbc,
		"Enemy::@1823": 0x80401cc0,
		"@1823": 0x80401cc0,
		"Enemy::sEmitSandFrameFoot": 0x80401da8,
		"sEmitSandFrameFoot": 0x80401da8,
		"Enemy::@4729": 0x80401ee4,
		"Enemy::@2137": 0x80401fa0,
		"Enemy::@2138": 0x80401fa4,
		"Enemy::@2149": 0x80401fb0,
		"@unnamed@::cRedColor": 0x80401fc0,
		"cRedColor": 0x80401fc0,
		"@unnamed@::cBlueColor": 0x80401fc8,
		"cBlueColor": 0x80401fc8,
		"Enemy::@3864": 0x8040212c,
		"@3864": 0x8040212c,
		"Enemy::@4199": 0x80402150,
		"Enemy::@5252": 0x80402194,
		"Enemy::@5253": 0x80402198,
		"Enemy::@5506": 0x804021a0,
		"@5506": 0x804021a0,
		"Enemy::@5507": 0x804021a4,
		"@5507": 0x804021a4,
		"Enemy::@1966": 0x804021c0,
		"Enemy::@2039": 0x804021c4,
		"Enemy::@2040": 0x804021c8,
		"Enemy::@2119": 0x804021cc,
		"Enemy::@2152": 0x804021d0,
		"Enemy::@3774": 0x80402320,
		"Enemy::@6421": 0x80402350,
		"@6421": 0x80402350,
		"Enemy::@6422": 0x80402354,
		"@6422": 0x80402354,
		"Enemy::@6423": 0x80402358,
		"@6423": 0x80402358,
		"Enemy::@3636": 0x804024a0,
		"Enemy::@3600": 0x80402704,
		"Enemy::@2126": 0x80402744,
		"Enemy::@2127": 0x80402748,
		"Enemy::@2128": 0x8040274c,
		"Enemy::@2129": 0x80402750,
		"Enemy::@2130": 0x80402754,
		"Enemy::@2131": 0x80402758,
		"Camera::@2112": 0x8040808c,
		"Camera::@2113": 0x80408090,
		"Camera::@2304": 0x80408098,
		"Camera::@2305": 0x8040809c,
		"Camera::@2306": 0x804080a0,
		"Camera::@2307": 0x804080a4,
		"Camera::@2308": 0x804080a8,
		"Camera::@2309": 0x804080ac,
		"Camera::@1717": 0x804080c0,
		"@1717": 0x804080c0,
		"Camera::@1655": 0x80408148,
		"Camera::@1663": 0x80408158,
		"Camera::@1659": 0x80408168,
		"Camera::@1660": 0x8040816c,
		"Camera::@2403": 0x804081ac,
		"Camera::@2404": 0x804081b0,
		"Camera::@1896": 0x80408228,
		"@1896": 0x80408228,
		"Camera::@1900": 0x80408230,
		"Camera::@1902": 0x80408234,
		"Camera::@1904": 0x80408238,
		"Camera::@1914": 0x80408244,
		"@1914": 0x80408244,
		"Camera::@1916": 0x80408248,
		"@1916": 0x80408248,
		"Camera::@1918": 0x8040824c,
		"@1918": 0x8040824c,
		"Camera::@1920": 0x80408250,
		"@1920": 0x80408250,
		"Camera::@1938": 0x80408254,
		"Camera::@1940": 0x80408258,
		"Camera::@1942": 0x8040825c,
		"Camera::@1945": 0x80408260,
		"Camera::@1947": 0x80408264,
		"Camera::@1958": 0x80408278,
		"Camera::@1960": 0x8040827c,
		"Camera::@1963": 0x80408280,
		"Camera::@1965": 0x80408284,
		"Camera::@2121": 0x80408288,
		"Camera::@2126": 0x8040828c,
		"Camera::@2128": 0x80408290,
		"Camera::@2132": 0x80408294,
		"Camera::@2134": 0x80408298,
		"Camera::@2137": 0x8040829c,
		"Camera::@2145": 0x804082a0,
		"Camera::@2205": 0x804082a4,
		"Camera::@1807": 0x804082c0,
		"Camera::@1808": 0x804082c4,
		"Camera::@1810": 0x804082cc,
		"Camera::@1811": 0x804082d0,
		"Camera::@2158": 0x80408380,
		"Camera::@2159": 0x80408384,
		"Camera::@2160": 0x80408388,
		"Camera::@1864": 0x804083a4,
		"@1864": 0x804083a4,
		"Camera::@1865": 0x804083a8,
		"Camera::@1887": 0x804083b8,
		"@1887": 0x804083b8,
		"Camera::@2042": 0x804083e0,
		"Camera::@2043": 0x804083e4,
		"Camera::@2044": 0x804083e8,
		"Camera::@2045": 0x804083ec,
		"Camera::@1778": 0x804083f8,
		"Camera::@1652": 0x80408420,
		"Camera::@1653": 0x80408424,
		"Camera::@1758": 0x80408438,
		"Camera::@1759": 0x8040843c,
		"@1759": 0x8040843c,
		"Camera::@1762": 0x80408450,
		"@1762": 0x80408450,
		"Camera::@1763": 0x80408454,
		"Camera::@1705": 0x8040849c,
		"Camera::@1706": 0x804084a0,
		"Camera::@1707": 0x804084a4,
		"Camera::@1710": 0x804084b0,
		"Camera::@1765": 0x804084b4,
		"@1765": 0x804084b4,
		"Camera::@1768": 0x804084fc,
		"Animal::@2190": 0x803ffaa0,
		"Animal::@2191": 0x803ffaa4,
		"Animal::@2192": 0x803ffaa8,
		"Animal::@2193": 0x803ffaac,
		"Animal::@2194": 0x803ffab0,
		"Animal::@2195": 0x803ffab4,
		"Animal::@2196": 0x803ffab8,
		"Animal::@2202": 0x803ffac8,
		"Animal::@2203": 0x803ffacc,
		"Animal::@2289": 0x803ffad0,
		"Animal::@2290": 0x803ffad4,
		"Animal::@2526": 0x803ffad8,
		"Animal::@2527": 0x803ffadc,
		"Animal::@2528": 0x803ffae0,
		"Animal::@2529": 0x803ffae4,
		"Animal::@2530": 0x803ffae8,
		"Animal::@2531": 0x803ffaec,
		"Animal::@2532": 0x803ffaf0,
		"Animal::@2533": 0x803ffaf4,
		"Animal::@2577": 0x803ffaf8,
		"Animal::@2578": 0x803ffafc,
		"Animal::@2580": 0x803ffb04,
		"Animal::@2455": 0x803ffb14,
		"Animal::@2456": 0x803ffb18,
		"Animal::@2457": 0x803ffb1c,
		"Animal::@2601": 0x803ffb44,
		"Animal::@2605": 0x803ffb48,
		"Animal::@2606": 0x803ffb4c,
		"Animal::@2760": 0x803ffb50,
		"Animal::@2761": 0x803ffb54,
		"Animal::@2762": 0x803ffb58,
		"Animal::@2763": 0x803ffb5c,
		"Animal::@2764": 0x803ffb60,
		"Animal::@2765": 0x803ffb64,
		"Animal::@2766": 0x803ffb68,
		"Animal::@2767": 0x803ffb6c,
		"Animal::@2768": 0x803ffb70,
		"Animal::@2929": 0x803ffb74,
		"Animal::@3022": 0x803ffb78,
		"Animal::@3023": 0x803ffb7c,
		"Animal::@3201": 0x803ffb90,
		"Animal::@3267": 0x803ffb94,
		"Animal::@3268": 0x803ffb98,
		"Animal::@3269": 0x803ffb9c,
		"Animal::@2600": 0x803ffba0,
		"Animal::@2613": 0x803ffba4,
		"Animal::@1564": 0x803ffba8,
		"Animal::@1566": 0x803ffbac,
		"Animal::@1568": 0x803ffbb0,
		"Animal::@1570": 0x803ffbb4,
		"Animal::@1572": 0x803ffbb8,
		"Animal::@1574": 0x803ffbbc,
		"Animal::@1576": 0x803ffbc0,
		"Animal::@1578": 0x803ffbc4,
		"Animal::@2158": 0x803ffbc8,
		"Animal::@2159": 0x803ffbcc,
		"Animal::@2160": 0x803ffbd0,
		"Animal::@3220": 0x803ffbf4,
		"Animal::@3221": 0x803ffbf8,
		"Animal::@3303": 0x803ffc08,
		"Animal::@3407": 0x803ffc0c,
		"Animal::@3411": 0x803ffc10,
		"Animal::@3412": 0x803ffc14,
		"Animal::@3453": 0x803ffc18,
		"Animal::@3544": 0x803ffc1c,
		"Animal::@3545": 0x803ffc20,
		"Animal::@3691": 0x803ffc24,
		"Animal::@3692": 0x803ffc28,
		"Animal::@3773": 0x803ffc2c,
		"Animal::@3930": 0x803ffc30,
		"Animal::@3933": 0x803ffc34,
		"Animal::@3935": 0x803ffc38,
		"Animal::@3937": 0x803ffc3c,
		"Animal::@3939": 0x803ffc40,
		"Animal::@3944": 0x803ffc44,
		"Animal::@3946": 0x803ffc48,
		"Animal::@3951": 0x803ffc4c,
		"Animal::@3954": 0x803ffc50,
		"Animal::@4172": 0x803ffc54,
		"Animal::@4173": 0x803ffc58,
		"Animal::@4755": 0x803ffc5c,
		"Animal::@4897": 0x803ffc60,
		"Animal::@4898": 0x803ffc68,
		"Animal::@4921": 0x803ffc6c,
		"Animal::@4922": 0x803ffc70,
		"Animal::@4923": 0x803ffc74,
		"Animal::@3087": 0x803ffc78,
		"Animal::@3088": 0x803ffc7c,
		"Animal::@3089": 0x803ffc80,
		"Animal::@3203": 0x803ffc84,
		"Animal::@3204": 0x803ffc88,
		"Animal::@3205": 0x803ffc8c,
		"Animal::@3206": 0x803ffc90,
		"Animal::@3207": 0x803ffc94,
		"Animal::@3208": 0x803ffc98,
		"Animal::@3448": 0x803ffca0,
		"Animal::@3664": 0x803ffca4,
		"Animal::@3667": 0x803ffca8,
		"Animal::@3668": 0x803ffcac,
		"Animal::@3669": 0x803ffcb4,
		"Animal::@3671": 0x803ffcb8,
		"Animal::@3673": 0x803ffcbc,
		"Animal::@3676": 0x803ffcc0,
		"Animal::@3852": 0x803ffcd0,
		"Animal::@3853": 0x803ffcd4,
		"Animal::@3854": 0x803ffcd8,
		"Animal::@3855": 0x803ffcdc,
		"Animal::@4245": 0x803ffce0,
		"Animal::@4246": 0x803ffce4,
		"Animal::@4332": 0x803ffce8,
		"Animal::@4452": 0x803ffcec,
		"Animal::@4453": 0x803ffcf0,
		"@4453": 0x803ffcf0,
		"Animal::@4454": 0x803ffcf4,
		"Animal::@4455": 0x803ffcf8,
		"Animal::@4456": 0x803ffcfc,
		"Animal::@4641": 0x803ffd00,
		"Animal::@4642": 0x803ffd04,
		"Animal::@4709": 0x803ffd0c,
		"Animal::@4869": 0x803ffd10,
		"Animal::@4870": 0x803ffd14,
		"Animal::@5080": 0x803ffd1c,
		"Animal::@5340": 0x803ffd20,
		"Animal::@2489": 0x803ffd28,
		"Animal::@2490": 0x803ffd2c,
		"Animal::@2491": 0x803ffd30,
		"Animal::@2492": 0x803ffd38,
		"Animal::@2586": 0x803ffd3c,
		"Animal::@2587": 0x803ffd40,
		"Animal::@2588": 0x803ffd44,
		"Animal::@2589": 0x803ffd48,
		"Animal::@2590": 0x803ffd4c,
		"Animal::@2591": 0x803ffd50,
		"Animal::@2592": 0x803ffd54,
		"Animal::@2593": 0x803ffd58,
		"Animal::@2710": 0x803ffd60,
	},
}
